(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1870309,      45385]*)
(*NotebookOutlinePosition[   1871045,      45411]*)
(*  CellTagsIndexPosition[   1871001,      45407]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Maximum-likelihood examples: Normal density", "Title"],

Cell[TextData[{
  "This notebook gives examples of maximum-likelihood estimation for the \
Normal density, and assumes that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated."
}], "Text"],

Cell[CellGroupData[{

Cell["Global user definitions", "Section"],

Cell[CellGroupData[{

Cell["Colors representing two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Data colors", "Subsubsection"],

Cell[BoxData[{
    \(\(data1Color = Red;\)\), "\[IndentingNewLine]", 
    \(\(data2Color = Blue;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(style1\  = \ {data1Color, 
          PointSize[ .02]};\)\), "\[IndentingNewLine]", 
    \(\(style2\  = \ {data2Color, PointSize[ .02]};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification region colors", "Subsubsection"],

Cell[BoxData[{
    \(\(class1Color\  = \ RGBColor[1, 1,  .5];\)\), "\[IndentingNewLine]", 
    \(\(class2Color\  = \ RGBColor[ .5, 1, 1];\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(classColors\  = \ {class1Color, \ class2Color};\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Default plot range", "Subsection"],

Cell[BoxData[
    \(\(pr\  = \ {{\(-1\), 1}, {\(-1\), 1}};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["No frame ticks", "Subsection"],

Cell[BoxData[{
    \(\(nF = FrameTicks \[Rule] None;\)\), "\[IndentingNewLine]", 
    \(\(FS = Sequence[yS, \ nF];\)\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Example A: Uniform distributions\
\>", "Section"],

Cell[CellGroupData[{

Cell["Generate data from two uniform classes", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 100;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = \ 
        Table[{ru2[{pr[\([1, 1]\)], 0}], 
            ru2[pr[\([2]\)]]}, {n1}];\)\), "\n", 
    \(\(data2\  = \ 
        Table[{ru2[{0, pr[\([1, 2]\)]}], 
            ru2[pr[\([2]\)]]}, {n2}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, gd2, FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.19952 .78592 Mdot
.11998 .52055 Mdot
.35491 .83474 Mdot
.3554 .34672 Mdot
.0072 .89729 Mdot
.30746 .43669 Mdot
.36539 .67123 Mdot
.20317 .34479 Mdot
.19388 .91671 Mdot
.33213 .82124 Mdot
.42016 .221 Mdot
.38943 .90797 Mdot
.22559 .43013 Mdot
.27441 .39237 Mdot
.37069 .59045 Mdot
.41901 .0506 Mdot
.36843 .68821 Mdot
.11649 .60896 Mdot
.00799 .02192 Mdot
.41332 .26912 Mdot
.31411 .10026 Mdot
.08615 .44293 Mdot
.39395 .87431 Mdot
.19671 .53001 Mdot
.17331 .44913 Mdot
.42231 .14258 Mdot
.30262 .85373 Mdot
.00825 .09693 Mdot
.43419 .17047 Mdot
.39175 .48302 Mdot
.43115 .1535 Mdot
.47843 .21885 Mdot
.12198 .05818 Mdot
.39724 .77098 Mdot
.22803 .17892 Mdot
.20548 .24592 Mdot
.05967 .72485 Mdot
.28317 .10828 Mdot
.25705 .86617 Mdot
.27988 .0163 Mdot
.32286 .70065 Mdot
.38812 .52833 Mdot
.39171 .5521 Mdot
.40969 .31442 Mdot
.27468 .49887 Mdot
.0174 .5385 Mdot
.0516 .32489 Mdot
.31192 .29753 Mdot
.49193 .5951 Mdot
.0337 .1942 Mdot
.23983 .72398 Mdot
.25382 .18285 Mdot
.41697 .02828 Mdot
.3657 .64957 Mdot
.03021 .47123 Mdot
.45601 .34009 Mdot
.25553 .96741 Mdot
.44357 .79664 Mdot
.20888 .64747 Mdot
.1366 .50406 Mdot
.21695 .05732 Mdot
.10785 .31482 Mdot
.47712 .3284 Mdot
.35403 .13692 Mdot
.0651 .30507 Mdot
.48832 .4824 Mdot
.03985 .82889 Mdot
.03726 .14726 Mdot
.28432 .85652 Mdot
.09369 .34567 Mdot
.08039 .21401 Mdot
.4571 .83666 Mdot
.36343 .16163 Mdot
.3542 .52679 Mdot
.38631 .82828 Mdot
.00513 .39482 Mdot
.32615 .52817 Mdot
.0168 .90747 Mdot
.29126 .69433 Mdot
.47954 .76516 Mdot
.01189 .83285 Mdot
.3908 .42444 Mdot
.43151 .6238 Mdot
.4337 .58283 Mdot
.07303 .46712 Mdot
.08445 .06099 Mdot
.18672 .63388 Mdot
.08428 .66122 Mdot
.36056 .11067 Mdot
.07242 .7488 Mdot
.07425 .41139 Mdot
.09288 .97869 Mdot
.06731 .57358 Mdot
.20208 .5592 Mdot
.1358 .94483 Mdot
.26839 .97142 Mdot
.06773 .48266 Mdot
.18889 .91538 Mdot
.38101 .84383 Mdot
.10956 .25911 Mdot
0 0 1 r
.97461 .73811 Mdot
.95791 .50536 Mdot
.54886 .33168 Mdot
.5508 .52172 Mdot
.61122 .75315 Mdot
.74793 .95757 Mdot
.74207 .80336 Mdot
.51632 .9812 Mdot
.80485 .32565 Mdot
.70025 .07076 Mdot
.68586 .47687 Mdot
.80486 .8067 Mdot
.7063 .73381 Mdot
.842 .30628 Mdot
.65744 .40708 Mdot
.7912 .77961 Mdot
.54622 .64898 Mdot
.54327 .81709 Mdot
.79919 .84067 Mdot
.52695 .83095 Mdot
.98939 .51997 Mdot
.82175 .76513 Mdot
.80354 .04804 Mdot
.51689 .95349 Mdot
.59724 .30929 Mdot
.66994 .65215 Mdot
.93485 .89725 Mdot
.87379 .86759 Mdot
.88863 .25322 Mdot
.83052 .05545 Mdot
.58944 .4076 Mdot
.80357 .21955 Mdot
.59509 .88268 Mdot
.97686 .44946 Mdot
.78661 .83959 Mdot
.95997 .49103 Mdot
.68937 .53525 Mdot
.79003 .83392 Mdot
.74957 .63305 Mdot
.91128 .96138 Mdot
.85599 .38478 Mdot
.58076 .91089 Mdot
.76655 .97223 Mdot
.77224 .69629 Mdot
.67146 .09449 Mdot
.79043 .25178 Mdot
.8799 .24995 Mdot
.82551 .7558 Mdot
.69053 .70975 Mdot
.53548 .91693 Mdot
.93601 .08165 Mdot
.61925 .95059 Mdot
.58002 .69192 Mdot
.53849 .04465 Mdot
.80851 .71475 Mdot
.76129 .34341 Mdot
.63705 .6252 Mdot
.96591 .09658 Mdot
.7522 .3802 Mdot
.6404 .33583 Mdot
.56167 .6655 Mdot
.60492 .41395 Mdot
.62071 .58879 Mdot
.98072 .4584 Mdot
.5407 .89192 Mdot
.94223 .4187 Mdot
.72724 .18212 Mdot
.68094 .08024 Mdot
.59018 .55197 Mdot
.71007 .97871 Mdot
.83303 .17673 Mdot
.56967 .64783 Mdot
.77136 .50628 Mdot
.9598 .23883 Mdot
.65065 .91253 Mdot
.97413 .77548 Mdot
.60995 .02557 Mdot
.53189 .36173 Mdot
.87777 .83849 Mdot
.84601 .28644 Mdot
.78758 .29147 Mdot
.63593 .30278 Mdot
.9496 .11969 Mdot
.56627 .65 Mdot
.67824 .60846 Mdot
.60152 .41611 Mdot
.52759 .69098 Mdot
.62244 .63568 Mdot
.91269 .67037 Mdot
.59055 .2789 Mdot
.53492 .82692 Mdot
.73959 .98751 Mdot
.74239 .54041 Mdot
.60366 .68968 Mdot
.78784 .42566 Mdot
.53739 .04464 Mdot
.6096 .81225 Mdot
.93092 .62357 Mdot
.58201 .12622 Mdot
.80848 .98294 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo04cooooo0ooo
003<ooooo`4000000Oooool000?oo`00Boooool5ool00<_ooooo0@000001ooooo`001?oo001:oooo
o`Goo`00F_ooool3o`00ofkooooo0@000001ooooo`001?oo001:ooooo`Goo`008oooool3ool003?o
oooo1Ol00?m]ooooo`4000000Oooool000Coo`00Boooool3ool002?ooooo1Ooo000booooo`Go003o
KOooool10000007ooooo0003ool007;ooooo1Ooo000booooo`Go003oKOooool10000007ooooo0000
0`00003oooooooooo`1booooo`Goo`00<oooool3o`00ofkooooo0@000001ooooo`0000<00000oooo
ooooool0Loooool3ool00:Gooooo0@000001ooooo`0000<00000ooooooooool0UOooool4o`00oh;o
oooo0@000001ooooo`0000<00000ooooooooool0Loooool3ool001kooooo1_l00?m8ooooo`?o003o
=_ooool10000007ooooo00000`00003oooooooooo`1booooo`Goo`007Oooool6o`00odOooooo1Ol0
0?leooooo`4000000Oooool0000300000?oooooooooo03[ooooo0ooo000eooooo`Goo`007Oooool6
o`00odOooooo1Ol00?l3ooooo`?o003o;oooool10000007ooooo00000`00003oooooooooo`0Doooo
o`?oo`001oooool3ool001Sooooo1Ooo000dooooo`Goo`007_ooool4o`00odSooooo1Ol00?l2oooo
o`Go003o;_ooool10000007ooooo00000`00003oooooooooo`0Cooooo`Goo`001Oooool5ool001Oo
oooo1Ooo000eooooo`?oo`00K?ooool3o`00o`?ooooo1Ol00?l^ooooo`4000000Oooool000030000
0?oooooooooo01?ooooo1Ooo0005ooooo`Goo`005oooool5ool00:[ooooo1Ol00?l^ooooo`400000
0Oooool0000300000?oooooooooo01?ooooo1Ooo0005ooooo`Goo`006?ooool3ool008Oooooo0ol0
0?lRooooo`?o003o;oooool10000007ooooo00000`00003oooooooooo`0Dooooo`?oo`001oooool3
ool00:;ooooo1Ol00?mCooooo`4000000Oooool0000300000?oooooooooo0<?ooooo1Ol00?mCoooo
o`4000000Oooool0000300000?oooooooooo0;oooooo0ol00?l00ooooooo003oo`00o`03o`00od3o
oooo0ol00?l@ooooo`4000000Oooool0000300000?oooooooooo0;kooooo1Ol00?l01?oooooo003o
o`00ool00?m0ooooo`Go003o3oooool10000007ooooo00000`00003oooooooooo`2nooooo`Go003o
A?ooool5o`00o`oooooo0@000001ooooo`0000<00000ooooooooool0__ooool5o`00odCooooo1Ol0
0?l?ooooo`4000000Oooool0000300000?oooooooooo0;cooooo1_l00?m6ooooo`?o003o4?ooool1
0000007ooooo0003ool00;_ooooo1Ol00?m@ooooo`?o003o2?ooool10000007ooooo0004ool005Co
oooo0ooo001Sooooo`Go003oCoooool5o`00o`Oooooo0@000001ooooo`001?oo001Cooooo`Goo`00
H_ooool5o`00odoooooo1Ol00?l7ooooo`4000000Oooool000Coo`00C?ooool3ool000Cooooo1Ooo
001Sooooo`?o003oD?ooool5o`00o`Oooooo0@000001ooooo`000ooo001<ooooo`Goo`000oooool5
ool000[ooooo0ooo002Zooooo`?o003o2?ooool10000007ooooo00000`00003oooooooooo`1<oooo
o`Goo`001?ooool3ool000[ooooo1Ooo002dooooo`4000000Oooool0000300000?oooooooooo04co
oooo1Ooo000Aooooo`Goo`00YOooool3o`00o`cooooo0@000001ooooo`0000<00000ooooooooool0
COooool3ool001;ooooo1Ooo002Tooooo`Go003o2oooool10000007ooooo00000`00003ooooooooo
o`1Sooooo`?oo`00??ooool3o`00ofKooooo1Ol00?l;ooooo`4000000Oooool0000300000?oooooo
oooo0:7ooooo1Ol00?mUooooo`Go003o2oooool10000007ooooo00000`00003oooooooooo`2Qoooo
o`Go003oI_ooool3o`00o`cooooo0@000001ooooo`0000<00000ooooooooool0HOooool3ool003go
oooo1Ol00?meooooo`4000000Oooool0000300000?oooooooooo063ooooo1Ooo000mooooo`?o003o
M_ooool10000007ooooo00000`00003oooooooooo`1Pooooo`Goo`003oooool3ool00:Cooooo0@00
0001ooooo`0000<00000ooooooooool01_ooool3ool005Oooooo1Ooo000>ooooo`Goo`00Xoooool1
0000007ooooo00000`00003oooooooooo`05ooooo`Goo`00Eoooool3ool000oooooo1Ooo002Soooo
o`4000000Oooool0000300000?oooooooooo00Gooooo1Ooo001Yooooo`Ooo`00XOooool10000007o
oooo00000`00003oooooooooo`05ooooo`Goo`00J_ooool7ool00:3ooooo0@000001ooooo`0000<0
0000ooooooooool01_ooool3ool005_ooooo0ooo000?ooooo`Goo`00X?ooool10000007ooooo0000
0`00003oooooooooo`1Sooooo`Goo`003_ooool5ool00:3ooooo0@000001ooooo`0000<00000oooo
ooooool0Hoooool5ool000oooooo0ooo002Qooooo`4000000Oooool0000300000?oooooooooo06?o
oooo1Ooo000@ooooo`?oo`00X?ooool10000007ooooo00000`00003oooooooooo`1Tooooo`?oo`00
4?ooool5ool009oooooo0@000001ooooo`0000<00000ooooooooool0?Oooool3ool003Oooooo1Ooo
001^ooooo`?o003o;_ooool10000007ooooo00000`00003oooooooooo`0looooo`Goo`000oooool3
ool0033ooooo1Ooo001@ooooo`?o003o6_ooool5o`00obgooooo0@000001ooooo`0000<00000oooo
ooooool0??ooool5ool000;ooooo1Ooo000`ooooo`?oo`00D?ooool5o`00oaWooooo1Ol00?l]oooo
o`4000000Oooool0000300000?oooooooooo03cooooo1Ooo0002ooooo`Goo`00Poooool5o`00oaWo
oooo1Ol00?l]ooooo`4000000Oooool0000300000?oooooooooo03gooooo0ooo0003ooooo`Goo`00
Poooool5o`00oa[ooooo0ol00?l^ooooo`4000000Oooool0000300000?oooooooooo00Gooooo0ooo
000looooo`?oo`00QOooool3o`00odcooooo0@000001ooooo`0000<00000ooooooooool01?ooool5
ool00?oooooo4oooool10000007ooooo00000`00003oooooooooo`04ooooo`Goo`00oooooolCoooo
o`4000000Oooool0000300000?oooooooooo00Cooooo1Ooo003ooooooa?ooooo0@000001ooooo`00
00<00000ooooooooool01Oooool3ool00?oooooo5?ooool10000007ooooo00000`00003ooooooooo
o`0Booooo`?oo`00ooooool7ooooo`4000000Oooool0000300000?oooooooooo017ooooo1Ooo003o
ooooo`Kooooo0@000001ooooo`0000<00000ooooooooool04Oooool5ool005kooooo0ooo000>oooo
o`?oo`00F_ooool3o`00ocKooooo0@000001ooooo`0000<00000ooooooooool04Oooool5ool005go
oooo1Ooo000<ooooo`Goo`00F?ooool5o`00ocGooooo0@000001ooooo`0000<00000ooooooooool0
4_ooool3ool005kooooo1Ooo000<ooooo`Goo`00F?ooool5o`00ocGooooo0@000001ooooo`0000<0
0000ooooooooool0Loooool5ool000cooooo1Ooo001Hooooo`Go003o=Oooool10000007ooooo0000
0`00003oooooooooo`1dooooo`?oo`003_ooool3ool005[ooooo0ol00?lfooooo`4000000Oooool0
000300000?oooooooooo0?oooooo4?ooool3o`00o`Wooooo0@000001ooooo`0000<00000oooooooo
ool0ooooool?ooooo`Go003o2?ooool10000007ooooo00000`00003oooooooooo`0fooooo`?oo`00
eOooool5o`00o`Sooooo0@000001ooooo`0000<00000ooooooooool0=Oooool5ool00=Cooooo1Ol0
0?l8ooooo`4000000Oooool0000300000?oooooooooo03Gooooo1Ooo002Tooooo`?o003o5oooool3
o`00oaCooooo0ol00?l9ooooo`4000000Oooool0000300000?oooooooooo03Gooooo1Ooo002Soooo
o`Go003o5Oooool6o`00oakooooo0@000001ooooo`0000<00000ooooooooool06oooool3ool001So
oooo0ooo002Tooooo`Go003o5Oooool7o`00oagooooo0@000001ooooo`0000<00000ooooooooool0
6_ooool5ool00;kooooo1Ol00?lEooooo`Oo003o7Oooool10000007ooooo00000`00003ooooooooo
o`0Jooooo`Goo`00_oooool3o`00oaOooooo1_l00?lMooooo`4000000Oooool0000300000?oooooo
oooo01[ooooo1Ooo001Cooooo`?oo`00QOooool3o`00oakooooo0@000001ooooo`0000<00000oooo
ooooool06oooool3ool005?ooooo1Ooo002Uooooo`4000000Oooool0000300000?oooooooooo077o
oooo1Ooo002Uooooo`4000000Oooool0000300000?oooooooooo077ooooo1Ooo000_ooooo`?o003o
Loooool10000007ooooo00000`00003oooooooooo`1booooo`?oo`00;oooool5o`00og;ooooo0@00
0001ooooo`0000<00000ooooooooool0Y?ooool5o`00odGooooo0ol00?lZooooo`4000000Oooool0
000300000?oooooooooo0:Cooooo1Ol00?m4ooooo`Go003o:Oooool10000007ooooo00000`00003o
ooooooooo`2Uooooo`?o003o=Oooool3o`00o`gooooo1Ol00?lYooooo`4000000Oooool000030000
0?oooooooooo05Gooooo0ooo0024ooooo`Go003o3?ooool5o`00obWooooo0@000001ooooo`0000<0
0000ooooooooool0E?ooool5ool008?ooooo1Ol00?l=ooooo`?o003o:_ooool10000007ooooo0000
0`00003oooooooooo`0>ooooo`?oo`00@oooool5ool005Wooooo0ol00?lWooooo`Go003o>_ooool1
0000007ooooo00000`00003oooooooooo`0=ooooo`Goo`00@_ooool5ool005Sooooo1Ol00?lWoooo
o`?o003o3Oooool3o`00ob_ooooo0@000001ooooo`0000<00000ooooooooool03Oooool5ool004?o
oooo0ooo001?ooooo`?o003o1oooool5o`00ocKooooo1Ol00?lZooooo`4000000Oooool000030000
0?oooooooooo00gooooo1Ooo0008ooooo`?oo`00E?ooool3ool003;ooooo1Ol00?l6ooooo`Go003o
=_ooool5o`00ob[ooooo0@000001ooooo`0000<00000ooooooooool03_ooool3ool000Sooooo1Ooo
001Booooo`Goo`00<Oooool5o`00o`Oooooo0ol00?lgooooo`Go003o:_ooool10000007ooooo0000
0`00003oooooooooo`0Iooooo`Goo`00D_ooool5ool0037ooooo1Ol00?m2ooooo`?o003o:oooool1
0000007ooooo00000`00003oooooooooo`0:ooooo`?oo`003?ooool5ool005;ooooo1Ooo000boooo
o`?o003o>?ooool3o`00ocKooooo0@000001ooooo`0000<00000ooooooooool02Oooool5ool000co
oooo0ooo001Dooooo`?oo`004?ooool3ool005[ooooo1Ol00?leooooo`4000000Oooool000030000
0?oooooooooo00Wooooo1Ooo001eooooo`Goo`004Oooool3o`00odGooooo1Ol00?leooooo`400000
0Oooool0000300000?oooooooooo00Wooooo1Ooo001eooooo`Goo`004?ooool5o`00oaKooooo0ol0
0?l[ooooo`Go003o=Oooool10000007ooooo00000`00003oooooooooo`0:ooooo`?oo`00LOooool3
ool000;ooooo1Ooo000@ooooo`Go003o5Oooool5o`00ob_ooooo0ol00?lfooooo`4000000Oooool0
000300000?oooooooooo07gooooo1Ooo0002ooooo`?oo`004Oooool5o`00oaGooooo1Ol00?lOoooo
o`?o003o@_ooool10000007ooooo00000`00003oooooooooo`0Fooooo`?oo`007Oooool3ool002So
oooo0ooo000Iooooo`Goo`005oooool3o`00oaKooooo1Ol00?lNooooo`Go003o@Oooool10000007o
oooo00000`00003oooooooooo`0Eooooo`Goo`006oooool5ool002Kooooo1Ooo000Hooooo`Goo`00
<Oooool3o`00oaoooooo1Ol00?m1ooooo`4000000Oooool0000300000?oooooooooo01Gooooo1Ooo
000Kooooo`Goo`009_ooool5ool001Wooooo0ooo001Dooooo`Go003o@Oooool10000007ooooo0000
0`00003oooooooooo`0Eooooo`Goo`006oooool5ool002Kooooo1Ooo001aooooo`?o003o@_ooool1
0000007ooooo00000`00003oooooooooo`0Fooooo`?oo`007Oooool3ool002Sooooo0ooo002goooo
o`4000000Oooool0000300000?oooooooooo09Cooooo0ol00?n4ooooo`4000000Oooool000030000
0?oooooooooo09?ooooo1Ol00?n3ooooo`4000000Oooool0000300000?oooooooooo09?ooooo1Ol0
0?n3ooooo`4000000Oooool0000300000?oooooooooo09?ooooo1Ol00?n3ooooo`4000000Oooool0
000300000?oooooooooo09Cooooo0ol00?n4ooooo`4000000Oooool0000300000?oooooooooo0=?o
oooo0ol00?m5ooooo`4000000Oooool0000300000?oooooooooo0=;ooooo1Ol00?lJooooo`?o003o
9oooool10000007ooooo00000`00003oooooooooo`3Booooo`Go003o6Oooool5o`00obKooooo0@00
0001ooooo`0000<00000ooooooooool0B_ooool3ool008Gooooo1Ol00?lIooooo`Go003o9_ooool1
0000007ooooo0002ool004[ooooo1Ooo0025ooooo`?o003o6_ooool5o`00obKooooo0@000001oooo
o`000ooo0019ooooo`Goo`00Xoooool3o`00obOooooo0@000001ooooo`000ooo0019ooooo`Goo`00
cOooool10000007ooooo0003ool004[ooooo0ooo003>ooooo`4000000Oooool000;oo`00YOooool3
o`00oa7ooooo0ol00?mPooooo`4000000Oooool0000300000?oooooooooo017ooooo0ooo002?oooo
o`Go003o3oooool5o`00oeoooooo0@000001ooooo`0000<00000ooooooooool04?ooool5ool008ko
oooo2Ol00?l;ooooo`Go003oGoooool10000007ooooo00000`00003oooooooooo`0@ooooo`Goo`00
S_ooool:o`00o`[ooooo1Ol00?m=ooooo`?o003o3oooool10000007ooooo00000`00003ooooooooo
o`0@ooooo`Goo`00Soooool9o`00o`_ooooo0ol00?m=ooooo`Go003o3_ooool10000007ooooo0000
0`00003oooooooooo`0Aooooo`?oo`00Eoooool3ool003Wooooo1_l00?l`ooooo`?o003o:?ooool5
o`00o`kooooo0@000001ooooo`0000<00000ooooooooool0??ooool3ool002_ooooo1Ooo000ioooo
o`Co003o<?ooool5o`00obOooooo1Ol00?l>ooooo`4000000Oooool0000300000?oooooooooo03_o
oooo1Ooo000Zooooo`Goo`00KOooool5o`00obSooooo0ol00?l?ooooo`4000000Oooool000030000
0?oooooooooo03_ooooo1Ooo000Cooooo`?oo`005?ooool5ool006gooooo1Ol00?ljooooo`400000
0Oooool0000300000?oooooooooo03_ooooo1Ooo000Booooo`Goo`005?ooool3ool006oooooo0ol0
0?lkooooo`4000000Oooool0000300000?oooooooooo01Cooooo0ooo000Uooooo`?oo`004oooool5
ool00<Cooooo0@000001ooooo`0000<00000ooooooooool04oooool5ool003[ooooo1Ooo0034oooo
o`4000000Oooool0000300000?oooooooooo01?ooooo1Ooo000Eooooo`?oo`008oooool3ool00;go
oooo0ol00?l5ooooo`4000000Oooool0000300000?oooooooooo01?ooooo1Ooo000Dooooo`Goo`00
hOooool5o`00o`Cooooo0@000001ooooo`0000<00000ooooooooool05?ooool3ool001Gooooo1Ooo
003Qooooo`Ko003o0oooool10000007ooooo00000`00003oooooooooo`0/ooooo`Goo`00hOooool7
o`00o`;ooooo0@000001ooooo`0000<00000ooooooooool0;Oooool3ool00>?ooooo1_l00?l2oooo
o`4000000Oooool0000300000?oooooooooo013ooooo0ooo003oooooo`;ooooo1Ol00?l2ooooo`40
00000Oooool0000300000?oooooooooo00Cooooo0ooo0008ooooo`Goo`00ooooool2ooooo`?o003o
0oooool10000007ooooo00000`00003oooooooooo`03ooooo`Goo`001oooool5ool00?oooooo2?oo
ool10000007ooooo00000`00003oooooooooo`03ooooo`Goo`001oooool5ool00:cooooo0ol00?mH
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo1Ooo0007ooooo`Coo`00FOooool3ool0
01Sooooo0ooo000eooooo`Go003oEoooool10000007ooooo00000`00003oooooooooo`04ooooo`?o
o`001oooool5ool005Sooooo1Ooo000Fooooo`Goo`00=?ooool5o`00oeOooooo0@000001ooooo`00
00<00000ooooooooool03_ooool5ool005Sooooo1Ooo000Fooooo`Goo`00=?ooool5o`00oeOooooo
0@000001ooooo`0000<00000ooooooooool03_ooool5ool005Sooooo1Ooo000Fooooo`Goo`00=Ooo
ool3o`00odcooooo0ol00?l9ooooo`4000000Oooool0000300000?oooooooooo00oooooo0ooo001J
ooooo`?oo`006?ooool3ool008Cooooo1Ol00?l8ooooo`4000000Oooool0000300000?oooooooooo
04[ooooo0ooo0031ooooo`Go003o2?ooool10000007ooooo00000`00003oooooooooo`0Rooooo`?o
o`009?ooool5ool00<3ooooo1Ol00?l8ooooo`4000000Oooool0000300000?oooooooooo027ooooo
1Ooo000Sooooo`Goo`00Roooool3o`00oc;ooooo1?l00?l9ooooo`4000000Oooool0000300000?oo
oooooooo027ooooo1Ooo000Sooooo`Goo`00R_ooool5o`00oc3ooooo1Ol00?l9ooooo`4000000Ooo
ool0000300000?oooooooooo027ooooo1Ooo000Tooooo`?oo`00Roooool5o`00oc3ooooo1Ol00?l9
ooooo`4000000Oooool0000300000?oooooooooo02;ooooo0ooo002cooooo`Go003o<?ooool5o`00
o`Wooooo0@000001ooooo`0000<00000ooooooooool07_ooool3ool00;Sooooo0ol00?lbooooo`?o
003o1_ooool3o`00o`7ooooo0@000001ooooo`0000<00000ooooooooool07Oooool5ool007Oooooo
0ol00?mjooooo`Go003o0@000001ooooo`0000<00000ooooooooool07Oooool5ool003Oooooo0ooo
0005ooooo`?oo`001oooool3ool002[ooooo1Ol00?miooooo`Go003o0@000001ooooo`0000<00000
ooooooooool07Oooool5ool001;ooooo0ooo000Qooooo`Goo`000oooool5ool000Gooooo1Ooo000Y
ooooo`Go003oNOooool5o`00o`4000000Oooool0000300000?oooooooooo01kooooo0ooo000Boooo
o`Goo`008?ooool5ool000?ooooo1Ooo0005ooooo`Goo`00:Oooool5o`00obCooooo0ol00?mCoooo
o`?o003o0Oooool10000007ooooo00000`00003oooooooooo`03ool0033ooooo1Ooo000Pooooo`Go
o`000oooool5ool000Gooooo1Ooo000Zooooo`?o003o9?ooool5o`00oeKooooo0@000001ooooo`00
00<00000oooooooo00001?oo000_ooooo`Goo`008Oooool3ool000Gooooo0ooo0007ooooo`?oo`00
D_ooool5o`00o`_ooooo0ol00?m8ooooo`4000000Oooool0000300000?ooooooo`0000Coo`00<?oo
ool3ool008Wooooo1Ol00?l:ooooo`Go003oAoooool10000007ooooo00000`00003oooooool00004
ool00;gooooo0ol00?l;ooooo`Go003oAoooool10000007ooooo00000`00003oooooooooo`03ool0
06Wooooo0ooo000fooooo`?o003o9oooool5o`00odOooooo0@000001ooooo`0000<00000oooooooo
ool0Joooool5ool003Cooooo1Ol00?lWooooo`?o003oB?ooool10000007ooooo00000`00003ooooo
ooooo`0eooooo`?oo`00<oooool5ool003Cooooo1Ol00?mbooooo`4000000Oooool0000300000?oo
oooooooo03Cooooo1Ooo000booooo`Goo`00=?ooool5o`00og;ooooo0@000001ooooo`0000<00000
ooooooooool0=?ooool5ool003?ooooo0ooo000fooooo`?o003oLoooool10000007ooooo00000`00
003oooooooooo`0dooooo`Goo`00h_ooool10000007ooooo00000`00003oooooooooo`0?ooooo`?o
o`008oooool3ool00>?ooooo0@000001ooooo`0000<00000ooooooooool03_ooool5ool00?oooooo
2Oooool10000007ooooo00000`00003oooooooooo`0>ooooo`Goo`00ooooool9ooooo`4000000Ooo
ool0000300000?oooooooooo00kooooo1Ooo001Uooooo`?oo`00X?ooool10000007ooooo00000`00
003oooooooooo`0?ooooo`?oo`00IOooool5ool009oooooo0@000001ooooo`0000<00000oooooooo
ool0I_ooool3ool000kooooo1Ooo000aooooo`?o003oJoooool10000007ooooo00000`00003ooooo
ooooo`1Uooooo`Goo`003Oooool5ool0033ooooo1Ol00?mZooooo`4000000Oooool0000300000?oo
oooooooo06Gooooo1Ooo000>ooooo`?oo`003Oooool3ool0027ooooo1Ol00?mZooooo`4000000Ooo
ool0000300000?oooooooooo06Gooooo1Ooo000Mooooo`Goo`008?ooool5o`00of[ooooo0@000001
ooooo`0000<00000ooooooooool0I_ooool3ool001kooooo1Ooo000Qooooo`?o003oJoooool10000
007ooooo00000`00003oooooooooo`27ooooo`Goo`00<_ooool3o`00oe[ooooo0@000001ooooo`00
00<00000ooooooooool07Oooool3ool006Sooooo0ooo000booooo`Go003oFOooool10000007ooooo
00000`00003oooooooooo`0Looooo`Goo`00W?ooool5o`00oeWooooo0@000001ooooo`0000<00000
ooooooooool07?ooool5ool009cooooo1Ol00?mIooooo`4000000Oooool0000300000?oooooooooo
01cooooo1Ooo002Mooooo`?o003oF_ooool10000007ooooo00000`00003oooooooooo`0Mooooo`?o
o`00Eoooool3ool003Sooooo0ol00?mAooooo`?o003o4_ooool10000007ooooo00000`00003ooooo
ooooo`1fooooo`Goo`00=_ooool5o`00odoooooo1Ol00?lAooooo`4000000Oooool0000300000?oo
oooooooo07Kooooo1Ooo000fooooo`Go003o7?ooool3o`00oc3ooooo1Ol00?lAooooo`4000000Ooo
ool0000300000?oooooooooo037ooooo0ooo0012ooooo`Goo`00<oooool8o`00oa_ooooo1Ol00?l_
ooooo`Go003o4Oooool10000007ooooo00000`00003oooooooooo`0`ooooo`Goo`00@_ooool3ool0
03?ooooo2?l00?lLooooo`Go003o<?ooool3o`00oa;ooooo0@000001ooooo`0000<00000oooooooo
ool0<?ooool5ool007Sooooo1Ol00?lOooooo`Go003oAOooool10000007ooooo00000`00003ooooo
ooooo`0`ooooo`Goo`00N?ooool5o`00ob3ooooo0ol00?m6ooooo`4000000Oooool0000300000?oo
oooooooo037ooooo0ooo0003ooooo`?oo`00:_ooool3ool0037ooooo0ol00?l3ooooo`Co003o3?oo
ool3o`00of[ooooo0@000001ooooo`0000<00000ooooooooool0=_ooool5ool002Sooooo1Ooo000_
ooooo`Go003o00?oooooo`00ool00?l01?l00?lHooooo`?o003oGOooool10000007ooooo00000`00
003oooooooooo`0fooooo`Goo`00:?ooool5ool002oooooo1Ol00?l00ooooooo003oo`00o`04o`00
oaOooooo1Ol00?mLooooo`4000000Oooool0000300000?oooooooooo03Kooooo1Ooo000Xooooo`Go
o`00;oooool5o`00o`03ooooool00?oo003o00Co003o5oooool5o`00oecooooo0@000001ooooo`00
00<00000ooooooooool04oooool3ool0027ooooo0ooo000Zooooo`?oo`00<Oooool3o`00o`?ooooo
1?l00?lHooooo`Go003oG?ooool10000007ooooo00000`00003oooooooooo`0Booooo`Goo`00QOoo
ool3o`00oacooooo0ol00?mMooooo`4000000Oooool0000300000?oooooooooo01;ooooo1Ooo001=
ooooo`?oo`00=?ooool5o`00of7ooooo0ol00?lGooooo`4000000Oooool0000300000?oooooooooo
01;ooooo1Ooo001<ooooo`Goo`00<oooool5o`00of3ooooo1Ol00?lFooooo`4000000Oooool00003
00000?oooooooooo01?ooooo0ooo001=ooooo`Goo`00<oooool5o`00of3ooooo1Ol00?lFooooo`40
00000Oooool0000300000?oooooooooo06?ooooo1Ooo000dooooo`?o003oHOooool5o`00oaKooooo
0@000001ooooo`0000<00000ooooooooool0I?ooool3ool009[ooooo0ol00?lGooooo`4000000Ooo
ool0000300000?oooooooooo06Gooooo0ooo002cooooo`4000000Oooool0000300000?oooooooooo
06Cooooo1Ooo000Zooooo`?o003o3?ooool3o`00o`?ooooo0ol00?m`ooooo`4000000Oooool00003
00000?oooooooooo04oooooo0ooo000Booooo`Goo`00:Oooool5o`00o`[ooooo1Ol00?l00ooooooo
003oo`00o`03o`00ofoooooo0@000001ooooo`0000<00000ooooooooool0C_ooool5ool0017ooooo
1Ooo000Yooooo`Go003o2_ooool5o`00o`03ooooool00?oo003o00?o003o;Oooool3o`00ocoooooo
0@000001ooooo`0000<00000ooooooooool0C_ooool5ool000Gooooo0ooo000:ooooo`?oo`00:_oo
ool5o`00o`[ooooo1Ol00?l00ooooooo003oo`00o`03o`00obcooooo1Ol00?lnooooo`4000000Ooo
ool0000300000?oooooooooo04kooooo1Ooo0004ooooo`Goo`00=oooool3o`00o`cooooo0ol00?l3
ooooo`?o003o;Oooool5o`00ockooooo0@000001ooooo`0000<00000ooooooooool0Coooool3ool0
00Gooooo1Ooo001Uooooo`?o003o5?ooool5o`00ockooooo0@000001ooooo`0000<00000oooooooo
ool0Eoooool5ool006Cooooo1Ol00?lDooooo`?o003o?oooool10000007ooooo00000`00003ooooo
ooooo`1Hooooo`?oo`00IOooool5o`00oakooooo0ol00?leooooo`4000000Oooool0000300000?oo
oooooooo0<3ooooo1Ol00?lMooooo`Go003o=?ooool10000007ooooo00000`00003oooooooooo`31
ooooo`?o003o7_ooool5o`00ocCooooo0@000001ooooo`0000<00000ooooooooool03?ooool3ool0
037ooooo0ooo002Oooooo`Go003o=?ooool10000007ooooo00000`00003oooooooooo`0;ooooo`Go
o`00;oooool5ool009oooooo0ol00?leooooo`4000000Oooool0000300000?oooooooooo00_ooooo
1Ooo000_ooooo`Goo`00P_ooool3o`00oe;ooooo0@000001ooooo`0000<00000ooooooooool02ooo
ool5ool002oooooo1Ooo0021ooooo`Go003oDOooool10000007ooooo00000`00003oooooooooo`0<
ooooo`?oo`00<Oooool3ool008;ooooo1Ol00?m9ooooo`?o003o1Oooool10000007ooooo00000`00
003oooooooooo`35ooooo`Go003oB?ooool5o`00o`Cooooo0@000001ooooo`0000<00000oooooooo
ool0a_ooool3o`00odWooooo1Ol00?l4ooooo`4000000Oooool0000300000?oooooooooo013ooooo
0ooo003oooooo`Go003o1?ooool10000007ooooo00000`00003oooooooooo`0?ooooo`Goo`00Uooo
ool3o`00ofGooooo0ol00?l5ooooo`4000000Oooool0000300000?oooooooooo00oooooo1Ooo002F
ooooo`Go003o>Oooool3o`00oc3ooooo0@000001ooooo`0000<00000ooooooooool03oooool5ool0
09Kooooo1Ol00?lhooooo`Go003o;oooool10000007ooooo00000`00003oooooooooo`0@ooooo`?o
o`00L_ooool3ool002;ooooo1Ol00?lhooooo`Go003o;oooool10000007ooooo00000`00003ooooo
ooooo`24ooooo`Goo`008_ooool3o`00ocSooooo1_l00?l_ooooo`4000000Oooool0000300000?oo
oooooooo06gooooo0ooo000Dooooo`Goo`00GOooool5o`00oc3ooooo0@000001ooooo`0000<00000
ooooooooool0K?ooool5ool001?ooooo1Ooo001Mooooo`Go003o:?ooool3o`00o`Gooooo0@000001
ooooo`0000<00000ooooooooool0K?ooool5ool001Cooooo0ooo001Fooooo`?o003o1_ooool3o`00
obSooooo1Ol00?l4ooooo`4000000Oooool0000300000?oooooooooo06cooooo1Ooo001/ooooo`Go
003o<?ooool5o`00o`Cooooo0@000001ooooo`0000<00000ooooooooool0=Oooool3ool003Gooooo
0ooo001]ooooo`Go003o<?ooool5o`00o`Cooooo0@000001ooooo`0000<00000ooooooooool0=?oo
ool5ool00:Cooooo1Ol00?laooooo`?o003o1Oooool10000007ooooo00000`00003oooooooooo`0d
ooooo`Goo`00YOooool3o`00oc[ooooo0@000001ooooo`0000<00000ooooooooool0=?ooool5ool0
04;ooooo0ooo002Mooooo`4000000Oooool0000300000?oooooooooo03Gooooo0ooo0012ooooo`Go
o`00W?ooool10000007ooooo00000`00003oooooooooo`1jooooo`Goo`00DOooool3o`00odSooooo
0@000001ooooo`0000<00000ooooooooool0N_ooool5ool0053ooooo1Ol00?l>ooooo`?o003o=_oo
ool10000007ooooo00000`00003oooooooooo`1kooooo`?oo`00DOooool5o`00o`gooooo1Ol00?le
ooooo`4000000Oooool0000300000?oooooooooo0:[ooooo0ol00?lRooooo`Go003o3Oooool5o`00
ocGooooo0@000001ooooo`0000<00000ooooooooool0Uoooool3o`00o`oooooo1Ol00?lRooooo`?o
003o3_ooool5o`00ocGooooo0@000001ooooo`0000<00000ooooooooool0Foooool3ool003Sooooo
1Ol00?l>ooooo`Go003o=?ooool3o`00ocKooooo0@000001ooooo`0000<00000ooooooooool0F_oo
ool5ool003Oooooo1Ol00?l>ooooo`Go003oKOooool10000007ooooo00000`00003oooooooooo`1J
ooooo`Goo`002oooool3ool002Sooooo1_l00?l?ooooo`?o003oK_ooool10000007ooooo00000`00
003oooooooooo`07ooooo`?oo`00D?ooool5ool000[ooooo1Ooo000Tooooo`So003oPOooool10000
007ooooo00000`00003oooooool00002ool000Cooooo1Ooo001@ooooo`?oo`000oooool3ool000Go
oooo1Ooo000Sooooo`So003oAOooool3o`00oc[ooooo0@000001ooooo`0000<00000ool00?oo0000
0ooo0003ooooo`Goo`00EOooool5ool000Cooooo1Ooo000@ooooo`?oo`004?ooool8o`00odCooooo
1Ol00?lEooooo`?o003o8Oooool10000007ooooo00000`00003oo`00ool00003ool000?ooooo1Ooo
001Eooooo`Goo`001Oooool3ool0013ooooo1Ooo000?ooooo`Oo003oAOooool6o`00oa?ooooo1Ol0
0?lPooooo`4000000Oooool0000300000?oo003oo`0000?oo`001?ooool3ool005Kooooo1Ooo0004
ooooo`?oo`004Oooool5ool0013ooooo0ol00?m7ooooo`So003o4_ooool5o`00ob3ooooo0@000001
ooooo`0000<00000oooooooo00000_oo001Oooooo`?oo`001?ooool5ool0013ooooo1Ooo001Joooo
o`So003o4_ooool5o`00ob3ooooo0@000001ooooo`0000<00000ooooooooool0J?ooool5ool0017o
oooo0ooo001Kooooo`So003o4oooool3o`00ob7ooooo0@000001ooooo`0000<00000ooooooooool0
D_ooool3ool001?ooooo1Ooo001`ooooo`Ko003o>?ooool10000007ooooo00000`00003ooooooooo
o`1=ooooo`?oo`0000?oooooool00?oo00000ooo000Cooooo`?oo`00[oooool10000007ooooo0000
0`00003oooooooooo`1<ooooo`[oo`00aOooool10000007ooooo00000`00003oooooooooo`15oooo
o`?oo`001?ooool:ool00<Gooooo0@000001ooooo`0000<00000ooooooooool0A?ooool5ool000?o
oooo1Ooo00001?ooooooo`00ool00?oo002Qooooo`?o003o8_ooool10000007ooooo00000`00003o
ooooooooo`14ooooo`Goo`001?ooool3ool00:Gooooo1Ol00?lQooooo`4000000Oooool000030000
0?oooooooooo04Cooooo1Ooo000Sooooo`?oo`00Q_ooool5o`00ob7ooooo0@000001ooooo`0000<0
0000ooooooooool0AOooool3ool002?ooooo1Ooo0025ooooo`Go003o8Oooool10000007ooooo0000
0`00003oooooooooo`1[ooooo`Goo`00=_ooool3o`00odgooooo0ol00?lRooooo`4000000Oooool0
000300000?oooooooooo06_ooooo1Ooo000eooooo`Go003oLOooool10000007ooooo00000`00003o
ooooooooo`1/ooooo`?oo`00=_ooool5o`00og7ooooo0@000001ooooo`0000<00000ooooooooool0
U_ooool3o`00o`cooooo1Ol00?maooooo`4000000Oooool000;oo`00U_ooool5o`00o`cooooo0ol0
0?mNooooo`?o003o4Oooool10000007ooooo0003ool009Gooooo1Ol00?m/ooooo`Go003o4?ooool1
0000007ooooo0003ool009Gooooo1Ol00?m/ooooo`Go003o4?ooool10000007ooooo0006ool006So
oooo0ooo000Xooooo`?o003oKOooool5o`00oa3ooooo0@000001ooooo`001ooo001Vooooo`Goo`00
<oooool3o`00of;ooooo0ol00?lAooooo`4000000Oooool0000300000?ooooooo`0000Coo`00;Ooo
ool3ool003Kooooo1Ooo000booooo`Go003o4?ooool3o`00of;ooooo0@000001ooooo`0000<00000
oooooooo00001?oo000/ooooo`Koo`00=?ooool5ool002Kooooo0ol00?l9ooooo`Go003o3oooool5
o`00of7ooooo0@000001ooooo`0000<00000ooooooooool00ooo000]ooooo`Ooo`00=?ooool3ool0
02Kooooo1Ol00?l8ooooo`Go003o3oooool5o`00of7ooooo0@000001ooooo`0000<00000oooooooo
ool0<?ooool7ool005gooooo1Ol00?l9ooooo`?o003o4?ooool5o`00of7ooooo0@000001ooooo`00
00<00000ooooooooool0<Oooool6ool005gooooo1Ol00?lMooooo`?o003oH_ooool10000007ooooo
00000`00003oooooooooo`0cooooo`?oo`00Goooool3o`00oh?ooooo0@000001ooooo`0000<00000
ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000
007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0
8_ooool3ool00?Kooooo0@000001ooooo`0000<00000ooooooooool08Oooool5ool00?Gooooo0@00
0001ooooo`0000<00000ooooooooool08Oooool5ool006[ooooo0ol00?lJooooo`?o003oJoooool1
0000007ooooo00000`00003oooooooooo`0Qooooo`Goo`00JOooool5o`00oaSooooo1Ol00?mZoooo
o`4000000Oooool0000300000?oooooooooo02;ooooo0ooo001Zooooo`Go003o6?ooool5o`00ob7o
oooo0ol00?m6ooooo`4000000Oooool0000300000?oooooooooo08oooooo1Ol00?lHooooo`Go003o
8?ooool5o`00ob_ooooo0ol00?lGooooo`4000000Oooool0000300000?oooooooooo04Gooooo0ooo
0018ooooo`?o003o6_ooool3o`00ob7ooooo1Ol00?lZooooo`Go003o5_ooool10000007ooooo0000
0`00003oooooooooo`14ooooo`Ooo`00Q_ooool5o`00ob[ooooo1Ol00?lFooooo`4000000Oooool0
000300000?oooooooooo04Cooooo2?oo0026ooooo`?o003o0_ooool3o`00obKooooo1Ol00?lFoooo
o`4000000Oooool0000300000?oooooooooo04Cooooo2?oo002:ooooo`Go003o9_ooool3o`00oaOo
oooo0@000001ooooo`0000<00000ooooooooool05_ooool3ool002cooooo1ooo0013ooooo`?o003o
=Oooool3o`00o`cooooo1Ol00?m0ooooo`4000000Oooool0000300000?oooooooooo01Gooooo1Ooo
000^ooooo`?oo`00@oooool5o`00oc?ooooo1Ol00?l;ooooo`Go003o2?ooool3o`00ocGooooo0@00
0001ooooo`0000<00000ooooooooool05Oooool5ool007Cooooo1Ol00?lcooooo`Go003o1?ooool3
o`00o`Gooooo0ol00?l8ooooo`Go003o=?ooool10000007ooooo00000`00003oooooooooo`0Eoooo
o`Goo`00M?ooool5o`00oc?ooooo1Ol00?l3ooooo`Go003o3oooool5o`00ocCooooo0@000001oooo
o`0000<00000ooooooooool05_ooool3ool007Kooooo0ol00?leooooo`?o003o1?ooool5o`00o`oo
oooo1Ol00?ldooooo`4000000Oooool0000300000?oooooooooo0<kooooo1Ol00?l@ooooo`?o003o
=Oooool10000007ooooo00000`00003oooooooooo`3?ooooo`?o003oBOooool10000007ooooo003o
0000020000000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Gaussian probability density functions", "Subsection"],

Cell[CellGroupData[{

Cell["Compute Gaussian pdfs", "Subsubsection"],

Cell[BoxData[{
    \(\(pdf1\  = \ gaussian[data1, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(pdf2\  = \ gaussian[data2, {x, y}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Gaussian pdfs", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[pdf1, pdf2, pr, x, y, yS, imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.2 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.1 g
.01923 .75437 m
.02061 .75888 L
.02882 .78353 L
.03819 .80819 L
.04389 .82178 L
.04882 .83284 L
.06089 .8575 L
.06854 .8716 L
.0747 .88215 L
.09071 .9068 L
.0932 .91031 L
.10962 .93146 L
.11785 .94086 L
.13276 .95611 L
.1425 .96489 L
.16325 .98077 L
.01923 .98077 L
F
0 g
.01923 .75437 m
.02061 .75888 L
.02882 .78353 L
.03819 .80819 L
.04389 .82178 L
.04882 .83284 L
.06089 .8575 L
.06854 .8716 L
.0747 .88215 L
.09071 .9068 L
.0932 .91031 L
.10962 .93146 L
.11785 .94086 L
.13276 .95611 L
.1425 .96489 L
.16325 .98077 L
s
.1 g
.01923 .24631 m
.02082 .24112 L
.02901 .21647 L
.03834 .19181 L
.04389 .17852 L
.04893 .16716 L
.06091 .1425 L
.06854 .12832 L
.07459 .11785 L
.09041 .0932 L
.0932 .08923 L
.10903 .06854 L
.11785 .0583 L
.13165 .04389 L
.1425 .03389 L
.16103 .01923 L
.01923 .01923 L
F
0 g
.01923 .24631 m
.02082 .24112 L
.02901 .21647 L
.03834 .19181 L
.04389 .17852 L
.04893 .16716 L
.06091 .1425 L
.06854 .12832 L
.07459 .11785 L
.09041 .0932 L
.0932 .08923 L
.10903 .06854 L
.11785 .0583 L
.13165 .04389 L
.1425 .03389 L
.16103 .01923 L
s
.01923 .06472 m
.03058 .04389 L
.04389 .02194 L
.04563 .01923 L
.01923 .01923 L
F
.01923 .06472 m
.03058 .04389 L
.04389 .02194 L
.04563 .01923 L
s
.01923 .93596 m
.03029 .95611 L
.04389 .97836 L
.04546 .98077 L
.01923 .98077 L
F
.01923 .93596 m
.03029 .95611 L
.04389 .97836 L
.04546 .98077 L
s
.3 g
.21647 .06223 m
.24112 .05638 L
.26578 .05536 L
.29043 .05914 L
.31509 .06786 L
.31662 .06854 L
.33974 .08185 L
.3549 .0932 L
.3644 .10165 L
.38027 .11785 L
.38905 .12821 L
.39997 .1425 L
.41371 .16316 L
.41614 .16716 L
.42978 .19181 L
.43836 .20955 L
.44146 .21647 L
.45152 .24112 L
.46024 .26578 L
.46302 .27445 L
.46774 .29043 L
.47417 .31509 L
.47964 .33974 L
.48422 .3644 L
.48767 .38696 L
.48795 .38905 L
.49084 .41371 L
.49296 .43836 L
.49433 .46302 L
.49497 .48767 L
.49487 .51233 L
.49404 .53698 L
.49247 .56164 L
.49015 .58629 L
.48767 .60653 L
.48704 .61095 L
.4831 .6356 L
.47831 .66026 L
.47261 .68491 L
.46595 .70957 L
.46302 .71938 L
.4582 .73422 L
.44922 .75888 L
.43887 .78353 L
.43836 .78466 L
.42686 .80819 L
.41371 .83143 L
.41285 .83284 L
.3962 .8575 L
.38905 .86676 L
.37585 .88215 L
.3644 .8937 L
.34939 .9068 L
.33974 .91389 L
.31509 .92825 L
.30933 .93146 L
.29043 .93735 L
.26578 .94151 L
.24112 .94087 L
.21647 .9354 L
.20472 .93146 L
.19181 .9249 L
.16716 .90899 L
.16432 .9068 L
.1425 .88698 L
.13792 .88215 L
.11785 .85774 L
.11767 .8575 L
.10112 .83284 L
.0932 .81929 L
.08722 .80819 L
.07532 .78353 L
.06854 .76766 L
.06507 .75888 L
.05622 .73422 L
.04856 .70957 L
.04389 .69249 L
.04197 .68491 L
.03637 .66026 L
.03168 .6356 L
.02786 .61095 L
.02486 .58629 L
.02265 .56164 L
.02119 .53698 L
.02047 .51233 L
.02048 .48767 L
.02121 .46302 L
.02269 .43836 L
.02493 .41371 L
.02794 .38905 L
.03177 .3644 L
.03645 .33974 L
.04205 .31509 L
.04389 .30781 L
.04863 .29043 L
.05626 .26578 L
.06506 .24112 L
.06854 .23226 L
.07524 .21647 L
.08702 .19181 L
.0932 .18025 L
.10077 .16716 L
.11706 .1425 L
.11785 .14142 L
.13688 .11785 L
.1425 .1118 L
.1624 .0932 L
.16716 .08941 L
.19181 .07311 L
.19996 .06854 L
F
0 g
.21647 .06223 m
.24112 .05638 L
.26578 .05536 L
.29043 .05914 L
.31509 .06786 L
.31662 .06854 L
.33974 .08185 L
.3549 .0932 L
.3644 .10165 L
.38027 .11785 L
.38905 .12821 L
.39997 .1425 L
.41371 .16316 L
.41614 .16716 L
.42978 .19181 L
.43836 .20955 L
.44146 .21647 L
.45152 .24112 L
.46024 .26578 L
.46302 .27445 L
.46774 .29043 L
.47417 .31509 L
.47964 .33974 L
.48422 .3644 L
.48767 .38696 L
.48795 .38905 L
.49084 .41371 L
.49296 .43836 L
.49433 .46302 L
.49497 .48767 L
.49487 .51233 L
.49404 .53698 L
.49247 .56164 L
.49015 .58629 L
.48767 .60653 L
.48704 .61095 L
.4831 .6356 L
.47831 .66026 L
.47261 .68491 L
.46595 .70957 L
.46302 .71938 L
.4582 .73422 L
.44922 .75888 L
.43887 .78353 L
.43836 .78466 L
.42686 .80819 L
.41371 .83143 L
.41285 .83284 L
.3962 .8575 L
.38905 .86676 L
Mistroke
.37585 .88215 L
.3644 .8937 L
.34939 .9068 L
.33974 .91389 L
.31509 .92825 L
.30933 .93146 L
.29043 .93735 L
.26578 .94151 L
.24112 .94087 L
.21647 .9354 L
.20472 .93146 L
.19181 .9249 L
.16716 .90899 L
.16432 .9068 L
.1425 .88698 L
.13792 .88215 L
.11785 .85774 L
.11767 .8575 L
.10112 .83284 L
.0932 .81929 L
.08722 .80819 L
.07532 .78353 L
.06854 .76766 L
.06507 .75888 L
.05622 .73422 L
.04856 .70957 L
.04389 .69249 L
.04197 .68491 L
.03637 .66026 L
.03168 .6356 L
.02786 .61095 L
.02486 .58629 L
.02265 .56164 L
.02119 .53698 L
.02047 .51233 L
.02048 .48767 L
.02121 .46302 L
.02269 .43836 L
.02493 .41371 L
.02794 .38905 L
.03177 .3644 L
.03645 .33974 L
.04205 .31509 L
.04389 .30781 L
.04863 .29043 L
.05626 .26578 L
.06506 .24112 L
.06854 .23226 L
.07524 .21647 L
.08702 .19181 L
Mistroke
.0932 .18025 L
.10077 .16716 L
.11706 .1425 L
.11785 .14142 L
.13688 .11785 L
.1425 .1118 L
.1624 .0932 L
.16716 .08941 L
.19181 .07311 L
.19996 .06854 L
.21647 .06223 L
Mfstroke
.4 g
.24112 .11124 m
.26578 .11011 L
.29043 .11446 L
.30245 .11785 L
.31509 .1245 L
.33974 .14072 L
.34199 .1425 L
.3644 .16403 L
.36719 .16716 L
.3862 .19181 L
.38905 .19608 L
.40149 .21647 L
.41371 .24014 L
.41417 .24112 L
.42485 .26578 L
.43389 .29043 L
.43836 .3043 L
.44154 .31509 L
.44795 .33974 L
.45327 .3644 L
.45758 .38905 L
.46094 .41371 L
.46302 .43372 L
.46339 .43836 L
.46497 .46302 L
.4657 .48767 L
.46559 .51233 L
.46465 .53698 L
.46302 .56021 L
.46286 .56164 L
.46019 .58629 L
.4566 .61095 L
.45207 .6356 L
.44651 .66026 L
.43985 .68491 L
.43836 .6899 L
.43194 .70957 L
.4226 .73422 L
.41371 .75445 L
.41159 .75888 L
.39852 .78353 L
.38905 .79889 L
.38275 .80819 L
.3644 .83132 L
.36306 .83284 L
.33974 .85501 L
.33675 .8575 L
.31509 .87161 L
.29043 .88204 L
.29006 .88215 L
.26578 .88677 L
.24112 .88601 L
.22372 .88215 L
.21647 .87972 L
.19181 .86761 L
.17703 .8575 L
.16716 .84907 L
.15087 .83284 L
.1425 .82297 L
.13133 .80819 L
.11785 .78726 L
.11567 .78353 L
.1027 .75888 L
.0932 .73762 L
.0918 .73422 L
.08258 .70957 L
.07477 .68491 L
.06854 .66165 L
.0682 .66026 L
.06277 .6356 L
.05836 .61095 L
.05489 .58629 L
.05233 .56164 L
.05064 .53698 L
.0498 .51233 L
.0498 .48767 L
.05065 .46302 L
.05234 .43836 L
.0549 .41371 L
.05837 .38905 L
.06277 .3644 L
.06818 .33974 L
.06854 .33827 L
.07472 .31509 L
.08248 .29043 L
.09162 .26578 L
.0932 .26192 L
.10241 .24112 L
.11521 .21647 L
.11785 .2119 L
.1306 .19181 L
.1425 .17581 L
.14968 .16716 L
.16716 .14933 L
.17488 .1425 L
.19181 .1304 L
.21647 .11791 L
.21663 .11785 L
F
0 g
.24112 .11124 m
.26578 .11011 L
.29043 .11446 L
.30245 .11785 L
.31509 .1245 L
.33974 .14072 L
.34199 .1425 L
.3644 .16403 L
.36719 .16716 L
.3862 .19181 L
.38905 .19608 L
.40149 .21647 L
.41371 .24014 L
.41417 .24112 L
.42485 .26578 L
.43389 .29043 L
.43836 .3043 L
.44154 .31509 L
.44795 .33974 L
.45327 .3644 L
.45758 .38905 L
.46094 .41371 L
.46302 .43372 L
.46339 .43836 L
.46497 .46302 L
.4657 .48767 L
.46559 .51233 L
.46465 .53698 L
.46302 .56021 L
.46286 .56164 L
.46019 .58629 L
.4566 .61095 L
.45207 .6356 L
.44651 .66026 L
.43985 .68491 L
.43836 .6899 L
.43194 .70957 L
.4226 .73422 L
.41371 .75445 L
.41159 .75888 L
.39852 .78353 L
.38905 .79889 L
.38275 .80819 L
.3644 .83132 L
.36306 .83284 L
.33974 .85501 L
.33675 .8575 L
.31509 .87161 L
.29043 .88204 L
.29006 .88215 L
Mistroke
.26578 .88677 L
.24112 .88601 L
.22372 .88215 L
.21647 .87972 L
.19181 .86761 L
.17703 .8575 L
.16716 .84907 L
.15087 .83284 L
.1425 .82297 L
.13133 .80819 L
.11785 .78726 L
.11567 .78353 L
.1027 .75888 L
.0932 .73762 L
.0918 .73422 L
.08258 .70957 L
.07477 .68491 L
.06854 .66165 L
.0682 .66026 L
.06277 .6356 L
.05836 .61095 L
.05489 .58629 L
.05233 .56164 L
.05064 .53698 L
.0498 .51233 L
.0498 .48767 L
.05065 .46302 L
.05234 .43836 L
.0549 .41371 L
.05837 .38905 L
.06277 .3644 L
.06818 .33974 L
.06854 .33827 L
.07472 .31509 L
.08248 .29043 L
.09162 .26578 L
.0932 .26192 L
.10241 .24112 L
.11521 .21647 L
.11785 .2119 L
.1306 .19181 L
.1425 .17581 L
.14968 .16716 L
.16716 .14933 L
.17488 .1425 L
.19181 .1304 L
.21647 .11791 L
.21663 .11785 L
.24112 .11124 L
Mfstroke
.5 g
.21647 .16651 m
.24112 .15892 L
.26578 .15765 L
.29043 .16264 L
.30391 .16716 L
.31509 .1742 L
.33844 .19181 L
.33974 .19308 L
.36112 .21647 L
.3644 .2208 L
.37818 .24112 L
.38905 .26045 L
.39176 .26578 L
.4029 .29043 L
.4121 .31509 L
.41371 .3199 L
.4197 .33974 L
.42593 .3644 L
.43092 .38905 L
.43479 .41371 L
.43761 .43836 L
.43836 .44533 L
.43942 .46302 L
.44026 .48767 L
.44015 .51233 L
.43909 .53698 L
.43836 .54826 L
.43704 .56164 L
.43399 .58629 L
.42988 .61095 L
.42463 .6356 L
.41814 .66026 L
.41371 .67469 L
.41025 .68491 L
.40073 .70957 L
.3892 .73422 L
.38905 .73451 L
.37516 .75888 L
.3644 .77455 L
.3575 .78353 L
.33974 .80265 L
.33386 .80819 L
.31509 .82191 L
.29383 .83284 L
.29043 .83385 L
.26578 .83923 L
.24112 .83834 L
.22076 .83284 L
.21647 .83112 L
.19181 .81714 L
.18024 .80819 L
.16716 .79542 L
.1567 .78353 L
.1425 .76404 L
.13916 .75888 L
.12518 .73422 L
.11785 .71889 L
.11379 .70957 L
.10437 .68491 L
.09659 .66026 L
.0932 .64781 L
.09021 .6356 L
.08508 .61095 L
.08108 .58629 L
.07814 .56164 L
.0762 .53698 L
.07524 .51233 L
.07524 .48767 L
.07619 .46302 L
.07811 .43836 L
.08104 .41371 L
.08502 .38905 L
.09011 .3644 L
.0932 .35172 L
.09644 .33974 L
.10416 .31509 L
.11347 .29043 L
.11785 .28026 L
.1247 .26578 L
.13843 .24112 L
.1425 .23473 L
.15555 .21647 L
.16716 .20298 L
.17823 .19181 L
.19181 .18088 L
.21486 .16716 L
F
0 g
.21647 .16651 m
.24112 .15892 L
.26578 .15765 L
.29043 .16264 L
.30391 .16716 L
.31509 .1742 L
.33844 .19181 L
.33974 .19308 L
.36112 .21647 L
.3644 .2208 L
.37818 .24112 L
.38905 .26045 L
.39176 .26578 L
.4029 .29043 L
.4121 .31509 L
.41371 .3199 L
.4197 .33974 L
.42593 .3644 L
.43092 .38905 L
.43479 .41371 L
.43761 .43836 L
.43836 .44533 L
.43942 .46302 L
.44026 .48767 L
.44015 .51233 L
.43909 .53698 L
.43836 .54826 L
.43704 .56164 L
.43399 .58629 L
.42988 .61095 L
.42463 .6356 L
.41814 .66026 L
.41371 .67469 L
.41025 .68491 L
.40073 .70957 L
.3892 .73422 L
.38905 .73451 L
.37516 .75888 L
.3644 .77455 L
.3575 .78353 L
.33974 .80265 L
.33386 .80819 L
.31509 .82191 L
.29383 .83284 L
.29043 .83385 L
.26578 .83923 L
.24112 .83834 L
.22076 .83284 L
.21647 .83112 L
.19181 .81714 L
Mistroke
.18024 .80819 L
.16716 .79542 L
.1567 .78353 L
.1425 .76404 L
.13916 .75888 L
.12518 .73422 L
.11785 .71889 L
.11379 .70957 L
.10437 .68491 L
.09659 .66026 L
.0932 .64781 L
.09021 .6356 L
.08508 .61095 L
.08108 .58629 L
.07814 .56164 L
.0762 .53698 L
.07524 .51233 L
.07524 .48767 L
.07619 .46302 L
.07811 .43836 L
.08104 .41371 L
.08502 .38905 L
.09011 .3644 L
.0932 .35172 L
.09644 .33974 L
.10416 .31509 L
.11347 .29043 L
.11785 .28026 L
.1247 .26578 L
.13843 .24112 L
.1425 .23473 L
.15555 .21647 L
.16716 .20298 L
.17823 .19181 L
.19181 .18088 L
.21486 .16716 L
.21647 .16651 L
Mfstroke
.6 g
.21647 .21172 m
.24112 .20299 L
.26578 .20156 L
.29043 .20733 L
.31026 .21647 L
.31509 .22078 L
.33801 .24112 L
.33974 .24313 L
.35733 .26578 L
.3644 .27708 L
.37187 .29043 L
.38339 .31509 L
.38905 .32959 L
.39262 .33974 L
.40005 .3644 L
.40593 .38905 L
.41044 .41371 L
.4137 .43836 L
.41371 .43841 L
.4158 .46302 L
.41677 .48767 L
.41665 .51233 L
.41543 .53698 L
.41371 .557 L
.41309 .56164 L
.40957 .58629 L
.40479 .61095 L
.39863 .6356 L
.39088 .66026 L
.38905 .66537 L
.38129 .68491 L
.36934 .70957 L
.3644 .71826 L
.35425 .73422 L
.33974 .7526 L
.33416 .75888 L
.31509 .77533 L
.30407 .78353 L
.29043 .78916 L
.26578 .79532 L
.24112 .79427 L
.21647 .78592 L
.21137 .78353 L
.19181 .76958 L
.18015 .75888 L
.16716 .74363 L
.16019 .73422 L
.14518 .70957 L
.1425 .70443 L
.13333 .68491 L
.12384 .66026 L
.11785 .64136 L
.11622 .6356 L
.11016 .61095 L
.10549 .58629 L
.10208 .56164 L
.09984 .53698 L
.09873 .51233 L
.09872 .48767 L
.09981 .46302 L
.10201 .43836 L
.10539 .41371 L
.11001 .38905 L
.116 .3644 L
.11785 .3578 L
.12352 .33974 L
.13288 .31509 L
.1425 .29434 L
.14451 .29043 L
.15917 .26578 L
.16716 .25477 L
.17846 .24112 L
.19181 .22844 L
.20727 .21647 L
F
0 g
.21647 .21172 m
.24112 .20299 L
.26578 .20156 L
.29043 .20733 L
.31026 .21647 L
.31509 .22078 L
.33801 .24112 L
.33974 .24313 L
.35733 .26578 L
.3644 .27708 L
.37187 .29043 L
.38339 .31509 L
.38905 .32959 L
.39262 .33974 L
.40005 .3644 L
.40593 .38905 L
.41044 .41371 L
.4137 .43836 L
.41371 .43841 L
.4158 .46302 L
.41677 .48767 L
.41665 .51233 L
.41543 .53698 L
.41371 .557 L
.41309 .56164 L
.40957 .58629 L
.40479 .61095 L
.39863 .6356 L
.39088 .66026 L
.38905 .66537 L
.38129 .68491 L
.36934 .70957 L
.3644 .71826 L
.35425 .73422 L
.33974 .7526 L
.33416 .75888 L
.31509 .77533 L
.30407 .78353 L
.29043 .78916 L
.26578 .79532 L
.24112 .79427 L
.21647 .78592 L
.21137 .78353 L
.19181 .76958 L
.18015 .75888 L
.16716 .74363 L
.16019 .73422 L
.14518 .70957 L
.1425 .70443 L
.13333 .68491 L
Mistroke
.12384 .66026 L
.11785 .64136 L
.11622 .6356 L
.11016 .61095 L
.10549 .58629 L
.10208 .56164 L
.09984 .53698 L
.09873 .51233 L
.09872 .48767 L
.09981 .46302 L
.10201 .43836 L
.10539 .41371 L
.11001 .38905 L
.116 .3644 L
.11785 .3578 L
.12352 .33974 L
.13288 .31509 L
.1425 .29434 L
.14451 .29043 L
.15917 .26578 L
.16716 .25477 L
.17846 .24112 L
.19181 .22844 L
.20727 .21647 L
.21647 .21172 L
Mfstroke
.7 g
.21647 .25605 m
.24112 .24582 L
.26578 .24418 L
.29043 .25098 L
.3141 .26578 L
.31509 .26699 L
.33697 .29043 L
.33974 .29439 L
.35284 .31509 L
.3644 .33903 L
.3647 .33974 L
.37398 .3644 L
.38112 .38905 L
.3865 .41371 L
.38905 .42864 L
.39035 .43836 L
.39283 .46302 L
.39398 .48767 L
.39385 .51233 L
.39243 .53698 L
.38968 .56164 L
.38905 .56614 L
.38554 .58629 L
.37985 .61095 L
.37236 .6356 L
.3644 .65633 L
.36271 .66026 L
.35032 .68491 L
.33974 .70134 L
.33383 .70957 L
.31509 .72913 L
.31028 .73422 L
.29043 .74552 L
.26578 .7527 L
.24112 .75144 L
.21647 .74159 L
.20459 .73422 L
.19181 .72198 L
.18072 .70957 L
.16716 .68961 L
.16437 .68491 L
.15198 .66026 L
.14251 .6356 L
.1425 .63559 L
.13511 .61095 L
.12951 .58629 L
.12547 .56164 L
.12284 .53698 L
.12153 .51233 L
.12151 .48767 L
.12277 .46302 L
.12534 .43836 L
.12932 .41371 L
.13483 .38905 L
.1421 .3644 L
.1425 .36318 L
.15139 .33974 L
.16348 .31509 L
.16716 .30878 L
.17932 .29043 L
.19181 .27603 L
.20191 .26578 L
F
0 g
.21647 .25605 m
.24112 .24582 L
.26578 .24418 L
.29043 .25098 L
.3141 .26578 L
.31509 .26699 L
.33697 .29043 L
.33974 .29439 L
.35284 .31509 L
.3644 .33903 L
.3647 .33974 L
.37398 .3644 L
.38112 .38905 L
.3865 .41371 L
.38905 .42864 L
.39035 .43836 L
.39283 .46302 L
.39398 .48767 L
.39385 .51233 L
.39243 .53698 L
.38968 .56164 L
.38905 .56614 L
.38554 .58629 L
.37985 .61095 L
.37236 .6356 L
.3644 .65633 L
.36271 .66026 L
.35032 .68491 L
.33974 .70134 L
.33383 .70957 L
.31509 .72913 L
.31028 .73422 L
.29043 .74552 L
.26578 .7527 L
.24112 .75144 L
.21647 .74159 L
.20459 .73422 L
.19181 .72198 L
.18072 .70957 L
.16716 .68961 L
.16437 .68491 L
.15198 .66026 L
.14251 .6356 L
.1425 .63559 L
.13511 .61095 L
.12951 .58629 L
.12547 .56164 L
.12284 .53698 L
.12153 .51233 L
.12151 .48767 L
Mistroke
.12277 .46302 L
.12534 .43836 L
.12932 .41371 L
.13483 .38905 L
.1421 .3644 L
.1425 .36318 L
.15139 .33974 L
.16348 .31509 L
.16716 .30878 L
.17932 .29043 L
.19181 .27603 L
.20191 .26578 L
.21647 .25605 L
Mfstroke
.8 g
.24112 .28963 m
.26578 .28769 L
.27779 .29043 L
.29043 .29599 L
.31453 .31509 L
.31509 .31596 L
.33299 .33974 L
.33974 .35235 L
.3455 .3644 L
.35481 .38905 L
.36155 .41371 L
.3644 .42707 L
.36629 .43836 L
.36932 .46302 L
.37073 .48767 L
.37058 .51233 L
.36887 .53698 L
.36553 .56164 L
.3644 .56813 L
.36046 .58629 L
.35333 .61095 L
.34353 .6356 L
.33974 .64338 L
.33045 .66026 L
.31509 .68016 L
.31169 .68491 L
.29043 .70051 L
.26578 .70918 L
.24112 .70762 L
.21647 .69555 L
.20309 .68491 L
.19181 .67073 L
.18442 .66026 L
.17124 .6356 L
.16716 .62582 L
.16167 .61095 L
.15458 .58629 L
.14959 .56164 L
.14639 .53698 L
.14481 .51233 L
.14477 .48767 L
.14627 .46302 L
.14938 .43836 L
.15425 .41371 L
.16117 .38905 L
.16716 .37257 L
.17052 .3644 L
.18325 .33974 L
.19181 .32729 L
.20108 .31509 L
.21647 .30208 L
.23853 .29043 L
F
0 g
.24112 .28963 m
.26578 .28769 L
.27779 .29043 L
.29043 .29599 L
.31453 .31509 L
.31509 .31596 L
.33299 .33974 L
.33974 .35235 L
.3455 .3644 L
.35481 .38905 L
.36155 .41371 L
.3644 .42707 L
.36629 .43836 L
.36932 .46302 L
.37073 .48767 L
.37058 .51233 L
.36887 .53698 L
.36553 .56164 L
.3644 .56813 L
.36046 .58629 L
.35333 .61095 L
.34353 .6356 L
.33974 .64338 L
.33045 .66026 L
.31509 .68016 L
.31169 .68491 L
.29043 .70051 L
.26578 .70918 L
.24112 .70762 L
.21647 .69555 L
.20309 .68491 L
.19181 .67073 L
.18442 .66026 L
.17124 .6356 L
.16716 .62582 L
.16167 .61095 L
.15458 .58629 L
.14959 .56164 L
.14639 .53698 L
.14481 .51233 L
.14477 .48767 L
.14627 .46302 L
.14938 .43836 L
.15425 .41371 L
.16117 .38905 L
.16716 .37257 L
.17052 .3644 L
.18325 .33974 L
.19181 .32729 L
.20108 .31509 L
Mistroke
.21647 .30208 L
.23853 .29043 L
.24112 .28963 L
Mfstroke
.9 g
.24112 .33766 m
.26578 .3352 L
.27987 .33974 L
.29043 .34612 L
.31008 .3644 L
.31509 .37396 L
.32359 .38905 L
.33328 .41371 L
.3395 .43836 L
.33974 .43926 L
.34352 .46302 L
.34538 .48767 L
.3452 .51233 L
.34298 .53698 L
.33974 .55702 L
.33862 .56164 L
.33193 .58629 L
.32157 .61095 L
.31509 .62215 L
.30732 .6356 L
.29043 .65038 L
.27151 .66026 L
.26578 .66166 L
.24319 .66026 L
.24112 .65959 L
.21647 .64351 L
.20857 .6356 L
.19337 .61095 L
.19181 .60728 L
.18323 .58629 L
.1764 .56164 L
.1722 .53698 L
.17017 .51233 L
.1701 .48767 L
.172 .46302 L
.17603 .43836 L
.18262 .41371 L
.19181 .39076 L
.19252 .38905 L
.20673 .3644 L
.21647 .35412 L
.23626 .33974 L
F
0 g
.24112 .33766 m
.26578 .3352 L
.27987 .33974 L
.29043 .34612 L
.31008 .3644 L
.31509 .37396 L
.32359 .38905 L
.33328 .41371 L
.3395 .43836 L
.33974 .43926 L
.34352 .46302 L
.34538 .48767 L
.3452 .51233 L
.34298 .53698 L
.33974 .55702 L
.33862 .56164 L
.33193 .58629 L
.32157 .61095 L
.31509 .62215 L
.30732 .6356 L
.29043 .65038 L
.27151 .66026 L
.26578 .66166 L
.24319 .66026 L
.24112 .65959 L
.21647 .64351 L
.20857 .6356 L
.19337 .61095 L
.19181 .60728 L
.18323 .58629 L
.1764 .56164 L
.1722 .53698 L
.17017 .51233 L
.1701 .48767 L
.172 .46302 L
.17603 .43836 L
.18262 .41371 L
.19181 .39076 L
.19252 .38905 L
.20673 .3644 L
.21647 .35412 L
.23626 .33974 L
.24112 .33766 L
s
1 g
.24112 .39819 m
.26578 .39443 L
.29043 .41284 L
.29122 .41371 L
.30588 .43836 L
.31187 .46302 L
.31408 .48767 L
.3139 .51233 L
.31123 .53698 L
.30438 .56164 L
.29043 .58376 L
.28835 .58629 L
.26578 .60246 L
.24112 .59906 L
.22673 .58629 L
.21647 .57041 L
.21223 .56164 L
.2044 .53698 L
.20104 .51233 L
.20091 .48767 L
.20396 .46302 L
.21126 .43836 L
.21647 .42715 L
.22479 .41371 L
F
0 g
.24112 .39819 m
.26578 .39443 L
.29043 .41284 L
.29122 .41371 L
.30588 .43836 L
.31187 .46302 L
.31408 .48767 L
.3139 .51233 L
.31123 .53698 L
.30438 .56164 L
.29043 .58376 L
.28835 .58629 L
.26578 .60246 L
.24112 .59906 L
.22673 .58629 L
.21647 .57041 L
.21223 .56164 L
.2044 .53698 L
.20104 .51233 L
.20091 .48767 L
.20396 .46302 L
.21126 .43836 L
.21647 .42715 L
.22479 .41371 L
.24112 .39819 L
s
.1 g
.35012 .98077 m
.3644 .97023 L
.38067 .95611 L
.38905 .94784 L
.40392 .93146 L
.41371 .91931 L
.42293 .9068 L
.43836 .8833 L
.43906 .88215 L
.45297 .8575 L
.46302 .83742 L
.46515 .83284 L
.47584 .80819 L
.48531 .78353 L
.48767 .7769 L
.49363 .75888 L
.50097 .73422 L
.50744 .70957 L
.51233 .6884 L
.51306 .68491 L
.51784 .66026 L
.5219 .6356 L
.52526 .61095 L
.52795 .58629 L
.52998 .56164 L
.53136 .53698 L
.53209 .51233 L
.53219 .48767 L
.53164 .46302 L
.53045 .43836 L
.52861 .41371 L
.52611 .38905 L
.52294 .3644 L
.51907 .33974 L
.51449 .31509 L
.51233 .30466 L
.50909 .29043 L
.50284 .26578 L
.49571 .24112 L
.48767 .21655 L
.48764 .21647 L
.47841 .19181 L
.46798 .16716 L
.46302 .15641 L
.45612 .1425 L
.44254 .11785 L
.43836 .11092 L
.42683 .0932 L
.41371 .07528 L
.40833 .06854 L
.38905 .04713 L
.3858 .04389 L
.3644 .02512 L
.35658 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.35012 .98077 m
.3644 .97023 L
.38067 .95611 L
.38905 .94784 L
.40392 .93146 L
.41371 .91931 L
.42293 .9068 L
.43836 .8833 L
.43906 .88215 L
.45297 .8575 L
.46302 .83742 L
.46515 .83284 L
.47584 .80819 L
.48531 .78353 L
.48767 .7769 L
.49363 .75888 L
.50097 .73422 L
.50744 .70957 L
.51233 .6884 L
.51306 .68491 L
.51784 .66026 L
.5219 .6356 L
.52526 .61095 L
.52795 .58629 L
.52998 .56164 L
.53136 .53698 L
.53209 .51233 L
.53219 .48767 L
.53164 .46302 L
.53045 .43836 L
.52861 .41371 L
.52611 .38905 L
.52294 .3644 L
.51907 .33974 L
.51449 .31509 L
.51233 .30466 L
.50909 .29043 L
.50284 .26578 L
.49571 .24112 L
.48767 .21655 L
.48764 .21647 L
.47841 .19181 L
.46798 .16716 L
.46302 .15641 L
.45612 .1425 L
.44254 .11785 L
.43836 .11092 L
.42683 .0932 L
.41371 .07528 L
.40833 .06854 L
Mistroke
.38905 .04713 L
.3858 .04389 L
.3644 .02512 L
.35658 .01923 L
Mfstroke
.46784 .98077 m
.48308 .95611 L
.48767 .94809 L
.4966 .93146 L
.50876 .9068 L
.51233 .89908 L
.51965 .88215 L
.5295 .8575 L
.53698 .8371 L
.53843 .83284 L
.54639 .80819 L
.55363 .78353 L
.56017 .75888 L
.56164 .75296 L
.56589 .73422 L
.57097 .70957 L
.57547 .68491 L
.57939 .66026 L
.58275 .6356 L
.58554 .61095 L
.58629 .60346 L
.58772 .58629 L
.58935 .56164 L
.59046 .53698 L
.59106 .51233 L
.59114 .48767 L
.59071 .46302 L
.58977 .43836 L
.58831 .41371 L
.58634 .38905 L
.58629 .38856 L
.58372 .3644 L
.58054 .33974 L
.57679 .31509 L
.57247 .29043 L
.56756 .26578 L
.56206 .24112 L
.56164 .23935 L
.55572 .21647 L
.54866 .19181 L
.54089 .16716 L
.53698 .15558 L
.53223 .1425 L
.52258 .11785 L
.51233 .09398 L
.51197 .0932 L
.50005 .06854 L
.48767 .04536 L
.48684 .04389 L
.47191 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.46784 .98077 m
.48308 .95611 L
.48767 .94809 L
.4966 .93146 L
.50876 .9068 L
.51233 .89908 L
.51965 .88215 L
.5295 .8575 L
.53698 .8371 L
.53843 .83284 L
.54639 .80819 L
.55363 .78353 L
.56017 .75888 L
.56164 .75296 L
.56589 .73422 L
.57097 .70957 L
.57547 .68491 L
.57939 .66026 L
.58275 .6356 L
.58554 .61095 L
.58629 .60346 L
.58772 .58629 L
.58935 .56164 L
.59046 .53698 L
.59106 .51233 L
.59114 .48767 L
.59071 .46302 L
.58977 .43836 L
.58831 .41371 L
.58634 .38905 L
.58629 .38856 L
.58372 .3644 L
.58054 .33974 L
.57679 .31509 L
.57247 .29043 L
.56756 .26578 L
.56206 .24112 L
.56164 .23935 L
.55572 .21647 L
.54866 .19181 L
.54089 .16716 L
.53698 .15558 L
.53223 .1425 L
.52258 .11785 L
.51233 .09398 L
.51197 .0932 L
.50005 .06854 L
.48767 .04536 L
.48684 .04389 L
.47191 .01923 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.46061 .98077 m
.45161 .95611 L
.44358 .93146 L
.43836 .91378 L
.43648 .9068 L
.4303 .88215 L
.42482 .8575 L
.42001 .83284 L
.41583 .80819 L
.41371 .79398 L
.41234 .78353 L
.40949 .75888 L
.40717 .73422 L
.40538 .70957 L
.4041 .68491 L
.40332 .66026 L
.40303 .6356 L
.40323 .61095 L
.40391 .58629 L
.40506 .56164 L
.40668 .53698 L
.40875 .51233 L
.41126 .48767 L
.41371 .46702 L
.41425 .46302 L
.41786 .43836 L
.42195 .41371 L
.42653 .38905 L
.43158 .3644 L
.43708 .33974 L
.43836 .3343 L
.44329 .31509 L
.45012 .29043 L
.45747 .26578 L
.46302 .24826 L
.46545 .24112 L
.47427 .21647 L
.48375 .19181 L
.48767 .18209 L
.4941 .16716 L
.5054 .1425 L
.51233 .12827 L
.51771 .11785 L
.53125 .0932 L
.53698 .08337 L
.54618 .06854 L
.56164 .0455 L
.56278 .04389 L
.58157 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.46061 .98077 m
.45161 .95611 L
.44358 .93146 L
.43836 .91378 L
.43648 .9068 L
.4303 .88215 L
.42482 .8575 L
.42001 .83284 L
.41583 .80819 L
.41371 .79398 L
.41234 .78353 L
.40949 .75888 L
.40717 .73422 L
.40538 .70957 L
.4041 .68491 L
.40332 .66026 L
.40303 .6356 L
.40323 .61095 L
.40391 .58629 L
.40506 .56164 L
.40668 .53698 L
.40875 .51233 L
.41126 .48767 L
.41371 .46702 L
.41425 .46302 L
.41786 .43836 L
.42195 .41371 L
.42653 .38905 L
.43158 .3644 L
.43708 .33974 L
.43836 .3343 L
.44329 .31509 L
.45012 .29043 L
.45747 .26578 L
.46302 .24826 L
.46545 .24112 L
.47427 .21647 L
.48375 .19181 L
.48767 .18209 L
.4941 .16716 L
.5054 .1425 L
.51233 .12827 L
.51771 .11785 L
.53125 .0932 L
.53698 .08337 L
.54618 .06854 L
.56164 .0455 L
.56278 .04389 L
.58157 .01923 L
s
.2 g
.98077 .41031 m
.97902 .38905 L
.97638 .3644 L
.97303 .33974 L
.96891 .31509 L
.96396 .29043 L
.95813 .26578 L
.95611 .25808 L
.95133 .24112 L
.94345 .21647 L
.93434 .19181 L
.93146 .1847 L
.92373 .16716 L
.91132 .1425 L
.9068 .13448 L
.89656 .11785 L
.88215 .09769 L
.87858 .0932 L
.8575 .07041 L
.85553 .06854 L
.83284 .05057 L
.82243 .04389 L
.80819 .03696 L
.78353 .02887 L
.75888 .02581 L
.73422 .02751 L
.70957 .03384 L
.68646 .04389 L
.68491 .04481 L
.66026 .06052 L
.64989 .06854 L
.6356 .08123 L
.62363 .0932 L
.61095 .10741 L
.60243 .11785 L
.58629 .13979 L
.58444 .1425 L
.56879 .16716 L
.56164 .17953 L
.55497 .19181 L
.54261 .21647 L
.53698 .22861 L
.53153 .24112 L
.52154 .26578 L
.51247 .29043 L
.51233 .29083 L
.50437 .31509 L
.49702 .33974 L
.49039 .3644 L
.48767 .37532 L
.48451 .38905 L
.47933 .41371 L
.47474 .43836 L
.47075 .46302 L
.46736 .48767 L
.46455 .51233 L
.46302 .52838 L
.46234 .53698 L
.46073 .56164 L
.45969 .58629 L
.45922 .61095 L
.45933 .6356 L
.46003 .66026 L
.46134 .68491 L
.46302 .70676 L
.46329 .70957 L
.46594 .73422 L
.46929 .75888 L
.47338 .78353 L
.47826 .80819 L
.48399 .83284 L
.48767 .84693 L
.49069 .8575 L
.49852 .88215 L
.50756 .9068 L
.51233 .9185 L
.51807 .93146 L
.53039 .95611 L
.53698 .96781 L
.545 .98077 L
.98077 .98077 L
F
0 g
.98077 .41031 m
.97902 .38905 L
.97638 .3644 L
.97303 .33974 L
.96891 .31509 L
.96396 .29043 L
.95813 .26578 L
.95611 .25808 L
.95133 .24112 L
.94345 .21647 L
.93434 .19181 L
.93146 .1847 L
.92373 .16716 L
.91132 .1425 L
.9068 .13448 L
.89656 .11785 L
.88215 .09769 L
.87858 .0932 L
.8575 .07041 L
.85553 .06854 L
.83284 .05057 L
.82243 .04389 L
.80819 .03696 L
.78353 .02887 L
.75888 .02581 L
.73422 .02751 L
.70957 .03384 L
.68646 .04389 L
.68491 .04481 L
.66026 .06052 L
.64989 .06854 L
.6356 .08123 L
.62363 .0932 L
.61095 .10741 L
.60243 .11785 L
.58629 .13979 L
.58444 .1425 L
.56879 .16716 L
.56164 .17953 L
.55497 .19181 L
.54261 .21647 L
.53698 .22861 L
.53153 .24112 L
.52154 .26578 L
.51247 .29043 L
.51233 .29083 L
.50437 .31509 L
.49702 .33974 L
.49039 .3644 L
.48767 .37532 L
Mistroke
.48451 .38905 L
.47933 .41371 L
.47474 .43836 L
.47075 .46302 L
.46736 .48767 L
.46455 .51233 L
.46302 .52838 L
.46234 .53698 L
.46073 .56164 L
.45969 .58629 L
.45922 .61095 L
.45933 .6356 L
.46003 .66026 L
.46134 .68491 L
.46302 .70676 L
.46329 .70957 L
.46594 .73422 L
.46929 .75888 L
.47338 .78353 L
.47826 .80819 L
.48399 .83284 L
.48767 .84693 L
.49069 .8575 L
.49852 .88215 L
.50756 .9068 L
.51233 .9185 L
.51807 .93146 L
.53039 .95611 L
.53698 .96781 L
.545 .98077 L
Mfstroke
.3 g
.76284 .98077 m
.78353 .96561 L
.79435 .95611 L
.80819 .94205 L
.81751 .93146 L
.83284 .9117 L
.83632 .9068 L
.85226 .88215 L
.8575 .87319 L
.86605 .8575 L
.87818 .83284 L
.88215 .82406 L
.88888 .80819 L
.89839 .78353 L
.9068 .75907 L
.90687 .75888 L
.91433 .73422 L
.92096 .70957 L
.92679 .68491 L
.93146 .66236 L
.93186 .66026 L
.93615 .6356 L
.93975 .61095 L
.94268 .58629 L
.94494 .56164 L
.94655 .53698 L
.94748 .51233 L
.94774 .48767 L
.94731 .46302 L
.94618 .43836 L
.94432 .41371 L
.94169 .38905 L
.93826 .3644 L
.93396 .33974 L
.93146 .3274 L
.92869 .31509 L
.92233 .29043 L
.91478 .26578 L
.9068 .24361 L
.90583 .24112 L
.89515 .21647 L
.88231 .19181 L
.88215 .19154 L
.86654 .16716 L
.8575 .15532 L
.84632 .1425 L
.83284 .12973 L
.81753 .11785 L
.80819 .11229 L
.78353 .10166 L
.75888 .09704 L
.73422 .09798 L
.70957 .10429 L
.68491 .11596 L
.68165 .11785 L
.66026 .13318 L
.64944 .1425 L
.6356 .15637 L
.62598 .16716 L
.61095 .18631 L
.60699 .19181 L
.59092 .21647 L
.58629 .22431 L
.57703 .24112 L
.56482 .26578 L
.56164 .27275 L
.55406 .29043 L
.54448 .31509 L
.53698 .33661 L
.53596 .33974 L
.52845 .3644 L
.52177 .38905 L
.5159 .41371 L
.51233 .43052 L
.5108 .43836 L
.50647 .46302 L
.50283 .48767 L
.49986 .51233 L
.49756 .53698 L
.49592 .56164 L
.49495 .58629 L
.49466 .61095 L
.49505 .6356 L
.49614 .66026 L
.49797 .68491 L
.50055 .70957 L
.50395 .73422 L
.5082 .75888 L
.51233 .77881 L
.51341 .78353 L
.51971 .80819 L
.5272 .83284 L
.53607 .8575 L
.53698 .8598 L
.54665 .88215 L
.55936 .9068 L
.56164 .91075 L
.57494 .93146 L
.58629 .94627 L
.59487 .95611 L
.61095 .97137 L
.62292 .98077 L
F
0 g
.76284 .98077 m
.78353 .96561 L
.79435 .95611 L
.80819 .94205 L
.81751 .93146 L
.83284 .9117 L
.83632 .9068 L
.85226 .88215 L
.8575 .87319 L
.86605 .8575 L
.87818 .83284 L
.88215 .82406 L
.88888 .80819 L
.89839 .78353 L
.9068 .75907 L
.90687 .75888 L
.91433 .73422 L
.92096 .70957 L
.92679 .68491 L
.93146 .66236 L
.93186 .66026 L
.93615 .6356 L
.93975 .61095 L
.94268 .58629 L
.94494 .56164 L
.94655 .53698 L
.94748 .51233 L
.94774 .48767 L
.94731 .46302 L
.94618 .43836 L
.94432 .41371 L
.94169 .38905 L
.93826 .3644 L
.93396 .33974 L
.93146 .3274 L
.92869 .31509 L
.92233 .29043 L
.91478 .26578 L
.9068 .24361 L
.90583 .24112 L
.89515 .21647 L
.88231 .19181 L
.88215 .19154 L
.86654 .16716 L
.8575 .15532 L
.84632 .1425 L
.83284 .12973 L
.81753 .11785 L
.80819 .11229 L
.78353 .10166 L
Mistroke
.75888 .09704 L
.73422 .09798 L
.70957 .10429 L
.68491 .11596 L
.68165 .11785 L
.66026 .13318 L
.64944 .1425 L
.6356 .15637 L
.62598 .16716 L
.61095 .18631 L
.60699 .19181 L
.59092 .21647 L
.58629 .22431 L
.57703 .24112 L
.56482 .26578 L
.56164 .27275 L
.55406 .29043 L
.54448 .31509 L
.53698 .33661 L
.53596 .33974 L
.52845 .3644 L
.52177 .38905 L
.5159 .41371 L
.51233 .43052 L
.5108 .43836 L
.50647 .46302 L
.50283 .48767 L
.49986 .51233 L
.49756 .53698 L
.49592 .56164 L
.49495 .58629 L
.49466 .61095 L
.49505 .6356 L
.49614 .66026 L
.49797 .68491 L
.50055 .70957 L
.50395 .73422 L
.5082 .75888 L
.51233 .77881 L
.51341 .78353 L
.51971 .80819 L
.5272 .83284 L
.53607 .8575 L
.53698 .8598 L
.54665 .88215 L
.55936 .9068 L
.56164 .91075 L
.57494 .93146 L
.58629 .94627 L
.59487 .95611 L
Mistroke
.61095 .97137 L
.62292 .98077 L
Mfstroke
.4 g
.70957 .15975 m
.73422 .15346 L
.75888 .15331 L
.78353 .15959 L
.80029 .16716 L
.80819 .17301 L
.83005 .19181 L
.83284 .19487 L
.85017 .21647 L
.8575 .22766 L
.86536 .24112 L
.87747 .26578 L
.88215 .27688 L
.88733 .29043 L
.89543 .31509 L
.90209 .33974 L
.9068 .36087 L
.9075 .3644 L
.9118 .38905 L
.91511 .41371 L
.9175 .43836 L
.91904 .46302 L
.91976 .48767 L
.9197 .51233 L
.91886 .53698 L
.91727 .56164 L
.91492 .58629 L
.9118 .61095 L
.90791 .6356 L
.9068 .64182 L
.90318 .66026 L
.89759 .68491 L
.89109 .70957 L
.88362 .73422 L
.88215 .73872 L
.87504 .75888 L
.86523 .78353 L
.8575 .80086 L
.85399 .80819 L
.84099 .83284 L
.83284 .84656 L
.8258 .8575 L
.80819 .88133 L
.80753 .88215 L
.78448 .9068 L
.78353 .90767 L
.75888 .92687 L
.75233 .93146 L
.73422 .93963 L
.70957 .94625 L
.68491 .94676 L
.66026 .94085 L
.64015 .93146 L
.6356 .92786 L
.6112 .9068 L
.61095 .90653 L
.59135 .88215 L
.58629 .87445 L
.57634 .8575 L
.56437 .83284 L
.56164 .82641 L
.55461 .80819 L
.54659 .78353 L
.54 .75888 L
.53698 .74567 L
.53466 .73422 L
.53041 .70957 L
.52715 .68491 L
.5248 .66026 L
.5233 .6356 L
.52262 .61095 L
.52273 .58629 L
.52361 .56164 L
.52524 .53698 L
.52764 .51233 L
.53079 .48767 L
.53473 .46302 L
.53698 .45074 L
.53949 .43836 L
.54513 .41371 L
.55168 .38905 L
.5592 .3644 L
.56164 .35709 L
.56784 .33974 L
.57773 .31509 L
.58629 .29613 L
.58905 .29043 L
.60215 .26578 L
.61095 .25114 L
.61748 .24112 L
.6356 .21689 L
.63595 .21647 L
.65933 .19181 L
.66026 .19098 L
.68491 .17216 L
.69221 .16716 L
F
0 g
.70957 .15975 m
.73422 .15346 L
.75888 .15331 L
.78353 .15959 L
.80029 .16716 L
.80819 .17301 L
.83005 .19181 L
.83284 .19487 L
.85017 .21647 L
.8575 .22766 L
.86536 .24112 L
.87747 .26578 L
.88215 .27688 L
.88733 .29043 L
.89543 .31509 L
.90209 .33974 L
.9068 .36087 L
.9075 .3644 L
.9118 .38905 L
.91511 .41371 L
.9175 .43836 L
.91904 .46302 L
.91976 .48767 L
.9197 .51233 L
.91886 .53698 L
.91727 .56164 L
.91492 .58629 L
.9118 .61095 L
.90791 .6356 L
.9068 .64182 L
.90318 .66026 L
.89759 .68491 L
.89109 .70957 L
.88362 .73422 L
.88215 .73872 L
.87504 .75888 L
.86523 .78353 L
.8575 .80086 L
.85399 .80819 L
.84099 .83284 L
.83284 .84656 L
.8258 .8575 L
.80819 .88133 L
.80753 .88215 L
.78448 .9068 L
.78353 .90767 L
.75888 .92687 L
.75233 .93146 L
.73422 .93963 L
.70957 .94625 L
Mistroke
.68491 .94676 L
.66026 .94085 L
.64015 .93146 L
.6356 .92786 L
.6112 .9068 L
.61095 .90653 L
.59135 .88215 L
.58629 .87445 L
.57634 .8575 L
.56437 .83284 L
.56164 .82641 L
.55461 .80819 L
.54659 .78353 L
.54 .75888 L
.53698 .74567 L
.53466 .73422 L
.53041 .70957 L
.52715 .68491 L
.5248 .66026 L
.5233 .6356 L
.52262 .61095 L
.52273 .58629 L
.52361 .56164 L
.52524 .53698 L
.52764 .51233 L
.53079 .48767 L
.53473 .46302 L
.53698 .45074 L
.53949 .43836 L
.54513 .41371 L
.55168 .38905 L
.5592 .3644 L
.56164 .35709 L
.56784 .33974 L
.57773 .31509 L
.58629 .29613 L
.58905 .29043 L
.60215 .26578 L
.61095 .25114 L
.61748 .24112 L
.6356 .21689 L
.63595 .21647 L
.65933 .19181 L
.66026 .19098 L
.68491 .17216 L
.69221 .16716 L
.70957 .15975 L
Mfstroke
.5 g
.70957 .20791 m
.73422 .20164 L
.75888 .20239 L
.78353 .2106 L
.79476 .21647 L
.80819 .22738 L
.82205 .24112 L
.83284 .25497 L
.84016 .26578 L
.85378 .29043 L
.8575 .29842 L
.86445 .31509 L
.87298 .33974 L
.87978 .3644 L
.88215 .37447 L
.88516 .38905 L
.8893 .41371 L
.89233 .43836 L
.89434 .46302 L
.89541 .48767 L
.89556 .51233 L
.89483 .53698 L
.89324 .56164 L
.89078 .58629 L
.88745 .61095 L
.88322 .6356 L
.88215 .64111 L
.87802 .66026 L
.87182 .68491 L
.86451 .70957 L
.8575 .73009 L
.85597 .73422 L
.84601 .75888 L
.83435 .78353 L
.83284 .78645 L
.8206 .80819 L
.80819 .82696 L
.80393 .83284 L
.78353 .85666 L
.78275 .8575 L
.75888 .87779 L
.75354 .88215 L
.73422 .89145 L
.70957 .8981 L
.68491 .89776 L
.66026 .88998 L
.64554 .88215 L
.6356 .87373 L
.61924 .8575 L
.61095 .84683 L
.60143 .83284 L
.58801 .80819 L
.58629 .80451 L
.57746 .78353 L
.56903 .75888 L
.56231 .73422 L
.56164 .73144 L
.557 .70957 L
.55292 .68491 L
.54995 .66026 L
.54798 .6356 L
.54697 .61095 L
.54686 .58629 L
.54763 .56164 L
.54927 .53698 L
.55177 .51233 L
.55515 .48767 L
.55944 .46302 L
.56164 .45205 L
.56468 .43836 L
.57094 .41371 L
.57831 .38905 L
.58629 .36607 L
.58692 .3644 L
.59695 .33974 L
.60871 .31509 L
.61095 .31083 L
.6226 .29043 L
.6356 .27103 L
.63945 .26578 L
.66026 .24185 L
.66095 .24112 L
.68491 .22116 L
.69073 .21647 L
F
0 g
.70957 .20791 m
.73422 .20164 L
.75888 .20239 L
.78353 .2106 L
.79476 .21647 L
.80819 .22738 L
.82205 .24112 L
.83284 .25497 L
.84016 .26578 L
.85378 .29043 L
.8575 .29842 L
.86445 .31509 L
.87298 .33974 L
.87978 .3644 L
.88215 .37447 L
.88516 .38905 L
.8893 .41371 L
.89233 .43836 L
.89434 .46302 L
.89541 .48767 L
.89556 .51233 L
.89483 .53698 L
.89324 .56164 L
.89078 .58629 L
.88745 .61095 L
.88322 .6356 L
.88215 .64111 L
.87802 .66026 L
.87182 .68491 L
.86451 .70957 L
.8575 .73009 L
.85597 .73422 L
.84601 .75888 L
.83435 .78353 L
.83284 .78645 L
.8206 .80819 L
.80819 .82696 L
.80393 .83284 L
.78353 .85666 L
.78275 .8575 L
.75888 .87779 L
.75354 .88215 L
.73422 .89145 L
.70957 .8981 L
.68491 .89776 L
.66026 .88998 L
.64554 .88215 L
.6356 .87373 L
.61924 .8575 L
.61095 .84683 L
Mistroke
.60143 .83284 L
.58801 .80819 L
.58629 .80451 L
.57746 .78353 L
.56903 .75888 L
.56231 .73422 L
.56164 .73144 L
.557 .70957 L
.55292 .68491 L
.54995 .66026 L
.54798 .6356 L
.54697 .61095 L
.54686 .58629 L
.54763 .56164 L
.54927 .53698 L
.55177 .51233 L
.55515 .48767 L
.55944 .46302 L
.56164 .45205 L
.56468 .43836 L
.57094 .41371 L
.57831 .38905 L
.58629 .36607 L
.58692 .3644 L
.59695 .33974 L
.60871 .31509 L
.61095 .31083 L
.6226 .29043 L
.6356 .27103 L
.63945 .26578 L
.66026 .24185 L
.66095 .24112 L
.68491 .22116 L
.69073 .21647 L
.70957 .20791 L
Mfstroke
.6 g
.70957 .25239 m
.73422 .24615 L
.75888 .24799 L
.78353 .25863 L
.79423 .26578 L
.80819 .27988 L
.81693 .29043 L
.83235 .31509 L
.83284 .31603 L
.84394 .33974 L
.8528 .3644 L
.8575 .38058 L
.85965 .38905 L
.86489 .41371 L
.86873 .43836 L
.87134 .46302 L
.87282 .48767 L
.87324 .51233 L
.87265 .53698 L
.87106 .56164 L
.86848 .58629 L
.86488 .61095 L
.86023 .6356 L
.8575 .64794 L
.85446 .66026 L
.84746 .68491 L
.83907 .70957 L
.83284 .7254 L
.82907 .73422 L
.8171 .75888 L
.80819 .77446 L
.80252 .78353 L
.78392 .80819 L
.78353 .80863 L
.75888 .83218 L
.7583 .83284 L
.73422 .84694 L
.70957 .85362 L
.68491 .85224 L
.66026 .84214 L
.64649 .83284 L
.6356 .82155 L
.6245 .80819 L
.61095 .78644 L
.60937 .78353 L
.59794 .75888 L
.58921 .73422 L
.58629 .72437 L
.58244 .70957 L
.57728 .68491 L
.5735 .66026 L
.57096 .6356 L
.56954 .61095 L
.56917 .58629 L
.56981 .56164 L
.57146 .53698 L
.57409 .51233 L
.57774 .48767 L
.58245 .46302 L
.58629 .44621 L
.58828 .43836 L
.59535 .41371 L
.60382 .38905 L
.61095 .37122 L
.61391 .3644 L
.626 .33974 L
.6356 .3232 L
.64074 .31509 L
.6596 .29043 L
.66026 .2897 L
.68491 .26668 L
.68567 .26578 L
F
0 g
.70957 .25239 m
.73422 .24615 L
.75888 .24799 L
.78353 .25863 L
.79423 .26578 L
.80819 .27988 L
.81693 .29043 L
.83235 .31509 L
.83284 .31603 L
.84394 .33974 L
.8528 .3644 L
.8575 .38058 L
.85965 .38905 L
.86489 .41371 L
.86873 .43836 L
.87134 .46302 L
.87282 .48767 L
.87324 .51233 L
.87265 .53698 L
.87106 .56164 L
.86848 .58629 L
.86488 .61095 L
.86023 .6356 L
.8575 .64794 L
.85446 .66026 L
.84746 .68491 L
.83907 .70957 L
.83284 .7254 L
.82907 .73422 L
.8171 .75888 L
.80819 .77446 L
.80252 .78353 L
.78392 .80819 L
.78353 .80863 L
.75888 .83218 L
.7583 .83284 L
.73422 .84694 L
.70957 .85362 L
.68491 .85224 L
.66026 .84214 L
.64649 .83284 L
.6356 .82155 L
.6245 .80819 L
.61095 .78644 L
.60937 .78353 L
.59794 .75888 L
.58921 .73422 L
.58629 .72437 L
.58244 .70957 L
.57728 .68491 L
Mistroke
.5735 .66026 L
.57096 .6356 L
.56954 .61095 L
.56917 .58629 L
.56981 .56164 L
.57146 .53698 L
.57409 .51233 L
.57774 .48767 L
.58245 .46302 L
.58629 .44621 L
.58828 .43836 L
.59535 .41371 L
.60382 .38905 L
.61095 .37122 L
.61391 .3644 L
.626 .33974 L
.6356 .3232 L
.64074 .31509 L
.6596 .29043 L
.66026 .2897 L
.68491 .26668 L
.68567 .26578 L
.70957 .25239 L
Mfstroke
.7 g
.73422 .28937 m
.75042 .29043 L
.75888 .29265 L
.78353 .30663 L
.79324 .31509 L
.80819 .33467 L
.81146 .33974 L
.82424 .3644 L
.83284 .3873 L
.83342 .38905 L
.84032 .41371 L
.84533 .43836 L
.84874 .46302 L
.85078 .48767 L
.85155 .51233 L
.85113 .53698 L
.84955 .56164 L
.8468 .58629 L
.84286 .61095 L
.83765 .6356 L
.83284 .65416 L
.83108 .66026 L
.82297 .68491 L
.81295 .70957 L
.80819 .71967 L
.80067 .73422 L
.78485 .75888 L
.78353 .76063 L
.76355 .78353 L
.75888 .78752 L
.73422 .80372 L
.722 .80819 L
.70957 .81044 L
.68653 .80819 L
.68491 .80771 L
.66026 .79439 L
.64783 .78353 L
.6356 .7673 L
.63012 .75888 L
.61761 .73422 L
.61095 .71672 L
.60857 .70957 L
.60177 .68491 L
.59686 .66026 L
.59352 .6356 L
.59156 .61095 L
.59085 .58629 L
.59133 .56164 L
.59298 .53698 L
.59578 .51233 L
.59978 .48767 L
.60506 .46302 L
.61095 .44096 L
.61172 .43836 L
.6199 .41371 L
.63003 .38905 L
.6356 .37745 L
.64247 .3644 L
.6585 .33974 L
.66026 .33745 L
.68023 .31509 L
.68491 .31122 L
.70957 .29557 L
.72596 .29043 L
F
0 g
.73422 .28937 m
.75042 .29043 L
.75888 .29265 L
.78353 .30663 L
.79324 .31509 L
.80819 .33467 L
.81146 .33974 L
.82424 .3644 L
.83284 .3873 L
.83342 .38905 L
.84032 .41371 L
.84533 .43836 L
.84874 .46302 L
.85078 .48767 L
.85155 .51233 L
.85113 .53698 L
.84955 .56164 L
.8468 .58629 L
.84286 .61095 L
.83765 .6356 L
.83284 .65416 L
.83108 .66026 L
.82297 .68491 L
.81295 .70957 L
.80819 .71967 L
.80067 .73422 L
.78485 .75888 L
.78353 .76063 L
.76355 .78353 L
.75888 .78752 L
.73422 .80372 L
.722 .80819 L
.70957 .81044 L
.68653 .80819 L
.68491 .80771 L
.66026 .79439 L
.64783 .78353 L
.6356 .7673 L
.63012 .75888 L
.61761 .73422 L
.61095 .71672 L
.60857 .70957 L
.60177 .68491 L
.59686 .66026 L
.59352 .6356 L
.59156 .61095 L
.59085 .58629 L
.59133 .56164 L
.59298 .53698 L
.59578 .51233 L
Mistroke
.59978 .48767 L
.60506 .46302 L
.61095 .44096 L
.61172 .43836 L
.6199 .41371 L
.63003 .38905 L
.6356 .37745 L
.64247 .3644 L
.6585 .33974 L
.66026 .33745 L
.68023 .31509 L
.68491 .31122 L
.70957 .29557 L
.72596 .29043 L
.73422 .28937 L
Mfstroke
.8 g
.70957 .33966 m
.73422 .33351 L
.75888 .33892 L
.76053 .33974 L
.78353 .3582 L
.7889 .3644 L
.80378 .38905 L
.80819 .39946 L
.81356 .41371 L
.82054 .43836 L
.82523 .46302 L
.82808 .48767 L
.82935 .51233 L
.82918 .53698 L
.82761 .56164 L
.82464 .58629 L
.82021 .61095 L
.81417 .6356 L
.80819 .65488 L
.80634 .66026 L
.7964 .68491 L
.78353 .70905 L
.78325 .70957 L
.76582 .73422 L
.75888 .74126 L
.73616 .75888 L
.73422 .75958 L
.70957 .76635 L
.68491 .76162 L
.6795 .75888 L
.66026 .74325 L
.6524 .73422 L
.6381 .70957 L
.6356 .7037 L
.62839 .68491 L
.62156 .66026 L
.61699 .6356 L
.61423 .61095 L
.61304 .58629 L
.61328 .56164 L
.61492 .53698 L
.61796 .51233 L
.62247 .48767 L
.62859 .46302 L
.6356 .44107 L
.63656 .43836 L
.64659 .41371 L
.65997 .38905 L
.66026 .3886 L
.67768 .3644 L
.68491 .35729 L
.7093 .33974 L
F
0 g
.70957 .33966 m
.73422 .33351 L
.75888 .33892 L
.76053 .33974 L
.78353 .3582 L
.7889 .3644 L
.80378 .38905 L
.80819 .39946 L
.81356 .41371 L
.82054 .43836 L
.82523 .46302 L
.82808 .48767 L
.82935 .51233 L
.82918 .53698 L
.82761 .56164 L
.82464 .58629 L
.82021 .61095 L
.81417 .6356 L
.80819 .65488 L
.80634 .66026 L
.7964 .68491 L
.78353 .70905 L
.78325 .70957 L
.76582 .73422 L
.75888 .74126 L
.73616 .75888 L
.73422 .75958 L
.70957 .76635 L
.68491 .76162 L
.6795 .75888 L
.66026 .74325 L
.6524 .73422 L
.6381 .70957 L
.6356 .7037 L
.62839 .68491 L
.62156 .66026 L
.61699 .6356 L
.61423 .61095 L
.61304 .58629 L
.61328 .56164 L
.61492 .53698 L
.61796 .51233 L
.62247 .48767 L
.62859 .46302 L
.6356 .44107 L
.63656 .43836 L
.64659 .41371 L
.65997 .38905 L
.66026 .3886 L
.67768 .3644 L
Mistroke
.68491 .35729 L
.7093 .33974 L
.70957 .33966 L
Mfstroke
.9 g
.70957 .38782 m
.73422 .38175 L
.75607 .38905 L
.75888 .39096 L
.78078 .41371 L
.78353 .42155 L
.79122 .43836 L
.79862 .46302 L
.80295 .48767 L
.80507 .51233 L
.8053 .53698 L
.80376 .56164 L
.80043 .58629 L
.79513 .61095 L
.78746 .6356 L
.78353 .6457 L
.77751 .66026 L
.76242 .68491 L
.75888 .68922 L
.73709 .70957 L
.73422 .71133 L
.70957 .7182 L
.68491 .70993 L
.68415 .70957 L
.66143 .68491 L
.66026 .68092 L
.65064 .66026 L
.64349 .6356 L
.63932 .61095 L
.63733 .58629 L
.63719 .56164 L
.6388 .53698 L
.64221 .51233 L
.6476 .48767 L
.65539 .46302 L
.66026 .4509 L
.66553 .43836 L
.68088 .41371 L
.68491 .40898 L
.7074 .38905 L
F
0 g
.70957 .38782 m
.73422 .38175 L
.75607 .38905 L
.75888 .39096 L
.78078 .41371 L
.78353 .42155 L
.79122 .43836 L
.79862 .46302 L
.80295 .48767 L
.80507 .51233 L
.8053 .53698 L
.80376 .56164 L
.80043 .58629 L
.79513 .61095 L
.78746 .6356 L
.78353 .6457 L
.77751 .66026 L
.76242 .68491 L
.75888 .68922 L
.73709 .70957 L
.73422 .71133 L
.70957 .7182 L
.68491 .70993 L
.68415 .70957 L
.66143 .68491 L
.66026 .68092 L
.65064 .66026 L
.64349 .6356 L
.63932 .61095 L
.63733 .58629 L
.63719 .56164 L
.6388 .53698 L
.64221 .51233 L
.6476 .48767 L
.65539 .46302 L
.66026 .4509 L
.66553 .43836 L
.68088 .41371 L
.68491 .40898 L
.7074 .38905 L
.70957 .38782 L
s
1 g
.70957 .44786 m
.73422 .44208 L
.75888 .46272 L
.7591 .46302 L
.77097 .48767 L
.77555 .51233 L
.77662 .53698 L
.77501 .56164 L
.77047 .58629 L
.76199 .61095 L
.75888 .61761 L
.74856 .6356 L
.73422 .65105 L
.70957 .65809 L
.68491 .63946 L
.68195 .6356 L
.67078 .61095 L
.66665 .58629 L
.66579 .56164 L
.66749 .53698 L
.67212 .51233 L
.68081 .48767 L
.68491 .47936 L
.69477 .46302 L
F
0 g
.70957 .44786 m
.73422 .44208 L
.75888 .46272 L
.7591 .46302 L
.77097 .48767 L
.77555 .51233 L
.77662 .53698 L
.77501 .56164 L
.77047 .58629 L
.76199 .61095 L
.75888 .61761 L
.74856 .6356 L
.73422 .65105 L
.70957 .65809 L
.68491 .63946 L
.68195 .6356 L
.67078 .61095 L
.66665 .58629 L
.66579 .56164 L
.66749 .53698 L
.67212 .51233 L
.68081 .48767 L
.68491 .47936 L
.69477 .46302 L
.70957 .44786 L
s
.1 g
.98077 .55394 m
.98019 .56164 L
.97805 .58629 L
.97532 .61095 L
.97199 .6356 L
.96805 .66026 L
.96347 .68491 L
.95824 .70957 L
.95611 .71877 L
.95233 .73422 L
.94574 .75888 L
.93844 .78353 L
.93146 .80507 L
.93038 .80819 L
.92136 .83284 L
.91143 .8575 L
.9068 .86821 L
.9004 .88215 L
.88812 .9068 L
.88215 .9179 L
.87438 .93146 L
.85884 .95611 L
.8575 .95811 L
.84099 .98077 L
.98077 .98077 L
F
0 g
.98077 .55394 m
.98019 .56164 L
.97805 .58629 L
.97532 .61095 L
.97199 .6356 L
.96805 .66026 L
.96347 .68491 L
.95824 .70957 L
.95611 .71877 L
.95233 .73422 L
.94574 .75888 L
.93844 .78353 L
.93146 .80507 L
.93038 .80819 L
.92136 .83284 L
.91143 .8575 L
.9068 .86821 L
.9004 .88215 L
.88812 .9068 L
.88215 .9179 L
.87438 .93146 L
.85884 .95611 L
.8575 .95811 L
.84099 .98077 L
s
.98077 .84746 m
.97749 .8575 L
.96881 .88215 L
.95926 .9068 L
.95611 .91448 L
.94886 .93146 L
.93762 .95611 L
.93146 .9689 L
.92537 .98077 L
.98077 .98077 L
F
.98077 .84746 m
.97749 .8575 L
.96881 .88215 L
.95926 .9068 L
.95611 .91448 L
.94886 .93146 L
.93762 .95611 L
.93146 .9689 L
.92537 .98077 L
s
.98077 .11647 m
.97106 .0932 L
.95931 .06854 L
.95611 .06237 L
.94586 .04389 L
.93146 .02087 L
.93034 .01923 L
.98077 .01923 L
F
.98077 .11647 m
.97106 .0932 L
.95931 .06854 L
.95611 .06237 L
.94586 .04389 L
.93146 .02087 L
.93034 .01923 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.481 .737 .984 r
.39684 .60838 .40477 .6139 .41785 .61307 .40995 .60807 Mtetra
.423 .731 .99 r
.40995 .60807 .41785 .61307 .43101 .61269 .42313 .60828 Mtetra
.357 .721 .987 r
.42313 .60828 .43101 .61269 .44425 .61264 .4364 .60888 Mtetra
.291 .709 .972 r
.4364 .60888 .44425 .61264 .45758 .61275 .44976 .60969 Mtetra
.239 .7 .949 r
.44976 .60969 .45758 .61275 .47102 .6128 .46323 .61042 Mtetra
.214 .703 .925 r
.46323 .61042 .47102 .6128 .48455 .61253 .47682 .61079 Mtetra
.226 .724 .911 r
.47682 .61079 .48455 .61253 .49819 .61166 .49051 .61046 Mtetra
.277 .766 .912 r
.49051 .61046 .49819 .61166 .51193 .60995 .50431 .60913 Mtetra
.362 .821 .925 r
.50431 .60913 .51193 .60995 .52575 .60719 .5182 .60658 Mtetra
.465 .878 .942 r
.5182 .60658 .52575 .60719 .53965 .60327 .53217 .60267 Mtetra
.568 .921 .955 r
.53217 .60267 .53965 .60327 .55361 .59818 .54621 .59736 Mtetra
.654 .945 .958 r
.54621 .59736 .55361 .59818 .56762 .59199 .5603 .59077 Mtetra
.715 .949 .954 r
.5603 .59077 .56762 .59199 .58167 .58487 .57442 .5831 Mtetra
.754 .939 .944 r
.57442 .5831 .58167 .58487 .59575 .57707 .58857 .57461 Mtetra
.775 .922 .934 r
.58857 .57461 .59575 .57707 .60987 .56884 .60275 .56564 Mtetra
.782 .9 .926 r
.60275 .56564 .60987 .56884 .62402 .56047 .61695 .55649 Mtetra
.779 .878 .919 r
.61695 .55649 .62402 .56047 .63821 .55219 .63119 .54746 Mtetra
.77 .856 .914 r
.63119 .54746 .63821 .55219 .65245 .54418 .64548 .53875 Mtetra
.758 .835 .911 r
.64548 .53875 .65245 .54418 .66675 .53658 .65983 .53053 Mtetra
.743 .816 .909 r
.65983 .53053 .66675 .53658 .68111 .52946 .67424 .52288 Mtetra
.729 .8 .908 r
.67424 .52288 .68111 .52946 .69556 .52283 .68872 .5158 Mtetra
.715 .786 .907 r
.68872 .5158 .69556 .52283 .71008 .51666 .70329 .50928 Mtetra
.703 .774 .907 r
.70329 .50928 .71008 .51666 .7247 .5109 .71795 .50324 Mtetra
.692 .765 .907 r
.71795 .50324 .7247 .5109 .73939 .50548 .7327 .49761 Mtetra
.684 .757 .907 r
.7327 .49761 .73939 .50548 .75418 .50033 .74753 .49229 Mtetra
.677 .752 .907 r
.74753 .49229 .75418 .50033 .76905 .49538 .76245 .48721 Mtetra
.673 .748 .907 r
.76245 .48721 .76905 .49538 .78401 .49056 .77747 .4823 Mtetra
.669 .746 .908 r
.77747 .4823 .78401 .49056 .79906 .48584 .79256 .47749 Mtetra
.667 .744 .908 r
.79256 .47749 .79906 .48584 .81419 .48117 .80775 .47276 Mtetra
.666 .743 .908 r
.80775 .47276 .81419 .48117 .8294 .47653 .82301 .46806 Mtetra
.665 .742 .908 r
.82301 .46806 .8294 .47653 .84469 .4719 .83836 .46337 Mtetra
.664 .742 .908 r
.83836 .46337 .84469 .4719 .86007 .46726 .8538 .45868 Mtetra
.8538 .45868 .86007 .46726 .87552 .46261 .86932 .45398 Mtetra
.664 .741 .908 r
.86932 .45398 .87552 .46261 .89107 .45794 .88492 .44927 Mtetra
.88492 .44927 .89107 .45794 .90669 .45325 .9006 .44453 Mtetra
.9006 .44453 .90669 .45325 .9224 .44853 .91637 .43977 Mtetra
.91637 .43977 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.434 .724 .987 r
.38883 .60299 .39684 .60838 .40995 .60807 .40195 .60325 Mtetra
.355 .707 .985 r
.40195 .60325 .40995 .60807 .42313 .60828 .41515 .60412 Mtetra
.265 .682 .967 r
.41515 .60412 .42313 .60828 .4364 .60888 .42844 .60547 Mtetra
.177 .653 .931 r
.42844 .60547 .4364 .60888 .44976 .60969 .44184 .60704 Mtetra
.109 .628 .885 r
.44184 .60704 .44976 .60969 .46323 .61042 .45534 .60855 Mtetra
.078 .622 .845 r
.45534 .60855 .46323 .61042 .47682 .61079 .46897 .60963 Mtetra
.094 .644 .824 r
.46897 .60963 .47682 .61079 .49051 .61046 .48272 .6099 Mtetra
.16 .696 .83 r
.48272 .6099 .49051 .61046 .50431 .60913 .49658 .60902 Mtetra
.267 .772 .857 r
.49658 .60902 .50431 .60913 .5182 .60658 .51054 .6067 Mtetra
.399 .852 .894 r
.51054 .6067 .5182 .60658 .53217 .60267 .52459 .60279 Mtetra
.532 .917 .923 r
.52459 .60279 .53217 .60267 .54621 .59736 .53871 .59726 Mtetra
.642 .954 .938 r
.53871 .59726 .54621 .59736 .5603 .59077 .55288 .59023 Mtetra
.719 .964 .94 r
.55288 .59023 .5603 .59077 .57442 .5831 .56708 .58193 Mtetra
.766 .956 .934 r
.56708 .58193 .57442 .5831 .58857 .57461 .5813 .57269 Mtetra
.791 .937 .926 r
.5813 .57269 .58857 .57461 .60275 .56564 .59555 .56288 Mtetra
.798 .915 .918 r
.59555 .56288 .60275 .56564 .61695 .55649 .60982 .55288 Mtetra
.796 .89 .912 r
.60982 .55288 .61695 .55649 .63119 .54746 .62411 .54301 Mtetra
.786 .867 .909 r
.62411 .54301 .63119 .54746 .64548 .53875 .63845 .53353 Mtetra
.772 .845 .907 r
.63845 .53353 .64548 .53875 .65983 .53053 .65284 .52463 Mtetra
.755 .824 .906 r
.65284 .52463 .65983 .53053 .67424 .52288 .6673 .51638 Mtetra
.739 .806 .905 r
.6673 .51638 .67424 .52288 .68872 .5158 .68183 .50882 Mtetra
.723 .791 .906 r
.68183 .50882 .68872 .5158 .70329 .50928 .69644 .50191 Mtetra
.709 .778 .906 r
.69644 .50191 .70329 .50928 .71795 .50324 .71114 .49556 Mtetra
.697 .767 .906 r
.71114 .49556 .71795 .50324 .7327 .49761 .72593 .48969 Mtetra
.687 .759 .907 r
.72593 .48969 .7327 .49761 .74753 .49229 .74082 .48419 Mtetra
.68 .754 .907 r
.74082 .48419 .74753 .49229 .76245 .48721 .75579 .47897 Mtetra
.674 .749 .907 r
.75579 .47897 .76245 .48721 .77747 .4823 .77085 .47395 Mtetra
.67 .746 .907 r
.77085 .47395 .77747 .4823 .79256 .47749 .78601 .46907 Mtetra
.668 .744 .908 r
.78601 .46907 .79256 .47749 .80775 .47276 .80124 .46426 Mtetra
.666 .743 .908 r
.80124 .46426 .80775 .47276 .82301 .46806 .81657 .4595 Mtetra
.665 .742 .908 r
.81657 .4595 .82301 .46806 .83836 .46337 .83198 .45476 Mtetra
.664 .742 .908 r
.83198 .45476 .83836 .46337 .8538 .45868 .84747 .45002 Mtetra
.84747 .45002 .8538 .45868 .86932 .45398 .86305 .44527 Mtetra
.664 .741 .908 r
.86305 .44527 .86932 .45398 .88492 .44927 .87871 .44051 Mtetra
.87871 .44051 .88492 .44927 .9006 .44453 .89446 .43572 Mtetra
.89446 .43572 .9006 .44453 .91637 .43977 .91029 .43091 Mtetra
.91029 .43091 .91637 .43977 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.375 .703 .985 r
.38073 .59773 .38883 .60299 .40195 .60325 .39387 .59862 Mtetra
.271 .671 .969 r
.39387 .59862 .40195 .60325 .41515 .60412 .40708 .60022 Mtetra
.153 .625 .927 r
.40708 .60022 .41515 .60412 .42844 .60547 .42039 .60238 Mtetra
.043 .572 .862 r
.42039 .60238 .42844 .60547 .44184 .60704 .43381 .60482 Mtetra
0 .53 .79 r
.43381 .60482 .44184 .60704 .45534 .60855 .44734 .60718 Mtetra
0 .516 .734 r
.44734 .60718 .45534 .60855 .46897 .60963 .46101 .60905 Mtetra
0 .54 .71 r
.46101 .60905 .46897 .60963 .48272 .6099 .47481 .60999 Mtetra
.034 .605 .724 r
.47481 .60999 .48272 .6099 .49658 .60902 .48874 .6096 Mtetra
.163 .703 .769 r
.48874 .6096 .49658 .60902 .51054 .6067 .50277 .60755 Mtetra
.326 .812 .829 r
.50277 .60755 .51054 .6067 .52459 .60279 .5169 .60365 Mtetra
.491 .903 .881 r
.5169 .60365 .52459 .60279 .53871 .59726 .53111 .59787 Mtetra
.628 .958 .912 r
.53111 .59787 .53871 .59726 .55288 .59023 .54536 .59035 Mtetra
.723 .976 .922 r
.54536 .59035 .55288 .59023 .56708 .58193 .55965 .58137 Mtetra
.779 .97 .92 r
.55965 .58137 .56708 .58193 .5813 .57269 .57395 .5713 Mtetra
.807 .951 .914 r
.57395 .5713 .5813 .57269 .59555 .56288 .58827 .56057 Mtetra
.816 .927 .908 r
.58827 .56057 .59555 .56288 .60982 .55288 .6026 .54963 Mtetra
.813 .901 .904 r
.6026 .54963 .60982 .55288 .62411 .54301 .61696 .53885 Mtetra
.802 .877 .902 r
.61696 .53885 .62411 .54301 .63845 .53353 .63135 .52852 Mtetra
.786 .853 .901 r
.63135 .52852 .63845 .53353 .65284 .52463 .64578 .51886 Mtetra
.768 .832 .901 r
.64578 .51886 .65284 .52463 .6673 .51638 .66029 .50998 Mtetra
.749 .812 .902 r
.66029 .50998 .6673 .51638 .68183 .50882 .67486 .50188 Mtetra
.731 .796 .903 r
.67486 .50188 .68183 .50882 .69644 .50191 .68952 .49454 Mtetra
.715 .782 .904 r
.68952 .49454 .69644 .50191 .71114 .49556 .70427 .48786 Mtetra
.702 .77 .905 r
.70427 .48786 .71114 .49556 .72593 .48969 .7191 .48173 Mtetra
.691 .762 .906 r
.7191 .48173 .72593 .48969 .74082 .48419 .73404 .47604 Mtetra
.682 .755 .906 r
.73404 .47604 .74082 .48419 .75579 .47897 .74906 .47067 Mtetra
.676 .75 .907 r
.74906 .47067 .75579 .47897 .77085 .47395 .76418 .46554 Mtetra
.671 .747 .907 r
.76418 .46554 .77085 .47395 .78601 .46907 .77938 .46056 Mtetra
.668 .745 .907 r
.77938 .46056 .78601 .46907 .80124 .46426 .79468 .45569 Mtetra
.667 .743 .908 r
.79468 .45569 .80124 .46426 .81657 .4595 .81006 .45086 Mtetra
.665 .742 .908 r
.81006 .45086 .81657 .4595 .83198 .45476 .82553 .44607 Mtetra
.82553 .44607 .83198 .45476 .84747 .45002 .84108 .44128 Mtetra
.664 .742 .908 r
.84108 .44128 .84747 .45002 .86305 .44527 .85672 .43648 Mtetra
.664 .741 .908 r
.85672 .43648 .86305 .44527 .87871 .44051 .87244 .43166 Mtetra
.87244 .43166 .87871 .44051 .89446 .43572 .88825 .42683 Mtetra
.88825 .42683 .89446 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.304 .674 .975 r
.37254 .59257 .38073 .59773 .39387 .59862 .38568 .59415 Mtetra
.17 .62 .937 r
.38568 .59415 .39387 .59862 .40708 .60022 .39891 .59656 Mtetra
.025 .546 .863 r
.39891 .59656 .40708 .60022 .42039 .60238 .41223 .59961 Mtetra
0 .47 .764 r
.41223 .59961 .42039 .60238 .43381 .60482 .42566 .60298 Mtetra
.181 0 0 r
.42566 .60298 .43381 .60482 .44734 .60718 .43923 .60628 Mtetra
.207 0 0 r
.43923 .60628 .44734 .60718 .46101 .60905 .45293 .60902 Mtetra
.175 0 0 r
.45293 .60902 .46101 .60905 .47481 .60999 .46678 .6107 Mtetra
.086 0 0 r
.46678 .6107 .47481 .60999 .48874 .6096 .48077 .61085 Mtetra
0 0 0 r
.48077 .61085 .48874 .6096 .50277 .60755 .49488 .60909 Mtetra
.251 .76 .754 r
.49488 .60909 .50277 .60755 .5169 .60365 .5091 .60521 Mtetra
.45 .882 .832 r
.5091 .60521 .5169 .60365 .53111 .59787 .52339 .59917 Mtetra
.615 .957 .881 r
.52339 .59917 .53111 .59787 .54536 .59035 .53774 .59112 Mtetra
.727 .984 .901 r
.53774 .59112 .54536 .59035 .55965 .58137 .55212 .58139 Mtetra
.792 .98 .903 r
.55212 .58139 .55965 .58137 .57395 .5713 .5665 .57041 Mtetra
.823 .961 .899 r
.5665 .57041 .57395 .5713 .58827 .56057 .5809 .55869 Mtetra
.833 .936 .895 r
.5809 .55869 .58827 .56057 .6026 .54963 .5953 .54672 Mtetra
.83 .91 .893 r
.5953 .54672 .6026 .54963 .61696 .53885 .60972 .53494 Mtetra
.818 .885 .893 r
.60972 .53494 .61696 .53885 .63135 .52852 .62417 .5237 Mtetra
.801 .861 .894 r
.62417 .5237 .63135 .52852 .64578 .51886 .63866 .51323 Mtetra
.781 .838 .896 r
.63866 .51323 .64578 .51886 .66029 .50998 .65321 .50364 Mtetra
.76 .818 .898 r
.65321 .50364 .66029 .50998 .67486 .50188 .66783 .49498 Mtetra
.74 .8 .9 r
.66783 .49498 .67486 .50188 .68952 .49454 .68253 .48717 Mtetra
.722 .785 .902 r
.68253 .48717 .68952 .49454 .70427 .48786 .69732 .48013 Mtetra
.707 .773 .904 r
.69732 .48013 .70427 .48786 .7191 .48173 .71221 .47373 Mtetra
.695 .764 .905 r
.71221 .47373 .7191 .48173 .73404 .47604 .72719 .46783 Mtetra
.685 .756 .906 r
.72719 .46783 .73404 .47604 .74906 .47067 .74227 .4623 Mtetra
.678 .751 .906 r
.74227 .4623 .74906 .47067 .76418 .46554 .75744 .45705 Mtetra
.673 .748 .907 r
.75744 .45705 .76418 .46554 .77938 .46056 .7727 .45198 Mtetra
.669 .745 .907 r
.7727 .45198 .77938 .46056 .79468 .45569 .78805 .44703 Mtetra
.667 .744 .908 r
.78805 .44703 .79468 .45569 .81006 .45086 .80349 .44214 Mtetra
.666 .743 .908 r
.80349 .44214 .81006 .45086 .82553 .44607 .81901 .43729 Mtetra
.665 .742 .908 r
.81901 .43729 .82553 .44607 .84108 .44128 .83462 .43244 Mtetra
.664 .742 .908 r
.83462 .43244 .84108 .44128 .85672 .43648 .85032 .42759 Mtetra
.85032 .42759 .85672 .43648 .87244 .43166 .8661 .42273 Mtetra
.664 .741 .908 r
.8661 .42273 .87244 .43166 .88825 .42683 .88197 .41785 Mtetra
.88197 .41785 .88825 .42683 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91398 .40801 Mtetra
.91398 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.221 .633 .955 r
.36425 .58752 .37254 .59257 .38568 .59415 .3774 .58985 Mtetra
.056 .551 .887 r
.3774 .58985 .38568 .59415 .39891 .59656 .39063 .59312 Mtetra
0 .45 .776 r
.39063 .59312 .39891 .59656 .41223 .59961 .40395 .59712 Mtetra
.239 0 0 r
.40395 .59712 .41223 .59961 .42566 .60298 .4174 .60151 Mtetra
.312 0 0 r
.4174 .60151 .42566 .60298 .43923 .60628 .43099 .60582 Mtetra
.328 0 0 r
.43099 .60582 .43923 .60628 .45293 .60902 .44473 .60951 Mtetra
.288 0 0 r
.44473 .60951 .45293 .60902 .46678 .6107 .45863 .61198 Mtetra
.191 0 0 r
.45863 .61198 .46678 .6107 .48077 .61085 .47268 .61272 Mtetra
.032 0 0 r
.47268 .61272 .48077 .61085 .49488 .60909 .48687 .61128 Mtetra
0 0 0 r
.48687 .61128 .49488 .60909 .5091 .60521 .50117 .60742 Mtetra
.412 .858 .783 r
.50117 .60742 .5091 .60521 .52339 .59917 .51556 .6011 Mtetra
.606 .954 .85 r
.51556 .6011 .52339 .59917 .53774 .59112 .53001 .59248 Mtetra
.734 .99 .878 r
.53001 .59248 .53774 .59112 .55212 .58139 .54448 .58195 Mtetra
.806 .988 .885 r
.54448 .58195 .55212 .58139 .5665 .57041 .55896 .57 Mtetra
.84 .968 .883 r
.55896 .57 .5665 .57041 .5809 .55869 .57344 .5572 Mtetra
.85 .943 .881 r
.57344 .5572 .5809 .55869 .5953 .54672 .58792 .54413 Mtetra
.846 .917 .881 r
.58792 .54413 .5953 .54672 .60972 .53494 .60241 .53128 Mtetra
.833 .891 .882 r
.60241 .53128 .60972 .53494 .62417 .5237 .61691 .51905 Mtetra
.815 .867 .885 r
.61691 .51905 .62417 .5237 .63866 .51323 .63146 .5077 Mtetra
.794 .844 .889 r
.63146 .5077 .63866 .51323 .65321 .50364 .64606 .49737 Mtetra
.771 .823 .893 r
.64606 .49737 .65321 .50364 .66783 .49498 .66072 .48809 Mtetra
.749 .805 .897 r
.66072 .48809 .66783 .49498 .68253 .48717 .67547 .4798 Mtetra
.73 .789 .9 r
.67547 .4798 .68253 .48717 .69732 .48013 .69031 .47237 Mtetra
.713 .776 .902 r
.69031 .47237 .69732 .48013 .71221 .47373 .70525 .46568 Mtetra
.699 .766 .904 r
.70525 .46568 .71221 .47373 .72719 .46783 .72028 .45955 Mtetra
.688 .758 .905 r
.72028 .45955 .72719 .46783 .74227 .4623 .73541 .45387 Mtetra
.68 .752 .906 r
.73541 .45387 .74227 .4623 .75744 .45705 .75063 .44849 Mtetra
.674 .748 .907 r
.75063 .44849 .75744 .45705 .7727 .45198 .76595 .44332 Mtetra
.67 .746 .907 r
.76595 .44332 .7727 .45198 .78805 .44703 .78135 .43829 Mtetra
.667 .744 .907 r
.78135 .43829 .78805 .44703 .80349 .44214 .79685 .43334 Mtetra
.666 .743 .908 r
.79685 .43334 .80349 .44214 .81901 .43729 .81243 .42842 Mtetra
.665 .742 .908 r
.81243 .42842 .81901 .43729 .83462 .43244 .8281 .42352 Mtetra
.664 .742 .908 r
.8281 .42352 .83462 .43244 .85032 .42759 .84386 .41862 Mtetra
.84386 .41862 .85032 .42759 .8661 .42273 .85971 .41371 Mtetra
.664 .741 .908 r
.85971 .41371 .8661 .42273 .88197 .41785 .87564 .40877 Mtetra
.87564 .40877 .88197 .41785 .89793 .41294 .89166 .40382 Mtetra
.89166 .40382 .89793 .41294 .91398 .40801 .90777 .39883 Mtetra
.90777 .39883 .91398 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.127 .58 .922 r
.35587 .58255 .36425 .58752 .3774 .58985 .36901 .58566 Mtetra
0 .469 .818 r
.36901 .58566 .3774 .58985 .39063 .59312 .38224 .58985 Mtetra
0 .343 .673 r
.38224 .58985 .39063 .59312 .40395 .59712 .39556 .59488 Mtetra
.361 0 0 r
.39556 .59488 .40395 .59712 .4174 .60151 .40902 .60035 Mtetra
.421 0 0 r
.40902 .60035 .4174 .60151 .43099 .60582 .42262 .60574 Mtetra
.426 0 0 r
.42262 .60574 .43099 .60582 .44473 .60951 .43639 .61043 Mtetra
.379 0 0 r
.43639 .61043 .44473 .60951 .45863 .61198 .45034 .61377 Mtetra
.278 0 0 r
.45034 .61377 .45863 .61198 .47268 .61272 .46445 .61514 Mtetra
.111 0 0 r
.46445 .61514 .47268 .61272 .48687 .61128 .47872 .61405 Mtetra
0 0 0 r
.47872 .61405 .48687 .61128 .50117 .60742 .49312 .61021 Mtetra
.383 .835 .739 r
.49312 .61021 .50117 .60742 .51556 .6011 .50761 .60359 Mtetra
.602 .95 .822 r
.50761 .60359 .51556 .6011 .53001 .59248 .52216 .59437 Mtetra
.745 .993 .858 r
.52216 .59437 .53001 .59248 .54448 .58195 .53673 .58298 Mtetra
.822 .992 .867 r
.53673 .58298 .54448 .58195 .55896 .57 .55131 .56999 Mtetra
.856 .972 .867 r
.55131 .56999 .55896 .57 .57344 .5572 .56588 .55605 Mtetra
.866 .947 .866 r
.56588 .55605 .57344 .5572 .58792 .54413 .58044 .5418 Mtetra
.862 .92 .867 r
.58044 .5418 .58792 .54413 .60241 .53128 .595 .52782 Mtetra
.848 .895 .871 r
.595 .52782 .60241 .53128 .61691 .51905 .60957 .51454 Mtetra
.829 .871 .876 r
.60957 .51454 .61691 .51905 .63146 .5077 .62418 .50227 Mtetra
.806 .848 .882 r
.62418 .50227 .63146 .5077 .64606 .49737 .63883 .49115 Mtetra
.782 .827 .887 r
.63883 .49115 .64606 .49737 .66072 .48809 .65355 .48122 Mtetra
.759 .808 .892 r
.65355 .48122 .66072 .48809 .67547 .4798 .66835 .4724 Mtetra
.737 .792 .897 r
.66835 .4724 .67547 .4798 .69031 .47237 .68323 .46457 Mtetra
.718 .778 .9 r
.68323 .46457 .69031 .47237 .70525 .46568 .69822 .45757 Mtetra
.703 .768 .902 r
.69822 .45757 .70525 .46568 .72028 .45955 .7133 .45122 Mtetra
.691 .759 .904 r
.7133 .45122 .72028 .45955 .73541 .45387 .72848 .44535 Mtetra
.682 .753 .905 r
.72848 .44535 .73541 .45387 .75063 .44849 .74376 .43984 Mtetra
.675 .749 .906 r
.74376 .43984 .75063 .44849 .76595 .44332 .75913 .43458 Mtetra
.671 .746 .907 r
.75913 .43458 .76595 .44332 .78135 .43829 .77459 .42946 Mtetra
.668 .744 .907 r
.77459 .42946 .78135 .43829 .79685 .43334 .79014 .42444 Mtetra
.666 .743 .908 r
.79014 .42444 .79685 .43334 .81243 .42842 .80579 .41947 Mtetra
.665 .742 .908 r
.80579 .41947 .81243 .42842 .8281 .42352 .82152 .41451 Mtetra
.664 .742 .908 r
.82152 .41451 .8281 .42352 .84386 .41862 .83734 .40956 Mtetra
.83734 .40956 .84386 .41862 .85971 .41371 .85325 .40459 Mtetra
.664 .741 .908 r
.85325 .40459 .85971 .41371 .87564 .40877 .86924 .39961 Mtetra
.86924 .39961 .87564 .40877 .89166 .40382 .88532 .3946 Mtetra
.88532 .3946 .89166 .40382 .90777 .39883 .9015 .38957 Mtetra
.9015 .38957 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.026 .516 .876 r
.34739 .57762 .35587 .58255 .36901 .58566 .36053 .58156 Mtetra
0 .377 .735 r
.36053 .58156 .36901 .58566 .38224 .58985 .37374 .58671 Mtetra
.356 0 0 r
.37374 .58671 .38224 .58985 .39556 .59488 .38706 .59281 Mtetra
.462 0 0 r
.38706 .59281 .39556 .59488 .40902 .60035 .40052 .59942 Mtetra
.507 0 0 r
.40052 .59942 .40902 .60035 .42262 .60574 .41413 .60596 Mtetra
.502 0 0 r
.41413 .60596 .42262 .60574 .43639 .61043 .42793 .61171 Mtetra
.451 0 0 r
.42793 .61171 .43639 .61043 .45034 .61377 .44192 .61596 Mtetra
.347 0 0 r
.44192 .61596 .45034 .61377 .46445 .61514 .45609 .618 Mtetra
.173 0 0 r
.45609 .618 .46445 .61514 .47872 .61405 .47044 .61728 Mtetra
0 0 0 r
.47044 .61728 .47872 .61405 .49312 .61021 .48493 .61348 Mtetra
.366 .819 .706 r
.48493 .61348 .49312 .61021 .50761 .60359 .49952 .60653 Mtetra
.608 .95 .802 r
.49952 .60653 .50761 .60359 .52216 .59437 .51418 .59668 Mtetra
.76 .996 .841 r
.51418 .59668 .52216 .59437 .53673 .58298 .52887 .58439 Mtetra
.838 .993 .85 r
.52887 .58439 .53673 .58298 .55131 .56999 .54355 .5703 Mtetra
.872 .973 .85 r
.54355 .5703 .55131 .56999 .56588 .55605 .55822 .55516 Mtetra
.881 .947 .85 r
.55822 .55516 .56588 .55605 .58044 .5418 .57287 .53969 Mtetra
.876 .921 .853 r
.57287 .53969 .58044 .5418 .595 .52782 .58751 .52451 Mtetra
.862 .896 .858 r
.58751 .52451 .595 .52782 .60957 .51454 .60215 .51013 Mtetra
.842 .873 .865 r
.60215 .51013 .60957 .51454 .62418 .50227 .61682 .49689 Mtetra
.818 .851 .873 r
.61682 .49689 .62418 .50227 .63883 .49115 .63152 .48495 Mtetra
.793 .83 .881 r
.63152 .48495 .63883 .49115 .65355 .48122 .6463 .47433 Mtetra
.768 .812 .888 r
.6463 .47433 .65355 .48122 .66835 .4724 .66114 .46498 Mtetra
.744 .795 .893 r
.66114 .46498 .66835 .4724 .68323 .46457 .67608 .45673 Mtetra
.724 .781 .898 r
.67608 .45673 .68323 .46457 .69822 .45757 .69112 .4494 Mtetra
.707 .769 .901 r
.69112 .4494 .69822 .45757 .7133 .45122 .70625 .44281 Mtetra
.694 .761 .903 r
.70625 .44281 .7133 .45122 .72848 .44535 .72148 .43676 Mtetra
.684 .754 .905 r
.72148 .43676 .72848 .44535 .74376 .43984 .73681 .43112 Mtetra
.676 .749 .906 r
.73681 .43112 .74376 .43984 .75913 .43458 .75224 .42575 Mtetra
.672 .746 .907 r
.75224 .42575 .75913 .43458 .77459 .42946 .76776 .42055 Mtetra
.668 .744 .907 r
.76776 .42055 .77459 .42946 .79014 .42444 .78337 .41546 Mtetra
.666 .743 .907 r
.78337 .41546 .79014 .42444 .80579 .41947 .79907 .41042 Mtetra
.665 .742 .908 r
.79907 .41042 .80579 .41947 .82152 .41451 .81487 .40541 Mtetra
.664 .742 .908 r
.81487 .40541 .82152 .41451 .83734 .40956 .83075 .40041 Mtetra
.83075 .40041 .83734 .40956 .85325 .40459 .84672 .39539 Mtetra
.664 .741 .908 r
.84672 .39539 .85325 .40459 .86924 .39961 .86278 .39035 Mtetra
.86278 .39035 .86924 .39961 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38957 .89516 .3802 Mtetra
.89516 .3802 .9015 .38957 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
0 .444 .819 r
.33881 .5727 .34739 .57762 .36053 .58156 .35194 .57749 Mtetra
0 .283 .647 r
.35194 .57749 .36053 .58156 .37374 .58671 .36514 .58365 Mtetra
.453 0 0 r
.36514 .58365 .37374 .58671 .38706 .59281 .37844 .59086 Mtetra
.541 0 0 r
.37844 .59086 .38706 .59281 .40052 .59942 .39189 .59865 Mtetra
.573 0 0 r
.39189 .59865 .40052 .59942 .41413 .60596 .40551 .60637 Mtetra
.561 0 0 r
.40551 .60637 .41413 .60596 .42793 .61171 .41933 .61324 Mtetra
.507 0 0 r
.41933 .61324 .42793 .61171 .44192 .61596 .43335 .61843 Mtetra
.401 0 0 r
.43335 .61843 .44192 .61596 .45609 .618 .44759 .62117 Mtetra
.222 0 0 r
.44759 .62117 .45609 .618 .47044 .61728 .46201 .62084 Mtetra
0 0 0 r
.46201 .62084 .47044 .61728 .48493 .61348 .4766 .61707 Mtetra
.363 .814 .688 r
.4766 .61707 .48493 .61348 .49952 .60653 .4913 .60981 Mtetra
.624 .954 .791 r
.4913 .60981 .49952 .60653 .51418 .59668 .50607 .59929 Mtetra
.78 .998 .829 r
.50607 .59929 .51418 .59668 .52887 .58439 .52088 .58606 Mtetra
.856 .992 .835 r
.52088 .58606 .52887 .58439 .54355 .5703 .53568 .57084 Mtetra
.887 .97 .834 r
.53568 .57084 .54355 .5703 .55822 .55516 .55045 .55445 Mtetra
.894 .944 .835 r
.55045 .55445 .55822 .55516 .57287 .53969 .5652 .5377 Mtetra
.888 .919 .838 r
.5652 .5377 .57287 .53969 .58751 .52451 .57992 .52129 Mtetra
.874 .895 .845 r
.57992 .52129 .58751 .52451 .60215 .51013 .59464 .50578 Mtetra
.853 .873 .854 r
.59464 .50578 .60215 .51013 .61682 .49689 .60937 .49153 Mtetra
.829 .852 .864 r
.60937 .49153 .61682 .49689 .63152 .48495 .62414 .47873 Mtetra
.803 .832 .874 r
.62414 .47873 .63152 .48495 .6463 .47433 .63897 .46742 Mtetra
.777 .814 .882 r
.63897 .46742 .6463 .47433 .66114 .46498 .65387 .4575 Mtetra
.752 .797 .889 r
.65387 .4575 .66114 .46498 .67608 .45673 .66886 .44882 Mtetra
.73 .783 .895 r
.66886 .44882 .67608 .45673 .69112 .4494 .68394 .44116 Mtetra
.711 .771 .899 r
.68394 .44116 .69112 .4494 .70625 .44281 .69913 .43432 Mtetra
.697 .762 .902 r
.69913 .43432 .70625 .44281 .72148 .43676 .71441 .42809 Mtetra
.686 .755 .904 r
.71441 .42809 .72148 .43676 .73681 .43112 .7298 .42231 Mtetra
.678 .75 .905 r
.7298 .42231 .73681 .43112 .75224 .42575 .74528 .41683 Mtetra
.672 .747 .906 r
.74528 .41683 .75224 .42575 .76776 .42055 .76086 .41155 Mtetra
.669 .745 .907 r
.76086 .41155 .76776 .42055 .78337 .41546 .77653 .40639 Mtetra
.667 .743 .907 r
.77653 .40639 .78337 .41546 .79907 .41042 .79229 .40129 Mtetra
.665 .742 .908 r
.79229 .40129 .79907 .41042 .81487 .40541 .80815 .39622 Mtetra
.80815 .39622 .81487 .40541 .83075 .40041 .82409 .39116 Mtetra
.664 .742 .908 r
.82409 .39116 .83075 .40041 .84672 .39539 .84012 .38609 Mtetra
.664 .741 .908 r
.84012 .38609 .84672 .39539 .86278 .39035 .85625 .381 Mtetra
.85625 .381 .86278 .39035 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37075 Mtetra
.88876 .37075 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
0 .368 .755 r
.33014 .56775 .33881 .5727 .35194 .57749 .34325 .57342 Mtetra
.388 0 0 r
.34325 .57342 .35194 .57749 .36514 .58365 .35642 .58059 Mtetra
.53 0 0 r
.35642 .58059 .36514 .58365 .37844 .59086 .36971 .58894 Mtetra
.602 .031 0 r
.36971 .58894 .37844 .59086 .39189 .59865 .38315 .59794 Mtetra
.623 .065 0 r
.38315 .59794 .39189 .59865 .40551 .60637 .39676 .60687 Mtetra
.606 .055 0 r
.39676 .60687 .40551 .60637 .41933 .61324 .41059 .61488 Mtetra
.551 0 0 r
.41059 .61488 .41933 .61324 .43335 .61843 .42465 .62104 Mtetra
.443 0 0 r
.42465 .62104 .43335 .61843 .44759 .62117 .43894 .6245 Mtetra
.257 0 0 r
.43894 .6245 .44759 .62117 .46201 .62084 .45345 .62458 Mtetra
0 0 0 r
.45345 .62458 .46201 .62084 .4766 .61707 .46813 .62085 Mtetra
.377 .821 .687 r
.46813 .62085 .4766 .61707 .4913 .60981 .48294 .61324 Mtetra
.651 .964 .791 r
.48294 .61324 .4913 .60981 .50607 .59929 .49784 .60205 Mtetra
.804 1 .822 r
.49784 .60205 .50607 .59929 .52088 .58606 .51276 .58786 Mtetra
.874 .988 .823 r
.51276 .58786 .52088 .58606 .53568 .57084 .52768 .57147 Mtetra
.901 .964 .82 r
.52768 .57147 .53568 .57084 .55045 .55445 .54257 .55381 Mtetra
.906 .938 .82 r
.54257 .55381 .55045 .55445 .5652 .5377 .55742 .53575 Mtetra
.899 .914 .824 r
.55742 .53575 .5652 .5377 .57992 .52129 .57224 .51808 Mtetra
.884 .892 .832 r
.57224 .51808 .57992 .52129 .59464 .50578 .58704 .50141 Mtetra
.863 .872 .843 r
.58704 .50141 .59464 .50578 .60937 .49153 .60184 .48614 Mtetra
.839 .852 .855 r
.60184 .48614 .60937 .49153 .62414 .47873 .61667 .47247 Mtetra
.812 .833 .866 r
.61667 .47247 .62414 .47873 .63897 .46742 .63156 .46045 Mtetra
.785 .815 .877 r
.63156 .46045 .63897 .46742 .65387 .4575 .64651 .44996 Mtetra
.759 .799 .885 r
.64651 .44996 .65387 .4575 .66886 .44882 .66156 .44084 Mtetra
.735 .784 .892 r
.66156 .44084 .66886 .44882 .68394 .44116 .67669 .43285 Mtetra
.715 .772 .897 r
.67669 .43285 .68394 .44116 .69913 .43432 .69193 .42575 Mtetra
.7 .763 .901 r
.69193 .42575 .69913 .43432 .71441 .42809 .70727 .41934 Mtetra
.688 .756 .903 r
.70727 .41934 .71441 .42809 .7298 .42231 .72271 .41341 Mtetra
.679 .751 .905 r
.72271 .41341 .7298 .42231 .74528 .41683 .73825 .40783 Mtetra
.673 .747 .906 r
.73825 .40783 .74528 .41683 .76086 .41155 .75389 .40246 Mtetra
.669 .745 .907 r
.75389 .40246 .76086 .41155 .77653 .40639 .76962 .39722 Mtetra
.667 .743 .907 r
.76962 .39722 .77653 .40639 .79229 .40129 .78544 .39206 Mtetra
.665 .742 .908 r
.78544 .39206 .79229 .40129 .80815 .39622 .80136 .38693 Mtetra
.80136 .38693 .80815 .39622 .82409 .39116 .81737 .38182 Mtetra
.664 .742 .908 r
.81737 .38182 .82409 .39116 .84012 .38609 .83346 .37669 Mtetra
.664 .741 .908 r
.83346 .37669 .84012 .38609 .85625 .381 .84965 .37155 Mtetra
.84965 .37155 .85625 .381 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37075 .8823 .36119 Mtetra
.8823 .36119 .88876 .37075 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
0 .294 .69 r
.32137 .56272 .33014 .56775 .34325 .57342 .33445 .56926 Mtetra
.466 0 0 r
.33445 .56926 .34325 .57342 .35642 .58059 .34761 .57745 Mtetra
.59 .016 0 r
.34761 .57745 .35642 .58059 .36971 .58894 .36087 .58694 Mtetra
.648 .091 0 r
.36087 .58694 .36971 .58894 .38315 .59794 .37428 .59715 Mtetra
.663 .118 0 r
.37428 .59715 .38315 .59794 .39676 .60687 .38789 .60731 Mtetra
.643 .102 0 r
.38789 .60731 .39676 .60687 .41059 .61488 .40172 .61647 Mtetra
.586 .041 0 r
.40172 .61647 .41059 .61488 .42465 .62104 .41581 .62361 Mtetra
.477 0 0 r
.41581 .62361 .42465 .62104 .43894 .6245 .43016 .62781 Mtetra
.281 0 0 r
.43016 .62781 .43894 .6245 .45345 .62458 .44474 .62829 Mtetra
0 0 0 r
.44474 .62829 .45345 .62458 .46813 .62085 .45952 .6246 Mtetra
.407 .841 .705 r
.45952 .6246 .46813 .62085 .48294 .61324 .47444 .61666 Mtetra
.687 .976 .8 r
.47444 .61666 .48294 .61324 .49784 .60205 .48946 .60478 Mtetra
.83 1 .819 r
.48946 .60478 .49784 .60205 .51276 .58786 .50452 .58962 Mtetra
.89 .981 .814 r
.50452 .58962 .51276 .58786 .52768 .57147 .51957 .57206 Mtetra
.912 .955 .807 r
.51957 .57206 .52768 .57147 .54257 .55381 .53458 .5531 Mtetra
.915 .929 .806 r
.53458 .5531 .54257 .55381 .55742 .53575 .54954 .53373 Mtetra
.907 .907 .81 r
.54954 .53373 .55742 .53575 .57224 .51808 .56445 .51479 Mtetra
.892 .887 .819 r
.56445 .51479 .57224 .51808 .58704 .50141 .57934 .49696 Mtetra
.872 .868 .831 r
.57934 .49696 .58704 .50141 .60184 .48614 .59422 .48066 Mtetra
.848 .85 .845 r
.59422 .48066 .60184 .48614 .61667 .47247 .60912 .46613 Mtetra
.82 .833 .858 r
.60912 .46613 .61667 .47247 .63156 .46045 .62406 .45339 Mtetra
.792 .816 .871 r
.62406 .45339 .63156 .46045 .64651 .44996 .63908 .44234 Mtetra
.765 .8 .881 r
.63908 .44234 .64651 .44996 .66156 .44084 .65418 .43277 Mtetra
.741 .785 .889 r
.65418 .43277 .66156 .44084 .67669 .43285 .66937 .42444 Mtetra
.72 .773 .895 r
.66937 .42444 .67669 .43285 .69193 .42575 .68466 .4171 Mtetra
.703 .764 .899 r
.68466 .4171 .69193 .42575 .70727 .41934 .70006 .41049 Mtetra
.69 .756 .902 r
.70006 .41049 .70727 .41934 .72271 .41341 .71556 .40443 Mtetra
.681 .751 .904 r
.71556 .40443 .72271 .41341 .73825 .40783 .73115 .39873 Mtetra
.674 .747 .906 r
.73115 .39873 .73825 .40783 .75389 .40246 .74685 .39327 Mtetra
.67 .745 .907 r
.74685 .39327 .75389 .40246 .76962 .39722 .76264 .38796 Mtetra
.667 .743 .907 r
.76264 .38796 .76962 .39722 .78544 .39206 .77852 .38274 Mtetra
.666 .742 .907 r
.77852 .38274 .78544 .39206 .80136 .38693 .7945 .37755 Mtetra
.665 .742 .908 r
.7945 .37755 .80136 .38693 .81737 .38182 .81057 .37238 Mtetra
.664 .742 .908 r
.81057 .37238 .81737 .38182 .83346 .37669 .82673 .3672 Mtetra
.664 .741 .908 r
.82673 .3672 .83346 .37669 .84965 .37155 .84298 .362 Mtetra
.84298 .362 .84965 .37155 .86593 .36638 .85933 .35678 Mtetra
.85933 .35678 .86593 .36638 .8823 .36119 .87576 .35153 Mtetra
.87576 .35153 .8823 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
0 .225 .628 r
.31251 .55756 .32137 .56272 .33445 .56926 .32556 .56495 Mtetra
.527 0 0 r
.32556 .56495 .33445 .56926 .34761 .57745 .33868 .57414 Mtetra
.636 .074 0 r
.33868 .57414 .34761 .57745 .36087 .58694 .35191 .58476 Mtetra
.684 .14 0 r
.35191 .58476 .36087 .58694 .37428 .59715 .3653 .59617 Mtetra
.693 .16 0 r
.3653 .59617 .37428 .59715 .38789 .60731 .37889 .60754 Mtetra
.671 .14 0 r
.37889 .60754 .38789 .60731 .40172 .61647 .39273 .61783 Mtetra
.614 .074 0 r
.39273 .61783 .40172 .61647 .41581 .62361 .40684 .62596 Mtetra
.502 0 0 r
.40684 .62596 .41581 .62361 .43016 .62781 .42123 .63088 Mtetra
.294 0 0 r
.42123 .63088 .43016 .62781 .44474 .62829 .43588 .63177 Mtetra
0 0 0 r
.43588 .63177 .44474 .62829 .45952 .6246 .45076 .62812 Mtetra
.455 .872 .74 r
.45076 .62812 .45952 .6246 .47444 .61666 .46581 .61985 Mtetra
.728 .989 .817 r
.46581 .61985 .47444 .61666 .48946 .60478 .48095 .60729 Mtetra
.855 .996 .819 r
.48095 .60729 .48946 .60478 .50452 .58962 .49614 .59117 Mtetra
.905 .971 .806 r
.49614 .59117 .50452 .58962 .51957 .57206 .51132 .57244 Mtetra
.922 .943 .796 r
.51132 .57244 .51957 .57206 .53458 .5531 .52646 .5522 Mtetra
.922 .919 .794 r
.52646 .5522 .53458 .5531 .54954 .53373 .54154 .53153 Mtetra
.914 .898 .798 r
.54154 .53153 .54954 .53373 .56445 .51479 .55656 .51134 Mtetra
.899 .88 .807 r
.55656 .51134 .56445 .51479 .57934 .49696 .57154 .49235 Mtetra
.879 .863 .82 r
.57154 .49235 .57934 .49696 .59422 .48066 .5865 .47505 Mtetra
.855 .847 .835 r
.5865 .47505 .59422 .48066 .60912 .46613 .60147 .45965 Mtetra
.828 .831 .85 r
.60147 .45965 .60912 .46613 .62406 .45339 .61649 .44621 Mtetra
.799 .815 .864 r
.61649 .44621 .62406 .45339 .63908 .44234 .63156 .4346 Mtetra
.771 .8 .876 r
.63156 .4346 .63908 .44234 .65418 .43277 .64672 .4246 Mtetra
.746 .786 .886 r
.64672 .4246 .65418 .43277 .66937 .42444 .66197 .41594 Mtetra
.723 .774 .893 r
.66197 .41594 .66937 .42444 .68466 .4171 .67732 .40834 Mtetra
.705 .764 .898 r
.67732 .40834 .68466 .4171 .70006 .41049 .69277 .40155 Mtetra
.692 .757 .902 r
.69277 .40155 .70006 .41049 .71556 .40443 .70833 .39534 Mtetra
.682 .751 .904 r
.70833 .39534 .71556 .40443 .73115 .39873 .72398 .38954 Mtetra
.675 .748 .905 r
.72398 .38954 .73115 .39873 .74685 .39327 .73974 .38399 Mtetra
.67 .745 .906 r
.73974 .38399 .74685 .39327 .76264 .38796 .75559 .37861 Mtetra
.668 .744 .907 r
.75559 .37861 .76264 .38796 .77852 .38274 .77153 .37332 Mtetra
.666 .743 .907 r
.77153 .37332 .77852 .38274 .7945 .37755 .78757 .36807 Mtetra
.665 .742 .908 r
.78757 .36807 .7945 .37755 .81057 .37238 .80371 .36284 Mtetra
.664 .742 .908 r
.80371 .36284 .81057 .37238 .82673 .3672 .81993 .35761 Mtetra
.664 .741 .908 r
.81993 .35761 .82673 .3672 .84298 .362 .83625 .35235 Mtetra
.83625 .35235 .84298 .362 .85933 .35678 .85266 .34708 Mtetra
.85266 .34708 .85933 .35678 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.399 0 0 r
.30355 .55222 .31251 .55756 .32556 .56495 .31658 .56043 Mtetra
.575 .007 0 r
.31658 .56043 .32556 .56495 .33868 .57414 .32966 .57059 Mtetra
.671 .12 0 r
.32966 .57059 .33868 .57414 .35191 .58476 .34285 .58228 Mtetra
.712 .178 0 r
.34285 .58228 .35191 .58476 .3653 .59617 .3562 .59486 Mtetra
.718 .194 0 r
.3562 .59486 .3653 .59617 .37889 .60754 .36977 .6074 Mtetra
.695 .17 0 r
.36977 .6074 .37889 .60754 .39273 .61783 .38361 .6188 Mtetra
.637 .1 0 r
.38361 .6188 .39273 .61783 .40684 .62596 .39774 .62787 Mtetra
.521 0 0 r
.39774 .62787 .40684 .62596 .42123 .63088 .41217 .6335 Mtetra
.295 0 0 r
.41217 .6335 .42123 .63088 .43588 .63177 .4269 .63478 Mtetra
0 0 0 r
.4269 .63478 .43588 .63177 .45076 .62812 .44187 .63117 Mtetra
.516 .91 .788 r
.44187 .63117 .45076 .62812 .46581 .61985 .45703 .62258 Mtetra
.771 .997 .836 r
.45703 .62258 .46581 .61985 .48095 .60729 .47231 .60936 Mtetra
.877 .987 .82 r
.47231 .60936 .48095 .60729 .49614 .59117 .48764 .5923 Mtetra
.917 .957 .799 r
.48764 .5923 .49614 .59117 .51132 .57244 .50296 .57244 Mtetra
.928 .929 .786 r
.50296 .57244 .51132 .57244 .52646 .5522 .51823 .55096 Mtetra
.927 .906 .782 r
.51823 .55096 .52646 .5522 .54154 .53153 .53343 .52902 Mtetra
.918 .887 .786 r
.53343 .52902 .54154 .53153 .55656 .51134 .54856 .50761 Mtetra
.903 .871 .796 r
.54856 .50761 .55656 .51134 .57154 .49235 .56364 .48751 Mtetra
.884 .856 .81 r
.56364 .48751 .57154 .49235 .5865 .47505 .57869 .46923 Mtetra
.86 .842 .826 r
.57869 .46923 .5865 .47505 .60147 .45965 .59374 .453 Mtetra
.834 .828 .842 r
.59374 .453 .60147 .45965 .61649 .44621 .60882 .43888 Mtetra
.805 .814 .858 r
.60882 .43888 .61649 .44621 .63156 .4346 .62396 .42672 Mtetra
.777 .8 .872 r
.62396 .42672 .63156 .4346 .64672 .4246 .63918 .4163 Mtetra
.75 .786 .882 r
.63918 .4163 .64672 .4246 .66197 .41594 .65449 .40732 Mtetra
.727 .775 .891 r
.65449 .40732 .66197 .41594 .67732 .40834 .6699 .39948 Mtetra
.708 .765 .896 r
.6699 .39948 .67732 .40834 .69277 .40155 .68541 .3925 Mtetra
.694 .757 .901 r
.68541 .3925 .69277 .40155 .70833 .39534 .70102 .38616 Mtetra
.683 .752 .903 r
.70102 .38616 .70833 .39534 .72398 .38954 .71674 .38024 Mtetra
.676 .748 .905 r
.71674 .38024 .72398 .38954 .73974 .38399 .73255 .37461 Mtetra
.671 .745 .906 r
.73255 .37461 .73974 .38399 .75559 .37861 .74846 .36916 Mtetra
.668 .744 .907 r
.74846 .36916 .75559 .37861 .77153 .37332 .76447 .3638 Mtetra
.666 .743 .907 r
.76447 .3638 .77153 .37332 .78757 .36807 .78057 .3585 Mtetra
.665 .742 .908 r
.78057 .3585 .78757 .36807 .80371 .36284 .79677 .35321 Mtetra
.664 .742 .908 r
.79677 .35321 .80371 .36284 .81993 .35761 .81306 .34791 Mtetra
.664 .741 .908 r
.81306 .34791 .81993 .35761 .83625 .35235 .82944 .34261 Mtetra
.82944 .34261 .83625 .35235 .85266 .34708 .84592 .33728 Mtetra
.84592 .33728 .85266 .34708 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.448 0 0 r
.29451 .54663 .30355 .55222 .31658 .56043 .3075 .55561 Mtetra
.611 .051 0 r
.3075 .55561 .31658 .56043 .32966 .57059 .32054 .56668 Mtetra
.697 .155 0 r
.32054 .56668 .32966 .57059 .34285 .58228 .33369 .5794 Mtetra
.733 .208 0 r
.33369 .5794 .34285 .58228 .3562 .59486 .34701 .59307 Mtetra
.737 .22 0 r
.34701 .59307 .3562 .59486 .36977 .6074 .36055 .60671 Mtetra
.714 .192 0 r
.36055 .60671 .36977 .6074 .38361 .6188 .37438 .61916 Mtetra
.655 .117 0 r
.37438 .61916 .38361 .6188 .39774 .62787 .38852 .62913 Mtetra
.532 0 0 r
.38852 .62913 .39774 .62787 .41217 .6335 .40299 .63543 Mtetra
.283 0 0 r
.40299 .63543 .41217 .6335 .4269 .63478 .41779 .63709 Mtetra
0 0 0 r
.41779 .63709 .4269 .63478 .44187 .63117 .43285 .63352 Mtetra
.585 .945 .842 r
.43285 .63352 .44187 .63117 .45703 .62258 .44813 .62461 Mtetra
.81 .997 .853 r
.44813 .62461 .45703 .62258 .47231 .60936 .46354 .61076 Mtetra
.894 .973 .821 r
.46354 .61076 .47231 .60936 .48764 .5923 .47901 .59281 Mtetra
.924 .94 .793 r
.47901 .59281 .48764 .5923 .50296 .57244 .49447 .57187 Mtetra
.932 .913 .777 r
.49447 .57187 .50296 .57244 .51823 .55096 .50988 .54921 Mtetra
.929 .891 .772 r
.50988 .54921 .51823 .55096 .53343 .52902 .52521 .52607 Mtetra
.92 .875 .776 r
.52521 .52607 .53343 .52902 .54856 .50761 .54045 .50351 Mtetra
.906 .861 .786 r
.54045 .50351 .54856 .50761 .56364 .48751 .55564 .48235 Mtetra
.887 .849 .8 r
.55564 .48235 .56364 .48751 .57869 .46923 .57078 .46314 Mtetra
.864 .837 .817 r
.57078 .46314 .57869 .46923 .59374 .453 .58591 .44613 Mtetra
.838 .825 .835 r
.58591 .44613 .59374 .453 .60882 .43888 .60107 .43136 Mtetra
.81 .812 .852 r
.60107 .43136 .60882 .43888 .62396 .42672 .61628 .41869 Mtetra
.781 .799 .867 r
.61628 .41869 .62396 .42672 .63918 .4163 .63156 .40786 Mtetra
.754 .786 .879 r
.63156 .40786 .63918 .4163 .65449 .40732 .64693 .39857 Mtetra
.73 .775 .888 r
.64693 .39857 .65449 .40732 .6699 .39948 .6624 .3905 Mtetra
.711 .765 .895 r
.6624 .3905 .6699 .39948 .68541 .3925 .67797 .38335 Mtetra
.695 .757 .9 r
.67797 .38335 .68541 .3925 .70102 .38616 .69364 .37687 Mtetra
.684 .752 .903 r
.69364 .37687 .70102 .38616 .71674 .38024 .70941 .37085 Mtetra
.677 .748 .905 r
.70941 .37085 .71674 .38024 .73255 .37461 .72529 .36514 Mtetra
.671 .745 .906 r
.72529 .36514 .73255 .37461 .74846 .36916 .74126 .35961 Mtetra
.668 .744 .907 r
.74126 .35961 .74846 .36916 .76447 .3638 .75733 .35419 Mtetra
.666 .743 .907 r
.75733 .35419 .76447 .3638 .78057 .3585 .7735 .34882 Mtetra
.665 .742 .908 r
.7735 .34882 .78057 .3585 .79677 .35321 .78976 .34347 Mtetra
.664 .742 .908 r
.78976 .34347 .79677 .35321 .81306 .34791 .80612 .33812 Mtetra
.664 .741 .908 r
.80612 .33812 .81306 .34791 .82944 .34261 .82256 .33276 Mtetra
.82256 .33276 .82944 .34261 .84592 .33728 .83911 .32737 Mtetra
.83911 .32737 .84592 .33728 .86249 .33192 .85575 .32196 Mtetra
.85575 .32196 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.484 0 0 r
.28539 .54074 .29451 .54663 .3075 .55561 .29834 .55043 Mtetra
.637 .085 0 r
.29834 .55043 .3075 .55561 .32054 .56668 .31134 .56232 Mtetra
.716 .183 0 r
.31134 .56232 .32054 .56668 .33369 .5794 .32445 .57597 Mtetra
.749 .231 0 r
.32445 .57597 .33369 .5794 .34701 .59307 .33772 .59065 Mtetra
.752 .239 0 r
.33772 .59065 .34701 .59307 .36055 .60671 .35123 .60531 Mtetra
.728 .208 0 r
.35123 .60531 .36055 .60671 .37438 .61916 .36504 .61872 Mtetra
.667 .127 0 r
.36504 .61872 .37438 .61916 .38852 .62913 .37919 .62952 Mtetra
.536 0 0 r
.37919 .62952 .38852 .62913 .40299 .63543 .3937 .63645 Mtetra
.255 0 0 r
.3937 .63645 .40299 .63543 .41779 .63709 .40855 .63845 Mtetra
.231 .749 .768 r
.40855 .63845 .41779 .63709 .43285 .63352 .42371 .63491 Mtetra
.654 .969 .892 r
.42371 .63491 .43285 .63352 .44813 .62461 .4391 .62571 Mtetra
.84 .987 .865 r
.4391 .62571 .44813 .62461 .46354 .61076 .45464 .61128 Mtetra
.905 .953 .819 r
.45464 .61128 .46354 .61076 .47901 .59281 .47025 .59249 Mtetra
.927 .92 .787 r
.47025 .59249 .47901 .59281 .49447 .57187 .48586 .57055 Mtetra
.932 .895 .77 r
.48586 .57055 .49447 .57187 .50988 .54921 .50141 .5468 Mtetra
.928 .876 .764 r
.50141 .5468 .50988 .54921 .52521 .52607 .51687 .52255 Mtetra
.92 .861 .767 r
.51687 .52255 .52521 .52607 .54045 .50351 .53224 .49892 Mtetra
.906 .85 .776 r
.53224 .49892 .54045 .50351 .55564 .48235 .54753 .47679 Mtetra
.889 .84 .791 r
.54753 .47679 .55564 .48235 .57078 .46314 .56277 .45672 Mtetra
.867 .83 .809 r
.56277 .45672 .57078 .46314 .58591 .44613 .57799 .43898 Mtetra
.842 .82 .828 r
.57799 .43898 .58591 .44613 .60107 .43136 .59323 .42361 Mtetra
.814 .809 .846 r
.59323 .42361 .60107 .43136 .61628 .41869 .60851 .41046 Mtetra
.785 .797 .862 r
.60851 .41046 .61628 .41869 .63156 .40786 .62386 .39926 Mtetra
.758 .785 .876 r
.62386 .39926 .63156 .40786 .64693 .39857 .63929 .38969 Mtetra
.733 .774 .886 r
.63929 .38969 .64693 .39857 .6624 .3905 .65482 .3814 Mtetra
.713 .765 .893 r
.65482 .3814 .6624 .3905 .67797 .38335 .67045 .37408 Mtetra
.697 .757 .899 r
.67045 .37408 .67797 .38335 .69364 .37687 .68618 .36748 Mtetra
.685 .752 .902 r
.68618 .36748 .69364 .37687 .70941 .37085 .70202 .36135 Mtetra
.677 .748 .904 r
.70202 .36135 .70941 .37085 .72529 .36514 .71795 .35555 Mtetra
.672 .745 .906 r
.71795 .35555 .72529 .36514 .74126 .35961 .73399 .34995 Mtetra
.668 .744 .907 r
.73399 .34995 .74126 .35961 .75733 .35419 .75012 .34447 Mtetra
.666 .743 .907 r
.75012 .34447 .75733 .35419 .7735 .34882 .76635 .33904 Mtetra
.665 .742 .908 r
.76635 .33904 .7735 .34882 .78976 .34347 .78268 .33363 Mtetra
.664 .742 .908 r
.78268 .33363 .78976 .34347 .80612 .33812 .7991 .32823 Mtetra
.664 .741 .908 r
.7991 .32823 .80612 .33812 .82256 .33276 .81561 .3228 Mtetra
.81561 .3228 .82256 .33276 .83911 .32737 .83223 .31736 Mtetra
.83223 .31736 .83911 .32737 .85575 .32196 .84893 .31189 Mtetra
.84893 .31189 .85575 .32196 .87248 .31651 .86574 .30639 Mtetra
.86574 .30639 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.509 0 0 r
.27618 .5345 .28539 .54074 .29834 .55043 .2891 .5448 Mtetra
.654 .109 0 r
.2891 .5448 .29834 .55043 .31134 .56232 .30206 .55742 Mtetra
.729 .202 0 r
.30206 .55742 .31134 .56232 .32445 .57597 .31512 .5719 Mtetra
.761 .246 0 r
.31512 .5719 .32445 .57597 .33772 .59065 .32835 .58746 Mtetra
.763 .252 0 r
.32835 .58746 .33772 .59065 .35123 .60531 .34183 .60303 Mtetra
.738 .218 0 r
.34183 .60303 .35123 .60531 .36504 .61872 .35562 .61729 Mtetra
.674 .13 0 r
.35562 .61729 .36504 .61872 .37919 .62952 .36977 .62883 Mtetra
.53 0 0 r
.36977 .62883 .37919 .62952 .3937 .63645 .38431 .63631 Mtetra
.205 0 0 r
.38431 .63631 .3937 .63645 .40855 .63845 .39922 .63862 Mtetra
.326 .81 .867 r
.39922 .63862 .40855 .63845 .42371 .63491 .41446 .6351 Mtetra
.711 .973 .926 r
.41446 .6351 .42371 .63491 .4391 .62571 .42996 .62564 Mtetra
.858 .965 .869 r
.42996 .62564 .4391 .62571 .45464 .61128 .44564 .61068 Mtetra
.909 .929 .815 r
.44564 .61068 .45464 .61128 .47025 .59249 .46139 .59115 Mtetra
.926 .898 .781 r
.46139 .59115 .47025 .59249 .48586 .57055 .47714 .56831 Mtetra
.929 .876 .762 r
.47714 .56831 .48586 .57055 .50141 .5468 .49283 .54358 Mtetra
.926 .859 .756 r
.49283 .54358 .50141 .5468 .51687 .52255 .50843 .51833 Mtetra
.918 .848 .759 r
.50843 .51833 .51687 .52255 .53224 .49892 .52392 .49375 Mtetra
.905 .838 .768 r
.52392 .49375 .53224 .49892 .54753 .47679 .53933 .47075 Mtetra
.889 .831 .783 r
.53933 .47075 .54753 .47679 .56277 .45672 .55467 .4499 Mtetra
.868 .823 .801 r
.55467 .4499 .56277 .45672 .57799 .43898 .56998 .43151 Mtetra
.844 .814 .821 r
.56998 .43151 .57799 .43898 .59323 .42361 .5853 .41561 Mtetra
.816 .805 .84 r
.5853 .41561 .59323 .42361 .60851 .41046 .60065 .40203 Mtetra
.788 .795 .858 r
.60065 .40203 .60851 .41046 .62386 .39926 .61607 .39049 Mtetra
.76 .784 .872 r
.61607 .39049 .62386 .39926 .63929 .38969 .63156 .38065 Mtetra
.735 .774 .884 r
.63156 .38065 .63929 .38969 .65482 .3814 .64716 .37217 Mtetra
.715 .765 .892 r
.64716 .37217 .65482 .3814 .67045 .37408 .66285 .3647 Mtetra
.698 .757 .898 r
.66285 .3647 .67045 .37408 .68618 .36748 .67864 .35797 Mtetra
.686 .752 .901 r
.67864 .35797 .68618 .36748 .70202 .36135 .69454 .35175 Mtetra
.678 .748 .904 r
.69454 .35175 .70202 .36135 .71795 .35555 .71054 .34587 Mtetra
.672 .745 .906 r
.71054 .34587 .71795 .35555 .73399 .34995 .72664 .3402 Mtetra
.669 .744 .907 r
.72664 .3402 .73399 .34995 .75012 .34447 .74284 .33465 Mtetra
.666 .743 .907 r
.74284 .33465 .75012 .34447 .76635 .33904 .75913 .32916 Mtetra
.665 .742 .907 r
.75913 .32916 .76635 .33904 .78268 .33363 .77552 .32369 Mtetra
.664 .742 .908 r
.77552 .32369 .78268 .33363 .7991 .32823 .79201 .31822 Mtetra
.79201 .31822 .7991 .32823 .81561 .3228 .80859 .31274 Mtetra
.664 .741 .908 r
.80859 .31274 .81561 .3228 .83223 .31736 .82527 .30724 Mtetra
.82527 .30724 .83223 .31736 .84893 .31189 .84205 .30171 Mtetra
.84205 .30171 .84893 .31189 .86574 .30639 .85892 .29615 Mtetra
.85892 .29615 .86574 .30639 .88264 .30085 .87589 .29056 Mtetra
.523 0 0 r
.2669 .52785 .27618 .5345 .2891 .5448 .27978 .53867 Mtetra
.663 .124 0 r
.27978 .53867 .2891 .5448 .30206 .55742 .2927 .5519 Mtetra
.736 .214 0 r
.2927 .5519 .30206 .55742 .31512 .5719 .30572 .56708 Mtetra
.767 .256 0 r
.30572 .56708 .31512 .5719 .32835 .58746 .31891 .58339 Mtetra
.769 .259 0 r
.31891 .58339 .32835 .58746 .34183 .60303 .33235 .59971 Mtetra
.743 .221 0 r
.33235 .59971 .34183 .60303 .35562 .61729 .34612 .6147 Mtetra
.673 .124 0 r
.34612 .6147 .35562 .61729 .36977 .62883 .36027 .62686 Mtetra
.508 0 0 r
.36027 .62686 .36977 .62883 .38431 .63631 .37483 .6348 Mtetra
.129 0 0 r
.37483 .6348 .38431 .63631 .39922 .63862 .3898 .63737 Mtetra
.422 .85 .947 r
.3898 .63737 .39922 .63862 .41446 .6351 .40512 .63387 Mtetra
.749 .955 .941 r
.40512 .63387 .41446 .6351 .42996 .62564 .42073 .62418 Mtetra
.866 .934 .865 r
.42073 .62418 .42996 .62564 .44564 .61068 .43652 .60877 Mtetra
.907 .901 .809 r
.43652 .60877 .44564 .61068 .46139 .59115 .45241 .58859 Mtetra
.921 .875 .774 r
.45241 .58859 .46139 .59115 .47714 .56831 .46831 .56498 Mtetra
.924 .856 .756 r
.46831 .56498 .47714 .56831 .49283 .54358 .48414 .53941 Mtetra
.921 .843 .749 r
.48414 .53941 .49283 .54358 .50843 .51833 .49988 .5133 Mtetra
.914 .833 .752 r
.49988 .5133 .50843 .51833 .52392 .49375 .5155 .4879 Mtetra
.903 .826 .761 r
.5155 .4879 .52392 .49375 .53933 .47075 .53102 .46414 Mtetra
.888 .821 .776 r
.53102 .46414 .53933 .47075 .55467 .4499 .54647 .44264 Mtetra
.868 .815 .795 r
.54647 .44264 .55467 .4499 .56998 .43151 .56187 .42369 Mtetra
.845 .809 .815 r
.56187 .42369 .56998 .43151 .5853 .41561 .57727 .40732 Mtetra
.818 .801 .835 r
.57727 .40732 .5853 .41561 .60065 .40203 .5927 .39336 Mtetra
.79 .792 .854 r
.5927 .39336 .60065 .40203 .61607 .39049 .60819 .38153 Mtetra
.762 .782 .869 r
.60819 .38153 .61607 .39049 .63156 .38065 .62376 .37146 Mtetra
.737 .773 .881 r
.62376 .37146 .63156 .38065 .64716 .37217 .63941 .36279 Mtetra
.716 .764 .89 r
.63941 .36279 .64716 .37217 .66285 .3647 .65517 .35518 Mtetra
.699 .757 .897 r
.65517 .35518 .66285 .3647 .67864 .35797 .67102 .34834 Mtetra
.687 .752 .901 r
.67102 .34834 .67864 .35797 .69454 .35175 .68698 .34203 Mtetra
.678 .748 .904 r
.68698 .34203 .69454 .35175 .71054 .34587 .70305 .33608 Mtetra
.672 .745 .905 r
.70305 .33608 .71054 .34587 .72664 .3402 .71921 .33033 Mtetra
.669 .744 .906 r
.71921 .33033 .72664 .3402 .74284 .33465 .73547 .32472 Mtetra
.666 .743 .907 r
.73547 .32472 .74284 .33465 .75913 .32916 .75183 .31917 Mtetra
.665 .742 .907 r
.75183 .31917 .75913 .32916 .77552 .32369 .76829 .31364 Mtetra
.664 .742 .908 r
.76829 .31364 .77552 .32369 .79201 .31822 .78484 .30812 Mtetra
.78484 .30812 .79201 .31822 .80859 .31274 .80149 .30258 Mtetra
.664 .741 .908 r
.80149 .30258 .80859 .31274 .82527 .30724 .81824 .29701 Mtetra
.81824 .29701 .82527 .30724 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.527 0 0 r
.25754 .52076 .2669 .52785 .27978 .53867 .2704 .53198 Mtetra
.665 .131 0 r
.2704 .53198 .27978 .53867 .2927 .5519 .28328 .54569 Mtetra
.737 .219 0 r
.28328 .54569 .2927 .5519 .30572 .56708 .29626 .5614 Mtetra
.768 .259 0 r
.29626 .5614 .30572 .56708 .31891 .58339 .30941 .5783 Mtetra
.769 .26 0 r
.30941 .5783 .31891 .58339 .33235 .59971 .32281 .59523 Mtetra
.74 .217 0 r
.32281 .59523 .33235 .59971 .34612 .6147 .33656 .61078 Mtetra
.661 .108 0 r
.33656 .61078 .34612 .6147 .36027 .62686 .35071 .62344 Mtetra
.465 0 0 r
.35071 .62344 .36027 .62686 .37483 .6348 .36529 .63174 Mtetra
0 .531 .805 r
.36529 .63174 .37483 .6348 .3898 .63737 .3803 .63451 Mtetra
.503 .858 .991 r
.3803 .63451 .3898 .63737 .40512 .63387 .3957 .63102 Mtetra
.769 .92 .937 r
.3957 .63102 .40512 .63387 .42073 .62418 .4114 .62114 Mtetra
.864 .899 .856 r
.4114 .62114 .42073 .62418 .43652 .60877 .42732 .60535 Mtetra
.9 .871 .801 r
.42732 .60535 .43652 .60877 .45241 .58859 .44334 .58465 Mtetra
.913 .85 .767 r
.44334 .58465 .45241 .58859 .46831 .56498 .45938 .56041 Mtetra
.917 .836 .75 r
.45938 .56041 .46831 .56498 .48414 .53941 .47535 .53415 Mtetra
.915 .826 .743 r
.47535 .53415 .48414 .53941 .49988 .5133 .49122 .50735 Mtetra
.909 .819 .746 r
.49122 .50735 .49988 .5133 .5155 .4879 .50697 .48128 Mtetra
.899 .814 .755 r
.50697 .48128 .5155 .4879 .53102 .46414 .52261 .45691 Mtetra
.885 .811 .77 r
.52261 .45691 .53102 .46414 .54647 .44264 .53817 .43487 Mtetra
.867 .807 .789 r
.53817 .43487 .54647 .44264 .56187 .42369 .55367 .41546 Mtetra
.844 .802 .81 r
.55367 .41546 .56187 .42369 .57727 .40732 .56916 .3987 Mtetra
.819 .796 .831 r
.56916 .3987 .57727 .40732 .5927 .39336 .58467 .38444 Mtetra
.791 .789 .85 r
.58467 .38444 .5927 .39336 .60819 .38153 .60023 .37236 Mtetra
.764 .78 .866 r
.60023 .37236 .60819 .38153 .62376 .37146 .61586 .3621 Mtetra
.738 .771 .879 r
.61586 .3621 .62376 .37146 .63941 .36279 .63158 .35327 Mtetra
.717 .763 .889 r
.63158 .35327 .63941 .36279 .65517 .35518 .6474 .34554 Mtetra
.7 .757 .896 r
.6474 .34554 .65517 .35518 .67102 .34834 .66332 .3386 Mtetra
.687 .752 .9 r
.66332 .3386 .67102 .34834 .68698 .34203 .67935 .33221 Mtetra
.679 .748 .903 r
.67935 .33221 .68698 .34203 .70305 .33608 .69547 .32617 Mtetra
.673 .745 .905 r
.69547 .32617 .70305 .33608 .71921 .33033 .7117 .32036 Mtetra
.669 .744 .906 r
.7117 .32036 .71921 .33033 .73547 .32472 .72803 .31468 Mtetra
.667 .743 .907 r
.72803 .31468 .73547 .32472 .75183 .31917 .74445 .30907 Mtetra
.665 .742 .907 r
.74445 .30907 .75183 .31917 .76829 .31364 .76098 .30348 Mtetra
.664 .742 .908 r
.76098 .30348 .76829 .31364 .78484 .30812 .7776 .2979 Mtetra
.7776 .2979 .78484 .30812 .80149 .30258 .79432 .2923 Mtetra
.664 .741 .908 r
.79432 .2923 .80149 .30258 .81824 .29701 .81113 .28668 Mtetra
.81113 .28668 .81824 .29701 .83509 .29142 .82805 .28103 Mtetra
.82805 .28103 .83509 .29142 .85203 .2858 .84507 .27535 Mtetra
.84507 .27535 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.521 0 0 r
.24812 .51318 .25754 .52076 .2704 .53198 .26096 .52467 Mtetra
.659 .13 0 r
.26096 .52467 .2704 .53198 .28328 .54569 .27381 .53871 Mtetra
.732 .216 0 r
.27381 .53871 .28328 .54569 .29626 .5614 .28675 .5548 Mtetra
.763 .255 0 r
.28675 .5548 .29626 .5614 .30941 .5783 .29986 .57211 Mtetra
.762 .253 0 r
.29986 .57211 .30941 .5783 .32281 .59523 .31323 .58946 Mtetra
.728 .204 0 r
.31323 .58946 .32281 .59523 .33656 .61078 .32696 .60541 Mtetra
.633 .08 0 r
.32696 .60541 .33656 .61078 .35071 .62344 .3411 .61841 Mtetra
.395 0 0 r
.3411 .61841 .35071 .62344 .36529 .63174 .3557 .62697 Mtetra
.087 .582 .898 r
.3557 .62697 .36529 .63174 .3803 .63451 .37075 .62987 Mtetra
.559 .836 .997 r
.37075 .62987 .3803 .63451 .3957 .63102 .38621 .62638 Mtetra
.775 .877 .921 r
.38621 .62638 .3957 .63102 .4114 .62114 .40201 .61635 Mtetra
.856 .861 .844 r
.40201 .61635 .4114 .62114 .42732 .60535 .41804 .60028 Mtetra
.889 .842 .792 r
.41804 .60028 .42732 .60535 .44334 .58465 .43419 .57919 Mtetra
.903 .826 .761 r
.43419 .57919 .44334 .58465 .45938 .56041 .45036 .55448 Mtetra
.908 .816 .744 r
.45036 .55448 .45938 .56041 .47535 .53415 .46647 .52772 Mtetra
.908 .809 .738 r
.46647 .52772 .47535 .53415 .49122 .50735 .48248 .5004 Mtetra
.903 .805 .741 r
.48248 .5004 .49122 .50735 .50697 .48128 .49835 .47383 Mtetra
.894 .802 .75 r
.49835 .47383 .50697 .48128 .52261 .45691 .51411 .44901 Mtetra
.882 .801 .765 r
.51411 .44901 .52261 .45691 .53817 .43487 .52977 .42656 Mtetra
.864 .799 .784 r
.52977 .42656 .53817 .43487 .55367 .41546 .54537 .4068 Mtetra
.843 .796 .805 r
.54537 .4068 .55367 .41546 .56916 .3987 .56095 .38975 Mtetra
.818 .791 .827 r
.56095 .38975 .56916 .3987 .58467 .38444 .57654 .37525 Mtetra
.791 .785 .847 r
.57654 .37525 .58467 .38444 .60023 .37236 .59218 .36297 Mtetra
.764 .778 .864 r
.59218 .36297 .60023 .37236 .61586 .3621 .60788 .35255 Mtetra
.739 .77 .878 r
.60788 .35255 .61586 .3621 .63158 .35327 .62367 .3436 Mtetra
.718 .762 .888 r
.62367 .3436 .63158 .35327 .6474 .34554 .63956 .33576 Mtetra
.701 .756 .895 r
.63956 .33576 .6474 .34554 .66332 .3386 .65554 .32873 Mtetra
.688 .751 .9 r
.65554 .32873 .66332 .3386 .67935 .33221 .67163 .32226 Mtetra
.679 .748 .903 r
.67163 .32226 .67935 .33221 .69547 .32617 .68782 .31616 Mtetra
.673 .745 .905 r
.68782 .31616 .69547 .32617 .7117 .32036 .70411 .31028 Mtetra
.669 .744 .906 r
.70411 .31028 .7117 .32036 .72803 .31468 .72051 .30454 Mtetra
.667 .743 .907 r
.72051 .30454 .72803 .31468 .74445 .30907 .737 .29887 Mtetra
.665 .742 .907 r
.737 .29887 .74445 .30907 .76098 .30348 .75359 .29322 Mtetra
.664 .742 .908 r
.75359 .29322 .76098 .30348 .7776 .2979 .77028 .28757 Mtetra
.664 .741 .908 r
.77028 .28757 .7776 .2979 .79432 .2923 .78707 .28191 Mtetra
.78707 .28191 .79432 .2923 .81113 .28668 .80395 .27623 Mtetra
.80395 .27623 .81113 .28668 .82805 .28103 .82094 .27052 Mtetra
.82094 .27052 .82805 .28103 .84507 .27535 .83803 .26477 Mtetra
.83803 .26477 .84507 .27535 .86218 .26963 .85521 .259 Mtetra
.505 0 0 r
.23864 .5051 .24812 .51318 .26096 .52467 .25146 .51673 Mtetra
.644 .121 0 r
.25146 .51673 .26096 .52467 .27381 .53871 .26428 .53093 Mtetra
.718 .206 0 r
.26428 .53093 .27381 .53871 .28675 .5548 .27719 .54722 Mtetra
.749 .244 0 r
.27719 .54722 .28675 .5548 .29986 .57211 .29027 .56475 Mtetra
.746 .239 0 r
.29027 .56475 .29986 .57211 .31323 .58946 .30362 .58232 Mtetra
.703 .181 0 r
.30362 .58232 .31323 .58946 .32696 .60541 .31732 .59849 Mtetra
.583 .04 0 r
.31732 .59849 .32696 .60541 .3411 .61841 .33146 .61168 Mtetra
0 .241 .674 r
.33146 .61168 .3411 .61841 .3557 .62697 .34607 .62037 Mtetra
.196 .607 .946 r
.34607 .62037 .3557 .62697 .37075 .62987 .36116 .62334 Mtetra
.592 .797 .978 r
.36116 .62334 .37075 .62987 .38621 .62638 .37669 .61983 Mtetra
.77 .831 .899 r
.37669 .61983 .38621 .62638 .40201 .61635 .39257 .6097 Mtetra
.844 .824 .829 r
.39257 .6097 .40201 .61635 .41804 .60028 .4087 .59344 Mtetra
.876 .813 .783 r
.4087 .59344 .41804 .60028 .43419 .57919 .42497 .57211 Mtetra
.892 .803 .754 r
.42497 .57211 .43419 .57919 .45036 .55448 .44126 .54711 Mtetra
.898 .797 .739 r
.44126 .54711 .45036 .55448 .46647 .52772 .45751 .52002 Mtetra
.899 .793 .734 r
.45751 .52002 .46647 .52772 .48248 .5004 .47364 .49238 Mtetra
.896 .791 .737 r
.47364 .49238 .48248 .5004 .49835 .47383 .48964 .4655 Mtetra
.888 .791 .746 r
.48964 .4655 .49835 .47383 .51411 .44901 .50552 .44038 Mtetra
.877 .791 .761 r
.50552 .44038 .51411 .44901 .52977 .42656 .52128 .41767 Mtetra
.861 .79 .78 r
.52128 .41767 .52977 .42656 .54537 .4068 .53698 .39768 Mtetra
.841 .789 .802 r
.53698 .39768 .54537 .4068 .56095 .38975 .55265 .38044 Mtetra
.817 .786 .824 r
.55265 .38044 .56095 .38975 .57654 .37525 .56832 .36577 Mtetra
.791 .781 .844 r
.56832 .36577 .57654 .37525 .59218 .36297 .58404 .35336 Mtetra
.764 .775 .862 r
.58404 .35336 .59218 .36297 .60788 .35255 .59982 .34282 Mtetra
.739 .768 .876 r
.59982 .34282 .60788 .35255 .62367 .3436 .61567 .33377 Mtetra
.718 .761 .887 r
.61567 .33377 .62367 .3436 .63956 .33576 .63163 .32585 Mtetra
.701 .755 .894 r
.63163 .32585 .63956 .33576 .65554 .32873 .64768 .31874 Mtetra
.688 .751 .899 r
.64768 .31874 .65554 .32873 .67163 .32226 .66383 .3122 Mtetra
.679 .747 .903 r
.66383 .3122 .67163 .32226 .68782 .31616 .68009 .30603 Mtetra
.673 .745 .905 r
.68009 .30603 .68782 .31616 .70411 .31028 .69644 .30009 Mtetra
.669 .744 .906 r
.69644 .30009 .70411 .31028 .72051 .30454 .7129 .29428 Mtetra
.667 .743 .907 r
.7129 .29428 .72051 .30454 .737 .29887 .72946 .28855 Mtetra
.665 .742 .907 r
.72946 .28855 .737 .29887 .75359 .29322 .74612 .28284 Mtetra
.664 .742 .908 r
.74612 .28284 .75359 .29322 .77028 .28757 .76288 .27713 Mtetra
.664 .741 .908 r
.76288 .27713 .77028 .28757 .78707 .28191 .77973 .27141 Mtetra
.77973 .27141 .78707 .28191 .80395 .27623 .79669 .26567 Mtetra
.79669 .26567 .80395 .27623 .82094 .27052 .81375 .25989 Mtetra
.81375 .25989 .82094 .27052 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.478 0 0 r
.2291 .49649 .23864 .5051 .25146 .51673 .24191 .50812 Mtetra
.619 .103 0 r
.24191 .50812 .25146 .51673 .26428 .53093 .25472 .52233 Mtetra
.696 .188 0 r
.25472 .52233 .26428 .53093 .27719 .54722 .26761 .53863 Mtetra
.726 .225 0 r
.26761 .53863 .27719 .54722 .29027 .56475 .28066 .55617 Mtetra
.718 .215 0 r
.28066 .55617 .29027 .56475 .30362 .58232 .29399 .57377 Mtetra
.661 .147 0 r
.29399 .57377 .30362 .58232 .31732 .59849 .30768 .58997 Mtetra
.509 0 0 r
.30768 .58997 .31732 .59849 .33146 .61168 .32181 .60317 Mtetra
0 .299 .762 r
.32181 .60317 .33146 .61168 .34607 .62037 .33644 .61187 Mtetra
.285 .608 .954 r
.33644 .61187 .34607 .62037 .36116 .62334 .35156 .61483 Mtetra
.61 .754 .947 r
.35156 .61483 .36116 .62334 .37669 .61983 .36713 .61129 Mtetra
.761 .788 .875 r
.36713 .61129 .37669 .61983 .39257 .6097 .38309 .6011 Mtetra
.829 .79 .815 r
.38309 .6011 .39257 .6097 .4087 .59344 .39931 .58477 Mtetra
.862 .785 .774 r
.39931 .58477 .4087 .59344 .42497 .57211 .41568 .56334 Mtetra
.879 .781 .749 r
.41568 .56334 .42497 .57211 .44126 .54711 .4321 .53822 Mtetra
.887 .778 .735 r
.4321 .53822 .44126 .54711 .45751 .52002 .44846 .51102 Mtetra
.89 .777 .731 r
.44846 .51102 .45751 .52002 .47364 .49238 .46472 .48325 Mtetra
.888 .778 .734 r
.46472 .48325 .47364 .49238 .48964 .4655 .48084 .45625 Mtetra
.882 .779 .743 r
.48084 .45625 .48964 .4655 .50552 .44038 .49683 .43101 Mtetra
.872 .781 .758 r
.49683 .43101 .50552 .44038 .52128 .41767 .51271 .40819 Mtetra
.857 .782 .777 r
.51271 .40819 .52128 .41767 .53698 .39768 .5285 .38809 Mtetra
.838 .782 .799 r
.5285 .38809 .53698 .39768 .55265 .38044 .54426 .37076 Mtetra
.815 .781 .821 r
.54426 .37076 .55265 .38044 .56832 .36577 .56002 .356 Mtetra
.789 .777 .842 r
.56002 .356 .56832 .36577 .58404 .35336 .57581 .34351 Mtetra
.763 .772 .86 r
.57581 .34351 .58404 .35336 .59982 .34282 .59166 .3329 Mtetra
.739 .766 .875 r
.59166 .3329 .59982 .34282 .61567 .33377 .60759 .32378 Mtetra
.718 .76 .886 r
.60759 .32378 .61567 .33377 .63163 .32585 .62361 .31579 Mtetra
.701 .755 .894 r
.62361 .31579 .63163 .32585 .64768 .31874 .63973 .30862 Mtetra
.688 .75 .899 r
.63973 .30862 .64768 .31874 .66383 .3122 .65595 .30201 Mtetra
.679 .747 .903 r
.65595 .30201 .66383 .3122 .68009 .30603 .67227 .29578 Mtetra
.673 .745 .905 r
.67227 .29578 .68009 .30603 .69644 .30009 .68869 .28978 Mtetra
.669 .743 .906 r
.68869 .28978 .69644 .30009 .7129 .29428 .70522 .28392 Mtetra
.667 .743 .907 r
.70522 .28392 .7129 .29428 .72946 .28855 .72184 .27812 Mtetra
.665 .742 .907 r
.72184 .27812 .72946 .28855 .74612 .28284 .73857 .27235 Mtetra
.664 .742 .908 r
.73857 .27235 .74612 .28284 .76288 .27713 .7554 .26658 Mtetra
.664 .741 .908 r
.7554 .26658 .76288 .27713 .77973 .27141 .77232 .2608 Mtetra
.77232 .2608 .77973 .27141 .79669 .26567 .78935 .25499 Mtetra
.78935 .25499 .79669 .26567 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
0 .063 .557 r
.2195 .48736 .2291 .49649 .24191 .50812 .23231 .49883 Mtetra
.584 .076 0 r
.23231 .49883 .24191 .50812 .25472 .52233 .24512 .51288 Mtetra
.662 .161 0 r
.24512 .51288 .25472 .52233 .26761 .53863 .258 .52901 Mtetra
.692 .196 0 r
.258 .52901 .26761 .53863 .28066 .55617 .27104 .54638 Mtetra
.676 .18 0 r
.27104 .54638 .28066 .55617 .29399 .57377 .28435 .5638 Mtetra
.598 .102 0 r
.28435 .5638 .29399 .57377 .30768 .58997 .29803 .57982 Mtetra
0 .072 .582 r
.29803 .57982 .30768 .58997 .32181 .60317 .31216 .59288 Mtetra
0 .347 .818 r
.31216 .59288 .32181 .60317 .33644 .61187 .3268 .60146 Mtetra
.351 .597 .939 r
.3268 .60146 .33644 .61187 .35156 .61483 .34195 .60433 Mtetra
.617 .713 .914 r
.34195 .60433 .35156 .61483 .36713 .61129 .35757 .60074 Mtetra
.749 .75 .853 r
.35757 .60074 .36713 .61129 .38309 .6011 .37359 .59055 Mtetra
.814 .759 .801 r
.37359 .59055 .38309 .6011 .39931 .58477 .38989 .57425 Mtetra
.848 .76 .766 r
.38989 .57425 .39931 .58477 .41568 .56334 .40636 .55286 Mtetra
.866 .76 .743 r
.40636 .55286 .41568 .56334 .4321 .53822 .42288 .52782 Mtetra
.876 .761 .732 r
.42288 .52782 .4321 .53822 .44846 .51102 .43935 .50069 Mtetra
.88 .763 .728 r
.43935 .50069 .44846 .51102 .46472 .48325 .45573 .473 Mtetra
.88 .765 .732 r
.45573 .473 .46472 .48325 .48084 .45625 .47196 .44607 Mtetra
.875 .768 .741 r
.47196 .44607 .48084 .45625 .49683 .43101 .48806 .42089 Mtetra
.866 .772 .756 r
.48806 .42089 .49683 .43101 .51271 .40819 .50404 .3981 Mtetra
.852 .774 .775 r
.50404 .3981 .51271 .40819 .5285 .38809 .51993 .37803 Mtetra
.834 .776 .797 r
.51993 .37803 .5285 .38809 .54426 .37076 .53578 .36071 Mtetra
.812 .776 .819 r
.53578 .36071 .54426 .37076 .56002 .356 .55162 .34594 Mtetra
.787 .773 .84 r
.55162 .34594 .56002 .356 .57581 .34351 .56749 .33343 Mtetra
.762 .769 .859 r
.56749 .33343 .57581 .34351 .59166 .3329 .58342 .32278 Mtetra
.738 .764 .874 r
.58342 .32278 .59166 .3329 .60759 .32378 .59942 .31362 Mtetra
.717 .759 .885 r
.59942 .31362 .60759 .32378 .62361 .31579 .61551 .30559 Mtetra
.7 .754 .893 r
.61551 .30559 .62361 .31579 .63973 .30862 .63169 .29837 Mtetra
.688 .75 .899 r
.63169 .29837 .63973 .30862 .65595 .30201 .64798 .29171 Mtetra
.679 .747 .902 r
.64798 .29171 .65595 .30201 .67227 .29578 .66437 .28542 Mtetra
.673 .745 .905 r
.66437 .28542 .67227 .29578 .68869 .28978 .68086 .27936 Mtetra
.669 .743 .906 r
.68086 .27936 .68869 .28978 .70522 .28392 .69745 .27343 Mtetra
.667 .742 .907 r
.69745 .27343 .70522 .28392 .72184 .27812 .71414 .26758 Mtetra
.665 .742 .907 r
.71414 .26758 .72184 .27812 .73857 .27235 .73094 .26174 Mtetra
.664 .742 .908 r
.73094 .26174 .73857 .27235 .7554 .26658 .74783 .25591 Mtetra
.664 .741 .908 r
.74783 .25591 .7554 .26658 .77232 .2608 .76483 .25007 Mtetra
.76483 .25007 .77232 .2608 .78935 .25499 .78193 .24419 Mtetra
.78193 .24419 .78935 .25499 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
0 .097 .6 r
.20985 .4777 .2195 .48736 .23231 .49883 .22267 .48889 Mtetra
.536 .04 0 r
.22267 .48889 .23231 .49883 .24512 .51288 .23549 .50262 Mtetra
.617 .124 0 r
.23549 .50262 .24512 .51288 .258 .52901 .24837 .51839 Mtetra
.643 .157 0 r
.24837 .51839 .258 .52901 .27104 .54638 .26141 .53538 Mtetra
.616 .135 0 r
.26141 .53538 .27104 .54638 .28435 .5638 .27472 .55242 Mtetra
0 0 .481 r
.27472 .55242 .28435 .5638 .29803 .57982 .28839 .56809 Mtetra
0 .134 .661 r
.28839 .56809 .29803 .57982 .31216 .59288 .30253 .58083 Mtetra
.053 .381 .845 r
.30253 .58083 .31216 .59288 .3268 .60146 .31718 .58916 Mtetra
.399 .581 .913 r
.31718 .58916 .3268 .60146 .34195 .60433 .33235 .59187 Mtetra
.62 .678 .884 r
.33235 .59187 .34195 .60433 .35757 .60074 .34801 .58822 Mtetra
.737 .716 .832 r
.34801 .58822 .35757 .60074 .37359 .59055 .36408 .57807 Mtetra
.799 .731 .789 r
.36408 .57807 .37359 .59055 .38989 .57425 .38045 .56189 Mtetra
.833 .737 .758 r
.38045 .56189 .38989 .57425 .40636 .55286 .397 .54071 Mtetra
.853 .741 .739 r
.397 .54071 .40636 .55286 .42288 .52782 .41361 .51592 Mtetra
.865 .745 .729 r
.41361 .51592 .42288 .52782 .43935 .50069 .43019 .48906 Mtetra
.87 .749 .726 r
.43019 .48906 .43935 .50069 .45573 .473 .44666 .46165 Mtetra
.871 .753 .73 r
.44666 .46165 .45573 .473 .47196 .44607 .463 .43497 Mtetra
.867 .758 .74 r
.463 .43497 .47196 .44607 .48806 .42089 .47921 .41002 Mtetra
.859 .763 .755 r
.47921 .41002 .48806 .42089 .50404 .3981 .49528 .38742 Mtetra
.847 .767 .774 r
.49528 .38742 .50404 .3981 .51993 .37803 .51127 .3675 Mtetra
.829 .77 .795 r
.51127 .3675 .51993 .37803 .53578 .36071 .52721 .35028 Mtetra
.808 .771 .818 r
.52721 .35028 .53578 .36071 .55162 .34594 .54314 .33559 Mtetra
.785 .769 .839 r
.54314 .33559 .55162 .34594 .56749 .33343 .55908 .32311 Mtetra
.76 .766 .858 r
.55908 .32311 .56749 .33343 .58342 .32278 .57508 .31247 Mtetra
.737 .762 .873 r
.57508 .31247 .58342 .32278 .59942 .31362 .59116 .3033 Mtetra
.716 .757 .885 r
.59116 .3033 .59942 .31362 .61551 .30559 .60732 .29524 Mtetra
.7 .753 .893 r
.60732 .29524 .61551 .30559 .63169 .29837 .62357 .28798 Mtetra
.687 .749 .899 r
.62357 .28798 .63169 .29837 .64798 .29171 .63992 .28127 Mtetra
.679 .746 .902 r
.63992 .28127 .64798 .29171 .66437 .28542 .65638 .27493 Mtetra
.673 .745 .905 r
.65638 .27493 .66437 .28542 .68086 .27936 .67294 .26882 Mtetra
.669 .743 .906 r
.67294 .26882 .68086 .27936 .69745 .27343 .6896 .26283 Mtetra
.667 .742 .907 r
.6896 .26283 .69745 .27343 .71414 .26758 .70636 .25692 Mtetra
.665 .742 .907 r
.70636 .25692 .71414 .26758 .73094 .26174 .72322 .25102 Mtetra
.664 .742 .908 r
.72322 .25102 .73094 .26174 .74783 .25591 .74019 .24513 Mtetra
.664 .741 .908 r
.74019 .24513 .74783 .25591 .76483 .25007 .75726 .23922 Mtetra
.75726 .23922 .76483 .25007 .78193 .24419 .77443 .23328 Mtetra
.77443 .23328 .78193 .24419 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
0 .138 .646 r
.20015 .46754 .20985 .4777 .22267 .48889 .21299 .47831 Mtetra
0 .005 .521 r
.21299 .47831 .22267 .48889 .23549 .50262 .22583 .49156 Mtetra
.557 .078 0 r
.22583 .49156 .23549 .50262 .24837 .51839 .23872 .5068 Mtetra
.579 .108 0 r
.23872 .5068 .24837 .51839 .26141 .53538 .25177 .52323 Mtetra
0 0 .455 r
.25177 .52323 .26141 .53538 .27472 .55242 .26509 .5397 Mtetra
0 .018 .563 r
.26509 .5397 .27472 .55242 .28839 .56809 .27877 .55482 Mtetra
0 .194 .721 r
.27877 .55482 .28839 .56809 .30253 .58083 .29292 .56709 Mtetra
.145 .405 .852 r
.29292 .56709 .30253 .58083 .31718 .58916 .30758 .57506 Mtetra
.434 .565 .887 r
.30758 .57506 .31718 .58916 .33235 .59187 .32277 .57754 Mtetra
.62 .649 .857 r
.32277 .57754 .33235 .59187 .34801 .58822 .33846 .57381 Mtetra
.725 .688 .814 r
.33846 .57381 .34801 .58822 .36408 .57807 .35457 .56374 Mtetra
.784 .706 .778 r
.35457 .56374 .36408 .57807 .38045 .56189 .371 .54779 Mtetra
.819 .717 .752 r
.371 .54779 .38045 .56189 .397 .54071 .38761 .52695 Mtetra
.841 .724 .735 r
.38761 .52695 .397 .54071 .41361 .51592 .4043 .50258 Mtetra
.853 .73 .727 r
.4043 .50258 .41361 .51592 .43019 .48906 .42097 .47618 Mtetra
.86 .736 .725 r
.42097 .47618 .43019 .48906 .44666 .46165 .43754 .44923 Mtetra
.862 .742 .729 r
.43754 .44923 .44666 .46165 .463 .43497 .45398 .42299 Mtetra
.859 .748 .739 r
.45398 .42299 .463 .43497 .47921 .41002 .47027 .39843 Mtetra
.852 .754 .754 r
.47027 .39843 .47921 .41002 .49528 .38742 .48645 .37617 Mtetra
.84 .76 .773 r
.48645 .37617 .49528 .38742 .51127 .3675 .50253 .35651 Mtetra
.824 .764 .795 r
.50253 .35651 .51127 .3675 .52721 .35028 .51855 .33949 Mtetra
.804 .766 .817 r
.51855 .33949 .52721 .35028 .54314 .33559 .53456 .32494 Mtetra
.781 .765 .839 r
.53456 .32494 .54314 .33559 .55908 .32311 .55059 .31255 Mtetra
.757 .763 .858 r
.55059 .31255 .55908 .32311 .57508 .31247 .56666 .30197 Mtetra
.735 .76 .873 r
.56666 .30197 .57508 .31247 .59116 .3033 .58281 .29282 Mtetra
.715 .756 .884 r
.58281 .29282 .59116 .3033 .60732 .29524 .59903 .28475 Mtetra
.699 .752 .893 r
.59903 .28475 .60732 .29524 .62357 .28798 .61536 .27746 Mtetra
.687 .749 .898 r
.61536 .27746 .62357 .28798 .63992 .28127 .63178 .27072 Mtetra
.678 .746 .902 r
.63178 .27072 .63992 .28127 .65638 .27493 .6483 .26433 Mtetra
.672 .744 .904 r
.6483 .26433 .65638 .27493 .67294 .26882 .66493 .25816 Mtetra
.669 .743 .906 r
.66493 .25816 .67294 .26882 .6896 .26283 .68166 .25212 Mtetra
.667 .742 .907 r
.68166 .25212 .6896 .26283 .70636 .25692 .69849 .24614 Mtetra
.665 .742 .907 r
.69849 .24614 .70636 .25692 .72322 .25102 .71542 .24018 Mtetra
.664 .742 .908 r
.71542 .24018 .72322 .25102 .74019 .24513 .73246 .23422 Mtetra
.664 .741 .908 r
.73246 .23422 .74019 .24513 .75726 .23922 .7496 .22825 Mtetra
.7496 .22825 .75726 .23922 .77443 .23328 .76684 .22224 Mtetra
.76684 .22224 .77443 .23328 .7917 .22731 .78419 .21621 Mtetra
.78419 .21621 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
0 .184 .694 r
.19039 .45691 .20015 .46754 .21299 .47831 .20327 .46714 Mtetra
0 .057 .583 r
.20327 .46714 .21299 .47831 .22583 .49156 .21614 .47976 Mtetra
0 0 .51 r
.21614 .47976 .22583 .49156 .23872 .5068 .22906 .49431 Mtetra
0 0 .492 r
.22906 .49431 .23872 .5068 .25177 .52323 .24214 .50999 Mtetra
0 0 .534 r
.24214 .50999 .25177 .52323 .26509 .5397 .25547 .52572 Mtetra
0 .084 .634 r
.25547 .52572 .26509 .5397 .27877 .55482 .26917 .54014 Mtetra
0 .246 .761 r
.26917 .54014 .27877 .55482 .29292 .56709 .28333 .55179 Mtetra
.219 .422 .848 r
.28333 .55179 .29292 .56709 .30758 .57506 .29801 .55928 Mtetra
.46 .552 .862 r
.29801 .55928 .30758 .57506 .32277 .57754 .31322 .56146 Mtetra
.618 .625 .835 r
.31322 .56146 .32277 .57754 .33846 .57381 .32893 .55765 Mtetra
.713 .664 .799 r
.32893 .55765 .33846 .57381 .35457 .56374 .34507 .5477 Mtetra
.771 .685 .769 r
.34507 .5477 .35457 .56374 .371 .54779 .36154 .53206 Mtetra
.806 .699 .747 r
.36154 .53206 .371 .54779 .38761 .52695 .37821 .51169 Mtetra
.828 .709 .732 r
.37821 .51169 .38761 .52695 .4043 .50258 .39497 .48789 Mtetra
.842 .717 .725 r
.39497 .48789 .4043 .50258 .42097 .47618 .4117 .46213 Mtetra
.85 .724 .724 r
.4117 .46213 .42097 .47618 .43754 .44923 .42836 .43582 Mtetra
.853 .732 .73 r
.42836 .43582 .43754 .44923 .45398 .42299 .44488 .41019 Mtetra
.851 .739 .74 r
.44488 .41019 .45398 .42299 .47027 .39843 .46127 .38617 Mtetra
.845 .746 .755 r
.46127 .38617 .47027 .39843 .48645 .37617 .47753 .36437 Mtetra
.834 .753 .774 r
.47753 .36437 .48645 .37617 .50253 .35651 .49369 .34509 Mtetra
.819 .758 .795 r
.49369 .34509 .50253 .35651 .51855 .33949 .5098 .32836 Mtetra
.799 .761 .818 r
.5098 .32836 .51855 .33949 .53456 .32494 .52589 .31402 Mtetra
.777 .762 .839 r
.52589 .31402 .53456 .32494 .55059 .31255 .542 .30178 Mtetra
.754 .76 .858 r
.542 .30178 .55059 .31255 .56666 .30197 .55815 .29128 Mtetra
.732 .758 .873 r
.55815 .29128 .56666 .30197 .58281 .29282 .57437 .28217 Mtetra
.713 .754 .884 r
.57437 .28217 .58281 .29282 .59903 .28475 .59066 .27411 Mtetra
.698 .751 .893 r
.59066 .27411 .59903 .28475 .61536 .27746 .60706 .26681 Mtetra
.686 .748 .898 r
.60706 .26681 .61536 .27746 .63178 .27072 .62355 .26003 Mtetra
.678 .746 .902 r
.62355 .26003 .63178 .27072 .6483 .26433 .64014 .2536 Mtetra
.672 .744 .904 r
.64014 .2536 .6483 .26433 .66493 .25816 .65683 .24738 Mtetra
.669 .743 .906 r
.65683 .24738 .66493 .25816 .68166 .25212 .67363 .24128 Mtetra
.666 .742 .907 r
.67363 .24128 .68166 .25212 .69849 .24614 .69053 .23524 Mtetra
.665 .742 .907 r
.69053 .23524 .69849 .24614 .71542 .24018 .70753 .22922 Mtetra
.664 .742 .908 r
.70753 .22922 .71542 .24018 .73246 .23422 .72464 .22319 Mtetra
.664 .741 .908 r
.72464 .22319 .73246 .23422 .7496 .22825 .74185 .21715 Mtetra
.74185 .21715 .7496 .22825 .76684 .22224 .75917 .21108 Mtetra
.75917 .21108 .76684 .22224 .78419 .21621 .77659 .20498 Mtetra
.77659 .20498 .78419 .21621 .80164 .21014 .79412 .19885 Mtetra
.79412 .19885 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
0 .235 .74 r
.18058 .44584 .19039 .45691 .20327 .46714 .19351 .45541 Mtetra
0 .115 .644 r
.19351 .45541 .20327 .46714 .21614 .47976 .20642 .46728 Mtetra
0 .039 .58 r
.20642 .46728 .21614 .47976 .22906 .49431 .21939 .48099 Mtetra
0 .016 .566 r
.21939 .48099 .22906 .49431 .24214 .50999 .2325 .49578 Mtetra
0 .052 .606 r
.2325 .49578 .24214 .50999 .25547 .52572 .24587 .51061 Mtetra
0 .148 .691 r
.24587 .51061 .25547 .52572 .26917 .54014 .2596 .52417 Mtetra
.031 .291 .784 r
.2596 .52417 .26917 .54014 .28333 .55179 .27378 .53507 Mtetra
.278 .435 .839 r
.27378 .53507 .28333 .55179 .29801 .55928 .28847 .54198 Mtetra
.48 .541 .842 r
.28847 .54198 .29801 .55928 .31322 .56146 .30369 .54381 Mtetra
.617 .606 .817 r
.30369 .54381 .31322 .56146 .32893 .55765 .31942 .53989 Mtetra
.703 .644 .787 r
.31942 .53989 .32893 .55765 .34507 .5477 .33559 .5301 Mtetra
.758 .667 .761 r
.33559 .5301 .34507 .5477 .36154 .53206 .35209 .51485 Mtetra
.793 .683 .742 r
.35209 .51485 .36154 .53206 .37821 .51169 .3688 .49507 Mtetra
.816 .695 .73 r
.3688 .49507 .37821 .51169 .39497 .48789 .3856 .47199 Mtetra
.831 .705 .725 r
.3856 .47199 .39497 .48789 .4117 .46213 .4024 .44701 Mtetra
.84 .714 .725 r
.4024 .44701 .4117 .46213 .42836 .43582 .41912 .4215 Mtetra
.843 .723 .73 r
.41912 .4215 .42836 .43582 .44488 .41019 .43572 .39662 Mtetra
.843 .731 .741 r
.43572 .39662 .44488 .41019 .46127 .38617 .45218 .37328 Mtetra
.837 .739 .756 r
.45218 .37328 .46127 .38617 .47753 .36437 .46853 .35206 Mtetra
.827 .747 .775 r
.46853 .35206 .47753 .36437 .49369 .34509 .48478 .33325 Mtetra
.812 .753 .797 r
.48478 .33325 .49369 .34509 .5098 .32836 .50097 .3169 Mtetra
.794 .756 .819 r
.50097 .3169 .5098 .32836 .52589 .31402 .51714 .30283 Mtetra
.773 .758 .84 r
.51714 .30283 .52589 .31402 .542 .30178 .53332 .29078 Mtetra
.751 .758 .858 r
.53332 .29078 .542 .30178 .55815 .29128 .54954 .28041 Mtetra
.73 .756 .873 r
.54954 .28041 .55815 .29128 .57437 .28217 .56583 .27137 Mtetra
.711 .753 .885 r
.56583 .27137 .57437 .28217 .59066 .27411 .5822 .26333 Mtetra
.696 .75 .893 r
.5822 .26333 .59066 .27411 .60706 .26681 .59866 .25603 Mtetra
.685 .747 .898 r
.59866 .25603 .60706 .26681 .62355 .26003 .61522 .24922 Mtetra
.677 .745 .902 r
.61522 .24922 .62355 .26003 .64014 .2536 .63188 .24275 Mtetra
.672 .744 .905 r
.63188 .24275 .64014 .2536 .65683 .24738 .64865 .23648 Mtetra
.668 .743 .906 r
.64865 .23648 .65683 .24738 .67363 .24128 .66551 .23032 Mtetra
.666 .742 .907 r
.66551 .23032 .67363 .24128 .69053 .23524 .68248 .22422 Mtetra
.665 .742 .907 r
.68248 .22422 .69053 .23524 .70753 .22922 .69956 .21813 Mtetra
.664 .742 .908 r
.69956 .21813 .70753 .22922 .72464 .22319 .71674 .21204 Mtetra
.664 .741 .908 r
.71674 .21204 .72464 .22319 .74185 .21715 .73402 .20594 Mtetra
.73402 .20594 .74185 .21715 .75917 .21108 .75141 .1998 Mtetra
.75141 .1998 .75917 .21108 .77659 .20498 .76891 .19363 Mtetra
.76891 .19363 .77659 .20498 .79412 .19885 .78651 .18742 Mtetra
.78651 .18742 .79412 .19885 .81176 .19267 .80423 .18118 Mtetra
0 .286 .782 r
.17072 .43437 .18058 .44584 .19351 .45541 .18371 .4432 Mtetra
0 .177 .701 r
.18371 .4432 .19351 .45541 .20642 .46728 .19667 .4542 Mtetra
0 .106 .647 r
.19667 .4542 .20642 .46728 .21939 .48099 .2097 .46694 Mtetra
0 .085 .635 r
.2097 .46694 .21939 .48099 .2325 .49578 .22286 .48071 Mtetra
0 .12 .668 r
.22286 .48071 .2325 .49578 .24587 .51061 .23627 .4945 Mtetra
0 .208 .734 r
.23627 .4945 .24587 .51061 .2596 .52417 .25004 .50708 Mtetra
.115 .328 .798 r
.25004 .50708 .2596 .52417 .27378 .53507 .26425 .51712 Mtetra
.326 .446 .829 r
.26425 .51712 .27378 .53507 .28847 .54198 .27896 .52337 Mtetra
.496 .534 .825 r
.27896 .52337 .28847 .54198 .30369 .54381 .2942 .5248 Mtetra
.615 .591 .803 r
.2942 .5248 .30369 .54381 .31942 .53989 .30995 .52076 Mtetra
.695 .628 .778 r
.30995 .52076 .31942 .53989 .33559 .5301 .32612 .51115 Mtetra
.747 .652 .756 r
.32612 .51115 .33559 .5301 .35209 .51485 .34264 .49637 Mtetra
.782 .669 .739 r
.34264 .49637 .35209 .51485 .3688 .49507 .35937 .47726 Mtetra
.805 .683 .729 r
.35937 .47726 .3688 .49507 .3856 .47199 .37621 .45502 Mtetra
.82 .694 .725 r
.37621 .45502 .3856 .47199 .4024 .44701 .39306 .43095 Mtetra
.83 .705 .726 r
.39306 .43095 .4024 .44701 .41912 .4215 .40983 .40637 Mtetra
.834 .714 .732 r
.40983 .40637 .41912 .4215 .43572 .39662 .4265 .38237 Mtetra
.834 .724 .743 r
.4265 .38237 .43572 .39662 .45218 .37328 .44303 .35983 Mtetra
.829 .733 .758 r
.44303 .35983 .45218 .37328 .46853 .35206 .45945 .33929 Mtetra
.82 .741 .777 r
.45945 .33929 .46853 .35206 .48478 .33325 .47578 .32105 Mtetra
.806 .748 .798 r
.47578 .32105 .48478 .33325 .50097 .3169 .49204 .30513 Mtetra
.788 .752 .82 r
.49204 .30513 .50097 .3169 .51714 .30283 .50829 .2914 Mtetra
.768 .755 .841 r
.50829 .2914 .51714 .30283 .53332 .29078 .52455 .27958 Mtetra
.747 .755 .859 r
.52455 .27958 .53332 .29078 .54954 .28041 .54085 .26936 Mtetra
.727 .754 .874 r
.54085 .26936 .54954 .28041 .56583 .27137 .55721 .26041 Mtetra
.709 .751 .885 r
.55721 .26041 .56583 .27137 .5822 .26333 .57365 .25241 Mtetra
.695 .749 .893 r
.57365 .25241 .5822 .26333 .59866 .25603 .59018 .24511 Mtetra
.684 .747 .899 r
.59018 .24511 .59866 .25603 .61522 .24922 .60681 .23828 Mtetra
.677 .745 .902 r
.60681 .23828 .61522 .24922 .63188 .24275 .62354 .23177 Mtetra
.671 .744 .905 r
.62354 .23177 .63188 .24275 .64865 .23648 .64037 .22545 Mtetra
.668 .743 .906 r
.64037 .22545 .64865 .23648 .66551 .23032 .65731 .21924 Mtetra
.666 .742 .907 r
.65731 .21924 .66551 .23032 .68248 .22422 .67435 .21307 Mtetra
.665 .742 .907 r
.67435 .21307 .68248 .22422 .69956 .21813 .69149 .20692 Mtetra
.664 .742 .908 r
.69149 .20692 .69956 .21813 .71674 .21204 .70875 .20077 Mtetra
.664 .741 .908 r
.70875 .20077 .71674 .21204 .73402 .20594 .7261 .19459 Mtetra
.7261 .19459 .73402 .20594 .75141 .1998 .74357 .18838 Mtetra
.74357 .18838 .75141 .1998 .76891 .19363 .76114 .18214 Mtetra
.76114 .18214 .76891 .19363 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
0 .337 .818 r
.16079 .42256 .17072 .43437 .18371 .4432 .17385 .43056 Mtetra
0 .239 .752 r
.17385 .43056 .18371 .4432 .19667 .4542 .18689 .4406 Mtetra
0 .173 .706 r
.18689 .4406 .19667 .4542 .2097 .46694 .19998 .45228 Mtetra
0 .154 .694 r
.19998 .45228 .2097 .46694 .22286 .48071 .21321 .46491 Mtetra
0 .185 .718 r
.21321 .46491 .22286 .48071 .23627 .4945 .22668 .47755 Mtetra
.009 .26 .764 r
.22668 .47755 .23627 .4945 .25004 .50708 .2405 .48904 Mtetra
.187 .36 .805 r
.2405 .48904 .25004 .50708 .26425 .51712 .25474 .49814 Mtetra
.364 .455 .821 r
.25474 .49814 .26425 .51712 .27896 .52337 .26948 .50366 Mtetra
.509 .529 .812 r
.26948 .50366 .27896 .52337 .2942 .5248 .28474 .50464 Mtetra
.614 .58 .792 r
.28474 .50464 .2942 .5248 .30995 .52076 .30049 .50049 Mtetra
.687 .615 .77 r
.30049 .50049 .30995 .52076 .32612 .51115 .31667 .49108 Mtetra
.737 .639 .752 r
.31667 .49108 .32612 .51115 .34264 .49637 .33319 .4768 Mtetra
.771 .658 .738 r
.33319 .4768 .34264 .49637 .35937 .47726 .34994 .45845 Mtetra
.794 .672 .729 r
.34994 .45845 .35937 .47726 .37621 .45502 .3668 .43714 Mtetra
.81 .685 .726 r
.3668 .43714 .37621 .45502 .39306 .43095 .38368 .4141 Mtetra
.82 .696 .728 r
.38368 .4141 .39306 .43095 .40983 .40637 .40049 .39055 Mtetra
.825 .707 .735 r
.40049 .39055 .40983 .40637 .4265 .38237 .41721 .36754 Mtetra
.825 .717 .746 r
.41721 .36754 .4265 .38237 .44303 .35983 .43381 .34589 Mtetra
.821 .727 .761 r
.43381 .34589 .44303 .35983 .45945 .33929 .4503 .32612 Mtetra
.812 .736 .78 r
.4503 .32612 .45945 .33929 .47578 .32105 .46669 .30852 Mtetra
.799 .743 .801 r
.46669 .30852 .47578 .32105 .49204 .30513 .48303 .2931 Mtetra
.782 .749 .822 r
.48303 .2931 .49204 .30513 .50829 .2914 .49935 .27974 Mtetra
.763 .752 .843 r
.49935 .27974 .50829 .2914 .52455 .27958 .51568 .26818 Mtetra
.743 .752 .86 r
.51568 .26818 .52455 .27958 .54085 .26936 .53206 .25814 Mtetra
.723 .752 .875 r
.53206 .25814 .54085 .26936 .55721 .26041 .54849 .24929 Mtetra
.707 .75 .886 r
.54849 .24929 .55721 .26041 .57365 .25241 .565 .24135 Mtetra
.693 .748 .893 r
.565 .24135 .57365 .25241 .59018 .24511 .5816 .23406 Mtetra
.683 .746 .899 r
.5816 .23406 .59018 .24511 .60681 .23828 .5983 .22722 Mtetra
.676 .744 .902 r
.5983 .22722 .60681 .23828 .62354 .23177 .6151 .22067 Mtetra
.671 .743 .905 r
.6151 .22067 .62354 .23177 .64037 .22545 .632 .2143 Mtetra
.668 .742 .906 r
.632 .2143 .64037 .22545 .65731 .21924 .64901 .20803 Mtetra
.666 .742 .907 r
.64901 .20803 .65731 .21924 .67435 .21307 .66612 .2018 Mtetra
.665 .742 .907 r
.66612 .2018 .67435 .21307 .69149 .20692 .68334 .19559 Mtetra
.664 .742 .908 r
.68334 .19559 .69149 .20692 .70875 .20077 .70066 .18936 Mtetra
.664 .741 .908 r
.70066 .18936 .70875 .20077 .7261 .19459 .71809 .18312 Mtetra
.71809 .18312 .7261 .19459 .74357 .18838 .73563 .17684 Mtetra
.73563 .17684 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.057 .386 .848 r
.15079 .41045 .16079 .42256 .17385 .43056 .16394 .41756 Mtetra
0 .299 .795 r
.16394 .41756 .17385 .43056 .18689 .4406 .17706 .42657 Mtetra
0 .239 .756 r
.17706 .42657 .18689 .4406 .19998 .45228 .19023 .43711 Mtetra
0 .22 .743 r
.19023 .43711 .19998 .45228 .21321 .46491 .20354 .44853 Mtetra
0 .245 .757 r
.20354 .44853 .21321 .46491 .22668 .47755 .21708 .45993 Mtetra
.094 .307 .785 r
.21708 .45993 .22668 .47755 .2405 .48904 .23096 .47026 Mtetra
.247 .387 .808 r
.23096 .47026 .2405 .48904 .25474 .49814 .24525 .47835 Mtetra
.397 .465 .813 r
.24525 .47835 .25474 .49814 .26948 .50366 .26001 .48309 Mtetra
.521 .527 .803 r
.26001 .48309 .26948 .50366 .28474 .50464 .27529 .48359 Mtetra
.614 .572 .784 r
.27529 .48359 .28474 .50464 .30049 .50049 .29104 .4793 Mtetra
.68 .605 .765 r
.29104 .4793 .30049 .50049 .31667 .49108 .30722 .47012 Mtetra
.727 .629 .749 r
.30722 .47012 .31667 .49108 .33319 .4768 .32374 .45639 Mtetra
.761 .648 .737 r
.32374 .45639 .33319 .4768 .34994 .45845 .34049 .43885 Mtetra
.784 .663 .73 r
.34049 .43885 .34994 .45845 .3668 .43714 .35736 .41854 Mtetra
.8 .677 .728 r
.35736 .41854 .3668 .43714 .38368 .4141 .37426 .3966 Mtetra
.811 .689 .731 r
.37426 .3966 .38368 .4141 .40049 .39055 .39111 .37417 Mtetra
.816 .701 .738 r
.39111 .37417 .40049 .39055 .41721 .36754 .40786 .35223 Mtetra
.817 .712 .749 r
.40786 .35223 .41721 .36754 .43381 .34589 .42451 .33154 Mtetra
.813 .722 .765 r
.42451 .33154 .43381 .34589 .4503 .32612 .44106 .31262 Mtetra
.805 .732 .784 r
.44106 .31262 .4503 .32612 .46669 .30852 .45752 .29569 Mtetra
.792 .739 .804 r
.45752 .29569 .46669 .30852 .48303 .2931 .47393 .28082 Mtetra
.776 .745 .825 r
.47393 .28082 .48303 .2931 .49935 .27974 .49033 .26787 Mtetra
.757 .749 .845 r
.49033 .26787 .49935 .27974 .51568 .26818 .50673 .25661 Mtetra
.738 .75 .862 r
.50673 .25661 .51568 .26818 .53206 .25814 .52317 .24676 Mtetra
.72 .75 .876 r
.52317 .24676 .53206 .25814 .54849 .24929 .53968 .23803 Mtetra
.704 .748 .886 r
.53968 .23803 .54849 .24929 .565 .24135 .55626 .23015 Mtetra
.691 .747 .894 r
.55626 .23015 .565 .24135 .5816 .23406 .57293 .22287 Mtetra
.682 .745 .899 r
.57293 .22287 .5816 .23406 .5983 .22722 .5897 .21602 Mtetra
.675 .744 .903 r
.5897 .21602 .5983 .22722 .6151 .22067 .60657 .20944 Mtetra
.671 .743 .905 r
.60657 .20944 .6151 .22067 .632 .2143 .62354 .20302 Mtetra
.668 .742 .906 r
.62354 .20302 .632 .2143 .64901 .20803 .64062 .19669 Mtetra
.666 .742 .907 r
.64062 .19669 .64901 .20803 .66612 .2018 .6578 .1904 Mtetra
.665 .742 .907 r
.6578 .1904 .66612 .2018 .68334 .19559 .67509 .18412 Mtetra
.664 .741 .908 r
.67509 .18412 .68334 .19559 .70066 .18936 .69249 .17783 Mtetra
.69249 .17783 .70066 .18936 .71809 .18312 .70999 .17151 Mtetra
.70999 .17151 .71809 .18312 .73563 .17684 .72761 .16517 Mtetra
.72761 .16517 .73563 .17684 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.133 .431 .871 r
.14073 .39811 .15079 .41045 .16394 .41756 .15396 .40428 Mtetra
.044 .355 .829 r
.15396 .40428 .16394 .41756 .17706 .42657 .16718 .41222 Mtetra
0 .301 .795 r
.16718 .41222 .17706 .42657 .19023 .43711 .18045 .42155 Mtetra
.001 .281 .781 r
.18045 .42155 .19023 .43711 .20354 .44853 .19385 .43169 Mtetra
.062 .3 .786 r
.19385 .43169 .20354 .44853 .21708 .45993 .20747 .44181 Mtetra
.168 .348 .8 r
.20747 .44181 .21708 .45993 .23096 .47026 .22141 .45092 Mtetra
.297 .412 .81 r
.22141 .45092 .23096 .47026 .24525 .47835 .23575 .45795 Mtetra
.424 .474 .808 r
.23575 .45795 .24525 .47835 .26001 .48309 .25055 .46188 Mtetra
.531 .527 .796 r
.25055 .46188 .26001 .48309 .27529 .48359 .26584 .46188 Mtetra
.613 .567 .779 r
.26584 .46188 .27529 .48359 .29104 .4793 .2816 .45746 Mtetra
.674 .598 .762 r
.2816 .45746 .29104 .4793 .30722 .47012 .29778 .44851 Mtetra
.719 .621 .748 r
.29778 .44851 .30722 .47012 .32374 .45639 .31428 .43535 Mtetra
.751 .64 .738 r
.31428 .43535 .32374 .45639 .34049 .43885 .33102 .41866 Mtetra
.774 .656 .732 r
.33102 .41866 .34049 .43885 .35736 .41854 .34789 .3994 Mtetra
.791 .67 .731 r
.34789 .3994 .35736 .41854 .37426 .3966 .36479 .37861 Mtetra
.801 .683 .734 r
.36479 .37861 .37426 .3966 .39111 .37417 .38166 .35735 Mtetra
.807 .695 .742 r
.38166 .35735 .39111 .37417 .40786 .35223 .39845 .33654 Mtetra
.808 .707 .754 r
.39845 .33654 .40786 .35223 .42451 .33154 .41515 .31687 Mtetra
.805 .718 .769 r
.41515 .31687 .42451 .33154 .44106 .31262 .43175 .29882 Mtetra
.797 .728 .788 r
.43175 .29882 .44106 .31262 .45752 .29569 .44827 .28263 Mtetra
.785 .736 .808 r
.44827 .28263 .45752 .29569 .47393 .28082 .46475 .26833 Mtetra
.769 .742 .828 r
.46475 .26833 .47393 .28082 .49033 .26787 .48121 .25582 Mtetra
.751 .746 .847 r
.48121 .25582 .49033 .26787 .50673 .25661 .49768 .24487 Mtetra
.733 .748 .864 r
.49768 .24487 .50673 .25661 .52317 .24676 .51419 .23523 Mtetra
.716 .748 .877 r
.51419 .23523 .52317 .24676 .53968 .23803 .53077 .22663 Mtetra
.701 .747 .887 r
.53077 .22663 .53968 .23803 .55626 .23015 .54742 .21881 Mtetra
.689 .746 .895 r
.54742 .21881 .55626 .23015 .57293 .22287 .56416 .21156 Mtetra
.681 .745 .9 r
.56416 .21156 .57293 .22287 .5897 .21602 .581 .20469 Mtetra
.674 .744 .903 r
.581 .20469 .5897 .21602 .60657 .20944 .59794 .19808 Mtetra
.67 .743 .905 r
.59794 .19808 .60657 .20944 .62354 .20302 .61498 .19161 Mtetra
.667 .742 .906 r
.61498 .19161 .62354 .20302 .64062 .19669 .63213 .18523 Mtetra
.666 .742 .907 r
.63213 .18523 .64062 .19669 .6578 .1904 .64939 .17887 Mtetra
.665 .742 .907 r
.64939 .17887 .6578 .1904 .67509 .18412 .66675 .17253 Mtetra
.664 .741 .908 r
.66675 .17253 .67509 .18412 .69249 .17783 .68422 .16617 Mtetra
.68422 .16617 .69249 .17783 .70999 .17151 .7018 .15978 Mtetra
.7018 .15978 .70999 .17151 .72761 .16517 .71949 .15336 Mtetra
.71949 .15336 .72761 .16517 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Mtetra
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.204 .472 .888 r
.13058 .38558 .14073 .39811 .15396 .40428 .14392 .3908 Mtetra
.127 .405 .854 r
.14392 .3908 .15396 .40428 .16718 .41222 .15724 .39762 Mtetra
.086 .357 .826 r
.15724 .39762 .16718 .41222 .18045 .42155 .17061 .40573 Mtetra
.09 .337 .81 r
.17061 .40573 .18045 .42155 .19385 .43169 .18411 .41456 Mtetra
.142 .348 .807 r
.18411 .41456 .19385 .43169 .20747 .44181 .19782 .42336 Mtetra
.232 .384 .811 r
.19782 .42336 .20747 .44181 .22141 .45092 .21184 .43122 Mtetra
.341 .434 .812 r
.21184 .43122 .22141 .45092 .23575 .45795 .22624 .43717 Mtetra
.448 .485 .805 r
.22624 .43717 .23575 .45795 .25055 .46188 .24108 .44026 Mtetra
.54 .529 .791 r
.24108 .44026 .25055 .46188 .26584 .46188 .25639 .43975 Mtetra
.614 .565 .776 r
.25639 .43975 .26584 .46188 .2816 .45746 .27215 .43519 Mtetra
.67 .593 .76 r
.27215 .43519 .2816 .45746 .29778 .44851 .28832 .42648 Mtetra
.712 .615 .748 r
.28832 .42648 .29778 .44851 .31428 .43535 .30481 .4139 Mtetra
.743 .634 .739 r
.30481 .4139 .31428 .43535 .33102 .41866 .32153 .39808 Mtetra
.765 .65 .735 r
.32153 .39808 .33102 .41866 .34789 .3994 .33838 .37989 Mtetra
.782 .665 .735 r
.33838 .37989 .34789 .3994 .36479 .37861 .35528 .36028 Mtetra
.792 .678 .739 r
.35528 .36028 .36479 .37861 .38166 .35735 .37216 .34023 Mtetra
.798 .691 .747 r
.37216 .34023 .38166 .35735 .39845 .33654 .38898 .32057 Mtetra
.799 .703 .759 r
.38898 .32057 .39845 .33654 .41515 .31687 .40571 .30195 Mtetra
.796 .715 .775 r
.40571 .30195 .41515 .31687 .43175 .29882 .42235 .28481 Mtetra
.789 .725 .793 r
.42235 .28481 .43175 .29882 .44827 .28263 .43893 .26937 Mtetra
.777 .733 .813 r
.43893 .26937 .44827 .28263 .46475 .26833 .45547 .25567 Mtetra
.762 .74 .832 r
.45547 .25567 .46475 .26833 .48121 .25582 .47199 .24361 Mtetra
.745 .744 .85 r
.47199 .24361 .48121 .25582 .49768 .24487 .48853 .23298 Mtetra
.728 .746 .866 r
.48853 .23298 .49768 .24487 .51419 .23523 .50511 .22356 Mtetra
.712 .747 .879 r
.50511 .22356 .51419 .23523 .53077 .22663 .52176 .21509 Mtetra
.698 .746 .888 r
.52176 .21509 .53077 .22663 .54742 .21881 .53848 .20734 Mtetra
.687 .745 .895 r
.53848 .20734 .54742 .21881 .56416 .21156 .55529 .20011 Mtetra
.679 .744 .9 r
.55529 .20011 .56416 .21156 .581 .20469 .5722 .19324 Mtetra
.673 .743 .903 r
.5722 .19324 .581 .20469 .59794 .19808 .58921 .18659 Mtetra
.67 .743 .905 r
.58921 .18659 .59794 .19808 .61498 .19161 .60633 .18007 Mtetra
.667 .742 .906 r
.60633 .18007 .61498 .19161 .63213 .18523 .62355 .17363 Mtetra
.666 .742 .907 r
.62355 .17363 .63213 .18523 .64939 .17887 .64087 .16721 Mtetra
.665 .742 .907 r
.64087 .16721 .64939 .17887 .66675 .17253 .65831 .1608 Mtetra
.664 .741 .908 r
.65831 .1608 .66675 .17253 .68422 .16617 .67586 .15437 Mtetra
.67586 .15437 .68422 .16617 .7018 .15978 .69351 .14791 Mtetra
.69351 .14791 .7018 .15978 .71949 .15336 .71128 .14141 Mtetra
.71128 .14141 .71949 .15336 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Mtetra
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Mtetra
.267 .508 .9 r
.12035 .37293 .13058 .38558 .14392 .3908 .13379 .37717 Mtetra
.202 .45 .873 r
.13379 .37717 .14392 .3908 .15724 .39762 .14723 .38288 Mtetra
.167 .406 .848 r
.14723 .38288 .15724 .39762 .17061 .40573 .16071 .38974 Mtetra
.17 .386 .831 r
.16071 .38974 .17061 .40573 .18411 .41456 .17432 .39726 Mtetra
.213 .391 .823 r
.17432 .39726 .18411 .41456 .19782 .42336 .18813 .40473 Mtetra
.287 .417 .819 r
.18813 .40473 .19782 .42336 .21184 .43122 .20223 .41134 Mtetra
.378 .455 .813 r
.20223 .41134 .21184 .43122 .22624 .43717 .2167 .4162 Mtetra
.469 .495 .803 r
.2167 .4162 .22624 .43717 .24108 .44026 .23158 .41846 Mtetra
.549 .533 .789 r
.23158 .41846 .24108 .44026 .25639 .43975 .24691 .41744 Mtetra
.614 .564 .774 r
.24691 .41744 .25639 .43975 .27215 .43519 .26268 .41273 Mtetra
.666 .59 .761 r
.26268 .41273 .27215 .43519 .28832 .42648 .27883 .40425 Mtetra
.705 .612 .75 r
.27883 .40425 .28832 .42648 .30481 .4139 .2953 .39225 Mtetra
.735 .63 .742 r
.2953 .39225 .30481 .4139 .32153 .39808 .31199 .3773 Mtetra
.757 .646 .739 r
.31199 .3773 .32153 .39808 .33838 .37989 .32883 .36018 Mtetra
.773 .661 .739 r
.32883 .36018 .33838 .37989 .35528 .36028 .34572 .34176 Mtetra
.783 .675 .744 r
.34572 .34176 .35528 .36028 .37216 .34023 .3626 .32292 Mtetra
.789 .688 .752 r
.3626 .32292 .37216 .34023 .38898 .32057 .37943 .30443 Mtetra
.791 .7 .765 r
.37943 .30443 .38898 .32057 .40571 .30195 .39619 .28687 Mtetra
.788 .712 .78 r
.39619 .28687 .40571 .30195 .42235 .28481 .41288 .27064 Mtetra
.78 .722 .798 r
.41288 .27064 .42235 .28481 .43893 .26937 .4295 .25596 Mtetra
.769 .731 .817 r
.4295 .25596 .43893 .26937 .45547 .25567 .4461 .24286 Mtetra
.755 .738 .836 r
.4461 .24286 .45547 .25567 .47199 .24361 .46268 .23125 Mtetra
.739 .742 .854 r
.46268 .23125 .47199 .24361 .48853 .23298 .47929 .22096 Mtetra
.723 .744 .869 r
.47929 .22096 .48853 .23298 .50511 .22356 .49594 .21176 Mtetra
.708 .745 .881 r
.49594 .21176 .50511 .22356 .52176 .21509 .51265 .20342 Mtetra
.696 .745 .89 r
.51265 .20342 .52176 .21509 .53848 .20734 .52944 .19575 Mtetra
.685 .744 .896 r
.52944 .19575 .53848 .20734 .55529 .20011 .54633 .18854 Mtetra
.678 .744 .9 r
.54633 .18854 .55529 .20011 .5722 .19324 .5633 .18165 Mtetra
.673 .743 .903 r
.5633 .18165 .5722 .19324 .58921 .18659 .58039 .17497 Mtetra
.669 .742 .905 r
.58039 .17497 .58921 .18659 .60633 .18007 .59757 .1684 Mtetra
.667 .742 .906 r
.59757 .1684 .60633 .18007 .62355 .17363 .61486 .1619 Mtetra
.665 .742 .907 r
.61486 .1619 .62355 .17363 .64087 .16721 .63227 .15542 Mtetra
.63227 .15542 .64087 .16721 .65831 .1608 .64978 .14893 Mtetra
.664 .741 .908 r
.64978 .14893 .65831 .1608 .67586 .15437 .6674 .14243 Mtetra
.6674 .14243 .67586 .15437 .69351 .14791 .68513 .1359 Mtetra
.68513 .1359 .69351 .14791 .71128 .14141 .70297 .12933 Mtetra
.70297 .12933 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.324 .539 .907 r
.11003 .36018 .12035 .37293 .13379 .37717 .12358 .36347 Mtetra
.269 .49 .886 r
.12358 .36347 .13379 .37717 .14723 .38288 .13714 .36806 Mtetra
.238 .45 .865 r
.13714 .36806 .14723 .38288 .16071 .38974 .15074 .37369 Mtetra
.24 .429 .847 r
.15074 .37369 .16071 .38974 .17432 .39726 .16446 .37991 Mtetra
.274 .429 .835 r
.16446 .37991 .17432 .39726 .18813 .40473 .17838 .38607 Mtetra
.336 .446 .826 r
.17838 .38607 .18813 .40473 .20223 .41134 .19257 .39145 Mtetra
.411 .475 .816 r
.19257 .39145 .20223 .41134 .2167 .4162 .2071 .39523 Mtetra
.488 .507 .803 r
.2071 .39523 .2167 .4162 .23158 .41846 .22204 .39666 Mtetra
.557 .538 .789 r
.22204 .39666 .23158 .41846 .24691 .41744 .23739 .39514 Mtetra
.616 .565 .775 r
.23739 .39514 .24691 .41744 .26268 .41273 .25316 .39029 Mtetra
.662 .589 .762 r
.25316 .39029 .26268 .41273 .27883 .40425 .2693 .38203 Mtetra
.699 .609 .753 r
.2693 .38203 .27883 .40425 .2953 .39225 .28574 .3706 Mtetra
.728 .627 .746 r
.28574 .3706 .2953 .39225 .31199 .3773 .30241 .35651 Mtetra
.749 .643 .744 r
.30241 .35651 .31199 .3773 .32883 .36018 .31922 .34044 Mtetra
.764 .658 .745 r
.31922 .34044 .32883 .36018 .34572 .34176 .33609 .32319 Mtetra
.775 .672 .75 r
.33609 .32319 .34572 .34176 .3626 .32292 .35297 .30554 Mtetra
.781 .686 .759 r
.35297 .30554 .3626 .32292 .37943 .30443 .36981 .28819 Mtetra
.782 .698 .771 r
.36981 .28819 .37943 .30443 .39619 .28687 .38659 .27168 Mtetra
.779 .71 .787 r
.38659 .27168 .39619 .28687 .41288 .27064 .40331 .25636 Mtetra
.772 .72 .804 r
.40331 .25636 .41288 .27064 .4295 .25596 .41998 .24244 Mtetra
.761 .729 .823 r
.41998 .24244 .4295 .25596 .4461 .24286 .43663 .22994 Mtetra
.748 .736 .841 r
.43663 .22994 .4461 .24286 .46268 .23125 .45328 .21878 Mtetra
.733 .74 .857 r
.45328 .21878 .46268 .23125 .47929 .22096 .46995 .20881 Mtetra
.718 .743 .871 r
.46995 .20881 .47929 .22096 .49594 .21176 .48666 .19983 Mtetra
.704 .744 .882 r
.48666 .19983 .49594 .21176 .51265 .20342 .50344 .19163 Mtetra
.693 .744 .891 r
.50344 .19163 .51265 .20342 .52944 .19575 .52031 .18402 Mtetra
.683 .744 .897 r
.52031 .18402 .52944 .19575 .54633 .18854 .53726 .17683 Mtetra
.677 .743 .901 r
.53726 .17683 .54633 .18854 .5633 .18165 .55431 .16993 Mtetra
.672 .743 .904 r
.55431 .16993 .5633 .18165 .58039 .17497 .57146 .16321 Mtetra
.669 .742 .905 r
.57146 .16321 .58039 .17497 .59757 .1684 .58872 .1566 Mtetra
.666 .742 .906 r
.58872 .1566 .59757 .1684 .61486 .1619 .60608 .15004 Mtetra
.665 .742 .907 r
.60608 .15004 .61486 .1619 .63227 .15542 .62356 .14349 Mtetra
.664 .741 .907 r
.62356 .14349 .63227 .15542 .64978 .14893 .64114 .13693 Mtetra
.664 .741 .908 r
.64114 .13693 .64978 .14893 .6674 .14243 .65884 .13035 Mtetra
.65884 .13035 .6674 .14243 .68513 .1359 .67665 .12375 Mtetra
.67665 .12375 .68513 .1359 .70297 .12933 .69457 .1171 Mtetra
.69457 .1171 .70297 .12933 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.374 .567 .912 r
.0996 .3474 .11003 .36018 .12358 .36347 .11328 .34974 Mtetra
.328 .524 .895 r
.11328 .34974 .12358 .36347 .13714 .36806 .12695 .35325 Mtetra
.301 .489 .876 r
.12695 .35325 .13714 .36806 .15074 .37369 .14068 .35768 Mtetra
.301 .467 .859 r
.14068 .35768 .15074 .37369 .16446 .37991 .15452 .36262 Mtetra
.328 .463 .844 r
.15452 .36262 .16446 .37991 .17838 .38607 .16855 .36751 Mtetra
.378 .474 .832 r
.16855 .36751 .17838 .38607 .19257 .39145 .18283 .37168 Mtetra
.44 .494 .819 r
.18283 .37168 .19257 .39145 .2071 .39523 .19745 .37442 Mtetra
.505 .519 .805 r
.19745 .37442 .2071 .39523 .22204 .39666 .21243 .37505 Mtetra
.565 .545 .791 r
.21243 .37505 .22204 .39666 .23739 .39514 .22781 .37303 Mtetra
.617 .569 .777 r
.22781 .37303 .23739 .39514 .25316 .39029 .24358 .36804 Mtetra
.66 .59 .766 r
.24358 .36804 .25316 .39029 .2693 .38203 .25971 .36 Mtetra
.694 .609 .757 r
.25971 .36 .2693 .38203 .28574 .3706 .27613 .34911 Mtetra
.721 .626 .751 r
.27613 .34911 .28574 .3706 .30241 .35651 .29276 .33584 Mtetra
.741 .642 .75 r
.29276 .33584 .30241 .35651 .31922 .34044 .30955 .32079 Mtetra
.756 .657 .751 r
.30955 .32079 .31922 .34044 .33609 .32319 .3264 .30467 Mtetra
.767 .671 .757 r
.3264 .30467 .33609 .32319 .35297 .30554 .34326 .28818 Mtetra
.772 .684 .766 r
.34326 .28818 .35297 .30554 .36981 .28819 .36011 .27195 Mtetra
.773 .697 .779 r
.36011 .27195 .36981 .28819 .38659 .27168 .3769 .25646 Mtetra
.771 .709 .794 r
.3769 .25646 .38659 .27168 .40331 .25636 .39366 .24203 Mtetra
.764 .719 .811 r
.39366 .24203 .40331 .25636 .41998 .24244 .41037 .22884 Mtetra
.754 .728 .829 r
.41037 .22884 .41998 .24244 .43663 .22994 .42707 .21692 Mtetra
.741 .735 .846 r
.42707 .21692 .43663 .22994 .45328 .21878 .44377 .2062 Mtetra
.727 .739 .861 r
.44377 .2062 .45328 .21878 .46995 .20881 .4605 .19655 Mtetra
.713 .742 .874 r
.4605 .19655 .46995 .20881 .48666 .19983 .47728 .18778 Mtetra
.701 .743 .884 r
.47728 .18778 .48666 .19983 .50344 .19163 .49413 .17971 Mtetra
.69 .743 .892 r
.49413 .17971 .50344 .19163 .52031 .18402 .51106 .17216 Mtetra
.681 .743 .898 r
.51106 .17216 .52031 .18402 .53726 .17683 .52809 .165 Mtetra
.675 .743 .902 r
.52809 .165 .53726 .17683 .55431 .16993 .54521 .15808 Mtetra
.671 .742 .904 r
.54521 .15808 .55431 .16993 .57146 .16321 .56243 .15133 Mtetra
.668 .742 .906 r
.56243 .15133 .57146 .16321 .58872 .1566 .57976 .14466 Mtetra
.666 .742 .907 r
.57976 .14466 .58872 .1566 .60608 .15004 .5972 .13803 Mtetra
.665 .742 .907 r
.5972 .13803 .60608 .15004 .62356 .14349 .61475 .13142 Mtetra
.664 .741 .908 r
.61475 .13142 .62356 .14349 .64114 .13693 .63241 .12479 Mtetra
.63241 .12479 .64114 .13693 .65884 .13035 .65018 .11814 Mtetra
.65018 .11814 .65884 .13035 .67665 .12375 .66806 .11145 Mtetra
.66806 .11145 .67665 .12375 .69457 .1171 .68606 .10473 Mtetra
.68606 .10473 .69457 .1171 .7126 .11041 .70418 .09796 Mtetra
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.417 .591 .915 r
.08907 .33461 .0996 .3474 .11328 .34974 .10286 .33604 Mtetra
.379 .554 .9 r
.10286 .33604 .11328 .34974 .12695 .35325 .11666 .3385 Mtetra
.355 .522 .884 r
.11666 .3385 .12695 .35325 .14068 .35768 .13052 .34178 Mtetra
.354 .501 .867 r
.13052 .34178 .14068 .35768 .15452 .36262 .14448 .34549 Mtetra
.375 .494 .852 r
.14448 .34549 .15452 .36262 .16855 .36751 .15863 .34916 Mtetra
.415 .499 .837 r
.15863 .34916 .16855 .36751 .18283 .37168 .17301 .35217 Mtetra
.466 .513 .823 r
.17301 .35217 .18283 .37168 .19745 .37442 .1877 .3539 Mtetra
.521 .532 .808 r
.1877 .3539 .19745 .37442 .21243 .37505 .20274 .35376 Mtetra
.573 .553 .794 r
.20274 .35376 .21243 .37505 .22781 .37303 .21815 .35127 Mtetra
.619 .574 .781 r
.21815 .35127 .22781 .37303 .24358 .36804 .23393 .34613 Mtetra
.658 .593 .77 r
.23393 .34613 .24358 .36804 .25971 .36 .25004 .33829 Mtetra
.69 .61 .762 r
.25004 .33829 .25971 .36 .27613 .34911 .26644 .32793 Mtetra
.715 .627 .758 r
.26644 .32793 .27613 .34911 .29276 .33584 .28304 .31543 Mtetra
.734 .642 .756 r
.28304 .31543 .29276 .33584 .30955 .32079 .29979 .30135 Mtetra
.749 .656 .759 r
.29979 .30135 .30955 .32079 .3264 .30467 .31662 .28632 Mtetra
.758 .67 .765 r
.31662 .28632 .3264 .30467 .34326 .28818 .33347 .27094 Mtetra
.764 .684 .774 r
.33347 .27094 .34326 .28818 .36011 .27195 .35032 .25577 Mtetra
.765 .697 .786 r
.35032 .25577 .36011 .27195 .3769 .25646 .36713 .24126 Mtetra
.762 .708 .801 r
.36713 .24126 .3769 .25646 .39366 .24203 .38391 .22768 Mtetra
.756 .719 .818 r
.38391 .22768 .39366 .24203 .41037 .22884 .40066 .21519 Mtetra
.746 .727 .835 r
.40066 .21519 .41037 .22884 .42707 .21692 .41741 .20383 Mtetra
.734 .734 .851 r
.41741 .20383 .42707 .21692 .44377 .2062 .43416 .19354 Mtetra
.721 .738 .865 r
.43416 .19354 .44377 .2062 .4605 .19655 .45096 .18419 Mtetra
.708 .741 .877 r
.45096 .18419 .4605 .19655 .47728 .18778 .4678 .17562 Mtetra
.697 .742 .886 r
.4678 .17562 .47728 .18778 .49413 .17971 .48472 .16767 Mtetra
.687 .743 .894 r
.48472 .16767 .49413 .17971 .51106 .17216 .50172 .16018 Mtetra
.68 .743 .899 r
.50172 .16018 .51106 .17216 .52809 .165 .51881 .15303 Mtetra
.674 .742 .902 r
.51881 .15303 .52809 .165 .54521 .15808 .536 .1461 Mtetra
.67 .742 .904 r
.536 .1461 .54521 .15808 .56243 .15133 .5533 .1393 Mtetra
.668 .742 .906 r
.5533 .1393 .56243 .15133 .57976 .14466 .5707 .13258 Mtetra
.666 .742 .907 r
.5707 .13258 .57976 .14466 .5972 .13803 .58821 .12589 Mtetra
.665 .742 .907 r
.58821 .12589 .5972 .13803 .61475 .13142 .60583 .11921 Mtetra
.664 .741 .908 r
.60583 .11921 .61475 .13142 .63241 .12479 .62357 .11251 Mtetra
.62357 .11251 .63241 .12479 .65018 .11814 .64142 .10578 Mtetra
.64142 .10578 .65018 .11814 .66806 .11145 .65938 .09901 Mtetra
.65938 .09901 .66806 .11145 .68606 .10473 .67746 .09221 Mtetra
.67746 .09221 .68606 .10473 .70418 .09796 .69565 .08537 Mtetra
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.455 .612 .915 r
.07843 .32184 .08907 .33461 .10286 .33604 .09234 .3224 Mtetra
.423 .58 .904 r
.09234 .3224 .10286 .33604 .11666 .3385 .10627 .32387 Mtetra
.402 .551 .889 r
.10627 .32387 .11666 .3385 .13052 .34178 .12025 .32604 Mtetra
.399 .531 .873 r
.12025 .32604 .13052 .34178 .14448 .34549 .13434 .3286 Mtetra
.415 .522 .858 r
.13434 .3286 .14448 .34549 .15863 .34916 .1486 .3311 Mtetra
.447 .522 .842 r
.1486 .3311 .15863 .34916 .17301 .35217 .16309 .33302 Mtetra
.489 .532 .827 r
.16309 .33302 .17301 .35217 .1877 .3539 .17786 .3338 Mtetra
.536 .546 .812 r
.17786 .3338 .1877 .3539 .20274 .35376 .19296 .33293 Mtetra
.581 .563 .798 r
.19296 .33293 .20274 .35376 .21815 .35127 .2084 .32998 Mtetra
.622 .58 .786 r
.2084 .32998 .21815 .35127 .23393 .34613 .22419 .3247 Mtetra
.657 .597 .776 r
.22419 .3247 .23393 .34613 .25004 .33829 .24029 .31705 Mtetra
.686 .613 .769 r
.24029 .31705 .25004 .33829 .26644 .32793 .25666 .30716 Mtetra
.709 .628 .765 r
.25666 .30716 .26644 .32793 .28304 .31543 .27323 .2954 Mtetra
.728 .643 .764 r
.27323 .2954 .28304 .31543 .29979 .30135 .28995 .28223 Mtetra
.741 .657 .767 r
.28995 .28223 .29979 .30135 .31662 .28632 .30675 .26821 Mtetra
.751 .671 .773 r
.30675 .26821 .31662 .28632 .33347 .27094 .32359 .25387 Mtetra
.756 .684 .783 r
.32359 .25387 .33347 .27094 .35032 .25577 .34043 .23972 Mtetra
.757 .697 .795 r
.34043 .23972 .35032 .25577 .36713 .24126 .35726 .22612 Mtetra
.754 .708 .809 r
.35726 .22612 .36713 .24126 .38391 .22768 .37406 .21334 Mtetra
.747 .718 .825 r
.37406 .21334 .38391 .22768 .40066 .21519 .39085 .20152 Mtetra
.738 .727 .841 r
.39085 .20152 .40066 .21519 .41741 .20383 .40764 .19069 Mtetra
.727 .733 .856 r
.40764 .19069 .41741 .20383 .43416 .19354 .42445 .1808 Mtetra
.715 .737 .869 r
.42445 .1808 .43416 .19354 .45096 .18419 .44131 .17173 Mtetra
.703 .74 .88 r
.44131 .17173 .45096 .18419 .4678 .17562 .45822 .16335 Mtetra
.693 .742 .888 r
.45822 .16335 .4678 .17562 .48472 .16767 .4752 .15551 Mtetra
.684 .742 .895 r
.4752 .15551 .48472 .16767 .50172 .16018 .49227 .14808 Mtetra
.678 .742 .899 r
.49227 .14808 .50172 .16018 .51881 .15303 .50943 .14094 Mtetra
.673 .742 .903 r
.50943 .14094 .51881 .15303 .536 .1461 .52669 .13398 Mtetra
.669 .742 .905 r
.52669 .13398 .536 .1461 .5533 .1393 .54406 .12714 Mtetra
.667 .742 .906 r
.54406 .12714 .5533 .1393 .5707 .13258 .56153 .12037 Mtetra
.666 .742 .907 r
.56153 .12037 .5707 .13258 .58821 .12589 .57912 .11361 Mtetra
.665 .741 .907 r
.57912 .11361 .58821 .12589 .60583 .11921 .59682 .10685 Mtetra
.664 .741 .908 r
.59682 .10685 .60583 .11921 .62357 .11251 .61463 .10008 Mtetra
.61463 .10008 .62357 .11251 .64142 .10578 .63255 .09327 Mtetra
.63255 .09327 .64142 .10578 .65938 .09901 .6506 .08643 Mtetra
.6506 .08643 .65938 .09901 .67746 .09221 .66875 .07955 Mtetra
.66875 .07955 .67746 .09221 .69565 .08537 .68703 .07262 Mtetra
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05864 Mtetra
.488 .63 .915 r
.06766 .30913 .07843 .32184 .09234 .3224 .08169 .30887 Mtetra
.46 .602 .906 r
.08169 .30887 .09234 .3224 .10627 .32387 .09575 .3094 Mtetra
.443 .577 .893 r
.09575 .3094 .10627 .32387 .12025 .32604 .10986 .31053 Mtetra
.439 .558 .878 r
.10986 .31053 .12025 .32604 .13434 .3286 .12407 .312 Mtetra
.451 .547 .863 r
.12407 .312 .13434 .3286 .1486 .3311 .13845 .3134 Mtetra
.476 .545 .847 r
.13845 .3134 .1486 .3311 .16309 .33302 .15304 .31429 Mtetra
.511 .55 .832 r
.15304 .31429 .16309 .33302 .17786 .3338 .1679 .31419 Mtetra
.55 .56 .818 r
.1679 .31419 .17786 .3338 .19296 .33293 .18306 .31263 Mtetra
.588 .573 .804 r
.18306 .31263 .19296 .33293 .2084 .32998 .19854 .30925 Mtetra
.624 .588 .792 r
.19854 .30925 .2084 .32998 .22419 .3247 .21433 .30384 Mtetra
.656 .603 .783 r
.21433 .30384 .22419 .3247 .24029 .31705 .23043 .29634 Mtetra
.683 .617 .776 r
.23043 .29634 .24029 .31705 .25666 .30716 .24678 .2869 Mtetra
.705 .632 .773 r
.24678 .2869 .25666 .30716 .27323 .2954 .26332 .27581 Mtetra
.722 .646 .773 r
.26332 .27581 .27323 .2954 .28995 .28223 .28001 .26349 Mtetra
.734 .659 .776 r
.28001 .26349 .28995 .28223 .30675 .26821 .29679 .25041 Mtetra
.743 .673 .782 r
.29679 .25041 .30675 .26821 .32359 .25387 .31361 .23704 Mtetra
.748 .686 .792 r
.31361 .23704 .32359 .25387 .34043 .23972 .33045 .22383 Mtetra
.748 .698 .803 r
.33045 .22383 .34043 .23972 .35726 .22612 .34728 .21109 Mtetra
.745 .709 .817 r
.34728 .21109 .35726 .22612 .37406 .21334 .36411 .19906 Mtetra
.739 .719 .832 r
.36411 .19906 .37406 .21334 .39085 .20152 .38093 .18786 Mtetra
.731 .727 .847 r
.38093 .18786 .39085 .20152 .40764 .19069 .39777 .17752 Mtetra
.72 .733 .861 r
.39777 .17752 .40764 .19069 .42445 .1808 .41464 .16799 Mtetra
.709 .737 .873 r
.41464 .16799 .42445 .1808 .44131 .17173 .43155 .15918 Mtetra
.699 .739 .883 r
.43155 .15918 .44131 .17173 .45822 .16335 .44852 .15097 Mtetra
.69 .741 .89 r
.44852 .15097 .45822 .16335 .4752 .15551 .46557 .14324 Mtetra
.682 .742 .896 r
.46557 .14324 .4752 .15551 .49227 .14808 .4827 .13585 Mtetra
.676 .742 .9 r
.4827 .13585 .49227 .14808 .50943 .14094 .49994 .12871 Mtetra
.672 .742 .903 r
.49994 .12871 .50943 .14094 .52669 .13398 .51727 .12173 Mtetra
.669 .742 .905 r
.51727 .12173 .52669 .13398 .54406 .12714 .53471 .11484 Mtetra
.667 .742 .906 r
.53471 .11484 .54406 .12714 .56153 .12037 .55226 .10801 Mtetra
.665 .742 .907 r
.55226 .10801 .56153 .12037 .57912 .11361 .56992 .10119 Mtetra
.665 .741 .907 r
.56992 .10119 .57912 .11361 .59682 .10685 .58769 .09436 Mtetra
.664 .741 .908 r
.58769 .09436 .59682 .10685 .61463 .10008 .60558 .0875 Mtetra
.60558 .0875 .61463 .10008 .63255 .09327 .62358 .08062 Mtetra
.62358 .08062 .63255 .09327 .6506 .08643 .6417 .07369 Mtetra
.6417 .07369 .6506 .08643 .66875 .07955 .65994 .06673 Mtetra
.65994 .06673 .66875 .07955 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05864 .71537 .04556 Mtetra
.516 .646 .915 r
.05677 .29648 .06766 .30913 .08169 .30887 .07092 .29545 Mtetra
.493 .622 .907 r
.07092 .29545 .08169 .30887 .09575 .3094 .08509 .29511 Mtetra
.478 .6 .896 r
.08509 .29511 .09575 .3094 .10986 .31053 .09933 .29528 Mtetra
.474 .582 .882 r
.09933 .29528 .10986 .31053 .12407 .312 .11367 .29573 Mtetra
.482 .57 .868 r
.11367 .29573 .12407 .312 .13845 .3134 .12817 .29612 Mtetra
.502 .566 .853 r
.12817 .29612 .13845 .3134 .15304 .31429 .14286 .29606 Mtetra
.53 .568 .838 r
.14286 .29606 .15304 .31429 .1679 .31419 .1578 .29512 Mtetra
.562 .574 .823 r
.1578 .29512 .1679 .31419 .18306 .31263 .17302 .29293 Mtetra
.596 .585 .81 r
.17302 .29293 .18306 .31263 .19854 .30925 .18854 .28915 Mtetra
.627 .597 .799 r
.18854 .28915 .19854 .30925 .21433 .30384 .20436 .28361 Mtetra
.656 .609 .791 r
.20436 .28361 .21433 .30384 .23043 .29634 .22045 .27626 Mtetra
.68 .623 .785 r
.22045 .27626 .23043 .29634 .24678 .2869 .23678 .26721 Mtetra
.7 .636 .782 r
.23678 .26721 .24678 .2869 .26332 .27581 .2533 .25673 Mtetra
.716 .649 .782 r
.2533 .25673 .26332 .27581 .28001 .26349 .26996 .24518 Mtetra
.728 .662 .785 r
.26996 .24518 .28001 .26349 .29679 .25041 .28672 .23296 Mtetra
.736 .675 .792 r
.28672 .23296 .29679 .25041 .31361 .23704 .30352 .22049 Mtetra
.74 .688 .801 r
.30352 .22049 .31361 .23704 .33045 .22383 .32036 .20813 Mtetra
.74 .699 .812 r
.32036 .20813 .33045 .22383 .34728 .21109 .3372 .19618 Mtetra
.737 .71 .825 r
.3372 .19618 .34728 .21109 .36411 .19906 .35405 .18483 Mtetra
.732 .719 .839 r
.35405 .18483 .36411 .19906 .38093 .18786 .37091 .1742 Mtetra
.723 .727 .853 r
.37091 .1742 .38093 .18786 .39777 .17752 .38779 .16431 Mtetra
.714 .732 .865 r
.38779 .16431 .39777 .17752 .41464 .16799 .40471 .15512 Mtetra
.704 .737 .876 r
.40471 .15512 .41464 .16799 .43155 .15918 .42168 .14655 Mtetra
.695 .739 .885 r
.42168 .14655 .43155 .15918 .44852 .15097 .43871 .1385 Mtetra
.686 .741 .892 r
.43871 .1385 .44852 .15097 .46557 .14324 .45583 .13084 Mtetra
.68 .741 .897 r
.45583 .13084 .46557 .14324 .4827 .13585 .47303 .12349 Mtetra
.674 .742 .901 r
.47303 .12349 .4827 .13585 .49994 .12871 .49033 .11635 Mtetra
.671 .742 .904 r
.49033 .11635 .49994 .12871 .51727 .12173 .50774 .10934 Mtetra
.668 .742 .905 r
.50774 .10934 .51727 .12173 .53471 .11484 .52525 .1024 Mtetra
.666 .742 .906 r
.52525 .1024 .53471 .11484 .55226 .10801 .54288 .09551 Mtetra
.665 .741 .907 r
.54288 .09551 .55226 .10801 .56992 .10119 .56061 .08861 Mtetra
.664 .741 .907 r
.56061 .08861 .56992 .10119 .58769 .09436 .57846 .08171 Mtetra
.664 .741 .908 r
.57846 .08171 .58769 .09436 .60558 .0875 .59643 .07478 Mtetra
.59643 .07478 .60558 .0875 .62358 .08062 .61451 .06781 Mtetra
.61451 .06781 .62358 .08062 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06673 .65103 .05375 Mtetra
.65103 .05375 .65994 .06673 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Mtetra
.54 .66 .914 r
.04575 .2839 .05677 .29648 .07092 .29545 .06001 .28217 Mtetra
.521 .639 .907 r
.06001 .28217 .07092 .29545 .08509 .29511 .07431 .28102 Mtetra
.508 .619 .897 r
.07431 .28102 .08509 .29511 .09933 .29528 .08867 .28031 Mtetra
.503 .603 .885 r
.08867 .28031 .09933 .29528 .11367 .29573 .10313 .27982 Mtetra
.509 .591 .872 r
.10313 .27982 .11367 .29573 .12817 .29612 .11774 .27928 Mtetra
.525 .585 .858 r
.11774 .27928 .12817 .29612 .14286 .29606 .13254 .27834 Mtetra
.547 .585 .844 r
.13254 .27834 .14286 .29606 .1578 .29512 .14757 .27665 Mtetra
.575 .589 .83 r
.14757 .27665 .1578 .29512 .17302 .29293 .16285 .27386 Mtetra
.603 .597 .818 r
.16285 .27386 .17302 .29293 .18854 .28915 .17841 .26972 Mtetra
.631 .606 .807 r
.17841 .26972 .18854 .28915 .20436 .28361 .19424 .26405 Mtetra
.656 .617 .799 r
.19424 .26405 .20436 .28361 .22045 .27626 .21034 .25682 Mtetra
.678 .629 .794 r
.21034 .25682 .22045 .27626 .23678 .26721 .22665 .24813 Mtetra
.696 .642 .791 r
.22665 .24813 .23678 .26721 .2533 .25673 .24315 .2382 Mtetra
.71 .654 .792 r
.24315 .2382 .2533 .25673 .26996 .24518 .25979 .22734 Mtetra
.721 .666 .795 r
.25979 .22734 .26996 .24518 .28672 .23296 .27653 .2159 Mtetra
.728 .679 .802 r
.27653 .2159 .28672 .23296 .30352 .22049 .29332 .20423 Mtetra
.732 .69 .811 r
.29332 .20423 .30352 .22049 .32036 .20813 .31016 .19265 Mtetra
.732 .702 .821 r
.31016 .19265 .32036 .20813 .3372 .19618 .32701 .18141 Mtetra
.73 .712 .834 r
.32701 .18141 .3372 .19618 .35405 .18483 .34388 .17069 Mtetra
.724 .72 .846 r
.34388 .17069 .35405 .18483 .37091 .1742 .36078 .16057 Mtetra
.716 .727 .859 r
.36078 .16057 .37091 .1742 .38779 .16431 .3777 .15109 Mtetra
.708 .733 .87 r
.3777 .15109 .38779 .16431 .40471 .15512 .39467 .1422 Mtetra
.699 .736 .88 r
.39467 .1422 .40471 .15512 .42168 .14655 .4117 .13384 Mtetra
.691 .739 .888 r
.4117 .13384 .42168 .14655 .43871 .1385 .42879 .12592 Mtetra
.683 .74 .894 r
.42879 .12592 .43871 .1385 .45583 .13084 .44598 .11834 Mtetra
.677 .741 .899 r
.44598 .11834 .45583 .13084 .47303 .12349 .46325 .11101 Mtetra
.673 .741 .902 r
.46325 .11101 .47303 .12349 .49033 .11635 .48062 .10385 Mtetra
.67 .741 .904 r
.48062 .10385 .49033 .11635 .50774 .10934 .4981 .0968 Mtetra
.667 .741 .906 r
.4981 .0968 .50774 .10934 .52525 .1024 .51568 .08982 Mtetra
.666 .741 .907 r
.51568 .08982 .52525 .1024 .54288 .09551 .53338 .08286 Mtetra
.665 .741 .907 r
.53338 .08286 .54288 .09551 .56061 .08861 .55119 .07589 Mtetra
.664 .741 .907 r
.55119 .07589 .56061 .08861 .57846 .08171 .56912 .06891 Mtetra
.664 .741 .908 r
.56912 .06891 .57846 .08171 .59643 .07478 .58716 .0619 Mtetra
.58716 .0619 .59643 .07478 .61451 .06781 .60532 .05485 Mtetra
.60532 .05485 .61451 .06781 .63271 .0608 .6236 .04776 Mtetra
.6236 .04776 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.56 .672 .913 r
.03458 .2714 .04575 .2839 .06001 .28217 .04896 .26903 Mtetra
.544 .654 .907 r
.04896 .26903 .06001 .28217 .07431 .28102 .06337 .26714 Mtetra
.533 .637 .899 r
.06337 .26714 .07431 .28102 .08867 .28031 .07786 .26562 Mtetra
.529 .622 .888 r
.07786 .26562 .08867 .28031 .10313 .27982 .09244 .26429 Mtetra
.533 .61 .876 r
.09244 .26429 .10313 .27982 .11774 .27928 .10716 .2629 Mtetra
.545 .604 .863 r
.10716 .2629 .11774 .27928 .13254 .27834 .12206 .26116 Mtetra
.563 .602 .85 r
.12206 .26116 .13254 .27834 .14757 .27665 .13717 .25877 Mtetra
.586 .604 .837 r
.13717 .25877 .14757 .27665 .16285 .27386 .15252 .25545 Mtetra
.61 .609 .825 r
.15252 .25545 .16285 .27386 .17841 .26972 .16813 .25096 Mtetra
.634 .617 .816 r
.16813 .25096 .17841 .26972 .19424 .26405 .18398 .24517 Mtetra
.656 .626 .808 r
.18398 .24517 .19424 .26405 .21034 .25682 .20008 .23804 Mtetra
.676 .637 .803 r
.20008 .23804 .21034 .25682 .22665 .24813 .21639 .22966 Mtetra
.692 .648 .801 r
.21639 .22966 .22665 .24813 .24315 .2382 .23287 .22022 Mtetra
.705 .659 .802 r
.23287 .22022 .24315 .2382 .25979 .22734 .24949 .20998 Mtetra
.715 .671 .806 r
.24949 .20998 .25979 .22734 .27653 .2159 .26621 .19923 Mtetra
.722 .683 .812 r
.26621 .19923 .27653 .2159 .29332 .20423 .283 .18828 Mtetra
.725 .694 .82 r
.283 .18828 .29332 .20423 .31016 .19265 .29983 .1774 Mtetra
.725 .704 .83 r
.29983 .1774 .31016 .19265 .32701 .18141 .3167 .1668 Mtetra
.722 .714 .842 r
.3167 .1668 .32701 .18141 .34388 .17069 .3336 .15663 Mtetra
.717 .722 .853 r
.3336 .15663 .34388 .17069 .36078 .16057 .35053 .14697 Mtetra
.71 .728 .865 r
.35053 .14697 .36078 .16057 .3777 .15109 .3675 .13784 Mtetra
.702 .733 .875 r
.3675 .13784 .3777 .15109 .39467 .1422 .38452 .12922 Mtetra
.694 .736 .883 r
.38452 .12922 .39467 .1422 .4117 .13384 .4016 .12104 Mtetra
.687 .739 .89 r
.4016 .12104 .4117 .13384 .42879 .12592 .41876 .11323 Mtetra
.681 .74 .896 r
.41876 .11323 .42879 .12592 .44598 .11834 .43601 .10571 Mtetra
.675 .741 .9 r
.43601 .10571 .44598 .11834 .46325 .11101 .45335 .09839 Mtetra
.672 .741 .903 r
.45335 .09839 .46325 .11101 .48062 .10385 .47079 .09122 Mtetra
.669 .741 .905 r
.47079 .09122 .48062 .10385 .4981 .0968 .48834 .08413 Mtetra
.667 .741 .906 r
.48834 .08413 .4981 .0968 .51568 .08982 .506 .07709 Mtetra
.666 .741 .907 r
.506 .07709 .51568 .08982 .53338 .08286 .52377 .07006 Mtetra
.665 .741 .907 r
.52377 .07006 .53338 .08286 .55119 .07589 .54166 .06302 Mtetra
.664 .741 .908 r
.54166 .06302 .55119 .07589 .56912 .06891 .55966 .05596 Mtetra
.55966 .05596 .56912 .06891 .58716 .0619 .57778 .04886 Mtetra
.57778 .04886 .58716 .0619 .60532 .05485 .59602 .04173 Mtetra
.59602 .04173 .60532 .05485 .6236 .04776 .61438 .03456 Mtetra
.61438 .03456 .6236 .04776 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58845 Mtetra
.663 .741 .908 r
.42372 .58845 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58784 .4504 .5804 Mtetra
.4504 .5804 .45807 .58784 .47147 .58383 .46385 .57635 Mtetra
.46385 .57635 .47147 .58383 .48494 .5798 .47736 .5723 Mtetra
.662 .741 .908 r
.47736 .5723 .48494 .5798 .49847 .57578 .49093 .56824 Mtetra
.662 .741 .909 r
.49093 .56824 .49847 .57578 .51207 .57176 .50458 .56419 Mtetra
.66 .741 .91 r
.50458 .56419 .51207 .57176 .52574 .56777 .51829 .56018 Mtetra
.658 .74 .911 r
.51829 .56018 .52574 .56777 .53948 .56385 .53207 .55623 Mtetra
.654 .74 .913 r
.53207 .55623 .53948 .56385 .55329 .56003 .54593 .55241 Mtetra
.647 .739 .916 r
.54593 .55241 .55329 .56003 .56718 .55638 .55986 .54878 Mtetra
.638 .737 .92 r
.55986 .54878 .56718 .55638 .58114 .55299 .57387 .54544 Mtetra
.624 .735 .927 r
.57387 .54544 .58114 .55299 .59519 .54996 .58797 .54252 Mtetra
.605 .732 .935 r
.58797 .54252 .59519 .54996 .60933 .54742 .60216 .54014 Mtetra
.577 .728 .945 r
.60216 .54014 .60933 .54742 .62358 .54549 .61646 .53847 Mtetra
.538 .721 .958 r
.61646 .53847 .62358 .54549 .63794 .5443 .63088 .53763 Mtetra
.485 .71 .969 r
.63088 .53763 .63794 .5443 .65244 .54392 .64544 .53772 Mtetra
.415 .693 .977 r
.64544 .53772 .65244 .54392 .66707 .54437 .66016 .53879 Mtetra
.327 .668 .975 r
.66016 .53879 .66707 .54437 .68187 .5456 .67504 .54075 Mtetra
.226 .635 .956 r
.67504 .54075 .68187 .5456 .69681 .54743 .69008 .54343 Mtetra
.125 .598 .918 r
.69008 .54343 .69681 .54743 .71191 .54956 .70529 .5465 Mtetra
.045 .568 .867 r
.70529 .5465 .71191 .54956 .72714 .55162 .72064 .54951 Mtetra
.003 .558 .817 r
.72064 .54951 .72714 .55162 .74246 .55312 .73609 .55193 Mtetra
.012 .58 .782 r
.73609 .55193 .74246 .55312 .75786 .55359 .75162 .5532 Mtetra
.075 .636 .772 r
.75162 .5532 .75786 .55359 .77326 .55258 .76716 .5528 Mtetra
.189 .721 .786 r
.76716 .5528 .77326 .55258 .78864 .54978 .78267 .55035 Mtetra
.337 .818 .815 r
.78267 .55035 .78864 .54978 .80396 .545 .79809 .54564 Mtetra
.491 .903 .846 r
.79809 .54564 .80396 .545 .81919 .53827 .8134 .53868 Mtetra
.624 .961 .869 r
.8134 .53868 .81919 .53827 .83431 .52982 .8286 .5297 Mtetra
.722 .987 .883 r
.8286 .5297 .83431 .52982 .84936 .52 .84368 .51912 Mtetra
.784 .989 .891 r
.84368 .51912 .84936 .52 .86435 .50927 .85869 .50746 Mtetra
.816 .975 .896 r
.85869 .50746 .86435 .50927 .87931 .49811 .87366 .49529 Mtetra
.826 .951 .9 r
.87366 .49529 .87931 .49811 .89431 .48699 .88864 .48312 Mtetra
.82 .923 .904 r
.88864 .48312 .89431 .48699 .90937 .47626 .90369 .47139 Mtetra
.805 .894 .907 r
.90369 .47139 .90937 .47626 .92454 .46618 .91885 .46041 Mtetra
.785 .865 .908 r
.91885 .46041 .92454 .46618 .93985 .4569 .93415 .45034 Mtetra
.763 .838 .909 r
.93415 .45034 .93985 .4569 .95531 .44846 .94961 .44124 Mtetra
.741 .815 .91 r
.94961 .44124 .95531 .44846 .97093 .4408 .96524 .43305 Mtetra
.664 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58845 .41589 .58101 Mtetra
.663 .741 .908 r
.41589 .58101 .42372 .58845 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .5804 .44266 .57289 Mtetra
.44266 .57289 .4504 .5804 .46385 .57635 .45615 .56881 Mtetra
.45615 .56881 .46385 .57635 .47736 .5723 .4697 .56472 Mtetra
.662 .741 .908 r
.4697 .56472 .47736 .5723 .49093 .56824 .48332 .56062 Mtetra
.661 .741 .909 r
.48332 .56062 .49093 .56824 .50458 .56419 .49701 .55655 Mtetra
.66 .741 .91 r
.49701 .55655 .50458 .56419 .51829 .56018 .51077 .55251 Mtetra
.657 .74 .911 r
.51077 .55251 .51829 .56018 .53207 .55623 .5246 .54855 Mtetra
.653 .739 .913 r
.5246 .54855 .53207 .55623 .54593 .55241 .5385 .54472 Mtetra
.646 .738 .916 r
.5385 .54472 .54593 .55241 .55986 .54878 .55248 .54111 Mtetra
.635 .736 .921 r
.55248 .54111 .55986 .54878 .57387 .54544 .56653 .53783 Mtetra
.62 .734 .928 r
.56653 .53783 .57387 .54544 .58797 .54252 .58068 .53501 Mtetra
.597 .73 .937 r
.58068 .53501 .58797 .54252 .60216 .54014 .59492 .53281 Mtetra
.565 .723 .948 r
.59492 .53281 .60216 .54014 .61646 .53847 .60927 .5314 Mtetra
.519 .714 .96 r
.60927 .5314 .61646 .53847 .63088 .53763 .62376 .53093 Mtetra
.456 .698 .971 r
.62376 .53093 .63088 .53763 .64544 .53772 .63838 .53153 Mtetra
.371 .673 .975 r
.63838 .53153 .64544 .53772 .66016 .53879 .65317 .53324 Mtetra
.263 .636 .963 r
.65317 .53324 .66016 .53879 .67504 .54075 .66813 .53599 Mtetra
.14 .585 .928 r
.66813 .53599 .67504 .54075 .69008 .54343 .68327 .53958 Mtetra
.02 .53 .868 r
.68327 .53958 .69008 .54343 .70529 .5465 .69859 .54366 Mtetra
0 .484 .795 r
.69859 .54366 .70529 .5465 .72064 .54951 .71407 .54771 Mtetra
0 .465 .73 r
.71407 .54771 .72064 .54951 .73609 .55193 .72966 .55114 Mtetra
.106 0 0 r
.72966 .55114 .73609 .55193 .75162 .5532 .74533 .5533 Mtetra
.035 0 0 r
.74533 .5533 .75162 .5532 .76716 .5528 .76101 .5536 Mtetra
.092 .648 .702 r
.76101 .5536 .76716 .5528 .78267 .55035 .77664 .55156 Mtetra
.261 .765 .744 r
.77664 .55156 .78267 .55035 .79809 .54564 .79218 .54695 Mtetra
.441 .874 .79 r
.79218 .54695 .79809 .54564 .8134 .53868 .80759 .53976 Mtetra
.6 .95 .826 r
.80759 .53976 .8134 .53868 .8286 .5297 .82286 .53024 Mtetra
.717 .988 .85 r
.82286 .53024 .8286 .5297 .84368 .51912 .83798 .51886 Mtetra
.79 .996 .864 r
.83798 .51886 .84368 .51912 .85869 .50746 .85301 .50621 Mtetra
.829 .985 .875 r
.85301 .50621 .85869 .50746 .87366 .49529 .86798 .49294 Mtetra
.843 .964 .883 r
.86798 .49294 .87366 .49529 .88864 .48312 .88295 .47965 Mtetra
.839 .936 .891 r
.88295 .47965 .88864 .48312 .90369 .47139 .89798 .46684 Mtetra
.823 .907 .897 r
.89798 .46684 .90369 .47139 .91885 .46041 .91312 .45487 Mtetra
.801 .877 .902 r
.91312 .45487 .91885 .46041 .93415 .45034 .92841 .44393 Mtetra
.777 .848 .905 r
.92841 .44393 .93415 .45034 .94961 .44124 .94387 .43411 Mtetra
.752 .823 .907 r
.94387 .43411 .94961 .44124 .96524 .43305 .9595 .42534 Mtetra
.664 .741 .908 r
.38141 .58164 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57352 Mtetra
.663 .741 .908 r
.408 .57352 .41589 .58101 .42925 .57696 .42139 .56943 Mtetra
.42139 .56943 .42925 .57696 .44266 .57289 .43485 .56532 Mtetra
.43485 .56532 .44266 .57289 .45615 .56881 .44838 .5612 Mtetra
.44838 .5612 .45615 .56881 .4697 .56472 .46198 .55707 Mtetra
.662 .741 .908 r
.46198 .55707 .4697 .56472 .48332 .56062 .47564 .55294 Mtetra
.661 .741 .909 r
.47564 .55294 .48332 .56062 .49701 .55655 .48938 .54883 Mtetra
.659 .741 .91 r
.48938 .54883 .49701 .55655 .51077 .55251 .50318 .54477 Mtetra
.656 .74 .911 r
.50318 .54477 .51077 .55251 .5246 .54855 .51705 .54079 Mtetra
.652 .739 .914 r
.51705 .54079 .5246 .54855 .5385 .54472 .531 .53696 Mtetra
.644 .738 .917 r
.531 .53696 .5385 .54472 .55248 .54111 .54502 .53337 Mtetra
.632 .735 .922 r
.54502 .53337 .55248 .54111 .56653 .53783 .55912 .53015 Mtetra
.615 .732 .929 r
.55912 .53015 .56653 .53783 .58068 .53501 .57332 .52744 Mtetra
.59 .727 .939 r
.57332 .52744 .58068 .53501 .59492 .53281 .58761 .52542 Mtetra
.553 .719 .95 r
.58761 .52542 .59492 .53281 .60927 .5314 .60202 .52428 Mtetra
.5 .706 .962 r
.60202 .52428 .60927 .5314 .62376 .53093 .61655 .5242 Mtetra
.425 .684 .971 r
.61655 .5242 .62376 .53093 .63838 .53153 .63124 .52532 Mtetra
.323 .649 .969 r
.63124 .52532 .63838 .53153 .65317 .53324 .6461 .52771 Mtetra
.195 .596 .944 r
.6461 .52771 .65317 .53324 .66813 .53599 .66115 .53129 Mtetra
.05 .527 .889 r
.66115 .53129 .66813 .53599 .68327 .53958 .67639 .53585 Mtetra
0 .453 .806 r
.67639 .53585 .68327 .53958 .69859 .54366 .69182 .54099 Mtetra
0 .394 .715 r
.69182 .54099 .69859 .54366 .71407 .54771 .70742 .54616 Mtetra
.228 0 0 r
.70742 .54616 .71407 .54771 .72966 .55114 .72316 .55069 Mtetra
.213 0 0 r
.72316 .55069 .72966 .55114 .74533 .5533 .73897 .55382 Mtetra
.137 0 0 r
.73897 .55382 .74533 .5533 .76101 .5536 .7548 .55489 Mtetra
0 0 0 r
.7548 .55489 .76101 .5536 .77664 .55156 .77057 .55335 Mtetra
.77057 .55335 .77664 .55156 .79218 .54695 .78623 .54888 Mtetra
.394 .84 .734 r
.78623 .54888 .79218 .54695 .80759 .53976 .80174 .54148 Mtetra
.577 .935 .783 r
.80174 .54148 .80759 .53976 .82286 .53024 .81708 .53141 Mtetra
.712 .985 .815 r
.81708 .53141 .82286 .53024 .83798 .51886 .83225 .51919 Mtetra
.797 .999 .835 r
.83225 .51919 .83798 .51886 .85301 .50621 .8473 .50549 Mtetra
.842 .992 .851 r
.8473 .50549 .85301 .50621 .86798 .49294 .86227 .49105 Mtetra
.859 .973 .864 r
.86227 .49105 .86798 .49294 .88295 .47965 .87723 .47656 Mtetra
.856 .947 .876 r
.87723 .47656 .88295 .47965 .89798 .46684 .89224 .46258 Mtetra
.841 .917 .886 r
.89224 .46258 .89798 .46684 .91312 .45487 .90736 .44954 Mtetra
.818 .887 .894 r
.90736 .44954 .91312 .45487 .92841 .44393 .92263 .43768 Mtetra
.791 .858 .9 r
.92263 .43768 .92841 .44393 .94387 .43411 .93808 .42707 Mtetra
.765 .831 .904 r
.93808 .42707 .94387 .43411 .9595 .42534 .95372 .41768 Mtetra
.664 .741 .908 r
.37336 .57414 .38141 .58164 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57352 .40003 .56595 Mtetra
.663 .741 .908 r
.40003 .56595 .408 .57352 .42139 .56943 .41347 .56182 Mtetra
.41347 .56182 .42139 .56943 .43485 .56532 .42697 .55768 Mtetra
.42697 .55768 .43485 .56532 .44838 .5612 .44054 .55352 Mtetra
.44054 .55352 .44838 .5612 .46198 .55707 .45418 .54935 Mtetra
.662 .741 .909 r
.45418 .54935 .46198 .55707 .47564 .55294 .46789 .54519 Mtetra
.661 .741 .909 r
.46789 .54519 .47564 .55294 .48938 .54883 .48167 .54104 Mtetra
.659 .74 .91 r
.48167 .54104 .48938 .54883 .50318 .54477 .49551 .53695 Mtetra
.656 .74 .911 r
.49551 .53695 .50318 .54477 .51705 .54079 .50943 .53295 Mtetra
.651 .739 .914 r
.50943 .53295 .51705 .54079 .531 .53696 .52343 .52912 Mtetra
.642 .737 .918 r
.52343 .52912 .531 .53696 .54502 .53337 .53749 .52556 Mtetra
.63 .734 .923 r
.53749 .52556 .54502 .53337 .55912 .53015 .55164 .52239 Mtetra
.61 .73 .931 r
.55164 .52239 .55912 .53015 .57332 .52744 .56588 .51979 Mtetra
.582 .724 .941 r
.56588 .51979 .57332 .52744 .58761 .52542 .58023 .51795 Mtetra
.54 .714 .952 r
.58023 .51795 .58761 .52542 .60202 .52428 .59468 .51708 Mtetra
.479 .696 .964 r
.59468 .51708 .60202 .52428 .61655 .5242 .60928 .5174 Mtetra
.392 .667 .969 r
.60928 .5174 .61655 .5242 .63124 .52532 .62403 .51907 Mtetra
.273 .621 .959 r
.62403 .51907 .63124 .52532 .6461 .52771 .63896 .52215 Mtetra
.123 .551 .92 r
.63896 .52215 .6461 .52771 .66115 .53129 .65409 .52659 Mtetra
0 .463 .843 r
.65409 .52659 .66115 .53129 .67639 .53585 .66943 .53216 Mtetra
0 .372 .739 r
.66943 .53216 .67639 .53585 .69182 .54099 .68497 .53843 Mtetra
.284 0 0 r
.68497 .53843 .69182 .54099 .70742 .54616 .7007 .5448 Mtetra
.325 0 0 r
.7007 .5448 .70742 .54616 .72316 .55069 .71657 .55049 Mtetra
.305 0 0 r
.71657 .55049 .72316 .55069 .73897 .55382 .73253 .55469 Mtetra
.224 0 0 r
.73253 .55469 .73897 .55382 .7548 .55489 .74851 .5566 Mtetra
.078 0 0 r
.74851 .5566 .7548 .55489 .77057 .55335 .76443 .55561 Mtetra
0 0 0 r
.76443 .55561 .77057 .55335 .78623 .54888 .78022 .55134 Mtetra
.354 .808 .685 r
.78022 .55134 .78623 .54888 .80174 .54148 .79583 .54376 Mtetra
.56 .92 .744 r
.79583 .54376 .80174 .54148 .81708 .53141 .81125 .53314 Mtetra
.71 .98 .782 r
.81125 .53314 .81708 .53141 .83225 .51919 .82648 .52005 Mtetra
.804 .999 .807 r
.82648 .52005 .83225 .51919 .8473 .50549 .84155 .50526 Mtetra
.854 .995 .826 r
.84155 .50526 .8473 .50549 .86227 .49105 .85653 .48958 Mtetra
.874 .978 .842 r
.85653 .48958 .86227 .49105 .87723 .47656 .87148 .47381 Mtetra
.873 .954 .858 r
.87148 .47381 .87723 .47656 .89224 .46258 .88647 .4586 Mtetra
.858 .926 .872 r
.88647 .4586 .89224 .46258 .90736 .44954 .90156 .44442 Mtetra
.834 .896 .884 r
.90156 .44442 .90736 .44954 .92263 .43768 .91681 .43156 Mtetra
.806 .867 .893 r
.91681 .43156 .92263 .43768 .93808 .42707 .93225 .42012 Mtetra
.777 .839 .899 r
.93225 .42012 .93808 .42707 .95372 .41768 .9479 .41004 Mtetra
.664 .741 .908 r
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.37858 .56245 .38666 .57005 .40003 .56595 .39199 .55831 Mtetra
.663 .741 .908 r
.39199 .55831 .40003 .56595 .41347 .56182 .40547 .55414 Mtetra
.40547 .55414 .41347 .56182 .42697 .55768 .41902 .54996 Mtetra
.41902 .54996 .42697 .55768 .44054 .55352 .43263 .54577 Mtetra
.43263 .54577 .44054 .55352 .45418 .54935 .44631 .54156 Mtetra
.662 .741 .909 r
.44631 .54156 .45418 .54935 .46789 .54519 .46007 .53736 Mtetra
.661 .741 .909 r
.46007 .53736 .46789 .54519 .48167 .54104 .47389 .53318 Mtetra
.659 .74 .91 r
.47389 .53318 .48167 .54104 .49551 .53695 .48778 .52906 Mtetra
.655 .74 .912 r
.48778 .52906 .49551 .53695 .50943 .53295 .50174 .52504 Mtetra
.65 .738 .914 r
.50174 .52504 .50943 .53295 .52343 .52912 .51578 .52121 Mtetra
.641 .736 .918 r
.51578 .52121 .52343 .52912 .53749 .52556 .52989 .51766 Mtetra
.627 .733 .924 r
.52989 .51766 .53749 .52556 .55164 .52239 .54409 .51455 Mtetra
.606 .729 .932 r
.54409 .51455 .55164 .52239 .56588 .51979 .55838 .51205 Mtetra
.574 .721 .942 r
.55838 .51205 .56588 .51979 .58023 .51795 .57277 .51039 Mtetra
.527 .708 .954 r
.57277 .51039 .58023 .51795 .59468 .51708 .58728 .5098 Mtetra
.458 .686 .964 r
.58728 .5098 .59468 .51708 .60928 .5174 .60193 .51052 Mtetra
.358 .649 .966 r
.60193 .51052 .60928 .5174 .62403 .51907 .61674 .51273 Mtetra
.221 .59 .947 r
.61674 .51273 .62403 .51907 .63896 .52215 .63174 .51652 Mtetra
.052 .503 .89 r
.63174 .51652 .63896 .52215 .65409 .52659 .64695 .52184 Mtetra
0 .396 .792 r
.64695 .52184 .65409 .52659 .66943 .53216 .66238 .52846 Mtetra
0 .294 .671 r
.66238 .52846 .66943 .53216 .68497 .53843 .67803 .5359 Mtetra
.369 0 0 r
.67803 .5359 .68497 .53843 .7007 .5448 .69389 .54351 Mtetra
.405 0 0 r
.69389 .54351 .7007 .5448 .71657 .55049 .7099 .55044 Mtetra
.382 0 0 r
.7099 .55044 .71657 .55049 .73253 .55469 .72601 .55577 Mtetra
.298 0 0 r
.72601 .55577 .73253 .55469 .74851 .5566 .74214 .55861 Mtetra
.145 0 0 r
.74214 .55861 .74851 .5566 .76443 .55561 .7582 .55824 Mtetra
0 0 0 r
.7582 .55824 .76443 .55561 .78022 .55134 .77413 .55422 Mtetra
.324 .783 .647 r
.77413 .55422 .78022 .55134 .79583 .54376 .78986 .54648 Mtetra
.55 .909 .714 r
.78986 .54648 .79583 .54376 .81125 .53314 .80537 .53531 Mtetra
.713 .976 .755 r
.80537 .53531 .81125 .53314 .82648 .52005 .82065 .52135 Mtetra
.813 .998 .781 r
.82065 .52135 .82648 .52005 .84155 .50526 .83575 .50543 Mtetra
.866 .995 .802 r
.83575 .50543 .84155 .50526 .85653 .48958 .85074 .48847 Mtetra
.888 .98 .821 r
.85074 .48847 .85653 .48958 .87148 .47381 .86567 .47137 Mtetra
.888 .958 .839 r
.86567 .47137 .87148 .47381 .88647 .4586 .88064 .45486 Mtetra
.874 .932 .857 r
.88064 .45486 .88647 .4586 .90156 .44442 .89571 .43948 Mtetra
.85 .903 .872 r
.89571 .43948 .90156 .44442 .91681 .43156 .91094 .42557 Mtetra
.821 .874 .885 r
.91094 .42557 .91681 .43156 .93225 .42012 .92637 .41323 Mtetra
.79 .846 .894 r
.92637 .41323 .93225 .42012 .9479 .41004 .94202 .40243 Mtetra
.664 .741 .908 r
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.663 .741 .908 r
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Mtetra
.3974 .54639 .40547 .55414 .41902 .54996 .41099 .54217 Mtetra
.41099 .54217 .41902 .54996 .43263 .54577 .42465 .53794 Mtetra
.42465 .53794 .43263 .54577 .44631 .54156 .43837 .5337 Mtetra
.662 .741 .909 r
.43837 .5337 .44631 .54156 .46007 .53736 .45217 .52946 Mtetra
.661 .741 .909 r
.45217 .52946 .46007 .53736 .47389 .53318 .46603 .52525 Mtetra
.659 .74 .91 r
.46603 .52525 .47389 .53318 .48778 .52906 .47997 .5211 Mtetra
.655 .739 .912 r
.47997 .5211 .48778 .52906 .50174 .52504 .49398 .51706 Mtetra
.649 .738 .915 r
.49398 .51706 .50174 .52504 .51578 .52121 .50806 .51321 Mtetra
.639 .736 .919 r
.50806 .51321 .51578 .52121 .52989 .51766 .52222 .50968 Mtetra
.624 .732 .925 r
.52222 .50968 .52989 .51766 .54409 .51455 .53647 .50662 Mtetra
.601 .727 .933 r
.53647 .50662 .54409 .51455 .55838 .51205 .5508 .50422 Mtetra
.566 .717 .943 r
.5508 .50422 .55838 .51205 .57277 .51039 .56524 .50273 Mtetra
.514 .702 .955 r
.56524 .50273 .57277 .51039 .58728 .5098 .57979 .50242 Mtetra
.436 .675 .964 r
.57979 .50242 .58728 .5098 .60193 .51052 .59449 .50352 Mtetra
.324 .63 .961 r
.59449 .50352 .60193 .51052 .61674 .51273 .60937 .50627 Mtetra
.17 .557 .931 r
.60937 .50627 .61674 .51273 .63174 .51652 .62443 .51077 Mtetra
0 .453 .858 r
.62443 .51077 .63174 .51652 .64695 .52184 .63972 .51699 Mtetra
0 .331 .742 r
.63972 .51699 .64695 .52184 .66238 .52846 .65524 .52466 Mtetra
.35 0 0 r
.65524 .52466 .66238 .52846 .67803 .5359 .671 .5333 Mtetra
.439 0 0 r
.671 .5333 .67803 .5359 .69389 .54351 .68697 .54219 Mtetra
.47 0 0 r
.68697 .54219 .69389 .54351 .7099 .55044 .70312 .55041 Mtetra
.444 0 0 r
.70312 .55041 .7099 .55044 .72601 .55577 .71938 .55694 Mtetra
.358 0 0 r
.71938 .55694 .72601 .55577 .74214 .55861 .73567 .56076 Mtetra
.2 0 0 r
.73567 .56076 .74214 .55861 .7582 .55824 .75189 .56107 Mtetra
0 0 0 r
.75189 .56107 .7582 .55824 .77413 .55422 .76796 .55736 Mtetra
.76796 .55736 .77413 .55422 .78986 .54648 .78381 .54951 Mtetra
.552 .905 .696 r
.78381 .54951 .78986 .54648 .80537 .53531 .79941 .53782 Mtetra
.724 .974 .737 r
.79941 .53782 .80537 .53531 .82065 .52135 .81476 .52299 Mtetra
.826 .996 .761 r
.81476 .52299 .82065 .52135 .83575 .50543 .82989 .50592 Mtetra
.879 .993 .78 r
.82989 .50592 .83575 .50543 .85074 .48847 .84489 .48765 Mtetra
.901 .979 .8 r
.84489 .48765 .85074 .48847 .86567 .47137 .85981 .46916 Mtetra
.902 .959 .82 r
.85981 .46916 .86567 .47137 .88064 .45486 .87476 .4513 Mtetra
.889 .935 .841 r
.87476 .4513 .88064 .45486 .89571 .43948 .88981 .43468 Mtetra
.865 .908 .86 r
.88981 .43468 .89571 .43948 .91094 .42557 .90503 .41966 Mtetra
.835 .88 .875 r
.90503 .41966 .91094 .42557 .92637 .41323 .92044 .40639 Mtetra
.802 .852 .887 r
.92044 .40639 .92637 .41323 .94202 .40243 .93608 .39484 Mtetra
.664 .741 .908 r
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54282 Mtetra
.663 .741 .908 r
.37569 .54282 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.38925 .53857 .3974 .54639 .41099 .54217 .40288 .53431 Mtetra
.40288 .53431 .41099 .54217 .42465 .53794 .41658 .53004 Mtetra
.41658 .53004 .42465 .53794 .43837 .5337 .43035 .52576 Mtetra
.662 .741 .909 r
.43035 .52576 .43837 .5337 .45217 .52946 .44419 .52148 Mtetra
.661 .741 .909 r
.44419 .52148 .45217 .52946 .46603 .52525 .45811 .51724 Mtetra
.658 .74 .91 r
.45811 .51724 .46603 .52525 .47997 .5211 .47209 .51305 Mtetra
.654 .739 .912 r
.47209 .51305 .47997 .5211 .49398 .51706 .48614 .50899 Mtetra
.648 .738 .915 r
.48614 .50899 .49398 .51706 .50806 .51321 .50027 .50514 Mtetra
.638 .735 .919 r
.50027 .50514 .50806 .51321 .52222 .50968 .51448 .50161 Mtetra
.621 .731 .925 r
.51448 .50161 .52222 .50968 .53647 .50662 .52877 .49859 Mtetra
.597 .725 .934 r
.52877 .49859 .53647 .50662 .5508 .50422 .54314 .49629 Mtetra
.559 .714 .944 r
.54314 .49629 .5508 .50422 .56524 .50273 .55763 .49497 Mtetra
.501 .695 .956 r
.55763 .49497 .56524 .50273 .57979 .50242 .57223 .49491 Mtetra
.416 .663 .963 r
.57223 .49491 .57979 .50242 .59449 .50352 .58698 .49639 Mtetra
.291 .609 .955 r
.58698 .49639 .59449 .50352 .60937 .50627 .60191 .49967 Mtetra
.122 .523 .914 r
.60191 .49967 .60937 .50627 .62443 .51077 .61704 .50487 Mtetra
0 .404 .825 r
.61704 .50487 .62443 .51077 .63972 .51699 .6324 .51196 Mtetra
0 .271 .694 r
.6324 .51196 .63972 .51699 .65524 .52466 .648 .52068 Mtetra
.412 0 0 r
.648 .52068 .65524 .52466 .671 .5333 .66386 .53054 Mtetra
.495 0 0 r
.66386 .53054 .671 .5333 .68697 .54219 .67995 .54073 Mtetra
.521 0 0 r
.67995 .54073 .68697 .54219 .70312 .55041 .69624 .55027 Mtetra
.494 0 0 r
.69624 .55027 .70312 .55041 .71938 .55694 .71265 .55803 Mtetra
.406 0 0 r
.71265 .55803 .71938 .55694 .73567 .56076 .72909 .5629 Mtetra
.244 0 0 r
.72909 .5629 .73567 .56076 .75189 .56107 .74546 .56396 Mtetra
0 0 0 r
.74546 .56396 .75189 .56107 .76796 .55736 .76168 .5606 Mtetra
.76168 .5606 .76796 .55736 .78381 .54951 .77765 .55268 Mtetra
.565 .909 .692 r
.77765 .55268 .78381 .54951 .79941 .53782 .79335 .54051 Mtetra
.741 .976 .728 r
.79335 .54051 .79941 .53782 .81476 .52299 .80878 .52481 Mtetra
.841 .994 .746 r
.80878 .52481 .81476 .52299 .82989 .50592 .82396 .5066 Mtetra
.893 .989 .762 r
.82396 .5066 .82989 .50592 .84489 .48765 .83897 .487 Mtetra
.914 .975 .781 r
.83897 .487 .84489 .48765 .85981 .46916 .85389 .46711 Mtetra
.915 .957 .802 r
.85389 .46711 .85981 .46916 .87476 .4513 .86883 .44787 Mtetra
.902 .935 .825 r
.86883 .44787 .87476 .4513 .88981 .43468 .88385 .42996 Mtetra
.879 .911 .846 r
.88385 .42996 .88981 .43468 .90503 .41966 .89905 .41381 Mtetra
.848 .884 .865 r
.89905 .41381 .90503 .41966 .92044 .40639 .91445 .39958 Mtetra
.815 .857 .88 r
.91445 .39958 .92044 .40639 .93608 .39484 .93009 .38723 Mtetra
.664 .741 .908 r
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54282 .36742 .53496 Mtetra
.663 .741 .908 r
.36742 .53496 .37569 .54282 .38925 .53857 .38103 .53068 Mtetra
.38103 .53068 .38925 .53857 .40288 .53431 .3947 .52638 Mtetra
.3947 .52638 .40288 .53431 .41658 .53004 .40845 .52206 Mtetra
.40845 .52206 .41658 .53004 .43035 .52576 .42226 .51774 Mtetra
.662 .741 .909 r
.42226 .51774 .43035 .52576 .44419 .52148 .43615 .51343 Mtetra
.661 .741 .909 r
.43615 .51343 .44419 .52148 .45811 .51724 .4501 .50914 Mtetra
.658 .74 .91 r
.4501 .50914 .45811 .51724 .47209 .51305 .46413 .50493 Mtetra
.654 .739 .912 r
.46413 .50493 .47209 .51305 .48614 .50899 .47823 .50084 Mtetra
.647 .737 .915 r
.47823 .50084 .48614 .50899 .50027 .50514 .4924 .49697 Mtetra
.636 .735 .919 r
.4924 .49697 .50027 .50514 .51448 .50161 .50666 .49346 Mtetra
.619 .73 .926 r
.50666 .49346 .51448 .50161 .52877 .49859 .52099 .49047 Mtetra
.592 .723 .934 r
.52099 .49047 .52877 .49859 .54314 .49629 .53541 .48825 Mtetra
.552 .71 .945 r
.53541 .48825 .54314 .49629 .55763 .49497 .54994 .48708 Mtetra
.49 .689 .956 r
.54994 .48708 .55763 .49497 .57223 .49491 .56459 .48726 Mtetra
.396 .652 .961 r
.56459 .48726 .57223 .49491 .58698 .49639 .57939 .4891 Mtetra
.26 .589 .947 r
.57939 .4891 .58698 .49639 .60191 .49967 .59437 .49288 Mtetra
.078 .49 .896 r
.59437 .49288 .60191 .49967 .61704 .50487 .60956 .49874 Mtetra
0 .358 .793 r
.60956 .49874 .61704 .50487 .6324 .51196 .62498 .50669 Mtetra
0 .218 .653 r
.62498 .50669 .6324 .51196 .648 .52068 .64067 .51645 Mtetra
.461 0 0 r
.64067 .51645 .648 .52068 .66386 .53054 .65662 .52749 Mtetra
.538 0 0 r
.65662 .52749 .66386 .53054 .67995 .54073 .67282 .53899 Mtetra
.561 0 0 r
.67282 .53899 .67995 .54073 .69624 .55027 .68924 .54986 Mtetra
.533 0 0 r
.68924 .54986 .69624 .55027 .71265 .55803 .70579 .55889 Mtetra
.445 0 0 r
.70579 .55889 .71265 .55803 .72909 .5629 .72239 .56484 Mtetra
.277 0 0 r
.72239 .56484 .72909 .5629 .74546 .56396 .73892 .56669 Mtetra
.011 0 0 r
.73892 .56669 .74546 .56396 .76168 .5606 .75528 .56375 Mtetra
.313 .773 .635 r
.75528 .56375 .76168 .5606 .77765 .55268 .77139 .55581 Mtetra
.59 .922 .703 r
.77139 .55581 .77765 .55268 .79335 .54051 .78719 .5432 Mtetra
.765 .981 .728 r
.78719 .5432 .79335 .54051 .80878 .52481 .80269 .52668 Mtetra
.86 .992 .738 r
.80269 .52668 .80878 .52481 .82396 .5066 .81793 .50734 Mtetra
.907 .984 .749 r
.81793 .50734 .82396 .5066 .83897 .487 .83296 .48642 Mtetra
.925 .97 .764 r
.83296 .48642 .83897 .487 .85389 .46711 .84789 .46512 Mtetra
.926 .953 .785 r
.84789 .46512 .85389 .46711 .86883 .44787 .86281 .44449 Mtetra
.914 .933 .809 r
.86281 .44449 .86883 .44787 .88385 .42996 .87783 .42528 Mtetra
.891 .911 .833 r
.87783 .42528 .88385 .42996 .89905 .41381 .893 .40797 Mtetra
.86 .886 .854 r
.893 .40797 .89905 .41381 .91445 .39958 .9084 .39275 Mtetra
.826 .86 .872 r
.9084 .39275 .91445 .39958 .93009 .38723 .92404 .3796 Mtetra
.664 .741 .908 r
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.663 .741 .908 r
.35908 .52703 .36742 .53496 .38103 .53068 .37272 .52271 Mtetra
.37272 .52271 .38103 .53068 .3947 .52638 .38644 .51837 Mtetra
.38644 .51837 .3947 .52638 .40845 .52206 .40023 .51401 Mtetra
.40023 .51401 .40845 .52206 .42226 .51774 .41409 .50965 Mtetra
.662 .741 .909 r
.41409 .50965 .42226 .51774 .43615 .51343 .42802 .5053 Mtetra
.66 .741 .909 r
.42802 .5053 .43615 .51343 .4501 .50914 .44202 .50098 Mtetra
.658 .74 .91 r
.44202 .50098 .4501 .50914 .46413 .50493 .4561 .49672 Mtetra
.654 .739 .912 r
.4561 .49672 .46413 .50493 .47823 .50084 .47024 .49261 Mtetra
.646 .737 .915 r
.47024 .49261 .47823 .50084 .4924 .49697 .48446 .48872 Mtetra
.635 .734 .92 r
.48446 .48872 .4924 .49697 .50666 .49346 .49876 .4852 Mtetra
.617 .729 .926 r
.49876 .4852 .50666 .49346 .52099 .49047 .51314 .48225 Mtetra
.589 .721 .935 r
.51314 .48225 .52099 .49047 .53541 .48825 .52761 .4801 Mtetra
.546 .707 .945 r
.52761 .4801 .53541 .48825 .54994 .48708 .54218 .47905 Mtetra
.479 .682 .955 r
.54218 .47905 .54994 .48708 .56459 .48726 .55688 .47945 Mtetra
.379 .641 .958 r
.55688 .47945 .56459 .48726 .57939 .4891 .57172 .48162 Mtetra
.233 .57 .94 r
.57172 .48162 .57939 .4891 .59437 .49288 .58675 .48586 Mtetra
.04 .46 .879 r
.58675 .48586 .59437 .49288 .60956 .49874 .60198 .49235 Mtetra
0 .318 .765 r
.60198 .49235 .60956 .49874 .62498 .50669 .61747 .5011 Mtetra
0 .173 .619 r
.61747 .5011 .62498 .50669 .64067 .51645 .63323 .51185 Mtetra
.497 0 0 r
.63323 .51185 .64067 .51645 .65662 .52749 .64927 .52405 Mtetra
.57 .004 0 r
.64927 .52405 .65662 .52749 .67282 .53899 .66557 .53682 Mtetra
.591 .019 0 r
.66557 .53682 .67282 .53899 .68924 .54986 .68211 .54902 Mtetra
.562 0 0 r
.68211 .54902 .68924 .54986 .70579 .55889 .6988 .55931 Mtetra
.474 0 0 r
.6988 .55931 .70579 .55889 .72239 .56484 .71554 .56638 Mtetra
.299 0 0 r
.71554 .56638 .72239 .56484 .73892 .56669 .73223 .56906 Mtetra
.012 0 0 r
.73223 .56906 .73892 .56669 .75528 .56375 .74874 .56658 Mtetra
.339 .797 .67 r
.74874 .56658 .75528 .56375 .77139 .55581 .76498 .55869 Mtetra
.626 .942 .727 r
.76498 .55869 .77139 .55581 .78719 .5432 .78091 .54569 Mtetra
.795 .988 .737 r
.78091 .54569 .78719 .5432 .80269 .52668 .79649 .52839 Mtetra
.88 .99 .736 r
.79649 .52839 .80269 .52668 .81793 .50734 .81179 .50797 Mtetra
.92 .977 .739 r
.81179 .50797 .81793 .50734 .83296 .48642 .82685 .48576 Mtetra
.936 .962 .751 r
.82685 .48576 .83296 .48642 .84789 .46512 .84179 .46308 Mtetra
.936 .946 .77 r
.84179 .46308 .84789 .46512 .86281 .44449 .85672 .44107 Mtetra
.923 .929 .794 r
.85672 .44107 .86281 .44449 .87783 .42528 .87172 .42056 Mtetra
.901 .909 .819 r
.87172 .42056 .87783 .42528 .893 .40797 .88689 .40209 Mtetra
.871 .887 .843 r
.88689 .40209 .893 .40797 .9084 .39275 .90227 .38588 Mtetra
.837 .862 .863 r
.90227 .38588 .9084 .39275 .92404 .3796 .91792 .37191 Mtetra
.664 .741 .908 r
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.663 .741 .908 r
.35065 .51903 .35908 .52703 .37272 .52271 .36434 .51466 Mtetra
.36434 .51466 .37272 .52271 .38644 .51837 .3781 .51028 Mtetra
.3781 .51028 .38644 .51837 .40023 .51401 .39194 .50589 Mtetra
.39194 .50589 .40023 .51401 .41409 .50965 .40584 .50148 Mtetra
.662 .741 .909 r
.40584 .50148 .41409 .50965 .42802 .5053 .41982 .49709 Mtetra
.66 .74 .909 r
.41982 .49709 .42802 .5053 .44202 .50098 .43386 .49273 Mtetra
.658 .74 .91 r
.43386 .49273 .44202 .50098 .4561 .49672 .44798 .48844 Mtetra
.653 .739 .912 r
.44798 .48844 .4561 .49672 .47024 .49261 .46218 .48429 Mtetra
.646 .737 .915 r
.46218 .48429 .47024 .49261 .48446 .48872 .47644 .48038 Mtetra
.634 .733 .92 r
.47644 .48038 .48446 .48872 .49876 .4852 .49079 .47685 Mtetra
.615 .728 .926 r
.49079 .47685 .49876 .4852 .51314 .48225 .50521 .47392 Mtetra
.586 .719 .935 r
.50521 .47392 .51314 .48225 .52761 .4801 .51972 .47182 Mtetra
.54 .703 .945 r
.51972 .47182 .52761 .4801 .54218 .47905 .53434 .47088 Mtetra
.47 .676 .955 r
.53434 .47088 .54218 .47905 .55688 .47945 .54908 .47146 Mtetra
.364 .63 .955 r
.54908 .47146 .55688 .47945 .57172 .48162 .56397 .47392 Mtetra
.211 .552 .932 r
.56397 .47392 .57172 .48162 .58675 .48586 .57903 .47858 Mtetra
.01 .433 .864 r
.57903 .47858 .58675 .48586 .60198 .49235 .59432 .48565 Mtetra
0 .284 .743 r
.59432 .48565 .60198 .49235 .61747 .5011 .60986 .49514 Mtetra
0 .137 .594 r
.60986 .49514 .61747 .5011 .63323 .51185 .62568 .50682 Mtetra
.523 0 0 r
.62568 .50682 .63323 .51185 .64927 .52405 .6418 .52011 Mtetra
.592 .035 0 r
.6418 .52011 .64927 .52405 .66557 .53682 .6582 .5341 Mtetra
.612 .048 0 r
.6582 .5341 .66557 .53682 .68211 .54902 .67485 .54757 Mtetra
.584 .008 0 r
.67485 .54757 .68211 .54902 .6988 .55931 .69167 .55912 Mtetra
.495 0 0 r
.69167 .55912 .6988 .55931 .71554 .56638 .70855 .56729 Mtetra
.312 0 0 r
.70855 .56729 .71554 .56638 .73223 .56906 .72539 .57083 Mtetra
0 0 0 r
.72539 .57083 .73223 .56906 .74874 .56658 .74205 .56887 Mtetra
.381 .831 .723 r
.74205 .56887 .74874 .56658 .76498 .55869 .75843 .56108 Mtetra
.671 .965 .762 r
.75843 .56108 .76498 .55869 .78091 .54569 .77447 .54776 Mtetra
.826 .994 .752 r
.77447 .54776 .78091 .54569 .79649 .52839 .79016 .52976 Mtetra
.9 .986 .738 r
.79016 .52976 .79649 .52839 .81179 .50797 .80552 .50832 Mtetra
.933 .969 .734 r
.80552 .50832 .81179 .50797 .82685 .48576 .82063 .48488 Mtetra
.945 .952 .741 r
.82063 .48488 .82685 .48576 .84179 .46308 .83559 .46086 Mtetra
.943 .937 .757 r
.83559 .46086 .84179 .46308 .85672 .44107 .85052 .4375 Mtetra
.931 .922 .78 r
.85052 .4375 .85672 .44107 .87172 .42056 .86553 .41572 Mtetra
.91 .905 .806 r
.86553 .41572 .87172 .42056 .88689 .40209 .88069 .39611 Mtetra
.881 .885 .832 r
.88069 .39611 .88689 .40209 .90227 .38588 .89608 .37892 Mtetra
.846 .863 .855 r
.89608 .37892 .90227 .38588 .91792 .37191 .91173 .36414 Mtetra
.664 .741 .908 r
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.663 .741 .908 r
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .3781 .51028 .36969 .50212 Mtetra
.36969 .50212 .3781 .51028 .39194 .50589 .38356 .49768 Mtetra
.38356 .49768 .39194 .50589 .40584 .50148 .39751 .49324 Mtetra
.662 .741 .909 r
.39751 .49324 .40584 .50148 .41982 .49709 .41153 .4888 Mtetra
.66 .74 .909 r
.41153 .4888 .41982 .49709 .43386 .49273 .42563 .48439 Mtetra
.658 .74 .91 r
.42563 .48439 .43386 .49273 .44798 .48844 .43979 .48007 Mtetra
.653 .738 .912 r
.43979 .48007 .44798 .48844 .46218 .48429 .45403 .47588 Mtetra
.646 .736 .915 r
.45403 .47588 .46218 .48429 .47644 .48038 .46834 .47194 Mtetra
.633 .733 .92 r
.46834 .47194 .47644 .48038 .49079 .47685 .48273 .4684 Mtetra
.614 .727 .926 r
.48273 .4684 .49079 .47685 .50521 .47392 .4972 .46547 Mtetra
.583 .717 .935 r
.4972 .46547 .50521 .47392 .51972 .47182 .51176 .46341 Mtetra
.536 .7 .945 r
.51176 .46341 .51972 .47182 .53434 .47088 .52642 .46256 Mtetra
.463 .671 .954 r
.52642 .46256 .53434 .47088 .54908 .47146 .5412 .46329 Mtetra
.353 .62 .952 r
.5412 .46329 .54908 .47146 .56397 .47392 .55613 .46599 Mtetra
.193 .536 .925 r
.55613 .46599 .56397 .47392 .57903 .47858 .57124 .47101 Mtetra
0 .411 .851 r
.57124 .47101 .57903 .47858 .59432 .48565 .58656 .47857 Mtetra
0 .257 .726 r
.58656 .47857 .59432 .48565 .60986 .49514 .60215 .48873 Mtetra
0 .11 .578 r
.60215 .48873 .60986 .49514 .62568 .50682 .61803 .50125 Mtetra
.539 0 0 r
.61803 .50125 .62568 .50682 .6418 .52011 .63421 .51554 Mtetra
.606 .058 0 r
.63421 .51554 .6418 .52011 .6582 .5341 .6507 .53067 Mtetra
.624 .068 0 r
.6507 .53067 .6582 .5341 .67485 .54757 .66745 .54536 Mtetra
.596 .025 0 r
.66745 .54536 .67485 .54757 .69167 .55912 .68438 .55811 Mtetra
.505 0 0 r
.68438 .55811 .69167 .55912 .70855 .56729 .70141 .56737 Mtetra
.312 0 0 r
.70141 .56737 .70855 .56729 .72539 .57083 .71838 .57178 Mtetra
0 0 0 r
.71838 .57178 .72539 .57083 .74205 .56887 .73519 .57036 Mtetra
.436 .871 .791 r
.73519 .57036 .74205 .56887 .75843 .56108 .75171 .56274 Mtetra
.719 .985 .803 r
.75171 .56274 .75843 .56108 .77447 .54776 .76788 .54919 Mtetra
.857 .996 .77 r
.76788 .54919 .77447 .54776 .79016 .52976 .78367 .53057 Mtetra
.918 .979 .743 r
.78367 .53057 .79016 .52976 .80552 .50832 .79911 .50819 Mtetra
.944 .958 .731 r
.79911 .50819 .80552 .50832 .82063 .48488 .81428 .48361 Mtetra
.952 .941 .733 r
.81428 .48361 .82063 .48488 .83559 .46086 .82927 .45833 Mtetra
.949 .927 .747 r
.82927 .45833 .83559 .46086 .85052 .4375 .84422 .43369 Mtetra
.937 .914 .768 r
.84422 .43369 .85052 .4375 .86553 .41572 .85923 .41068 Mtetra
.916 .899 .794 r
.85923 .41068 .86553 .41572 .88069 .39611 .8744 .38996 Mtetra
.888 .882 .821 r
.8744 .38996 .88069 .39611 .89608 .37892 .8898 .37182 Mtetra
.855 .862 .846 r
.8898 .37182 .89608 .37892 .91173 .36414 .90546 .35624 Mtetra
.664 .741 .908 r
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.663 .741 .908 r
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Mtetra
.34734 .49834 .35588 .50654 .36969 .50212 .36119 .49388 Mtetra
.36119 .49388 .36969 .50212 .38356 .49768 .37511 .48939 Mtetra
.37511 .48939 .38356 .49768 .39751 .49324 .38911 .48491 Mtetra
.662 .741 .909 r
.38911 .48491 .39751 .49324 .41153 .4888 .40317 .48043 Mtetra
.66 .74 .909 r
.40317 .48043 .41153 .4888 .42563 .48439 .41731 .47598 Mtetra
.658 .74 .91 r
.41731 .47598 .42563 .48439 .43979 .48007 .43152 .47161 Mtetra
.653 .738 .912 r
.43152 .47161 .43979 .48007 .45403 .47588 .44581 .46739 Mtetra
.645 .736 .915 r
.44581 .46739 .45403 .47588 .46834 .47194 .46017 .46341 Mtetra
.633 .732 .92 r
.46017 .46341 .46834 .47194 .48273 .4684 .4746 .45985 Mtetra
.613 .726 .926 r
.4746 .45985 .48273 .4684 .4972 .46547 .48912 .45691 Mtetra
.582 .716 .935 r
.48912 .45691 .4972 .46547 .51176 .46341 .50372 .45486 Mtetra
.533 .698 .945 r
.50372 .45486 .51176 .46341 .52642 .46256 .51842 .45406 Mtetra
.458 .666 .952 r
.51842 .45406 .52642 .46256 .5412 .46329 .53324 .45491 Mtetra
.344 .613 .95 r
.53324 .45491 .5412 .46329 .55613 .46599 .54821 .4578 Mtetra
.181 .524 .919 r
.54821 .4578 .55613 .46599 .57124 .47101 .56335 .46311 Mtetra
0 .393 .842 r
.56335 .46311 .57124 .47101 .58656 .47857 .57872 .47109 Mtetra
0 .237 .716 r
.57872 .47109 .58656 .47857 .60215 .48873 .59434 .48182 Mtetra
0 .092 .571 r
.59434 .48182 .60215 .48873 .61803 .50125 .61027 .49507 Mtetra
.545 .014 0 r
.61027 .49507 .61803 .50125 .63421 .51554 .62651 .51025 Mtetra
.61 .072 0 r
.62651 .51025 .63421 .51554 .6507 .53067 .64307 .52641 Mtetra
.628 .08 0 r
.64307 .52641 .6507 .53067 .66745 .54536 .6599 .54221 Mtetra
.599 .035 0 r
.6599 .54221 .66745 .54536 .68438 .55811 .67695 .55609 Mtetra
.504 0 0 r
.67695 .55609 .68438 .55811 .70141 .56737 .69409 .5664 Mtetra
.297 0 0 r
.69409 .5664 .70141 .56737 .71838 .57178 .7112 .57167 Mtetra
.074 .636 .752 r
.7112 .57167 .71838 .57178 .73519 .57036 .72815 .57083 Mtetra
.498 .908 .863 r
.72815 .57083 .73519 .57036 .75171 .56274 .74481 .56344 Mtetra
.764 .996 .842 r
.74481 .56344 .75171 .56274 .76788 .54919 .76111 .54973 Mtetra
.882 .992 .789 r
.76111 .54973 .76788 .54919 .78367 .53057 .77701 .53059 Mtetra
.932 .968 .749 r
.77701 .53059 .78367 .53057 .79911 .50819 .79254 .5074 Mtetra
.952 .945 .73 r
.79254 .5074 .79911 .50819 .81428 .48361 .80778 .48178 Mtetra
.957 .928 .728 r
.80778 .48178 .81428 .48361 .82927 .45833 .82282 .45534 Mtetra
.953 .915 .739 r
.82282 .45534 .82927 .45833 .84422 .43369 .8378 .42951 Mtetra
.941 .904 .758 r
.8378 .42951 .84422 .43369 .85923 .41068 .85283 .40536 Mtetra
.921 .892 .784 r
.85283 .40536 .85923 .41068 .8744 .38996 .86802 .38359 Mtetra
.894 .877 .811 r
.86802 .38359 .8744 .38996 .8898 .37182 .88343 .36453 Mtetra
.861 .86 .837 r
.88343 .36453 .8898 .37182 .90546 .35624 .89911 .34819 Mtetra
.664 .741 .908 r
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Mtetra
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Mtetra
.663 .741 .908 r
.32489 .49455 .33356 .50279 .34734 .49834 .33871 .49006 Mtetra
.33871 .49006 .34734 .49834 .36119 .49388 .35261 .48555 Mtetra
.35261 .48555 .36119 .49388 .37511 .48939 .36658 .48103 Mtetra
.36658 .48103 .37511 .48939 .38911 .48491 .38062 .4765 Mtetra
.662 .741 .909 r
.38062 .4765 .38911 .48491 .40317 .48043 .39473 .47197 Mtetra
.66 .74 .909 r
.39473 .47197 .40317 .48043 .41731 .47598 .40891 .46748 Mtetra
.658 .74 .91 r
.40891 .46748 .41731 .47598 .43152 .47161 .42317 .46307 Mtetra
.653 .738 .912 r
.42317 .46307 .43152 .47161 .44581 .46739 .4375 .4588 Mtetra
.645 .736 .915 r
.4375 .4588 .44581 .46739 .46017 .46341 .45191 .45479 Mtetra
.633 .732 .92 r
.45191 .45479 .46017 .46341 .4746 .45985 .46639 .45119 Mtetra
.612 .725 .926 r
.46639 .45119 .4746 .45985 .48912 .45691 .48095 .44822 Mtetra
.581 .714 .934 r
.48095 .44822 .48912 .45691 .50372 .45486 .4956 .44617 Mtetra
.531 .695 .944 r
.4956 .44617 .50372 .45486 .51842 .45406 .51034 .4454 Mtetra
.455 .663 .951 r
.51034 .4454 .51842 .45406 .53324 .45491 .5252 .44631 Mtetra
.34 .606 .947 r
.5252 .44631 .53324 .45491 .54821 .4578 .5402 .44933 Mtetra
.175 .515 .915 r
.5402 .44933 .54821 .4578 .56335 .46311 .55538 .45486 Mtetra
0 .382 .837 r
.55538 .45486 .56335 .46311 .57872 .47109 .57078 .46317 Mtetra
0 .225 .712 r
.57078 .46317 .57872 .47109 .59434 .48182 .58644 .47436 Mtetra
0 .082 .572 r
.58644 .47436 .59434 .48182 .61027 .49507 .6024 .48821 Mtetra
.542 .022 0 r
.6024 .48821 .61027 .49507 .62651 .51025 .61869 .50415 Mtetra
.606 .078 0 r
.61869 .50415 .62651 .51025 .64307 .52641 .6353 .5212 Mtetra
.622 .084 0 r
.6353 .5212 .64307 .52641 .6599 .54221 .65221 .53799 Mtetra
.591 .036 0 r
.65221 .53799 .6599 .54221 .67695 .55609 .66935 .55289 Mtetra
.49 0 0 r
.66935 .55289 .67695 .55609 .69409 .5664 .6866 .56418 Mtetra
.266 0 0 r
.6866 .56418 .69409 .5664 .7112 .57167 .70384 .57027 Mtetra
.134 .673 .842 r
.70384 .57027 .7112 .57167 .72815 .57083 .72092 .57003 Mtetra
.559 .928 .927 r
.72092 .57003 .72815 .57083 .74481 .56344 .73772 .56292 Mtetra
.8 .993 .874 r
.73772 .56292 .74481 .56344 .76111 .54973 .75415 .54916 Mtetra
.9 .978 .803 r
.75415 .54916 .76111 .54973 .77701 .53059 .77017 .52963 Mtetra
.94 .952 .755 r
.77017 .52963 .77701 .53059 .79254 .5074 .7858 .50575 Mtetra
.956 .93 .731 r
.7858 .50575 .79254 .5074 .80778 .48178 .80112 .47923 Mtetra
.959 .914 .725 r
.80112 .47923 .80778 .48178 .82282 .45534 .81623 .45176 Mtetra
.955 .902 .732 r
.81623 .45176 .82282 .45534 .8378 .42951 .83125 .42484 Mtetra
.943 .893 .75 r
.83125 .42484 .8378 .42951 .85283 .40536 .84632 .39964 Mtetra
.924 .883 .774 r
.84632 .39964 .85283 .40536 .86802 .38359 .86153 .37691 Mtetra
.899 .871 .802 r
.86153 .37691 .86802 .38359 .88343 .36453 .87696 .357 Mtetra
.867 .856 .829 r
.87696 .357 .88343 .36453 .89911 .34819 .89267 .33994 Mtetra
.664 .741 .908 r
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Mtetra
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Mtetra
.663 .741 .908 r
.31614 .48624 .32489 .49455 .33871 .49006 .33001 .48171 Mtetra
.33001 .48171 .33871 .49006 .35261 .48555 .34395 .47715 Mtetra
.34395 .47715 .35261 .48555 .36658 .48103 .35796 .47258 Mtetra
.35796 .47258 .36658 .48103 .38062 .4765 .37204 .468 Mtetra
.662 .741 .909 r
.37204 .468 .38062 .4765 .39473 .47197 .3862 .46343 Mtetra
.66 .74 .909 r
.3862 .46343 .39473 .47197 .40891 .46748 .40043 .4589 Mtetra
.658 .74 .91 r
.40043 .4589 .40891 .46748 .42317 .46307 .41474 .45444 Mtetra
.653 .738 .912 r
.41474 .45444 .42317 .46307 .4375 .4588 .42912 .45012 Mtetra
.645 .736 .915 r
.42912 .45012 .4375 .4588 .45191 .45479 .44357 .44607 Mtetra
.633 .732 .919 r
.44357 .44607 .45191 .45479 .46639 .45119 .4581 .44242 Mtetra
.612 .725 .926 r
.4581 .44242 .46639 .45119 .48095 .44822 .4727 .43942 Mtetra
.581 .713 .934 r
.4727 .43942 .48095 .44822 .4956 .44617 .48739 .43734 Mtetra
.531 .694 .943 r
.48739 .43734 .4956 .44617 .51034 .4454 .50218 .43656 Mtetra
.454 .66 .949 r
.50218 .43656 .51034 .4454 .5252 .44631 .51707 .43749 Mtetra
.339 .602 .945 r
.51707 .43749 .5252 .44631 .5402 .44933 .53211 .44058 Mtetra
.175 .509 .912 r
.53211 .44058 .5402 .44933 .55538 .45486 .54732 .44624 Mtetra
0 .376 .835 r
.54732 .44624 .55538 .45486 .57078 .46317 .56275 .45478 Mtetra
0 .221 .715 r
.56275 .45478 .57078 .46317 .58644 .47436 .57844 .4663 Mtetra
0 .079 .58 r
.57844 .4663 .58644 .47436 .6024 .48821 .59443 .48061 Mtetra
.53 .023 0 r
.59443 .48061 .6024 .48821 .61869 .50415 .61075 .49715 Mtetra
.592 .076 0 r
.61075 .49715 .61869 .50415 .6353 .5212 .62741 .51493 Mtetra
.607 .081 0 r
.62741 .51493 .6353 .5212 .65221 .53799 .64438 .53256 Mtetra
.571 .029 0 r
.64438 .53256 .65221 .53799 .66935 .55289 .66159 .54836 Mtetra
.46 0 0 r
.66159 .54836 .66935 .55289 .6866 .56418 .67894 .56052 Mtetra
0 .354 .707 r
.67894 .56052 .6866 .56418 .70384 .57027 .69629 .5674 Mtetra
.201 .697 .917 r
.69629 .5674 .70384 .57027 .72092 .57003 .7135 .56775 Mtetra
.607 .925 .969 r
.7135 .56775 .72092 .57003 .73772 .56292 .73043 .56098 Mtetra
.821 .974 .894 r
.73043 .56098 .73772 .56292 .75415 .54916 .74699 .54725 Mtetra
.908 .957 .813 r
.74699 .54725 .75415 .54916 .77017 .52963 .76314 .52746 Mtetra
.943 .932 .76 r
.76314 .52746 .77017 .52963 .7858 .50575 .77888 .50305 Mtetra
.956 .912 .732 r
.77888 .50305 .7858 .50575 .80112 .47923 .79429 .47578 Mtetra
.958 .898 .723 r
.79429 .47578 .80112 .47923 .81623 .45176 .80947 .44743 Mtetra
.954 .889 .727 r
.80947 .44743 .81623 .45176 .83125 .42484 .82456 .41958 Mtetra
.943 .881 .743 r
.82456 .41958 .83125 .42484 .84632 .39964 .83967 .39345 Mtetra
.926 .874 .766 r
.83967 .39345 .84632 .39964 .86153 .37691 .85493 .36985 Mtetra
.901 .864 .794 r
.85493 .36985 .86153 .37691 .87696 .357 .8704 .34917 Mtetra
.871 .852 .821 r
.8704 .34917 .87696 .357 .89267 .33994 .88614 .33145 Mtetra
.664 .741 .908 r
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Mtetra
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Mtetra
.663 .741 .908 r
.3073 .47784 .31614 .48624 .33001 .48171 .32121 .47327 Mtetra
.32121 .47327 .33001 .48171 .34395 .47715 .3352 .46867 Mtetra
.3352 .46867 .34395 .47715 .35796 .47258 .34925 .46405 Mtetra
.34925 .46405 .35796 .47258 .37204 .468 .36339 .45943 Mtetra
.662 .741 .909 r
.36339 .45943 .37204 .468 .3862 .46343 .37759 .45481 Mtetra
.66 .74 .909 r
.37759 .45481 .3862 .46343 .40043 .4589 .39187 .45023 Mtetra
.658 .74 .91 r
.39187 .45023 .40043 .4589 .41474 .45444 .40622 .44572 Mtetra
.653 .738 .912 r
.40622 .44572 .41474 .45444 .42912 .45012 .42065 .44135 Mtetra
.645 .736 .915 r
.42065 .44135 .42912 .45012 .44357 .44607 .43515 .43724 Mtetra
.633 .732 .919 r
.43515 .43724 .44357 .44607 .4581 .44242 .44972 .43355 Mtetra
.613 .724 .925 r
.44972 .43355 .4581 .44242 .4727 .43942 .46437 .43048 Mtetra
.581 .713 .933 r
.46437 .43048 .4727 .43942 .48739 .43734 .47911 .42836 Mtetra
.532 .692 .942 r
.47911 .42836 .48739 .43734 .50218 .43656 .49393 .42753 Mtetra
.456 .658 .948 r
.49393 .42753 .50218 .43656 .51707 .43749 .50887 .42844 Mtetra
.342 .6 .943 r
.50887 .42844 .51707 .43749 .53211 .44058 .52394 .43153 Mtetra
.181 .507 .911 r
.52394 .43153 .53211 .44058 .54732 .44624 .53918 .43724 Mtetra
0 .375 .837 r
.53918 .43724 .54732 .44624 .56275 .45478 .55463 .44589 Mtetra
0 .223 .722 r
.55463 .44589 .56275 .45478 .57844 .4663 .57034 .45761 Mtetra
0 .084 .595 r
.57034 .45761 .57844 .4663 .59443 .48061 .58635 .47223 Mtetra
.51 .015 0 r
.58635 .47223 .59443 .48061 .61075 .49715 .6027 .4892 Mtetra
.569 .068 0 r
.6027 .4892 .61075 .49715 .62741 .51493 .61939 .50753 Mtetra
.58 .07 0 r
.61939 .50753 .62741 .51493 .64438 .53256 .6364 .52583 Mtetra
.538 .014 0 r
.6364 .52583 .64438 .53256 .66159 .54836 .65367 .54236 Mtetra
0 .125 .576 r
.65367 .54236 .66159 .54836 .67894 .56052 .6711 .55528 Mtetra
0 .379 .775 r
.6711 .55528 .67894 .56052 .69629 .5674 .68855 .56287 Mtetra
.266 .7 .964 r
.68855 .56287 .69629 .5674 .7135 .56775 .70587 .56379 Mtetra
.637 .898 .985 r
.70587 .56379 .7135 .56775 .73043 .56098 .72293 .5574 Mtetra
.828 .94 .9 r
.72293 .5574 .73043 .56098 .74699 .54725 .73963 .54381 Mtetra
.907 .928 .818 r
.73963 .54381 .74699 .54725 .76314 .52746 .7559 .52389 Mtetra
.939 .908 .763 r
.7559 .52389 .76314 .52746 .77888 .50305 .77176 .49912 Mtetra
.952 .892 .733 r
.77176 .49912 .77888 .50305 .79429 .47578 .78728 .47129 Mtetra
.955 .881 .721 r
.78728 .47129 .79429 .47578 .80947 .44743 .80256 .44224 Mtetra
.951 .874 .724 r
.80256 .44224 .80947 .44743 .82456 .41958 .81772 .41361 Mtetra
.941 .868 .738 r
.81772 .41361 .82456 .41958 .83967 .39345 .8329 .3867 Mtetra
.925 .863 .76 r
.8329 .3867 .83967 .39345 .85493 .36985 .8482 .36236 Mtetra
.902 .856 .787 r
.8482 .36236 .85493 .36985 .8704 .34917 .86372 .341 Mtetra
.873 .846 .814 r
.86372 .341 .8704 .34917 .88614 .33145 .87951 .32269 Mtetra
.664 .741 .908 r
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Mtetra
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46937 Mtetra
.663 .741 .908 r
.29838 .46937 .3073 .47784 .32121 .47327 .31234 .46474 Mtetra
.31234 .46474 .32121 .47327 .3352 .46867 .32636 .4601 Mtetra
.32636 .4601 .3352 .46867 .34925 .46405 .34047 .45544 Mtetra
.34047 .45544 .34925 .46405 .36339 .45943 .35464 .45077 Mtetra
.662 .741 .909 r
.35464 .45077 .36339 .45943 .37759 .45481 .3689 .4461 Mtetra
.66 .74 .909 r
.3689 .4461 .37759 .45481 .39187 .45023 .38322 .44147 Mtetra
.658 .74 .91 r
.38322 .44147 .39187 .45023 .40622 .44572 .39762 .43691 Mtetra
.653 .738 .912 r
.39762 .43691 .40622 .44572 .42065 .44135 .4121 .43249 Mtetra
.646 .736 .915 r
.4121 .43249 .42065 .44135 .43515 .43724 .42665 .42832 Mtetra
.633 .731 .919 r
.42665 .42832 .43515 .43724 .44972 .43355 .44127 .42456 Mtetra
.614 .724 .924 r
.44127 .42456 .44972 .43355 .46437 .43048 .45596 .42143 Mtetra
.582 .712 .932 r
.45596 .42143 .46437 .43048 .47911 .42836 .47074 .41923 Mtetra
.534 .692 .94 r
.47074 .41923 .47911 .42836 .49393 .42753 .48561 .41833 Mtetra
.46 .657 .946 r
.48561 .41833 .49393 .42753 .50887 .42844 .50058 .41916 Mtetra
.348 .6 .941 r
.50058 .41916 .50887 .42844 .52394 .43153 .51568 .42219 Mtetra
.192 .508 .911 r
.51568 .42219 .52394 .43153 .53918 .43724 .53095 .42786 Mtetra
0 .38 .841 r
.53095 .42786 .53918 .43724 .55463 .44589 .54643 .43651 Mtetra
0 .232 .734 r
.54643 .43651 .55463 .44589 .57034 .45761 .56215 .44829 Mtetra
0 .096 .615 r
.56215 .44829 .57034 .45761 .58635 .47223 .57818 .46305 Mtetra
0 0 .518 r
.57818 .46305 .58635 .47223 .6027 .4892 .59454 .48026 Mtetra
.537 .052 0 r
.59454 .48026 .6027 .4892 .61939 .50753 .61124 .49895 Mtetra
.543 .052 0 r
.61124 .49895 .61939 .50753 .6364 .52583 .62828 .51771 Mtetra
0 .009 .509 r
.62828 .51771 .6364 .52583 .65367 .54236 .6456 .53481 Mtetra
0 .151 .635 r
.6456 .53481 .65367 .54236 .6711 .55528 .66309 .54834 Mtetra
0 .398 .826 r
.66309 .54834 .6711 .55528 .68855 .56287 .68062 .55654 Mtetra
.321 .685 .979 r
.68062 .55654 .68855 .56287 .70587 .56379 .69805 .55801 Mtetra
.651 .854 .978 r
.69805 .55801 .70587 .56379 .72293 .5574 .71523 .55203 Mtetra
.822 .898 .895 r
.71523 .55203 .72293 .5574 .73963 .54381 .73205 .53867 Mtetra
.898 .895 .817 r
.73205 .53867 .73963 .54381 .7559 .52389 .74846 .51877 Mtetra
.931 .882 .764 r
.74846 .51877 .7559 .52389 .77176 .49912 .76445 .49381 Mtetra
.945 .871 .734 r
.76445 .49381 .77176 .49912 .78728 .47129 .78008 .46561 Mtetra
.949 .863 .721 r
.78008 .46561 .78728 .47129 .80256 .44224 .79546 .43605 Mtetra
.946 .858 .722 r
.79546 .43605 .80256 .44224 .81772 .41361 .81072 .40684 Mtetra
.938 .855 .734 r
.81072 .40684 .81772 .41361 .8329 .3867 .82598 .37931 Mtetra
.923 .852 .754 r
.82598 .37931 .8329 .3867 .8482 .36236 .84135 .35435 Mtetra
.902 .847 .78 r
.84135 .35435 .8482 .36236 .86372 .341 .85694 .33243 Mtetra
.874 .84 .808 r
.85694 .33243 .86372 .341 .87951 .32269 .87279 .31363 Mtetra
.664 .741 .908 r
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Mtetra
.27545 .46545 .2845 .47397 .29838 .46937 .28937 .46081 Mtetra
.663 .741 .908 r
.28937 .46081 .29838 .46937 .31234 .46474 .30337 .45614 Mtetra
.30337 .45614 .31234 .46474 .32636 .4601 .31744 .45145 Mtetra
.31744 .45145 .32636 .4601 .34047 .45544 .33159 .44674 Mtetra
.33159 .44674 .34047 .45544 .35464 .45077 .34582 .44202 Mtetra
.662 .741 .909 r
.34582 .44202 .35464 .45077 .3689 .4461 .36011 .43731 Mtetra
.661 .74 .909 r
.36011 .43731 .3689 .4461 .38322 .44147 .37449 .43262 Mtetra
.658 .74 .91 r
.37449 .43262 .38322 .44147 .39762 .43691 .38894 .42801 Mtetra
.654 .738 .912 r
.38894 .42801 .39762 .43691 .4121 .43249 .40346 .42353 Mtetra
.646 .736 .914 r
.40346 .42353 .4121 .43249 .42665 .42832 .41806 .4193 Mtetra
.634 .731 .918 r
.41806 .4193 .42665 .42832 .44127 .42456 .43272 .41546 Mtetra
.615 .724 .924 r
.43272 .41546 .44127 .42456 .45596 .42143 .44747 .41225 Mtetra
.585 .712 .931 r
.44747 .41225 .45596 .42143 .47074 .41923 .46229 .40995 Mtetra
.537 .692 .939 r
.46229 .40995 .47074 .41923 .48561 .41833 .4772 .40894 Mtetra
.465 .658 .944 r
.4772 .40894 .48561 .41833 .50058 .41916 .49221 .40965 Mtetra
.358 .601 .94 r
.49221 .40965 .50058 .41916 .51568 .42219 .50735 .41255 Mtetra
.208 .512 .912 r
.50735 .41255 .51568 .42219 .53095 .42786 .52264 .41809 Mtetra
.022 .389 .848 r
.52264 .41809 .53095 .42786 .54643 .43651 .53813 .42662 Mtetra
0 .246 .749 r
.53813 .42662 .54643 .43651 .56215 .44829 .55387 .43832 Mtetra
0 .115 .639 r
.55387 .43832 .56215 .44829 .57818 .46305 .5699 .45305 Mtetra
0 .02 .55 r
.5699 .45305 .57818 .46305 .59454 .48026 .58627 .47032 Mtetra
0 0 .5 r
.58627 .47032 .59454 .48026 .61124 .49895 .60298 .48915 Mtetra
0 0 .501 r
.60298 .48915 .61124 .49895 .62828 .51771 .62003 .50817 Mtetra
0 .037 .56 r
.62003 .50817 .62828 .51771 .6456 .53481 .63737 .52563 Mtetra
0 .18 .685 r
.63737 .52563 .6456 .53481 .66309 .54834 .65491 .53962 Mtetra
.002 .41 .854 r
.65491 .53962 .66309 .54834 .68062 .55654 .67251 .54832 Mtetra
.364 .657 .969 r
.67251 .54832 .68062 .55654 .69805 .55801 .69003 .55029 Mtetra
.652 .805 .956 r
.69003 .55029 .69805 .55801 .71523 .55203 .70732 .54474 Mtetra
.808 .853 .883 r
.70732 .54474 .71523 .55203 .73205 .53867 .72426 .5317 Mtetra
.883 .859 .813 r
.72426 .5317 .73205 .53867 .74846 .51877 .7408 .51196 Mtetra
.918 .855 .763 r
.7408 .51196 .74846 .51877 .76445 .49381 .75693 .48699 Mtetra
.935 .849 .734 r
.75693 .48699 .76445 .49381 .78008 .46561 .77269 .45863 Mtetra
.941 .845 .72 r
.77269 .45863 .78008 .46561 .79546 .43605 .7882 .42878 Mtetra
.94 .843 .72 r
.7882 .42878 .79546 .43605 .81072 .40684 .80356 .39917 Mtetra
.933 .842 .731 r
.80356 .39917 .81072 .40684 .82598 .37931 .81892 .3712 Mtetra
.92 .841 .75 r
.81892 .3712 .82598 .37931 .84135 .35435 .83438 .34579 Mtetra
.9 .838 .776 r
.83438 .34579 .84135 .35435 .85694 .33243 .85003 .32342 Mtetra
.874 .833 .803 r
.85003 .32342 .85694 .33243 .87279 .31363 .86595 .30422 Mtetra
.664 .741 .908 r
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Mtetra
.2663 .45685 .27545 .46545 .28937 .46081 .28027 .45216 Mtetra
.663 .741 .908 r
.28027 .45216 .28937 .46081 .30337 .45614 .29432 .44744 Mtetra
.29432 .44744 .30337 .45614 .31744 .45145 .30843 .44271 Mtetra
.30843 .44271 .31744 .45145 .33159 .44674 .32263 .43795 Mtetra
.32263 .43795 .33159 .44674 .34582 .44202 .3369 .43319 Mtetra
.662 .741 .908 r
.3369 .43319 .34582 .44202 .36011 .43731 .35125 .42842 Mtetra
.661 .74 .909 r
.35125 .42842 .36011 .43731 .37449 .43262 .36567 .42369 Mtetra
.658 .74 .91 r
.36567 .42369 .37449 .43262 .38894 .42801 .38016 .41901 Mtetra
.654 .738 .911 r
.38016 .41901 .38894 .42801 .40346 .42353 .39473 .41448 Mtetra
.647 .736 .914 r
.39473 .41448 .40346 .42353 .41806 .4193 .40938 .41017 Mtetra
.635 .731 .918 r
.40938 .41017 .41806 .4193 .43272 .41546 .4241 .40626 Mtetra
.617 .724 .923 r
.4241 .40626 .43272 .41546 .44747 .41225 .43889 .40295 Mtetra
.587 .712 .93 r
.43889 .40295 .44747 .41225 .46229 .40995 .45376 .40053 Mtetra
.542 .693 .937 r
.45376 .40053 .46229 .40995 .4772 .40894 .46871 .39938 Mtetra
.473 .659 .943 r
.46871 .39938 .4772 .40894 .49221 .40965 .48376 .39992 Mtetra
.37 .604 .939 r
.48376 .39992 .49221 .40965 .50735 .41255 .49893 .40262 Mtetra
.228 .519 .914 r
.49893 .40262 .50735 .41255 .52264 .41809 .51425 .40795 Mtetra
.051 .402 .856 r
.51425 .40795 .52264 .41809 .53813 .42662 .52976 .41625 Mtetra
0 .265 .767 r
.52976 .41625 .53813 .42662 .55387 .43832 .54551 .42772 Mtetra
0 .139 .666 r
.54551 .42772 .55387 .43832 .5699 .45305 .56154 .44226 Mtetra
0 .046 .585 r
.56154 .44226 .5699 .45305 .58627 .47032 .5779 .45937 Mtetra
0 0 .541 r
.5779 .45937 .58627 .47032 .60298 .48915 .59461 .47815 Mtetra
0 .005 .546 r
.59461 .47815 .60298 .48915 .62003 .50817 .61166 .49721 Mtetra
0 .07 .607 r
.61166 .49721 .62003 .50817 .63737 .52563 .62901 .51483 Mtetra
0 .208 .724 r
.62901 .51483 .63737 .52563 .65491 .53962 .64658 .5291 Mtetra
.072 .416 .865 r
.64658 .5291 .65491 .53962 .67251 .54832 .66423 .53817 Mtetra
.394 .626 .946 r
.66423 .53817 .67251 .54832 .69003 .55029 .68182 .54057 Mtetra
.645 .756 .929 r
.68182 .54057 .69003 .55029 .70732 .54474 .69921 .53546 Mtetra
.79 .808 .867 r
.69921 .53546 .70732 .54474 .72426 .5317 .71627 .52281 Mtetra
.865 .824 .806 r
.71627 .52281 .72426 .5317 .7408 .51196 .73294 .50338 Mtetra
.903 .827 .761 r
.73294 .50338 .7408 .51196 .75693 .48699 .74921 .47859 Mtetra
.922 .826 .734 r
.74921 .47859 .75693 .48699 .77269 .45863 .76512 .45026 Mtetra
.931 .826 .72 r
.76512 .45026 .77269 .45863 .7882 .42878 .78075 .42033 Mtetra
.931 .827 .72 r
.78075 .42033 .7882 .42878 .80356 .39917 .79624 .39055 Mtetra
.926 .828 .729 r
.79624 .39055 .80356 .39917 .81892 .3712 .81171 .36232 Mtetra
.915 .829 .747 r
.81171 .36232 .81892 .3712 .83438 .34579 .82726 .33661 Mtetra
.897 .829 .772 r
.82726 .33661 .83438 .34579 .85003 .32342 .84301 .31394 Mtetra
.872 .825 .799 r
.84301 .31394 .85003 .32342 .86595 .30422 .85901 .29444 Mtetra
.664 .741 .908 r
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Mtetra
.25707 .44817 .2663 .45685 .28027 .45216 .27108 .44343 Mtetra
.663 .741 .908 r
.27108 .44343 .28027 .45216 .29432 .44744 .28517 .43867 Mtetra
.28517 .43867 .29432 .44744 .30843 .44271 .29934 .43388 Mtetra
.29934 .43388 .30843 .44271 .32263 .43795 .31358 .42908 Mtetra
.31358 .42908 .32263 .43795 .3369 .43319 .32789 .42426 Mtetra
.662 .741 .908 r
.32789 .42426 .3369 .43319 .35125 .42842 .34229 .41945 Mtetra
.661 .74 .909 r
.34229 .41945 .35125 .42842 .36567 .42369 .35676 .41466 Mtetra
.658 .74 .91 r
.35676 .41466 .36567 .42369 .38016 .41901 .3713 .40993 Mtetra
.654 .738 .911 r
.3713 .40993 .38016 .41901 .39473 .41448 .38592 .40532 Mtetra
.648 .736 .914 r
.38592 .40532 .39473 .41448 .40938 .41017 .40062 .40095 Mtetra
.636 .732 .917 r
.40062 .40095 .40938 .41017 .4241 .40626 .41538 .39694 Mtetra
.619 .725 .922 r
.41538 .39694 .4241 .40626 .43889 .40295 .43022 .39352 Mtetra
.59 .713 .929 r
.43022 .39352 .43889 .40295 .45376 .40053 .44514 .39097 Mtetra
.547 .694 .936 r
.44514 .39097 .45376 .40053 .46871 .39938 .46013 .38965 Mtetra
.481 .661 .941 r
.46013 .38965 .46871 .39938 .48376 .39992 .47522 .38998 Mtetra
.385 .609 .938 r
.47522 .38998 .48376 .39992 .49893 .40262 .49043 .39242 Mtetra
.251 .529 .916 r
.49043 .39242 .49893 .40262 .51425 .40795 .50577 .39745 Mtetra
.085 .418 .866 r
.50577 .39745 .51425 .40795 .52976 .41625 .5213 .40541 Mtetra
0 .289 .785 r
.5213 .40541 .52976 .41625 .54551 .42772 .53705 .41652 Mtetra
0 .168 .695 r
.53705 .41652 .54551 .42772 .56154 .44226 .55309 .43069 Mtetra
0 .078 .621 r
.55309 .43069 .56154 .44226 .5779 .45937 .56944 .44747 Mtetra
0 .034 .583 r
.56944 .44747 .5779 .45937 .59461 .47815 .58614 .46596 Mtetra
0 .04 .591 r
.58614 .46596 .59461 .47815 .61166 .49721 .60318 .48485 Mtetra
0 .105 .649 r
.60318 .48485 .61166 .49721 .62901 .51483 .62053 .50242 Mtetra
0 .236 .752 r
.62053 .50242 .62901 .51483 .64658 .5291 .6381 .51678 Mtetra
.134 .419 .863 r
.6381 .51678 .64658 .5291 .66423 .53817 .65578 .52608 Mtetra
.416 .596 .919 r
.65578 .52608 .66423 .53817 .68182 .54057 .67343 .52884 Mtetra
.636 .711 .901 r
.67343 .52884 .68182 .54057 .69921 .53546 .69091 .52417 Mtetra
.77 .767 .85 r
.69091 .52417 .69921 .53546 .71627 .52281 .70809 .51198 Mtetra
.845 .79 .798 r
.70809 .51198 .71627 .52281 .73294 .50338 .72489 .49297 Mtetra
.886 .8 .758 r
.72489 .49297 .73294 .50338 .74921 .47859 .7413 .46854 Mtetra
.908 .804 .733 r
.7413 .46854 .74921 .47859 .76512 .45026 .75735 .44046 Mtetra
.919 .808 .721 r
.75735 .44046 .76512 .45026 .78075 .42033 .77313 .41067 Mtetra
.922 .811 .719 r
.77313 .41067 .78075 .42033 .79624 .39055 .78875 .38091 Mtetra
.918 .815 .728 r
.78875 .38091 .79624 .39055 .81171 .36232 .80435 .35263 Mtetra
.909 .818 .745 r
.80435 .35263 .81171 .36232 .82726 .33661 .82002 .32679 Mtetra
.892 .819 .769 r
.82002 .32679 .82726 .33661 .84301 .31394 .83587 .30396 Mtetra
.869 .818 .796 r
.83587 .30396 .84301 .31394 .85901 .29444 .85196 .28427 Mtetra
.664 .741 .908 r
.23376 .44416 .24313 .45288 .25707 .44817 .24775 .4394 Mtetra
.24775 .4394 .25707 .44817 .27108 .44343 .2618 .43461 Mtetra
.663 .741 .908 r
.2618 .43461 .27108 .44343 .28517 .43867 .27594 .4298 Mtetra
.27594 .4298 .28517 .43867 .29934 .43388 .29015 .42497 Mtetra
.29015 .42497 .29934 .43388 .31358 .42908 .30443 .42012 Mtetra
.30443 .42012 .31358 .42908 .32789 .42426 .3188 .41525 Mtetra
.662 .741 .908 r
.3188 .41525 .32789 .42426 .34229 .41945 .33324 .41038 Mtetra
.661 .74 .909 r
.33324 .41038 .34229 .41945 .35676 .41466 .34776 .40554 Mtetra
.659 .74 .91 r
.34776 .40554 .35676 .41466 .3713 .40993 .36235 .40075 Mtetra
.655 .738 .911 r
.36235 .40075 .3713 .40993 .38592 .40532 .37702 .39608 Mtetra
.648 .736 .913 r
.37702 .39608 .38592 .40532 .40062 .40095 .39176 .39162 Mtetra
.638 .732 .916 r
.39176 .39162 .40062 .40095 .41538 .39694 .40658 .38752 Mtetra
.621 .725 .921 r
.40658 .38752 .41538 .39694 .43022 .39352 .42147 .38398 Mtetra
.594 .714 .927 r
.42147 .38398 .43022 .39352 .44514 .39097 .43643 .38127 Mtetra
.553 .695 .934 r
.43643 .38127 .44514 .39097 .46013 .38965 .45147 .37975 Mtetra
.491 .664 .939 r
.45147 .37975 .46013 .38965 .47522 .38998 .4666 .37983 Mtetra
.401 .615 .937 r
.4666 .37983 .47522 .38998 .49043 .39242 .48184 .38196 Mtetra
.277 .54 .919 r
.48184 .38196 .49043 .39242 .50577 .39745 .49721 .38661 Mtetra
.122 .436 .875 r
.49721 .38661 .50577 .39745 .5213 .40541 .51276 .39414 Mtetra
0 .315 .805 r
.51276 .39414 .5213 .40541 .53705 .41652 .52852 .40475 Mtetra
0 .2 .724 r
.52852 .40475 .53705 .41652 .55309 .43069 .54455 .4184 Mtetra
0 .115 .657 r
.54455 .4184 .55309 .43069 .56944 .44747 .56089 .43465 Mtetra
0 .072 .623 r
.56089 .43465 .56944 .44747 .58614 .46596 .57757 .45266 Mtetra
0 .079 .632 r
.57757 .45266 .58614 .46596 .60318 .48485 .59459 .47115 Mtetra
0 .142 .685 r
.59459 .47115 .60318 .48485 .62053 .50242 .61192 .48846 Mtetra
0 .261 .77 r
.61192 .48846 .62053 .50242 .6381 .51678 .62949 .50272 Mtetra
.187 .42 .854 r
.62949 .50272 .6381 .51678 .65578 .52608 .64719 .51212 Mtetra
.432 .57 .892 r
.64719 .51212 .65578 .52608 .67343 .52884 .66489 .51515 Mtetra
.626 .673 .876 r
.66489 .51515 .67343 .52884 .69091 .52417 .68244 .51089 Mtetra
.751 .73 .833 r
.68244 .51089 .69091 .52417 .70809 .51198 .69972 .49921 Mtetra
.825 .759 .79 r
.69972 .49921 .70809 .51198 .72489 .49297 .71664 .48075 Mtetra
.868 .774 .755 r
.71664 .48075 .72489 .49297 .7413 .46854 .7332 .45683 Mtetra
.893 .783 .732 r
.7332 .45683 .7413 .46854 .75735 .44046 .7494 .42921 Mtetra
.906 .79 .721 r
.7494 .42921 .75735 .44046 .77313 .41067 .76533 .39976 Mtetra
.911 .796 .72 r
.76533 .39976 .77313 .41067 .78875 .38091 .78111 .37025 Mtetra
.91 .801 .728 r
.78111 .37025 .78875 .38091 .80435 .35263 .79684 .3421 Mtetra
.901 .806 .744 r
.79684 .3421 .80435 .35263 .82002 .32679 .81264 .31631 Mtetra
.887 .809 .767 r
.81264 .31631 .82002 .32679 .83587 .30396 .8286 .29345 Mtetra
.865 .81 .793 r
.8286 .29345 .83587 .30396 .85196 .28427 .8448 .27369 Mtetra
.664 .741 .908 r
.2243 .43535 .23376 .44416 .24775 .4394 .23833 .43054 Mtetra
.23833 .43054 .24775 .4394 .2618 .43461 .25243 .42571 Mtetra
.663 .741 .908 r
.25243 .42571 .2618 .43461 .27594 .4298 .26661 .42085 Mtetra
.26661 .42085 .27594 .4298 .29015 .42497 .28087 .41597 Mtetra
.28087 .41597 .29015 .42497 .30443 .42012 .2952 .41106 Mtetra
.2952 .41106 .30443 .42012 .3188 .41525 .30961 .40615 Mtetra
.662 .741 .908 r
.30961 .40615 .3188 .41525 .33324 .41038 .3241 .40123 Mtetra
.661 .74 .909 r
.3241 .40123 .33324 .41038 .34776 .40554 .33867 .39632 Mtetra
.659 .74 .91 r
.33867 .39632 .34776 .40554 .36235 .40075 .35331 .39147 Mtetra
.655 .738 .911 r
.35331 .39147 .36235 .40075 .37702 .39608 .36803 .38673 Mtetra
.649 .736 .913 r
.36803 .38673 .37702 .39608 .39176 .39162 .38282 .38219 Mtetra
.639 .732 .916 r
.38282 .38219 .39176 .39162 .40658 .38752 .39769 .37799 Mtetra
.623 .726 .92 r
.39769 .37799 .40658 .38752 .42147 .38398 .41263 .37432 Mtetra
.598 .715 .926 r
.41263 .37432 .42147 .38398 .43643 .38127 .42764 .37144 Mtetra
.56 .697 .932 r
.42764 .37144 .43643 .38127 .45147 .37975 .44273 .3697 Mtetra
.502 .668 .937 r
.44273 .3697 .45147 .37975 .4666 .37983 .4579 .36949 Mtetra
.419 .622 .936 r
.4579 .36949 .4666 .37983 .48184 .38196 .47317 .37126 Mtetra
.304 .552 .921 r
.47317 .37126 .48184 .38196 .49721 .38661 .48857 .37546 Mtetra
.162 .456 .884 r
.48857 .37546 .49721 .38661 .51276 .39414 .50414 .38246 Mtetra
.01 .344 .823 r
.50414 .38246 .51276 .39414 .52852 .40475 .51991 .39246 Mtetra
0 .236 .752 r
.51991 .39246 .52852 .40475 .54455 .4184 .53593 .40544 Mtetra
0 .154 .692 r
.53593 .40544 .54455 .4184 .56089 .43465 .55225 .42099 Mtetra
0 .113 .661 r
.55225 .42099 .56089 .43465 .57757 .45266 .56891 .43833 Mtetra
0 .119 .669 r
.56891 .43833 .57757 .45266 .59459 .47115 .5859 .45622 Mtetra
0 .178 .713 r
.5859 .45622 .59459 .47115 .61192 .48846 .60321 .47306 Mtetra
.02 .285 .781 r
.60321 .47306 .61192 .48846 .62949 .50272 .62076 .48704 Mtetra
.231 .421 .843 r
.62076 .48704 .62949 .50272 .64719 .51212 .63847 .49638 Mtetra
.445 .549 .868 r
.63847 .49638 .64719 .51212 .66489 .51515 .65619 .49958 Mtetra
.616 .641 .853 r
.65619 .49958 .66489 .51515 .68244 .51089 .6738 .4957 Mtetra
.732 .698 .818 r
.6738 .4957 .68244 .51089 .69972 .49921 .69118 .48457 Mtetra
.805 .731 .782 r
.69118 .48457 .69972 .49921 .71664 .48075 .70822 .46675 Mtetra
.85 .75 .752 r
.70822 .46675 .71664 .48075 .7332 .45683 .72492 .4435 Mtetra
.878 .763 .732 r
.72492 .4435 .7332 .45683 .7494 .42921 .74128 .41652 Mtetra
.893 .773 .722 r
.74128 .41652 .7494 .42921 .76533 .39976 .75737 .38762 Mtetra
.9 .781 .721 r
.75737 .38762 .76533 .39976 .78111 .37025 .7733 .35855 Mtetra
.9 .789 .729 r
.7733 .35855 .78111 .37025 .79684 .3421 .78918 .33072 Mtetra
.894 .795 .744 r
.78918 .33072 .79684 .3421 .81264 .31631 .80512 .30515 Mtetra
.88 .8 .766 r
.80512 .30515 .81264 .31631 .8286 .29345 .82121 .2824 Mtetra
.86 .802 .792 r
.82121 .2824 .8286 .29345 .8448 .27369 .83753 .26269 Mtetra
.664 .741 .908 r
.21474 .42645 .2243 .43535 .23833 .43054 .22882 .42159 Mtetra
.22882 .42159 .23833 .43054 .25243 .42571 .24296 .41671 Mtetra
.663 .741 .908 r
.24296 .41671 .25243 .42571 .26661 .42085 .25719 .4118 Mtetra
.25719 .4118 .26661 .42085 .28087 .41597 .27149 .40687 Mtetra
.27149 .40687 .28087 .41597 .2952 .41106 .28587 .40192 Mtetra
.28587 .40192 .2952 .41106 .30961 .40615 .30033 .39695 Mtetra
.662 .741 .908 r
.30033 .39695 .30961 .40615 .3241 .40123 .31487 .39198 Mtetra
.661 .741 .909 r
.31487 .39198 .3241 .40123 .33867 .39632 .32948 .38702 Mtetra
.659 .74 .909 r
.32948 .38702 .33867 .39632 .35331 .39147 .34418 .3821 Mtetra
.656 .739 .911 r
.34418 .3821 .35331 .39147 .36803 .38673 .35895 .37729 Mtetra
.65 .736 .912 r
.35895 .37729 .36803 .38673 .38282 .38219 .37379 .37266 Mtetra
.641 .733 .915 r
.37379 .37266 .38282 .38219 .39769 .37799 .38871 .36835 Mtetra
.626 .726 .919 r
.38871 .36835 .39769 .37799 .41263 .37432 .4037 .36454 Mtetra
.603 .716 .924 r
.4037 .36454 .41263 .37432 .42764 .37144 .41876 .36148 Mtetra
.567 .699 .93 r
.41876 .36148 .42764 .37144 .44273 .3697 .43389 .3595 Mtetra
.514 .672 .935 r
.43389 .3595 .44273 .3697 .4579 .36949 .44911 .35898 Mtetra
.437 .629 .935 r
.44911 .35898 .4579 .36949 .47317 .37126 .46442 .36034 Mtetra
.332 .565 .923 r
.46442 .36034 .47317 .37126 .48857 .37546 .47985 .36404 Mtetra
.203 .478 .892 r
.47985 .36404 .48857 .37546 .50414 .38246 .49544 .37042 Mtetra
.063 .374 .84 r
.49544 .37042 .50414 .38246 .51991 .39246 .51122 .37971 Mtetra
0 .273 .778 r
.51122 .37971 .51991 .39246 .53593 .40544 .52724 .39188 Mtetra
0 .195 .725 r
.52724 .39188 .53593 .40544 .55225 .42099 .54355 .40659 Mtetra
0 .155 .696 r
.54355 .40659 .55225 .42099 .56891 .43833 .56017 .42307 Mtetra
0 .16 .701 r
.56017 .42307 .56891 .43833 .5859 .45622 .57713 .44017 Mtetra
0 .212 .736 r
.57713 .44017 .5859 .45622 .60321 .47306 .5944 .45635 Mtetra
.08 .306 .788 r
.5944 .45635 .60321 .47306 .62076 .48704 .61193 .46988 Mtetra
.268 .422 .832 r
.61193 .46988 .62076 .48704 .63847 .49638 .62963 .47901 Mtetra
.455 .532 .847 r
.62963 .47901 .63847 .49638 .65619 .49958 .64737 .48227 Mtetra
.607 .615 .834 r
.64737 .48227 .65619 .49958 .6738 .4957 .66503 .47874 Mtetra
.715 .671 .805 r
.66503 .47874 .6738 .4957 .69118 .48457 .68248 .46816 Mtetra
.787 .705 .775 r
.68248 .46816 .69118 .48457 .70822 .46675 .69964 .45107 Mtetra
.833 .728 .749 r
.69964 .45107 .70822 .46675 .72492 .4435 .71648 .42863 Mtetra
.862 .744 .731 r
.71648 .42863 .72492 .4435 .74128 .41652 .73299 .40244 Mtetra
.879 .756 .722 r
.73299 .40244 .74128 .41652 .75737 .38762 .74925 .37428 Mtetra
.888 .767 .722 r
.74925 .37428 .75737 .38762 .7733 .35855 .76535 .34584 Mtetra
.89 .776 .73 r
.76535 .34584 .7733 .35855 .78918 .33072 .78139 .31852 Mtetra
.885 .784 .745 r
.78139 .31852 .78918 .33072 .80512 .30515 .79748 .29332 Mtetra
.873 .791 .766 r
.79748 .29332 .80512 .30515 .82121 .2824 .81371 .27083 Mtetra
.855 .794 .791 r
.81371 .27083 .82121 .2824 .83753 .26269 .83014 .25127 Mtetra
.664 .741 .908 r
.20509 .41746 .21474 .42645 .22882 .42159 .21921 .41256 Mtetra
.21921 .41256 .22882 .42159 .24296 .41671 .2334 .40763 Mtetra
.663 .741 .908 r
.2334 .40763 .24296 .41671 .25719 .4118 .24767 .40267 Mtetra
.24767 .40267 .25719 .4118 .27149 .40687 .26202 .39769 Mtetra
.26202 .39769 .27149 .40687 .28587 .40192 .27645 .39268 Mtetra
.27645 .39268 .28587 .40192 .30033 .39695 .29095 .38766 Mtetra
.662 .741 .908 r
.29095 .38766 .30033 .39695 .31487 .39198 .30554 .38263 Mtetra
.661 .741 .909 r
.30554 .38263 .31487 .39198 .32948 .38702 .3202 .37761 Mtetra
.66 .74 .909 r
.3202 .37761 .32948 .38702 .34418 .3821 .33495 .37263 Mtetra
.657 .739 .91 r
.33495 .37263 .34418 .3821 .35895 .37729 .34977 .36775 Mtetra
.651 .737 .912 r
.34977 .36775 .35895 .37729 .37379 .37266 .36466 .36303 Mtetra
.643 .733 .915 r
.36466 .36303 .37379 .37266 .38871 .36835 .37963 .35861 Mtetra
.629 .727 .918 r
.37963 .35861 .38871 .36835 .4037 .36454 .39467 .35465 Mtetra
.607 .718 .923 r
.39467 .35465 .4037 .36454 .41876 .36148 .40979 .3514 Mtetra
.574 .702 .929 r
.40979 .3514 .41876 .36148 .43389 .3595 .42497 .34916 Mtetra
.525 .676 .933 r
.42497 .34916 .43389 .3595 .44911 .35898 .44023 .3483 Mtetra
.456 .637 .934 r
.44023 .3483 .44911 .35898 .46442 .36034 .45559 .34923 Mtetra
.361 .579 .924 r
.45559 .34923 .46442 .36034 .47985 .36404 .47105 .35236 Mtetra
.244 .499 .899 r
.47105 .35236 .47985 .36404 .49544 .37042 .48666 .35806 Mtetra
.116 .405 .856 r
.48666 .35806 .49544 .37042 .51122 .37971 .50246 .36655 Mtetra
.001 .311 .802 r
.50246 .36655 .51122 .37971 .52724 .39188 .51847 .37781 Mtetra
0 .237 .755 r
.51847 .37781 .52724 .39188 .54355 .40659 .53476 .39153 Mtetra
0 .198 .728 r
.53476 .39153 .54355 .40659 .56017 .42307 .55136 .407 Mtetra
0 .201 .728 r
.55136 .407 .56017 .42307 .57713 .44017 .56828 .42314 Mtetra
0 .246 .754 r
.56828 .42314 .57713 .44017 .5944 .45635 .58551 .43849 Mtetra
.134 .326 .791 r
.58551 .43849 .5944 .45635 .61193 .46988 .60301 .45139 Mtetra
.3 .425 .822 r
.60301 .45139 .61193 .46988 .62963 .47901 .62069 .46017 Mtetra
.464 .52 .83 r
.62069 .46017 .62963 .47901 .64737 .48227 .63844 .46341 Mtetra
.599 .594 .818 r
.63844 .46341 .64737 .48227 .66503 .47874 .65613 .46016 Mtetra
.7 .647 .794 r
.65613 .46016 .66503 .47874 .68248 .46816 .67366 .45015 Mtetra
.769 .683 .768 r
.67366 .45015 .68248 .46816 .69964 .45107 .69092 .43384 Mtetra
.816 .708 .747 r
.69092 .43384 .69964 .45107 .71648 .42863 .70789 .41231 Mtetra
.846 .727 .731 r
.70789 .41231 .71648 .42863 .73299 .40244 .72456 .38706 Mtetra
.866 .741 .724 r
.72456 .38706 .73299 .40244 .74925 .37428 .74099 .35981 Mtetra
.876 .754 .724 r
.74099 .35981 .74925 .37428 .76535 .34584 .75725 .33217 Mtetra
.879 .765 .732 r
.75725 .33217 .76535 .34584 .78139 .31852 .77346 .30551 Mtetra
.876 .774 .746 r
.77346 .30551 .78139 .31852 .79748 .29332 .7897 .28084 Mtetra
.865 .782 .767 r
.7897 .28084 .79748 .29332 .81371 .27083 .80608 .25874 Mtetra
.848 .786 .791 r
.80608 .25874 .81371 .27083 .83014 .25127 .82265 .23944 Mtetra
.664 .741 .908 r
.19534 .40839 .20509 .41746 .21921 .41256 .2095 .40343 Mtetra
.2095 .40343 .21921 .41256 .2334 .40763 .22374 .39845 Mtetra
.663 .741 .908 r
.22374 .39845 .2334 .40763 .24767 .40267 .23806 .39344 Mtetra
.23806 .39344 .24767 .40267 .26202 .39769 .25245 .38841 Mtetra
.25245 .38841 .26202 .39769 .27645 .39268 .26693 .38335 Mtetra
.26693 .38335 .27645 .39268 .29095 .38766 .28148 .37827 Mtetra
.28148 .37827 .29095 .38766 .30554 .38263 .29612 .37319 Mtetra
.662 .741 .909 r
.29612 .37319 .30554 .38263 .3202 .37761 .31083 .36811 Mtetra
.66 .74 .909 r
.31083 .36811 .3202 .37761 .33495 .37263 .32562 .36307 Mtetra
.657 .739 .91 r
.32562 .36307 .33495 .37263 .34977 .36775 .3405 .35811 Mtetra
.652 .737 .912 r
.3405 .35811 .34977 .36775 .36466 .36303 .35544 .3533 Mtetra
.644 .734 .914 r
.35544 .3533 .36466 .36303 .37963 .35861 .37047 .34876 Mtetra
.631 .728 .917 r
.37047 .34876 .37963 .35861 .39467 .35465 .38556 .34466 Mtetra
.612 .719 .922 r
.38556 .34466 .39467 .35465 .40979 .3514 .40072 .34121 Mtetra
.582 .704 .927 r
.40072 .34121 .40979 .3514 .42497 .34916 .41596 .3387 Mtetra
.537 .681 .931 r
.41596 .3387 .42497 .34916 .44023 .3483 .43127 .33748 Mtetra
.474 .645 .932 r
.43127 .33748 .44023 .3483 .45559 .34923 .44667 .33794 Mtetra
.389 .592 .925 r
.44667 .33794 .45559 .34923 .47105 .35236 .46217 .34048 Mtetra
.284 .521 .905 r
.46217 .34048 .47105 .35236 .48666 .35806 .47781 .34544 Mtetra
.169 .435 .869 r
.47781 .34544 .48666 .35806 .50246 .36655 .49362 .35305 Mtetra
.063 .349 .823 r
.49362 .35305 .50246 .36655 .51847 .37781 .50964 .3633 Mtetra
0 .28 .781 r
.50964 .3633 .51847 .37781 .53476 .39153 .52591 .37592 Mtetra
0 .241 .755 r
.52591 .37592 .53476 .39153 .55136 .407 .54248 .39026 Mtetra
0 .24 .751 r
.54248 .39026 .55136 .407 .56828 .42314 .55937 .40529 Mtetra
.061 .278 .768 r
.55937 .40529 .56828 .42314 .58551 .43849 .57656 .41966 Mtetra
.182 .346 .793 r
.57656 .41966 .58551 .43849 .60301 .45139 .59401 .43179 Mtetra
.328 .429 .813 r
.59401 .43179 .60301 .45139 .62069 .46017 .61167 .44009 Mtetra
.472 .511 .817 r
.61167 .44009 .62069 .46017 .63844 .46341 .62941 .44319 Mtetra
.593 .578 .806 r
.62941 .44319 .63844 .46341 .65613 .46016 .64713 .44017 Mtetra
.686 .628 .785 r
.64713 .44017 .65613 .46016 .67366 .45015 .66471 .43072 Mtetra
.753 .664 .763 r
.66471 .43072 .67366 .45015 .69092 .43384 .68207 .41523 Mtetra
.8 .691 .745 r
.68207 .41523 .69092 .43384 .70789 .41231 .69917 .39468 Mtetra
.831 .711 .732 r
.69917 .39468 .70789 .41231 .72456 .38706 .71599 .3705 Mtetra
.852 .727 .726 r
.71599 .3705 .72456 .38706 .74099 .35981 .73258 .34429 Mtetra
.864 .741 .726 r
.73258 .34429 .74099 .35981 .75725 .33217 .74902 .3176 Mtetra
.868 .754 .734 r
.74902 .3176 .75725 .33217 .77346 .30551 .7654 .29176 Mtetra
.866 .765 .749 r
.7654 .29176 .77346 .30551 .7897 .28084 .78181 .26774 Mtetra
.857 .773 .769 r
.78181 .26774 .7897 .28084 .80608 .25874 .79834 .24614 Mtetra
.841 .779 .792 r
.79834 .24614 .80608 .25874 .82265 .23944 .81504 .22721 Mtetra
.664 .741 .908 r
.18549 .39922 .19534 .40839 .2095 .40343 .1997 .39421 Mtetra
.1997 .39421 .2095 .40343 .22374 .39845 .21398 .38918 Mtetra
.21398 .38918 .22374 .39845 .23806 .39344 .22835 .38412 Mtetra
.663 .741 .908 r
.22835 .38412 .23806 .39344 .25245 .38841 .24279 .37903 Mtetra
.24279 .37903 .25245 .38841 .26693 .38335 .25731 .37392 Mtetra
.25731 .37392 .26693 .38335 .28148 .37827 .27191 .36879 Mtetra
.27191 .36879 .28148 .37827 .29612 .37319 .2866 .36365 Mtetra
.662 .741 .908 r
.2866 .36365 .29612 .37319 .31083 .36811 .30136 .35851 Mtetra
.66 .74 .909 r
.30136 .35851 .31083 .36811 .32562 .36307 .3162 .3534 Mtetra
.658 .739 .91 r
.3162 .3534 .32562 .36307 .3405 .35811 .33113 .34837 Mtetra
.653 .737 .911 r
.33113 .34837 .3405 .35811 .35544 .3533 .34613 .34347 Mtetra
.646 .734 .913 r
.34613 .34347 .35544 .3533 .37047 .34876 .3612 .33882 Mtetra
.634 .729 .916 r
.3612 .33882 .37047 .34876 .38556 .34466 .37635 .33456 Mtetra
.616 .721 .92 r
.37635 .33456 .38556 .34466 .40072 .34121 .39157 .3309 Mtetra
.589 .707 .925 r
.39157 .3309 .40072 .34121 .41596 .3387 .40685 .32811 Mtetra
.549 .686 .929 r
.40685 .32811 .41596 .3387 .43127 .33748 .42222 .32652 Mtetra
.492 .653 .931 r
.42222 .32652 .43127 .33748 .44667 .33794 .43766 .3265 Mtetra
.417 .606 .926 r
.43766 .3265 .44667 .33794 .46217 .34048 .4532 .32842 Mtetra
.323 .542 .909 r
.4532 .32842 .46217 .34048 .47781 .34544 .46887 .3326 Mtetra
.22 .465 .88 r
.46887 .3326 .47781 .34544 .49362 .35305 .4847 .33928 Mtetra
.124 .386 .841 r
.4847 .33928 .49362 .35305 .50964 .3633 .50073 .34846 Mtetra
.055 .321 .804 r
.50073 .34846 .50964 .3633 .52591 .37592 .517 .35989 Mtetra
.028 .282 .778 r
.517 .35989 .52591 .37592 .54248 .39026 .53354 .37298 Mtetra
.049 .278 .771 r
.53354 .37298 .54248 .39026 .55937 .40529 .55039 .38679 Mtetra
.118 .308 .779 r
.55039 .38679 .55937 .40529 .57656 .41966 .56754 .40004 Mtetra
.225 .364 .795 r
.56754 .40004 .57656 .41966 .59401 .43179 .58495 .41127 Mtetra
.353 .435 .807 r
.58495 .41127 .59401 .43179 .61167 .44009 .60257 .41898 Mtetra
.479 .505 .807 r
.60257 .41898 .61167 .44009 .62941 .44319 .6203 .42185 Mtetra
.588 .565 .796 r
.6203 .42185 .62941 .44319 .64713 .44017 .63804 .41899 Mtetra
.674 .613 .778 r
.63804 .41899 .64713 .44017 .66471 .43072 .65567 .41007 Mtetra
.738 .648 .76 r
.65567 .41007 .66471 .43072 .68207 .41523 .67312 .39542 Mtetra
.784 .676 .744 r
.67312 .39542 .68207 .41523 .69917 .39468 .69033 .37592 Mtetra
.817 .697 .733 r
.69033 .37592 .69917 .39468 .71599 .3705 .7073 .35289 Mtetra
.838 .715 .728 r
.7073 .35289 .71599 .3705 .73258 .34429 .72406 .32782 Mtetra
.851 .73 .729 r
.72406 .32782 .73258 .34429 .74902 .3176 .74067 .30221 Mtetra
.857 .744 .737 r
.74067 .30221 .74902 .3176 .7654 .29176 .75722 .27731 Mtetra
.856 .756 .752 r
.75722 .27731 .7654 .29176 .78181 .26774 .7738 .25407 Mtetra
.848 .765 .771 r
.7738 .25407 .78181 .26774 .79834 .24614 .79048 .23308 Mtetra
.833 .772 .794 r
.79048 .23308 .79834 .24614 .81504 .22721 .80733 .21459 Mtetra
.664 .741 .908 r
.17555 .38995 .18549 .39922 .1997 .39421 .1898 .3849 Mtetra
.1898 .3849 .1997 .39421 .21398 .38918 .20413 .37981 Mtetra
.20413 .37981 .21398 .38918 .22835 .38412 .21853 .3747 Mtetra
.663 .741 .908 r
.21853 .3747 .22835 .38412 .24279 .37903 .23302 .36956 Mtetra
.23302 .36956 .24279 .37903 .25731 .37392 .24759 .3644 Mtetra
.24759 .3644 .25731 .37392 .27191 .36879 .26225 .35921 Mtetra
.26225 .35921 .27191 .36879 .2866 .36365 .27698 .35401 Mtetra
.662 .741 .908 r
.27698 .35401 .2866 .36365 .30136 .35851 .29179 .34881 Mtetra
.661 .74 .909 r
.29179 .34881 .30136 .35851 .3162 .3534 .30669 .34364 Mtetra
.658 .739 .91 r
.30669 .34364 .3162 .3534 .33113 .34837 .32166 .33852 Mtetra
.654 .738 .911 r
.32166 .33852 .33113 .34837 .34613 .34347 .33671 .33353 Mtetra
.648 .735 .913 r
.33671 .33353 .34613 .34347 .3612 .33882 .35184 .32876 Mtetra
.637 .73 .915 r
.35184 .32876 .3612 .33882 .37635 .33456 .36704 .32435 Mtetra
.621 .722 .919 r
.36704 .32435 .37635 .33456 .39157 .3309 .38231 .32049 Mtetra
.596 .71 .923 r
.38231 .32049 .39157 .3309 .40685 .32811 .39766 .31742 Mtetra
.56 .691 .927 r
.39766 .31742 .40685 .32811 .42222 .32652 .41307 .31546 Mtetra
.51 .661 .929 r
.41307 .31546 .42222 .32652 .43766 .3265 .42857 .31493 Mtetra
.443 .619 .926 r
.42857 .31493 .43766 .3265 .4532 .32842 .44415 .31621 Mtetra
.36 .562 .913 r
.44415 .31621 .4532 .32842 .46887 .3326 .45986 .3196 Mtetra
.268 .493 .889 r
.45986 .3196 .46887 .3326 .4847 .33928 .47571 .3253 Mtetra
.182 .421 .856 r
.47571 .3253 .4847 .33928 .50073 .34846 .49175 .33336 Mtetra
.119 .36 .823 r
.49175 .33336 .50073 .34846 .517 .35989 .50801 .34353 Mtetra
.093 .323 .798 r
.50801 .34353 .517 .35989 .53354 .37298 .52454 .3553 Mtetra
.11 .315 .788 r
.52454 .3553 .53354 .37298 .55039 .38679 .54135 .36779 Mtetra
.17 .337 .789 r
.54135 .36779 .55039 .38679 .56754 .40004 .55846 .37983 Mtetra
.264 .383 .797 r
.55846 .37983 .56754 .40004 .58495 .41127 .57583 .39006 Mtetra
.375 .442 .802 r
.57583 .39006 .58495 .41127 .60257 .41898 .59341 .39707 Mtetra
.486 .502 .799 r
.59341 .39707 .60257 .41898 .6203 .42185 .61113 .39963 Mtetra
.585 .556 .789 r
.61113 .39963 .6203 .42185 .63804 .41899 .62887 .39686 Mtetra
.664 .6 .773 r
.62887 .39686 .63804 .41899 .65567 .41007 .64655 .38844 Mtetra
.725 .635 .757 r
.64655 .38844 .65567 .41007 .67312 .39542 .66407 .37462 Mtetra
.77 .663 .744 r
.66407 .37462 .67312 .39542 .69033 .37592 .68139 .3562 Mtetra
.803 .685 .735 r
.68139 .3562 .69033 .37592 .7073 .35289 .6985 .33437 Mtetra
.825 .704 .731 r
.6985 .33437 .7073 .35289 .72406 .32782 .71542 .31055 Mtetra
.839 .72 .733 r
.71542 .31055 .72406 .32782 .74067 .30221 .73221 .2861 Mtetra
.846 .735 .741 r
.73221 .2861 .74067 .30221 .75722 .27731 .74893 .26224 Mtetra
.845 .747 .755 r
.74893 .26224 .75722 .27731 .7738 .25407 .76568 .23987 Mtetra
.838 .758 .774 r
.76568 .23987 .7738 .25407 .79048 .23308 .78252 .21958 Mtetra
.825 .766 .796 r
.78252 .21958 .79048 .23308 .80733 .21459 .79952 .20161 Mtetra
.664 .741 .908 r
.1655 .38059 .17555 .38995 .1898 .3849 .17979 .37549 Mtetra
.17979 .37549 .1898 .3849 .20413 .37981 .19417 .37035 Mtetra
.19417 .37035 .20413 .37981 .21853 .3747 .20862 .36518 Mtetra
.663 .741 .908 r
.20862 .36518 .21853 .3747 .23302 .36956 .22316 .35999 Mtetra
.22316 .35999 .23302 .36956 .24759 .3644 .23778 .35477 Mtetra
.23778 .35477 .24759 .3644 .26225 .35921 .25248 .34953 Mtetra
.25248 .34953 .26225 .35921 .27698 .35401 .26726 .34428 Mtetra
.662 .741 .908 r
.26726 .34428 .27698 .35401 .29179 .34881 .28212 .33902 Mtetra
.661 .74 .909 r
.28212 .33902 .29179 .34881 .30669 .34364 .29707 .33377 Mtetra
.659 .739 .909 r
.29707 .33377 .30669 .34364 .32166 .33852 .3121 .32858 Mtetra
.655 .738 .91 r
.3121 .32858 .32166 .33852 .33671 .33353 .3272 .3235 Mtetra
.649 .735 .912 r
.3272 .3235 .33671 .33353 .35184 .32876 .34238 .31861 Mtetra
.64 .731 .915 r
.34238 .31861 .35184 .32876 .36704 .32435 .35764 .31405 Mtetra
.625 .724 .918 r
.35764 .31405 .36704 .32435 .38231 .32049 .37297 .30998 Mtetra
.603 .713 .921 r
.37297 .30998 .38231 .32049 .39766 .31742 .38836 .30663 Mtetra
.571 .695 .925 r
.38836 .30663 .39766 .31742 .41307 .31546 .40383 .30429 Mtetra
.527 .669 .927 r
.40383 .30429 .41307 .31546 .42857 .31493 .41938 .30326 Mtetra
.468 .631 .925 r
.41938 .30326 .42857 .31493 .44415 .31621 .43502 .30389 Mtetra
.394 .581 .915 r
.43502 .30389 .44415 .31621 .45986 .3196 .45076 .30646 Mtetra
.313 .52 .896 r
.45076 .30646 .45986 .3196 .47571 .3253 .46664 .31118 Mtetra
.237 .455 .869 r
.46664 .31118 .47571 .3253 .49175 .33336 .4827 .31808 Mtetra
.179 .398 .839 r
.4827 .31808 .49175 .33336 .50801 .34353 .49896 .32697 Mtetra
.153 .361 .815 r
.49896 .32697 .50801 .34353 .52454 .3553 .51548 .33736 Mtetra
.167 .349 .802 r
.51548 .33736 .52454 .3553 .54135 .36779 .53227 .34847 Mtetra
.218 .365 .798 r
.53227 .34847 .54135 .36779 .55846 .37983 .54933 .35923 Mtetra
.299 .401 .799 r
.54933 .35923 .55846 .37983 .57583 .39006 .56666 .36837 Mtetra
.395 .45 .8 r
.56666 .36837 .57583 .39006 .59341 .39707 .58421 .3746 Mtetra
.494 .502 .794 r
.58421 .3746 .59341 .39707 .61113 .39963 .6019 .37676 Mtetra
.582 .55 .784 r
.6019 .37676 .61113 .39963 .62887 .39686 .61965 .37403 Mtetra
.656 .591 .77 r
.61965 .37403 .62887 .39686 .64655 .38844 .63735 .36606 Mtetra
.714 .624 .756 r
.63735 .36606 .64655 .38844 .66407 .37462 .65495 .35305 Mtetra
.757 .652 .745 r
.65495 .35305 .66407 .37462 .68139 .3562 .67237 .33571 Mtetra
.79 .674 .737 r
.67237 .33571 .68139 .3562 .6985 .33437 .68961 .31513 Mtetra
.812 .694 .734 r
.68961 .31513 .6985 .33437 .71542 .31055 .70669 .29259 Mtetra
.827 .711 .737 r
.70669 .29259 .71542 .31055 .73221 .2861 .72364 .26938 Mtetra
.834 .726 .745 r
.72364 .26938 .73221 .2861 .74893 .26224 .74054 .24663 Mtetra
.835 .74 .759 r
.74054 .24663 .74893 .26224 .76568 .23987 .75745 .22521 Mtetra
.829 .751 .778 r
.75745 .22521 .76568 .23987 .78252 .21958 .77446 .20568 Mtetra
.816 .76 .799 r
.77446 .20568 .78252 .21958 .79952 .20161 .79161 .18831 Mtetra
.664 .741 .908 r
.15534 .37114 .1655 .38059 .17979 .37549 .16968 .36598 Mtetra
.16968 .36598 .17979 .37549 .19417 .37035 .1841 .36079 Mtetra
.1841 .36079 .19417 .37035 .20862 .36518 .19861 .35557 Mtetra
.663 .741 .908 r
.19861 .35557 .20862 .36518 .22316 .35999 .21319 .35032 Mtetra
.21319 .35032 .22316 .35999 .23778 .35477 .22786 .34505 Mtetra
.22786 .34505 .23778 .35477 .25248 .34953 .24261 .33975 Mtetra
.24261 .33975 .25248 .34953 .26726 .34428 .25744 .33444 Mtetra
.662 .741 .908 r
.25744 .33444 .26726 .34428 .28212 .33902 .27235 .32911 Mtetra
.661 .74 .909 r
.27235 .32911 .28212 .33902 .29707 .33377 .28735 .3238 Mtetra
.659 .74 .909 r
.28735 .3238 .29707 .33377 .3121 .32858 .30243 .31853 Mtetra
.656 .738 .91 r
.30243 .31853 .3121 .32858 .3272 .3235 .31759 .31336 Mtetra
.651 .736 .912 r
.31759 .31336 .3272 .3235 .34238 .31861 .33282 .30836 Mtetra
.642 .732 .914 r
.33282 .30836 .34238 .31861 .35764 .31405 .34814 .30364 Mtetra
.629 .725 .917 r
.34814 .30364 .35764 .31405 .37297 .30998 .36352 .29937 Mtetra
.61 .715 .92 r
.36352 .29937 .37297 .30998 .38836 .30663 .37898 .29574 Mtetra
.582 .7 .923 r
.37898 .29574 .38836 .30663 .40383 .30429 .3945 .29303 Mtetra
.542 .676 .925 r
.3945 .29303 .40383 .30429 .41938 .30326 .4101 .29151 Mtetra
.491 .643 .924 r
.4101 .29151 .41938 .30326 .43502 .30389 .42579 .29149 Mtetra
.427 .599 .917 r
.42579 .29149 .43502 .30389 .45076 .30646 .44158 .29325 Mtetra
.356 .544 .901 r
.44158 .29325 .45076 .30646 .46664 .31118 .4575 .29698 Mtetra
.287 .486 .878 r
.4575 .29698 .46664 .31118 .4827 .31808 .47358 .30271 Mtetra
.235 .434 .852 r
.47358 .30271 .4827 .31808 .49896 .32697 .48985 .31029 Mtetra
.21 .397 .83 r
.48985 .31029 .49896 .32697 .51548 .33736 .50636 .31929 Mtetra
.219 .383 .814 r
.50636 .31929 .51548 .33736 .53227 .34847 .52312 .32898 Mtetra
.262 .392 .806 r
.52312 .32898 .53227 .34847 .54933 .35923 .54016 .3384 Mtetra
.331 .42 .803 r
.54016 .3384 .54933 .35923 .56666 .36837 .55745 .3464 Mtetra
.415 .46 .799 r
.55745 .3464 .56666 .36837 .58421 .3746 .57496 .35179 Mtetra
.501 .504 .792 r
.57496 .35179 .58421 .3746 .6019 .37676 .59263 .35349 Mtetra
.581 .547 .781 r
.59263 .35349 .6019 .37676 .61965 .37403 .61037 .35073 Mtetra
.649 .584 .769 r
.61037 .35073 .61965 .37403 .63735 .36606 .62811 .34316 Mtetra
.703 .616 .756 r
.62811 .34316 .63735 .36606 .65495 .35305 .64576 .33093 Mtetra
.745 .643 .746 r
.64576 .33093 .65495 .35305 .67237 .33571 .66328 .31466 Mtetra
.777 .666 .74 r
.66328 .31466 .67237 .33571 .68961 .31513 .68065 .29533 Mtetra
.8 .686 .738 r
.68065 .29533 .68961 .31513 .70669 .29259 .69787 .2741 Mtetra
.815 .703 .742 r
.69787 .2741 .70669 .29259 .72364 .26938 .71498 .25216 Mtetra
.823 .719 .75 r
.71498 .25216 .72364 .26938 .74054 .24663 .73205 .23058 Mtetra
.824 .733 .764 r
.73205 .23058 .74054 .24663 .75745 .22521 .74913 .21016 Mtetra
.819 .745 .782 r
.74913 .21016 .75745 .22521 .77446 .20568 .7663 .19145 Mtetra
.808 .754 .803 r
.7663 .19145 .77446 .20568 .79161 .18831 .7836 .1747 Mtetra
.664 .741 .908 r
.14508 .36159 .15534 .37114 .16968 .36598 .15947 .35637 Mtetra
.15947 .35637 .16968 .36598 .1841 .36079 .17394 .35113 Mtetra
.17394 .35113 .1841 .36079 .19861 .35557 .18849 .34585 Mtetra
.663 .741 .908 r
.18849 .34585 .19861 .35557 .21319 .35032 .20312 .34055 Mtetra
.20312 .34055 .21319 .35032 .22786 .34505 .21783 .33522 Mtetra
.21783 .33522 .22786 .34505 .24261 .33975 .23263 .32987 Mtetra
.23263 .32987 .24261 .33975 .25744 .33444 .24751 .32449 Mtetra
.662 .741 .908 r
.24751 .32449 .25744 .33444 .27235 .32911 .26248 .31911 Mtetra
.662 .74 .909 r
.26248 .31911 .27235 .32911 .28735 .3238 .27753 .31373 Mtetra
.66 .74 .909 r
.27753 .31373 .28735 .3238 .30243 .31853 .29266 .30838 Mtetra
.657 .739 .91 r
.29266 .30838 .30243 .31853 .31759 .31336 .30787 .30312 Mtetra
.652 .736 .911 r
.30787 .30312 .31759 .31336 .33282 .30836 .32316 .298 Mtetra
.645 .733 .913 r
.32316 .298 .33282 .30836 .34814 .30364 .33853 .29313 Mtetra
.633 .727 .915 r
.33853 .29313 .34814 .30364 .36352 .29937 .35397 .28866 Mtetra
.616 .718 .918 r
.35397 .28866 .36352 .29937 .37898 .29574 .36949 .28477 Mtetra
.591 .704 .921 r
.36949 .28477 .37898 .29574 .3945 .29303 .38507 .28169 Mtetra
.557 .684 .924 r
.38507 .28169 .3945 .29303 .4101 .29151 .40073 .27968 Mtetra
.512 .654 .923 r
.40073 .27968 .4101 .29151 .42579 .29149 .41647 .27903 Mtetra
.456 .615 .917 r
.41647 .27903 .42579 .29149 .44158 .29325 .43231 .27999 Mtetra
.394 .567 .905 r
.43231 .27999 .44158 .29325 .4575 .29698 .44827 .28274 Mtetra
.334 .515 .886 r
.44827 .28274 .4575 .29698 .47358 .30271 .46438 .28732 Mtetra
.286 .467 .863 r
.46438 .28732 .47358 .30271 .48985 .31029 .48067 .2936 Mtetra
.262 .431 .842 r
.48067 .2936 .48985 .31029 .50636 .31929 .49718 .30119 Mtetra
.267 .415 .825 r
.49718 .30119 .50636 .31929 .52312 .32898 .51393 .30945 Mtetra
.302 .418 .814 r
.51393 .30945 .52312 .32898 .54016 .3384 .53094 .31752 Mtetra
.361 .439 .806 r
.53094 .31752 .54016 .3384 .55745 .3464 .5482 .32435 Mtetra
.433 .471 .799 r
.5482 .32435 .55745 .3464 .57496 .35179 .56568 .32885 Mtetra
.509 .508 .791 r
.56568 .32885 .57496 .35179 .59263 .35349 .58332 .33004 Mtetra
.581 .546 .78 r
.58332 .33004 .59263 .35349 .61037 .35073 .60106 .32719 Mtetra
.643 .58 .769 r
.60106 .32719 .61037 .35073 .62811 .34316 .61882 .31996 Mtetra
.694 .61 .758 r
.61882 .31996 .62811 .34316 .64576 .33093 .63652 .30846 Mtetra
.735 .636 .749 r
.63652 .30846 .64576 .33093 .66328 .31466 .65413 .29322 Mtetra
.766 .658 .744 r
.65413 .29322 .66328 .31466 .68065 .29533 .67161 .27512 Mtetra
.788 .679 .743 r
.67161 .27512 .68065 .29533 .69787 .2741 .68897 .2552 Mtetra
.804 .697 .747 r
.68897 .2552 .69787 .2741 .71498 .25216 .70624 .23456 Mtetra
.812 .713 .756 r
.70624 .23456 .71498 .25216 .73205 .23058 .72347 .21416 Mtetra
.814 .727 .769 r
.72347 .21416 .73205 .23058 .74913 .21016 .74072 .19477 Mtetra
.809 .74 .787 r
.74072 .19477 .74913 .21016 .7663 .19145 .75804 .17691 Mtetra
.799 .749 .807 r
.75804 .17691 .7663 .19145 .7836 .1747 .7755 .16084 Mtetra
.664 .741 .908 r
.13472 .35194 .14508 .36159 .15947 .35637 .14915 .34667 Mtetra
.14915 .34667 .15947 .35637 .17394 .35113 .16366 .34137 Mtetra
.16366 .34137 .17394 .35113 .18849 .34585 .17826 .33604 Mtetra
.663 .741 .908 r
.17826 .33604 .18849 .34585 .20312 .34055 .19294 .33068 Mtetra
.19294 .33068 .20312 .34055 .21783 .33522 .2077 .32529 Mtetra
.2077 .32529 .21783 .33522 .23263 .32987 .22255 .31988 Mtetra
.22255 .31988 .23263 .32987 .24751 .32449 .23748 .31445 Mtetra
.23748 .31445 .24751 .32449 .26248 .31911 .2525 .309 Mtetra
.662 .741 .908 r
.2525 .309 .26248 .31911 .27753 .31373 .2676 .30355 Mtetra
.66 .74 .909 r
.2676 .30355 .27753 .31373 .29266 .30838 .28278 .29813 Mtetra
.658 .739 .91 r
.28278 .29813 .29266 .30838 .30787 .30312 .29805 .29277 Mtetra
.654 .737 .911 r
.29805 .29277 .30787 .30312 .32316 .298 .3134 .28754 Mtetra
.647 .734 .912 r
.3134 .28754 .32316 .298 .33853 .29313 .32882 .28253 Mtetra
.637 .729 .914 r
.32882 .28253 .33853 .29313 .35397 .28866 .34432 .27786 Mtetra
.622 .721 .917 r
.34432 .27786 .35397 .28866 .36949 .28477 .3599 .27371 Mtetra
.6 .708 .92 r
.3599 .27371 .36949 .28477 .38507 .28169 .37554 .27028 Mtetra
.571 .69 .922 r
.37554 .27028 .38507 .28169 .40073 .27968 .39126 .2678 Mtetra
.531 .664 .922 r
.39126 .2678 .40073 .27968 .41647 .27903 .40706 .26654 Mtetra
.483 .63 .918 r
.40706 .26654 .41647 .27903 .43231 .27999 .42295 .26672 Mtetra
.429 .588 .908 r
.42295 .26672 .43231 .27999 .44827 .28274 .43896 .26851 Mtetra
.376 .542 .892 r
.43896 .26851 .44827 .28274 .46438 .28732 .4551 .27197 Mtetra
.333 .498 .872 r
.4551 .27197 .46438 .28732 .48067 .2936 .47142 .27696 Mtetra
.31 .464 .852 r
.47142 .27696 .48067 .2936 .49718 .30119 .48793 .28317 Mtetra
.312 .445 .834 r
.48793 .28317 .49718 .30119 .51393 .30945 .50468 .29002 Mtetra
.339 .443 .821 r
.50468 .29002 .51393 .30945 .53094 .31752 .52167 .29673 Mtetra
.388 .458 .811 r
.52167 .29673 .53094 .31752 .5482 .32435 .53891 .30238 Mtetra
.451 .483 .802 r
.53891 .30238 .5482 .32435 .56568 .32885 .55636 .30596 Mtetra
.517 .514 .792 r
.55636 .30596 .56568 .32885 .58332 .33004 .57398 .3066 Mtetra
.581 .547 .781 r
.57398 .3066 .58332 .33004 .60106 .32719 .59171 .30361 Mtetra
.638 .578 .77 r
.59171 .30361 .60106 .32719 .61882 .31996 .60949 .29667 Mtetra
.686 .606 .76 r
.60949 .29667 .61882 .31996 .63652 .30846 .62724 .28584 Mtetra
.725 .631 .753 r
.62724 .28584 .63652 .30846 .65413 .29322 .64492 .27159 Mtetra
.755 .653 .749 r
.64492 .27159 .65413 .29322 .67161 .27512 .66251 .25468 Mtetra
.777 .673 .749 r
.66251 .25468 .67161 .27512 .68897 .2552 .68 .23605 Mtetra
.792 .691 .753 r
.68 .23605 .68897 .2552 .70624 .23456 .69742 .21668 Mtetra
.801 .708 .762 r
.69742 .21668 .70624 .23456 .72347 .21416 .7148 .19747 Mtetra
.803 .722 .775 r
.7148 .19747 .72347 .21416 .74072 .19477 .73221 .17913 Mtetra
.799 .735 .793 r
.73221 .17913 .74072 .19477 .75804 .17691 .7497 .16213 Mtetra
.789 .745 .812 r
.7497 .16213 .75804 .17691 .7755 .16084 .7673 .14674 Mtetra
.664 .741 .908 r
.12424 .34218 .13472 .35194 .14915 .34667 .13872 .33686 Mtetra
.13872 .33686 .14915 .34667 .16366 .34137 .15328 .3315 Mtetra
.15328 .3315 .16366 .34137 .17826 .33604 .16793 .32612 Mtetra
.16793 .32612 .17826 .33604 .19294 .33068 .18265 .3207 Mtetra
.663 .741 .908 r
.18265 .3207 .19294 .33068 .2077 .32529 .19746 .31526 Mtetra
.19746 .31526 .2077 .32529 .22255 .31988 .21236 .30979 Mtetra
.21236 .30979 .22255 .31988 .23748 .31445 .22734 .30429 Mtetra
.22734 .30429 .23748 .31445 .2525 .309 .24241 .29878 Mtetra
.662 .741 .908 r
.24241 .29878 .2525 .309 .2676 .30355 .25757 .29326 Mtetra
.661 .74 .909 r
.25757 .29326 .2676 .30355 .28278 .29813 .2728 .28777 Mtetra
.659 .739 .909 r
.2728 .28777 .28278 .29813 .29805 .29277 .28813 .28232 Mtetra
.655 .737 .91 r
.28813 .28232 .29805 .29277 .3134 .28754 .30353 .27698 Mtetra
.649 .735 .912 r
.30353 .27698 .3134 .28754 .32882 .28253 .31901 .27183 Mtetra
.64 .73 .913 r
.31901 .27183 .32882 .28253 .34432 .27786 .33457 .26698 Mtetra
.627 .723 .916 r
.33457 .26698 .34432 .27786 .3599 .27371 .3502 .26257 Mtetra
.609 .712 .918 r
.3502 .26257 .3599 .27371 .37554 .27028 .36591 .2588 Mtetra
.583 .696 .92 r
.36591 .2588 .37554 .27028 .39126 .2678 .38169 .25587 Mtetra
.549 .674 .92 r
.38169 .25587 .39126 .2678 .40706 .26654 .39755 .25402 Mtetra
.508 .644 .917 r
.39755 .25402 .40706 .26654 .42295 .26672 .4135 .25346 Mtetra
.461 .607 .909 r
.4135 .25346 .42295 .26672 .43896 .26851 .42955 .25433 Mtetra
.415 .566 .896 r
.42955 .25433 .43896 .26851 .4551 .27197 .44574 .2567 Mtetra
.376 .526 .879 r
.44574 .2567 .4551 .27197 .47142 .27696 .46209 .26046 Mtetra
.354 .494 .86 r
.46209 .26046 .47142 .27696 .48793 .28317 .47862 .26532 Mtetra
.353 .474 .843 r
.47862 .26532 .48793 .28317 .50468 .29002 .49537 .27079 Mtetra
.374 .468 .828 r
.49537 .27079 .50468 .29002 .52167 .29673 .51236 .27617 Mtetra
.414 .477 .816 r
.51236 .27617 .52167 .29673 .53891 .30238 .52957 .28063 Mtetra
.467 .497 .805 r
.52957 .28063 .53891 .30238 .55636 .30596 .547 .28329 Mtetra
.526 .522 .794 r
.547 .28329 .55636 .30596 .57398 .3066 .5646 .28335 Mtetra
.583 .55 .784 r
.5646 .28335 .57398 .3066 .59171 .30361 .58233 .28018 Mtetra
.635 .578 .773 r
.58233 .28018 .59171 .30361 .60949 .29667 .60012 .27346 Mtetra
.679 .604 .764 r
.60012 .27346 .60949 .29667 .62724 .28584 .61792 .26325 Mtetra
.716 .627 .758 r
.61792 .26325 .62724 .28584 .64492 .27159 .63567 .24992 Mtetra
.745 .649 .754 r
.63567 .24992 .64492 .27159 .66251 .25468 .65336 .23414 Mtetra
.766 .669 .755 r
.65336 .23414 .66251 .25468 .68 .23605 .67097 .21675 Mtetra
.781 .687 .76 r
.67097 .21675 .68 .23605 .69742 .21668 .68853 .19863 Mtetra
.79 .703 .769 r
.68853 .19863 .69742 .21668 .7148 .19747 .70606 .18059 Mtetra
.793 .718 .782 r
.70606 .18059 .7148 .19747 .73221 .17913 .72363 .16328 Mtetra
.789 .731 .798 r
.72363 .16328 .73221 .17913 .7497 .16213 .74126 .14715 Mtetra
.78 .741 .817 r
.74126 .14715 .7497 .16213 .7673 .14674 .75901 .13245 Mtetra
.664 .741 .908 r
.11366 .33233 .12424 .34218 .13872 .33686 .12818 .32695 Mtetra
.12818 .32695 .13872 .33686 .15328 .3315 .14279 .32154 Mtetra
.14279 .32154 .15328 .3315 .16793 .32612 .15748 .31609 Mtetra
.15748 .31609 .16793 .32612 .18265 .3207 .17226 .31062 Mtetra
.663 .741 .908 r
.17226 .31062 .18265 .3207 .19746 .31526 .18712 .30512 Mtetra
.18712 .30512 .19746 .31526 .21236 .30979 .20207 .29958 Mtetra
.20207 .29958 .21236 .30979 .22734 .30429 .2171 .29403 Mtetra
.2171 .29403 .22734 .30429 .24241 .29878 .23222 .28845 Mtetra
.662 .741 .908 r
.23222 .28845 .24241 .29878 .25757 .29326 .24742 .28287 Mtetra
.661 .74 .909 r
.24742 .28287 .25757 .29326 .2728 .28777 .26271 .27729 Mtetra
.659 .739 .909 r
.26271 .27729 .2728 .28777 .28813 .28232 .27809 .27176 Mtetra
.656 .738 .91 r
.27809 .27176 .28813 .28232 .30353 .27698 .29355 .26631 Mtetra
.651 .735 .911 r
.29355 .26631 .30353 .27698 .31901 .27183 .30909 .26103 Mtetra
.644 .731 .913 r
.30909 .26103 .31901 .27183 .33457 .26698 .32471 .256 Mtetra
.632 .725 .915 r
.32471 .256 .33457 .26698 .3502 .26257 .34041 .25135 Mtetra
.616 .716 .917 r
.34041 .25135 .3502 .26257 .36591 .2588 .35617 .24726 Mtetra
.594 .702 .918 r
.35617 .24726 .36591 .2588 .38169 .25587 .37202 .24391 Mtetra
.565 .682 .919 r
.37202 .24391 .38169 .25587 .39755 .25402 .38794 .2415 Mtetra
.529 .657 .917 r
.38794 .2415 .39755 .25402 .4135 .25346 .40395 .24022 Mtetra
.489 .625 .91 r
.40395 .24022 .4135 .25346 .42955 .25433 .42006 .24022 Mtetra
.449 .588 .9 r
.42006 .24022 .42955 .25433 .44574 .2567 .43629 .24155 Mtetra
.415 .552 .885 r
.43629 .24155 .44574 .2567 .46209 .26046 .45268 .24413 Mtetra
.393 .521 .868 r
.45268 .24413 .46209 .26046 .47862 .26532 .46924 .2477 Mtetra
.39 .501 .851 r
.46924 .2477 .47862 .26532 .49537 .27079 .486 .25183 Mtetra
.406 .493 .835 r
.486 .25183 .49537 .27079 .51236 .27617 .50299 .25592 Mtetra
.439 .497 .822 r
.50299 .25592 .51236 .27617 .52957 .28063 .52019 .25923 Mtetra
.484 .511 .81 r
.52019 .25923 .52957 .28063 .547 .28329 .5376 .26098 Mtetra
.534 .532 .798 r
.5376 .26098 .547 .28329 .5646 .28335 .5552 .26044 Mtetra
.585 .555 .787 r
.5552 .26044 .5646 .28335 .58233 .28018 .57292 .25705 Mtetra
.632 .58 .777 r
.57292 .25705 .58233 .28018 .60012 .27346 .59073 .25051 Mtetra
.673 .603 .769 r
.59073 .25051 .60012 .27346 .61792 .26325 .60856 .24084 Mtetra
.708 .626 .763 r
.60856 .24084 .61792 .26325 .63567 .24992 .62638 .22836 Mtetra
.735 .647 .761 r
.62638 .22836 .63567 .24992 .65336 .23414 .64416 .21364 Mtetra
.756 .666 .762 r
.64416 .21364 .65336 .23414 .67097 .21675 .66188 .19743 Mtetra
.771 .684 .767 r
.66188 .19743 .67097 .21675 .68853 .19863 .67957 .18051 Mtetra
.78 .7 .776 r
.67957 .18051 .68853 .19863 .70606 .18059 .69725 .1636 Mtetra
.782 .715 .789 r
.69725 .1636 .70606 .18059 .72363 .16328 .71496 .1473 Mtetra
.779 .728 .805 r
.71496 .1473 .72363 .16328 .74126 .14715 .73275 .13202 Mtetra
.771 .738 .822 r
.73275 .13202 .74126 .14715 .75901 .13245 .75064 .11799 Mtetra
.664 .741 .908 r
.10296 .32237 .11366 .33233 .12818 .32695 .11753 .31693 Mtetra
.11753 .31693 .12818 .32695 .14279 .32154 .13219 .31146 Mtetra
.13219 .31146 .14279 .32154 .15748 .31609 .14693 .30596 Mtetra
.14693 .30596 .15748 .31609 .17226 .31062 .16175 .30043 Mtetra
.663 .741 .908 r
.16175 .30043 .17226 .31062 .18712 .30512 .17666 .29487 Mtetra
.17666 .29487 .18712 .30512 .20207 .29958 .19166 .28927 Mtetra
.19166 .28927 .20207 .29958 .2171 .29403 .20674 .28365 Mtetra
.20674 .28365 .2171 .29403 .23222 .28845 .22191 .27801 Mtetra
.662 .741 .908 r
.22191 .27801 .23222 .28845 .24742 .28287 .23717 .27236 Mtetra
.661 .74 .908 r
.23717 .27236 .24742 .28287 .26271 .27729 .25252 .26671 Mtetra
.66 .74 .909 r
.25252 .26671 .26271 .27729 .27809 .27176 .26795 .26109 Mtetra
.657 .738 .91 r
.26795 .26109 .27809 .27176 .29355 .26631 .28346 .25554 Mtetra
.653 .736 .911 r
.28346 .25554 .29355 .26631 .30909 .26103 .29906 .25012 Mtetra
.646 .733 .912 r
.29906 .25012 .30909 .26103 .32471 .256 .31474 .24492 Mtetra
.637 .727 .914 r
.31474 .24492 .32471 .256 .34041 .25135 .3305 .24005 Mtetra
.623 .719 .915 r
.3305 .24005 .34041 .25135 .35617 .24726 .34633 .23566 Mtetra
.604 .707 .917 r
.34633 .23566 .35617 .24726 .37202 .24391 .36224 .2319 Mtetra
.579 .69 .917 r
.36224 .2319 .37202 .24391 .38794 .2415 .37823 .22897 Mtetra
.549 .668 .916 r
.37823 .22897 .38794 .2415 .40395 .24022 .3943 .22703 Mtetra
.514 .64 .911 r
.3943 .22703 .40395 .24022 .42006 .24022 .41047 .22621 Mtetra
.48 .608 .902 r
.41047 .22621 .42006 .24022 .43629 .24155 .42676 .22656 Mtetra
.449 .576 .889 r
.42676 .22656 .43629 .24155 .45268 .24413 .44319 .22802 Mtetra
.429 .547 .874 r
.44319 .22802 .45268 .24413 .46924 .2477 .45978 .23037 Mtetra
.424 .527 .858 r
.45978 .23037 .46924 .2477 .486 .25183 .47657 .23323 Mtetra
.436 .516 .842 r
.47657 .23323 .486 .25183 .50299 .25592 .49356 .23609 Mtetra
.462 .517 .828 r
.49356 .23609 .50299 .25592 .52019 .25923 .51076 .23828 Mtetra
.5 .526 .815 r
.51076 .23828 .52019 .25923 .5376 .26098 .52817 .23913 Mtetra
.543 .542 .803 r
.52817 .23913 .5376 .26098 .5552 .26044 .54575 .23799 Mtetra
.588 .562 .793 r
.54575 .23799 .5552 .26044 .57292 .25705 .56348 .23435 Mtetra
.631 .584 .783 r
.56348 .23435 .57292 .25705 .59073 .25051 .5813 .22793 Mtetra
.668 .605 .775 r
.5813 .22793 .59073 .25051 .60856 .24084 .59917 .21874 Mtetra
.701 .626 .77 r
.59917 .21874 .60856 .24084 .62638 .22836 .61705 .20703 Mtetra
.727 .646 .768 r
.61705 .20703 .62638 .22836 .64416 .21364 .63491 .1933 Mtetra
.747 .664 .769 r
.63491 .1933 .64416 .21364 .66188 .19743 .65274 .17819 Mtetra
.761 .682 .775 r
.65274 .17819 .66188 .19743 .67957 .18051 .67055 .1624 Mtetra
.769 .698 .784 r
.67055 .1624 .67957 .18051 .69725 .1636 .68837 .14657 Mtetra
.772 .713 .796 r
.68837 .14657 .69725 .1636 .71496 .1473 .70622 .13123 Mtetra
.769 .725 .812 r
.70622 .13123 .71496 .1473 .73275 .13202 .72415 .11677 Mtetra
.762 .735 .828 r
.72415 .11677 .73275 .13202 .75064 .11799 .74218 .10341 Mtetra
.664 .741 .908 r
.09215 .3123 .10296 .32237 .11753 .31693 .10677 .30681 Mtetra
.10677 .30681 .11753 .31693 .13219 .31146 .12147 .30128 Mtetra
.12147 .30128 .13219 .31146 .14693 .30596 .13626 .29572 Mtetra
.13626 .29572 .14693 .30596 .16175 .30043 .15113 .29013 Mtetra
.663 .741 .908 r
.15113 .29013 .16175 .30043 .17666 .29487 .16609 .28451 Mtetra
.16609 .28451 .17666 .29487 .19166 .28927 .18114 .27885 Mtetra
.18114 .27885 .19166 .28927 .20674 .28365 .19627 .27317 Mtetra
.19627 .27317 .20674 .28365 .22191 .27801 .2115 .26746 Mtetra
.2115 .26746 .22191 .27801 .23717 .27236 .22681 .26174 Mtetra
.662 .741 .908 r
.22681 .26174 .23717 .27236 .25252 .26671 .24221 .25602 Mtetra
.66 .74 .909 r
.24221 .25602 .25252 .26671 .26795 .26109 .25769 .25031 Mtetra
.658 .739 .909 r
.25769 .25031 .26795 .26109 .28346 .25554 .27327 .24466 Mtetra
.655 .737 .91 r
.27327 .24466 .28346 .25554 .29906 .25012 .28892 .23912 Mtetra
.649 .734 .911 r
.28892 .23912 .29906 .25012 .31474 .24492 .30466 .23376 Mtetra
.641 .729 .913 r
.30466 .23376 .31474 .24492 .3305 .24005 .32048 .22867 Mtetra
.629 .722 .914 r
.32048 .22867 .3305 .24005 .34633 .23566 .33638 .224 Mtetra
.613 .712 .915 r
.33638 .224 .34633 .23566 .36224 .2319 .35235 .21987 Mtetra
.592 .697 .916 r
.35235 .21987 .36224 .2319 .37823 .22897 .36841 .21645 Mtetra
.566 .678 .915 r
.36841 .21645 .37823 .22897 .3943 .22703 .38454 .21389 Mtetra
.537 .654 .911 r
.38454 .21389 .3943 .22703 .41047 .22621 .40078 .21231 Mtetra
.507 .626 .904 r
.40078 .21231 .41047 .22621 .42676 .22656 .41712 .21174 Mtetra
.48 .598 .893 r
.41712 .21174 .42676 .22656 .44319 .22802 .4336 .21215 Mtetra
.462 .571 .879 r
.4336 .21215 .44319 .22802 .45978 .23037 .45024 .21336 Mtetra
.455 .551 .864 r
.45024 .21336 .45978 .23037 .47657 .23323 .46705 .21503 Mtetra
.463 .539 .849 r
.46705 .21503 .47657 .23323 .49356 .23609 .48406 .21671 Mtetra
.484 .536 .835 r
.48406 .21671 .49356 .23609 .51076 .23828 .50127 .21785 Mtetra
.515 .542 .822 r
.50127 .21785 .51076 .23828 .52817 .23913 .51868 .21783 Mtetra
.553 .554 .809 r
.51868 .21783 .52817 .23913 .54575 .23799 .53626 .21609 Mtetra
.592 .571 .799 r
.53626 .21609 .54575 .23799 .56348 .23435 .554 .21218 Mtetra
.63 .589 .789 r
.554 .21218 .56348 .23435 .5813 .22793 .57184 .20584 Mtetra
.665 .608 .782 r
.57184 .20584 .5813 .22793 .59917 .21874 .58974 .19705 Mtetra
.694 .628 .777 r
.58974 .19705 .59917 .21874 .61705 .20703 .60767 .18603 Mtetra
.719 .646 .776 r
.60767 .18603 .61705 .20703 .63491 .1933 .62561 .1732 Mtetra
.738 .664 .778 r
.62561 .1732 .63491 .1933 .65274 .17819 .64354 .15911 Mtetra
.752 .681 .783 r
.64354 .15911 .65274 .17819 .67055 .1624 .66147 .14437 Mtetra
.76 .697 .792 r
.66147 .14437 .67055 .1624 .68837 .14657 .67941 .12955 Mtetra
.762 .711 .804 r
.67941 .12955 .68837 .14657 .70622 .13123 .6974 .11513 Mtetra
.76 .723 .819 r
.6974 .11513 .70622 .13123 .72415 .11677 .71546 .10145 Mtetra
.753 .733 .834 r
.71546 .10145 .72415 .11677 .74218 .10341 .73363 .08872 Mtetra
.664 .741 .908 r
.08123 .30213 .09215 .3123 .10677 .30681 .09589 .29658 Mtetra
.09589 .29658 .10677 .30681 .12147 .30128 .11064 .29099 Mtetra
.11064 .29099 .12147 .30128 .13626 .29572 .12548 .28537 Mtetra
.12548 .28537 .13626 .29572 .15113 .29013 .1404 .27972 Mtetra
.663 .741 .908 r
.1404 .27972 .15113 .29013 .16609 .28451 .15541 .27403 Mtetra
.15541 .27403 .16609 .28451 .18114 .27885 .1705 .26832 Mtetra
.1705 .26832 .18114 .27885 .19627 .27317 .18569 .26257 Mtetra
.18569 .26257 .19627 .27317 .2115 .26746 .20096 .2568 Mtetra
.20096 .2568 .2115 .26746 .22681 .26174 .21633 .25101 Mtetra
.662 .741 .908 r
.21633 .25101 .22681 .26174 .24221 .25602 .23178 .24521 Mtetra
.661 .74 .909 r
.23178 .24521 .24221 .25602 .25769 .25031 .24732 .23942 Mtetra
.659 .739 .909 r
.24732 .23942 .25769 .25031 .27327 .24466 .26296 .23367 Mtetra
.656 .738 .91 r
.26296 .23367 .27327 .24466 .28892 .23912 .27867 .22801 Mtetra
.651 .735 .911 r
.27867 .22801 .28892 .23912 .30466 .23376 .29447 .2225 Mtetra
.644 .731 .912 r
.29447 .2225 .30466 .23376 .32048 .22867 .31035 .21721 Mtetra
.634 .725 .913 r
.31035 .21721 .32048 .22867 .33638 .224 .32632 .21227 Mtetra
.621 .716 .914 r
.32632 .21227 .33638 .224 .35235 .21987 .34236 .2078 Mtetra
.603 .704 .915 r
.34236 .2078 .35235 .21987 .36841 .21645 .35848 .20393 Mtetra
.581 .687 .914 r
.35848 .20393 .36841 .21645 .38454 .21389 .37468 .2008 Mtetra
.556 .666 .911 r
.37468 .2008 .38454 .21389 .40078 .21231 .39098 .19851 Mtetra
.531 .642 .905 r
.39098 .19851 .40078 .21231 .41712 .21174 .40739 .19711 Mtetra
.507 .617 .896 r
.40739 .19711 .41712 .21174 .4336 .21215 .42393 .19655 Mtetra
.49 .593 .884 r
.42393 .19655 .4336 .21215 .45024 .21336 .44061 .19668 Mtetra
.483 .573 .87 r
.44061 .19668 .45024 .21336 .46705 .21503 .45746 .19724 Mtetra
.488 .561 .856 r
.45746 .19724 .46705 .21503 .48406 .21671 .47449 .19783 Mtetra
.505 .556 .842 r
.47449 .19783 .48406 .21671 .50127 .21785 .49172 .19797 Mtetra
.53 .558 .828 r
.49172 .19797 .50127 .21785 .51868 .21783 .50913 .19712 Mtetra
.562 .567 .816 r
.50913 .19712 .51868 .21783 .53626 .21609 .52673 .1948 Mtetra
.596 .58 .806 r
.52673 .1948 .53626 .21609 .554 .21218 .54447 .19061 Mtetra
.63 .596 .797 r
.54447 .19061 .554 .21218 .57184 .20584 .56233 .1843 Mtetra
.661 .613 .79 r
.56233 .1843 .57184 .20584 .58974 .19705 .58027 .17585 Mtetra
.689 .631 .786 r
.58027 .17585 .58974 .19705 .60767 .18603 .59826 .16544 Mtetra
.712 .648 .784 r
.59826 .16544 .60767 .18603 .62561 .1732 .61627 .15342 Mtetra
.73 .665 .786 r
.61627 .15342 .62561 .1732 .64354 .15911 .63429 .14026 Mtetra
.742 .681 .792 r
.63429 .14026 .64354 .15911 .66147 .14437 .65233 .12649 Mtetra
.75 .697 .801 r
.65233 .12649 .66147 .14437 .67941 .12955 .67039 .1126 Mtetra
.753 .71 .812 r
.67039 .1126 .67941 .12955 .6974 .11513 .68851 .09903 Mtetra
.75 .722 .826 r
.68851 .09903 .6974 .11513 .71546 .10145 .7067 .08608 Mtetra
.744 .731 .84 r
.7067 .08608 .71546 .10145 .73363 .08872 .72499 .07394 Mtetra
.664 .741 .908 r
.07019 .29185 .08123 .30213 .09589 .29658 .0849 .28624 Mtetra
.0849 .28624 .09589 .29658 .11064 .29099 .09969 .28059 Mtetra
.09969 .28059 .11064 .29099 .12548 .28537 .11458 .27491 Mtetra
.11458 .27491 .12548 .28537 .1404 .27972 .12955 .26919 Mtetra
.12955 .26919 .1404 .27972 .15541 .27403 .14461 .26345 Mtetra
.663 .741 .908 r
.14461 .26345 .15541 .27403 .1705 .26832 .15975 .25767 Mtetra
.15975 .25767 .1705 .26832 .18569 .26257 .17499 .25186 Mtetra
.17499 .25186 .18569 .26257 .20096 .2568 .19032 .24602 Mtetra
.19032 .24602 .20096 .2568 .21633 .25101 .20574 .24016 Mtetra
.662 .741 .908 r
.20574 .24016 .21633 .25101 .23178 .24521 .22124 .23428 Mtetra
.661 .74 .908 r
.22124 .23428 .23178 .24521 .24732 .23942 .23684 .22841 Mtetra
.66 .739 .909 r
.23684 .22841 .24732 .23942 .26296 .23367 .25253 .22257 Mtetra
.657 .738 .909 r
.25253 .22257 .26296 .23367 .27867 .22801 .2683 .21679 Mtetra
.653 .736 .91 r
.2683 .21679 .27867 .22801 .29447 .2225 .28417 .21114 Mtetra
.647 .732 .911 r
.28417 .21114 .29447 .2225 .31035 .21721 .30011 .20567 Mtetra
.639 .727 .912 r
.30011 .20567 .31035 .21721 .32632 .21227 .31614 .20048 Mtetra
.627 .72 .913 r
.31614 .20048 .32632 .21227 .34236 .2078 .33225 .19569 Mtetra
.613 .709 .914 r
.33225 .19569 .34236 .2078 .35848 .20393 .34843 .19141 Mtetra
.594 .695 .913 r
.34843 .19141 .35848 .20393 .37468 .2008 .36471 .18776 Mtetra
.573 .677 .91 r
.36471 .18776 .37468 .2008 .39098 .19851 .38108 .18482 Mtetra
.551 .657 .906 r
.38108 .18482 .39098 .19851 .40739 .19711 .39755 .18265 Mtetra
.531 .634 .898 r
.39755 .18265 .40739 .19711 .42393 .19655 .41415 .1812 Mtetra
.516 .613 .887 r
.41415 .1812 .42393 .19655 .44061 .19668 .43088 .18036 Mtetra
.509 .594 .875 r
.43088 .18036 .44061 .19668 .45746 .19724 .44778 .1799 Mtetra
.511 .581 .862 r
.44778 .1799 .45746 .19724 .47449 .19783 .46484 .17947 Mtetra
.524 .575 .848 r
.46484 .17947 .47449 .19783 .49172 .19797 .48209 .17867 Mtetra
.545 .575 .836 r
.48209 .17867 .49172 .19797 .50913 .19712 .49953 .17705 Mtetra
.572 .581 .824 r
.49953 .17705 .50913 .19712 .52673 .1948 .51713 .17416 Mtetra
.601 .591 .813 r
.51713 .17416 .52673 .1948 .54447 .19061 .53489 .16967 Mtetra
.631 .604 .805 r
.53489 .16967 .54447 .19061 .56233 .1843 .55278 .16337 Mtetra
.659 .619 .798 r
.55278 .16337 .56233 .1843 .58027 .17585 .57075 .1552 Mtetra
.684 .635 .794 r
.57075 .1552 .58027 .17585 .59826 .16544 .58879 .14532 Mtetra
.705 .651 .794 r
.58879 .14532 .59826 .16544 .61627 .15342 .60687 .13401 Mtetra
.722 .667 .796 r
.60687 .13401 .61627 .15342 .63429 .14026 .62498 .12168 Mtetra
.734 .683 .801 r
.62498 .12168 .63429 .14026 .65233 .12649 .64312 .10879 Mtetra
.741 .697 .809 r
.64312 .10879 .65233 .12649 .67039 .1126 .6613 .09576 Mtetra
.743 .71 .82 r
.6613 .09576 .67039 .1126 .68851 .09903 .67954 .08297 Mtetra
.741 .721 .833 r
.67954 .08297 .68851 .09903 .7067 .08608 .69785 .07069 Mtetra
.735 .73 .846 r
.69785 .07069 .7067 .08608 .72499 .07394 .71627 .0591 Mtetra
.664 .741 .908 r
.05902 .28146 .07019 .29185 .0849 .28624 .07378 .27578 Mtetra
.07378 .27578 .0849 .28624 .09969 .28059 .08863 .27007 Mtetra
.08863 .27007 .09969 .28059 .11458 .27491 .10356 .26433 Mtetra
.10356 .26433 .11458 .27491 .12955 .26919 .11858 .25855 Mtetra
.11858 .25855 .12955 .26919 .14461 .26345 .13369 .25274 Mtetra
.663 .741 .908 r
.13369 .25274 .14461 .26345 .15975 .25767 .14888 .2469 Mtetra
.14888 .2469 .15975 .25767 .17499 .25186 .16417 .24102 Mtetra
.16417 .24102 .17499 .25186 .19032 .24602 .17955 .23512 Mtetra
.17955 .23512 .19032 .24602 .20574 .24016 .19502 .22919 Mtetra
.19502 .22919 .20574 .24016 .22124 .23428 .21059 .22324 Mtetra
.662 .74 .908 r
.21059 .22324 .22124 .23428 .23684 .22841 .22624 .21729 Mtetra
.66 .74 .909 r
.22624 .21729 .23684 .22841 .25253 .22257 .24199 .21135 Mtetra
.658 .739 .909 r
.24199 .21135 .25253 .22257 .2683 .21679 .25782 .20547 Mtetra
.655 .737 .91 r
.25782 .20547 .2683 .21679 .28417 .21114 .27374 .19967 Mtetra
.65 .734 .911 r
.27374 .19967 .28417 .21114 .30011 .20567 .28975 .19403 Mtetra
.643 .729 .911 r
.28975 .19403 .30011 .20567 .31614 .20048 .30584 .18863 Mtetra
.633 .723 .912 r
.30584 .18863 .31614 .20048 .33225 .19569 .32202 .18354 Mtetra
.621 .714 .913 r
.32202 .18354 .33225 .19569 .34843 .19141 .33828 .17889 Mtetra
.606 .702 .912 r
.33828 .17889 .34843 .19141 .36471 .18776 .35462 .17476 Mtetra
.588 .687 .91 r
.35462 .17476 .36471 .18776 .38108 .18482 .37106 .17124 Mtetra
.57 .669 .906 r
.37106 .17124 .38108 .18482 .39755 .18265 .38761 .16836 Mtetra
.552 .65 .9 r
.38761 .16836 .39755 .18265 .41415 .1812 .40427 .16611 Mtetra
.539 .631 .891 r
.40427 .16611 .41415 .1812 .43088 .18036 .42106 .16438 Mtetra
.531 .614 .88 r
.42106 .16438 .43088 .18036 .44778 .1799 .438 .16298 Mtetra
.532 .601 .868 r
.438 .16298 .44778 .1799 .46484 .17947 .45511 .16162 Mtetra
.542 .593 .855 r
.45511 .16162 .46484 .17947 .48209 .17867 .47239 .15996 Mtetra
.558 .591 .843 r
.47239 .15996 .48209 .17867 .49953 .17705 .48985 .15761 Mtetra
.581 .595 .831 r
.48985 .15761 .49953 .17705 .51713 .17416 .50748 .15419 Mtetra
.606 .603 .822 r
.50748 .15419 .51713 .17416 .53489 .16967 .52526 .1494 Mtetra
.632 .614 .813 r
.52526 .1494 .53489 .16967 .55278 .16337 .54317 .14306 Mtetra
.658 .627 .807 r
.54317 .14306 .55278 .16337 .57075 .1552 .56118 .13512 Mtetra
.68 .641 .804 r
.56118 .13512 .57075 .1552 .58879 .14532 .57927 .12568 Mtetra
.699 .655 .803 r
.57927 .12568 .58879 .14532 .60687 .13401 .59742 .115 Mtetra
.715 .67 .805 r
.59742 .115 .60687 .13401 .62498 .12168 .61561 .10341 Mtetra
.726 .685 .81 r
.61561 .10341 .62498 .12168 .64312 .10879 .63385 .0913 Mtetra
.732 .698 .818 r
.63385 .0913 .64312 .10879 .6613 .09576 .65213 .07904 Mtetra
.734 .71 .828 r
.65213 .07904 .6613 .09576 .67954 .08297 .67049 .06696 Mtetra
.733 .721 .84 r
.67049 .06696 .67954 .08297 .69785 .07069 .68892 .0553 Mtetra
.727 .729 .852 r
.68892 .0553 .69785 .07069 .71627 .0591 .70746 .04421 Mtetra
.664 .741 .908 r
.04774 .27095 .05902 .28146 .07378 .27578 .06255 .26522 Mtetra
.06255 .26522 .07378 .27578 .08863 .27007 .07744 .25944 Mtetra
.07744 .25944 .08863 .27007 .10356 .26433 .09242 .25364 Mtetra
.09242 .25364 .10356 .26433 .11858 .25855 .10749 .2478 Mtetra
.10749 .2478 .11858 .25855 .13369 .25274 .12265 .24192 Mtetra
.663 .741 .908 r
.12265 .24192 .13369 .25274 .14888 .2469 .1379 .23601 Mtetra
.1379 .23601 .14888 .2469 .16417 .24102 .15324 .23007 Mtetra
.15324 .23007 .16417 .24102 .17955 .23512 .16867 .2241 Mtetra
.16867 .2241 .17955 .23512 .19502 .22919 .18419 .2181 Mtetra
.18419 .2181 .19502 .22919 .21059 .22324 .19981 .21208 Mtetra
.662 .741 .908 r
.19981 .21208 .21059 .22324 .22624 .21729 .21552 .20604 Mtetra
.661 .74 .909 r
.21552 .20604 .22624 .21729 .24199 .21135 .23132 .20002 Mtetra
.659 .739 .909 r
.23132 .20002 .24199 .21135 .25782 .20547 .24722 .19403 Mtetra
.656 .737 .909 r
.24722 .19403 .25782 .20547 .27374 .19967 .2632 .18811 Mtetra
.652 .735 .91 r
.2632 .18811 .27374 .19967 .28975 .19403 .27927 .18231 Mtetra
.647 .731 .911 r
.27927 .18231 .28975 .19403 .30584 .18863 .29543 .17669 Mtetra
.639 .726 .911 r
.29543 .17669 .30584 .18863 .32202 .18354 .31167 .17135 Mtetra
.628 .718 .912 r
.31167 .17135 .32202 .18354 .33828 .17889 .328 .16635 Mtetra
.615 .708 .911 r
.328 .16635 .33828 .17889 .35462 .17476 .34442 .1618 Mtetra
.601 .696 .91 r
.34442 .1618 .35462 .17476 .37106 .17124 .36093 .15775 Mtetra
.585 .681 .906 r
.36093 .15775 .37106 .17124 .38761 .16836 .37755 .15424 Mtetra
.57 .664 .901 r
.37755 .15424 .38761 .16836 .40427 .16611 .39427 .15126 Mtetra
.558 .647 .893 r
.39427 .15126 .40427 .16611 .42106 .16438 .41113 .14872 Mtetra
.552 .631 .884 r
.41113 .14872 .42106 .16438 .438 .16298 .42812 .14647 Mtetra
.551 .619 .873 r
.42812 .14647 .438 .16298 .45511 .16162 .44528 .14427 Mtetra
.558 .611 .861 r
.44528 .14427 .45511 .16162 .47239 .15996 .4626 .14182 Mtetra
.571 .607 .85 r
.4626 .14182 .47239 .15996 .48985 .15761 .48009 .13879 Mtetra
.59 .609 .839 r
.48009 .13879 .48985 .15761 .50748 .15419 .49775 .13487 Mtetra
.612 .615 .83 r
.49775 .13487 .50748 .15419 .52526 .1494 .51556 .12979 Mtetra
.634 .624 .822 r
.51556 .12979 .52526 .1494 .54317 .14306 .5335 .12339 Mtetra
.656 .635 .817 r
.5335 .12339 .54317 .14306 .56118 .13512 .55155 .11561 Mtetra
.677 .647 .813 r
.55155 .11561 .56118 .13512 .57927 .12568 .56969 .10656 Mtetra
.694 .661 .813 r
.56969 .10656 .57927 .12568 .59742 .115 .58791 .09641 Mtetra
.708 .674 .815 r
.58791 .09641 .59742 .115 .61561 .10341 .60618 .08547 Mtetra
.718 .687 .82 r
.60618 .08547 .61561 .10341 .63385 .0913 .6245 .07405 Mtetra
.724 .7 .827 r
.6245 .07405 .63385 .0913 .65213 .07904 .64289 .06248 Mtetra
.726 .711 .836 r
.64289 .06248 .65213 .07904 .67049 .06696 .66136 .05103 Mtetra
.724 .721 .847 r
.66136 .05103 .67049 .06696 .68892 .0553 .67991 .03992 Mtetra
.72 .729 .858 r
.67991 .03992 .68892 .0553 .70746 .04421 .69856 .02928 Mtetra
.664 .741 .908 r
.03634 .26033 .04774 .27095 .06255 .26522 .05119 .25453 Mtetra
.05119 .25453 .06255 .26522 .07744 .25944 .06613 .2487 Mtetra
.06613 .2487 .07744 .25944 .09242 .25364 .08116 .24283 Mtetra
.08116 .24283 .09242 .25364 .10749 .2478 .09628 .23692 Mtetra
.09628 .23692 .10749 .2478 .12265 .24192 .11148 .23098 Mtetra
.11148 .23098 .12265 .24192 .1379 .23601 .12679 .22501 Mtetra
.663 .741 .908 r
.12679 .22501 .1379 .23601 .15324 .23007 .14218 .219 Mtetra
.14218 .219 .15324 .23007 .16867 .2241 .15766 .21296 Mtetra
.15766 .21296 .16867 .2241 .18419 .2181 .17324 .20689 Mtetra
.17324 .20689 .18419 .2181 .19981 .21208 .18891 .20079 Mtetra
.662 .741 .908 r
.18891 .20079 .19981 .21208 .21552 .20604 .20468 .19468 Mtetra
.661 .74 .908 r
.20468 .19468 .21552 .20604 .23132 .20002 .22054 .18856 Mtetra
.66 .739 .909 r
.22054 .18856 .23132 .20002 .24722 .19403 .23649 .18247 Mtetra
.658 .738 .909 r
.23649 .18247 .24722 .19403 .2632 .18811 .25254 .17643 Mtetra
.654 .736 .91 r
.25254 .17643 .2632 .18811 .27927 .18231 .26867 .17048 Mtetra
.65 .733 .91 r
.26867 .17048 .27927 .18231 .29543 .17669 .2849 .16468 Mtetra
.643 .728 .911 r
.2849 .16468 .29543 .17669 .31167 .17135 .30121 .15909 Mtetra
.634 .722 .911 r
.30121 .15909 .31167 .17135 .328 .16635 .31761 .15379 Mtetra
.624 .714 .911 r
.31761 .15379 .328 .16635 .34442 .1618 .3341 .14885 Mtetra
.612 .703 .909 r
.3341 .14885 .34442 .1618 .36093 .15775 .35068 .14433 Mtetra
.599 .69 .907 r
.35068 .14433 .36093 .15775 .37755 .15424 .36737 .14026 Mtetra
.586 .676 .902 r
.36737 .14026 .37755 .15424 .39427 .15126 .38416 .13662 Mtetra
.576 .661 .896 r
.38416 .13662 .39427 .15126 .41113 .14872 .40108 .13337 Mtetra
.569 .647 .887 r
.40108 .13337 .41113 .14872 .42812 .14647 .41814 .13035 Mtetra
.568 .635 .878 r
.41814 .13035 .42812 .14647 .44528 .14427 .43535 .12739 Mtetra
.573 .627 .868 r
.43535 .12739 .44528 .14427 .4626 .14182 .45272 .12422 Mtetra
.584 .623 .857 r
.45272 .12422 .4626 .14182 .48009 .13879 .47025 .12057 Mtetra
.599 .623 .847 r
.47025 .12057 .48009 .13879 .49775 .13487 .48794 .11618 Mtetra
.617 .627 .838 r
.48794 .11618 .49775 .13487 .51556 .12979 .50578 .11081 Mtetra
.636 .634 .831 r
.50578 .11081 .51556 .12979 .5335 .12339 .52376 .10433 Mtetra
.656 .643 .826 r
.52376 .10433 .5335 .12339 .55155 .11561 .54185 .09668 Mtetra
.674 .654 .823 r
.54185 .09668 .55155 .11561 .56969 .10656 .56005 .08793 Mtetra
.689 .666 .822 r
.56005 .08793 .56969 .10656 .58791 .09641 .57832 .07825 Mtetra
.702 .679 .824 r
.57832 .07825 .58791 .09641 .60618 .08547 .59667 .06786 Mtetra
.711 .691 .829 r
.59667 .06786 .60618 .08547 .6245 .07405 .61509 .05704 Mtetra
.716 .702 .836 r
.61509 .05704 .6245 .07405 .64289 .06248 .63357 .04607 Mtetra
.718 .713 .844 r
.63357 .04607 .64289 .06248 .66136 .05103 .65214 .03517 Mtetra
.717 .722 .854 r
.65214 .03517 .66136 .05103 .67991 .03992 .6708 .02455 Mtetra
.712 .729 .864 r
.6708 .02455 .67991 .03992 .69856 .02928 .68957 .0143 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`006_oooonD000003?oooooU?l0000Kooooo`006_oo
ool00`00003oooooooooo`2@ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0T?oo
ool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2@ooooo`0300000?oooooo
oooo037ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Iooooo`006_ooool00`00
003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0_l0000Kooooo`<000003_ooool00`00
003oooooooooo`1;ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool001[o
oooo00<00000ooooooooool0100000000ol000006ATI01TI6@0<01TI6@03o`00000c<c<0<c<c01h0
<c<c00<0000001TI6@0I6AT0300I6AU:000000?ooooo00<00000ooooooooool0<Oooool00ol0003o
ooooooooo`1Co`0001@06ATI3000000C01TI6@03o`0000000000000000@000000oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0300000003o`00000I6AT06ATI00`06ATI
00?o000003<c<`0c<c<0800c<c<00`0000006ATI01TI6@0<01TI6DT000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo05;o00004P0I6AT3000000`0<c<c0`00000A01TI6@03o`00
00000000000000<000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`0200000003o`00000I6AT06ATI00/06ATI0_l0000T03<c<`030000000I6AT06ATI00`06ATIB000
0003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0DOl0000@01TI6@<000004P0c
<c<00`0000006ATI01TI6@0?01TI6@03o`00000000000000008000000oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00`00003oooooooooo`0200000003o`00000I6AT06ATI00X06ATI00?o0000
03<c<`0c<c<0900c<c<00ol000006ATI01TI6@0<01TI6DP000000oooool00`00003oooooooooo`0a
ooooo`03o`000?oooooooooo053o0000400I6AT00`000000<c<c03<c<`0D03<c<`03o`0000000000
6ATI00h06ATI00?o00000000000000000P000003ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`0500000?oooooooooo00000?l00000300I6AT00ol00000<c<c03<c<`0>03<c<`/000003@0c<c<0
0`0000006ATI01TI6@0<01TI6DL000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooo
oooo04oo0000400I6AT00`000000<c<c03<c<`0G03<c<`030000000I6AT06ATI00d06ATI00Co0000
00000000000000000oooool00ol0003oooooooooo`0Iooooo`006_ooool01000003oooooooooool0
000=01TI6@03o`00000c<c<0<c<c00/0<c<c0`00000;04a<C0030000000c<c<0<c<c00/0<c<c00<0
000001TI6@0I6AT02`0I6AU7000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`1?o`0000h06ATI0P00000K03<c<`030000000I6AT06ATI00`06ATI00Co00000000000000000000
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0=01TI6@03o`00000c
<c<0<c<c00X0<c<c0P00000?04a<C003o`0000000000000000/0<c<c00<0000001TI6@0I6AT02`0I
6AU6000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`1>o`0000h06ATI00<0
000003<c<`0c<c<0700c<c<00`0000006ATI01TI6@0<01TI6@03o`0000000000000000?ooooo00?o
0000ooooooooool06Oooool001[ooooo00<00000ooooooooool03@0I6AT00ol00000<c<c03<c<`08
03<c<`800000501<C4`00`000000<c<c03<c<`0903<c<`03o`00000I6AT06ATI00X06ATIAP000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0C_l0000=01TI6@030000000c<c<0
<c<c01h0<c<c00<0000001TI6@0I6AT02`0I6AT00ol00000000000000003ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`0300000?oooooooooo00`06ATI00?o000003<c<`0c<c<0200c<c<00`00
0000C4a<04a<C00E04a<C08000002P0c<c<00`0000006ATI01TI6@0:01TI6DD000000oooool00`00
003oooooooooo`0aooooo`03o`000?oooooooooo04go00003@0I6AT00ol00000<c<c03<c<`0P03<c
<`030000000I6AT06ATI00/06ATI00?o000000000?ooool00_ooool00ol0003oooooooooo`0Ioooo
o`006_ooool00`00003oooooooooo`0:01TI6@;o00002@0c<c<00ol00000000004a<C00I04a<C003
0000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT02@0I6AU5000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`1<o`0000d06ATI00<0000003<c<`0c<c<08P0c<c<00`000000
6ATI01TI6@0;01TI6@05o`000?ooooooooooooooool000006oooool001[ooooo00<00000oooooooo
ool02P0I6AT00ol00000<c<c03<c<`0703<c<`030000001<C4`0C4a<01/0C4a<00<0000003<c<`0c
<c<01`0c<c<00`0000006ATI01TI6@0901TI6@03o`00000000000000048000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo04co00003@0I6AT00`000000<c<c03<c<`0;03<c<`P0
00003`0c<c<00ol000006ATI01TI6@0;01TI6@05o`000?ooooooooooooooool000006oooool001[o
oooo00<00000ooooooooool02@0I6AT00ol00000<c<c03<c<`0703<c<`030000001<C4`0C4a<01d0
C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0801TI6DD000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo04_o00003@0I6AT00`000000<c<c03<c<`0903<c<`<0
0000201<C4`4000000`0<c<c00<0000001TI6@0I6AT02P0I6AT01Ol0003ooooooooooooooooo0000
01_ooooo000Jooooo`0300000?oooooooooo00T06ATI00?o000003<c<`0c<c<01P0c<c<00`000000
C4a<04a<C00:04a<C0P000003@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00T0
6ATIA0000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0Bol0000;01TI6@80
00002`0c<c<00`000000C4a<04a<C00=04a<C08000002`0c<c<00`0000006ATI01TI6@0:01TI6@04
o`000?ooooooooooo`0001_ooooo000Jooooo`0300000?oooooooooo00P06ATI00?o000003<c<`0c
<c<01P0c<c<00ol00000C4a<04a<C00804a<C0<00000201VIVH300000003o`00001<C4`0C4a<00P0
C4a<00<0000003<c<`0c<c<01P0c<c<00ol000006ATI01TI6@0901TI6D<000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo04[o00002`0I6AT00`000000<c<c03<c<`0803<c<`80
000000?o000004a<C01<C4`0401<C4`00ol00000<c<c03<c<`0903<c<`030000000I6AT06ATI00T0
6ATI00Co0000oooooooooooo00006oooool001[ooooo00<00000ooooooooool0200I6AT00ol00000
<c<c03<c<`0603<c<`030000001<C4`0C4a<00H0C4a<0P00000?06IVIP800000201<C4`00`000000
<c<c03<c<`0603<c<`030000000I6AT06ATI00T06ATI@`000003ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool0B_l0000;01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<
C4`0501<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00T06ATI0oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0701TI6@03o`00000c<c<0<c<c00H0<c<c
00<0000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0A06IVIP8000001`1<C4`00`000000<c<c
03<c<`0603<c<`030000000I6AT06ATI00P06ATI@`000003ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool0BOl0000;01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`0
5P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00P06ATI0oooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00`00003oooooooooo`0701TI6@03o`00000c<c<0<c<c00D0<c<c00<0
000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0D06IVIP03o`00001<C4`0C4a<00D0C4a<00<0
000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6D8000000oooool00`00003ooooooooo
o`0aooooo`03o`000?oooooooooo04Wo00002P0I6AT00ol00000<c<c03<c<`0703<c<`030000001<
C4`0C4a<01P0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0801TI6@?ooooo00?o
0000ooooooooool06Oooool001[ooooo00<00000ooooooooool01P0I6AT00ol00000<c<c03<c<`05
03<c<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH05@1VIVH2000000L0C4a<00<00000
03<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0801TI6D8000000oooool00`00003oooooooooo`0a
ooooo`03o`000?oooooooooo04So00002`0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0
C4a<01X0C4a<00<0000003<c<`0c<c<01`0c<c<00ol000006ATI01TI6@0701TI6@?ooooo00?o0000
ooooooooool06Oooool001[ooooo00<00000ooooooooool01P0I6AT00ol00000<c<c03<c<`0503<c
<`030000001<C4`0C4a<00@0C4a<00<00000o`00001VIVH06@1VIVH00`000000C4a<04a<C00404a<
C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0200I6AU2000000?ooooo00<00000oooo
ooooool0<Oooool00ol0003oooooooooo`18o`0000/06ATI00<0000003<c<`0c<c<01@0c<c<00`00
0000C4a<04a<C00904a<C0P000002`1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI
00L06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0501TI6@03
o`00000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0806IVIPP0
00002`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I
6AT0200I6AU1000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`17o`0000/0
6ATI00<0000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00704a<C0<000002?mVIVH3000000T0
C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0601TI6@?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00<00000ooooooooool0100I6AT00ol00000<c<c03<c<`0503<c<`030000
001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH01P1VIVH00`00003o00000000000807moO`<00000
00?o000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c
00?o000001TI6@0I6AT0200I6AT00ol0000000000000000m000000?ooooo00<00000ooooooooool0
<Oooool00ol0003oooooooooo`17o`0000X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<
04a<C00704a<C00300000?mVIVKoIVIV00coIVIV0P00000804a<C003o`00000c<c<0<c<c00H0<c<c
00<0000001TI6@0I6AT01@0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oo
oooooooo00@06ATI00?o000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001V
IVH0IVIV00@0IVIV0P00000?07moO`8000001P1VIVH00`000000C4a<04a<C00404a<C0030000000c
<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0200I6AU0000000?ooooo00<00000ooooooooool0<Ooo
ool00ol0003oooooooooo`17o`0000T06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<
C00504a<C00300000?l0003oIVIV013oIVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c
<`0603<c<`030000000I6AT06ATI00D06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0`00003oooooooooo`0401TI6@03o`00000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0101<C4`0
0`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo0140Ogmo00<0000006IVIP1VIVH0101VIVH0
0`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AU0
000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`16o`0000T06ATI00<00000
03<c<`0c<c<01P0c<c<00`000000C4a<04a<C00504a<C00300000?mVIVKoIVIV01;oIVIV00<00000
04a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00@06ATI0oooool0
0ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0401TI6@03o`00000c<c<0<c<c
00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo
01<0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c
00D0<c<c00<0000001TI6@0I6AT0200I6ATo000000?ooooo00<00000ooooooooool0<Oooool00ol0
003oooooooooo`16o`0000T06ATI00<0000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00504a<
C00300000?mVIVKoIVIV01CoIVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c
<`030000000I6AT06ATI00@06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`0301TI6@03o`00000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000
IVIV06IVIP0406IVIP030000001oOgl0Ogmo01D0Ogmo00<0000006IVIP1VIVH0101VIVH00ol00000
C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6ATo000000?o
oooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`15o`0000X06ATI00<0000003<c<`0c
<c<0100c<c<00`000000C4a<04a<C00504a<C00300000?mVIVKoIVIV01KoIVIV00<0000004a<C01<
C4`0101<C4`00`00003o000003<c<`0503<c<`03o`00000I6AT06ATI00@06ATI0oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0301TI6@03o`00000c<c<0<c<c00@0<c<c
00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00T0Ogmo
1000000807moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c
03<c<`0403<c<`030000000I6AT06ATI00P06ATI?`000003ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool0AOl0000:01TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0
101<C4`00`00003oIVIVofIVIP07ofIVIPL000002OmVIVH00`000000C4a<04a<C00504a<C0030000
000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0100I6AT3ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0300000?oooooooooo00806ATI00?o000003<c<`0c<c<0100c<c<00`000000C4a<04a<
C00304a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01P1oOgl4000000@0VIVI0`00
000607moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c
<`0403<c<`030000000I6AT06ATI00L06ATI?`000003ooooo`0300000?oooooooooo037ooooo00?o
0000ooooooooool0AOl0000901TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0101<
C4`00`00003oIVIVofIVIP05ofIVIP<000001`1oOgl2000000SoIVIV00<0000004a<C01<C4`0101<
C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00@06ATI0oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00`00003oooooooooo`0201TI6@03o`00000c<c<0<c<c00@0<c<c00<00000
04a<C01<C4`00P1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00D0Ogmo00?o0000
0000002IVIT02P2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00<0IVIV00<00000
04a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`0300000?l000006ATI00P06ATI?P000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0A?l0000:01TI6@030000000c<c<0
<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`00003oIVIVofIVIP05ofIVIP030000001oOgl0
Ogmo00X0Ogmo0P000007ofIVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0100c<c<0
0`0000006ATI01TI6@0301TI6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00D00000oooo
ooooool06ATIo`00000603<c<`030000001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00`1VIVH0
0`000000Ogmo07moO`0407moO`0300000?l00000VIVI00d0VIVI0P00000507moO`03o`0000000000
IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT0
6ATI00L06ATI?P000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0A?l00009
01TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00`00003oIVIVofIVIP04
ofIVIP8000003`1oOgl2000000KoIVIV00?o000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`04
03<c<`030000000I6AT06ATI00<06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool01@00
003oooooooooo`0I6AWo000000H0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP02
06IVIP030000001oOgl0Ogmo00<0Ogmo0P00000B09VIV@030000001oOgl0Ogmo00<0Ogmo00<00000
06IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<00000
01TI6@0I6AT01`0I6ATn000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`14
o`0000P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00404a<C00300000?mVIVKo
IVIV00?oIVIV00<0000007moO`1oOgl04@1oOgl00`00003oIVIVofIVIP04ofIVIP030000001<C4`0
C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0301TI6@?ooooo00?o0000
ooooooooool06Oooool001[ooooo00@00000oooooooooooo00001P0c<c<00`000000C4a<04a<C003
04a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0C
09VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C003
04a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01`0I6ATm000000?ooooo00<00000
ooooooooool0<Oooool00ol0003oooooooooo`13o`0000T06ATI00<0000003<c<`0c<c<0100c<c<0
0`000000C4a<04a<C00304a<C00300000?mVIVKoIVIV00?oIVIV00<0000007moO`1oOgl04`1oOgl0
0`00003oIVIVofIVIP03ofIVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<0
0`0000006ATI01TI6@0201TI6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00@00000oooo
oooooooo00001P0c<c<00ol00000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00?o0000
07moO`1oOgl00`1oOgl00`000000VIVI09VIV@0E09VIV@030000001oOgl0Ogmo00<0Ogmo00<00000
06IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<00000
01TI6@0I6AT01`0I6ATm000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`12
o`0000T06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C00300000?mVIVKo
IVIV00?oIVIV00<0000007moO`1oOgl05@1oOgl00`00003oIVIVofIVIP03ofIVIP030000001<C4`0
C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<0100000006ATI01TI6@0I6AT3ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`0400000?ooooooooooo`0000H0<c<c00<0000004a<C01<C4`00P1<
C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT01@2I
VIT8000000P0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IVIP030000001<
C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6Cd000000ooo
ool00`00003oooooooooo`0aooooo`03o`000?oooooooooo04;o00002@0I6AT00`000000<c<c03<c
<`0403<c<`030000001<C4`0C4a<00<0C4a<00<00000ofIVI_mVIVH00omVIVH00`000000Ogmo07mo
O`0607moO`L00000201oOgl00`00003oIVIVofIVIP03ofIVIP030000001<C4`0C4a<00<0C4a<00?o
000003<c<`0c<c<0100c<c<0100000006ATI01TI6@0I6AT3ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0300000?oooooooooo00H0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IV
IP0206IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0102IVIT2000000P0/k>c0`00
000609VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<
C00204a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01`0I6ATm000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`12o`0000T06ATI00<0000003<c<`0c<c<00`0c
<c<00`000000C4a<04a<C00304a<C00300000?mVIVKoIVIV00?oIVIV00<0000007moO`1oOgl0101o
Ogl3000000L0VIVI0P00000707moO`0300000?mVIVKoIVIV00?oIVIV00<0000004a<C01<C4`00P1<
C4`00`000000<c<c03<c<`0403<c<`040000000I6AT06ATI01TI6@?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00<00000ooooooooool01P0c<c<00`000000C4a<04a<C00204a<C0030000001V
IVH0IVIV0080IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@030000002c
/k<0/k>c00/0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0207moO`03o`00001V
IVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I
6AT06ATI00H06ATI?@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0@Ol0
000901TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`00003oIVIVofIV
IP03ofIVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT02P2IVIT2000000D0Ogmo00<0
0000ofIVI_mVIVH00omVIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00<0<c<c00@0
000001TI6@0I6AT06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`0503<c<`030000001<C4`0C4a<00<0C4a<00Go000006IVIP1VIVH0IVIV0000000507moO`030000
002IVIT0VIVI0080VIVI0P00000?0;>c/`8000001@2IVIT00ol00000Ogmo07moO`0207moO`030000
001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00ol00000<c<c03<c<`0303<c<`030000
000I6AT06ATI00H06ATI?@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
@Ol0000901TI6@030000000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`00P1<C4`00`00003oIVIV
ofIVIP03ofIVIP030000001oOgl0Ogmo00<0Ogmo0P00000?09VIV@030000001oOgl0Ogmo00<0Ogmo
00<00000ofIVI_mVIVH00omVIVH00ol00000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c
00?o000001TI6@0I6AT00oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`0503<c<`030000001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`030000
002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<04@2c/k<00`000000VIVI09VIV@0309VIV@050000
001oOgl0Ogmo07moO`000000101VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00<0
<c<c00<0000001TI6@0I6AT01P0I6ATm000000?ooooo00<00000ooooooooool0<Oooool00ol0003o
ooooooooo`11o`0000T06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C00304a<C003
00000?mVIVKoIVIV00;oIVIV00?o000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0@09VIV@03
0000001oOgl0Ogmo0080Ogmo00<00000ofIVI_mVIVH00omVIVH00`000000C4a<04a<C00204a<C003
0000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT00oooool00ol0003oooooooooo`0Iooooo`00
6_ooool00`00003oooooooooo`0403<c<`030000001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0
IVIV0000000407moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<04`2c/k<00`000000
VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH01@000000
C4a<04a<C01<C4`0000000H0<c<c00<0000001TI6@0I6AT01P0I6ATl000000?ooooo00<00000oooo
ooooool0<Oooool00ol0003oooooooooo`10o`0000T06ATI00<0000003<c<`0c<c<00`0c<c<00`00
0000C4a<04a<C00204a<C00300000?mVIVKoIVIV00;oIVIV00<0000007moO`1oOgl00`1oOgl00`00
0000VIVI09VIV@0B09VIV@03o`00001oOgl0Ogmo0080Ogmo00<00000ofIVI_mVIVH00_mVIVH00`00
0000C4a<04a<C00304a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT00oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0403<c<`030000001<C4`0C4a<0080
C4a<00<0000006IVIP1VIVH00P1VIVH01Ol00000Ogmo07moO`1oOgl0000000@0VIVI00<000000;>c
/`2c/k<01@2c/k<00`00003o0000o`000006000000L0/k>c00?o000009VIV@2IVIT00P2IVIT01@00
0000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`03
03<c<`030000000I6AT06ATI00H06ATI?0000003ooooo`0300000?oooooooooo037ooooo00?o0000
ooooooooool0@?l0000801TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<C4`0
1@00003oIVIVofIVI_mVIVH0000000D0Ogmo00<0000009VIV@2IVIT01P2IVIT01@00003o0000o`00
0000003o000000T0VIVI00<0000007moO`1oOgl00P1oOgl00`00003oIVIVofIVIP02ofIVIP030000
001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@03ooooo`03o`00
0?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00@0<c<c00<0000004a<C01<C4`00P1<
C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moOol00000102IVIT00`000000/k>c
0;>c/`040;>c/`030000003<c<`0c<c<00L0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI
09VIV@0209VIV@050000001oOgl0Ogmo07moO`000000101VIVH00`000000C4a<04a<C00204a<C003
0000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6ATl000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`10o`0000P06ATI00<0000003<c<`0c<c<00`0c<c<00`000000
C4a<04a<C00204a<C003o`000?mVIVKoIVIV00;oIVIV00<0000007moO`1oOgl00`1oOgl00`000000
VIVI09VIV@0309VIV@<000001@2c/k<2000000L0VIVI00<0000007moO`1oOgl00P1oOgl00`00003o
IVIVofIVIP02ofIVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00`0c<c<00`000000
6ATI01TI6@03ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00@0<c<c
00<0000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVH0000000@0Ogmo00D0000009VIV@2I
VIT0VIVI000000060;>c/`030000003<c<`0c<c<00T0c<c<00<000000;>c/`2c/k<00`2c/k<00`00
0000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00D0000006IVIP1VIVH0IVIV00000004
04a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6ATl000000?ooooo00<00000
ooooooooool0<Oooool00ol0003oooooooooo`10o`0000P06ATI00<0000003<c<`0c<c<00`0c<c<0
0`000000C4a<04a<C00204a<C00500000?mVIVKoIVIVofIVIP0000001@1oOgl00`000000VIVI09VI
V@0309VIV@030000002c/k<0/k>c00P0/k>c0P00000609VIV@030000001oOgl0Ogmo0080Ogmo00D0
0000ofIVI_mVIVKoIVIV0000000404a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT0
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0403<c<`050000001<
C4`0C4a<04a<C0000000101VIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI00<000000;>c/`2c
/k<00`2c/k<00`000000c<c<0<c<c00;0<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2I
VIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000<0IVIV00<0000004a<C01<C4`00`1<C4`00`00
0000<c<c03<c<`0203<c<`030000000I6AT06ATI00L06ATI>`000003ooooo`0300000?oooooooooo
037ooooo00?o0000ooooooooool0?ol0000801TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<
C01<C4`00P1<C4`00`00003oIVIVofIVIP02ofIVIP030000001oOgl0Ogmo0080Ogmo00<0000009VI
V@2IVIT00`2IVIT00`000000/k>c0;>c/`0;0;>c/`03o`00002IVIT0VIVI00<0VIVI00<0000007mo
O`1oOgl00P1oOgl00`00003oIVIVofIVIP02ofIVIP030000001<C4`0C4a<0080C4a<00<0000003<c
<`0c<c<00`0c<c<00`0000006ATIooooo`02ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
00000?oooooooooo00<0<c<c00?o000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVH00000
00@0Ogmo00D0000009VIV@2IVIT0VIVIo`0000050;>c/`030000003<c<`0c<c<00d0c<c<00<00000
0;>c/`2c/k<00`2c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo00Go000006IVIP1VIVH0IVIV
0000000404a<C0030000000c<c<0<c<c00<0<c<c00?o000001TI6@0I6AT01P0I6ATk000000?ooooo
00<00000ooooooooool0<Oooool00ol0003oooooooooo`0oo`0000P06ATI00<0000003<c<`0c<c<0
0`0c<c<00`000000C4a<04a<C00204a<C00500000?mVIVKoIVIVofIVI_l00000101oOgl00`000000
VIVI09VIV@0309VIV@03o`00002c/k<0/k>c00d0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000
Ogmo07moO`0207moO`0500000?mVIVKoIVIVofIVIP000000101<C4`00`000000<c<c03<c<`0303<c
<`030000000I6AWooooo00;ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooooooo
ool00`0c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP000000101oOgl01@00
0000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`03P3<c<`00`000000/k>c0;>c/`03
0;>c/`050000002IVIT0VIVI09VIV@000000101oOgl01@000000IVIV06IVIP1VIVH0000000@0C4a<
00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0601TI6C/000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo03oo0000200I6AT00`000000<c<c03<c<`0303<c<`030000
001<C4`0C4a<0080C4a<00D00000ofIVI_mVIVKoIVIV0000000307moO`03o`00002IVIT0VIVI00<0
VIVI00<000000;>c/`2c/k<03`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080
Ogmo00D00000ofIVI_mVIVKoIVIV0000000404a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI
6Oooool00_ooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0303<c<`05
0000001<C4`0C4a<04a<C0000000101VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00<00000
0;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c00@0<c<c0030000002c/k<0/k>c00<0/k>c00D00000
09VIV@2IVIT0VIVI0000000307moO`050000001VIVH0IVIV06IVIP000000101<C4`00`000000<c<c
03<c<`0303<c<`030000000I6AT06ATI00H06ATI>`000003ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool0?_l0000901TI6@030000000c<c<0<c<c0080<c<c00<0000004a<C01<C4`0
0P1<C4`00`00003oIVIVofIVIP02ofIVIP050000001oOgl0Ogmo07moO`000000102IVIT00`000000
/k>c0;>c/`0A0;>c/`030000002IVIT0VIVI0080VIVI00D0000007moO`1oOgl0Ogmo00000003ofIV
IP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATIooooo`02oooo
o`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00<0<c<c00D0000004a<C01<
C4`0C4a<0000000306IVIP030000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVI00000004
0;>c/`030000003<c<`0c<c<00D0c<c<1Ol000070<c<c0030000002c/k<0/k>c0080/k>c00D00000
09VIV@2IVIT0VIVI0000000407moO`050000001VIVH0IVIV06IVIP000000101<C4`00`000000<c<c
03<c<`0203<c<`030000000I6AT06ATI00H06ATI>`000003ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool0?_l0000801TI6@030000000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`0
0P1<C4`01@00003oIVIVofIVI_mVIVH0000000<0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000
/k>c0;>c/`040;>c/`03o`00002c/k<0000000@00000202c/k<01Ol00000VIVI09VIV@2IVIT00000
00@0Ogmo00D00000ofIVI_mVIVKoIVIV0000000404a<C0030000000c<c<0<c<c00<0<c<c00D00000
ooooooooooooooooo`00000Kooooo`006_ooool00`00003oooooooooo`0303<c<`050000001<C4`0
C4a<04a<C?l000000`1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00<000000;>c/`2c/k<0
0P2c/k<00`000000c<c<0<c<c0040<c<c0;o00001@3Vi^H2o`0000H0c<c<00?o00000;>c/`2c/k<0
0P2c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00D0000006IVIP1VIVH0IVIV0000000404a<
C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01P0I6ATk000000?ooooo00<00000oooo
ooooool0<Oooool00ol0003oooooooooo`0no`0000P06ATI00<0000003<c<`0c<c<00`0c<c<01@00
0000C4a<04a<C01<C4`0000000CoIVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@03o`00002c
/k<0/k>c00<0/k>c00<00000o`00000000001@3<c<`00ol000000000000000050;>c/`030000002I
VIT0VIVI0080VIVI00D0000007moO`1oOgl0Ogmo00000003ofIVIP030000001<C4`0C4a<0080C4a<
00<0000003<c<`0c<c<00`0c<c<01@00003ooooooooooooooooo000001_ooooo000Jooooo`030000
0?oooooooooo00<0<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP05o`00001oOgl0Ogmo07mo
O`0000000`2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KV
iP3Vi^H01`3Vi^H2o`0000D0c<c<00D000000;>c/`2c/k<0/k>c0000000309VIV@050000001oOgl0
Ogmo07moO`0000000`1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c0080<c<c00<0
000001TI6@0I6AT01P0I6ATk000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`0no`0000P06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000CoIVIV
00D0000007moO`1oOgl0Ogmo0000000309VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<
c<`02@3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00D0000007moO`1o
Ogl0Ogmo00000003ofIVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00`0c<c<01@00
003ooooooooooooooooo000001_ooooo000Jooooo`0300000?oooooooooo0080<c<c00D0000004a<
C01<C4`0C4a<0000000406IVIP040000001oOgl0Ogmo000000<0VIVI00<000000;>c/`2c/k<00P2c
/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00X0i^KV00?o00000<c<c03<c<`00P3<
c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@0000000`1oOgl01@000000IVIV
06IVIP1VIVH0000000<0C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0601TI6CX0
00000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03go0000200I6AT00`000000
<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C00000001?mVIVH01@000000Ogmo07moO`1oOgl0
000000<0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c00;0<c<c003o`00002c/k<0
/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000?oIVIV00<0
000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0203<c<`0500000?ooooooooooooooool00000
6oooool001[ooooo00<00000ooooooooool00P0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV
00D0000007moO`1oOgl0Ogmoo`00000309VIV@050000002c/k<0/k>c0;>c/`0000001@3<c<`00ol0
0000i^KV0>KViP0<0>KViP03o`00003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0/k>c00000003
09VIV@050000001oOgl0Ogmo07moO`0000000`1VIVH01@000000C4a<04a<C01<C4`0000000D0<c<c
00<0000001TI6@0I6AT01P0I6ATj000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`0mo`0000P06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4co000000?o
IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@030000002c/k<0/k>c00<0/k>c00?o00000<c<
c03<c<`03@3<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@0000000`1oOgl0
1@00003oIVIVofIVI_mVIVH0000000@0C4a<00<0000003<c<`0c<c<00P0c<c<01@00003ooooooooo
oooooooo000001_ooooo000Jooooo`0300000?oooooooooo0080<c<c00D0000004a<C01<C4`0C4a<
0000000306IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT01@000000/k>c0;>c/`2c/k?o0000
00D0c<c<00?o00000>KViP3Vi^H0303Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c
0;>c/`0000000`2IVIT01@000000Ogmo07moO`1oOgl0000000<0IVIV00D0000004a<C01<C4`0C4a<
0000000503<c<`030000000I6AT06ATI00H06ATI>P000003ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool0?Ol0000801TI6@030000000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0
C4a<00000003ofIVIP05o`00001oOgl0Ogmo07moOol000000`2IVIT00`000000/k>c0;>c/`030;>c
/`030000003<c<`0c<c<00d0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0
000000<0Ogmo00D00000ofIVI_mVIVKoIVIV0000000404a<C0030000000c<c<0<c<c0080<c<c00D0
0000ooooooooooooooooo`00000Kooooo`006_ooool00`00003oooooooooo`0203<c<`050000001<
C4`0C4a<04a<C00000000`1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00D000000;>c/`2c
/k<0/k>c000000040<c<c003o`00003Vi^H0i^KV00d0i^KV00?o00000<c<c03<c<`00P3<c<`01@00
0000/k>c0;>c/`2c/k<0000000<0VIVI00D0000007moO`1oOgl0Ogmo0000000306IVIP050000001<
C4`0C4a<04a<C00000001@0c<c<00`0000006ATI01TI6@0601TI6CX000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo03go0000200I6AT00`000000<c<c03<c<`0303<c<`050000
001<C4`0C4a<04a<C00000000omVIVH01@000000Ogmo07moO`1oOgl000000080VIVI00<000000;>c
/`2c/k<00`2c/k<00`000000c<c<0<c<c00?0<c<c0050000002c/k<0/k>c0;>c/`000000102IVIT0
10000000Ogmo07moO`000003ofIVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c
<c<01@00003ooooooooooooooooo000001_ooooo000Jooooo`0500000?oooooooooo03<c<`000000
101<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00D0000009VIV@2IVIT0VIVI000000030;>c
/`030000003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H03`3Vi^H00ol00000c<c<0<c<c0020<c<
c0050000002c/k<0/k>c0;>c/`0000000`2IVIT010000000Ogmo07moO`00000306IVIP030000001<
C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0601TI6CX000000ooo
ool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03go0000200I6AT00`000000<c<c03<c
<`0203<c<`050000001<C4`0C4a<04a<C00000000omVIVH01@000000Ogmo07moO`1oOgl0000000<0
VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0050<c<c0Go00001P3<c<`00`000000
/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIVOl000000P1oOgl00`00003oIVIVofIVIP02ofIV
IP050000001<C4`0C4a<04a<C00000001@0c<c<01000003oooooooooool0000Kooooo`006_ooool0
1@00003oooooooooo`0c<c<0000000@0C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`050000
002IVIT0VIVI09VIV@0000000`2c/k<01@000000c<c<0<c<c03<c<co000001<0i^KV00Go00000<c<
c03<c<`0c<c<000000030;>c/`050000002IVIT0VIVI09VIV@0000000P1oOgl01@000000IVIV06IV
IP1VIVH0000000@0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0601TI6CX00000
0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03go00001`0I6AT00`000000<c<c
03<c<`0303<c<`050000001<C4`0C4a<04a<C00000000omVIVH01@000000Ogmo07moO`1oOgl00000
00<0VIVI00D000000;>c/`2c/k<0/k>c000000060<c<c0;o00001@3Vi^H2o`0000D0c<c<00Go0000
0;>c/`2c/k<0/k>c0000000309VIV@050000001oOgl0Ogmo07moO`0000000omVIVH01@000000C4a<
04a<C01<C4`0000000D0<c<c00@00000oooooooooooo00006oooool001[ooooo00D00000oooooooo
ool0<c<c0000000404a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl01@000000VIVI09VIV@2I
VIT0000000<0/k>c00D000000<c<c03<c<`0c<c<o`0000060>KViPKo00001`3Vi^H01Ol00000c<c<
0<c<c03<c<`0000000<0/k>c00D0000009VIV@2IVIT0VIVI0000000207moO`050000001VIVH0IVIV
06IVIP000000101<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00H06ATI>P000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0?Ol0000701TI6@030000000c<c<0
<c<c00<0<c<c00D0000004a<C01<C4`0C4a<00000003ofIVIP050000001oOgl0Ogmo07moO`000000
0`2IVIT01@000000/k>c0;>c/`2c/k<0000000D0c<c<00?o00000>KViP3Vi^H01`3Vi^H00ol00000
c<c<0<c<c0030<c<c0040000002c/k<0/k>c000000<0VIVI00D0000007moO`1oOgl0Ogmo00000003
ofIVIP050000001<C4`0C4a<04a<C00000001@0c<c<01000003oooooooooool0000Kooooo`006_oo
ool01@00003oooooooooo`0c<c<0000000<0C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`04
0000002IVIT0VIVI000000<0/k>c00D000000<c<c03<c<`0c<c<o`0000060>KViP03o`00003oool0
oooo00@0oooo0_l000060>KViP05o`00003<c<`0c<c<0<c<c00000000`2c/k<010000000VIVI09VI
V@00000307moO`050000001VIVH0IVIV06IVIP0000000`1<C4`00`000000<c<c03<c<`0303<c<`03
0000000I6AT06ATI00D06ATI>P000003ooooo`0300000?oooooooooo037ooooo00?o0000oooooooo
ool0??l0000701TI6@030000000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<00000003ofIV
IP050000001oOgl0Ogmo07moO`0000000`2IVIT01@000000/k>c0;>c/`2c/k<0000000D0c<c<00?o
00000>KViP3Vi^H02@3Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`000000
0`2IVIT01@000000Ogmo07moO`1oOgl0000000;oIVIV00<0000004a<C01<C4`00P1<C4`00`000000
<c<c03<c<`0203<c<`0400000?ooooooooooo`0001_ooooo000Jooooo`0500000?oooooooooo03<c
<`0000000`1<C4`01@000000IVIV06IVIP1VIVH0000000<0Ogmo00@0000009VIV@2IVIT000000`2c
/k<01@000000c<c<0<c<c03<c<co000000D0i^KV00?o00000?ooo`3oool01`3oool00ol00000i^KV
0>KViP030>KViP05o`00003<c<`0c<c<0<c<c00000000`2c/k<010000000VIVI09VIV@00000307mo
O`050000001VIVH0IVIV06IVIP0000000`1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT0
6ATI00D06ATI>P000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0??l00007
01TI6@030000000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<00000003ofIVIP040000001o
Ogl0Ogmo000000<0VIVI00D000000;>c/`2c/k<0/k>c000000040<c<c0;o00003@3Vi^H01Ol00000
c<c<0<c<c03<c<`0000000<0/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`0400000?mVIVKo
IVIV000000@0C4a<00<0000003<c<`0c<c<00P0c<c<01000003oooooooooool0000Kooooo`006_oo
ool01@00003oooooooooo`0c<c<0000000<0C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`04
0000002IVIT0VIVI000000<0/k>c00D000000<c<c03<c<`0c<c<o`0000050>KViP03o`00003oool0
oooo00L0oooo00?o00000>KViP3Vi^H00`3Vi^H01Ol00000c<c<0<c<c03<c<`0000000<0/k>c00@0
000009VIV@2IVIT000000`1oOgl01@000000IVIV06IVIP1VIVH0000000<0C4a<00<0000003<c<`0c
<c<00`0c<c<00`0000006ATI01TI6@0501TI6CX000000oooool00`00003oooooooooo`0aooooo`03
o`000?oooooooooo03co00001`0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<
C00000000omVIVH010000000Ogmo07moO`00000309VIV@050000002c/k<0/k>c0;>c/`000000103<
c<`00ol00000i^KV0>KViP0<0>KViP05o`00003<c<`0c<c<0<c<c00000000`2c/k<01@000000VIVI
09VIV@2IVIT0000000<0Ogmo00@00000ofIVI_mVIVH00000101<C4`00`000000<c<c03<c<`0203<c
<`?ooooo00?o0000ooooooooool06Oooool001[ooooo00D00000ooooooooool0<c<c0000000304a<
C0050000001VIVH0IVIV06IVIP0000000`1oOgl010000000VIVI09VIV@0000030;>c/`050000003<
c<`0c<c<0<c<c?l00000103Vi^H00ol00000oooo0?ooo`090?ooo`03o`00003Vi^H0i^KV0080i^KV
00?o00000<c<c03<c<`00P3<c<`010000000/k>c0;>c/`00000209VIV@050000001oOgl0Ogmo07mo
O`0000000`1VIVH01@000000C4a<04a<C01<C4`0000000D0<c<c00<0000001TI6@0I6AT01@0I6ATj
000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0lo`0000L06ATI00<00000
03<c<`0c<c<00P0c<c<00`000000C4a<04a<C00204a<C00500000?mVIVKoIVIVofIVIP0000000P1o
Ogl01@000000VIVI09VIV@2IVIT000000080/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV
0>KViP0=0>KViP05o`00003<c<`0c<c<0<c<c00000000`2c/k<01@000000VIVI09VIV@2IVIT00000
00<0Ogmo00@00000ofIVI_mVIVH00000101<C4`00`000000<c<c03<c<`0203<c<`?ooooo00?o0000
ooooooooool06Oooool001[ooooo00D00000ooooooooool0<c<c0000000304a<C0050000001VIVH0
IVIV06IVIP0000000P1oOgl01@000000VIVI09VIV@2IVIT000000080/k>c00D000000<c<c03<c<`0
c<c<o`0000050>KViP03o`00003oool0oooo00T0oooo00?o00000>KViP3Vi^H00`3Vi^H01Ol00000
c<c<0<c<c03<c<`000000080/k>c00Go000009VIV@2IVIT0VIVI0000000207moO`050000001VIVH0
IVIV06IVI_l00000101<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00H06ATI>@00
0003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0>ol0000801TI6@030000000c
<c<0<c<c0080<c<c00Go000004a<C01<C4`0C4a<00000003ofIVIP040000001oOgl0Ogmo000000<0
VIVI00D000000;>c/`2c/k<0/k>c000000040<c<c003o`00003Vi^H0i^KV00d0i^KV00?o00000<c<
c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00@0000007moO`1oOgl000000omV
IVH01@000000C4a<04a<C01<C4`0000000@0<c<c0oooool00ol0003oooooooooo`0Iooooo`006_oo
ool01@00003oooooooooo`0c<c<0000000<0C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`05
0000002IVIT0VIVI09VIV@0000000P2c/k<01@000000c<c<0<c<c03<c<co000000@0i^KV00?o0000
0?ooo`3oool02`3oool00ol00000i^KV0>KViP020>KViP05o`00003<c<`0c<c<0<c<c00000000P2c
/k<01@000000VIVI09VIV@2IVIT000000080Ogmo00Go000006IVIP1VIVH0IVIV0000000404a<C003
0000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01P0I6ATi000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`0ko`0000P06ATI00<0000003<c<`0c<c<00P0c<c<01@000000
C4a<04a<C01<C4`0000000?oIVIV00@0000007moO`1oOgl000000`2IVIT010000000/k>c0;>c/`00
00040<c<c003o`00003Vi^H0i^KV00l0i^KV00Go00000<c<c03<c<`0c<c<000000030;>c/`050000
002IVIT0VIVI09VIV@0000000P1oOgl01@00003oIVIVofIVI_mVIVH0000000<0C4a<00<0000003<c
<`0c<c<00P0c<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0500000?oooooooooo03<c
<`0000000`1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00D0000009VIV@2IVIT0VIVI0000
00020;>c/`050000003<c<`0c<c<0<c<c?l00000103Vi^H00ol00000oooo0?ooo`0;0?ooo`03o`00
003Vi^H0i^KV0080i^KV00Go00000<c<c03<c<`0c<c<000000020;>c/`050000002IVIT0VIVI09VI
V@0000000P1oOgl01@000000IVIV06IVIP1VIVH0000000@0C4a<00<0000003<c<`0c<c<00P0c<c<0
0`0000006ATI01TI6@0601TI6CT000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooo
oooo03_o0000200I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000omV
IVH010000000Ogmo07moOol0000309VIV@040000002c/k<0/k>co`0000@0c<c<00?o00000>KViP3V
i^H01@3Vi^H3o`0000L0i^KV00Go00000<c<c03<c<`0c<c<000000030;>c/`050000002IVIT0VIVI
09VIV@0000000P1oOgl01@00003oIVIVofIVI_mVIVH0000000<0C4a<00<0000003<c<`0c<c<00P0c
<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0500000?oooooooooo03<c<`0000000`1<
C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00D0000009VIV@2IVIT0VIVI000000020;>c/`05
0000003<c<`0c<c<0<c<c?l00000103Vi^H00ol00000oooo0?ooo`0;0?ooo`03o`00003Vi^H0i^KV
0080i^KV00Go00000<c<c03<c<`0c<c<000000020;>c/`050000002IVIT0VIVI09VIV@0000000P1o
Ogl01@000000IVIV06IVIP1VIVH0000000@0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI
01TI6@0601TI6CT000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03_o0000
200I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000_mVIVH01@000000
Ogmo07moO`1oOgl0000000<0VIVI00@000000;>c/`2c/k<000000`3<c<`00ol00000i^KV0>KViP04
0>KViP;o00000`3oool00ol00000i^KV0>KViP040>KViP05o`00003<c<`0c<c<0<c<c00000000`2c
/k<01@000000VIVI09VIV@2IVIT000000080Ogmo00D00000ofIVI_mVIVKoIVIV0000000304a<C003
0000000c<c<0<c<c0080<c<c0oooool00ol0003oooooooooo`0Iooooo`006_ooool01000003ooooo
ooooo`00000404a<C0040000001VIVH0IVIV000000<0Ogmo00@0000009VIV@2IVIT000000`2c/k<0
10000000c<c<0<c<c?l000040>KViP03o`00003oool0oooo00d0oooo00?o00000>KViP3Vi^H00P3V
i^H01?l00000c<c<0<c<c00000030;>c/`040000002IVIT0VIVI000000<0Ogmo00@0000006IVIP1V
IVH00000101<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00H06ATI>@000003oooo
o`0300000?oooooooooo037ooooo00?o0000ooooooooool0>ol0000701TI6@030000000c<c<0<c<c
0080<c<c00<0000004a<C01<C4`00P1<C4`01000003oIVIVofIVIP00000307moO`040000002IVIT0
VIVI00000080/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP030>KViP03o`00003o
ool0oooo00@0oooo00?o00000>KViP3Vi^H0103Vi^H01Ol00000c<c<0<c<c03<c<`0000000<0/k>c
00@0000009VIV@2IVIT000000P1oOgl01@00003oIVIVofIVI_mVIVH0000000<0C4a<00<0000003<c
<`0c<c<00P0c<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0400000?oooooooooo0000
00@0C4a<00@0000006IVIP1VIVH000000`1oOgl010000000VIVI09VIV@0000030;>c/`040000003<
c<`0c<c<o`0000@0i^KV00?o00000?ooo`3oool03@3oool00ol00000i^KV0>KViP020>KViP04o`00
003<c<`0c<c<000000<0/k>c00@0000009VIV@2IVIT000000`1oOgl010000000IVIV06IVIP000004
04a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01P0I6ATi000000?ooooo00<00000
ooooooooool0<Oooool00ol0003oooooooooo`0ko`0000L06ATI00<0000003<c<`0c<c<00P0c<c<0
0`000000C4a<04a<C00204a<C00400000?mVIVKoIVIV000000<0Ogmo00@0000009VIV@2IVIT00000
0P2c/k<01@000000c<c<0<c<c03<c<co000000D0i^KV00?o00000?ooo`3oool01P3oool00ol00000
i^KV0>KViP030>KViP05o`00003<c<`0c<c<0<c<c00000000`2c/k<010000000VIVI09VIV@000002
07moO`0500000?mVIVKoIVIVofIVIP0000000`1<C4`00`000000<c<c03<c<`0203<c<`?ooooo00?o
0000ooooooooool06Oooool001[ooooo00@00000ooooooooool00000101<C4`010000000IVIV06IV
IP00000307moO`040000002IVIT0VIVI000000<0/k>c00@000000<c<c03<c<co0000103Vi^H00ol0
0000oooo0?ooo`0=0?ooo`03o`00003Vi^H0i^KV0080i^KV00Co00000<c<c03<c<`000000`2c/k<0
10000000VIVI09VIV@00000307moO`040000001VIVH0IVIV000000@0C4a<00<0000003<c<`0c<c<0
0P0c<c<00`0000006ATI01TI6@0601TI6CT000000oooool00`00003oooooooooo`0aooooo`03o`00
0?oooooooooo03_o00001`0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<
00@00000ofIVI_mVIVH000000`1oOgl010000000VIVI09VIV@0000020;>c/`050000003<c<`0c<c<
0<c<c?l000001@3Vi^H00ol00000oooo0?ooo`060?ooo`03o`00003Vi^H0i^KV00<0i^KV00Go0000
0<c<c03<c<`0c<c<000000030;>c/`040000002IVIT0VIVI00000080Ogmo00D00000ofIVI_mVIVKo
IVIV0000000304a<C0030000000c<c<0<c<c0080<c<c0oooool00ol0003oooooooooo`0Iooooo`00
6_ooool01000003oooooooooo`00000304a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl01000
0000VIVI09VIV@0000020;>c/`050000003<c<`0c<c<0<c<c?l00000103Vi^H00ol00000oooo0?oo
o`0=0?ooo`03o`00003Vi^H0i^KV0080i^KV00Go00000<c<c03<c<`0c<c<000000020;>c/`040000
002IVIT0VIVI000000<0Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<C0030000000c<c<0<c<c
0080<c<c00<0000001TI6@0I6AT01P0I6ATi000000?ooooo00<00000ooooooooool0<Oooool00ol0
003oooooooooo`0jo`0000P06ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`0
000000?oIVIV00@0000007moO`1oOgl000000P2IVIT010000000/k>c0;>c/`0000030<c<c003o`00
003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool0203oool00ol00000i^KV0>KViP030>KViP05o`00
003<c<`0c<c<0<c<c00000000P2c/k<010000000VIVI09VIV@00000207moO`0500000?mVIVKoIVIV
ofIVIP0000000`1<C4`00`000000<c<c03<c<`0203<c<`?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00@00000ooooooooool000000`1<C4`01@000000IVIV06IVIP1VIVH0000000<0Ogmo00@0
000009VIV@2IVIT000000P2c/k<01@000000c<c<0<c<c03<c<co000000@0i^KV00?o00000?ooo`3o
ool03@3oool00ol00000i^KV0>KViP020>KViP05o`00003<c<`0c<c<0<c<c00000000P2c/k<01000
0000VIVI09VIV@00000307moO`050000001VIVH0IVIV06IVIP0000000`1<C4`00`000000<c<c03<c
<`0203<c<`030000000I6AT06ATI00H06ATI>@000003ooooo`0300000?oooooooooo037ooooo00?o
0000ooooooooool0>_l0000801TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<
00000003ofIVIP040000001oOgl0Ogmo00000080VIVI00@000000;>c/`2c/k<000000`3<c<`00ol0
0000i^KV0>KViP020>KViP03o`00003oool0oooo00X0oooo00?o00000>KViP3Vi^H00P3Vi^H01Ol0
0000c<c<0<c<c03<c<`000000080/k>c00@0000009VIV@2IVIT000000P1oOgl01@00003oIVIVofIV
I_mVIVH0000000<0C4a<00<0000003<c<`0c<c<00P0c<c<3ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0400000?oooooooooo000000<0C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`04
0000002IVIT0VIVI00000080/k>c00D000000<c<c03<c<`0c<c<o`0000040>KViP03o`00003oool0
oooo00d0oooo00?o00000>KViP3Vi^H00P3Vi^H01Ol00000c<c<0<c<c03<c<`000000080/k>c00@0
000009VIV@2IVIT000000`1oOgl01@000000IVIV06IVIP1VIVH0000000<0C4a<00<0000003<c<`0c
<c<00P0c<c<00`0000006ATI01TI6@0601TI6CT000000oooool00`00003oooooooooo`0aooooo`03
o`000?oooooooooo03[o0000200I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<
C00000000omVIVH010000000Ogmo07moO`00000209VIV@040000002c/k<0/k>c000000<0c<c<00?o
00000>KViP3Vi^H00P3Vi^H00ol00000oooo0?ooo`0:0?ooo`03o`00003Vi^H0i^KV0080i^KV00Go
00000<c<c03<c<`0c<c<000000020;>c/`040000002IVIT0VIVI00000080Ogmo00D00000ofIVI_mV
IVKoIVIV0000000304a<C0030000000c<c<0<c<c0080<c<c0oooool00ol0003oooooooooo`0Ioooo
o`006_ooool01000003oooooooooo`00000304a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl0
10000000VIVI09VIV@0000020;>c/`050000003<c<`0c<c<0<c<c?l00000103Vi^H00ol00000oooo
0?ooo`0=0?ooo`03o`00003Vi^H0i^KV0080i^KV00Go00000<c<c03<c<`0c<c<000000020;>c/`04
0000002IVIT0VIVI000000<0Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<C0030000000c<c<0
<c<c0080<c<c00<0000001TI6@0I6AT01P0I6ATi000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`0jo`0000P06ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<
C4`0000000?oIVIV00@0000007moO`1oOgl000000P2IVIT010000000/k>c0;>c/`0000030<c<c003
o`00003Vi^H0i^KV0080i^KV00?o00000?ooo`3oool02P3oool00ol00000i^KV0>KViP020>KViP05
o`00003<c<`0c<c<0<c<c00000000P2c/k<010000000VIVI09VIV@00000207moO`0500000?mVIVKo
IVIVofIVIP0000000`1<C4`00`000000<c<c03<c<`0203<c<`?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00@00000ooooooooool000000`1<C4`01@000000IVIV06IVIP1VIVH0000000<0Ogmo
00@0000009VIV@2IVIT000000P2c/k<01@000000c<c<0<c<c03<c<co000000@0i^KV00?o00000?oo
o`3oool03@3oool00ol00000i^KV0>KViP020>KViP05o`00003<c<`0c<c<0<c<c00000000P2c/k<0
10000000VIVI09VIV@00000307moO`040000001VIVH0IVIV000000@0C4a<00<0000003<c<`0c<c<0
0P0c<c<00`0000006ATI01TI6@0601TI6CT000000oooool00`00003oooooooooo`0aooooo`03o`00
0?oooooooooo03[o00001`0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C000
00000omVIVH010000000Ogmo07moO`00000209VIV@050000002c/k<0/k>c0;>c/`0000000P3<c<`0
0ol00000i^KV0>KViP020>KViP03o`00003oool0oooo00`0oooo00Go00000>KViP3Vi^H0i^KVo`00
00030<c<c0040000002c/k<0/k>c00000080VIVI00@0000007moO`1oOgl000000omVIVH01@000000
C4a<04a<C01<C4`0000000@0<c<c0oooool00ol0003oooooooooo`0Iooooo`006_ooool01000003o
ooooooooo`00000304a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl010000000VIVI09VIV@00
00020;>c/`050000003<c<`0c<c<0<c<c?l00000103Vi^H00ol00000oooo0?ooo`0=0?ooo`03o`00
003Vi^H0i^KV0080i^KV00Go00000<c<c03<c<`0c<c<000000020;>c/`040000002IVIT0VIVI0000
00<0Ogmo00@0000006IVIP1VIVH00000101<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT0
6ATI00H06ATI>@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0>_l00007
01TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<00000003ofIVIP040000001o
Ogl0Ogmo00000080VIVI00D000000;>c/`2c/k<0/k>c000000020<c<c003o`00003Vi^H0i^KV0080
i^KV00?o00000?ooo`3oool0303oool01Ol00000i^KV0>KViP3Vi^Ko000000<0c<c<00@000000;>c
/`2c/k<000000P2IVIT010000000Ogmo07moO`000003ofIVIP050000001<C4`0C4a<04a<C0000000
100c<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0400000?oooooooooo000000<0C4a<
00D0000006IVIP1VIVH0IVIV0000000307moO`040000002IVIT0VIVI00000080/k>c00D000000<c<
c03<c<`0c<c<o`0000040>KViP03o`00003oool0oooo00d0oooo00?o00000>KViP3Vi^H00P3Vi^H0
1Ol00000c<c<0<c<c03<c<`000000080/k>c00@0000009VIV@2IVIT000000`1oOgl010000000IVIV
06IVIP00000404a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01P0I6ATi000000?o
oooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0jo`0000L06ATI00<0000003<c<`0c
<c<00P0c<c<01@000000C4a<04a<C01<C4`0000000?oIVIV00@0000007moO`1oOgl000000P2IVIT0
1@000000/k>c0;>c/`2c/k<000000080c<c<00?o00000>KViP3Vi^H00P3Vi^H00ol00000oooo0?oo
o`0<0?ooo`05o`00003Vi^H0i^KV0>KVi_l000000`3<c<`010000000/k>c0;>c/`00000209VIV@04
0000001oOgl0Ogmo000000?oIVIV00D0000004a<C01<C4`0C4a<0000000403<c<`?ooooo00?o0000
ooooooooool06Oooool001[ooooo00@00000ooooooooool000000`1<C4`01@000000IVIV06IVIP1V
IVH0000000<0Ogmo00@0000009VIV@2IVIT000000P2c/k<01@000000c<c<0<c<c03<c<co000000@0
i^KV00?o00000?ooo`3oool03@3oool00ol00000i^KV0>KViP020>KViP05o`00003<c<`0c<c<0<c<
c00000000P2c/k<010000000VIVI09VIV@00000307moO`040000001VIVH0IVIV000000@0C4a<00<0
000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0601TI6CT000000oooool00`00003ooooooooo
o`0aooooo`03o`000?oooooooooo03[o00001`0I6AT00`000000<c<c03<c<`0203<c<`050000001<
C4`0C4a<04a<C00000000omVIVH010000000Ogmo07moO`00000209VIV@050000002c/k<0/k>c0;>c
/`0000000P3<c<`00ol00000i^KV0>KViP020>KViP03o`00003oool0oooo00`0oooo00Go00000>KV
iP3Vi^H0i^KVo`0000030<c<c0040000002c/k<0/k>c00000080VIVI00@0000007moO`1oOgl00000
0omVIVH01@000000C4a<04a<C01<C4`0000000@0<c<c0oooool00ol0003oooooooooo`0Iooooo`00
6_ooool01000003oooooooooo`00000404a<C0040000001VIVH0IVIV000000<0Ogmo00@0000009VI
V@2IVIT000000`2c/k<010000000c<c<0<c<c?l000040>KViP03o`00003oool0oooo00d0oooo00?o
00000>KViP3Vi^H00P3Vi^H01?l00000c<c<0<c<c00000030;>c/`040000002IVIT0VIVI000000<0
Ogmo00@0000006IVIP1VIVH00000101<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI
00H06ATI>@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0>_l0000701TI
6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<00000003ofIVIP040000001oOgl0
Ogmo00000080VIVI00@000000;>c/`2c/k<000000`3<c<`01Ol00000i^KV0>KViP3Vi^Ko000000l0
oooo00Go00000>KViP3Vi^H0i^KVo`0000030<c<c0040000002c/k<0/k>c00000080VIVI00@00000
07moO`1oOgl000000omVIVH01@000000C4a<04a<C01<C4`0000000@0<c<c0oooool00ol0003ooooo
ooooo`0Iooooo`006_ooool01000003oooooooooo`00000404a<C0040000001VIVH0IVIV000000<0
Ogmo00@0000009VIV@2IVIT000000`2c/k<010000000c<c<0<c<c?l000040>KViP03o`00003oool0
oooo00d0oooo00?o00000>KViP3Vi^H00P3Vi^H01?l00000c<c<0<c<c00000030;>c/`040000002I
VIT0VIVI000000<0Ogmo00Co000006IVIP1VIVH00000101<C4`00`000000<c<c03<c<`0203<c<`03
0000000I6AT06ATI00H06ATI>@000003ooooo`0300000?oooooooooo037ooooo00?o0000oooooooo
ool0>_l0000701TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<00000003ofIV
IP040000001oOgl0Ogmo00000080VIVI00@000000;>c/`2c/k<000000`3<c<`01Ol00000i^KV0>KV
iP3Vi^Ko000000l0oooo00Go00000>KViP3Vi^H0i^KVo`0000030<c<c0040000002c/k<0/k>c0000
0080VIVI00@0000007moO`1oOgl000000omVIVH01@000000C4a<04a<C01<C4`0000000@0<c<c0ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool01000003oooooooooo`00000404a<C0040000001V
IVH0IVIV000000<0Ogmo00@0000009VIV@2IVIT000000`2c/k<010000000c<c<0<c<c?l000040>KV
iP03o`00003oool0oooo00d0oooo00?o00000>KViP3Vi^H00P3Vi^H01?l00000c<c<0<c<c0000003
0;>c/`040000002IVIT0VIVI00000080Ogmo00D0000006IVIP1VIVH0IVIV0000000404a<C0030000
000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01P0I6ATi000000?ooooo00<00000ooooooooool0
<Oooool00ol0003oooooooooo`0jo`0000L06ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<
04a<C01<C4`0000000?oIVIV00@0000007moO`1oOgl000000P2IVIT010000000/k>c0;>c/`000003
0<c<c005o`00003Vi^H0i^KV0>KVi_l000003`3oool01Ol00000i^KV0>KViP3Vi^Ko000000<0c<c<
00@000000;>c/`2c/k<000000P2IVIT010000000Ogmo07moO`000003ofIVIP050000001<C4`0C4a<
04a<C0000000100c<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0500000?oooooooooo
03<c<`0000000`1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00D0000009VIV@2IVIT0VIVI
000000020;>c/`050000003<c<`0c<c<0<c<c?l00000103Vi^H00ol00000oooo0?ooo`0;0?ooo`03
o`00003Vi^H0i^KV0080i^KV00Go00000<c<c03<c<`0c<c<000000020;>c/`050000002IVIT0VIVI
09VIV@0000000P1oOgl01@000000IVIV06IVIP1VIVH0000000<0C4a<00<0000003<c<`0c<c<00`0c
<c<00`0000006ATI01TI6@0601TI6CT000000oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo03[o00001`0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C0000000
0_mVIVH01@000000Ogmo07moO`1oOgl000000080VIVI00@000000;>c/`2c/k<000000`3<c<`01Ol0
0000i^KV0>KViP3Vi^Ko000000l0oooo00Go00000>KViP3Vi^H0i^KVo`0000020<c<c0050000002c
/k<0/k>c0;>c/`0000000P2IVIT010000000Ogmo07moO`000003ofIVIP050000001<C4`0C4a<04a<
C0000000100c<c<01?l0003oooooooooool0000Kooooo`006_ooool01@00003oooooooooo`0c<c<0
000000<0C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`050000002IVIT0VIVI09VIV@000000
0P2c/k<01@000000c<c<0<c<c03<c<co000000@0i^KV00?o00000?ooo`3oool02`3oool00ol00000
i^KV0>KViP020>KViP05o`00003<c<`0c<c<0<c<c?l000000P2c/k<01Ol00000VIVI09VIV@2IVIT0
00000080Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<C0030000000c<c<0<c<c00<0<c<c00<0
000001TI6@0I6AT01P0I6ATi000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`0jo`0000L06ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`0000000;oIVIV
00D0000007moO`1oOgl0Ogmo0000000209VIV@040000002c/k<0/k>c000000<0c<c<00Go00000>KV
iP3Vi^H0i^KVo`00000?0?ooo`05o`00003Vi^H0i^KV0>KVi_l000000P3<c<`01@000000/k>c0;>c
/`2c/k<000000080VIVI00@0000007moO`1oOgl000000omVIVH01@000000C4a<04a<C01<C4`00000
00@0<c<c00Co0000oooooooooooo00006oooool001[ooooo00D00000ooooooooool0<c<c00000003
04a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl01@000000VIVI09VIV@2IVIT000000080/k>c
00D000000<c<c03<c<`0c<c<o`0000050>KViP03o`00003oool0oooo00X0oooo00?o00000>KViP3V
i^H00P3Vi^H01Ol00000c<c<0<c<c03<c<`000000080/k>c00D0000009VIV@2IVIT0VIVI00000002
07moO`050000001VIVH0IVIV06IVIP0000000`1<C4`00`000000<c<c03<c<`0303<c<`030000000I
6AT06ATI00H06ATI>@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0>_l0
000701TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<00000002ofIVIP050000
001oOgl0Ogmo07moO`0000000P2IVIT010000000/k>c0;>c/`0000030<c<c005o`00003Vi^H0i^KV
0>KVi_l000003`3oool01Ol00000i^KV0>KViP3Vi^Ko00000080c<c<00D000000;>c/`2c/k<0/k>c
0000000209VIV@040000001oOgl0Ogmo000000?oIVIV00D0000004a<C01<C4`0C4a<0000000403<c
<`04o`000?ooooooooooo`0001_ooooo000Jooooo`0500000?oooooooooo03<c<`0000000`1<C4`0
1@000000IVIV06IVIP1VIVH000000080Ogmo00D0000009VIV@2IVIT0VIVI000000020;>c/`050000
003<c<`0c<c<0<c<c?l000001@3Vi^H00ol00000oooo0?ooo`090?ooo`03o`00003Vi^H0i^KV00<0
i^KV00Go00000<c<c03<c<`0c<c<000000020;>c/`050000002IVIT0VIVI09VIV@0000000P1oOgl0
1@000000IVIV06IVIP1VIVH0000000<0C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI
6@0601TI6CT000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03[o00001`0I
6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000_mVIVH01@000000Ogmo
07moO`1oOgl000000080VIVI00@000000;>c/`2c/k<000000`3<c<`01Ol00000i^KV0>KViP3Vi^Ko
000000l0oooo00Go00000>KViP3Vi^H0i^KVo`0000020<c<c0050000002c/k<0/k>c0;>c/`000000
0P2IVIT010000000Ogmo07moO`000003ofIVIP050000001<C4`0C4a<04a<C0000000100c<c<01?l0
003oooooooooool0000Kooooo`006_ooool01@00003oooooooooo`0c<c<0000000<0C4a<00D00000
06IVIP1VIVH0IVIV0000000307moO`040000002IVIT0VIVI000000<0/k>c00D000000<c<c03<c<`0
c<c<o`0000050>KViP03o`00003oool0oooo00L0oooo00?o00000>KViP3Vi^H00`3Vi^H01Ol00000
c<c<0<c<c03<c<`0000000<0/k>c00@0000009VIV@2IVIT000000`1oOgl01@000000IVIV06IVIP1V
IVH0000000<0C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0501TI6CX000000ooo
ool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03Wo0000200I6AT00`000000<c<c03<c
<`0203<c<`050000001<C4`0C4a<04a<C00000000_mVIVH01@000000Ogmo07moO`1oOgl000000080
VIVI00@000000;>c/`2c/k<000000`3<c<`01Ol00000i^KV0>KViP3Vi^Ko000000h0oooo00?o0000
0>KViP3Vi^H00P3Vi^H01?l00000c<c<0<c<c00000020;>c/`040000002IVIT0VIVI000000<0Ogmo
00@00000ofIVI_mVIVH000000`1<C4`00`000000<c<c03<c<`0303<c<`04o`000?ooooooooooo`00
01_ooooo000Jooooo`0500000?oooooooooo03<c<`0000000`1<C4`01@000000IVIV06IVIP1VIVH0
000000<0Ogmo00@0000009VIV@2IVIT000000`2c/k<01@000000c<c<0<c<c03<c<co000000D0i^KV
0_l000060?ooo`;o00001P3Vi^H01Ol00000c<c<0<c<c03<c<`0000000<0/k>c00@0000009VIV@2I
VIT000000`1oOgl01@000000IVIV06IVIP1VIVH0000000<0C4a<00<0000003<c<`0c<c<00`0c<c<0
0`0000006ATI01TI6@0501TI6CX000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooo
oooo03Wo0000200I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000_mV
IVH01@000000Ogmo07moO`1oOgl000000080VIVI00@000000;>c/`2c/k<000000`3<c<`01Ol00000
i^KV0>KViP3Vi^Ko000000h0oooo00?o00000>KViP3Vi^H00P3Vi^H01?l00000c<c<0<c<c0000002
0;>c/`040000002IVIT0VIVI000000<0Ogmo00@00000ofIVI_mVIVH000000`1<C4`00`000000<c<c
03<c<`0303<c<`04o`000?ooooooooooo`0001_ooooo000Jooooo`0500000?oooooooooo03<c<`00
00000`1<C4`01@000000IVIV06IVIP1VIVH0000000<0Ogmo00@0000009VIV@2IVIT000000`2c/k<0
1@000000c<c<0<c<c03<c<co000000L0i^KV00?o00000?ooo`3oool00P3oool00ol00000i^KV0>KV
iP060>KViP05o`00003<c<`0c<c<0<c<c00000000`2c/k<010000000VIVI09VIV@00000307moO`05
0000001VIVH0IVIV06IVIP0000000`1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI
00D06ATI>P000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0>Ol0000801TI
6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<00000002ofIVIP050000001oOgl0
Ogmo07moO`0000000P2IVIT010000000/k>c0;>c/`0000030<c<c005o`00003Vi^H0i^KV0>KVi_l0
00003P3oool00ol00000i^KV0>KViP020>KViP04o`00003<c<`0c<c<00000080/k>c00@0000009VI
V@2IVIT000000`1oOgl01000003oIVIVofIVIP00000304a<C0030000000c<c<0<c<c00<0<c<c00Co
0000oooooooooooo00006oooool001[ooooo00D00000ooooooooool0<c<c0000000404a<C0050000
001VIVH0IVIV06IVIP0000000P1oOgl01@000000VIVI09VIV@2IVIT0000000<0/k>c00D000000<c<
c03<c<`0c<c<o`0000070>KViPCo0000203Vi^H01Ol00000c<c<0<c<c03<c<`0000000<0/k>c00D0
000009VIV@2IVIT0VIVI0000000207moO`050000001VIVH0IVIV06IVIP000000101<C4`00`000000
<c<c03<c<`0203<c<`030000000I6AT06ATI00H06ATI>P000003ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool0>Ol0000701TI6@030000000c<c<0<c<c00<0<c<c00D0000004a<C01<
C4`0C4a<00000002ofIVIP050000001oOgl0Ogmo07moO`0000000P2IVIT010000000/k>c0;>c/`00
00030<c<c005o`00003Vi^H0i^KV0>KVi_l000003@3oool00ol00000i^KV0>KViP020>KViP04o`00
003<c<`0c<c<000000<0/k>c00@0000009VIV@2IVIT000000P1oOgl01@00003oIVIVofIVI_mVIVH0
000000<0C4a<00<0000003<c<`0c<c<00P0c<c<01Ol0003ooooooooooooooooo000001_ooooo000J
ooooo`0500000?oooooooooo03<c<`000000101<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo
00D0000009VIV@2IVIT0VIVI000000030;>c/`040000003<c<`0c<c<0<c<c0;o00004@3Vi^H00ol0
0000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT010000000Ogmo07moO`00
000306IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI
6@0601TI6@03o`0000000000000003L000000oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo03Wo00001`0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C0000000
0_mVIVH01@000000Ogmo07moO`1oOgl000000080VIVI00@000000;>c/`2c/k<000000`3<c<`01Ol0
0000i^KV0>KViP3Vi^Ko000000d0oooo00?o00000>KViP3Vi^H00P3Vi^H01?l00000c<c<0<c<c000
00030;>c/`040000002IVIT0VIVI00000080Ogmo00D00000ofIVI_mVIVKoIVIV0000000304a<C003
0000000c<c<0<c<c0080<c<c00Go0000ooooooooooooooooo`00000Kooooo`006_ooool01@00003o
ooooooooo`0c<c<0000000@0C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`050000002IVIT0
VIVI09VIV@0000000`2c/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00l0i^KV00?o
00000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00@0000007moO`1oOgl0
00000`1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I
6AT01P0I6ATj000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0io`0000L0
6ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000;oIVIV00D0000007mo
O`1oOgl0Ogmo0000000209VIV@040000002c/k<0/k>c000000<0c<c<00Go00000>KViP3Vi^H0i^KV
o`00000<0?ooo`03o`00003Vi^H0i^KV00<0i^KV00Co00000<c<c03<c<`000000`2c/k<010000000
VIVI09VIV@00000207moO`0500000?mVIVKoIVIVofIVIP0000000`1<C4`00`000000<c<c03<c<`02
03<c<`05o`000?ooooooooooooooool000006oooool001[ooooo00D00000ooooooooool0<c<c0000
000404a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl01@000000VIVI09VIV@2IVIT0000000@0
/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP0=0>KViP03o`00003<c<`0c<c<00<0
c<c<00D000000;>c/`2c/k<0/k>c0000000309VIV@040000001oOgl0Ogmo000000<0IVIV00<00000
04a<C01<C4`00P1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00H06ATI>P000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0>Ol0000701TI6@030000000c<c<0
<c<c00<0<c<c00D0000004a<C01<C4`0C4a<00000002ofIVIP050000001oOgl0Ogmo07moO`000000
0P2IVIT010000000/k>c0;>c/`0000030<c<c003o`00003Vi^H0i^KV0080i^KV00?o00000?ooo`3o
ool02@3oool00ol00000i^KV0>KViP030>KViP04o`00003<c<`0c<c<000000<0/k>c00@0000009VI
V@2IVIT000000P1oOgl01@00003oIVIVofIVI_mVIVH0000000<0C4a<00<0000003<c<`0c<c<00P0c
<c<01Ol0003ooooooooooooooooo000001_ooooo000Jooooo`0300000?oooooooooo0080<c<c00D0
000004a<C01<C4`0C4a<0000000306IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT01@000000
/k>c0;>c/`2c/k<0000000@0c<c<00?o00000>KViP3Vi^H03@3Vi^H00ol00000c<c<0<c<c0020<c<
c0050000002c/k<0/k>c0;>c/`0000000`2IVIT010000000Ogmo07moO`00000406IVIP050000001<
C4`0C4a<04a<C00000001@0c<c<00`0000006ATI01TI6@0601TI6CX000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo03Wo00001`0I6AT00`000000<c<c03<c<`0303<c<`050000
001<C4`0C4a<04a<C00000000_mVIVH01@000000Ogmo07moO`1oOgl000000080VIVI00D000000;>c
/`2c/k<0/k>c000000020<c<c003o`00003Vi^H0i^KV0080i^KV00?o00000?ooo`3oool0203oool0
0ol00000i^KV0>KViP030>KViP05o`00003<c<`0c<c<0<c<c00000000P2c/k<010000000VIVI09VI
V@00000307moO`0400000?mVIVKoIVIV000000<0C4a<00<0000003<c<`0c<c<00`0c<c<01Ol0003o
oooooooooooooooo000001_ooooo000Jooooo`0300000?oooooooooo0080<c<c00D0000004a<C01<
C4`0C4a<0000000306IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT01@000000/k>c0;>c/`2c
/k?o000000D0c<c<00?o00000>KViP3Vi^H02`3Vi^H00ol00000c<c<0<c<c0030<c<c005o`00002c
/k<0/k>c0;>c/`0000000`2IVIT010000000Ogmo07moO`00000406IVIP050000001<C4`0C4a<04a<
C00000001@0c<c<00`0000006ATI01TI6@0601TI6CX000000oooool00`00003oooooooooo`0aoooo
o`03o`000?oooooooooo03Wo00001`0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<
04a<C00000000_mVIVH01@000000Ogmo07moO`1oOgl000000080VIVI00D000000;>c/`2c/k<0/k>c
000000020<c<c003o`00003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool01`3oool00ol00000i^KV
0>KViP030>KViP05o`00003<c<`0c<c<0<c<c00000000P2c/k<010000000VIVI09VIV@00000307mo
O`04o`000?mVIVKoIVIVo`0000<0C4a<00<0000003<c<`0c<c<00`0c<c<01Ol0003ooooooooooooo
oooo000001_ooooo000Jooooo`0300000?oooooooooo0080<c<c00D0000004a<C01<C4`0C4a<0000
000306IVIP050000001oOgl0Ogmo07moOol000000`2IVIT01@000000/k>c0;>c/`2c/k<0000000H0
c<c<0_l0000:0>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000
VIVI09VIV@2IVIT000000080Ogmo00<0000006IVIP1VIVH00P1VIVH01@000000C4a<04a<C01<C4`0
000000D0<c<c00<0000001TI6@0I6AT01P0I6ATj000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`0io`0000L06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<
C4`0000000;oIVIV00D0000007moO`1oOgl0Ogmo0000000209VIV@050000002c/k<0/k>c0;>c/`00
00000P3<c<`00ol00000i^KV0>KViP040>KViP;o00001P3oool00ol00000i^KV0>KViP040>KViP05
o`00003<c<`0c<c<0<c<c00000000P2c/k<010000000VIVI09VIV@00000207moO`0500000?mVIVKo
IVIVofIVIP0000000`1<C4`00`000000<c<c03<c<`0303<c<`05o`000?ooooooooooooooool00000
6oooool001[ooooo00<00000ooooooooool00P0c<c<01@000000C4a<04a<C01<C4`0000000@0IVIV
00@0000007moO`1oOgl000000`2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00D0
c<c<00?o00000>KViP3Vi^H01@3Vi^H2o`0000H0c<c<00D000000;>c/`2c/k<0/k>c0000000409VI
V@040000001oOgl0Ogmo000000@0IVIV00D0000004a<C01<C4`0C4a<0000000503<c<`030000000I
6AT06ATI00H06ATI>P000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0>Ol0
000701TI6@030000000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<00000002ofIVIP050000
001oOgl0Ogmo07moO`0000000P2IVIT01@000000/k>c0;>c/`2c/k<0000000<0c<c<00?o00000>KV
iP3Vi^H01@3Vi^H00ol00000oooo0?ooo`03o`0000H0i^KV00Go00000<c<c03<c<`0c<c<00000002
0;>c/`050000002IVIT0VIVI09VIV@0000000P1oOgl01@00003oIVIVofIVI_mVIVH0000000<0C4a<
00<0000003<c<`0c<c<00`0c<c<01Ol0003ooooooooooooooooo000001_ooooo000Jooooo`030000
0?oooooooooo00<0<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP050000001oOgl0Ogmo07mo
O`0000000`2IVIT01@000000/k>c0;>c/`2c/k<0000000P0c<c<00?o00000>KViP3Vi^H00`3Vi^H0
0ol00000c<c<0<c<c0050<c<c0030000002c/k<0/k>c0080/k>c00Go000009VIV@2IVIT0VIVI0000
000307moO`050000001VIVH0IVIV06IVIP0000000`1<C4`00`000000<c<c03<c<`0303<c<`030000
000I6AT06ATI00H06ATI>`000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
>Ol0000801TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<00000003ofIVIP04
0000001oOgl0Ogmo000000<0VIVI00@000000;>c/`2c/k<000000`3<c<`00ol00000i^KV0>KViP06
0>KViP;o00002@3Vi^H01Ol00000c<c<0<c<c03<c<co00000080/k>c00Go000009VIV@2IVIT0VIVI
0000000207moO`0500000?mVIVKoIVIVofIVIP0000000`1<C4`00`000000<c<c03<c<`0203<c<`03
o`00000I6AWooooo00;ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0
0`0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00D0000007moO`1oOgl0Ogmo0000000309VI
V@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`01P3<c<`5o`0000P0c<c<00D000000;>c
/`2c/k<0/k>c0000000309VIV@0300000?l00000Ogmo0080Ogmo00D0000006IVIP1VIVH0IVIV0000
000304a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6ATk000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`0io`0000P06ATI00<0000003<c<`0c<c<00P0c
<c<01@000000C4a<04a<C01<C4`0000000?oIVIV00@0000007moO`1oOgl000000`2IVIT010000000
/k>c0;>c/`0000040<c<c003o`00003Vi^H0i^KV00l0i^KV00Go00000<c<c03<c<`0c<c<00000003
0;>c/`040000002IVIT0VIVI000000<0Ogmo00D00000ofIVI_mVIVKoIVIV0000000304a<C0030000
000c<c<0<c<c0080<c<c00?o000001TI6Oooool00_ooool00ol0003oooooooooo`0Iooooo`006_oo
ool00`00003oooooooooo`0303<c<`050000001<C4`0C4a<04a<C00000000`1VIVH01@000000Ogmo
07moO`1oOgl0000000<0VIVI00<000000;>c/`2c/k<00`2c/k<00ol00000c<c<0<c<c00A0<c<c003
0000002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0VIVI0000000407moO`050000001VIVH0IVIV
06IVIP0000000`1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00H06ATI>`000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0>Ol0000801TI6@030000000c<c<0
<c<c0080<c<c00D0000004a<C01<C4`0C4a<00000003ofIVIP040000001oOgl0Ogmo000000<0VIVI
00@000000;>c/`2c/k<00000103<c<`00ol00000i^KV0>KViP0?0>KViP05o`00003<c<`0c<c<0<c<
c00000000`2c/k<010000000VIVI09VIV@00000307moO`0500000?mVIVKoIVIVofIVIP0000000`1<
C4`00`000000<c<c03<c<`0203<c<`03o`00000I6AWooooo00;ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00<00000ooooooooool00`0c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0
IVIV06IVIP0000000`1oOgl01@000000VIVI09VIV@2IVIT0000000D0/k>c00<000000<c<c03<c<`0
3`3<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@000000101oOgl01Ol00000
IVIV06IVIP1VIVH0000000@0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0701TI
6C/000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03Wo0000200I6AT00`00
0000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000omVIVH01@000000Ogmo07moO`1o
Ogl000000080VIVI00D000000;>c/`2c/k<0/k>c000000040<c<c003o`00003Vi^H0i^KV00d0i^KV
00Go00000<c<c03<c<`0c<c<000000030;>c/`040000002IVIT0VIVI000000<0Ogmo00D00000ofIV
I_mVIVKoIVIV0000000304a<C0030000000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT00oooool0
0ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0303<c<`030000001<C4`0C4a<
0080C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`050000002IVIT0VIVI09VIV@0000001@2c
/k<00`000000c<c<0<c<c00=0<c<c0030000002c/k<0/k>c00<0/k>c00D0000009VIV@2IVIT0VIVI
0000000307moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00P1<C4`00`000000<c<c
03<c<`0203<c<`030000000I6AT06ATI00L06ATI>`000003ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool0>Ol0000801TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0
C4a<00000003ofIVIP050000001oOgl0Ogmo07moO`0000000P2IVIT01@000000/k>c0;>c/`2c/k<0
000000@0c<c<00?o00000>KViP3Vi^H0303Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0
/k>c0;>c/`0000000P2IVIT01@000000Ogmo07moO`1oOgl0000000?oIVIV00D0000004a<C01<C4`0
C4a<0000000403<c<`03o`00000I6AT06ATI00?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0100c<c<01Ol00000C4a<04a<C01<C4`0000000<0IVIV00<0000007moO`1o
Ogl00P1oOgl00`000000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c00<0/k>c00<000000<c<c03<
c<`02`3<c<`00`000000/k>c0;>c/`040;>c/`050000002IVIT0VIVI09VIV@0000000`1oOgl01@00
0000IVIV06IVIP1VIVH0000000D0C4a<00<0000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@07
01TI6C/000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03Wo0000200I6AT0
0`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000omVIVH01@000000Ogmo07mo
O`1oOgl000000080VIVI00D000000;>c/`2c/k<0/k>c000000040<c<c003o`00003Vi^H0i^KV00/0
i^KV00?o00000<c<c03<c<`00`3<c<`01@000000/k>c0;>c/`2c/k<000000080VIVI00D0000007mo
O`1oOgl0Ogmo00000003ofIVIP050000001<C4`0C4a<04a<C0000000100c<c<00ol000006ATI01TI
6@03ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00@0<c<c00D00000
04a<C01<C4`0C4a<0000000406IVIP030000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVI
000000060;>c/`8000002P3<c<`00`000000/k>c0;>c/`040;>c/`050000002IVIT0VIVI09VIV@00
0000101oOgl01@000000IVIV06IVIP1VIVH0000000D0C4a<00<0000003<c<`0c<c<00P0c<c<00`00
00006ATI01TI6@0701TI6C/000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo
03Wo0000200I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000omVIVH0
1@000000Ogmo07moO`1oOgl000000080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<
c0020<c<c003o`00003Vi^H0i^KV00T0i^KV00?o00000<c<c03<c<`00`3<c<`01@000000/k>c0;>c
/`2c/k<0000000<0VIVI00D0000007moO`1oOgl0Ogmo00000003ofIVIP050000001<C4`0C4a<04a<
C0000000100c<c<00ol000006ATI01TI6@03ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
00000?oooooooooo00@0<c<c00<0000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVH00000
00@0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`050;>c/`8000001@3<c<`30000
00H0/k>c00?o000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00<00000
04a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00H06ATI?0000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0>_l0000701TI6@03o`00000c<c<0
<c<c00<0<c<c00D0000004a<C01<C4`0C4a<00000003ofIVIP050000001oOgl0Ogmo07moO`000000
0P2IVIT01@000000/k>c0;>c/`2c/k<0000000D0c<c<00?o00000>KViP3Vi^H01`3Vi^H00ol00000
c<c<0<c<c0040<c<c0050000002c/k<0/k>c0;>c/`0000000P2IVIT01@000000Ogmo07moO`1oOgl0
000000?oIVIV00D0000004a<C01<C4`0C4a<0000000503<c<`03o`00000I6AT06ATI00?ooooo00?o
0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0100c<c<00`000000C4a<04a<C002
04a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmoo`00000509VIV@030000002c
/k<0/k>c00H0/k>c1@0000080;>c/`030000002IVIT0VIVI0080VIVI00?o000007moO`1oOgl00P1o
Ogl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<00`0c
<c<00`0000006ATI01TI6@0601TI6C`000000oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo03[o00001`0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C0000000
0omVIVH01@000000Ogmo07moO`1oOgl000000080VIVI00<000000;>c/`2c/k<00P2c/k<00ol00000
c<c<0<c<c0030<c<c0Co00000P3Vi^H3o`0000H0c<c<00D000000;>c/`2c/k<0/k>co`00000309VI
V@050000001oOgl0Ogmo07moO`0000000omVIVH01@000000C4a<04a<C01<C4`0000000D0<c<c00?o
000001TI6@0I6AT00oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`04
03<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01Ol00000Ogmo07moO`1o
Ogl0000000D0VIVI00<000000;>c/`2c/k<04P2c/k<00`000000VIVI09VIV@0309VIV@030000001o
Ogl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH01@000000C4a<04a<C01<C4`0000000H0<c<c
00<0000001TI6@0I6AT01P0I6ATl000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`0jo`0000L06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000?o
IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@05o`00002c/k<0/k>c0;>c/`0000002@3<c<`2
o`0000T0c<c<00D000000;>c/`2c/k<0/k>c0000000309VIV@050000001oOgl0Ogmo07moO`000000
0omVIVH01@000000C4a<04a<C01<C4`0000000@0<c<c00Co000001TI6@0I6AT06ATI0oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0403<c<`030000001<C4`0C4a<00<0
C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`030000002IVIT0VIVI00<0VIVI00<000000;>c
/`2c/k<0402c/k<00`000000VIVI09VIV@0409VIV@050000001oOgl0Ogmo07moO`000000101VIVH0
0`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01P0I6ATl
000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0jo`0000L06ATI00<00000
03<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000?oIVIV00D0000007moO`1oOgl0Ogmo
0000000309VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`0403<c<`00`000000/k>c
0;>c/`020;>c/`040000002IVIT0VIVI000000<0Ogmo00<00000ofIVI_mVIVH00_mVIVH01@000000
C4a<04a<C01<C4`0000000@0<c<c00Co000001TI6@0I6AT06ATI0oooool00ol0003oooooooooo`0I
ooooo`006_ooool00`00003oooooooooo`0503<c<`030000001<C4`0C4a<0080C4a<00<0000006IV
IP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c
/`2c/k<03P2c/k<00ol00000VIVI09VIV@0409VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IV
IP1VIVH00P1VIVH01@000000C4a<04a<C01<C4`0000000H0<c<c00<0000001TI6@0I6AT01P0I6ATm
000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0jo`0000L06ATI00<00000
03<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C00400000?mVIVKoIVIV000000<0Ogmo00<0
000009VIV@2IVIT00P2IVIT01@000000/k>c0;>c/`2c/k<000000140c<c<00<000000;>c/`2c/k<0
0P2c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00Go0000ofIVI_mVIVKoIVIV0000000304a<
C0030000000c<c<0<c<c00<0<c<c00Co000001TI6@0I6AT06ATI0oooool00ol0003oooooooooo`0I
ooooo`006_ooool00`00003oooooooooo`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IV
IP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI0P00000=0;>c
/`8000001@2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<
C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00H06ATI?@000003oooo
o`0300000?oooooooooo037ooooo00?o0000ooooooooool0>_l0000701TI6@030000000c<c<0<c<c
00<0<c<c00<0000004a<C01<C4`00P1<C4`01@00003oIVIVofIVI_mVIVKo000000<0Ogmo00D00000
09VIV@2IVIT0VIVI000000040;>c/`030000003<c<`0c<c<00d0c<c<00?o00000;>c/`2c/k<00`2c
/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00D00000ofIVI_mVIVH00000o`00000304a<C003
0000000c<c<0<c<c00<0<c<c00Co000001TI6@0I6AT06ATI0oooool00ol0003oooooooooo`0Ioooo
o`006_ooool00`00003oooooooooo`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1V
IVH00P1VIVH00`000000Ogmo07moO`0307moO`03o`00002IVIT0VIVI00@0VIVI0`0000060;>c/`@0
00001P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<
C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00H06ATI?@000003ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool0>_l0000701TI6@030000000c<c<0<c<c00<0
<c<c00<0000004a<C01<C4`00P1<C4`01Ol0003oIVIVofIVI_mVIVH0000000<0Ogmo00D0000009VI
V@2IVIT0VIVI000000050;>c/`03o`0000000000c<c<00X0c<c<0P0000050;>c/`030000002IVIT0
VIVI0080VIVI00D0000007moO`1oOgl0Ogmo00000002ofIVIP030000001<C4`0C4a<0080C4a<00<0
000003<c<`0c<c<00`0c<c<01?l000006ATI01TI6@0I6AT3ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0400000?ooooooooooo`0000D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV
06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT01P2IVIT6000000T0VIVI
00?o000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<0080C4a<
00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6Cd000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo03[o0000200I6AT00`000000<c<c03<c<`0303<c<`050000
001<C4`0C4a<04a<C00000001?mVIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00<000000;>c
/`2c/k<0102c/k<00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VI
V@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000;oIVIV00<0000004a<C01<C4`00P1<C4`0
0`000000<c<c03<c<`0303<c<`03o`00000I6AT06ATI00806ATI0oooool00ol0003oooooooooo`0I
ooooo`006_ooool01000003oooooooooool0000603<c<`030000001<C4`0C4a<0080C4a<00<00000
06IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI01<0VIVI00<00000
07moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<0080C4a<00<00000
03<c<`0c<c<0100c<c<00`0000006ATI01TI6@0601TI6@03o`0000000000000003/000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo03[o0000200I6AT00`000000<c<c03<c<`03
03<c<`050000001<C4`0C4a<04a<C00000001?mVIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI
00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0030<c<c0<000001P2c/k<00`000000VIVI
09VIV@0209VIV@050000001oOgl0Ogmo07moO`0000000omVIVH00`000000C4a<04a<C00204a<C003
0000000c<c<0<c<c00<0<c<c00?o000001TI6@0I6AT00P0I6AT3ooooo`03o`000?oooooooooo01Wo
oooo000Jooooo`0400000?ooooooooooo`0000H0<c<c00?o000004a<C01<C4`00P1<C4`00`000000
IVIV06IVIP0306IVIP03o`00001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT04P2IVIT00`000000
Ogmo07moO`0407moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000
<c<c03<c<`0403<c<`030000000I6AT06ATI00H06ATI?P000003ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool0>_l0000801TI6@030000000c<c<0<c<c00<0<c<c00D0000004a<C01<
C4`0C4a<00000004ofIVIP050000001oOgl0Ogmo07moO`000000102IVIT00ol00000/k>c0;>c/`05
0;>c/`03o`00000000000000008000002@2c/k<00`000000VIVI09VIV@0209VIV@050000001oOgl0
Ogmo07moO`0000000omVIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00<0<c<c00?o
000001TI6@0I6AT00P0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0400000?oooooo
ooooo`0000H0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001o
Ogl0Ogmo00@0Ogmo0P00000A09VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH00`1V
IVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01`0I
6ATn000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0jo`0000P06ATI00<0
000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000CoIVIV00D0000007moO`1oOgl0
Ogmo0000000409VIV@030000002c/k<0/k>c0180/k>c00<0000009VIV@2IVIT00P2IVIT01@000000
Ogmo07moO`1oOgl0000000CoIVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c
<`03o`00000I6AT06ATI00806ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool01@00003o
ooooooooo`0I6AWo000000H0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0306IV
IP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT03@2IVIT00ol00000Ogmo07moO`0507mo
O`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c
<`030000000I6AT06ATI00H06ATI?`000003ooooo`0300000?oooooooooo037ooooo00?o0000oooo
ooooool0>ol0000801TI6@030000000c<c<0<c<c0080<c<c00?o000004a<C01<C4`00P1<C4`00`00
003oIVIVofIVIP02ofIVIP050000001oOgl0Ogmo07moO`000000102IVIT00`000000/k>c0;>c/`0@
0;>c/`030000002IVIT0VIVI00<0VIVI00D0000007moO`1oOgl0Ogmo00000003ofIVIP030000001<
C4`0C4a<0080C4a<00<0000003<c<`0c<c<00`0c<c<00ol000006ATI01TI6@0301TI6@?ooooo00?o
0000ooooooooool06Oooool001[ooooo00D00000ooooooooool06ATIo`00000603<c<`030000001<
C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH2000000H0Ogmo00@00000o`00000000000000
2@2IVIT2000000L0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00204a<C0030000
0?l00000<c<c00@0<c<c00?o000001TI6@0I6AT01`0I6ATo000000?ooooo00<00000ooooooooool0
<Oooool00ol0003oooooooooo`0ko`0000P06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<
04a<C00204a<C00300000?mVIVKoIVIV00;oIVIV00H0000007moO`1oOgl0Ogmo00000?l0000409VI
V@8000003P2c/k<00`00003o000009VIV@0409VIV@050000001oOgl0Ogmo07moO`0000001?mVIVH0
0`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00<0<c<c00?o000001TI6@0I6AT00`0I6AT3
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0500000?oooooooooo01TI6Ol000001P0c<c<0
0`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl01`1oOgl9
000000P0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0
<c<c00@0<c<c00<0000001TI6@0I6AT01`0I6ATo000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`0ko`0000P06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C002
04a<C00300000?mVIVKoIVIV00;oIVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@04
09VIV@8000002`2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo0080Ogmo00<00000
ofIVI_mVIVH00_mVIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00<0<c<c00?o0000
01TI6@0I6AT00`0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo
00806ATI00?o000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV
00D0IVIV00<0000007moO`1oOgl05P1oOgl00`000000IVIV06IVIP0306IVIP03o`00001<C4`0C4a<
00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6D0000000oooool00`00
003oooooooooo`0aooooo`03o`000?oooooooooo03_o0000200I6AT00`000000<c<c03<c<`0303<c
<`030000001<C4`0C4a<0080C4a<00<00000ofIVI_mVIVH00_mVIVH00`000000Ogmo07moO`0207mo
O`030000002IVIT0VIVI00D0VIVI0P0000080;>c/`030000002IVIT0VIVI00@0VIVI00<0000007mo
O`1oOgl00P1oOgl00`00003oIVIVofIVIP02ofIVIP03o`00001<C4`0C4a<0080C4a<00<0000003<c
<`0c<c<00`0c<c<00ol000006ATI01TI6@0401TI6@?ooooo00?o0000ooooooooool06Oooool001[o
oooo00<00000ooooooooool00`0I6AT00ol00000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0
C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0B07moO`80000000?o000006IVIP1V
IVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I
6AT01`0I6AU0000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0ko`0000P0
6ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C00300000?mVIVKoIVIV00;o
IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0609VIV@<0000000<0/k>c00000000
00000P00000609VIV@030000001oOgl0Ogmo0080Ogmo00<00000ofIVI_mVIVH00_mVIVH00`000000
C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0100I6AT3ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00<06ATI00?o000003<c<`0c<c<0
100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl0
4@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0
100c<c<00`0000006ATI01TI6@0701TI6D0000000oooool00`00003oooooooooo`0aooooo`03o`00
0?oooooooooo03_o0000200I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<
00<00000ofIVI_mVIVH00_mVIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00T0VIVI
00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0307moO`0300000?mVIVKoIVIV00;oIVIV
00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00@06ATI
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0401TI6@03o`00000c
<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0506IVIP8000003`1o
Ogl2000000P0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0403<c<`030000000I
6AT06ATI00P06ATI@0000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0>ol0
000801TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<C4`00`00003oIVIVofIV
IP02ofIVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT04@2IVIT00`000000Ogmo07mo
O`0307moO`0300000?mVIVKoIVIV00;oIVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c
<`0403<c<`03o`00000I6AT06ATI00D06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0`00003oooooooooo`0401TI6@03o`00000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0101<C4`0
0`000000IVIV06IVIP0606IVIP800000301oOgl00`000000IVIV06IVIP0806IVIP030000001<C4`0
C4a<00@0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6D4000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo03co0000200I6AT00`000000<c<c03<c<`03
03<c<`030000001<C4`0C4a<0080C4a<00<00000ofIVI_mVIVH00_mVIVH00`000000Ogmo07moO`04
07moO`030000002IVIT0VIVI00l0VIVI00<0000007moO`1oOgl0101oOgl00ol0003oIVIVofIVIP02
ofIVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@05
01TI6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0100I6AT00ol0
0000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00?o00000000001VIVH01`1VIVH01000
003o000000000000000507moO`<000002@1VIVH00`00003o000004a<C00504a<C0030000000c<c<0
<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AU1000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`0lo`0000P06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C003
04a<C003o`000?mVIVKoIVIV00;oIVIV00<0000007moO`1oOgl0101oOgl2000000d0VIVI0P000006
07moO`0300000?mVIVKoIVIV00;oIVIV00<0000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`03
03<c<`03o`00000I6AT06ATI00H06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00
003oooooooooo`0401TI6@03o`00000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`01P1<C4`00`00
0000IVIV06IVIP0906IVIPD000002`1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c
00@0<c<c00?o000001TI6@0I6AT0200I6AT00ol0000000000000000n000000?ooooo00<00000oooo
ooooool0<Oooool00ol0003oooooooooo`0lo`0000P06ATI00<0000003<c<`0c<c<00`0c<c<00`00
0000C4a<04a<C00304a<C00300000?mVIVKoIVIV00?oIVIV00<0000007moO`1oOgl01@1oOgl20000
00X0VIVI00<0000007moO`1oOgl01@1oOgl00`00003oIVIVofIVIP03ofIVIP030000001<C4`0C4a<
00<0C4a<00<0000003<c<`0c<c<00`0c<c<00ol000006ATI01TI6@0601TI6@?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool01@0I6AT00ol00000<c<c03<c<`0503<c<`03
0000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH05`1VIVH00`000000C4a<04a<C00604a<C003
0000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0200I6AU1000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`0lo`0000T06ATI00<0000003<c<`0c<c<00`0c<c<00`000000
C4a<04a<C00304a<C00300000?mVIVKoIVIV00?oIVIV00<0000007moO`1oOgl01P1oOgl2000000D0
VIVI0`00000707moO`0300000?mVIVKoIVIV00?oIVIV00<0000004a<C01<C4`00`1<C4`00`000000
<c<c03<c<`0403<c<`03o`00000I6AT06ATI00H06ATI00Co0000oooooooooooo00006oooool001[o
oooo00<00000ooooooooool01@0I6AT00ol00000<c<c03<c<`0503<c<`030000001<C4`0C4a<00H0
C4a<00<0000006IVIP1VIVH05P1VIVH00ol00000C4a<04a<C00604a<C0030000000c<c<0<c<c00D0
<c<c00<0000001TI6@0I6AT0200I6AU2000000?ooooo00<00000ooooooooool0<Oooool00ol0003o
ooooooooo`0lo`0000T06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00304a<C003
00000?mVIVKoIVIV00?oIVIV00<0000007moO`1oOgl0201oOgl5000000T0Ogmo00?o0000ofIVI_mV
IVH01?mVIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00<0<c<c00?o000001TI6@0I
6AT01`0I6AT01?l0003oooooooooool0000Kooooo`006_ooool00`00003oooooooooo`0601TI6@03
o`00000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`01P1<C4`2000001D0IVIV0P00000704a<C003
o`00000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT0200I6AU2000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`0lo`0000T06ATI00<0000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00304a<C00300000?mVIVKoIVIV00?oIVIV00<0000007moO`1oOgl0501oOgl2000000Go
IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00H0
6ATI00Go0000ooooooooooooooooo`00000Kooooo`006_ooool00`00003oooooooooo`0601TI6@03
o`00000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01`1<C4`200000140IVIV0P00000804a<C003
0000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT0200I6AU2000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`0lo`0000T06ATI00<0000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00304a<C00300000?mVIVKoIVIV00CoIVIV00<0000007moO`1oOgl04P1oOgl00`00003o
IVIVofIVIP05ofIVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<00`0c<c<00ol00000
6ATI01TI6@0701TI6@05o`000?ooooooooooooooool000006oooool001[ooooo00<00000oooooooo
ool01`0I6AT00ol00000<c<c03<c<`0603<c<`030000001<C4`0C4a<00P0C4a<0P00000=06IVIP80
00002@1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00P06ATI@`000003ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool0?Ol0000901TI6@030000000c<c<0<c<c00@0
<c<c00<0000004a<C01<C4`00`1<C4`00`00003oIVIVofIVIP04ofIVIP8000004@1oOgl00`00003o
IVIVofIVIP05ofIVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00ol00000
6ATI01TI6@0601TI6@03o`000000003ooooo00;ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0200I6AT00ol00000<c<c03<c<`0603<c<`030000001<C4`0C4a<00T0C4a<
00@00000o`000000000000001@1VIVH4000000X0C4a<00<0000003<c<`0c<c<01P0c<c<00ol00000
000001TI6@0901TI6D@000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03go
00002@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00@0C4a<00?o0000ofIVI_mV
IVH01OmVIVH2000000d0Ogmo0P000007ofIVIP030000001<C4`0C4a<00<0C4a<00?o000003<c<`0c
<c<0100c<c<00ol000006ATI01TI6@0701TI6@03o`000000003ooooo00;ooooo00?o0000oooooooo
ool06Oooool001[ooooo00<00000ooooooooool0200I6AT00ol00000<c<c03<c<`0703<c<`03o`00
001<C4`0C4a<00`0C4a<1@00000>04a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT0
2@0I6AU4000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0mo`0000T06ATI
00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00404a<C00300000?mVIVKoIVIV00OoIVIV
0P00000:07moO`0300000?mVIVKoIVIV00KoIVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c
03<c<`0403<c<`03o`00000I6AT06ATI00L06ATI00?o000000000?ooool00_ooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00`00003oooooooooo`0901TI6@03o`00000c<c<0<c<c00L0<c<c00<0
000004a<C01<C4`0701<C4`2000000P0<c<c00<0000001TI6@0I6AT02@0I6AU5000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`0mo`0000X06ATI00<0000003<c<`0c<c<0100c
<c<00`000000C4a<04a<C00404a<C00300000?mVIVKoIVIV00SoIVIV0P00000507moO`<000002?mV
IVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0200I
6AT00ol000000000ooooo`02ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooo
oooo00T06ATI00?o000003<c<`0c<c<0200c<c<00`000000C4a<04a<C00J04a<C0030000000c<c<0
<c<c00P0<c<c00<0000001TI6@0I6AT02@0I6AU5000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`0no`0000T06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C005
04a<C00300000?mVIVKoIVIV00WoIVIV1@00000:ofIVIP030000001<C4`0C4a<00D0C4a<00<00000
03<c<`0c<c<0100c<c<00ol000006ATI01TI6@0701TI6@03o`0000000000000000?ooooo00?o0000
ooooooooool06Oooool001[ooooo00<00000ooooooooool02P0I6AT2o`0000T0<c<c00<00000o`00
00000000601<C4`00ol00000<c<c03<c<`0803<c<`030000000I6AT06ATI00X06ATI00?o00000000
00000000@P000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0?_l0000:01TI
6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`01@1<C4`00`00003oIVIVofIVIP0EofIV
IP8000001`1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00P06ATI00?o00000000
000000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0;01TI6@03
o`00000c<c<0<c<c00X0<c<c00<0000004a<C01<C4`04`1<C4`2000000/0<c<c00<0000001TI6@0I
6AT02P0I6AU5000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0no`0000X0
6ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00604a<C00300000?mVIVKoIVIV01?o
IVIV00<0000004a<C01<C4`01P1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00P0
6ATI00Co000000000000000000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`0<01TI6@03o`00000c<c<0<c<c00X0<c<c0P00000A04a<C08000002`0c<c<2000000`0
6ATIAP000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0?_l0000:01TI6@03
o`00000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`01P1<C4`00`00003oIVIVofIVIP0AofIVIP03
0000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0801TI6@04
o`00000000000000000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooooooo
ool03@0I6AT00ol00000<c<c03<c<`0;03<c<`8000003@1<C4`2000000`0<c<c00<0000001TI6@0I
6AT02`0I6AU7000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0oo`0000X0
6ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00604a<C00300000?l00000000000ko
IVIV00<00000o`00001<C4`01`1<C4`00`000000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00P0
6ATI00?o00000000000000000P000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`040000
0?ooooooooooo`0000`06ATI00?o000003<c<`0c<c<03@0c<c<3000000H0C4a<1000000>03<c<`03
0000000I6AT06ATI00/06ATIA`000003ooooo`0300000?oooooooooo037ooooo00?o0000oooooooo
ool0?ol0000:01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`02@1<C4`00`00003o
IVIVofIVIP0:ofIVIP030000001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<01@0c<c<00ol00000
6ATI01TI6@0801TI6@03o`00000000000000008000000oooool00ol0003oooooooooo`0Iooooo`00
6_ooool01000003oooooooooool0000=01TI6@;o0000400c<c<600000140<c<c00<0000001TI6@0I
6AT02`0I6AU8000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0oo`0000/0
6ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00904a<C0<000001_mVIVH3000000X0
C4a<00<0000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0901TI6@03o`000000000000000080
00000oooool00ol0003oooooooooo`0Iooooo`006_ooool01@00003oooooooooo`00003o000000h0
6ATI00?o000003<c<`0c<c<08`0c<c<00`0000006ATI01TI6@0<01TI6DP000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo043o00002P0I6AT00`000000<c<c03<c<`0603<c<`03
o`00001<C4`0C4a<00/0C4a<1P00000<04a<C0030000000c<c<0<c<c00H0<c<c00?o000001TI6@0I
6AT0200I6AT00ol00000000000000003000000?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool00P0000000ol000006ATI01TI6@0<01TI6@03o`00000c<c<0<c<c0240<c<c
00?o000001TI6@0I6AT0300I6AT00ol00000000000000016000000?ooooo00<00000ooooooooool0
<Oooool00ol0003oooooooooo`10o`0000/06ATI00<0000003<c<`0c<c<01P0c<c<2000001/0C4a<
0P00000803<c<`03o`00000I6AT06ATI00T06ATI00?o00000000000000000`000003ooooo`03o`00
0?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo0080000000?o000001TI6@0I6AT03@0I
6AT00ol00000<c<c03<c<`0O03<c<`030000000I6AT06ATI00d06ATIB@000003ooooo`0300000?oo
oooooooo037ooooo00?o0000ooooooooool0@?l0000;01TI6@030000000c<c<0<c<c00P0<c<c00<0
000004a<C01<C4`05`1<C4`00`000000<c<c03<c<`0803<c<`03o`00000I6AT06ATI00T06ATI00?o
00000000000000000`000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooo
oooo00<0000000?o000001TI6@0I6AT03@0I6AT00ol00000<c<c03<c<`0M03<c<`030000000I6AT0
6ATI00d06ATIBP000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0@Ol0000;
01TI6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`05@1<C4`00`000000<c<c03<c<`08
03<c<`03o`00000I6AT06ATI00T06ATI00?o000000000000000010000003ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`0300000?oooooooooo00@0000000?o000001TI6@0I6AT03@0I6AT00ol0
0000<c<c03<c<`0K03<c<`030000000I6AT06ATI00h06ATIBP000003ooooo`0300000?oooooooooo
037ooooo00?o0000ooooooooool0@Ol0000;01TI6@030000000c<c<0<c<c00P0<c<c00<0000004a<
C01<C4`0501<C4`00`000000<c<c03<c<`0803<c<`03o`00000I6AT06ATI00X06ATI00?o00000000
0000000010000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00@0
000000?o000001TI6@0I6AT03P0I6AT00ol00000<c<c03<c<`0I03<c<`030000000I6AT06ATI00h0
6ATIB`000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0@_l0000;01TI6@03
0000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`04P1<C4`00`000000<c<c03<c<`0803<c<`03
o`00000I6AT06ATI00X06ATI00?o00000000000000001@000003ooooo`03o`000?oooooooooo01Wo
oooo000Jooooo`0300000?oooooooooo093ooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`2@ooooo`03o`000?oooooooooo01Wooooo000Joooooi@00000<ooooonDo`0001_ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0025ooooo`;o0000aOoo
ool2o`0004;ooooo0022ooooo`?o000000?oooooo`000?ooool0`Oooool3o`000003ooooool0003o
oooo047ooooo0020ooooo`;o00000_ooool2ojVmj0;o0000_oooool2o`0000Cooooo0_l00011oooo
o`00OOooool3o`000003oooooonY_NSoZKgX00?oZKgX00?o0000ooooool00000^oooool3o`0000Ko
oooo00?o0000ooooool00000@?ooool007[ooooo0ol00003ooooo`KoZKgX00?o0000ooooool00000
^?ooool3o`0000Sooooo00Co][[Mo`000?oooooo0000@?ooool007Sooooo0_l00004ooooo`SoZKgX
00Co0000ojVmj?oooooo0000]Oooool2o`0000Wooooo0onf^]d01?l0003oooooooooool0000ooooo
o`00MOooool3o`0000;ooooo3?nY_NP01Ol0003oZKgXojVmj?oooooo00000;7ooooo0ol00009oooo
o`;o]kSJ0onf^]d01Ol0003ooooooooooooooooo000003kooooo001cooooo`;o00000_ooool?ojVm
j005o`000?nY_NSoZKgXooooool00000[oooool2o`0000Wooooo00?o]kKHokNhf_ng^=X00ong^=X0
1?nf^]go^;[Ko`000?nh^]/2ooooo`03o`000?oooooooooo03cooooo001`ooooo`?o00000oooool@
ojVmj006o`000?nY_NSoZKgXojVmj?oooooo0000Zoooool3o`0000[ooooo0ong]]P3okNhfP04okVh
f?nh^]_o^;[Ko`0000;o^;[K0_ooool00ol0003oooooooooo`0kooooo`00K_ooool2o`0000Cooooo
4_nY_NP01_l0003oZKgXojVmj?nY_NSoooooo`000:Wooooo0_l0000;ooooo`03okNce_ng]]So]kKH
00?o]kKH00So]kSJokVhf?ni^=So^KSHokRjfol0003o^;[KokZjfP;ooooo00?o0000ooooooooool0
>oooool006_ooooo0ol00002oooooaKoZKgX00?o0000ojVmj?nY_NP00_nY_NP00ooooooo0000oooo
o`2Tooooo`?o00002oooool4okNceP?o]kKH00?o^KKFokVhf?ni^=P00oni^=P01?l0003o^[[JokZj
f_nj^]X2ooooo`03o`000?oooooooooo03[ooooo001Xooooo`?o00000_oooolIojVmj003o`000?nY
_NSoZKgX00?oZKgX00?oooooo`000?ooool0X?ooool3o`0000cooooo00?o][3DokNce_ng/mH00ong
/mH00ong]]So^KKFokVfeP02okVfeP?o^KSH00?o^kSGo`000?nj^]X00onj^]X2ooooo`03o`000?oo
oooooooo03Wooooo001Vooooo`;o00001?oooolKojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000
ooooooooool0WOooool2o`0000kooooo0onf/=@4okNcePGo^KKF00?o^KSHok^heonk^=L00_nk^=L0
1?l0003o^[[JokZjf_nl^]P2ooooo`03o`000?oooooooooo03Wooooo001Sooooo`?o00001?ooool2
ojZmj1_oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oooooooooo`2Iooooo`?o00003_ooool0
0onc[M;o][3DokJ`e002okJ`e0?o]k?F0_ni/m<3okVfeP03ok^edonk^=Oo^kSG00?o^kSG00?o0000
okbjf?nl^]P00_nl^]P2ooooo`03o`000?oooooooooo03Sooooo001Qooooo`;o00001?ooool6ojZm
j1[oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ooooooo0000ooooo`2Gooooo`;o00004?ooool3ok>]
dPCo][3D00?o]k?FokVcdoni/m<00_ni/m<01?ni]]Ko^kGCok^edonk]M<3ok^he`03okfheOl0003o
_;[H00?o_;[H0oooool00ol0003oooooooooo`0gooooo`00G_ooool3o`0000;ooooo0_nZ_NL8ojZm
j1[oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oooooooooo`2Cooooo`?o00004?ooool00on`
Z];o/jgBok>]dP02ok>]dP?o][3D00?o]joAokVcdoni/m<00oni/m<5ok^ed`04ok^heonm^=Go_KSE
o`0000?o_;[H0_nn^mL2ooooo`03o`000?oooooooooo03Oooooo001Looooo`;o00000_ooool00on[
_NOoZ[gWojZmi`03ojZmi`SoZ[gX6OnY_NP00ol0003oZKgXojVmj005ojVmj003ooooool0003ooooo
097ooooo0_l0000Aooooo`?o/:[B1Onc[M801?nf/=Co]joAokN_dOng[m43okVcd`;o^k;A0onk]M<0
1onn]M7o_KSEokfheOnm^=Go0000okfheOnl^]P01?nn^mL2ooooo`03o`000?oooooooooo03Kooooo
001Iooooo`?o00000oooool3oj^mi`CoZ[gW2OnZ_NPHojVmj003o`000?nY_NSoZKgX00KoZKgX00?o
ooooo`000?ooool0SOooool3o`00017ooooo00?o[:OBok2Zd_n`Z]800on`Z]83ok>]dP03okF/d?ng
[m7o]joA00?o]joA00?o^K?Cok^bdOnk/]400_nk/]401?nk]M?o_[GAokjedOnn]M42okfhe@03o`00
0?no^=?o_[_G00?o_[_G00Go`;_Eooooooooooooooooo`00000gooooo`00Eoooool2o`0000Cooooo
0_n/_NL4oj^mi`CoZ[gW0onZ_NP00onZ_NOoZ[gXojZmj003ojZmj0;oZKgX0_nZ_NPCojVmj003o`00
0?nY_NSoZKgX00OoZKgX00?o0000ooooooooool0R_ooool2o`0001?ooooo0on/Ym84ok2ZdP03ok>]
d_ne[=3o]Jc@00;o]Jc@0ong[m400oni[loo^k;Aok^bd@02ok^bd@03okfbconn]M7o_[GA00?o_[GA
00Go_KSEo`000?no^=?o_kSCokjke`04ol2ke@;ooooo00?o0000ooooooooool0=Oooool005Cooooo
0ol00003ooooo`;o[;gV1?n/_NL4oj^mi`CoZ[gW00CoZ[gXojZmionZ_NOoZ[gW2OnZ_NPBojVmj003
o`000?nY_NSoZKgX00OoZKgX00?oooooo`000?ooool0Qoooool3o`0001?ooooo00?oYjCCojbWd_n/
Ym800on/Ym82ok2ZdP03ok6Yd?ne[=3o]Jc@00?o]Jc@00?o]joAokV_coni[ll00_ni[ll2ok^bd@?o
_K;?0onn]M400oo0]Loo_kSCo`000002oknhd`Go`;_E0oooool00ol0003oooooooooo`0dooooo`00
DOooool3o`0000?ooooo00?o[[gUojbmi_n/_NH00on/_NH2ojbmi`;o[;gV1?n[_NL2ojZmi`;oZkgW
1?nZ_NL8ojZmj1;oZKgX00?o0000ojVmj?nY_NP02?nY_NP00ooooooo0000ooooo`23ooooo`?o0000
4_ooool2oj:Re0CoYjCC0on/Ym800on]YM3o/JW@ok6Yd002ok6Yd0?o]Jc@00?o]j_>okV_coni[ll0
0oni[ll00onk/]7o_K;?okfbc`02okfbc`03okjedOo0]Loo`;G?00;o`;G?00Co0000oknhdoo2^M7o
`[WA0oo0^mD2ol>ld`?ooooo00?o0000ooooooooool0<oooool004oooooo0_l00005ooooo`?o[[gU
0on/_NH2ojfmiPCo[;gV2?n[_NL4ojZmi`SoZ[gX4OnY_NP00ol0003oZKgXojVmj008ojVmj003oooo
ool0003ooooo087ooooo0_l0000Booooo`03oifPe_nRX]CoXZ;D00?oXZ;D1?nWY=<01?n/Ym;o[JG@
ojfUd?n]YM04ok6Yd004okF/d?ngZlko]j_>okN[cP?o^Jo?00?o^jk=okfbconm//l00onm//l5ol2e
c`03o`000?o2^M7o`[WA00;o`[WA00?o`;_Eol>ldoo3_=<00_o3_=<2ooooo`03o`000?oooooooooo
03?ooooo001<ooooo`?o00001Oooool2ojnmh`Co[[gU00?o[;gVojfmi_n]_NH00_n]_NH4ojbmiPOo
ZkgW1OnZ_NL8ojZmj13oZKgX00?o0000ojVmj?nY_NP02OnY_NP00ooooooo0000ooooo`1mooooo`?o
00004Oooool00onIWmSoWJ3FoifPeP02oifPePCoXZ;D0_nWY=<2ojNRd@Co[JG@0onaZM000onbYlgo
]j_>okN[cP03okN[cP04okV_conk[/go^jk=ok^^c@?o_K;?0_no//d4ol2ec`03o`000?o2^M7o`[WA
00;o`[WA1Oo3_=<3ooooo`03o`000?oooooooooo03;ooooo001:ooooo`;o00001Oooool2ok6lhPCo
[kgS0_n^_ND2ojjmi0?o[KgV00?o[[gUojbmi_n/_NH00on/_NH2oj^mi`03ojbmion[_NOoZkgW00;o
ZkgW1?nZ_NL8ojZmj13oZKgX00?o0000ojVmj?nY_NP02_nY_NP00ol0003oooooooooo`1jooooo`;o
00004Oooool00onEWm_oVIoHoiVOf002oiVOf0?oWJ3F0onRX]@00onRWm;oYj;AojNRd@03ojNRd@Co
[JG@00Co/JW@ok:WcOnbYlgo/ZO=0ongZlh00onhZ/_o^jk=ok^^c@03ok^^c@04okfbcono//go_k;=
oknbc@?o`;G?00?o`kK=o`000?o2^M400_o2^M42olBic`?o`kcC0_o5_=82ooooo`03o`000?oooooo
oooo03;ooooo0017ooooo`?o00001?ooool00onc^moo/KcRok6lhP03ok6lhP;o[kgS00?o/;gSojjm
i?n^_N@00on^_N@01?n]_NKo[[gUojjmiOn^_ND3ojbmiP03ojfmi_n/_NOo[;gW00;o[;gW1?n[_NL4
ojZmi`SoZ[gX3onY_NP00ol0003oZKgXojVmj00;ojVmj003o`000?oooooooooo07Kooooo0ol0000=
ooooo`04oi6Rh?nBX=koTZ3Noi:PgPCoUIoK0onIWmP4oifPeP04oj:Re?nRWm;oXYoBoj:OdPCoYj;A
0on]YM000on^Y<go/ZO=ok:Wc@03ok:Wc@04okN[c_nhZ/_o^:[;okRZb`?o^jk=00?o_Jk:oknbcOno
//d00ono//d01_o0]Loo`kK=ol>fcOl0003o`kK=ol:id@Coa;W?00Co`kcColFld_o5_=;oaKcB0ooo
ool00ol0003oooooooooo`0aooooo`00AOooool2o`0000Kooooo0onc^ml3ok6lhP03ok:lhOn`_N?o
/;gS00;o/;gS0_n^_N@2ojnmi0Co[[gU00?o[;gVojfmi_n]_NH00_n]_NH3ojbmi`GoZkgW0_nZ_NL2
oj^mi`SoZ[gX3_nY_NP00ol0003oZKgXojVmj00;ojVmj003ooooool0003ooooo07Cooooo0_l00009
ooooo`;oTjWU0onAYN<4oi6Rh0?oTZ3N1?nEWm/3oiVOf0;oWJ3F00?oW9gDoj:Od_nRWm800_nRWm85
ojNRd@04ojfUd?n^Y<go[ZC=ojjTc@?o/ZO=00?o]:K;okRZbonhZ//00onhZ//01?nk[/go_Jk:okf^
b_nm[/X3oknbc@06ol:bb_o3]/go`kK=ol>fcOl0003o`kK=1?o4^Ll00oo7^/koaKcBolFldP02olFl
dPCooooo00?o0000ooooooooool0<?ooool004;ooooo0ol00006ooooo`03okFjgOnc^moo/k_O00;o
/k_O00?o/KcRok:lhOnb_>400_nb_>42ok2mh`;o/KgR1?n__N@4ojjmi@Co[KgV1?n/_NL9oj^mi`So
Z[gX3OnY_NP00ol0003oZKgXojVmj00<ojVmj003o`000?oooooooooo073ooooo0ol00005ooooo`03
oiV`j?nF[NKoUZgV00;oUZgV1?nCZND3oi6Uh`CoTJ;P0onBX=h2oiFOf`04oi:KfOnGVmKoUi_FoiNK
ePCoW9gD1?nRWm82ojNRd@;oZ:3>1?n^Y<d01?nbYlgo]:K;okBVbondY//4okRZb`03okZZbOnm[/[o
_Jk:00?o_Jk:00Co_k;=ol:bb_o2//[o`[;:0_o3]/d00ol0003oaKK;olFfb`02olBic`?oak[>0_o5
_=82olNmd@?ooooo00?o0000ooooooooool0<?ooool003oooooo0ol00008ooooo`?o]K[M0_nc^ml2
okFkgPCo/[cQ00?o/;gSok6mh_na_N800_na_N82ojnmi0;o/;gS1?n^_ND4ojfmiPCo[;gW2On[_NL7
ojZmj0goZKgX00?o0000ojVmj?nY_NP03?nY_NP00ooooooo0000ooooo`1]ooooo`?o00001Oooool0
0onL/nSoVK3XoiV`j002oiV`j0CoUZgV0onCZND3oi6Uh`;oTJ;P0_n=W]l3ohjLg0CoTY_I0onGVmH4
oibMe0;oXYoB00?oXIg@ojRPc_nXX<h00onXX<h2ojjTc@03ojnRbondY/_o]:K;00?o]:K;0_nhZ//2
okZZb@Co_Jk:00?o`:k8ol:bb_o2//X00oo2//X01Oo3]/go0000olFfboo5]/_oa;W?00Coak[>00?o
aKcBolNmdOo7_M400_o7_M43ooooo`03o`000?oooooooooo02oooooo000mooooo`;o00002?ooool2
okNhfP?o]K[M00?o]k[KokFkg_ne^mh00one^mh2ok:lh@;o];cP0ona_N800onb_N;o/;gSok2mh`03
ok2mh`;o[[gU0_n__ND4ojfmiP;o[;gW0_n/_NH9oj^mi`;oZ[gX00?oZ[gWojZmj?nZ_NP00_nZ_NP2
ojVmj0;oZ[gX2?nY_NP00ol0003oZKgXojVmj00=ojVmj003ooooool0003ooooo06[ooooo0_l00005
ooooo`;oWkKY0onL/nP4oiV`j0;oUZgV00CoTJWVohjUi?n>YNCoSZGT0on=XN85ohfNg`?oSYcL0onB
VmT4oiNKeP;oW9gD00?oVi[Boj6Md?nQWM000_nQWM04ojRPcP04ojjTcOn_X/_o[j;;ojnRb`Co]:K;
00?o^:[;okZZbOnjZ/T00_njZ/T2okf^bP?o`:k80oo2//X00oo4//SoaKK;o`000002olFfb`Goak[>
00GobK_<olNmdOo7_M7oakgAolVnc`04ooooo`03o`000?oooooooooo02kooooo000jooooo`?o0000
1oooool00onh]]Oo]kSJokNhfP03okNhfP04okFjgOng^]_o]k[KokNjf`?o]K_N00?o][_MokBlh?nd
_>000ond_>001?na_N;o/[gRok:mh_nb_N83ok2mh`;o/KgS1?n__ND2ojfmiP;o[[kV1?n/_NH8oj^m
i`CoZ[gW2?nZ_NP7ojVmj003o`000?nY_NSoZKgX00koZKgX00?o0000ooooooooool0I_ooool3o`00
00Cooooo0_nR^>T4oinfj@?oW;?X0_nI/>P00onE[^OoTJWVoi6YiP02oi6YiP?oSZGT0on=XN84ohfN
g`?oSYcL1?nBVmT2oiNKeP03oiBHe?nKV];oVi[B00;oVi[B0onQWM03ojRPcP03ojRNc?n_X/_o[j;;
00;o[j;;0ondY//00onfYLSo^Z[9okZZb@03okZZb@03okf^b_o0[/So`:k800;o`:k800?o`[;:olBb
b?o4//P00_o4//P01?l0003oaKK;olRgbOo8]lT3olNjcP?obK_<00CoakgAolVncoo9_/oobKk?0ooo
ool00ol0003oooooooooo`0^ooooo`00>?ooool2o`0000Wooooo0onh]]L3okNhfP03okVhf?ng^]_o
]k[K00?o]k[K00Co]K_NokJkgOnf^mgo][_M0ond_>02okFlg`Co/[gR00?o/;gSok6mhona_N<00_na
_N<2ojnmi@;o[kkT1?n^_^H2ojbmiP03ojbni_n[_NOoZkgW00OoZkgW0onZ_NL9ojZmj0KoZKgX00?o
0000ojVmj?nY_NP03_nY_NP00ooooooo0000ooooo`1Tooooo`;o00001?ooool2ojBjj@CoX[SY0_nO
]^T00onM]NWoVK;XoiVbj002oiVbj0?oUJkW1?nAZNH3ohjUi0?oSJ7R0_n=W]l01?n8VMkoRYOJohZG
f_n:UmX4ohjGe`CoU9SD0onKV]84oj6Md004ojRPc_nXW/coZ9k<ojRNc0Co[j;;00Co]:K;okJUb?nf
YLSo]ZG80onjZ/T00onlZLOo`:k8ol2^b003ol2^b0Goa;;800?o0000olRgbOo8]lT00_o8]lT00oo7
^/kobK_<olVkc002olVkc0CobKk?1?ooool00ol0003oooooooooo`0]ooooo`00=Oooool3o`0000Wo
oooo00?o^KCDokRfeonh]]L00onh]]L01?ng^=[o^KSHokVhf?ni^=P3okNjf`;o^K[J1?nf^md00ond
_>3o]KcOokFlg`02okFlg`;o/[gR0_nc_N43ok6mh`03ok:mh_n__^Co[kkT00?o[kkT0_n^_^H00on^
_^Go[;kVojbniP02ojbniP;oZkgW0_n/_^L4oj^mi`CoZ[gW2OnZ_NP5ojVmj003o`000?nY_NSoZKgX
00ooZKgX00?oooooo`000?ooool0H?ooool3o`0000Cooooo00?oY[_XojBjjOnT^^T00_nT^^T2oj:h
j@;oX;OY0onM]NT4oiVbj0?oUJkW0_nAZNH01?n=Y^KoRJ7TohVQi?n9XN@3ohNMh@CoR9WN0on:UmX4
ohjGe`?oU9SD1?nKV]82oj6Md003oj6Jc_nXW/coZ9k<00;oZ9k<0on_X//00on`XLWo]ZG8okJUb003
okJUb004okZZbOnlZLOo_:W7okbYa`?o`:k80_o2[/H4olBbb003o`000?o8]lWob;O900;ob;O91?o9
^l`2olblb`;obKk?0_o<_lh4ooooo`03o`000?oooooooooo02cooooo000cooooo`;o00002oooool3
okVde0?o^;KG00?o^[KEokVhf?ni^=P00oni^=P00ong^]_o^K[JokVjfP02okVjfP;o][_M0_nh^m`3
okFlg`;o]kcN1?nc_N401?na_N?o/[gRok:mh_nb_N83ojnni003ok2ni?n^_^Go[[kU00;o[[kU0_n/
_^H2ojfniPCo[;kW1?n[_NL4ojZmi`SoZ[gX1OnY_NP00ol0003oZKgXojVmj00@ojVmj003o`000?oo
oooooooo05gooooo0_l00004ooooo`;oYkcX0onV^nP2ojBjj@;oXkWY1?nP]nT3oifej@;oVK;X00?o
UZoXoi6[ionAZnL00_nAZnL3ohfViP?oRJ7T0on7WN43ohRIgPCoRYOJ0on>UmL4oiBHe0;oVi[B00?o
VIO@oj6Jc_nQV/h00_nQV/h4ojRNc004ojnRbon`XLWo/:79ok2Qb@Co]ZG81OnlZLL01?o0[/So`Zk6
ol:^a_o2[/H3olBbb003olNca_l0003ob;O900;ob;O90_o;]lP2olVkc0?oc;c;00?obKk?olboc_o<
_lh00_o<_lh3ooooo`03o`000?oooooooooo02cooooo000`ooooo`?o00002oooool00oni/M7o^KCD
okVde003okVde004okRfeonj]]Go^[KEokZfe@?o^KSH0_nk^=H3okVjfP03ok^jf?nh^mco^;_L00?o
^;_L00?o]KcOokNlg_ng_=h00_ng_=h2ok>mh@03okFmh?nb_N;o/[gR00;o/[gR00?o[kkTok2ni?n`
_^@00_n`_^@4ojjni@Co[KkV1?n/_^L4oj^mi`?oZ[gW2OnZ_NP4ojVmj003o`000?nY_NSoZKgX017o
ZKgX00?o0000ooooooooool0FOooool3o`0000?ooooo0_nX_>P4ojNlj003ojJkj?nU^nWoYK_Y00Co
XkWY0_nP]nT00onN]^WoVk?Yoi^cj@02oi^cj@?oUZoX1?nAZnL3ohfViP?oRJ7T0on7WN43ohRIgP;o
RYOJ00CoQY?Ioh^Ce_n;TmKoRi?F1?nBU=83oiVGd0GoXI[>0_nXW/`00onYW<[o/:79ok2Qb@02ok2Q
b@?o]ZG80_nhYLH4okbYa`Go`Zk600Koa;;8olNca_o7/lKo0000olNca_o8]lT3ol^gb003olVkc?o<
_<_oc;c;00;oc;c;1Oo<_lh4ooooo`03o`000?oooooooooo02_ooooo000]ooooo`?o00003Oooool3
okVad@?o^KCD00?o^k?BokZfeOnj]]D00onj]]D00oni^=So^kSFok^heP02ok^heP04okVjf_nk^]So
^k[Hok^jf0?o^;_L0_nj^m/3okNlgP03okRlgOne_N3o]KgP00;o]KgP0_nb_N82ok>nhP?o/;kT00?o
/KkTojjniOn^_^D00on^_^D4ojfniPCo[;kW0_n[_NL00on[_^OoZ[gWojZmi`02ojZmi`SoZ[gX1?nY
_NP00ol0003oZKgXojVmj00AojVmj003o`000?oooooooooo05Kooooo0ol00003ooooo`;oZ;gX1?nX
_>P2ojNlj003ojJlj?nU^nWoYK_Y00;oYK_Y0_nS^NT00onR^NWoW[KYoijfj@02oijfj@CoVk?Y0onF
[nP2oi6[i`04ohfXion7X^GoQj;UohNRi@?oQ9cS0on2V=l3oh:Dg0CoQY?I0on;TmH4oi:DdP?oVIO@
0onQV/h00onQV<coZIc:ojVLbP02ojVLbPCo/:7900Co]ZG8okRUa_nhYLKo^:G60onlZLL2oknYa0Co
`Zk60oo7/lH00ol0003oak?6ol^gb003ol^gb004olfha_o<_<_oc;c;olblb`;ockg90oo<_lh2olk1
c@?ooooo00?o0000ooooooooool0:oooool002_ooooo0_l0000>ooooo`03okR^coni/M7o^K7A00?o
^K7A00Co^KCDok^cd_nk/m;o^k?B0onj]]D2okbed`?o^kSF00?o_KSDok^jf?nk^]P00onk^]P00onh
^mco^[_KokZkf`02okZkf`04okNlg_nh_=go^;cMokRlg@;o]KgP0_nf_Ml4ok>nhP04ok2ni?na_^Co
/KkTok6ni0?o[[kU0_n__^D4ojfniP?o[;kW1?n[_^L4ojZmi`SoZ[gX1?nY_NP00ol0003oZKgXojVm
j00AojVmj003o`000?oooooooooo05?ooooo0_l00003ooooo`;oZKgX1?nX_NP2ojRlj0;oYkcX0onV
_>P2ojFkj@;oY;[Y0onR^NT4oijfj@;oVk?Y0_nH/NT3oi:]j0?oSJSW0on7X^D3ohBLh`?oPYSO0on2
U=`3ohJCf@?oRi?F1?nBU=83oiVGd004oj6Jc_nQV<coXIS<oj6Hc0CoZIc:0on`XLT00onaX<Ko^:G6
okRUaP03okRUaP04okbYaonoZLCo_jW4oknYa0?o`Zk60_o5[l@3olNcaP04o`000?o:/lCobkO8ol^g
b0?ocKS600?oc;c;olnmbOo?_LT00_o?_LT01?o<_lkoc/7=olk1cOo>`Ld4ooooo`03o`000?oooooo
oooo02[ooooo000Xooooo`?o00003oooool3okR^c`?o^K7A00?o^k3?ok^cd_nk/m800onk/m800onj
]]Go_;GCokbed`02okbed`04ok^he_nm^=Co_KSDokfhe0?o^k[H0_nl^]L3okZkf`03ok^kfOnh_=go
^;cM00;o^;cM00?o]KgPokJmgonf_Ml00_nf_Ml2ok>nhP;o];kQ1?na_^@00on^_^Go[kkUojnni@02
ojnni@?o[KkV1?n/_^L4oj^ni`CoZ[gW2?nZ_NP3ojVmj003o`000?nY_NSoZKgX017oZKgX00?ooooo
o`000?ooool0D?ooool3o`0000;ooooo1_nY_NP4ojRmj0CoYkcX00?oY[cXojJkjOnV^nT01?nT^^T3
oj:ij@;oW[KY0_nL]NT4oiRaj@?oTZgX0on=Z>L3ohNRi@?oQ9cS0on2V=l3oh:Dg0?oQY?I0on;TmH2
oi:DdP04ohnAd?nHU<koV9C>oiRDcPGoXIS<1?nYW<X01?n`XLWo/J36ok6Pa_naX<H4okRUaPGo_jW4
00?o`Zk6olF_a?o5[l@00_o5[l@01Oo7/lKob[?4o`000?o:/lCobkO800CocKS61?o?_LT01?oA_/So
c/7=olk1cOo>`Ld2om32c0Cooooo00?o0000ooooooooool0:Oooool002Kooooo0_l0000@ooooo`03
okN[c_nh[/oo^:k?00?o^:k?00Co^K7Aok^`conk/<oo^k3?0onk/m82okfbc`?o_;GC00?o_[GAokfh
e?nm^=@00onm^=@00onk^]So_;[Gokbje`02okbje`04okZkfonk^mWo^k_Iok^kf@;o^;cM0_nj_M`3
okJmg`;o]kkN1?nd_^42ok6ni003ok:nhon__^Go[kkU00?o[kkU1?n]_^H4ojbni`CoZkkW0_nZ_NL0
0on[_NOoZ[gXojZmj006ojZmj0?oZKgX00?o0000ojVmj?nY_NP04_nY_NP00ol0003oooooooooo`1=
ooooo`;o00000_ooool:ojVmj0CoZ;gX0onW_>P4ojJkj@;oY;[Y00?oXk[Yoj2hjOnP^>T00_nP^>T4
oibej@;oV;7Y00CoU:oYohjZjOn>Z^WoSZ[Y0on7Y>L3oh6Mi@?oOIOR0omkT]h3ogb?f`?oPHkG0on7
S]<4ohnAd0?oV9C>1?nQV<`2ojVLbP;oZY_81?naX<H3okRUaP;o^ZG41?noZL@4olF_a005olN_`_o:
/lCob[?4o`000?o:/l@01Oo=^<H00oo@^/Cockg9olnmb@03om6nb003olk1cOo@`/cod<;<00;od<;<
0oooool00ol0003oooooooooo`0Yooooo`008oooool3o`00017ooooo0ongZlh3okR^c`03okZ]cOnk
/<oo^k3?00?o^k3?00?o^k?Bokfbconm//l00_nm//l01?nl]M?o_[GAokjedOnn]M43okfhe0;o_kOC
0onl^]L01Onn^]Go^k_Iok^kfOnk^mWo_KcH00Go^[gL00?o][gOokNng_ng_]h00_ng_]h2okBnh@03
okFnhOnb_^?o/[kS00;o/[kS1On__^D2ojfniP;o[[kV1?n/_^L3oj^ni`CoZkgW2?nZ_NP2ojVmj003
o`000?nY_NSoZKgX01?oZKgX00?o0000ooooooooool0BOooool3o`0000?ooooo3?nY_NP4ojRmj0?o
YkcX0_nV^nT2ojFkj@?oXk[Y1?nP^>T2oibej@;oV[CZ0onD[nT3ohjZj@?oQjCW0on1WND3ogfGhP?o
Ni;N0omlSm/3oh6>e`?oQhkC0on?TM04oiRDcP;oXIS<00?oXIK9ojZKb?nZVlP00_nZVlP5ok6PaP04
okRUa_njYLCo^ZG4okZUa0?o_jW40_o1Z/<2olF_a0?oajo200Cob[?4o`000?o=]L?ocKG30oo=^<H2
om2ja003olnmbOoA_/SodKk800;odKk81Oo@`/`4ooooo`03o`000?oooooooooo02Sooooo000Qoooo
o`;o00004_ooool00ondZ<go]j_>okN[cP03okN[cP04okR^conj[Lgo^Zg=okZ]c@?o^k3?00?o_K3=
okfbconm//l00onm//l5okjed@03okfhe?no]m?o_kOC00;o_kOC00Go_;[GokjjeOnn^]Go_[[Eok^k
f@03okflf0?o^[gL0_nk_M/3okNngP03okVng_ne_^7o]KkQ00;o]KkQ1?nb_^<3ojnni@;o/;kU1?n^
_^H3ojbni`CoZkkW1?n[_NL8ojZmj003ojVmj?l0003oZKgX01GoZKgX00?o0000ooooooooool0A_oo
ool2o`0000Cooooo3OnY_NP6ojRmj0?oYkcX1?nU^nT3oj>jj@;oX;SY0_nN]nT4oiZdjP?oU:oY0_n>
Z^T2ohNTi`04oh6PiomjVNCoNYWTogZIi0?oMY;Q0omkT]h4ogb?f`;oPHkG0on7S]<4ohnAd0;oV9C>
00?oUi;<oj6FbOnQU/T00_nQU/T4ojZKb0?o/J3600?o/j35okZUa?njYL@00onjYL@01OnoZLCo`J[3
ol6Z`oo1Z/?oaJo400Coajo200?ob[?4o`000?o=]L<00_o=]L<01?o=^<Kod;[4om2ja?o@^/@5om6n
b004omC0aoo@`/cod<;<om32c0;odlC;1?ooool00ol0003oooooooooo`0Wooooo`007_ooool3o`00
01?ooooo0ondZ<d3okN[cP03okRZbonj[Lgo^Zg=00?o^Zg=00Co^k3?okf`cOnm/<go_K3=0onm//l2
oknbc@?o_[GA0_o1]Ll3okngd`03ol6hdOnn^]Go_[[E00;o_[[E1Onm_=P00onj_Mco^kgKok^mf`02
ok^mf`04okNng_ni_]ko^KkNokVngP;o]KkQ0_nf_n44ok:nh`03ojnniOn`_^Go/;kU00;o/;kU0on^
_^H4ojbni`CoZkkW1?n[_NL8ojZmj003o`000?nY_NSoZKgX01CoZKgX00?o0000ooooooooool0@ooo
ool3o`0000Cooooo3_nY_NP6ojRmj003ojRlj?nW_>SoYkcX00;oYkcX0_nU^nT2ojBkj@?oX[WY1?nN
]nT2oiZdjP04oiNbj_n@[N[oT:gZoi2]jP?oRJOY0on1X>L3ogZIi0;oMY;Q0omdSMd4ogJ9f@?oNhWE
0on7S]<2ohnAd003ohf=conGT/coUi;<00;oUi;<0onQU/T4ojZKb003ok6Pa_ncX<Go/j3500;o/j35
0onjYL@00onlYL;o`J[3ol6Z``02ol6Z``Goajo200?ocKG3o`000?o=]L<00_o=]L<4om2ja004om:k
`ooA_/SodKk8om6nb0?oe<3700Cod<;<om?4booCa<_odlC;1?ooool00ol0003oooooooooo`0Woooo
o`007?ooool2o`0001Cooooo00?o/JG=okBXcOndZ<d00ondZ<d01?ngZlko^:[;okRZbonhZ//3okZ]
c@03okb/b_nm/<go_K3=00?o_K3=00?o_K;?oknbcOno//d00_no//d00onn]M7o`KG?ol6ec`02ol6e
c`04okngdoo1^=7o`KSAol6hd@;o_[[E0_o1^]@3okflf0;o_kcG0onk_M/00onm_M[o^KkNokVngP02
okVngP03okFnhOnf_n7o][oQ00;o][oQ0_nb_^<2ok>oh`?o/;kU00?o/;oTojjni_n^_^H00_n^_^H2
ojbni`;o[KkV1?n[_^L2oj^mi`03oj^nionZ_NSoZ[gX00KoZ[gX00?o0000ojVmj?nY_NP05OnY_NP0
0ol0003oooooooooo`10ooooo`;o00001?oooolBojVmj0CoZ;gX0onX_>P2ojNlj0;oY[cY1?nT^nT3
oj:ij@;oW[OY0_nL]^X3oiNbjP?oT:gZ0on9YnT3oh6Pi`?oNYWT0_mfT^43ogB=g@?oMXWI0omkRMD3
oh>:dPCoSHg?0onGT/`4oj6Fb@;oZY_800?oZi[6ok>PaOncX<D00oncX<D00onjYLCo_:G2okbU`P02
okbU`P;o`J[30_o4Zl44olN_`P03olZ``?l0003ocKG300;ocKG300?ockK1om2ja?o@^/@00ooB^l<0
0ooA_/Soe<37omC0a`02omC0a`?odlC;0_oEaL/4ooooo`03o`000?oooooooooo02Kooooo000Ioooo
o`?o00005Oooool3ok6Uc@?o]:S=00?o]JO:okRZbonhZ//00onhZ//01?nj[Lgo_:c:okb/b_nl[<X3
okf`c@;o_jo:0ono//d00oo1//_o`KG?ol6ec`03ol6ec`Co`KSA00?o_[[Eol6je?o1^]@00_o1^]@0
0onm_=So_kcGoknle`02oknle`04ok^mfonm_M[o_KgJokfmfP;o^KkN0_nj_]d3okJoh@;o]koP1?nc
_n<01?n`_^Go/;oTok2oi?n`_n@4ojjniPCo[KkV1on[_^L7ojZmj003o`000?nY_NSoZKgX01GoZKgX
00?oooooo`000?ooool0?Oooool3o`0000?ooooo5_nY_NP4ojRmj003ojRlj?nW_>SoYkcX00CoY[cY
0_nT^nT00onT^^WoXKSYoj6hj@02oj6hj@CoW;KZ0_nG/^X2oi2]jP04ohb[j_n3XnWoPj?Yoh>Sj@?o
NY_V0ombTn<3off<g`?oM8gM0omfRMT3og^9e@?oPh[B0on=SLl3oiNBc0?oXIK900?oXIG8oj^Ja_n[
V/H00_n[V/H4ok>Pa@Go_:G200Co`J[3olB[`Oo4Zl7oa:_10oo7[l82olZ``003o`000?o=]L?ocKG3
00;ockK100?od;[4om:k`ooB^l<00_oB^l<4omC0a`;oe/;600GodlC;omG5booEaL_oeLG;omO7bP04
ooooo`03o`000?oooooooooo02Gooooo000Fooooo`?o00005_ooool00on]Xlgo/JG=ok6Uc@03ok6U
c@04okBXcOneYl[o]JO:okFWbP?o^:[;00?o^ZW8okb/b_nl[<X00onl[<X00onm/<go_jo:okn_bP02
okn_bP04oknbcOo1//_o`K;;ol6bb`?o`KG?0_o3]Ld2ol6hd@;o`kS?0oo1^]@2ol:jdP?o_kcG00Co
`KcFokfmf_nm_M[o_KgJ0_nn_]T4okZng@03okJohOng_n3o]koP00;o]koP0_nc_n<01?nd_n;o/;oT
ok2oi?n`_n@2ok6oi0Co[[kV0on]_^H8oj^ni`KoZ[gX00?o0000ojVmj?nY_NP05_nY_NP00ol0003o
ooooooooo`0iooooo`?o00000ooooolJojVmj0?oZ;gX1?nW_>P2ojJlj@;oY[_Y0onT^^T4oj6hj@;o
W;KZ00CoV[CZoiB`j_nD/>[oU;3Z0on<ZnX3oh>Sj@?oNY_V0ombTn<2off<g`?oK8KK0om_Q=L3og^9
e@CoPh[B0on=SLl3oiNBc004oj6FbOnQULSoXIG8oj6Eb0?oZi[60oncX<D2okFP``Co_:G21Oo4Zl40
1_o7[l;ob[30olZ``?o:/<3o0000olfe``?ockK11OoB^l<00ooE_L;oe<37omC0a`03omK2aPCoeLG;
0_oGalX3ooooo`03o`000?oooooooooo02Gooooo000Dooooo`;o00005_ooool00onWX<ko[J?=ojfS
c@02ojfSc@?o/JG=00?o/ZC:okFWb_neYlX00oneYlX01?nhZ/_o^ZW8okZYb?njZLP3okb/bP03okj/
b?no[l[o_jo:00?o_jo:1Oo1///01Oo1]Loo`kG=ol>ecOo3]Lgo`KSA00Co`kS?00?o`K[Dol:jd_o2
^]800_o2^]801Ono_=Oo`KcFol6le_o1_=Ko_KgJ00Co_[kI0_nj_]d2ok^og@?o]koP00?o^;oPokBo
h_nd_n800_nd_n800on`_nCo/KoTok6oi002ok6oi0;o[[kV00?o[koVojfni_n]_^H00_n]_^H2oj^n
i`;o[;kW1?n[_^L5ojZmj003o`000?nZ_NSoZKgX01KoZKgX00?oooooo`000?ooool0=oooool2o`00
00?ooooo7_nY_NP3ojRmj0CoYkcX1?nV^nT3ojBjj@;oXKSY00?oWkSZoiZdj_nJ]>X00_nJ]>X3oiB`
jP?oS:_Z0on3XnT3ogZKiP?oLY?S0_m]S=l3ofb6f`;oKhCG0omfQ=<4ogn6d0?oRh[=0onFSl/4oj6E
b0CoZi[600Co/j35okFP`oneX<?o]J330onlYL82okjV`@Coa:_11?o:/<000ol0003ockK1olnf`@02
olnf`@04om:h_ooB^l?od[_3om:k``;oeKg200?oe<37omK2a_oF`/H00_oF`/H00ooI`lGoeLG;omG5
b`03omO7bPCooooo00?o0000ooooooooool09?ooool0017ooooo0ol0000Fooooo`CoYj3>1?n]Xld0
1?naYLgo/ZC:ok:Tb_nbY<X4okFWbPGo^ZW800Co_:c:okj/b?nn[<So_Zc80ono[lX2ol6_b0?o`K;;
00?o`k;9ol>ecOo3]Ld00_o3]Ld01?o5]L_o`kS?ol>hcoo3^<l2olFhc@?o`[[B00Coa;_Aol6le_o1
_=Ko`KcF0_o3_M@3okjnf@03ol2nf?nk_mgo^koM00?o^koM00Co]koPokRoh?nh_n3o^;oP1?nd_n84
ok6oi0Co[koV1?n]_^H4ojbni`?oZkkW1?nZ_NP2o`0000;oZ[gX5onY_NP00ooooooo0000ooooo`0c
ooooo`?o00000ooooolQojVmj0?oZ;gX1?nW_>P2ojJkj@;oYK_Y0onS^^T3oinhjP;oV[CZ0_nH/n/3
oi2^j`?oQjSZ0ommWnP2og:FiP?oJXgR0omTQMh2ofb6f`?oKhCG0omfQ=<3ogn6d0?oRh[=1?nFSl/4
oj6Eb0;oZi[600?o[9[4okFP`oneX<<00oneX<<01?nlYL;o_ZK1okjV`OnnY/43olB[`@;oaZbo0_o:
/<02o`000003olfb_oo?]/7ockK100?od[Ro00God[_3omFm`_oE_L;oeKg2omRo`@03omK2aP;ofL?5
00?oeLG;omO7b_oGalX00_oGalX00ooIbL[oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo
000@ooooo`;o00005oooool2oj:Md0?oYj3>0on]Xld00on]XL_o/ZC:ok:TbP02ok:TbP?o]JO:0_ng
Y/P4okZYb0Go_Zc800Go_jo:ol6_b?o1[lSo`Jo8ol6bb`04ol>bb@;o`kG=0oo5]L/00oo3^<ooaKS=
olFhc@02olFhc@05ol:jd_o4^m7oa;_AolBkdOo1_=H01?o3_M@01?nn_]Wo`;kHol2nf?o0_]P3ok^o
g@04okbog?nh_n3o^;oPokRoh0;o^L3O1?nd_n84ok6oi0;o[koV0_n__nD4ojfniP?o[;kW1?n[_^L3
o`000003ojZmj?l0003oZ[gX00;oZ[gX5onY_NP00ol0003oooooooooo`0aooooo`;o00000_oooolS
ojVmj0GoZ;gX0_nW_>P2ojNlj@CoYK_Y0onS^^T00onO^>[oWKOZoifgjP04oiRcj`?oT:k[0on7Z>X3
ogfOj0;oLYKV0omZSN82ofB5gP?oHh3I0om_Q=L2ogJ4d`CoOhK@0on;R/d3oiJ?b`?oXIG800?oXIC6
ojbJa?n/V/@00_n/V/@4okFP``Go_ZK100?oa:_1olJ/_oo6[;l00ol000001?o=/[oo0000olfb_oo?
]/44om:h_`CoeKg20_oH_l401OoF`/KofL?5omW3aOoI`lGoflG400?oelO:0_oIbLX4ooooo`03o`00
0?oooooooooo02?ooooo000@ooooo`03o`000?oooooo0000017ooooo00CoUY[FoibKdonLVm?oW9_C
0onRWM04ojNPcP04ojfScOn]XL_o[J7;ojfQb`Co/ZC:00Co]JO:okNVb?ngY/So]jK80onjZLP2ok^X
aPCo_Zc81?o1[lP5ol>bb@03ol>ecOo5]L_oaKG;00;oaKG;1Oo5^<d4olBkd@Go`kgD1Oo0_]P01Onk
_mgo_;oLokbog?nl_mco^;oP00Co^L3O0_nd_n801?ne`>;o/KoTok6oi?na_n@2ok:oi0Co[koU0on]
_^H4ojbni`?o000000?oZkkWojZmj?nZ_NP00_nZ_NP01?l0003oZ[gXojZmj?nZ_NPGojVmj003o`00
0?oooooooooo033ooooo00?o0000ojVmj?nY_NP08onY_NP5ojRmj0;oZ;cX1?nW_>T2ojFkj@;oY;_Y
0_nQ^NX4oifgjP;oV;?[00?oUK;[ohb/jon<[>/00_n<[>/3oh:TjP;oMY_X0omZT>D3ofZ=hP;oI8GN
0_mSP=T3ofMne@?oL7oB0omoQ]03oh^:c@CoUXo;00CoXIG8oj6Da_nQU<KoXIC60on/V/@3okFP``;o
]j321?nnY/43o`0000;oaZbo0oo=/[l00ol0003od[Room:h_`03om:h_`03omFi__oE_L;oeKg200?o
f;o11?oI`lD2om_5a004omO7b_oIbL[ofLW:omW9bPGooooo00?o0000ooooooooool08_ooool0013o
oooo00Co0000oooooooooooo00002_ooool01?n;V]coT9[Ioi2JfOn@V]T4oiJJeP?oW9_C0onRWM02
ojNPcP03ojNMc?n]XL_o[J7;00?o[J7;0_nbY<X00oncX/So]jK8okNVb003okNVb004okZYb?nkZ<Ko
^jS6ok^XaP?o_Zc80_o0ZlD2ol6_b0;o`jo60oo3//T2olFba`?oaKG;0_o7]LT3olFhc@;oakS<0_o4
^m42olJkd0?o`kgD0_o4_M<3ol2nf004ol6of?nl_mco_;oLokbog0;o_/3L0oni`=l00onj`Moo]L3R
okG0hP02okG0hP03ok6oi?nb_nCo/[oT00;o/[oT0on__nD4ojfniP?o000000?o[;kWoj^nion[_^L0
0_n[_^L4ojZmj004o`000?nZ_NSoZ[gXojZmj1KoZKgX00?o0000ooooooooool0<?ooool00ol0003o
ZKgXojVmj00TojVmj0?oZ;gX1?nX_>P2ojNlj@;oY[cY1?nT^nT2oj6ijP;oWKOZ0_nK]^/3oiFbj`Co
S:c[0on2Y>X2ogJKj0;oJY3U0omPQ^43oeYng0;oHh3I0omWO]D2og1odP?oNh;?0on8R<`4oiF>b@Co
XIC61?n/V/@01OneX<?o]j32okNP`_ngX<;o_ZK100?o00001?o6[;l00oo9[KkocK:oolfb_`02olfb
_`04o`000?oB^;ood[Room:h_`;oeKVn00?oeKg2omRo`OoH_l400_oH_l400ooK`L3ofL?5omW3a@03
om_5a0?ofLW:0_oJblX4ooooo`03o`000?oooooooooo02;ooooo000@ooooo`05o`000?oooooooooo
oooooon;YnP00_n8XnH3ohNOh`?oR9cP0on;V]`3oi2Jf@?oUY[F0onLVm<2oj:Md003oj6Kc_nWWLco
Yig<00;oYig<0on]XL/00on^WlSo/j;8ok>Rb002ok>Rb0?o]jK800?o^:G5ok^Xa_nkZ<H00onkZ<H0
1Onn[<So`:_5ol2[aOo0ZlGo`Jo800Co`jo600?o`k;9olFbaoo5//L00_o5//L00oo5]L_oakG9olNe
b@02olNeb@05olFhcOo7^<coakS<olNhc?o4^m401?o6^m000oo3_MCoa;gColBmd`02olBmd`05ol2n
f?o1_mSo`KoHol6of?nl_m`01?nn`=`01?ni`=oo^/7Ook[1gonj`Ml2okG0hP;o]/3R0onb_n@00onb
`>Co[koUojnoi@02ojnoi@?o000000?o[KkVojbnion/_^L00_n/_^L3oj^ni`GoZ[gX00Co0000ojZm
j?nZ_NSoZ[gX5_nY_NP00ol0003oooooooooo`0_ooooo`03o`000?ooooooZKgX02GoZKgX0onX_NP2
ojRlj0;oYkcX1?nV_>T2ojBkj@04oj>jjOnP^N[oX;WZoj2ijPCoVkK[0onE/^/2ohb/j`04ohNYk?mk
XN_oNj7[og^Qj`;oKIKX0omZT>D3of26h@;oFWkL0omJNML2ofMne@?oL7oB0omkP/l3ohR8c0?oUHk9
1?nQU<H3ojbJa003ojfJ`ongX<;o]j3200?o000000Co_ZK1ol6W_oo1Ykoo`JNo0_o6[;l3olV]_P;o
cK:o0_o@/kd00ol0003od[RoomFi_P02omFi_P04omRl_OoH_l7of;o1omRo`@;ofl7000?ofL?5om_5
a?oKaL@00_oKaL@00ooMb<CofLW:om[;bP02om[;bP03omc=b_oooooooooo00;ooooo00?o0000oooo
ooooool08Oooool000oooooo00Co0000ohn/jOn?[>WoSjcY0on;YnP2ohRSiP?oQioS0on8W>03oh^J
g0?oT9[I0onFV]H00onLVm?oVYSAoj6KcP03oj6KcPCoYig<00Co[J7;ojjOb?n^WlSo[Yo81?ncX/P0
1?ngY/So^:G5okRUaOnhYLD3ok^XaP03okfXa?o0ZlGo`:_500;o`:_51Oo3[lH5olFba`GoakG91?o7
^<`01?o9^L_oa[_@olJkd?o6^m02olRlcP?oa;gC00Coa[kCol6of?o1_mSo`KoH0_o3`=L3okk0g003
oko1fonj`Moo^/7O00?o^/7O1?nf`>801?nb_nCo//3Tok;0i?nb`>@3o`000003ojnoiOn]_^Ko[KkV
00;o[KkV0on/_^L4oj^ni`CoZ[gX00Co0000ojZmj?nZ_NSoZ[gX5_nY_NP00ooooooo0000ooooo`0^
ooooo`04o`000?ooooooooooooooobKoZKgX0onX_NP4ojNlj0?oY[cY1?nS^^T3oj2ijP;oVkK[0_nI
]N/2oi:`k0CoQjW/0omkXN/2offFj0;oH8[T0omEOml3oeYng0;oFWWG0omOMm<2og1odP?oNh;?0on8
R<`4oiF>b@CoXIC600?o[9[4ojfJ`ol000000_l00002okNP`P03okVQ`?o1Ykoo`JNo00;o`JNo00?o
aZboolV]__o9[Kh00_o9[Kh01Oo=/[ood;>mom2c_Oo@/kgo000000CoeKVn0_oH_;d01OoH_l7ofl70
om_1`?oK`L3ogL>o00?oflG40_oMb<@01?oOb/Cof/_:om[;b_oJblX2omc=bPCooooo00?o0000oooo
ooooool08?ooool000oooooo00?o0000oooooon?[>T00_n?[>T3oh^Wj0;oR:?V0on7Wn<2ohRLh0;o
Ri[L00CoQYGKohbEf?n<UMSoS9GH0onCU]@3oiZHd@CoXI_>0_nWWL`00onWVl[o[Yo8ojjOb002ojjO
b0?o/j;800?o]:75okRUaOnhYLD00onhYLD01?nkZ<Ko_JS4okfXa?nmZ<@2ol2[a@;o`Z_30oo3[lH2
olF_a0?oaK;70_o8//D3olNeb@;obKK70_o7^<`3olVib`03olJkd?o8_<kob;c>00;ob;c>00Goa;gC
olJndoo6_]?oa[kCol6of004ol?0e`04okk0g?no`M_o_l7Koko1f`Go^/7O0_nf`>800onf`N;o//3T
o`000002o`000003ok;0i?n__nGo[koU00;o[koU0on]_^H4ojbni`GoZkkW0_nZ_NP00onZ_^So0000
ojZmj002ojZmj1KoZKgX00?o0000ooooooooool0;Oooool00ol0003oooooooooo`02ooooobGoZKgX
1?nX_NP4ojNlj0?oY[cY1?nS^^T3oinhjPCoVKG[0_nB/>`3ohNYk0?oNj7[0om]U^P2of2:i0;oEGoO
0om?M]X2oeYie`?oGgOC0omYN]03og^2c`?oR8S<0onES/T2oj6DaP04oj:CaOl0003o0000o`0000;o
[I[30_ngX<82okVQ`0Co`JNo1Oo9[Kh5om2c_@03o`000?oE^KkoeKVn00?of;bm1?oK`L02omg3_`04
om_5a?oMb<CogLS4omg8a0;ogl[400Cof/_:omc=b_oLcL[og<g:1?ooool00ol0003oooooooooo`0P
ooooo`003oooool00ol0003oooooohZXj@02ohZXj@CoQJ?X00CoPYkUoh2Jh_n0V^;oP9[R0_n2Uml4
ohJEf`?oS9GH0onCU]@3oiZHd@;oXI_>00?oX9S<ojNKb_nWVlX00_nWVlX4ojjOb004ok>Rb?ndXLGo
]:75okBQa@Co^:G51?nmZ<@00oo0ZlGo`Z_3ol:[``02ol:[``03ol>_a_o5[lCoaJo400;oaJo400?o
aK;7olRbaOo8//D00_o8//D01Oo7]LWobKK7olVfaoo9]/OoakS<00CobKW;1Oo8_<h3olJnd`;ob;oB
0oo3`=L2olC1e`?o_l7K00Co`<;Kok[1gonj`Moo^/7O0_nk`]l3o`0000Go//3T0_n__nD00on__nKo
[KkVojfniP02ojfniPCo[;kW1?n[_^L4ojZnj003o`000?nZ_NSoZ[gX01KoZKgX00?oooooo`000?oo
ool0;Oooool00ol0003oooooooooo`03ooooobGoZKgX1?nX_NP4ojNlj003ojJljOnU^nWoYK_Y00Co
Xk[Y0onO^>X2oiVej`04oiNdjon>[ncoSZo/ohj_k0?oPjO/0omdWNX2ofBAi`?oEH?R0_mEOml2odmf
fP;oCg7E00?oFWWGoemgdomOMm<00omYN]03ogMocP?oQXG;0onES<P3o`000003oj:CaOn]V/?o[I[3
00;o[I[300?o]j32okVQ`?niXL000_niXL02ol6W_`;oa:Rn1?o9[Kh01?o<[kcod;>mom2c_Oo@/kd2
om>f_003o`000?oH_;gof;bm00;of;bm00?ofkjlom_1`?oK`L000ooM`kl3omg8a0?ogl[40ooLcLX2
omg?b`Cooooo00?o0000ooooooooool07oooool000oooooo00?o0000ooooooooool00on:Z>T4ohFS
j004oh:NiOn0V^;oP9[Roh2JhP;oPYOO0on6UM/4ohbEf0;oTiKD0_nJV=400onHULooX9S<oj2Hc002
oj2Hc0?oYi_:0on^WlP00on^WLKo]:75okBQa@02okBQa@?o^:G500?o^ZC3okfXa?nmZ<@00_nmZ<@5
ol:[``GoaJo41Oo8//D4olVfa`04ol^ga_o9^L_obKW;olVib`;oc;[90oo8_<h2olZmc@03olJndoo8
_m;ob;oB00;ob;oB00?o`l3GolC1eoo4`ML00_o4`ML01Ono`M_o`<;Kol32foo0`]_o^/7O00?o0000
00Co^l;OokK1h_ng`N;o]l7R0onb`>@00onc`>Co[koVojnoiP02ojnoiP;o[KkV0_n]_nH4ojbni`Co
ZkkW0onZ_^P01?nZ_NSo0000ojZmj?nZ_NPFojVmj003ooooool0003ooooo02cooooo00?o0000oooo
ooooool01?oooolUojVmj0CoZ;gX0_nW_>P00onW_>WoYK_YojFkj@02ojFkj@;oXk[Y0_nR^^X3oifg
j`?oUkC[0on>[n`3oh>Wk0?oM9gZ0_mTTNL2oeF3hP?oBGOL0_m?M]X2odmae@?oGgOC0_mYN]04ogMo
cP;oQXG;0ol000000onES<SoXY?5oj:Ca@02oj:Ca@;o[I[300?o[i_2okVQ`?niXL000oniXL001?o1
Ykooa:RnolBX__o4Z;h3olV]_P?oc:nl00Kod;>mom>f_?oC][codkJlomRl_Ol00002omRl_@;ofkjl
00?ofl70omg3_ooM`kl00_oM`kl00ooPa[kogLS4omo:a003omo:a003on7<a?oLcL[ogLo;00;ogLo;
00?og]7;ooooooooool00_ooool00ol0003oooooooooo`0Nooooo`003oooool01?l0003ooooooooo
ooooool3ohZXj@;oQJ?X00?oOYoXogZIiOmjVND00on0V^82oh:Gg`?oQYGK0_n<UMP00on7TMKoSi;B
ohnBdP04oiREc`?oX9S<1?nWVlX01?n^WlSo[Yg6ojjMa_n^WLH4okBQa@04okRUaOnjY<?o^ZC3okZT
``;o_JS40_noYl83ol:[``;oa:_10oo5[l@2olN_`P?ob;;50_o:/l<2olVfa`?obkO600?obKW;olbj
bOo<^/T00_o<^/T01Oo8_<kob[g=olZmcOo:_Lgoc;k=00?ob;oB0_o9`=43olC1e`04olG2eoo0`]_o
`<;Kol32f`;o00000onk`]l00onl`]oo]l7RokO1hP02okO1hP04ok;0i?nc`>Co/l3Tok?0i0;o[koV
0_n`_nH4ojfoiPCo[;kW0on[_^L4ojZnj004o`000?nZ_NSoZ[gXojZmj1KoZKgX00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`05ooooobGoZKgX1?nX_NP3ojNlj@CoYK_Y1?nR^^X3oifgj`03
oiNdjonD/ncoU;?/00?oRZg/0ommY>`2offIjP?oFh_V0_mEPn82odUgg0;o@fkG0_m?LMD3oeIadP?o
JG[@0omgOlh2o`000004ohJ5bonES<SoUHc8oiF<b0CoXY?500Co[I[3ojnK`_n_Vl;o[i_21?niXL05
olBX_P03olV]__o<[kcoc:nl00;oc:nl1?oC][`00ooF^;_o0000omRl_@03om^n_004omk1^ooM`koo
gL>oomg3_`;oh<Jn00Coh/Rnomo:a?oOb/Cogl[40_oQc<@3omg?b`;og]7;00Gogm?<oooooooooooo
ooooo`00000Pooooo`003oooool00ol0003oooooooooo`02ooooo`?oQ:GZ0omnWnP2ogZIi@;oNICQ
0_mkTMh3oh2@fP?oQi7F0on?T]83oiREc`CoX9S<0_nWVlX00onWV/So[Yg6ojjMaP02ojjMaP?o]:75
00?o]J33okZT`onjY<<00_njY<<00onmZ<Co_jO2oknW`P02oknW`P03ol:[`oo4Zl7oa:_100;oa:_1
00?oaJo4olN_`_o7[l800_o7[l801Oo8//Gob[?3olZc`oo:/l?obKK700CobkO61Oo<^/T01?o>^lSo
b[g=olZmcOo:_Ld2olbnc@03olRod_o9`=7obL3A00;obL3A00?oa<7GolG2eoo5`]L00ol00003ol72
f`04ok_2gonl`]oo_<;Ookc2g`Co]l7R0_nc`>@2ok?1i0Co/;oV0_n]_nH2ojfoi`?o[;kW1?n[_^L4
ojZnj004o`000?nZ_NSoZ[gXojZmj1KoZKgX00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`06ooooob?oZKgX1_nX_NP00onW_>WoY[cYojJlj@04ojFkj@;oX[[Z00CoXKWZoibgjonL]n_oW;O[
1?nD/n`3ohZ]k0?oOJC/0_m]VNX2oe^;iP?oBGcP0_m9Mm`2od=^e`;oCg7E0_mFLM83of=ec`?o0000
00?oMgo>ohJ5bon6QL/01?nES<P2oj:Ca@03oj>CaOn_Vl;o[i_200;o[i_20oniXL02okbR_`Coa:Rn
1Oo<[k`00oo?/K_odkJlom>f_003omJh^`04o`000?oK_[cofkjlom^n_0;og/6k00CogL>oon36__oP
a[koh<Jn0_oRb;h01_oOb/CohLc4on7<a?oQc<Cohlo4omg?b`?og]7;0_oOdl`3ooooo`03o`000?oo
oooooooo01gooooo000>ooooo`03o`000?oooooooooo00Cooooo0on4YNX2ogjOj0?oNYWU0_miU>42
og^AgP?oP93J0on7TMH2ohnBdPCoV9G?0_nPV<`00onOU/[oYi[8ojNJb002ojNJb0Co[Yg600Co]:75
okFP`oneX<?o]J330_njY<<00onkY<7o_jO2oknW`P03oknW`PGoa:_11Oo7[l84olZc``04olbc`_o;
]lKobkO6ol^gaP;oc[O40oo<^/T3oljkb005olZmcOo<_/goc;k=olbncOo>_l`00oo9`=401?o;`M7o
0000o`000?l00002olK3eP?o`L;K00Co`L?Kokc2gonl`]oo_<;O0_nl`ml3okO1hP03okO2h_nc`NCo
/l7T00;o/l7T0on`_nH4ojfoi`Co[;kW1?n[_^L4ojZnj003o`000?nZ_NSoZ[gX01OoZKgX00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`08ooooob7oZKgX1onX_NP4ojJlj@;oYK_Y0_nT^nT3
oj6ijP?oW;O[0_nD/n`2oi:ak0?oQZ_]0_mgXN`3ofBDjP;oFh_V0_m9O>03oca_fP05od=^eom4J]?o
A6[CodAZdomFLM800ol00004og=kc@?oQ8?:0_nES<P00onDS<OoXi?5oj>Ca@02oj>Ca@Co[i_200Co
^J70okbR_onlX[oo_::o0oo4Z;h2olJZ_@?oc:nl0_o?/K/00ooC][coe[RkomJh^`02omJh^`03om^n
_?l0003ofkjl00?og/6k0ooPa[h3on;8_P?ohLc40_oScl@3omkAb`?ogm?<1?ooool00ol0003ooooo
ooooo`0Looooo`003_ooool00ol0003oooooooooo`05ooooo`?oO:7Z00CoMI[Wog6Ci?maTnCoLI?T
0om`S^02og^AgP?oP93J0_n7TMH3ohnBdP;oV9G?00?oUY;=oinFb_nOU/X00_nOU/X4ojNJb0;o[Yg6
00?o[ic4okFP`oneX<<00_neX<<01?njY<?o^jC1ok^T`OnkY<43oknW`P;o`JS01?o4Zl400oo6[;oo
ajo2olN_`P02olN_`P03olV``?o:/l?ob[?300?oc;?200?obkO6oljga?o>]l@00_o>]l@00oo<^/Wo
c[_8oljkb002oljkb0?oc;k=0oo>_l`3o`000003ol_1dOo5`]Ooa/?F00?oa/?F00Go`L;Kol73foo1
`m_o`L?Kokc2g`04okc3g`04okO1h_ng`^;o]l;RokO2hP?o/l7T1?n`_nH4ojfoi`Co[;kW1?n[_^L3
ojZnj004ojZmj?l0003oZ[gXojZmj1KoZKgX00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`09ooooob7oZKgX1onX_NP4ojJlj@CoY;_Y00?oXKWZoinijonO^N/00onJ]^/4oi:ak0?oQZ_]0_mg
XN`2ofBDjP;oD8GU0_llM=h00om9O>3o?6oJoca_fP02ocEUe0?o000000CoCF_@of=ecomSMLooHgG?
0omcNld3ohB3bPCoU8c70onSTlD3ojnK`P03ok6L`_nlX[oo_::o00?o_::o00?oa:RnolJZ_Oo6Z[d0
0_o6Z[d01?o<[kcock6kolna^oo?/K/5omJh^`03omVj^_oK_[co000000?og/6k00?ohL>kon36__oR
b;h00ooRb;h00ooTbkkohLc4on??a002on??a003onCAa?oNdL_ogm?<00?ogm?<00GogmG=oooooooo
ooooooooo`00000Nooooo`003_ooool00ol0003oooooooooo`06ooooo`?oO:7Z00CoMI[Wog6Ci?ma
TnCoLI?T0_m`S^02og><g0?oNH_H0_n2S=@3ohb?d@CoUY;=0onOU/X3ojNJb003ojRHa_n_W<Co[ic4
00;o[ic40_neX<<00ongX<;o^jC1ok^T`@03ok^T`@04oknW`_o1Z<3o`JS0ol6X`0?oa:_10_o6[;l3
olN_`P;obK3000?ob[?3olbc`_o</l800_o</l85oljga004om2h`oo>^lSoc[_8oljkb0;ockc700?o
c;k=oljoc?l000000_l00004ol_1d@05olc2dOo6`mKoa/?FolK3e_o7`mH00oo1`m/3ol;4f`?o_<?O
1?ng`^84ok?1i0;o/;oV0on``>H3ojfoi`Co[;kW0on[_^L4ojZnj003o`000?nZ_NSoZ[gX01OoZKgX
00?o0000ooooooooool09oooool00ol0003oooooooooo`0;ooooob3oZKgX1OnX_NP2ojNlj0CoY[cY
0_nT^nT00onS^n[oWkW[oinij`02oinij`?oV[K[0_nB/N`01?n?/>goPZW]oh:YkOn2ZNd2og6Nk@?o
G8oY0_m@QND2ocadgP05oca_f_l0003o0000o`000?leIM@00_m4J]<2ode[d0;oHgG?1?mcNld3ohB3
bP?oU8c71?nSTlD01?n_Vl;o/Ic2ok6L`_naW<84okbR_`GoaZZm1?o?/K/01?oC];_oe[RkomJh^ooF
^;/2omVj^P04om^n_?l0003og/6komk1^`;ohL>k00Coh<Jnon;8__oRb;koh/Rn0_oTbkh3on??a0;o
i=7400CoiMC5omoCc?oOdlcogm?<0_oOeLd01OoOelkooooooooooooooooo000001gooooo000>oooo
o`03o`000?oooooooooo00Kooooo0omdW>X2ofbDi`?oLI?T0_m`S^02og><g0?oNH_H0_n2S=@3ohb?
d@?oUY;=1?nOU/X00onWV/SoZ9S6ojRHaP04ojnLa004okFP`ongX<;o]j32okNP`PCo^jC11Oo1Z<00
0oo4Zl7oaZboolJ/_`02olJ/_`04olN_`_o9/<3obK30olV``0Goc;?200Coc[C1oljga?o>]lCoc[O4
0oo@^<<00oo>^lSockc7olnla`03o`0000;oc[o<0_o?`<`2ol_1d@?oc<;A00Goa/?FolO3e_o7`mKo
al?Fol73f`03ol;4f`03ol?4fonl`moo_<?O00;o_<?O1?ng`^84ok?1i0Co/<3V1?n]_nL3ojbni`Co
ZkkW0onZ_^P01?nZ_NSo0000ojZmj?nZ_NPFojVmj003ooooool0003ooooo02Oooooo00?o0000oooo
ooooool03?oooolPojVmj0?oZ;gX1?nW_>P4ojJlj@?oXk_Z0_nO^N/2oijhj`CoV;G/0_n?/>d3oh:Y
k@;oLIk]0omLSnT01?m4O^?o0000o`000?l00002obeUeP;o=FGD0_lhH]02ode[d0?oG73>0omcNld3
ohB3bPCoU8c70_nSTlD00onTU<Co/Ic2ok6L`P02ok6L`P?o_::o0_nnY;h4olJZ_@?ock6k0ooC];/0
1ooF^;_ofKZjomVj^_oI^[[ogKfiomk1^ol000000ooQ`k/00ooSa[[oh/Rnon;8_P03onC;_P03onK>
__oSclCoi=7400;oi=740_oUe<D00ooOdlcogmG=omoEc@02omoGcPCooooo00?o0000ooooooooool0
6_ooool000kooooo00?o0000ooooooooool01oooool3ogBLjP;oK9CW0_mVSN<2ofJ7g`?oLhcL0omi
RmP2oh:<e0?oS8oA0onFT/d2oinFbP03oinDbOnXV<KoZ9S600;oZ9S60_n_W<@00on`W<?o]j32okNP
`P02okNP`P?o^jC10_nmY;l4ol6X`0GoaZbo1?o9/<001?o</;ooc;?2olbc`_o</l83oljd`@03oljg
a?o@^<?od;S300;od;S30ol00003om6maP05oljoc?o?`<cocl3<olo0c?o;`M401?o<`]43olO3eP?o
b<CF00Co`/CKol?4foo3a=_o`lCK0_nl`ml2okg4g`;o]l;R0_ng`^<4ok?1i0Co/<3V0on]_nL4ojbn
i`?oZkkW1?nZ_^P00onZ_NSo0000ojZmj002ojZmj1GoZKgX00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0=ooooob7oZKgX0_nX_NP5ojNlj0?oY[cY00?oXk_Zoj>jj_nS^^X01?nN^>/2oiRe
k004oiJdk?n<[ngoS:o]ohb_k@?oOJO^0_mZVnd3o`0000;oA7kS0_l^Jm/01?l]IMKo9ec@obMLd?le
IM@2ocQRd0;oCF_@0_mLL<h3ofihc0CoQ8?:0_nDS<L00onDRlOoY9C4ojBDa002ojBDa0Co/Ic200Co
_::ookjT__nnY;ko_ZBn0oo6Z[d2olZ/_003olna^ooC];_odkBk00;odkBk1?oI^[X2omfm^@04omk1
^ol0003ohL>kon73^`;ohlJj00?oh/RnonC;__oTbkh00_oVc[h00ooXdKkoi=74onCAa003onGDa@03
onKFa_oOeLgogmO>00;ogmO>00GogmS@ooooooooooooooooo`00000Looooo`003_ooool00ol0003o
ooooooooo`08ooooo`?oM9cZ0_m/U>L2ofJ=h`04ofJ7gomZQM_oJXGKofZ5f`?oLXGG0_mmR=<3ohV;
c`?oU93<0onOU<T4ojRHaP04ojnLa?n`W<?o/9c3ok2L``Co]j3200Co^jC1okfT_onmY;oo_JBo0oo1
Z<02ol>X_P?oaZbo0_o8[;h2olV``0?oc;2o00?oc;?2oljd`Oo>]<400_o>]<42om2h``?o000000?o
d[[2olnlaooA_LH00ooA_LH4olo0c004om72boo<`]7oc<;Aolc2d@;ocLCA00?oal?FolS4e_o8a=H0
0_o8a=H3ol?4f`;o`lGL0onma=l00onma>3o]l;SokO2h`02okO2h`;o/l7T0_nc`ND2ok30iP03ojo0
i_n]_nOo[KoW00;o[KoW1?n/_^L3oj^ni`CoZ[kX00Co0000ojZmj?nZ_NSoZ[gX5OnY_NP00ooooooo
0000ooooo`0Vooooo`03o`000?oooooooooo00gooooo8OnY_NP4ojRmj0;oYkcX0_nW_>T3ojFlj@?o
Xk[Z0_nN^>/00onM^>_oU[C/oiJdk002oiJdk0?oS:o]00GoOJO^o`000?l0003o0000ofZKk@02oe::
j0?o>7OQ00?o;V_KoaiLd_lNG=800_lWG=02ocQRd0?o@fC>0_mLL<h2ofihc0CoPX;:0onDRlL4ojBD
a0?o/Ic200?o/ig1okjT__nnY;h00onnY;h01Oo6Z[gobZblolZ/_?o:[;cock6k00CodkBk00?oe[Nj
omVj^_oI^[X00ooM_KT00ooQ`k_o0000on73^`03on?6^P;oi<^n0ooVc[h2onSA_P05onCAa?oUe<Go
iMC5onGDaOoVe/H00ooOelh2omoHd0Cooooo00?o0000ooooooooool06Oooool000gooooo00?o0000
ooooooooool02_ooool3ofZGjP05of6=i_mJQN;oFXGRoeZ5h_mVQml00omZQM/2og:5e`?oOHSC0on9
Rll3oiB@c0?oWiC90_nXV<H00onXUlGo/9c3ok2L``02ok2L``?o]j3200?o^:30okfT_onmY;l00onm
Y;l00oo1Z<3o`jRnol>X_P02ol>X_P05olJ/_oo8[;kob:bnolR/__o9/<001?o</;l4oljd`@?o0000
0_o@^<<2om:j`PGodKg600?odko6olo0c?o?`<`00ooA`//00oo<`]7ocLCAolg4d@02olk5d@?ob<CF
0_o9aML00oo3a=_o`lGLol?5g002ol?5g004okg4gonma>3o_LCPokg4h0;o]l;S00?o]l?Sok?1iOnc
`ND00_nc`ND4ojo0iPCo[KoW1?n/_^L01?n[_^OoZkkXoj^nj?n[_^P3ojZnj004o`000?nZ_NSoZ[gX
ojZmj1GoZKgX00?o0000ooooooooool09?ooool00ol0003oooooooooo`0?ooooob7oZKgX1?nX_NP4
ojNlj@03ojFljOnU^nWoYK_Y00CoX[[Z0_nM^>/2oiJdk0;oU;C]0ol00002ogVUkP?oHiO/0_mBR^P2
ocQgh@;o7f;G0_lNG=801?lWG=3o:UW=obYIcOlhH]02od=TcP;oE6_=0om^N<`3oh:2bPCoU8_71?nT
U<@00onaW<;o/ig1ok>M`@04okjT_P03ol6V__o:[;cobZbl00;obZbl1?oC];/2omJg^P03omVj^_oM
_KWogKfi00;ogKfi00?oh<6ion73^ol000000ooSa[X01?oVbK[oi<^nonK>__oVc[h3onSA_P?oiMC5
0_oVe/H01?oVf<OogmO>omoHd?oOf=02omkJdP?ooooo00?o0000ooooooooool06Oooool000gooooo
00?o0000ooooooooool02oooool3ofZGjP03of6=i_mJQN;oFXGR00;oFX3M0omZQM/2og:5e`;oOHSC
0on9Rll3oiB@c0?oWiC900CoZ9S6ojRGaOnXUlGoZ9O51?n`W<<01?ngX<;o^:30okRP`?nhX<04okfT
_`Go`jRn1?o8[;h5olb`_`04olja_Oo>]<7o0000o`0000?odKJo00God;S3om:j`_oB^/;od[[2omBk
`P03om6maP;odko600?ocl3<om72booA`//00_oA`//00ooB`l_ocLCAolk5d@03olk5d@05olS4e_o9
aMOobLGGolW5eoo9a]L00oo3aM`01Oo3a]co_LCPokg4h?nma>3o_LGP00Co]l?S1?nc`ND4ojo0iPCo
[KoW1?n/_^L3oj^nj0CoZ[kX00?o0000ojZmj?nZ_NP05_nY_NP00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo013ooooo8OnY_NP4ojRmj0?oYkcY1?nU^nT2oj:jjP05oj6jj_nL^>coW;S/oibh
k?nD]>d00_l000001?nD]>goRJk^ohV^k_n9[^h2ogVUkP;oHiO/0_m8QNL3ocQgh@;o7f;G00?o7UcB
oaMBc?lGD/`00_lZFLd2od=TcP?oE6_=0_m^N<`4oh:2bP?oU8_70onTU<@00onVULCo/ig1ok>M`@02
ok>M`@;o_ZBn0_o1Y[h4olZ/_003olf__?oC];_odkBk00?oe[Nj1?oM_KT2on31^@04on73^ooSa[[o
0000on?6^P;oi/Vj0_oVc[h4onSA_P04on[D_ooUe<Goi]K6onKFaP;oi]S700?oi]_9omoHd?oNf]80
0_oNf]82omgKe0;ooooo00?o0000ooooooooool06?ooool000gooooo00?o0000ooooooooool03?oo
ool2oenAj@;oDhKU0_mJQN801?mJP=goGgkJoemnf_mOO]X2ofYoeP?oOHSC0on9Rll3oiB@c003oinD
bOnNT/OoZ9O500?oZ9O50on`W<<00onaVl7o^:30okRP`002okRP`0?o_JBo0_noY;h3ol>X_P;oaJVm
0_o8[;h2olZ]_@?oc;2o0ol000000oo>]<7odKJoom6f_`02om6f_`?od[[20ooD^l801OoA_LKodko6
om>oa_oC_lKoeL3600?odL;;0_oB`l/01OoDaL_oc/GAolk5dOo>aM7oclKA00?obLGG0oo9a]L01Oo3
aMco`lKLol?6g?o3a]co_LCP00?o_LGP1Ong`n<00onc`NGo//7Uok;1i@04ojo0iPCo[KoW0on/_^L4
oj^nj0?oZ[kX00CoZ[gXo`000?nZ_NSoZ[gX5_nY_NP00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo017ooooo8OnY_NP4ojRmj0?oYkcY0_nU^nT2ojBkj@?oXK[Z0ol00002oiBdk@04oi:ckOn6
[NkoQZg^ohJ]kP?oM:?_0_mLU>`2odR5i`;o:foN0_lOH]L2o`iBc@;o5e;<00Co:UW=ocMMc?lgGLco
@fC>0_mDJld3ofYec0?oPX;:0onDRlL01?nTU<CoYYG4ojJEa?nVUL@4ok>M`@03okjT__o1Y[ko`JJn
00;o`JJn0_o:[;`3olf__005om>d^ooF]k[oe[NjomJg^_oJ^[T00_oM_KT3on31^@04on?4^?oSa[[o
hlJjo`0000;oi/Vj00?oj<fjonK>__oXdKh00_oXdKh2on[D_`03on_G_ooVe/Koi]S700;oi]S700?o
i]_9onKMbooNf]800_oNf]82omgKe0?ooooo00?o0000ooooooooool05oooool000gooooo00?o0000
ooooooooool03Oooool2oenAj@05oe>6iOm=ON3oCGgPodemh?mJP=d00omOO]X01?mZOmKoMh?BogN3
d_mgPm83ohF8cP?oTXg;0onNT/L4ojRGa@04ok2L`onaVl7o/I_1ok6K`@Co^:3000?o_JBooknT__no
Y;h00_noY;h01Oo3Z;koaJVmolFY_Oo5ZKgob:bn00?obZfm0ol00003olja_@GodKJo00?odkNnom:j
`_oD^l800ooD^l83om>oaP?oeL3600CodL;;om;3booB`l_od/?;0_oDaL/01Oo>aM7oclKAolo6dOo?
a]7obLGG00?obLKG00Gob/OHol?6g?o3a]co`lKLol?7g@03okg5h0;o_<GQ1?ng`n<4ok;1i@Co[l3V
0on]_nL4ojbni`?oZkkX1?nZ_^P00ol0003oZ[gXojZmj00FojVmj003o`000?oooooooooo02;ooooo
00?o0000ooooooooool04_oooolOojVmj0KoZ;gX00?oYkcYojJljOnV_>T00onT^nT3o`000003oj6j
jonK]ncoVkO/00;oVkO/0_nB/nd3ohJ]kP?oM:?_0_mLU>`2ocioiP;o:foN00Oo45WBoamReol>D/go
3U;=oaMBc?lLD<Wo:UW=00;o=eg<0_mDJld3ofYec0?oP87:0onDS<L5ojJEa0;o/ig100?o]Yo1ol6V
__o1Y[h00oo1Y[h00oo:[;cocJnlolf__002olf__0?oe[Nj0ooJ^[T01?oM_KWoh<6ion31^OoP`KT2
on?4^003on?6^_l0003oi/Vj00;oj<fj00?ojm2jonSA__oXdKh00ooZe;l01?o[ekooi]S7onKHaooV
f<L2onKKb@;oi]g;00?og][BomgKe?oMfm@00_oLg=H2ooooo`03o`000?oooooooooo01Oooooo000=
ooooo`03o`000?oooooooooo00gooooo0_mBRNP2oe>6i@;oCGgP0_m=Mm/2oemnfP;oJWoF0omgPm83
ohF8cP;oTXg;0onNT/L3ojRGa@03ojRGa?naVl7o/I_100;o/I_10onhX<000onjX;ko_jBnoknT_P03
oknT_PCoaJVm00GobZfmo`000?l0003o0000olZ]_@05olja_@04om2c_?oA][oodKJoom6f_`;odkNn
1OoD^l800ooF_L7odko6omG0aP03omG0aP03omO2aOoB`l_od/?;00?oe<G;00CoeLK<olo6dOo?a]7o
clKA0_o@am801Oo9a]Oob/OHol[7f?o:amSo`lKL00?o`lOM00?o_LGPokc5hOnlaN400_nlaN44okO3
h`?o//7U1?n_`>H4ojfoi`;o[;kW00?oZkkWoj^nj?n[_^P00_n[_^P4ojZnj003o`000?nZ_NSoZ[gX
01KoZKgX00?o0000ooooooooool08Oooool00ol0003oooooooooo`0CoooooagoZKgX1onX_NP3ojJl
j@?o000000?oY;_Zoj6jjonQ^^/00_nQ^^/2oi^gk004oiZgk?nA/^koTK;^oi6bkP?oPjc_0om_XNl2
oeB@k0;o?WoV0_lMIm/01_l@FM;o3U;=o`iBcOl7B<Oo5e;<oaa@b@;o=eg<0_m<I/`01?mDJlgoJWG<
ofYec?mZML`3oh21bP?oU8c71?nVUL@01?ncWL7o]Yo1okJO`OnfWl44ol6V_PGocJnl00?odK:komJg
^_oJ^[T00ooJ^[T3on31^@?ohlBh0_oVbKX00ol0003oj<fjonS=^P02on_@^P03onSA__oZe;ooj]Bo
00;ojmNo00Cok=[1onKHaooVflWoi]_90ooVgL/01?oVg/gogM_DomcLe_oLg=H2om[Lf0;ooooo00?o
0000ooooooooool05_ooool000gooooo00?o0000ooooooooool03_ooool2oe:9j0;oA7gR0_m=ON00
1?m=Mm_oDgKHoe=ff?mCM]P2ofYoeP;oMh?B0on5R<h3oi:=b`?oWY;700CoZ9O5ojRGa?nXUlCoZ9O4
1?naVl401?nhX<3o^Z2nokZP__njX;h3oknT_P03ol6U_Oo5ZKgoaJVm00?o00001?o:[Kd01?o=[[_o
c[6molja_Oo>/Kd3om2c_005om6f_ooC]kkodkNnom>g__oE^Kh00ooD^l82omJm`@04omRn`OoE`<Ko
eL36omG0aP?oel;500?od/?;omC5booDaL/00ooEa/`01?o?a]7od<OBom37d_o@am83ol[7f0?ob/SH
1?o3amd4okc5h@;o]l?S00?o]l?Tok;1iOnb`ND00_nb`ND4ojo0iPCo[KoW0on[_^L4oj^nj0CoZ[kX
00Co0000ojZmj?nZ_NSoZ[gX5OnY_NP00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Go
oooo7?nY_NP6ojRmj0?o00000_nV_>T3ojBkjP;oXK[[0_nP^N/3oiZgk0?oTK;^0on3[>l3ofnQk`05
oeB@k?lcN^Co<g[Toc=ji?lMIm/00_l0Cld00ol0AlOo3U;=o`M8a`02oaa@b@;o=eg<0_m<I/`3ofYe
c0?oP87:0onDS<L3ojJEa003ojNGaOnfWl7o]Yo100;o]Yo10oo1Y[h2olFY_P?ocJnl0_oA/[/00ooF
]k[of[ZiomZj^@02omZj^@03omfm^OoP`KWoh<6i00?ohlBh00Coi/NhonK9^_oXcK[o00000oo[d;X0
1?o]dk[oj]Boon_G_oo[ekl2oncJ`@;ok=c200?oi]_9onKMbooVgL/00_oVg/d00ooTh<oog=cFom[L
f002om[Lf004omSLf_ooooooooooo`0001Oooooo000<ooooo`03o`000?oooooooooo013ooooo0_mB
RNP2odAmhP03ocacgOm=Mm_oCGOK00;oDgKH0_mPNM@3og1nd@?oQHS>0_nBSL/2oijBa`03oifAa_nX
UlCoZ9O400;oZ9O40onaVl400onbVl3o^Z2nokZP_P03okZP_P03oknT__o1YKgo000000;o000000?o
aJVmolRZ_?o8Z[`00oo:[Kd3olf^^`03olja_Oo@/kcod;>l00;od;>l0ooC]kh3omFi_P04omBk`_oF
_L7oe[g1omJm`@;of;k100?oeL36omO2aOoG`/D00_oG`/D00ooHa<Koe<G;omG6c003omG6c0?od<OB
0_oAbM800oo:amSob/SHol[8f002ol[8f0?o`lOM00Co`lSNokc5hOnlaN7o_<GQ0_nla^83okO3i0;o
//7U0onb`NH00on_`>Ko[l3Wojo0i`04ojfoi`?oZkkW1?n[_^P4ojZnj003o`000?nZ_NSoZ[gX01Go
ZKgX00?o0000ooooooooool07oooool00ol0003oooooooooo`0GoooooagoZKgX00CoZ;gXo`000?l0
003o00000onX_NP3ojJlj@CoY;_Z0onP^N/00onJ]ncoVKO]oiVgk@03ohnbkP;oP:__0om[Wnl2odf=
j`;o<g[T00Go45oGoaeWfol0Clgo04o=o`17a`02o`M8a`03oaa@bOl[E/Wo:eK900;oC6K<0omULl`0
1?mZMLcoP87:oh21b_n0PLX3oiB<a`04ojJEa?nWUlGoYiO5ojNGa@Co]Yo100?o`JJnolFY__o5ZKh0
0_o5ZKh01?o=[kcodK:kom6b^ooA/[/4omZj^@?ogKfi00?oh<6ion?4^?oSa;P00_oVakP01?oYbkSo
j<fjonS=^_l00002on_@^P03ongC^_o[ekoojmNo00?ok=[10_o/g<801?o]glCoi]g;onKNcOoVg/d2
onCPc`?of]cH0_oHg=X2ooooo`03o`000?oooooooooo01Gooooo000<ooooo`03o`000?oooooooooo
017ooooo00CoA8;Voc=cgolcLmoo<g?O0olmKMP2oe=ff0;oH7WD0_m`O]43oh64cP;oT8_:1?nMTLH4
ojRGa004ok6K`OnbVl3o/Y_0ok:K`0?o^Z2n0ol00002ol6U_@03olFY_Oo8Z[cob:Zl00;ob:Zl00?o
bZfmolf^^oo=[[/00_o=[[/5om2c_003om>d_?oC]kkoeKVn00?oeKVn00?oek^momJm`OoF_L400ooH
_/401?oJ`L7oel;5omO2aOoG`/D2omS4aP04om[6a_oEa/coeLK<omG6c0;oe/S<00God<OBom79d_oA
bM;odLWBom7:d`03ol[8f0;ob/WI00Go`lOMol?8g_o3b=ko`lSNokc5h@04okc6hP04okO3i?nf`nCo
]/?TokK3i0;o//7V00?o/L7Vojo0ion_`>L00_n_`>L3ojfoi`CoZkkW1?n[_^P2ojZnj003ojZmj?l0
003oZ[gX00;oZ[gX5OnY_NP00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Sooooo6_nY
_NP3o`0000GoZ;gX0_nW_NT3ojJlj@;oY;_Z0_nS^nX2oinij`CoVKO]0on?/^h2oh2[k`?oJio_0_m=
SN/2obUdhP06oa1Oeol0Clgo04o=o`0l`Ol0?L7o1dS70_l<AlD2ob]Fb@;oC6K<0omULl`3ogj0b`?o
U8c81?nWUlD3okJO`@03okVR`Oo5ZKkoaJVn00?oaJVn1?oA/[/00ooD][_of[ZiomZj^@04omfm^@;o
hlBh0ooVakP2onW;^003onS=^_l0003ojm2j00;okM>j00Cok]Nkon_G_oo/f/7ok=[10oo/g<800oo]
glCok>;6onKNc@03onCPc`04on?Qd_oJg=Sof=cJomSLfP;oe]cL0_ooool00ol0003oooooooooo`0D
ooooo`003?ooool00ol0003oooooooooo`0Booooo`04odB2i_lcLmoo<g?OobYWf@;o?FgH0_m6KMD2
of1ie0?oL7kA0_n1Q<h3oi2;bP?oWI760onXUl@00onYU/?o/Y_0ok:K`002ok:K`0?o000000?o_:6m
ol6U_Oo1YKd00_o1YKd5olRZ_0GocJjk00Cock2kom2c_?o@/kcod;>l0_oC];`5omFi_P;oek^m00Co
e[g1omRn`OoH_/7of;k10_oJ`L401?oG`/Gof<C6omS4a_oHa<H2om[6aP05omG6c?oFb<coe/S<omK8
c?oGbLd00ooAbM82om7:d`03ol[8f?o:bMWob/WI00;ob/[J0oo3b=h01Oo2b=oo_<KRokc6h_nla^;o
^lKR00?o]/?T00?o]/?Uok71i_na`NH00_na`NH2ojo0i`03ojk0ion]_nOo[KoW00;o[KoW1?n[_^L2
oj^nj003ojZnj?nZ_NSoZ[gX00;oZ[gX00?o0000ojZmj?nZ_NP05_nY_NP00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01Wooooo5_nY_NP3o`0000CoZKgX0onX_NP4ojNmj@?oY[cY1?nS^nX2
oinij`;oVKO]0_nH]^d2ohfak`?oOJW`0omVWNl2odJ:j`;o:GCR00Ko0USBo`15aol0Clgo03c1o`0m
`Ol7B<L2o`a7a@03ob]FbOm3H/co@f;<00?oIG?<1?mnP</3oiB<b0CoYiO500Co]Yo1okVR`OniX/7o
^J;11?o5ZKh00oo8[KkodK:kom6b^`03omBf^`03omZj^OoM_KWogKfi00;ogKfi00CohL6hon?4^?oV
akSoi/Nh0ooYbkP2on_@^P04o`000?o]dk[ok]NkonkG^`;ol=Zk00?ok=[1oncL`_o/g<800_o]gl@0
1?o/h/Koi>3?onCPcooTh<l2on?QdP04on7Re?oHg=[oe]cLomKLg0;odmcO0_ooool00ol0003ooooo
ooooo`0Cooooo`003?ooool00ol0003oooooooooo`0Cooooo`04ocAhholcLmoo<g?OobYWf@;o?FgH
00CoAVgEoeIbdomFL]?oEW;C0_m`O]43oh64cP;oT8_:1?nMTLH01OnXUlCoZIK3ojVF`onYU/?o/Y_0
00;o000000?o/Y_0okZP__nlXKd00_nlXKd2ol6U_@;o`jJl0oo8Z[`2olZ[^`?ocJjk0oo?/;/01Oo@
/kcodkBlom>d_?oC];coeKJk00?oeKVn0ooG^kd3omRn`@?of/710ooHa<H3om[6aP?oe/S<0ooGbLd0
0ooAbM;odL[Com7:d`02om7;e003ol[9fOo:b][ob/[J00;ob/[J00Go`lSNol;8goo2b=oo`/SOokc6
hP03ok_6hP04okK3i?nf`nGo]/?UokK3i@?o/L7V1?n^`>L2ojfoi`;o[;oW0_n[_^L00on[_^SoZ[kX
ojZnj002ojZnj0CoZ[gX00?o0000ojZmj?nZ_NP05OnY_NP00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01[ooooo4onY_NP2o`0000OoZKgX1?nX_NP2ojNmj@03ojNljOnV_>WoY[cY00;oY[cY
0onS^nX4oijij`?oV;K]0_n=/Nl3ogfYl0?oIYg_00KoAX[[oam_golOKmoo7foOo`9Hd_l0ALL2o`0l
`@03o`0m`Ol<AlGo34O500;o7Tk70_m3H/`3ofEcc0?oOX3;0onDS<P3ojNGa@03ojVIaOniX/7o^J;1
00;o^J;10oo5ZKh2olR]_P03om6b^ooD][_oe;Jk00;oe;Jk1?oM_KT2on71^0;oi/Nh1?oYbkP01?o/
ckSojm2jongC^_l00002onkG^`;ol=Zk00Col=jloncL`_o]glCokMo40_o/h/H01?o[i<Soi>3?on?Q
d_oShM82on7Re005omkSeooFg=codmcOom?Lgoo@fn400_ooool00ol0003oooooooooo`0Cooooo`00
3?ooool00ol0003oooooooooo`0Dooooo`04ocAhholPIm[o86OJobYWf@;o:f;D00?oAVgEoeIbdomF
L]<00omYNM02oh64cP?oT8_:0_nMTLH00onMT<KoZIK3ojVF``03o`0000;o/Y_000?o]9bookbQ_Onl
XKd00_nlXKd00oo1YKgo`jJlol>V_002ol>V_003olRZ_?o:Zk_obZ^k00;obZ^k00?ocJjkoln`^oo?
/;/00_o?/;/3om>d_0?oeKJk00?oeKVnomNk_OoG^kd00_oG^kd00ooI_Kgof;k1om[1`@03om[1`@03
om_3`OoHa<Kof/K600?of/K600?oflS6omK8c?oGbLd00ooGbLd00ooGblkodL[Com7;e002om7;e004
om7=eOo:b][ob/[Jol[:fP;obL_K0_o2b=l2ol;8h0;o^lKR0_nja^<2okK3i@03okG3iOna`NKo/L7V
00;o/L7V1?n^`>L3ojboi`CoZkkX0onZ_^P5ojZmj003o`000?nZ_NSoZKgX01GoZKgX00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Looooo`koZKgX0ol0000:ojVmj0CoZ;gX0onW_>T2ojJl
j@03ojFljOnS^n[oXk_Z00;oXk_Z0_nN^N/01?nN^NcoUkK]oiNfkOnG]^d4ohbak`?oNjW`00?oHY_`
od27j_m0QnX00_lOKml2o`1@cP03o`0l`?l0?<7o03:j00;o03g000Co34O5oai>aolNC/Oo@f;<0omO
LLd4ogj0b`?oU8c800CoYiO5ojVIaOnYVLGoZIW51?niX/401?o5ZKkob:fnolR]__o8[Kh5omBf^`03
omRj^ooM_KWogKfi00?ohL6h00?oi<FhonK7^?oYbkP00_oYbkP2onc?^004onkC^?o]dk[ok]Nko`00
00?ol=Zk00?ol=jloo7Q__o]gl@00_o/h/H2on_Tb004on[VbooShM;ohN;Don7Re0;og^?G00?og>;J
om?Lgoo@fn400_o@fn42ooooo`03o`000?oooooooooo01;ooooo000<ooooo`03o`000?oooooooooo
01Cooooo0_lRK]h01?lPIm[o5U_CoaIKdol[H]@2ocITdP;oEW;C0_mYNM02ogb1c@?oSXW90_nMT<H3
o`0000?oZIK300?o/Y_0okBL_ondW;l01?nlXKd5ol>V_0GobZ^k1Oo?/;/00ooA/[[odkBlomFf^`03
omFf^`04omNi^_oG^kgoek^momNk_@;ofKfm00Cofknmom[1`OoJ`L7of/710_oK`l401?oMaL7of/K6
om[6a_oJa/H2om_8aP04omc:aooGbLgoelW=omO9c@;oel_>00Cof<g?om7;e?oAbmCodL_D0_oAcMD0
1?o:b][obL_KolW;foo8c=`3ol;8h004ol79hOnja^?o^/KSok[6h`;o^/KT0one`nD5ok71iP?o[/3W
0on/_nL4oj^nj0?oZ[kX1?nZ_NP00ol0003oZ[gXojZmj00EojVmj003o`000?oooooooooo01cooooo
00?o0000ooooooooool07?ooool;ojVmj0?o00003onY_NP3ojRmj0CoYkcY0_nU_>T2oj>kjP;oX[_Z
0onN^N`3oiNfk@;oS;7_00CoR[7_ogVXlOmiZ?7oNJSa0_mNV_02od27jP;o5F_M0_l0D<h00ol0?<3o
03c1o`0b^P02o`0m`0;o7Tk70_liGL/2oemac@CoO83<0onES/T4ojVIa@?o^J;100?o_:G2olR]__o8
[Kh00_o8[Kh01?o</;koe;JkomBf^ooD][/3omRj^`03omfm^OoQ`KSohL6h00;oi<Fh00?oilZhonW;
^?oYbkP00oo/ckP01?o^dkSol=NhonkG^ol00002oo3J^`;ol=jl00?olN6noo7T_oo/h/H00_o[i<P2
on[Vb`03onSWc_oQh]Cog^?G00;og^?G00Cog>;Jom3KhOo@fn7od=_Q0_o=f^<00ooooooo0000oooo
o`0Cooooo`003?ooool00ol0003oooooooooo`0Eooooo`07ob9^g_l;F]Co86OJoaIKdolGE/oo:f;D
ocITdP02odUZd@?oJGW@0_mlPLd01?n>RLWo0000o`000?l00002oif@aP?oZIK300?oZYO2okBL_ond
W;l00_ndW;l2okbQ_@;o_Z:m1?o3Y[`00oo6Yk_obZ^kolZ[^`02olZ[^`04olb]^_o?/;_ock2koln`
^`;odK:j00?odkBlomFf^ooE][/00_oE][/2omNi^P04omNk_OoI_KgofKfmomVm_@;ofknm00Cof/71
om_3`OoK`l7ofl?10_oMaL401?oJa/KoflS6om_8a_oKb<H2omc:a`03omO9cOoGblkoel_>00?of<g?
00?odL_Dom7=eOoAcMD00_o@c]L01Oo9bm_ob<cLolS<g?o8c=co`/SP00?o`LWQ00?o^/KSok[6i?nj
a^@00_nja^@01?ne`nGo]<?UokC3iOnd`nD2ok71iP03ok31i_n^`>Oo[/3W00;o[/3W0on/_nL4oj^n
j0CoZ[kX0onZ_NP00ol0003oZKgXojVmj00EojVmj003o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07Oooool7ojVmj0?o00004onY_NP3ojRmj0?oYkcY1?nU_>T3oj:kjP03oijik?nM^NcoWKW/
00CoU[K^0_n:/Nl3ogVXl@;oGY[`0_ljQ>T2oaE[g@03o`19b?l0?<3o02Na00;o03:j00?o03g0o`m7
a?lNC/L00oliGL/2oemac@?oO83<0onES/T5ojVIa@04okVR`OnlYL;o_:G2okbU`P;ob:fn0_o</;h2
omBf^`Cof;Zk0_oQ`KP3onC5^0;oilZh00?ojL^honc?^?o/ckP00_o^dkP2oo3G^004onkG^ol0003o
l=jloo3N_0;olN6n00?olNBooo3W`_o[i<P00ooZi//01?oXilkoi^SAonKXdOoNhmL2omcRfP03omWR
gOo@fn7ocM[S00;ocM[S00?ob]STooooool000004oooool000_ooooo00?o0000ooooooooool05_oo
ool2o`iRf@04o`]Je?lFFm?o5U_CoaMFc`;o=VCB0_m9J]42ofUid0?o00000_n>RLT4oif@aP03ojVF
`onZUl;oZYO200Co]9bo00Co_:6mokjR_OnnX[go_Z:m0oo3Y[`2olJW^`?obZ^k0oo<[KX01Oo?/;_o
dK:jom6b^_oA/[[oe;Bi00?oeKJk0ooG^KX3omVm_@?ofknm0ooK`l43omg5`@?oflS60ooLb/L00ooM
c<Soel_>omS=c`03omS=c`03omS?d?oAcMGod<kG00;od<kG00Cod<oHolS<g?o8c=cob<cL0_o7c=d0
1?o1bN7o_lWQoko9hOnobN42ok[6i005okW6i?nd`nGo]<?UokC3iOnc`nH01?n``NH2ojk0i`03ojg0
ion/_nOo[;oW00;o[;oW1?n[_^P3ojZnj0CoZ[gX00?o0000ojVmj?nY_NP05OnY_NP00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01oooooo0onY_NP3o`0001OoZKgX0onX_NP3ojNlj@CoYKcY
0onR^n/3oifik0;oU[K^00CoUKK^ohVal?n9/O3oRK7`0omgZ?42oe^Il0;o>XCY0_l=I]/02?l0BLSo
03c0o`0W/Ol0<[[o03>jo`0m`?l?AlCo7Tk70_liGL/2oeY_cPCoO83<0onES/T3ojVIa@03ojbLaonl
YL;o_:G200;o_:G200?ob:fnolb`__o</;h00_o</;h00ooD][_of;ZkomRj^`02omRj^`04ombn^ooQ
`KSoi<FhonC5^0?oilZh0_o/ckP2onkC^0?ol=Nh00?ol]^hoo3J^ol000000_oahKh2oo7T_`04oo3W
`_o_jLCoknW4on[Vb`;oj>O>0_oVj=401?oTjMGog>;JomWRgOoIh]d2omGQg`03olgJhoo:f>Cob]ST
00;ooooo00?o0000ooooooooool04?ooool000_ooooo00?o0000ooooooooool05oooool2o`iRf@03
o`]Je?l0CL_o04g;00;o95W>00CoBF[Ao`000?l0003o00000omhO/d3ohj9b@?oWI361?nZUl82okBL
_`03okJM_onnX[go_Z:m00?o_Z:m00?o`jJlolJW^oo6Yk/00_o6Yk/00oo:Zk_oc:fjolb]^P02olb]
^PCodK:j0_oD];T00ooE][_oekVjomNi^P02omNi^P03omZk^_oI_Kgofknm00?ofknm00?ogL:mom_3
`OoMaL400ooMaL400ooOal;oflS6omc:a`02omc:a`;ogLc800CogLk9omS=cooHcLoof<g?0_oHcm03
om3>e`?od<oH00Cob<cLolO<gOo7c=goa/cO0onobN400onnbN;o^LKTokW6i002okW6i004okC3iOnc
`nKo/l?Vok?3iP;o/<7V0_n``NL3ojg0i`Co[;oW0on[_^P4ojZnj0?oZ[gX00?oZKgXo`000?nY_NP0
5OnY_NP00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01oooooo0ol0000JojVmj0CoZ;gX
0onW_>T4ojFlj@?oX[_[0onM^N`3oiFfkP?oRK7`0omgZ?42oe^Il0;o=H?Y00?o3FKKo`13a?l0@l@0
0_l09k401?l0<[[o03>jo`m7a?l?Al@2ocUMb`?oFVo>0omlP<`3oiF>b@04ojVIaOn/W<Oo[9c7ojbL
a`Co_:G21Oo</;h4omRj^`;og;jk0ooTaKP3onO:^004on_>^?o/ckSok]>honkC^0?ol=Nh00Col]^h
oo?O^Oo`g[co00000_oai;l2oo3W`P;oknW400Cok^c7onSWc_oVj=7oi^SA0_oTjMD01?oQjMSofN;M
omGQgooEhMl2om;OhP05ol[Hi?o6e^Koa]KVooooool000004_ooool000_ooooo00?o0000oooooooo
ool06?ooool2o`iRf@03o`1<bol0CL_o000000;o00000_m9J]42of1dd0;oN7k=0on<R<T3oif@aPCo
ZYO200Co]9bookJM_onfWKoo]Yfo1?nnX[d5olJW^`Coc:fj0_o?[kT2om6b^P?oe;Bi1?oG^KX2omZk
^P04omVm_OoK_kgofknmom^o_@;ogL:m00CoglBmomg5`OoMaL7ogLG10_oOal82on3:`P04omc:aooM
c<SogLc8omg<b0;ogLk900?of<g?omS?d?oHcm000_oHd=801?o@c]Ood<oHom3?f?o@cmP2olo?fP05
olO<gOo6c=ooa/cOolK<gonobN400onnbN82okW6i0;o^<GU0onc`nH3ok31i`03ojo1ion]_nOo[KoW
00;o[KoW0_n/_nL00on/_^SoZkkXoj^nj002oj^nj0?oZ[kX1?nZ_NP00ol0003oZKgXojVmj00EojVm
j003o`000?oooooooooo01Sooooo00?o0000ooooooooool07?ooool3o`0000?ooooo6onY_NP3ojRm
j0CoYkcY0onU_>T4oj:kj`?oWKW/0onD]^h3ohRal0;oMJSb0omIVO02oc62j@05o`ESfOl0@lCo04?4
o`0W/Ol07:T00_l0<kX01?l?AlCo;US;obiHboliGL/2oeY_cP?oNX7>0onFT</5ojbLa`;o_:G20_o0
ZL<4olb`_P03om2e_ooH^[_of;Zk00?og;jk00?oh<>konC5^?oTaKP00_oWb[P2on_>^0?ok]>h0_o`
ekP2oo;K^003oo?O^Oodhk[o000000;olNBo00Ool>O2onoYa?o_jLCoknW4onk/aoo/kL_oi^SA00;o
i>WE0_oQjMP01?oMj=coeN7Oom;Oh_oBgn82olkMi005olKFi_o3e>Oo`mCWol?Diol000004Oooool0
00_ooooo00?o0000ooooooooool06Oooool3o`000003o`0m`Ol0AlOo95W>00;o>f;?0_mPM=03ogQn
c@;oS8S91?nMT<H2ojZG`P03oj^G`_nfWKoo]Yfo00;o]Yfo0onnX[d2ol2S_0?oaZNk0_o8ZKX2olb]
^P?ocjni00?odK:jomBd^OoD];T00_oD];T00ooG][WoekVjomNi^P03omZk^P03ombm^_oK_kgofknm
00?ogL:m0_oOa;d01?oMaL7oglO2omo7`_oOal82on3:`P?ogLc80ooMc/T00ooNd<_of<o@omS@dP02
omS@dP;oem7C00Cod<oHolo?f_o?cm[oc]3K0oo6c=l2olG<h0;o_/WR0_nmb><2okS5i@;o]lGU0onc
`nH01?n``NOo[l7Wojo1ion_`NL3ojfoi`Co[;kX1?n[_^P3ojZnj0CoZ[gX00?o0000ojVmj?nY_NP0
5OnY_NP00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo0ol00007oooooacoZKgX
0_nX_NP5ojNlj@;oYKcY0onR^n/4oifik0?oU;K^00?oR;7`ohRalOn8/O400_mdZ?83oeVIl0;o<H;Y
00Ko067Go`0n_ol08j[o02Nao`0LZOl0<kX2o`0n`@;o;US;0omJKlh3ogZ1cP?oUY3;1?n/W<L01?nl
YL;o`:W3ol2Y`oo0ZL<3olb`_P?od;Fo00?of;Zkombn^ooL_[/00ooP`k/3onO:^0;ojljh0_o^dkP2
oo3G^0;ol]^h0_ocgkT01Oodhk[om>Jko`000?oai;ool>O200;oknW40_o^k<L00oo/kL_ojNk?onCY
e@02on7Yf0;ogNSL00GofNOOom;Oh_o>gNCoc]gTol[KiP03ol?Di`;o`=;X00?o0000ooooooooool0
3_ooool000_ooooo00?o0000ooooooooool05_ooool3o`000003ooooool0E]7o03g000;o03g10_l?
C<T01?lkH/ooEfo?oeM_comGKll2ogQnc@?oS8S90onMT<H01?nZUl;oZiO2oj^G`_n[Ul84okJM_`03
okjR_Oo0Xkco`:>l00;o`:>l00GoaZNkolRY^_o8ZK[ob:Vjolb]^P04oln_^@Coe;Bi0ooG][T01?oG
^K[of[^jomZk^_oJ^kX2ombm^P03om^o_OoM`[gogL:m00?oglBm00?ohLNnomo7`_oOal800ooPb/80
0ooQcL?ogLc8omg>b@02omg>b@;og]3;00Cog];=omS@d_oHd=;of=3B0_oGdM<00ooFdmGocloJolk@
f`02olk@f`05olK<goo5c>3oaLcPolG<h?o3c>400onmb><00onlb>Co]lGUokO5i@02okO5i@04ok?3
i_nb`nKo//?Vok;3iP?o[l7W0on]_nL2ojbnj0CoZkkX1OnZ_^P3ojZmj003ojVmj?l0003oZKgX01Go
ZKgX00?o0000ooooooooool05oooool00ol0003oooooooooo`0Fooooo`?o00002ooooolKojVmj0Co
Z;gX0onW_>T4ojFljP;oX[_[0_nM^N`2oibik0?oU;K^0on8/O43ogBXlP07oeNIlOl^PNWo;X7Yobj1
jOl0HMOo03joo`0SZP02o`0LZ@04o`0c^_l0?/7o03k1obiHb`;oDfg@00CoFVo>ogZ1c_mjPLkoNX7>
0onFT</3ojbLa`03ojnPb?o0ZL?o`:W300?o`:W300?oc;2nom2e_oo@]Kl00_o@]Kl2ombn^`Coh<>k
0_oWb[P2on_>^0?ok]>h00?ol=Rhoo3G^?obfkP00_ocgkT2ooCS^P;om>Jk00?o0000oo3W`_o_jL@0
0_o^k<L2onc]b`03onW^cooVkm?ohNWH00;ogNSL00CofNOOomGUh_oEiN;oc]gT0oo:fnH01Oo3e>Oo
`=;Xol3Bj?nmd>So0000013ooooo000;ooooo`03o`000?oooooooooo01Cooooo0_l00005ooooo`04
o`19b?l0?L3o03g1o`0h_P;o3dc900?o>f;?oeM_comGKll00ombO<h2ohb8b@?oWI361?n[Ul83okJM
_`03okRN_oo0Xkco`:>l00?o`:>l1?o8ZKX5oln_^@03om6a^OoD];Woe;Bi00CoekJi0ooJ^kX3ombm
^P;ogL:m1?oOa;d2on77_P03omo7`_oPb/;oh<[200;ohLg30_oRclD00ooMc/Wog]3;omk@b`03omkB
c@03omS@d_oGdM?oem7C00;oe]?E00CoeM?Golk@foo>d=_oc]3K0_o<d=d01Oo5c>3o`lcQol?<hOo3
c>7o_LSS00?o_<ST0_ngaND2okK5iP;o//?V00?o/L;Wojo1ion_`NL00_n_`NL01?n]_nOo[;oWojbo
ion/_nL3oj^nj0KoZ[kX1?nZ_NP00onY_NSo0000ojVmj00DojVmj003o`000?oooooooooo01Oooooo
00?o0000ooooooooool05?ooool2o`0000oooooo6onY_NP3ojRmj0CoYkcY0onU_>X4oj:kj`?oW;W/
00?oU;K^oiBfkonD]^l00_n7/O43ogBXlP;oEY[a0_l^PNT01_l0GmKo03^ko`0k^ol08j[o01bYo`0X
/`;o03k100?o8U?:obiHbomCKM000_mCKM03ogZ1cP?oUY3;00Co[9c7ojnPb?n_X<So[j381?o0ZL<5
om2e_`03omFj_ooL_[_oh<>k00?oh<>k00Coi<RkonO:^?o[c[Sojljh0oo^dkP01?o`f;Sol]bhoo;K
^?ocgkT2ooCS^P?om>Jk00ColnZmo`000?oakl7ok^c70_o/kL/01_oYk/ooi^oConK_dooSkmOogNSL
omWWg`;oeNGR0_oAhn@2ol[KiP;oa]WW00Co`=;Xokg@j?nmd>So00004?ooool000[ooooo00?o0000
ooooooooool04_ooool3o`0000Sooooo00Ko04W8o`0]/ol0?L7o03Rno`m<bOl[FL`3oeM_c`;oLWc>
0_n:QlX4oif@aPCoZiO200Co]YfookRN_onhW[oo^9jo1?o0Xk`4olRY^P04ol^/^_o?[kWocjnioln_
^@?odK6i00?oe;BiomNf^OoG][T00_oG][T00ooI^KWof[^jombm^P03ombm^P03omk0^_oM`[goglBm
00;oglBm0ooQakh00ooSb[koh<[2on7=``02on7=``;oh/o500?ohm;6omk@booNd/d00ooNd/d01?oM
e<ooem7ComKCeOoFdmD3omGCe`03olk@foo<d=goc=3M00;ob]3N0_o3c>42ol;<hP;o_<ST0_njb>D2
okK5iP03okC4i_na`^Oo/L;W00;o/L;W0_n_`NL2ojk0i`;o[;oW00?o[;oXoj^nj?n[_^P00_n[_^P6
ojZnj0?oZ[gX00?oZKgXo`000?nY_NP03_nY_NP6ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool04_ooool3o`0001;ooooo6OnY_NP5ojRmj0CoYkcY0onU_>X3oj:kj`CoW;W]0onD]^l2
ohNal@?oM:Sb0omFV_401_l/P^Wo05oFo`0k^ol0>k_o00^Eo`0LZ@;o03Jl00?o03k1ob9Cb_mCKM00
0_mCKM03ogR2d@?oUi?>1?n_X<P3ol2Y``;oa:k40oo@]Kl2omFj_`Coh<>k0_oTb;/2on_>^0?ok]>h
0_o`f;P00oobg;Som>6hoo?O^@02ooCS^P;om>Jk0_ocj[d01Ol0003olNo1onobaOo/kL_ojNk?00;o
i^oC00GohnoGomo^fooOk]_ofngOomGUhP02om7Si004olgPi_o6fNOoa]WWolKIi`;o`mKX0_nmd>P0
0ol0003oooooooooo`0>ooooo`002_ooool00ol0003oooooooooo`0?ooooo`?o00003?ooool01_l0
?;go02fco`0h__l0?/7o3dc9ob]Ic0;oEfo?0_mbO<h3ohZ7bP?oWI360on[Ul800on/VL?o^9jookRN
_`02okRN_`?o`:>l0_o2YK`2olRY^P?objbj00?ocjniom6a^OoA/KT00_oA/KT4omNf^@;ofKVi1?oL
_KX2omk0^P03on73^ooOa;goglBm00CohLNn00CohlZnonC=_ooQcL?ohLg30ooRclD00ooSd/KohmC8
omkBc@02omkBc@;ogMC?00?ogMKAomKCeOoEdmL00_oEdmL2om?Df@04olc@gOo:d=kob]3NolS@h0?o
`/cR00Go`<cSok[8iOnjb>Go^/SUokW7i@04okC4iP;o/L;W0_n``^L3ojk0i`Co[;oX0on[_^P5ojZn
j0GoZ[gX00?oZKgXo`000?nY_NP02_nY_NP:ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool03oooool3o`0001Kooooo6?nY_NP7ojRmj0?oYkcY1?nU_>X2oj:kj`?oW;W]1?nD]^l3ohNa
l@;oM:Wc0_mGVo82obb3jP;o063E00?o01RMo`0;UOl07Z/00_l0=[`2ob9CbP?oDfg@0_mhP]44oiNC
cPCo[j3800?o`:W3olB^a?o4[/@00_o4[/@01Oo@]KooeKZoomFj_ooE^[oofKo000;oh<>k0ooTb;/0
1?oXcK_ojljhonkC^?o^dkP2oo3H^0;ol]bh00Gom>6hooGU^OoeiKWom>>jooCV^`02oo?Z_@08oo;]
_ooakl7o0000onobaOo]llSoj_C=onK_dooSkmL2omo^f`;ofngO00?oen[Rom7Si?o=h>H00_o=h>H0
0oo6fNOo`mKXol?Fj004ooooo`03o`000?oooooooooo00gooooo000:ooooo`03o`000?oooooooooo
00cooooo0ol0000@ooooo`05o`0]/ol09k7o02Nao`0n`Ol[FL`00om<JLl2og9lcP;oRXO:1?nMT<H0
1?n[Ul;o[9W3ojbI`on/VL<4okRN_`05ol2S_?o2YKco`ZFlol:U_?o8ZKX01?o;[;X5om6a^@03omBd
^OoG][WoekJi00?ofKVi00?og;biombm^_oL_KX00ooN`;X2on73^`04omo4_OoQakkohLNnon77_P;o
hlZn0_oTcKl00ooQcL?oh/o5on;?a@02on?BaP;ohmC800?og];=omgDcooMe<l00_oMe]42omcGd`03
omGCeooCe=WodmCI00;odMGK00Gob]3NolS@h?o8d>3ob=3Pol;<hP03ol3<h`04ok[8iOnianGo^LOU
okW7i@;o]<CV0_nca>H3ok32i`Co[/3W1?n/_nP3oj^nj0CoZ[kX0onZ_NP4ojVmj003o`000?nY_NSo
ZKgX00GoZKgX3Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo0ol0000J
oooooaSoZKgX1onX_NP3ojNlj@?oYKcZ1?nR^n/2oibik@;oU;K_0_nD]nl2ohRbl@?oMJ[c0_mHW?<2
obb3jP05o`1Qe_l0>;Oo01RMo`0;UOl05:400_l0=[`01?lRDl[oC6cBoda/d_m<K=83ogR2d@CoUi?>
0_n_X<P00oncYL_oa:k4olB^a002olB^a004olVda_oE^[ooeKZoomFj_`?ofKo000?oh<>konC8^ooT
b;/00_oXcK/2oncC^`04onkC^?o`f;Sol]bhoo;L^0;om>6h0_oeiKT01?oejKWom>fjoo?Z_OobkKl2
oo7_`@07onobaOl0003okO?8on[dcOoVmM7ohoGFomo^f`02om_]g`;oen[R00?od^SUolgPi_o=h>H0
0_o8gNP00oo3e^Soooooooooo`03ooooo`03o`000?oooooooooo00gooooo000:ooooo`03o`000?oo
oooooooo00Wooooo0ol0000Cooooo`04o`0_/Ol0;K?o02Nao`0W/@;o64k80_m<JLl2ofaicP?oRXO:
0_nMT<H00onLTLOo[9W3ojbI``02ojbI``?o^9jo00?o^Z6ool:U_?o2YK`00_o2YK`5ol^/^P04olj^
^_oA/KWodK6iom6a^@?oe;Bi00?oekJiomVi^OoI^KT00ooL_;T00ooL_K[og/2jomk0^P03on73^`;o
hlNk00?ohLNnon?:__oSb[h00ooTcKl01?oVd<7oh/o5on?Ba_oSd/H3on?Db003on?Gb_oMe<oogMKA
00;ogMKA0_oLem<00ooJf=GodmCIom7Ef`02om7Ef`04oloEgOo8d>3ob=3PolS@h0;oa]3Q00Go`<cS
okk;i?nnbnCo_/_TokW7i@03okO7iP03ok?4i_nba>Oo//CW00?o/<;W0_n^`>L2ojg0i`;o[;oX00?o
ZkoXoj^nj?n[_^P00_n[_^P3ojZnj0CoZ[gX0onY_NP00ol0003oZKgXojVmj002ojVmj13ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`?o00007_oooolHojVmj0OoZ;gX0onW
_>T3ojFljP?oX[_[1?nL^Nd3oiBgk`;oR;;a0omeZ_<3oeRLl`07obj6jol0HMKo03Rgo`0HWOl029Go
01BQo`0f_002oaA>b@;oC6cB0omfQM@2oiNCcP;oVISA1?ncYL/2olB^a0?obKC600?oeKZoomVo`?oI
_l000_oI_l02onC8^`?oj<fk0_o/dk/00oo_fK_ol=Rhoo;L^002ooCQ^0?omNFi00SomNViooC]^_oc
l;_olO>moo7_`Oo_l/GokO?8o`0000;oj_C=00Coi_GAon?ee_oOm=_ofngO0_oGj^800ooBj>Goc^CX
olkTj002olSMj0Oooooo00?o0000ooooooooool03Oooool000[ooooo00?o0000ooooooooool01_oo
ool3o`0001Oooooo00Co02nao`0KYOl09k7o02ng0_lHC/P00om<JLooK7W>ofaicP03ohN6b`CoW977
1?n/VL<01?nhW[oo^Z6ookZQ_onjXKl2ol:U_0;oaJRl0oo;[;X3olj^^P03om6a^OoD];Woe;Bi00;o
e;Bi0_oI^KT4ombl^@03omjo^OoN`;[og/2j00?ohL>k0_oSak/2on?:_PCoi<fo00Coi]31onOC`_oW
dl;ohm;60_oSe<P2on?GbP;ohmW<00?ogMKAomcGdooLem<00_oJf=D01?oIfMSodMGKom7EfooAeM/2
oloEg@04olS@h?o6d>7oa]3QolC?h`?o_/_T00Go_<[UokO7i_nganKo]lOVokK6iP04ok;4i`05ok32
ion_`NOo[l7Wojo1ion]`>L00_n]_nP3oj^oj0?oZkkX1?nZ_^P4ojZmj0?oZKgX00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo0ol0000RoooooaSo
ZKgX1onX_NP3ojNlj@CoYKcZ0_nR^n/2oibik@03oifjkOnE]nooUKO_00;oUKO_0on9/o42ogJ[m0;o
FYkc0_laRN`2o`1Te`04o`00Q?l05:7o01BQo`0f_0;o54k90_m<K=82ogJ5e0CoVISA1?ncYL/00oo4
[/CobKC6olVdaP02olVdaP03omFj_ooI_l3ofKo000;ofKo000Cog/K1onC8^ooXcK_oj<fk0oo/dk/0
0oo_fK_olMjkoo;L^002ooCQ^0;omNFi00_omNViooC]^_odkK[olo2koo7c_Oo_m/3ok?S3ongcb?oZ
m<go0000onKed@02on?eeP04omodfooKl^3oen[Rom;Xi@;oc^CX2_ooool00ol0003oooooooooo`0=
ooooo`002_ooool00ol0003oooooooooo`03ooooo`?o00006oooool01ol08jGo00VDo`0W/Ol0;kOo
64k8ocmSc_m<JLl00_m/NLh3ohN6b`?oW9770on/VL<00on^V/?o^Z6ookZQ_`02okZQ_`03ol:U_?o5
Z;coaJRl00;oaJRl00?objbjolj^^_o>[[X00_o>[[X5omBd^@03omNg^OoI^KWog;bi00?og;bi0_oN
_kT00ooN`;[ohL>kon73^`03on?7^`03onG:_?oSb[koi<fo00;oi<fo0_oVd<42onOC`P03onOFa?oS
e<SohmO:00;ohmO:0_oSfL`00ooRfloog=OCom[He@02om[He@;ofMWH00?odMGKoloEgOo?eMd00_o=
e=l01Oo6d>7oa<oSolC?hoo4cn?o_/_T00?o_<[U00Co]lOVokK6i_nfa^Ko]/KV0_nba>L2ok73i`;o
[l7W00?o[/7Wojfoj?n]_nP00_n]_nP00on[_nSoZkkXoj^nj003oj^nj0CoZ[kX0_nZ_NP5ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`?o
00009_oooolHojVmj0OoZ;gX0onW_>T3ojFljPCoX[_[0_nM^^d2oiFgk`04oiJhkon:/o7oR[?aohZc
l@?oN:gd0_mMXO@2oc69k005o`1YfOl0?;Oo002:o`0DXOl09:l00_lDC/T2odA/e0?oMXGD1?nIV=42
ok>Ub`03okN[c_o9]<KobKC600?obKC600Coc[_8omVo`?oI_l3ofKo00_oNa/400ooRc<;oj<fkonS=
^`02oncC^`;okmVk00KolMjkoo?T^ooci;_om>6hooGU^OoejKT2ooC]^P05oo?`^ooalkgolO>monof
`?o/n<<00_oYnLL01?oVn/co0000on?ee_oOm=/2om_bh003omK_i?oAk>Ooc^CX00_ooooo00?o0000
ooooooooool03Oooool000Wooooo00Co0000oooooooooooooooo0ol0000Oooooo`06o`0SYOl02ICo
02ngo`92`olHC/So?f?>0om/NLh2ohN6b`CoW97700?o[9W3ojjJ`on^V/<01?njXKl5olFX_0GocZjj
00Cod;6jomBd^OoD];Woe;Bi0_oG]kT4ombl^@?og[ni0_oQ`k/3on?7^`;oiLZl0_oWc[d00ooTcKoo
i]31onK@`@03onOC`P04onOFa?oWfLKoimW6on?GbP;ohmW<0_oRfll2on7Ld@03om[HeOoIfMSofMWH
00;oe][J00?ocmGMolgDgoo=e=l00_o;e>42olC?h`;o`/kT0_nlb^D2ok[9iP;o]/KV0_ndaNL2ok73
i`03ok33ion^`NOo[/7W00;o[/7W0_n]_nP2ojboj0?oZkkX1OnZ_^P9ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05?ooool01?l0003oooooooooooooool3o`0002[ooooo6?nY_NP7
ojRmj0?oYkcY0onU_>X3oj:kj`CoWK[]0_nF^>l3ohZcl@?oN:gd0_mMXO@2ocJ=kP07o`1YfOl0?;Oo
002:o`0DXOl09:oo1DS7oaA>b@02odA/e0?oMXGD0onIV=401?ncYL_o]j_>okN[c_ngZlh3olVdaP?o
c[_800CofKo0omk6`OoNa/7og/K10_oRc<801?oXcK_ok=>konoI^oo_fK/2oo7N^`;olnBk00Gom>Vk
ooGU^OoejKWom>fjoo?`^`02oo7c_@05onof`?o/n<?ok?S3onWiaooVn/`00_oSn]801?l0003ofoWM
om_bh?oFkn@2om7/i`cooooo00?o0000ooooooooool03Oooool000Wooooo1?l0000Sooooo`05o`01
QOl07Z_o02ngo`92`oloHlh00omUMm03ohF6c@;oW97700?oWI;8ojjJ`on^V/<00_n^V/<2okZQ_`;o
_:?01?o5Z;`01?o8ZkgocZjjolj^^_o>[[X3om2a^P05omBd^OoG]kWoekNiomNg^OoJ^[X00_oL_;T4
omjo^@04on73^_oQ`k_ohlNkon?7^`?oiLZl0_oWc[d00ooXdKkoi]31onOC`P02onOC`P;oimK40_oW
fLH01?oWg<WohmW<on;KcooRfll3on7Ld@04omoNe?oIfMSoe][JomKJfP;oe=[M00CocMCOol_DhOo;
e>7obmCQ0_o8dn<01Oo2c^Co_lkUoko>iOnoc^Go^/WV00;o^<SV0_ndaNL00oncaNOo/<?Wok33i`02
ok33i`;o[/7W0_n^`NP3ojboj0CoZkkX00?oZ[kXooooooooool02_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Cooooo1?l0000_oooooaKoZKgX2?nX_NP3ojNlj@?oYKcZ0onR^n/3
oifjk@CoU[S_0_n;]?43ogZ^m0;oHJCe0_lkTO000ol2K]go046io`01R`02o`0T[`03o`E8aom4K=Co
A6cD00?oM8SH0onKWMD5okN[cP03olVda_o>^lSoc[_800;oc[_80ooNa/43on;<`P03onOC`_o/dk_o
kmVk00;olMjk0ooci;/01OodjK_om>jkoo?a^_odkK[olo2k00;olO>m00CokoK0onch`ooYnLOoi_[<
0_oSn]801_oOn]Oo0000omOfh_oGm^;odo?Vom7/i`gooooo00?o0000ooooooooool03Oooool000Wo
oooo0_l0000Vooooo`05o`01QOl07Z_o0T;3o`92`oloHlh00omUMm02ohF6c@?oWI;81?n^V/<01?nj
XKoo_:?0okbS`?nlXl03olFX_0;ob:^m0_o>[[X4om2a^P?oekNi0ooJ^[X01?oL_;Wog[niomjo^OoN
_kT2on73^P;ohlJk00?ohlNkonG:_?oUb[`00ooWc[d01?oXdKkojMG0onWE`?oWdl82onOFa0?oimW6
00?oimc9onONbooRfll00ooQg=42omoNe003omcOeooFf][oe=[M00;oe=[M0_oAfMl01?o;e>7ob=?S
olSChoo5d^@3oko>i@05okg<i_nhb>Ko^<SVokS8i_ngb>L00oncaNL2ok33i`;o[l;X0_n^`NP00on]
`>So[;oXojboj002ojboj0;oZkkX3oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01?ooooo0_l0000aoooooaOoZKgX2?nX_NP3ojNmj@?oYKcZ1?nR^n/2oifjk@;oU[S_00CoUkW_ohfe
lOn=]O7oSKGa0omm/?@2ofFVmP?o>i7`00Co2WGQo`01Rol09:oo04;50_lkJmL01?m4K=CoM8SHogB8
f?mdR=P3oi^Me@?o]j_>0_nk/]43oljkb0;odl;:00?og/K1on;<`_oRc<800_oRc<800ooWdl;ojm[3
onoI^`02oo7N^`;olnBk0_odjK/00oodk[_olo6joo7e^`02onkh^`0;on_j_OoXnkooi?g3on7naooM
o/goho[BomojeooKnMgoeoKRo`000?oClnH04?ooool00ol0003oooooooooo`0<ooooo`002oooool0
0ol0003oooooooooo`0Tooooo`03o`00P_l07Z_o0T;300;o;ec>0_mUMm03ohF6c@?oWI;80_n^V/<0
0on_WLGo_:?0okbS`003okbS`003olFX_?o8Zkgob:^m00;ob:^m00?ocZjjom2a^_o@/KX00_o@/KX0
0ooC]K_oekNiomZj^P03omZj^P03omfn^_oN_kWog[ni00?ohL>j0_oSa[/2onG:_0?oiljm0_oXdKh2
onWE`003on_I`_oWe/CoimW600;oimW60_oWg<T01?oWg/_oi^7>onKQc_oQg=42omoNe0;og=oG0_oJ
gmX00ooDf]godMWOom7Ig`02olkIh@05olSChoo5d^CoaM;TolGBi?noc^D00onmc>H01Onhb>Ko]lSW
okO8iongb>Oo/lGW00?o//CW00?o[l;Xojo1j?n]`>P00on]`>P2ojboj1?ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02oooooo6?nY_NP7ojRmj0?o
YkgY0onU_>X2oj:kj`03oj:ljonN^^goW[[]00;oW[[]0_nG^Nl3ohfel@?oOK3d0_mUY_H3od:FlP04
oa=miOl00H_o02B_o`12a@;o>f_G1?mdR=P3oi^Me@03okN[c_nk/]7o^k;A00;o^k;A00Goc[_8om?2
b_oC`/[odl;:omS:c003on;<`P;oim?200Gojm[3onkQ`oo^hL?olMjkoo?T^`02ooCY^`04ooC^^ooc
lK[olo6joo7e^`;ok_Rk00CojoZmonSk_ooToL?ohOk70_oJo]<01OoGoMWoe?cOomOfh_oClnKo0000
013ooooo00?o0000ooooooooool03?ooool000cooooo00?o0000ooooooooool09?ooool01?l007go
00fKo`92`ol_G<h3oeeddP?oQHK=0_nMT/P01?n^V/?o[ig5ojnMaOn_WLD4okbS`0Gob:^m1?o@/KX2
om>e^`03omNg^OoJ^[[of[Zj00;of[Zj0_oM_[X00ooN_kWohL>jon73^P03on?6^`04onK;^ooUb[co
iljmonO>_@;oj=6n0ooYeL001?o[fL;ojmc4on_La?oWfLH2onOLb@;oimk;0_oVhLh00ooThm7ogmkD
omcOe`02omcOe`04om[Of_oGgmgoemoMom7Ig`;oc]WQ0_o;f><2olGBi0;o`]7U0_nmc>H2ok_;i`;o
]lSW0_neanL2ok;4i`04ok73j?n_`NSo[l7Xojo1j0;o[L3X5oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<?oooolFojVmj0SoZ;gX0onW_NT3ojFl
jP?oX[c[0_nN^^d00onN^ncoV;W_oiRik`02oiRik`;oSkKa0on0/O@3ofZYmP04odZKm?lOQNWo7hGY
o`0AV`;o04;500?o>f_Gog6<g_maS=h00_maS=h3oifTfPCo^k;A00?o`;[Eom?2b_oC`/X00_oC`/X2
omS:c003on;<`_oWdl;oim?200;ojm[30_o^hL<01?o`j<?olnBkooCY^oodk[/2oo?a^P07oo7e^oo^
n;_ok_Rkon_j_OoXnkooi?g3on7na`02om[nd`03omOmfOoDo=ood?WU00?ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Tooooo`04o`00
OOl03I_o;ec>obmLcP;oGGCB0on2Qll2oifDbPCo[ig50onlXl02oknV`@?ob:^m0_o;[[d2om2a^P?o
dkFk00CoekVlomZj^_oJ^[[of[Zj0ooM_[X2on73^P?ohlJk0_oVbk/2onS?_003onO>_OoXdKkoj=6n
00;ojMG00_o[fL82on_La004on_Oa_oWg<Woimk;onONb`;oi^7>0_oThm42on;Te004omcOeooJgm[o
emoMomOOg@;oe=kP00Coc]WQol_Hhoo;f>?obmSS0_o7e^D00oo2dNGo_loVoko?iP02ok_;i`;o^L[W
0_neanL00onca^So/L?Xok73j002ok73j003ojo1j?oooooooooo01Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02oooooo5onY_NP7ojRmj0CoYkgY
0onU_>X3oj>lj`?oW[_/0_nH^Nl00onI^^koT;Oaoi2gl@02oi2gl@;oPk?d0om_[?H01OmBXOKo7hGY
oan5jOl04I_o04;500;o;f_J1?maS=h3oifTfP;o^k;A0oo0^]D2om?2bP?of<[<0_oWdl82on_J``?o
k^7300Col>S3oo7^`_odjK_om>jk0_oclKX02ooamK_ok_Rkon_j_OoXnkooi?g3on7naoo=olkof_kC
omOmfOoDo=ood?WU00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`00
3_ooool2o`0002Gooooo00?o00fKoaeCc?lMDl`00omMM=82oh:7c`?oWIC:1?n_WLD00onlXl3o_jK1
oknV`@02oknV`@03olR[_Oo;[[gobjjm00;objjm00Cod;6jom>e^ooC]K_odkFk0_oG^K`00ooJ^[[o
gKjjomfn^P02omfn^P04on32^ooQ`k[ohlJkon?6^`?oi/^k0_oXck`2on[C_P04onSA__oYeL3ojmW2
on_I`P?ojmc400Gojmo6on_SbOo[hlWoimk;onKQcP03onCSd@05on;Te?oOiMSognGHomcUfooGgmd0
0ooDg^02om3MhP04ol_Hhoo7e^GoamKUolCDiP?o_loV0_nmc^L00onib^Oo]lWXokO9j003ok?6j0;o
/L?X7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo0_l0000`oooooaSo
ZKgX00?oZ;gXojVmj?nY_NP00onX_NP3ojNmj@CoYKcZ0onS_>/3oinkk0?oVK[^0_n@]o401?nB^?7o
Q[GdohJem?n6]O@2ogF_mP?oFjKg00?o:hk^o`0AVol0@/D00_l_JmX3og6<gP?oWJCJ00?o^k;Aol2j
eOo0^]D00_o0^]D00ooC`/[of<[<omS:c002omS:c003omgBc_oWdl;ojm[300?ok^730_o`j<<02_oa
k/;ol??1onkg_oo^mkoojoZnonKl_?oQoKcog?flomOn__o@olL2olgocP03olcoeOo:o]gob?gT00Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`004?ooool00ol0003ooooo
ooooo`0Sooooo`03o`0=VolMDlco7E?<00;oGGCB0on2Qll3oifDbP;o[ig500?o/J37oknV`OnoY/40
0onoY/44ol^^_@04oljb_ooC]K_odkFkom>e^`?oekVl1?oM_[X2on32^`;ohlNl00?ohlJkonK;^ooV
bk/00ooXck`2on[C_P04on_G_ooYeL3ojmW2on_I`P;ojmc40_o[glH2on_Sb@05onWUc?oXj<ooj>S?
onCSdOoRi=@00_oOiMP2omcUf`;ofNGN00?oe=kPom3Mh_o@gN800_o=g>@01Oo7e^Goa=CVolCDi_o4
e>Ko_loV00;o_LkW00?o^/cXokO9j?ngbNP00_ngbNP00onca^Soooooooooo`0Oooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0_oooooa[oZKgX1?nX
_NP2ojNmj@;oYKcZ0_nV_>X3oj>lj`03oinkk?nP^ncoX;_/00?oVk[^0onB^?43ohJem0;oMJof0omK
Y_L00olhUo;o03Fiobm[fP02obm[fP;oKY7T1?nP[>03ol2je@;oaLCI0ooHb/`2omgBcP04on;Kd?o[
f/?ok^73onkQ``;ol>S30_oak/802?o`ll7ok_Noonkg_oo[n[koi_blomcm_?oGo[kod?o70_o=olh0
0oo<omGob_kMolSmi008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
017ooooo00?o0000ooooooooool08_ooool00onD6`3o02F`oaeCc003oe=be0;oPXO?0_nMU<X00onM
Ulgo/J37ok6Pa`02ok6Pa`?o_jK10_o2Z/82ol^^_@?oc[:o00?odkFkomNi_?oG^K`00_oG^K`00ooJ
_KgogKjjomfn^P03on32^`;ohlNl0_oVbk/3onS?_0?oj]>n00GojmNoongK`Oo]fl7ojmW2on_La002
on_OaP;ojn?90_oYiL`2onSXc`03onKYd_oSjmKognGH00?og>GK00CofNGNomGThOoEi>7od=gR0_o=
g>@2olWJiP;oa=CV0_o1d^L01?nmc^Oo^/cXok[<j?njc>P2okO9j2Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02oooooo6_nY_NP3ojRmj0CoYkgY
00?oY[cZojJljOnV_>T00onT_>/3oj2kk003oi^jk_nL^^koW;[^00?oU;W`0on:]_<3ogZbmP;oI:[h
00GoAIkeo`0e^OlRJmco8V_Lobm[fP02ofjAi0CoX:cP00?o`;[EolG4fOo5a=T00_o5a=T00ooHb/co
gM;>omgBcP02on;Kd0;oiNGA00Gok^73oo3X`ooak/;olNk2oo3c`@02onkg_`09on_j__oVo;cog?fl
omOn__nfnL7o]O[8okKld?ngo=Wo^?cR00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0<ooooo`004_ooool00ol0003oooooooooo`0Rooooo`03o`0EX_l7B/So1d[800;oDg;D0_mn
R=<4oifGc@Co/J3700Go_jK1ol:Z`_o2Z/;o`Z[2ol^^_@04oljb_`CoekVl0ooJ_Kd00ooM_[[oh<:k
on32^`03on?7_004onG<_OoVbk_oj<nlonS?_0?oj]>n0_o[ekl2ongK`@05ongP`oo]i<GokNC5on_O
a_o[hlT00_oYiL`2onSXc`03onKYd_oSjmKohn_F00;oh>_J00Cog>GKomWUg_oEi>7oeNCQ0_oAh^@0
1Oo=g>CobM[VolWJi_o9f^KoaMSX00;o`M;W0_nnd>P2ok[<j2Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02oooooo6_nY_NP3ojRmj0?oYkgY1?nV
_>T3ojBlj`?oXK_/0onL^^h01?nD^O3oUk[`oiNjl?nG^_02ohfhl`?oOkCf0_m/[oP01?mBY_So03Fi
ob9[g?lRJm`3ofZHj`;oX:cP00?oX[KVolG4fOo5a=T00_o5a=T2ol[>g@04omgBc_oRfm3oh]_@on;K
d0;oiNGA00?oj>gAoo3X`ooak/800_o`ll402_o^mkoojoZnonKl_?o3nk[o_OVjokWi_?nfnL7o]_c@
okOlfOnho>8<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool001?ooooo
0_l0000Sooooo`03o`0EX_l7B/So1d[800;oDg;D0_mnR=<3oifGc@?o/J3700?o/jC9ol:Z`_o2Z/80
0_o2Z/85oljb_`03om6g`?oG^KcoekVl00Cof[fm00?ogL:non32^ooSak`00_oSak`2onG<_@;oj=2n
00?oj<nlon[C__oZdkh00_o[ekl3ongK`@06ongP`oo]i<GokNC5ongWb?o/jl_ojNG<0_oXj<l01OoV
jM;ohn_Fon?[e_oSjmKoh>_J00;og>_M00?of>[QomGThOoAh^@00_oAh^@2olgPiP03olWJi_o5f>So
aMSX00;o`]GY00?o_]3Xooooooooool0:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01cooooo0_l0000`oooooa[oZKgX1?nX_NP2ojNmj@;oY[cY0_nV_NT3ojBlj`03oj6kk?nQ_>co
XKc/00?oWK_]0_nG^_001?nH^^ooT;Wboi2il_n@^O83ohBfm@?oM;;h0olBJ]d2ofZHj`CoX[KV00?o
aLCIol[>gOo:c]d00_o:c]d3on;Kd0;oiNGA0_oXkM403?oXm=3oi_[=onKjcOoQoLWofok5om?n`?o3
nk[o_OVjokWi_?nfnL7oVO?CoiofgPoooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`005Oooool00ol0003oooooooooo`0Qooooo`04o`0EX_l7B/SoAfoFodM_eP?oOXSC0onM
Uld01?naX<Oo/jC9ok>TbOncY<T3ol:Z`P04olF_a?o>/[ooc[:ooljb_`?odKO000?oekVlomZm_OoJ
_Kd00_oJ_Kd01?oM`[kohLNoon?7_?oSak`3onG<_@;oj=2n0_oZe[l00ooZdkkojmNoongK`@02ongK
`@06ongP`oo]i<GokNC5ongTaOo]ilSok>_;0_oZkLh01OoWl=7oi?7EonCaeOoSjmKoh>_J00;og>_M
0_oHj^42omCXi003om7Ri?o=h>KocN3V00;obMgX00?oaMSXol;EjOo2eNT0;_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0;ooooolIojVmj0?oZ;gX
1?nW_NT2ojJmj@CoY;cZ00?oXKc/oj:ljonR_>/00onN^nd3oiRjk`?oT;Wb00?oQ;KeohVhmOml]OP0
0oml]OP3oa9Zg@;oI:3b0_nR]^H2ojG1k@?ob/kM0_o>f^800ooRfm3oiNGAonGUd@02onS]d@0;onSd
d?oVn/goi_[=onKjcOoKo/Godok0ol?k^_n=ik;oS>Rfoi?_b?nIlm<04_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00_ooooo000Fooooo`03o`000?oooooooooo027ooooo00?o00B@
o`M:b?m7KmH00omjR]L3oifKd@Go/jC900Go`Z[2olF_a?o5[lCoaJo4oljb_`04om6g`004omFl`_oJ
_Kgof[fmomZm_@;ogL:n0_oQakl00ooSakcoiLbmonG<_@03onS@_P;oj]Jo00Gok=_1ongP`oo]h<?o
kM_1ongP``03ongTa@04ongWb?o/jl_ok>_;on[]cP;oio3A0_oTlMD00ooQl]WogO;Momc[g@02omSZ
h@;oe>ST00?od>KWol_SjOo;hnT00_o9gNP2olGKj@03ol;EjOoooooooooo02kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02kooooo6onY_NP2ojRm
j0CoYkgY0_nV_NT2ojBljP;oYKcZ0onR_>/00onN^ngoWkc]oinlk@03oiZkk`?oTk[a0_n9^?D2ogbe
n0;ooooo00?o02JRo`1Xf_lBJ]d00_mTX?84ojG1k@03ol[>gOo>f^;oc][R00?od^GU00?odo3VonS]
dOoXm=000ooVn/d01_oKo/Godok0oiO//on=ik;oI=Nkog3ObQGooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0;ooooo`005oooool00ol0003oooooooooo`0Qooooo`03o`04T?m7KmKo
AfoF00?oNX[G0onMVm43ok>Tb@03okJYc?o5[lCoaJo400;oaJo41OoA]l02omFl`P03omZm_OoM`[ko
gL:n00?ohLNo0_oTcL400ooUc;goj=2nonS@_P03on[F_`04oncK`Oo]h<?okN33onkUa@;ok^W600Go
kNC5ongWb?o/jl_ok>_;on[]cP02onO`d@;oi?7E00CohO;IomgbgOoMl]gofO7Q0_oEknD00ooDj>Co
d>KWol_Sj@02ol_Sj@;oan3[00?oaM_Yooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0;_oooolJojVmj0?oZ;gX0_nW_NT00onX_NWo
YkgYojNmj@02ojNmj@03ojFlj_nU_N[oYKgZ00?oXkc[0onO_>d00onJ^nooooooooooo`09ooooo`;o
06GC0omMZ?P2ojG1k@;oY/kd00Coc][Rom;UiOoBiNGod^GU0_oCl>H01OoBnNCoc?kOolcngooVn/go
^?c=00;oX?6j00?o@/>noeKAd?ooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00_ooooo000Hooooo`;o00008Oooool01?l0193o>6cIocQ/fOlhK=T2ogZ:e`CoWI_A00Co/jC9
okJYc?nfZLco]ZW<0_o5[l@2olRda`?odKO00ooE_<82omg2_PCohLNo0_oTcL400ooWdl;oj=2non[F
_`02on[F_`05oncK`Oo]h<?okN33ongP`oo^iLD00_o^jLH01?o]kLWok?7;oncabooYm<h2onKfd@03
on?heOoTlMGohO;I00;ogO;M00?ofO7QomG_iOoEknD00_o@kNP2olcZj`03ol_SjOo7h>_oan3[03Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`;o0000<?oooolIojVmj0Co
Z;gX0_nX_NT4ojNmj@?oYKgZ00?oXkc[ooooooooool03oooool2o`1Ud`?oGJSh0_nVc_@3ojKJnP04
om;UiOoCl>Kodo3Vom;ii0;oc?kO00Co`okGokSlcOnPlK[oX?6j6oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo01oooooo00?o00B@ocQ/
fOlhK=T00omeSM`2oifKd@03oijOeOnfZLco]ZW<00;o]ZW<00?oaJo4olRdaoo8]<L00_o8]<L00ooA
]l3oeKc2omFl`P02omFl`P03omW2a?oM`[kohLNo00;ohLNo0ooTcL401OoWdl;ojMW4onWIa?oZe[oo
k=_100?okN3300Gok^G5onkYa_o^jLKok^W6ong]b@02oncab`03onWdc_oVm]7ohoSE00;ogoWI00Co
foSMomOgh_oGmn;od_KV0_o>lnT01?o@kNSoc>[[olcZjoo8i^diooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0]oooooa[oZKgX0onX_NP4ojRmj@03
ojNmjOoooooooooo01Oooooo00Co06GCoe:_n_mB[o[oDZoj0_nVf_X2oj?Uo007om?`i_oBnNCoc?kO
olcngoo3o]Oo^?c=oeK<Z`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_oo
ool001_ooooo00?o0000ooooooooool07oooool00ol0<KSo>6cIocQ/f@02ogF=g0CoWYoE0_nfZL`0
0oni/=3ob;C7olRda`03olRda`04olbkbOoE_<;oeKc2omFl`P;ofL;400?og<S6on77_ooQakl00ooT
cL42onOC`P;ojMW400Cojmo6oncK`Oo]h<?okN330_o^iLD2onkYaP06ong]bOo/lL_ok?7;onWdc_oV
m]7ohoSE0_oOnMT01?oKn=goeoORomOgh_oBm^H2olkcj@;ob^o]00?oa^c_olSVkOooool0>_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0;OoooolJ
ojVmj0?oZ;gX0_nX_NTMooooo`?oA;?f0_nSiO`01OnKk?SoSng]oho]kOmoj=coKmk:02;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`0O
ooooo`03o`0RZOlUIm[o9FOJ00;oMHgL0onNWmD01?nfZLco^K3@okV`d?ni/=03olRda`?oc;_900Co
eKc2omW2a?oI`/CofL;40_oLb<H00ooQakooi<g1onC=`@02onOC`P?ojMW400?ojmo6ongUaoo]iLL0
0_o]jlT02?o^iLGok^W6ong]bOo]kLWok?7;on?kd?oOo=;ofogE0_oFo]T00ooBoMgoc_cRol[ji`02
olOhj`04olkcjOo:kngob^o]olK/kcgooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02kooooo6OnY_NP00onX_NSoooooooooo`0Qooooo`;o8ZcG00?o
4Z;0ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo000M
ooooo`03o`000?oooooooooo01oooooo00Co02:YobEWf_m_T>?oKi3S0_nNWmD2oijVf`Co^K3@00?o
b;C7olbkbOo<^lT00_o<^lT3omW2a0?og<S60_oPd<P00ooTcL7oim?2onWIa002onWIa0;ojmo60_o]
iLL2ong[b@06onc`booZm<coj_C<onOhc_oSnm3ogocB0_oKoMD01?oFo]Wod_gMolklh_o:n^L2olOh
j`;oa?C_00?o`O3aooooooooool0?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0;_oooolDojVmj5;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`007_ooool2o`00023ooooo00Co01:DobEWf_m_T>?oKi3S1?nNY]/2okV`
d0;o_;OD0oo<^lT2om32c@04omW2a?oLb<Kog<S6omc8aP?oh=3800CohmO:onOC`_oYfLCojMW40_o[
glH2ongUa`;okN_900Kok?3;on[dc?oZm<coioS>on?kd?oOo=82om_me@05omKnfOnkoN3o^__Vok[k
i_ninN`00_nhm_000oo4m>oo`O3aooooo`11ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool09_ooool2o`0002kooooo4_nY_NQEooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02_ooool0023ooooo00?o0000ooooooooool07_ooool01?l04YCoKi3Sofn@hom_T><2oijV
f`03oij]h_nl]mCo_;OD00?o_;OD00Coc;_9om32cOo@`/god<;=0_oDb]000ooLb<Koh=38on3@b002
on3@b004on?Gb_oVg/goi]k=onWIa0;ojmo600CokNG7ong[bOo]jlWok?3;0_oZm<`01?oWn<koe?oA
olgod_o7om@2ol;ne`04ok_mh?njnnKo^__VokWik0;o^?K`00?o]o;dooooooooool0@_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0;?ooool<ojVm
j5[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`008Oooool00ol0003o
ooooooooo`0Nooooo`04o`1HdOmVU>WoIYCYofJDj@?oWZgR0onl]m@01?no_m[od<;=om32cOo@`/d3
omC:d004omSBe?oPd<Soh=38on3@b0;ohmO:0_oVg/d2onSVc`04onS]d?oWlm7oio?AonCidP;oh?cA
00Cof_kAomCodOo=om;oaooD0_o2o]L2oigdh@04oj3ejOnTm?3oYo7eojOamDOooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02gooooo1onY_NQNoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000oooooooo
ool07_ooool01?l0F=7oIYCYofJDjOmVU>T3oij]hP05okbge?no_m[o_koJoknof_o@`/d00ooDb]03
omSBe003on3@b?oSel[ohmO:00;oi]k=0ooXi/l02?oXkM3oio?AonOcdOoTnM;oh?cAom[ndOoDom7o
WoC:0_nKlld01OmchMCoONOQoggWhOn8j^coTN_d04_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo02gooooo1?nY_NQQooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02Oooool002?ooooo0_l0000Oooooo`04o`1<`omIV?3oFIS`oeVH
l0?oWKKY0ono_mX2ol;9g`03omC:d?oHd]Cof=;D00;of=;D00CofmcHon?Gb_oVg/goi]k=0ooXi/l0
3?oXkM3oio?AonOcdOoTnM;oh?cAok[mdOnVm/[oWoC:of;E_OmYflSoDloDofKJi0;oMn3aC_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo0_l0000]ooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`0Mooooo`04o`1<`omIV?3oFIS`oeVHl0?oWKKY00?o_koJol;9goo2bMl00_o5e>H3
omSBe0;ofmcH0_oMi]/2omg_g@05onSVcooXkM3oio?AonOcdOo?omX00_njoM401?mLd;3o0000odK4
jOm6a>UCooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`009_ooool00ol0003oooooooooo`0Nooooo`03o`0m[?m8VoCoW<7b00?oW<7b00?o
`/WOolGDi_o5e>H00_o5e>H00ooHd]CofmcHom_Lf002omgVf`;ogNoM0_oKmmh00ooGo=gocooJoloo
fP02ok[mdEWooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0I?ooool01Ol0003ooooooooooooooooo000000_ooooo000Wooooo`03o`00
0?oooooooooo01oooooo00?o<Y_boic1l_nL`O800onGc?X2olGDiP;oa^3[0_o4jnl00ooMi]_ogNoM
omg_g@02om_ggP04omOlgOo?om[ocooJogCO_Ecooooo00Co0000oooooooooooo0000<?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo06Gooooo00Co0000oooooooooooo00002oooool0
02Sooooo0_l0000Qooooo`03oaJDiOnGc?[oUlcj00?oSmKo00?oa^3[olC[koo4jnl00_nom?02okKi
k@04ojOhi?nElMOoUO7GohCXbEoooooo00?o0000ooooool00000<Oooool2o`0002Sooooo00?o0000
ooooooooool0I_ooool00ol0003oooooo`00000;ooooo`00:_ooool00ol0003oooooooooo`0Poooo
o`03o`27c_n?e_ooSmKo00;oP=_m00?oa>__okodl?nom?000_nfnNd00onWn>Coooooooooo`1Qoooo
o`03o`000?oooooo000003?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooo000000_ooooo000[ooooo`03o`000?oooooooooo02?ooooo0_m/fO82oe??gFOo
oooo00?o0000ooooool00000<oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooool000002_ooool002cooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1Xooooo`;o0000=?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Sooooo
0_l0000:ooooo`00;Oooool2o`0002?ooooo00?o0000ooooooooool0Ioooool3o`0003Gooooo0_l0
000Sooooo`03o`000?oooooooooo06Oooooo0ol0000:ooooo`00;oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo06?ooooo1?l0000jooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0Hoooool4o`0000gooooo000`ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0H?ooool3o`0003oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Poooo
o`?o00004Oooool0037ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Looooo`Co
0000@oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05cooooo1?l0000Dooooo`00
<_ooool2o`0001kooooo00?o0000ooooooooool0F?ooool4o`0004Sooooo0_l0000Nooooo`03o`00
0?oooooooooo05Sooooo1?l0000Hooooo`00=?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo05Cooooo1?l0001>ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E?oo
ool4o`0001cooooo000eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool3
o`0005?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`?o00008?ooool0
03Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1=ooooo`Co0000Eoooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04gooooo1?l0000Sooooo`00=oooool2o`0001Wo
oooo00?o0000ooooooooool0BOooool4o`0005cooooo0_l0000Iooooo`03o`000?oooooooooo04Wo
oooo1?l0000Wooooo`00>Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Gooooo
1?l0001Rooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOooool4o`0002_ooooo
000jooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@oooool3o`0006Oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`13ooooo`?o0000;oooool003_ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0oooooo`Co0000Joooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo03oooooo1?l0000booooo`00??ooool2o`0001?ooooo00?o0000oooo
ooooool0>oooool4o`00073ooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0000foooo
o`00?_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Oooooo1?l0001fooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0=oooool4o`0003[ooooo000oooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0<oooool4o`0007_ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0cooooo`Co0000?_ooool0043ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0`ooooo`?o0000P?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo033ooooo0ol00012ooooo`00@Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo02cooooo1?l00024ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool4
o`0004Gooooo0012ooooo`;o00003Oooool00ol0003oooooooooo`0Xooooo`Co0000ROooool2o`00
00gooooo00?o0000ooooooooool0:?ooool4o`0004Wooooo0014ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool09?ooool4o`0008oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Tooooo`Co0000COooool004Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Qooooo`?o0000U?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo
0ol0001Aooooo`00A_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0
002Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`0005Cooooo0017
ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000WOooool2o`0000Sooooo00?o0000
ooooooooool06Oooool4o`0005Sooooo0019ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05Oooool4o`000:?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eoooo
o`Co0000G?ooool004[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`?o
0000Z?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol0001Pooooo`00
Boooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002/ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`0006?ooooo001<ooooo`;o00000ooo
ool00ol0003oooooooooo`0:ooooo`Co0000/Oooool2o`0000?ooooo00?o0000ooooooooool02_oo
ool4o`0006Oooooo001>ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002gooooo`04o`000?oo
ooooooooo`0000Sooooo1?l0001[ooooo`00Coooool00ol0003oooooo`000005ooooo`?o0000_?oo
ool00ol0003oooooo`000005ooooo`?o0000Koooool0053ooooo0_l000000ooooooo0000o`000002
o`000<3ooooo0_l000000ooooooo0000o`000002o`0007;ooooo001Aooooo`;o0000aOooool2o`00
07Kooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-1.41844, \
-1.14991, 0.01418, 0.01418}, {{208.5, 389.375}, {315.688, 169}} -> {-4.23892, \
-1.14991, 0.01418, 0.01418}, {{9.625, 190.438}, {154.375, 7.6875}} -> \
{-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, 389.375}, {154.375, \
7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoClassificationRegions[pdf1, pdf2, pr, x, y, classColors, gd, 
        Axes \[Rule] False, Frame \[Rule] True, FS];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.00495 .00495 m
.02346 .00495 L
.04365 .00495 L
.06261 .00495 L
.08084 .00495 L
.10025 .00495 L
.11893 .00495 L
.13879 .00495 L
.15792 .00495 L
.17633 .00495 L
.19591 .00495 L
.21476 .00495 L
.23289 .00495 L
.25219 .00495 L
.27077 .00495 L
.29052 .00495 L
.30955 .00495 L
.32784 .00495 L
.34732 .00495 L
.36607 .00495 L
.38599 .00495 L
.40519 .00495 L
.42366 .00495 L
.4433 .00495 L
.46126 .00495 L
s
.00495 .99505 m
.02346 .99505 L
.04365 .99505 L
.06261 .99505 L
.08084 .99505 L
.10025 .99505 L
.11893 .99505 L
.13879 .99505 L
.15792 .99505 L
.17633 .99505 L
.19591 .99505 L
.21476 .99505 L
.23289 .99505 L
.25219 .99505 L
.27077 .99505 L
.29052 .99505 L
.30955 .99505 L
.32784 .99505 L
.34732 .99505 L
.36607 .99505 L
.38599 .99505 L
.40519 .99505 L
.42366 .99505 L
.4433 .99505 L
.46126 .99505 L
s
1 1 .5 r
.00495 .00495 m
.02346 .00495 L
.04365 .00495 L
.06261 .00495 L
.08084 .00495 L
.10025 .00495 L
.11893 .00495 L
.13879 .00495 L
.15792 .00495 L
.17633 .00495 L
.19591 .00495 L
.21476 .00495 L
.23289 .00495 L
.25219 .00495 L
.27077 .00495 L
.29052 .00495 L
.30955 .00495 L
.32784 .00495 L
.34732 .00495 L
.36607 .00495 L
.38599 .00495 L
.40519 .00495 L
.42366 .00495 L
.4433 .00495 L
.46126 .00495 L
.46126 .99505 L
.4433 .99505 L
.42366 .99505 L
.40519 .99505 L
.38599 .99505 L
.36607 .99505 L
.34732 .99505 L
.32784 .99505 L
.30955 .99505 L
.29052 .99505 L
.27077 .99505 L
.25219 .99505 L
.23289 .99505 L
.21476 .99505 L
.19591 .99505 L
.17633 .99505 L
.15792 .99505 L
.13879 .99505 L
.11893 .99505 L
.10025 .99505 L
.08084 .99505 L
.06261 .99505 L
.04365 .99505 L
.02346 .99505 L
.00495 .99505 L
F
0 g
.00495 .00495 m
.02346 .00495 L
.04365 .00495 L
.06261 .00495 L
.08084 .00495 L
.10025 .00495 L
.11893 .00495 L
.13879 .00495 L
.15792 .00495 L
.17633 .00495 L
.19591 .00495 L
.21476 .00495 L
.23289 .00495 L
.25219 .00495 L
.27077 .00495 L
.29052 .00495 L
.30955 .00495 L
.32784 .00495 L
.34732 .00495 L
.36607 .00495 L
.38599 .00495 L
.40519 .00495 L
.42366 .00495 L
.4433 .00495 L
.46126 .00495 L
s
.00495 .99505 m
.02346 .99505 L
.04365 .99505 L
.06261 .99505 L
.08084 .99505 L
.10025 .99505 L
.11893 .99505 L
.13879 .99505 L
.15792 .99505 L
.17633 .99505 L
.19591 .99505 L
.21476 .99505 L
.23289 .99505 L
.25219 .99505 L
.27077 .99505 L
.29052 .99505 L
.30955 .99505 L
.32784 .99505 L
.34732 .99505 L
.36607 .99505 L
.38599 .99505 L
.40519 .99505 L
.42366 .99505 L
.4433 .99505 L
.46126 .99505 L
s
.46126 .00495 m
.46383 .00495 L
.46663 .00495 L
.46926 .00495 L
.47179 .00495 L
.47448 .00495 L
.47708 .00495 L
.47983 .00495 L
.48249 .00495 L
.48504 .00495 L
.48776 .00495 L
.49038 .00495 L
.49289 .00495 L
.49557 .00495 L
.49815 .00495 L
.50089 .00495 L
.50353 .00495 L
.50607 .00495 L
.50877 .00495 L
.51138 .00495 L
.51414 .00495 L
.51681 .00495 L
.51937 .00495 L
.5221 .00495 L
.52459 .00495 L
s
.46126 .99505 m
.46383 .96284 L
.46663 .92715 L
.46926 .89308 L
.47179 .85979 L
.47448 .82377 L
.47708 .78852 L
.47983 .75038 L
.48249 .71298 L
.48504 .67636 L
.48776 .63668 L
.49038 .59774 L
.49289 .5596 L
.49557 .51819 L
.49815 .47754 L
.50089 .43341 L
.50353 .38998 L
.50607 .34731 L
.50877 .30088 L
.51138 .25514 L
.51414 .20536 L
.51681 .15617 L
.51937 .10764 L
.5221 .05467 L
.52459 .00495 L
s
1 1 .5 r
.46126 .00495 m
.46383 .00495 L
.46663 .00495 L
.46926 .00495 L
.47179 .00495 L
.47448 .00495 L
.47708 .00495 L
.47983 .00495 L
.48249 .00495 L
.48504 .00495 L
.48776 .00495 L
.49038 .00495 L
.49289 .00495 L
.49557 .00495 L
.49815 .00495 L
.50089 .00495 L
.50353 .00495 L
.50607 .00495 L
.50877 .00495 L
.51138 .00495 L
.51414 .00495 L
.51681 .00495 L
.51937 .00495 L
.5221 .00495 L
.52459 .00495 L
.52459 .00495 L
.5221 .05467 L
.51937 .10764 L
.51681 .15617 L
.51414 .20536 L
.51138 .25514 L
.50877 .30088 L
.50607 .34731 L
.50353 .38998 L
.50089 .43341 L
.49815 .47754 L
.49557 .51819 L
.49289 .5596 L
.49038 .59774 L
.48776 .63668 L
.48504 .67636 L
.48249 .71298 L
.47983 .75038 L
.47708 .78852 L
.47448 .82377 L
.47179 .85979 L
.46926 .89308 L
.46663 .92715 L
.46383 .96284 L
.46126 .99505 L
F
0 g
.46126 .00495 m
.46383 .00495 L
.46663 .00495 L
.46926 .00495 L
.47179 .00495 L
.47448 .00495 L
.47708 .00495 L
.47983 .00495 L
.48249 .00495 L
.48504 .00495 L
.48776 .00495 L
.49038 .00495 L
.49289 .00495 L
.49557 .00495 L
.49815 .00495 L
.50089 .00495 L
.50353 .00495 L
.50607 .00495 L
.50877 .00495 L
.51138 .00495 L
.51414 .00495 L
.51681 .00495 L
.51937 .00495 L
.5221 .00495 L
.52459 .00495 L
s
.46126 .99505 m
.46383 .96284 L
.46663 .92715 L
.46926 .89308 L
.47179 .85979 L
.47448 .82377 L
.47708 .78852 L
.47983 .75038 L
.48249 .71298 L
.48504 .67636 L
.48776 .63668 L
.49038 .59774 L
.49289 .5596 L
.49557 .51819 L
.49815 .47754 L
.50089 .43341 L
.50353 .38998 L
.50607 .34731 L
.50877 .30088 L
.51138 .25514 L
.51414 .20536 L
.51681 .15617 L
.51937 .10764 L
.5221 .05467 L
.52459 .00495 L
s
.52459 .00495 m
.54367 .00495 L
.56449 .00495 L
.58403 .00495 L
.60283 .00495 L
.62284 .00495 L
.64211 .00495 L
.66258 .00495 L
.6823 .00495 L
.70128 .00495 L
.72147 .00495 L
.74091 .00495 L
.7596 .00495 L
.7795 .00495 L
.79865 .00495 L
.81902 .00495 L
.83863 .00495 L
.8575 .00495 L
.87758 .00495 L
.89691 .00495 L
.91745 .00495 L
.93724 .00495 L
.95628 .00495 L
.97654 .00495 L
.99505 .00495 L
s
.52459 .99505 m
.54367 .99505 L
.56449 .99505 L
.58403 .99505 L
.60283 .99505 L
.62284 .99505 L
.64211 .99505 L
.66258 .99505 L
.6823 .99505 L
.70128 .99505 L
.72147 .99505 L
.74091 .99505 L
.7596 .99505 L
.7795 .99505 L
.79865 .99505 L
.81902 .99505 L
.83863 .99505 L
.8575 .99505 L
.87758 .99505 L
.89691 .99505 L
.91745 .99505 L
.93724 .99505 L
.95628 .99505 L
.97654 .99505 L
.99505 .99505 L
s
.5 1 1 r
.52459 .00495 m
.54367 .00495 L
.56449 .00495 L
.58403 .00495 L
.60283 .00495 L
.62284 .00495 L
.64211 .00495 L
.66258 .00495 L
.6823 .00495 L
.70128 .00495 L
.72147 .00495 L
.74091 .00495 L
.7596 .00495 L
.7795 .00495 L
.79865 .00495 L
.81902 .00495 L
.83863 .00495 L
.8575 .00495 L
.87758 .00495 L
.89691 .00495 L
.91745 .00495 L
.93724 .00495 L
.95628 .00495 L
.97654 .00495 L
.99505 .00495 L
.99505 .99505 L
.97654 .99505 L
.95628 .99505 L
.93724 .99505 L
.91745 .99505 L
.89691 .99505 L
.87758 .99505 L
.8575 .99505 L
.83863 .99505 L
.81902 .99505 L
.79865 .99505 L
.7795 .99505 L
.7596 .99505 L
.74091 .99505 L
.72147 .99505 L
.70128 .99505 L
.6823 .99505 L
.66258 .99505 L
.64211 .99505 L
.62284 .99505 L
.60283 .99505 L
.58403 .99505 L
.56449 .99505 L
.54367 .99505 L
.52459 .99505 L
F
0 g
.52459 .00495 m
.54367 .00495 L
.56449 .00495 L
.58403 .00495 L
.60283 .00495 L
.62284 .00495 L
.64211 .00495 L
.66258 .00495 L
.6823 .00495 L
.70128 .00495 L
.72147 .00495 L
.74091 .00495 L
.7596 .00495 L
.7795 .00495 L
.79865 .00495 L
.81902 .00495 L
.83863 .00495 L
.8575 .00495 L
.87758 .00495 L
.89691 .00495 L
.91745 .00495 L
.93724 .00495 L
.95628 .00495 L
.97654 .00495 L
.99505 .00495 L
s
.52459 .99505 m
.54367 .99505 L
.56449 .99505 L
.58403 .99505 L
.60283 .99505 L
.62284 .99505 L
.64211 .99505 L
.66258 .99505 L
.6823 .99505 L
.70128 .99505 L
.72147 .99505 L
.74091 .99505 L
.7596 .99505 L
.7795 .99505 L
.79865 .99505 L
.81902 .99505 L
.83863 .99505 L
.8575 .99505 L
.87758 .99505 L
.89691 .99505 L
.91745 .99505 L
.93724 .99505 L
.95628 .99505 L
.97654 .99505 L
.99505 .99505 L
s
.46126 .99505 m
.46383 .96284 L
.46663 .92715 L
.46926 .89308 L
.47179 .85979 L
.47448 .82377 L
.47708 .78852 L
.47983 .75038 L
.48249 .71298 L
.48504 .67636 L
.48776 .63668 L
.49038 .59774 L
.49289 .5596 L
.49557 .51819 L
.49815 .47754 L
.50089 .43341 L
.50353 .38998 L
.50607 .34731 L
.50877 .30088 L
.51138 .25514 L
.51414 .20536 L
.51681 .15617 L
.51937 .10764 L
.5221 .05467 L
.52459 .00495 L
s
.46126 .99505 m
.46383 .99505 L
.46663 .99505 L
.46926 .99505 L
.47179 .99505 L
.47448 .99505 L
.47708 .99505 L
.47983 .99505 L
.48249 .99505 L
.48504 .99505 L
.48776 .99505 L
.49038 .99505 L
.49289 .99505 L
.49557 .99505 L
.49815 .99505 L
.50089 .99505 L
.50353 .99505 L
.50607 .99505 L
.50877 .99505 L
.51138 .99505 L
.51414 .99505 L
.51681 .99505 L
.51937 .99505 L
.5221 .99505 L
.52459 .99505 L
s
.5 1 1 r
.46126 .99505 m
.46383 .96284 L
.46663 .92715 L
.46926 .89308 L
.47179 .85979 L
.47448 .82377 L
.47708 .78852 L
.47983 .75038 L
.48249 .71298 L
.48504 .67636 L
.48776 .63668 L
.49038 .59774 L
.49289 .5596 L
.49557 .51819 L
.49815 .47754 L
.50089 .43341 L
.50353 .38998 L
.50607 .34731 L
.50877 .30088 L
.51138 .25514 L
.51414 .20536 L
.51681 .15617 L
.51937 .10764 L
.5221 .05467 L
.52459 .00495 L
.52459 .99505 L
.5221 .99505 L
.51937 .99505 L
.51681 .99505 L
.51414 .99505 L
.51138 .99505 L
.50877 .99505 L
.50607 .99505 L
.50353 .99505 L
.50089 .99505 L
.49815 .99505 L
.49557 .99505 L
.49289 .99505 L
.49038 .99505 L
.48776 .99505 L
.48504 .99505 L
.48249 .99505 L
.47983 .99505 L
.47708 .99505 L
.47448 .99505 L
.47179 .99505 L
.46926 .99505 L
.46663 .99505 L
.46383 .99505 L
.46126 .99505 L
F
0 g
.46126 .99505 m
.46383 .96284 L
.46663 .92715 L
.46926 .89308 L
.47179 .85979 L
.47448 .82377 L
.47708 .78852 L
.47983 .75038 L
.48249 .71298 L
.48504 .67636 L
.48776 .63668 L
.49038 .59774 L
.49289 .5596 L
.49557 .51819 L
.49815 .47754 L
.50089 .43341 L
.50353 .38998 L
.50607 .34731 L
.50877 .30088 L
.51138 .25514 L
.51414 .20536 L
.51681 .15617 L
.51937 .10764 L
.5221 .05467 L
.52459 .00495 L
s
.46126 .99505 m
.46383 .99505 L
.46663 .99505 L
.46926 .99505 L
.47179 .99505 L
.47448 .99505 L
.47708 .99505 L
.47983 .99505 L
.48249 .99505 L
.48504 .99505 L
.48776 .99505 L
.49038 .99505 L
.49289 .99505 L
.49557 .99505 L
.49815 .99505 L
.50089 .99505 L
.50353 .99505 L
.50607 .99505 L
.50877 .99505 L
.51138 .99505 L
.51414 .99505 L
.51681 .99505 L
.51937 .99505 L
.5221 .99505 L
.52459 .99505 L
s
1 0 0 r
.02 w
.19952 .78592 Mdot
.11998 .52055 Mdot
.35491 .83474 Mdot
.3554 .34672 Mdot
.0072 .89729 Mdot
.30746 .43669 Mdot
.36539 .67123 Mdot
.20317 .34479 Mdot
.19388 .91671 Mdot
.33213 .82124 Mdot
.42016 .221 Mdot
.38943 .90797 Mdot
.22559 .43013 Mdot
.27441 .39237 Mdot
.37069 .59045 Mdot
.41901 .0506 Mdot
.36843 .68821 Mdot
.11649 .60896 Mdot
.00799 .02192 Mdot
.41332 .26912 Mdot
.31411 .10026 Mdot
.08615 .44293 Mdot
.39395 .87431 Mdot
.19671 .53001 Mdot
.17331 .44913 Mdot
.42231 .14258 Mdot
.30262 .85373 Mdot
.00825 .09693 Mdot
.43419 .17047 Mdot
.39175 .48302 Mdot
.43115 .1535 Mdot
.47843 .21885 Mdot
.12198 .05818 Mdot
.39724 .77098 Mdot
.22803 .17892 Mdot
.20548 .24592 Mdot
.05967 .72485 Mdot
.28317 .10828 Mdot
.25705 .86617 Mdot
.27988 .0163 Mdot
.32286 .70065 Mdot
.38812 .52833 Mdot
.39171 .5521 Mdot
.40969 .31442 Mdot
.27468 .49887 Mdot
.0174 .5385 Mdot
.0516 .32489 Mdot
.31192 .29753 Mdot
.49193 .5951 Mdot
.0337 .1942 Mdot
.23983 .72398 Mdot
.25382 .18285 Mdot
.41697 .02828 Mdot
.3657 .64957 Mdot
.03021 .47123 Mdot
.45601 .34009 Mdot
.25553 .96741 Mdot
.44357 .79664 Mdot
.20888 .64747 Mdot
.1366 .50406 Mdot
.21695 .05732 Mdot
.10785 .31482 Mdot
.47712 .3284 Mdot
.35403 .13692 Mdot
.0651 .30507 Mdot
.48832 .4824 Mdot
.03985 .82889 Mdot
.03726 .14726 Mdot
.28432 .85652 Mdot
.09369 .34567 Mdot
.08039 .21401 Mdot
.4571 .83666 Mdot
.36343 .16163 Mdot
.3542 .52679 Mdot
.38631 .82828 Mdot
.00513 .39482 Mdot
.32615 .52817 Mdot
.0168 .90747 Mdot
.29126 .69433 Mdot
.47954 .76516 Mdot
.01189 .83285 Mdot
.3908 .42444 Mdot
.43151 .6238 Mdot
.4337 .58283 Mdot
.07303 .46712 Mdot
.08445 .06099 Mdot
.18672 .63388 Mdot
.08428 .66122 Mdot
.36056 .11067 Mdot
.07242 .7488 Mdot
.07425 .41139 Mdot
.09288 .97869 Mdot
.06731 .57358 Mdot
.20208 .5592 Mdot
.1358 .94483 Mdot
.26839 .97142 Mdot
.06773 .48266 Mdot
.18889 .91538 Mdot
.38101 .84383 Mdot
.10956 .25911 Mdot
0 0 1 r
.97461 .73811 Mdot
.95791 .50536 Mdot
.54886 .33168 Mdot
.5508 .52172 Mdot
.61122 .75315 Mdot
.74793 .95757 Mdot
.74207 .80336 Mdot
.51632 .9812 Mdot
.80485 .32565 Mdot
.70025 .07076 Mdot
.68586 .47687 Mdot
.80486 .8067 Mdot
.7063 .73381 Mdot
.842 .30628 Mdot
.65744 .40708 Mdot
.7912 .77961 Mdot
.54622 .64898 Mdot
.54327 .81709 Mdot
.79919 .84067 Mdot
.52695 .83095 Mdot
.98939 .51997 Mdot
.82175 .76513 Mdot
.80354 .04804 Mdot
.51689 .95349 Mdot
.59724 .30929 Mdot
.66994 .65215 Mdot
.93485 .89725 Mdot
.87379 .86759 Mdot
.88863 .25322 Mdot
.83052 .05545 Mdot
.58944 .4076 Mdot
.80357 .21955 Mdot
.59509 .88268 Mdot
.97686 .44946 Mdot
.78661 .83959 Mdot
.95997 .49103 Mdot
.68937 .53525 Mdot
.79003 .83392 Mdot
.74957 .63305 Mdot
.91128 .96138 Mdot
.85599 .38478 Mdot
.58076 .91089 Mdot
.76655 .97223 Mdot
.77224 .69629 Mdot
.67146 .09449 Mdot
.79043 .25178 Mdot
.8799 .24995 Mdot
.82551 .7558 Mdot
.69053 .70975 Mdot
.53548 .91693 Mdot
.93601 .08165 Mdot
.61925 .95059 Mdot
.58002 .69192 Mdot
.53849 .04465 Mdot
.80851 .71475 Mdot
.76129 .34341 Mdot
.63705 .6252 Mdot
.96591 .09658 Mdot
.7522 .3802 Mdot
.6404 .33583 Mdot
.56167 .6655 Mdot
.60492 .41395 Mdot
.62071 .58879 Mdot
.98072 .4584 Mdot
.5407 .89192 Mdot
.94223 .4187 Mdot
.72724 .18212 Mdot
.68094 .08024 Mdot
.59018 .55197 Mdot
.71007 .97871 Mdot
.83303 .17673 Mdot
.56967 .64783 Mdot
.77136 .50628 Mdot
.9598 .23883 Mdot
.65065 .91253 Mdot
.97413 .77548 Mdot
.60995 .02557 Mdot
.53189 .36173 Mdot
.87777 .83849 Mdot
.84601 .28644 Mdot
.78758 .29147 Mdot
.63593 .30278 Mdot
.9496 .11969 Mdot
.56627 .65 Mdot
.67824 .60846 Mdot
.60152 .41611 Mdot
.52759 .69098 Mdot
.62244 .63568 Mdot
.91269 .67037 Mdot
.59055 .2789 Mdot
.53492 .82692 Mdot
.73959 .98751 Mdot
.74239 .54041 Mdot
.60366 .68968 Mdot
.78784 .42566 Mdot
.53739 .04464 Mdot
.6096 .81225 Mdot
.93092 .62357 Mdot
.58201 .12622 Mdot
.80848 .98294 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00ool0000Po`000040oooo003oo`00023o00000@3oool00003o`00003oogl0oomo09<0oomo
00?o000007ooo`1oool0Q01oool10?ooo`7o00000@3oool00003o`00003oogl0oomo04`0oomo0ooo
00140?ooO`03o`00001oool0Oooo08@0Oooo0@3oool1o`000040oooo00000ol0003oo`00ool0001;
0?ooO`Goo`00@`3oogl00ol00000Oooo07ooo`2407ooo`40oooo0Ol000010?ooo`0000Co0000ool0
0?oo003oo`00BP3oogl5ool004<0oomo00?o000007ooo`1oool0501oool3o`00ofd0Oooo0@3oool1
o`000040oooo00001?l0003oo`00ool00?oo001:0?ooO`Goo`008`3oogl3ool001d0oomo00?o0000
07ooo`1oool04`1oool5o`00of`0Oooo0@3oool1o`000040oooo00001?l0003oo`00ool00?oo001;
0?ooO`?oo`008`3oogl5ool001`0oomo00?o000007ooo`1oool04`1oool5o`00of`0Oooo0@3oool1
o`000040oooo00000ol0003oo`00ool0001b0?ooO`Goo`00703oogl00ol00000Oooo07ooo`0C07oo
o`Go003oK01oool10?ooo`7o00000@3oool00003o`00003oogl0oomo0780oomo1Ooo000K0?ooO`03
o`00001oool0Oooo01D0Oooo0ol00?m]07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0
L`3oogl3ool001`0oomo00?o000007ooo`1oool0Q@1oool10?ooo`7o00000@3oool00003o`00003o
ogl0oomo0980oomo00?o000007ooo`1oool01?l00?n107ooo`40oooo0Ol000010?ooo`0000?o0000
0?ooO`3oogl0L`3oogl3ool001`0oomo00?o000007ooool00?l01Ol00?m807ooo`?o003o=@1oool1
0?ooo`7o00000@3oool00003o`00003oogl0oomo0780oomo1Ooo000K0?ooO`03o`00001ooooo003o
00Go003oA`1oool5o`00oc@0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0j0?ooO`?o
o`00=@3oogl5ool001/0oomo00?o000007ooool00?l01Ol00?m707ooo`Go003o0`1oool3o`00obh0
Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0D0?ooO`?oo`001`3oogl3ool001P0oomo
1Ooo000d0?ooO`Goo`006`3oogl00ol00000Oooo07ooo`04o`00odP0Oooo1Ol00?l207ooo`Go003o
;@1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo01<0oomo1Ooo00050?ooO`Goo`005`3o
ogl5ool003D0oomo0ooo000L0?ooO`03o`00001oool0Oooo04d0Oooo0ol00?l307ooo`Go003o;@1o
ool10?ooo`7o00000@3oool00003o`00003oogl0oomo01<0oomo1Ooo00050?ooO`Goo`005`3oogl5
ool005@0oomo00?o000007ooo`1oool0D`1oool5o`00obd0Oooo0@3oool1o`000040oooo00000ol0
0000oomo0?ooO`0C0?ooO`Goo`001@3oogl5ool001P0oomo0ooo001E0?ooO`03o`00001oool0Oooo
02l0Oooo0ol00?lR07ooo`?o003o;P1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo01@0
oomo0ooo00070?ooO`?oo`00L@3oogl00ol00000Oooo07ooo`0^07ooo`Go003oDP1oool10?ooo`7o
00000@3oool00003o`00003oogl0oomo0980oomo00?o000007ooo`1oool0;P1oool5o`00oe80Oooo
0@3oool1o`000040oooo00000ol00000oomo0?ooO`2B0?ooO`03o`00001oool0Oooo02X0Oooo0ol0
0?l00`1ooooo003oo`00o`03o`00od00Oooo0ol00?l?07ooo`40oooo0Ol000010?ooo`0000?o0000
0?ooO`3oogl0TP3oogl00ol00000Oooo07ooo`0Y07ooo`Go003o00@0Ooooo`00ool00?oo003o@01o
ool5o`00o`h0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`2B0?ooO`03o`00001oool0
Oooo02T0Oooo1Ol00?m407ooo`Go003o3P1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo
0980oomo00?o000007ooo`1oool0:@1oool5o`00od@0Oooo1Ol00?l>07ooo`40oooo0Ol000010?oo
o`0000?o00000?ooO`3oogl0TP3oogl00ol00000Oooo07ooo`0W07ooo`Ko003oAP1oool3o`00o`l0
Oooo0@3oool1o`000040oooo00000ol0003oo`00ool0002B0?ooO`03o`00001oool0Oooo02H0Oooo
1Ol00?m@07ooo`?o003o1`1oool10?ooo`7o00000@3oool00004o`000?oo003oo`00ool005@0oomo
0ooo000j0?ooO`03o`00001oool0Oooo02H0Oooo1Ol00?m?07ooo`Go003o1P1oool10?ooo`7o0000
0@3oool00004o`000?oo003oo`00ool005<0oomo1Ooo000i0?ooO`03o`00001oool0Oooo02H0Oooo
1Ol00?m?07ooo`Go003o1P1oool10?ooo`7o00000@3oool00004o`000?oo003oo`00ool004`0oomo
0ooo00040?ooO`Goo`00>@3oogl00ol00000Oooo07ooo`0W07ooo`?o003oD01oool5o`00o`H0Oooo
0@3oool1o`000040oooo00000ol0003oo`00ool0001<0?ooO`Goo`000`3oogl5ool000X0oomo0ooo
000/0?ooO`03o`00001oool0Oooo07/0Oooo0ol00?l707ooo`40oooo0Ol000010?ooo`0000?o0000
0?ooO`3oogl0C03oogl5ool000@0oomo0ooo000:0?ooO`Goo`00:`3oogl00ol00000Oooo07ooo`25
07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0C03oogl5ool00140oomo1Ooo000[0?oo
O`03o`00001oool0Oooo07L0Oooo0ol00?l;07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3o
ogl0C@3oogl3ool00180oomo1Ooo000[0?ooO`03o`00001oool0Oooo07H0Oooo1Ol00?l:07ooo`40
oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0H`3oogl3ool002`0oomo00?o000007ooo`1oool0
3@1oool3o`00ofH0Oooo1Ol00?l:07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0TP3o
ogl00ol00000Oooo07ooo`0<07ooo`Go003oI@1oool5o`00o`X0Oooo0@3oool1o`000040oooo0000
0ol00000oomo0?ooO`2B0?ooO`03o`00001oool0Oooo00`0Oooo1Ol00?mV07ooo`?o003o2`1oool1
0?ooo`7o00000@3oool00003o`00003oogl0oomo0640oomo0ooo000^0?ooO`03o`00001oool0Oooo
00`0Oooo1Ol00?md07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0H03oogl5ool002`0
oomo00?o000007ooo`1oool03P1oool3o`00ogD0Oooo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`1P0?ooO`Goo`003`3oogl3ool001X0oomo00?o000007ooo`1oool0QP1oool10?ooo`7o0000
0@3oool00003o`00003oogl0oomo00H0oomo0ooo001G0?ooO`Goo`003P3oogl5ool001T0oomo00?o
000007ooo`1oool0QP1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo00D0oomo1Ooo001G
0?ooO`?oo`003`3oogl5ool001T0oomo00?o000007ooo`1oool0QP1oool10?ooo`7o00000@3oool0
0003o`00003oogl0oomo00D0oomo1Ooo001Y0?ooO`Ooo`005`3oogl00ol00000Oooo07ooo`2607oo
o`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl01@3oogl5ool006X0oomo1ooo000F0?ooO`03
o`00001oool0Oooo08H0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`060?ooO`?oo`00
F`3oogl3ool000l0oomo1Ooo000F0?ooO`03o`00001oool0Oooo08H0Oooo0@3oool1o`000040oooo
00000ol00000oomo0?ooO`1S0?ooO`Goo`003P3oogl5ool001H0oomo00?o000007ooo`1oool0QP1o
ool10?ooo`7o00000@3oool00003o`00003oogl0oomo06<0oomo1Ooo000?0?ooO`?oo`005`3oogl0
0ol00000Oooo07ooo`2607ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0H`3oogl5ool0
0100oomo0ooo000F0?ooO`03o`00001oool0Oooo08H0Oooo0@3oool1o`000040oooo00000ol00000
oomo0?ooO`1T0?ooO`?oo`00403oogl5ool001D0oomo00?o000007ooo`1oool0QP1oool10?ooo`7o
00000@3oool00003o`00003oogl0oomo03d0oomo0ooo000g0?ooO`Goo`005@3oogl00ol00000Oooo
07ooo`1F07ooo`?o003o;@1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo03`0oomo1Ooo
00030?ooO`?oo`00<03oogl5ool001D0oomo00?o000007ooo`1oool0>01oool3o`00oaX0Oooo1Ol0
0?l/07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0?03oogl5ool00080oomo1Ooo000`
0?ooO`?oo`005P3oogl00ol00000Oooo07ooo`0g07ooo`Go003o6@1oool5o`00ob`0Oooo0@3oool1
o`000040oooo00000ol00000oomo0?ooO`0l0?ooO`Goo`000P3oogl5ool004P0oomo00?o000007oo
o`1oool0>01oool5o`00oaT0Oooo1Ol00?l/07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3o
ogl0?@3oogl3ool000<0oomo1Ooo00180?ooO`03o`00001oool0Oooo03P0Oooo1Ol00?lJ07ooo`?o
003o;@1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo00D0oomo0ooo000l0?ooO`?oo`00
B@3oogl00ol00000Oooo07ooo`0i07ooo`?o003oB`1oool10?ooo`7o00000@3oool00003o`00003o
ogl0oomo00@0oomo1Ooo00270?ooO`03o`00001oool0Oooo08L0Oooo0@3oool1o`000040oooo0000
0ol00000oomo0?ooO`040?ooO`Goo`00Q`3oogl00ol00000Oooo07ooo`2707ooo`40oooo0Ol00001
0?ooo`0000?o00000?ooO`3oogl0103oogl5ool008L0oomo00?o000007ooo`1oool0Q`1oool10?oo
o`7o00000@3oool00003o`00003oogl0oomo00D0oomo0ooo00280?ooO`03o`00001oool0Oooo08L0
Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0B0?ooO`?oo`00N`3oogl00ol00000Oooo
07ooo`2707ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl04@3oogl5ool007X0oomo00?o
000007ooo`1oool0Q`1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo0140oomo1Ooo001N
0?ooO`?oo`003P3oogl3ool000P0oomo00?o000007ooo`1oool0C`1oool3o`00ocD0Oooo0@3oool1
o`000040oooo00000ol00000oomo0?ooO`0A0?ooO`Goo`00G@3oogl5ool000`0oomo1Ooo00070?oo
O`03o`00001oool0Oooo04h0Oooo1Ol00?ld07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3o
ogl04P3oogl3ool005h0oomo1Ooo000<0?ooO`Goo`001`3oogl00ol00000Oooo07ooo`1>07ooo`Go
003o=01oool10?ooo`7o00000@3oool00003o`00003oogl0oomo07<0oomo1Ooo000<0?ooO`Goo`00
1`3oogl00ol00000Oooo07ooo`1>07ooo`Go003o=01oool10?ooo`7o00000@3oool00003o`00003o
ogl0oomo07@0oomo0ooo000>0?ooO`?oo`00203oogl00ol00000Oooo07ooo`1?07ooo`?o003o=@1o
ool10?ooo`7o00000@3oool00003o`00003oogl0oomo0900oomo00?o000007ooo`1oool0O01oool3
o`00o`P0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`2?0?ooO`03o`00001oool0Oooo
07`0Oooo1Ol00?l707ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0=P3oogl3ool005H0
oomo00?o000007ooo`1oool0O01oool5o`00o`L0Oooo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`0e0?ooO`Goo`00E@3oogl00ol00000Oooo07ooo`1l07ooo`Go003o1`1oool10?ooo`7o0000
0@3oool00003o`00003oogl0oomo03D0oomo1Ooo001E0?ooO`03o`00001oool0Oooo04`0Oooo0ol0
0?lG07ooo`?o003o501oool3o`00o`P0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0e
0?ooO`Goo`00E@3oogl00ol00000Oooo07ooo`1;07ooo`Go003o5@1oool6o`00oad0Oooo0@3oool1
o`000040oooo00000ol00000oomo0?ooO`0K0?ooO`?oo`00603oogl3ool005H0oomo00?o000007oo
o`1oool0B`1oool5o`00oaD0Oooo1ol00?lL07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3o
ogl06P3oogl5ool00700oomo00?o000007ooo`1oool0B`1oool5o`00oaD0Oooo1ol00?lL07ooo`40
oooo0Ol000010?ooo`0000?o00000?ooO`3oogl06P3oogl5ool00700oomo00?o000007ooo`1oool0
C01oool3o`00oaL0Oooo1_l00?lL07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl06P3o
ogl5ool005<0oomo0ooo000J0?ooO`03o`00001oool0Oooo06P0Oooo0ol00?lM07ooo`40oooo0Ol0
00010?ooo`0000?o00000?ooO`3oogl06`3oogl3ool005<0oomo1Ooo000I0?ooO`03o`00001oool0
Oooo08P0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`1a0?ooO`Goo`006@3oogl00ol0
0000Oooo07ooo`2807ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0L@3oogl5ool001T0
oomo00?o000007ooo`1oool04`1oool3o`00og80Oooo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`1b0?ooO`?oo`006P3oogl00ol00000Oooo07ooo`0B07ooo`Go003oL@1oool10?ooo`7o0000
0@3oool00003o`00003oogl0oomo08l0oomo00?o000007ooo`1oool04P1oool5o`00odD0Oooo0ol0
0?lY07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0S`3oogl00ol00000Oooo07ooo`0B
07ooo`Go003oA01oool5o`00obP0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`2?0?oo
O`03o`00001oool0Oooo01<0Oooo0ol00?le07ooo`?o003o3@1oool5o`00obP0Oooo0@3oool1o`00
0040oooo00000ol00000oomo0?ooO`1E0?ooO`?oo`00=`3oogl00ol00000Oooo07ooo`1:07ooo`Go
003o301oool5o`00obP0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`1D0?ooO`Goo`00
=P3oogl00ol00000Oooo07ooo`1:07ooo`Go003o3@1oool3o`00obT0Oooo0@3oool1o`000040oooo
00000ol00000oomo0?ooO`0>0?ooO`?oo`00@`3oogl5ool003H0oomo00?o000007ooo`1oool0801o
ool3o`00obL0Oooo1Ol00?li07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl03@3oogl5
ool00480oomo1Ooo000f0?ooO`03o`00001oool0Oooo01l0Oooo1Ol00?lW07ooo`?o003o3@1oool3
o`00obX0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0=0?ooO`Goo`00@`3oogl3ool0
03L0oomo00?o000007ooo`1oool05@1oool3o`00o`L0Oooo1Ol00?lf07ooo`Go003o:@1oool10?oo
o`7o00000@3oool00003o`00003oogl0oomo00d0oomo1Ooo00080?ooO`?oo`00E03oogl3ool001/0
oomo00?o000007ooo`1oool0501oool5o`00o`H0Oooo1Ol00?lf07ooo`Go003o:@1oool10?ooo`7o
00000@3oool00003o`00003oogl0oomo00h0oomo0ooo00080?ooO`Goo`00DP3oogl5ool001X0oomo
00?o000007ooo`1oool0501oool5o`00o`L0Oooo0ol00?lg07ooo`Go003o:@1oool10?ooo`7o0000
0@3oool00003o`00003oogl0oomo01T0oomo1Ooo001B0?ooO`Goo`006P3oogl00ol00000Oooo07oo
o`0D07ooo`Go003o@P1oool3o`00obX0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0:
0?ooO`?oo`00303oogl5ool00580oomo1Ooo000J0?ooO`03o`00001oool0Oooo01D0Oooo0ol00?lh
07ooo`?o003o=@1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo00T0oomo1Ooo000<0?oo
O`?oo`00E03oogl3ool00100oomo0ooo00080?ooO`03o`00001oool0Oooo04l0Oooo1Ol00?ld07oo
o`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl02@3oogl5ool007D0oomo1Ooo00060?ooO`03
o`00001oool0Oooo00P0Oooo0ol00?m507ooo`Go003o=01oool10?ooo`7o00000@3oool00003o`00
003oogl0oomo00T0oomo1Ooo001e0?ooO`Goo`001P3oogl00ol00000Oooo07ooo`0707ooo`Go003o
5P1oool3o`00ob/0Oooo1Ol00?ld07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl02P3o
ogl3ool00740oomo0ooo00020?ooO`Goo`001P3oogl00ol00000Oooo07ooo`0707ooo`Go003o5@1o
ool5o`00ob/0Oooo0ol00?le07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0O@3oogl5
ool00080oomo0ooo00070?ooO`03o`00001oool0Oooo00L0Oooo1Ol00?lE07ooo`Go003o7`1oool3
o`00od40Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0F0?ooO`?oo`007@3oogl3ool0
02P0oomo0ooo000I0?ooO`Goo`00303oogl00ol00000Oooo07ooo`0807ooo`?o003o5P1oool5o`00
oah0Oooo1Ol00?m007ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl05@3oogl5ool001/0
oomo1Ooo000V0?ooO`Goo`00603oogl5ool000`0oomo00?o000007ooo`1oool08P1oool3o`00oal0
Oooo1Ol00?m007ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl05@3oogl5ool001/0oomo
1Ooo000V0?ooO`Goo`006@3oogl3ool000d0oomo00?o000007ooo`1oool0A01oool5o`00od00Oooo
0@3oool1o`000040oooo00000ol00000oomo0?ooO`0E0?ooO`Goo`006`3oogl5ool002H0oomo1Ooo
000Y0?ooO`03o`00001oool0Oooo04D0Oooo0ol00?m107ooo`40oooo0Ol000010?ooo`0000?o0000
0?ooO`3oogl05P3oogl3ool001d0oomo0ooo000X0?ooO`?oo`00:P3oogl00ol00000Oooo07ooo`29
07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0SP3oogl00ol00000Oooo07ooo`0307oo
o`?o003oP`1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo08h0oomo00?o000007ooo`1o
ool00P1oool5o`00oh80Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`2>0?ooO`03o`00
001oool0Oooo0080Oooo1Ol00?n207ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0SP3o
ogl00ol00000Oooo07ooo`0207ooo`Go003oPP1oool10?ooo`7o00000@3oool00003o`00003oogl0
oomo08d0oomo00?o000007ooo`1oool0101oool3o`00oh<0Oooo0@3oool1o`000040oooo00000ol0
0000oomo0?ooO`2=0?ooO`03o`00001oool0Oooo04<0Oooo0ol00?m407ooo`40oooo0Ol000010?oo
o`0000?o00000?ooO`3oogl0S@3oogl00ol00000Oooo07ooo`1207ooo`Go003o6P1oool3o`00obH0
Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`2=0?ooO`03o`00001oool0Oooo0480Oooo
1Ol00?lI07ooo`Go003o9@1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo04X0oomo0ooo
00100?ooO`03o`00001oool0Oooo0480Oooo1Ol00?lI07ooo`Go003o9@1oool10?ooo`7o00000@3o
ool00003o`000?oo0000oomo04T0oomo1Ooo000o0?ooO`03o`00001oool0Oooo04<0Oooo0ol00?lJ
07ooo`Go003o9@1oool10?ooo`7o00000@3oool00003o`000?oo003oo`0004T0oomo1Ooo000o0?oo
O`03o`00001oool0Oooo0640Oooo0ol00?lV07ooo`40oooo0Ol000010?ooo`0000?o0000ool00?oo
0000B@3oogl5ool003l0oomo00?o000007ooo`1oool0RP1oool10?ooo`7o00000@3oool00003o`00
0?oo003oo`0004X0oomo0ooo00100?ooO`03o`00001oool0Oooo08X0Oooo0@3oool1o`000040oooo
00000ol0003oo`000?ooO`2=0?ooO`03o`00001oool0Oooo01@0Oooo0ol00?lA07ooo`?o003oG`1o
ool10?ooo`7o00000@3oool00003o`00003oogl0oomo0140oomo0ooo001i0?ooO`03o`00001oool0
Oooo01<0Oooo1Ol00?l?07ooo`Go003oGP1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo
0100oomo1Ooo001h0?ooO`03o`00001oool0Oooo01<0Oooo2Ol00?l;07ooo`Go003oGP1oool10?oo
o`7o00000@3oool00003o`00003oogl0oomo0100oomo1Ooo001g0?ooO`03o`00001oool0Oooo01@0
Oooo2_l00?l:07ooo`Go003oC@1oool3o`00o`h0Oooo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`0@0?ooO`Goo`00M`3oogl00ol00000Oooo07ooo`0E07ooo`Wo003o2`1oool3o`00odd0Oooo
1Ol00?l=07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl04@3oogl3ool005L0oomo0ooo
000N0?ooO`03o`00001oool0Oooo01P0Oooo1_l00?l`07ooo`?o003o:01oool5o`00o`d0Oooo0@3o
ool1o`000040oooo00000ol00000oomo0?ooO`0l0?ooO`?oo`00:`3oogl5ool001d0oomo00?o0000
07ooo`1oool06@1oool4o`00oc00Oooo1Ol00?lW07ooo`Go003o3@1oool10?ooo`7o00000@3oool0
0003o`00003oogl0oomo03/0oomo1Ooo000Z0?ooO`Goo`007@3oogl00ol00000Oooo07ooo`1=07oo
o`Go003o:01oool3o`00o`h0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0k0?ooO`Go
o`004`3oogl3ool001@0oomo1Ooo000M0?ooO`03o`00001oool0Oooo04d0Oooo1Ol00?li07ooo`40
oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0>`3oogl5ool00180oomo1Ooo000D0?ooO`?oo`00
7P3oogl00ol00000Oooo07ooo`1>07ooo`?o003o>P1oool10?ooo`7o00000@3oool00003o`00003o
ogl0oomo01@0oomo0ooo000U0?ooO`?oo`004`3oogl5ool003D0oomo00?o000007ooo`1oool0R`1o
ool10?ooo`7o00000@3oool00003o`00003oogl0oomo01<0oomo1Ooo000j0?ooO`Goo`00=@3oogl0
0ol00000Oooo07ooo`2;07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl04`3oogl5ool0
01D0oomo0ooo000S0?ooO`?oo`00=P3oogl00ol00000Oooo07ooo`2407ooo`?o003o101oool10?oo
o`7o00000@3oool00003o`00003oogl0oomo01<0oomo1Ooo000D0?ooO`Goo`00F`3oogl00ol00000
Oooo07ooo`2307ooo`Go003o0`1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo01@0oomo
0ooo000E0?ooO`Goo`00F`3oogl00ol00000Oooo07ooo`2307ooo`Ko003o0P1oool10?ooo`7o0000
0@3oool00003o`00003oogl0oomo02`0oomo1Ooo001K0?ooO`03o`00001oool0Oooo08<0Oooo1ol0
0?l00`1oool0ooooo`0000010?ooo`0000?o00000?ooO`3oogl0;@3oogl3ool005/0oomo00?o0000
07ooo`1oool0Q@1oool6o`00o`0307ooo`3ooooo00000040oooo00000ol00000oomo0?ooO`0@0?oo
O`?oo`00N03oogl00ol00000Oooo07ooo`2607ooo`Go003o00<0Oooo0?ooool000000@3oool00003
o`00003oogl0oomo00@0oomo0ooo00080?ooO`Goo`00M`3oogl00ol00000Oooo07ooo`2707ooo`?o
003o0P1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo00<0oomo1Ooo00070?ooO`Goo`00
M`3oogl00ol00000Oooo07ooo`2<07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl00`3o
ogl5ool000L0oomo1Ooo001g0?ooO`03o`00001oool0Oooo0380Oooo0ol00?mG07ooo`40oooo0Ol0
00010?ooo`0000?o00000?ooO`3oogl00`3oogl5ool000L0oomo1?oo001I0?ooO`?oo`00603oogl3
ool000030?ooOol00000Oooo0380Oooo1Ol00?mF07ooo`40oooo0Ol000010?ooo`0000?o00000?oo
O`3oogl0103oogl3ool000L0oomo1Ooo001H0?ooO`Goo`005P3oogl5ool00003o`00001oool0Oooo
0340Oooo1Ol00?mF07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl03P3oogl5ool005P0
oomo1Ooo000F0?ooO`Goo`0000?o000007ooo`1oool0<@1oool5o`00oeH0Oooo0@3oool1o`000040
oooo00000ol00000oomo0?ooO`0>0?ooO`Goo`00F03oogl5ool001H0oomo1Ooo00000ol00000Oooo
07ooo`0b07ooo`?o003oC01oool3o`00o`P0Oooo0@3oool1o`000040oooo00000ol00000oomo0?oo
O`0?0?ooO`?oo`00FP3oogl3ool001P0oomo0ooo00000`3oogoo000007ooo`2107ooo`Go003o1`1o
ool10?ooo`7o00000@3oool00003o`00003oogl0oomo04X0oomo0ooo000n0?ooO`03o`00001oool0
Oooo0800Oooo1Ol00?l707ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl08P3oogl3ool0
02@0oomo1Ooo000m0?ooO`03o`00001oool0Oooo0800Oooo1Ol00?l707ooo`40oooo0Ol000010?oo
o`0000?o00000?ooO`3oogl08@3oogl5ool002<0oomo1Ooo000m0?ooO`03o`00001oool0Oooo04/0
Oooo0ol00?lb07ooo`Co003o201oool10?ooo`7o00000@3oool00003o`00003oogl0oomo0240oomo
1Ooo000S0?ooO`Goo`00?@3oogl00ol00000Oooo07ooo`1:07ooo`Go003o<01oool5o`00o`P0Oooo
0@3oool1o`000040oooo00000ol00000oomo0?ooO`0Q0?ooO`Goo`00903oogl3ool003h0oomo00?o
000007ooo`1oool0BP1oool5o`00oc00Oooo1Ol00?l807ooo`40oooo0Ol000010?ooo`0000?o0000
0?ooO`3oogl08P3oogl3ool006H0oomo00?o000007ooo`1oool0BP1oool5o`00oc00Oooo1Ol00?l8
07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl07P3oogl3ool006X0oomo00?o000007oo
o`1oool0B`1oool3o`00oc80Oooo0ol00?l607ooo`?o003o0@3oool1o`000040oooo00000ol00000
oomo0?ooO`0M0?ooO`Goo`00J@3oogl00ol00000Oooo07ooo`0;07ooo`?o003oNP1oool5o`00o`7o
00000@3oool00003o`00003oogl0oomo01d0oomo1Ooo000g0?ooO`?oo`001@3oogl3ool000L0oomo
0ooo000M0?ooO`03o`00001oool0Oooo00X0Oooo1Ol00?mi07ooo`Go003o0Ol000010?ooo`0000?o
00000?ooO`3oogl07@3oogl5ool00180oomo0ooo000Q0?ooO`Goo`000`3oogl5ool000D0oomo1Ooo
000L0?ooO`03o`00001oool0Oooo00X0Oooo1Ol00?mi07ooo`Go003o0Ol000010?ooo`0000?o0000
0?ooO`3oogl07P3oogl3ool00180oomo1Ooo000P0?ooO`Goo`000`3oogl5ool000D0oomo1Ooo000L
0?ooO`03o`00001oool0Oooo00X0Oooo1Ol00?lT07ooo`?o003oD`1oool3o`00o`40oooo0Ol00001
0?ooo`0000?o00000?ooO`3oogl00ooo000`0?ooO`Goo`00803oogl5ool000<0oomo1Ooo00050?oo
O`Goo`00703oogl00ol00000Oooo07ooo`0;07ooo`?o003o901oool5o`00oeD0Oooo0@3oool1o`00
0040oooo00000ol00000oomoool00004ool002l0oomo1Ooo000Q0?ooO`?oo`001@3oogl3ool000L0
oomo0ooo000M0?ooO`03o`00001oool0Oooo0380Oooo1Ol00?l;07ooo`?o003oA`1oool10?ooo`7o
00000@3oool00003o`00003oogooo`0000Coo`00<03oogl3ool005@0oomo00?o000007ooo`1oool0
<P1oool5o`00o`X0Oooo1Ol00?m607ooo`40oooo0Ol000010?ooo`0000?o00000?ooOooo00001?oo
00260?ooO`03o`00001oool0Oooo03@0Oooo0ol00?l;07ooo`Go003oAP1oool10?ooo`7o00000@3o
ool00003o`00003oogl0oomo00?oo`00J@3oogl3ool001/0oomo00?o000007ooo`1oool0601oool3
o`00obL0Oooo1Ol00?m607ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0J`3oogl5ool0
01X0oomo00?o000007ooo`1oool05`1oool5o`00obL0Oooo0ol00?m707ooo`40oooo0Ol000010?oo
o`0000?o00000?ooO`3oogl0=@3oogl3ool003<0oomo1Ooo000J0?ooO`03o`00001oool0Oooo01L0
Oooo1Ol00?ma07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0=03oogl5ool00380oomo
1Ooo000J0?ooO`03o`00001oool0Oooo01L0Oooo1Ol00?ma07ooo`40oooo0Ol000010?ooo`0000?o
00000?ooO`3oogl0=03oogl5ool003<0oomo0ooo000K0?ooO`03o`00001oool0Oooo01P0Oooo0ol0
0?mb07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0=03oogl5ool00540oomo00?o0000
07ooo`1oool0S@1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo00l0oomo0ooo000S0?oo
O`?oo`00DP3oogl00ol00000Oooo07ooo`2=07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3o
ogl03P3oogl5ool007L0oomo00?o000007ooo`1oool0S@1oool10?ooo`7o00000@3oool00003o`00
003oogl0oomo00h0oomo1Ooo001g0?ooO`03o`00001oool0Oooo08d0Oooo0@3oool1o`000040oooo
00000ol00000oomo0?ooO`0>0?ooO`Goo`00I@3oogl3ool000l0oomo00?o000007ooo`1oool0S@1o
ool10?ooo`7o00000@3oool00003o`00003oogl0oomo00l0oomo0ooo001U0?ooO`Goo`003@3oogl0
0ol00000Oooo07ooo`2>07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0IP3oogl3ool0
00h0oomo1Ooo000=0?ooO`03o`00001oool0Oooo0240Oooo0ol00?mZ07ooo`40oooo0Ol000010?oo
o`0000?o00000?ooO`3oogl0I@3oogl5ool000d0oomo1Ooo000=0?ooO`03o`00001oool0Oooo0200
Oooo1Ol00?mY07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0I@3oogl5ool000h0oomo
0ooo000=0?ooO`?oo`008@1oool5o`00ofT0Oooo0@3oool1o`000040oooo00000ol00000oomo0?oo
O`1U0?ooO`Goo`007@3oogl5ool00200Oooo1Ol00?mY07ooo`40oooo0Ol000010?ooo`0000?o0000
0?ooO`3oogl0IP3oogl3ool001h0oomo1Ooo000Q07ooo`?o003oJP1oool10?ooo`7o00000@3oool0
0003o`00003oogl0oomo08L0oomo1Ooo000b07ooo`?o003oF@1oool10?ooo`7o00000@3oool00003
o`00003oogl0oomo01d0oomo0ooo001X0?ooO`?oo`00<P1oool5o`00oeP0Oooo0@3oool1o`000040
oooo00000ol00000oomo0?ooO`0L0?ooO`Goo`00J03oogl00ol00000Oooo07ooo`0a07ooo`Go003o
F01oool10?ooo`7o00000@3oool00003o`00003oogl0oomo01`0oomo1Ooo001X0?ooO`03o`00001o
ool0Oooo0340Oooo1Ol00?mH07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0703oogl5
ool006P0oomo00?o000007ooo`1oool0<P1oool3o`00oeT0Oooo0@3oool1o`000040oooo00000ol0
0000oomo0?ooO`0M0?ooO`?oo`00E`3oogl3ool000h0oomo00?o000007ooo`1oool09`1oool3o`00
oe40Oooo0ol00?lA07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0MP3oogl5ool000d0
oomo00?o000007ooo`1oool09P1oool5o`00odl0Oooo1Ol00?l@07ooo`40oooo0Ol000010?ooo`00
00?o00000?ooO`3oogl0MP3oogl5ool000d0oomo00?o000007ooo`1oool09P1oool5o`00oa`0Oooo
0ol00?l`07ooo`Go003o401oool10?ooo`7o00000@3oool00003o`00003oogl0oomo0340oomo0ooo
00120?ooO`Goo`003@3oogl00ol00000Oooo07ooo`0S07ooo`So003o6`1oool5o`00obl0Oooo1Ol0
0?l@07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0<03oogl5ool00480oomo0ooo000>
0?ooO`03o`00001oool0Oooo0280Oooo2?l00?lL07ooo`Go003o<01oool3o`00oa40Oooo0@3oool1
o`000040oooo00000ol00000oomo0?ooO`0`0?ooO`Goo`00D`3oogl00ol00000Oooo07ooo`0R07oo
o`Go003o7`1oool5o`00od@0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0`0?ooO`Go
o`00D`3oogl00ol00000Oooo07ooo`0R07ooo`Go003o801oool3o`00odD0Oooo0@3oool1o`000040
oooo00000ol00000oomo0?ooO`0a0?ooO`?oo`000`3oogl3ool002X0oomo0ooo000Q0?ooO`03o`00
001oool0Oooo00d0Oooo0ol00?l307ooo`Co003o301oool3o`00ofT0Oooo0@3oool1o`000040oooo
00000ol00000oomo0?ooO`0f0?ooO`Goo`00:03oogl5ool00200oomo00?o000007ooo`1oool0301o
ool5o`00o`0307ooool00?oo003o00Co003o601oool3o`00oe`0Oooo0@3oool1o`000040oooo0000
0ol00000oomo0?ooO`0f0?ooO`Goo`00:03oogl5ool00200oomo00?o000007ooo`1oool0301oool5
o`00o`0307ooool00?oo003o00Co003o5`1oool5o`00oe/0Oooo0@3oool1o`000040oooo00000ol0
0000oomo0?ooO`0f0?ooO`Goo`00:03oogl5ool00200oomo00?o000007ooo`1oool0301oool5o`00
o`0307ooool00?oo003o00Co003o5`1oool5o`00oe/0Oooo0@3oool1o`000040oooo00000ol00000
oomo0?ooO`0C0?ooO`?oo`008@3oogl3ool002X0oomo0ooo000Q0?ooO`03o`00001oool0Oooo00d0
Oooo0ol00?l307ooo`Co003o601oool5o`00oe/0Oooo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`0B0?ooO`Goo`00L@3oogl00ol00000Oooo07ooo`0A07ooo`?o003o701oool3o`00oe`0Oooo
0@3oool1o`000040oooo00000ol00000oomo0?ooO`0B0?ooO`Goo`00C@3oogl3ool00240oomo00?o
000007ooo`1oool0401oool5o`00of40Oooo0ol00?lF07ooo`40oooo0Ol000010?ooo`0000?o0000
0?ooO`3oogl04P3oogl5ool004`0oomo1Ooo000P0?ooO`03o`00001oool0Oooo0100Oooo1Ol00?mP
07ooo`Go003o5@1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo01<0oomo0ooo001=0?oo
O`Goo`00803oogl00ol00000Oooo07ooo`0@07ooo`Go003oH01oool5o`00oaD0Oooo0@3oool1o`00
0040oooo00000ol00000oomo0?ooO`1S0?ooO`Goo`00803oogl00ol00000Oooo07ooo`0A07ooo`?o
003oH@1oool5o`00oaD0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`1T0?ooO`?oo`00
8@3oogl00ol00000Oooo07ooo`1f07ooo`?o003o5P1oool10?ooo`7o00000@3oool00003o`00003o
ogl0oomo06D0oomo0ooo000P0?ooO`03o`00001oool0Oooo08l0Oooo0@3oool1o`000040oooo0000
0ol00000oomo0?ooO`1T0?ooO`Goo`007`3oogl00ol00000Oooo07ooo`0807ooo`?o003o301oool3
o`00o`<0Oooo0ol00?m_07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0C`3oogl3ool0
0180oomo1Ooo000O0?ooO`03o`00001oool0Oooo00L0Oooo1Ol00?l:07ooo`Go003o00<0Ooooo`00
ool00?l00ol00?m^07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0CP3oogl5ool00140
oomo1Ooo000O0?ooO`03o`00001oool0Oooo00L0Oooo1Ol00?l:07ooo`Go003o00<0Ooooo`00ool0
0?l00ol00?l]07ooo`?o003o?P1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo04h0oomo
1Ooo00050?ooO`?oo`002P3oogl3ool00200oomo00?o000007ooo`1oool01`1oool5o`00o`X0Oooo
1Ol00?l00`1ooooo003oo`00o`03o`00ob`0Oooo1Ol00?lm07ooo`40oooo0Ol000010?ooo`0000?o
00000?ooO`3oogl0CP3oogl5ool000@0oomo1Ooo000[0?ooO`03o`00001oool0Oooo00T0Oooo0ol0
0?l<07ooo`?o003o0`1oool3o`00obd0Oooo1Ol00?lm07ooo`40oooo0Ol000010?ooo`0000?o0000
0?ooO`3oogl0C`3oogl3ool000D0oomo1Ooo000[0?ooO`03o`00001oool0Oooo03L0Oooo0ol00?lD
07ooo`Go003o?@1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo05L0oomo1Ooo000[0?oo
O`03o`00001oool0Oooo03H0Oooo1Ol00?lD07ooo`?o003o?P1oool10?ooo`7o00000@3oool00003
o`00003oogl0oomo05P0oomo0ooo000/0?ooO`03o`00001oool0Oooo03H0Oooo1Ol00?lN07ooo`?o
003o=01oool10?ooo`7o00000@3oool00003o`00003oogl0oomo08L0oomo00?o000007ooo`1oool0
=P1oool5o`00oad0Oooo1Ol00?lc07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0Q`3o
ogl00ol00000Oooo07ooo`0g07ooo`?o003o7P1oool5o`00oc<0Oooo0@3oool1o`000040oooo0000
0ol00000oomo0?ooO`0<0?ooO`?oo`00<@3oogl3ool004@0oomo00?o000007ooo`1oool0F01oool5
o`00oc<0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0;0?ooO`Goo`00;`3oogl5ool0
04<0oomo00?o000007ooo`1oool0F@1oool3o`00oc@0Oooo0@3oool1o`000040oooo00000ol00000
oomo0?ooO`0;0?ooO`Goo`00;`3oogl5ool004<0oomo00?o000007ooo`1oool0?01oool3o`00oe40
Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0;0?ooO`Goo`00;`3oogl5ool004<0oomo
00?o000007ooo`1oool0>`1oool5o`00oe00Oooo0@3oool1o`000040oooo00000ol00000oomo0?oo
O`0<0?ooO`?oo`00<@3oogl3ool004<0oomo00?o000007ooo`1oool0?01oool5o`00odT0Oooo0ol0
0?l407ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0QP3oogl00ol00000Oooo07ooo`0l
07ooo`Go003oB01oool5o`00o`<0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`260?oo
O`03o`00001oool0Oooo03d0Oooo0ol00?m907ooo`Go003o0`1oool10?ooo`7o00000@3oool00003
o`00003oogl0oomo0100oomo0ooo001c0?ooO`03o`00001oool0Oooo08T0Oooo1Ol00?l307ooo`40
oooo0Ol000010?ooo`0000?o00000?ooO`3oogl03`3oogl5ool00780oomo00?o000007ooo`1oool0
8P1oool3o`00ofD0Oooo0ol00?l407ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl03`3o
ogl5ool00780oomo00?o000007ooo`1oool08@1oool5o`00ocT0Oooo0ol00?l_07ooo`40oooo0Ol0
00010?ooo`0000?o00000?ooO`3oogl03`3oogl5ool00780oomo00?o000007ooo`1oool08@1oool5
o`00ocP0Oooo1Ol00?l^07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0403oogl3ool0
0780oomo0ooo000R07ooo`Go003o>01oool5o`00obh0Oooo0@3oool1o`000040oooo00000ol00000
oomo0?ooO`240?ooO`Goo`008P1oool3o`00ocP0Oooo1_l00?l^07ooo`40oooo0Ol000010?ooo`00
00?o00000?ooO`3oogl0K@3oogl3ool001@0oomo1Ooo001M07ooo`Go003o;`1oool10?ooo`7o0000
0@3oool00003o`00003oogl0oomo06`0oomo1Ooo000C0?ooO`Goo`00G@1oool5o`00obP0Oooo0ol0
0?l407ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0K03oogl5ool001@0oomo0ooo001F
07ooo`?o003o1P1oool3o`00obP0Oooo1Ol00?l307ooo`40oooo0Ol000010?ooo`0000?o00000?oo
O`3oogl0K03oogl5ool001@0oomo00?o000007ooo`1oool0E@1oool5o`00oc00Oooo1Ol00?l307oo
o`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0=@3oogl3ool003D0oomo0ooo000E0?ooO`03
o`00001oool0Oooo05D0Oooo1Ol00?l`07ooo`Go003o0`1oool10?ooo`7o00000@3oool00003o`00
003oogl0oomo03@0oomo1Ooo001<0?ooO`03o`00001oool0Oooo05D0Oooo1Ol00?la07ooo`?o003o
101oool10?ooo`7o00000@3oool00003o`00003oogl0oomo03@0oomo1Ooo001<0?ooO`03o`00001o
ool0Oooo05H0Oooo0ol00?li07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0=03oogl5
ool00480oomo0ooo00070?ooO`03o`00001oool0Oooo0980Oooo0@3oool1o`000040oooo00000ol0
0000oomo0?ooO`0e0?ooO`?oo`00@P3oogl5ool000H0oomo00?o000007ooo`1oool0TP1oool10?oo
o`7o00000@3oool00003o`00003oogl0oomo07X0oomo1Ooo00060?ooO`03o`00001oool0Oooo04P0
Oooo0ol00?m707ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0NP3oogl5ool000H0oomo
00?o000007ooo`1oool0A`1oool5o`00o`h0Oooo0ol00?le07ooo`40oooo0Ol000010?ooo`0000?o
00000?ooO`3oogl0N`3oogl3ool000L0oomo00?o000007ooo`1oool0A`1oool5o`00o`d0Oooo1Ol0
0?ld07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0Q@3oogl00ol00000Oooo07ooo`0R
07ooo`?o003o8P1oool5o`00o`d0Oooo1Ol00?ld07ooo`40oooo0Ol000010?ooo`0000?o00000?oo
O`3oogl0Q@3oogl00ol00000Oooo07ooo`0?07ooo`?o003o3`1oool5o`00ob80Oooo0ol00?l>07oo
o`Go003o=01oool10?ooo`7o00000@3oool00003o`00003oogl0oomo05/0oomo0ooo000W0?ooO`03
o`00001oool0Oooo00h0Oooo1Ol00?l>07ooo`Go003o=01oool3o`00ocD0Oooo0@3oool1o`000040
oooo00000ol00000oomo0?ooO`1J0?ooO`Goo`009P3oogl00ol00000Oooo07ooo`0>07ooo`Go003o
3P1oool5o`00of`0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`1J0?ooO`Goo`002`3o
ogl3ool001P0oomo00?o000007ooo`1oool03@1oool6o`00o`l0Oooo0ol00?m]07ooo`40oooo0Ol0
00010?ooo`0000?o00000?ooO`3oogl01`3oogl3ool00500oomo1Ooo000:0?ooO`Goo`005`3oogl0
0ol00000Oooo07ooo`0:07ooo`So003oP01oool10?ooo`7o00000@3oool00003o`00003oogooo`00
00;oo`00103oogl5ool00500oomo0ooo00030?ooO`?oo`001@3oogl5ool001L0oomo00?o000007oo
o`1oool02@1oool8o`00odD0Oooo0ol00?li07ooo`40oooo0Ol000010?ooo`0000?o0000ool00?oo
00000ooo00030?ooO`Goo`00E@3oogl5ool000@0oomo1Ooo000@0?ooO`?oo`00103oogl00ol00000
Oooo07ooo`0907ooo`So003oA01oool5o`00oaD0Oooo0ol00?lP07ooo`40oooo0Ol000010?ooo`00
00?o0000ool00?oo00000ooo00030?ooO`Goo`00E@3oogl5ool000D0oomo0ooo000@0?ooO`Goo`00
0`3oogl00ol00000Oooo07ooo`0907ooo`Oo003oA@1oool6o`00oa<0Oooo1Ol00?lO07ooo`40oooo
0Ol000010?ooo`0000?o0000ool00?oo00000ooo00040?ooO`?oo`00EP3oogl5ool000@0oomo0ooo
000A0?ooO`Goo`000`3oogl00ol00000Oooo07ooo`0:07ooo`?o003oA`1oool8o`00oa80Oooo1Ol0
0?lO07ooo`40oooo0Ol000010?ooo`0000?o00000?ooOooo00000_oo001O0?ooO`?oo`00103oogl5
ool00100oomo1Ooo00030?ooO`03o`00001oool0Oooo05@0Oooo2?l00?lB07ooo`Go003o7`1oool1
0?ooo`7o00000@3oool00003o`00003oogl0oomo06P0oomo1Ooo000A0?ooO`?oo`000`3oogl00ol0
0000Oooo07ooo`1E07ooo`So003o4`1oool3o`00ob00Oooo0@3oool1o`000040oooo00000ol00000
oomo0?ooO`1B0?ooO`?oo`004`3oogl5ool001L0oomo00?o000007ooo`1oool0EP1oool6o`00ocL0
Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`1=0?ooO`?oo`0000<0oomoool00?oo0000
0ooo000C0?ooO`?oo`00603oogl00ol00000Oooo07ooo`2C07ooo`40oooo0Ol000010?ooo`0000?o
00000?ooO`3oogl0C03oogl:ool002h0oomo00?o000007ooo`1oool0T`1oool10?ooo`7o00000@3o
ool00003o`00003oogl0oomo04D0oomo0ooo00040?ooO`[oo`00;P3oogl00ol00000Oooo07ooo`2C
07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0A03oogl5ool000<0oomo1Ooo0000103o
ogooo`00ool00?oo000_0?ooO`03o`00001oool0Oooo06l0Oooo0ol00?lQ07ooo`40oooo0Ol00001
0?ooo`0000?o00000?ooO`3oogl0A03oogl5ool000@0oomo0ooo000d0?ooO`03o`00001oool0Oooo
06h0Oooo1Ol00?lP07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0A03oogl5ool002<0
oomo0ooo000E0?ooO`03o`00001oool0Oooo06h0Oooo1Ol00?lP07ooo`40oooo0Ol000010?ooo`00
00?o00000?ooO`3oogl0A@3oogl3ool002<0oomo1Ooo000D0?ooO`03o`00001oool0Oooo06h0Oooo
1Ol00?lP07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0J`3oogl5ool001@0oomo00?o
000007ooo`1oool07`1oool3o`00odd0Oooo0ol00?lQ07ooo`40oooo0Ol000010?ooo`0000?o0000
0?ooO`3oogl0J`3oogl5ool001<0oomo00?o000007ooo`1oool07`1oool5o`00og00Oooo0@3oool1
o`000040oooo00000ol00000oomo0?ooO`1/0?ooO`?oo`00503oogl00ol00000Oooo07ooo`0O07oo
o`Go003oL01oool10?ooo`7o00000@3oool00003o`00003oogl0oomo08<0oomo00?o000007ooo`1o
ool0401oool3o`00o``0Oooo1Ol00?m`07ooo`40oooo0Ol000010?ooo`0000?o0000ool0003oogl0
P`3oogl00ol00000Oooo07ooo`0?07ooo`Go003o301oool3o`00oeh0Oooo0ol00?l@07ooo`40oooo
0Ol000010?ooo`0000?o0000ool00?oo0000P`3oogl00ol00000Oooo07ooo`0?07ooo`Go003oK01o
ool5o`00o`l0Oooo0@3oool1o`000040oooo00000ol0003oo`00ool000230?ooO`03o`00001oool0
Oooo00l0Oooo1Ol00?m/07ooo`Go003o3`1oool10?ooo`7o00000@3oool00003o`000?oo003oo`00
00?oo`00J03oogl3ool001D0oomo00?o000007ooo`1oool0401oool3o`00ofd0Oooo1Ol00?l?07oo
o`40oooo0Ol000010?ooo`0000?o0000ool00?oo00001?oo001V0?ooO`Goo`00503oogl00ol00000
Oooo07ooo`0L07ooo`?o003oHP1oool3o`00oa00Oooo0@3oool1o`000040oooo00000ol00000oomo
ool00004ool002d0oomo0ooo000f0?ooO`Goo`00503oogl00ol00000Oooo07ooo`0K07ooo`Go003o
401oool3o`00of40Oooo0@3oool1o`000040oooo00000ol00000oomoool00004ool002`0oomo1_oo
000d0?ooO`Goo`004`3oogl00ol00000Oooo07ooo`0@07ooo`?o003o2@1oool5o`00o`l0Oooo1Ol0
0?mP07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl00ooo000]0?ooO`Ooo`00=03oogl3
ool001@0oomo00?o000007ooo`1oool03`1oool5o`00o`P0Oooo1Ol00?l?07ooo`Go003oH01oool1
0?ooo`7o00000@3oool00003o`00003oogl0oomo0300oomo1ooo001;0?ooO`03o`00001oool0Oooo
00l0Oooo1Ol00?l907ooo`?o003o401oool5o`00of00Oooo0@3oool1o`000040oooo00000ol00000
oomo0?ooO`0a0?ooO`Koo`00B`3oogl00ol00000Oooo07ooo`0?07ooo`Go003o7@1oool3o`00of40
Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0c0?ooO`?oo`00C03oogl00ol00000Oooo
07ooo`0@07ooo`?o003oPP1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo0880oomo00?o
000007ooo`1oool0U@1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo0880oomo00?o0000
07ooo`1oool0U@1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo0880oomo00?o000007oo
o`1oool0U@1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo0280oomo0ooo001M0?ooO`03
o`00001oool0Oooo09D0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0Q0?ooO`Goo`00
G03oogl00ol00000Oooo07ooo`2E07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl08@3o
ogl5ool005`0oomo00?o000007ooo`1oool02`1oool3o`00oaX0Oooo0ol00?mZ07ooo`40oooo0Ol0
00010?ooo`0000?o00000?ooO`3oogl08@3oogl5ool005`0oomo00?o000007ooo`1oool02P1oool5
o`00oaP0Oooo1Ol00?mY07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl08P3oogl3ool0
05d0oomo00?o000007ooo`1oool02P1oool5o`00oaP0Oooo1Ol00?lQ07ooo`?o003oA@1oool10?oo
o`7o00000@3oool00003o`00003oogl0oomo0880oomo00?o000007ooo`1oool02P1oool5o`00oaP0
Oooo1Ol00?lP07ooo`Go003o:`1oool3o`00oaH0Oooo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`150?ooO`?oo`00>P3oogl00ol00000Oooo07ooo`0;07ooo`?o003o6P1oool3o`00ob40Oooo
1Ol00?lZ07ooo`Go003o5@1oool10?ooo`7o00000@3oool00003o`00003oogl0oomo04@0oomo1ooo
000g0?ooO`03o`00001oool0Oooo04`0Oooo1Ol00?lZ07ooo`Go003o5@1oool10?ooo`7o00000@3o
ool00003o`00003oogl0oomo04@0oomo2?oo000f0?ooO`03o`00001oool0Oooo04d0Oooo0ol00?l2
07ooo`?o003o9P1oool5o`00oaD0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`140?oo
O`Soo`00=P3oogl00ol00000Oooo07ooo`1A07ooo`Go003o9P1oool3o`00oaH0Oooo0@3oool1o`00
0040oooo00000ol00000oomo0?ooO`0F0?ooO`?oo`00;03oogl7ool003H0oomo00?o000007ooo`1o
ool02P1oool3o`00ocD0Oooo0ol00?l<07ooo`Go003o?`1oool10?ooo`7o00000@3oool00003o`00
003oogl0oomo01D0oomo1Ooo000^0?ooO`?oo`00=`3oogl00ol00000Oooo07ooo`0907ooo`Go003o
<`1oool5o`00o`/0Oooo1Ol00?l807ooo`?o003o=01oool10?ooo`7o00000@3oool00003o`00003o
ogl0oomo01D0oomo1Ooo001W0?ooO`03o`00001oool0Oooo00X0Oooo1Ol00?lc07ooo`Go003o101o
ool3o`00o`D0Oooo0ol00?l807ooo`Go003o<`1oool10?ooo`7o00000@3oool00003o`00003oogl0
oomo01D0oomo1Ooo001W0?ooO`03o`00001oool0Oooo00X0Oooo1Ol00?lc07ooo`Go003o0`1oool5
o`00o`l0Oooo1Ol00?lc07ooo`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl05P3oogl3ool0
06P0oomo00?o000007ooo`1oool02`1oool3o`00ocD0Oooo0ol00?l407ooo`Go003o3`1oool5o`00
oc<0Oooo0@3oool1o`000040oooo00000ol00000oomo0?ooO`210?ooO`03o`00001oool0Oooo04X0
Oooo1Ol00?l@07ooo`?o003o=01oool10?ooo`7o00000@3oool00=;o00000ol00?m:o`000040oooo
003oo`00023o00000@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-6, -5.00005*^-6, \
0.00348436, 0.00348436}, {{0, 287}, {287, 0}} -> {-1.01089, -1.01089, \
0.00704453, 0.00704453}, {{0, 287}, {287, 0}} -> {-1.01089, -1.01089, \
0.00704453, 0.00704453}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example B: different uniform distributions", "Section"],

Cell[CellGroupData[{

Cell["Generate data from two non-rectangular uniform classes", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 100;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Specialized data generation", "Subsubsection"],

Cell[BoxData[
    \(\(SpecialDataGeneration[\ 
          flag_] := \[IndentingNewLine]Module[{x, 
            y}, \[IndentingNewLine]{x, y}\  = \ 
            r2[1]; \[IndentingNewLine]While[\(-flag\)*x\  > \ 
              flag\ *\ y, \ {x, y}\  = \ r2[1]]; {x, y}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = \ Table[SpecialDataGeneration[1], {n1}];\)\), "\n", 
    \(\(data2\  = \ 
        Table[SpecialDataGeneration[\(-1\)], \ {n2}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, gd2, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.44081 .70898 Mdot
.95172 .71652 Mdot
.66962 .9822 Mdot
.96441 .83576 Mdot
.79787 .36357 Mdot
.8004 .71449 Mdot
.73514 .66175 Mdot
.77847 .94028 Mdot
.43862 .56594 Mdot
.25006 .90803 Mdot
.36445 .9263 Mdot
.56164 .56768 Mdot
.64559 .53024 Mdot
.79094 .44468 Mdot
.86216 .58501 Mdot
.35727 .8738 Mdot
.82809 .66661 Mdot
.11216 .96082 Mdot
.46859 .73536 Mdot
.82651 .88855 Mdot
.902 .17263 Mdot
.52127 .97074 Mdot
.87073 .44545 Mdot
.70694 .45352 Mdot
.79998 .28585 Mdot
.90447 .72806 Mdot
.40798 .85976 Mdot
.22388 .81044 Mdot
.70424 .99452 Mdot
.44366 .73074 Mdot
.42835 .76586 Mdot
.97229 .71613 Mdot
.97182 .43634 Mdot
.62097 .89687 Mdot
.8851 .72456 Mdot
.4934 .54176 Mdot
.74969 .87772 Mdot
.51616 .82067 Mdot
.72931 .97163 Mdot
.7063 .98337 Mdot
.88759 .82958 Mdot
.81625 .26376 Mdot
.85995 .2901 Mdot
.63821 .61027 Mdot
.3715 .7434 Mdot
.88357 .7276 Mdot
.85039 .91778 Mdot
.94715 .42374 Mdot
.33961 .68795 Mdot
.87525 .81391 Mdot
.82317 .55571 Mdot
.98672 .09126 Mdot
.96783 .63298 Mdot
.83247 .33529 Mdot
.78655 .65407 Mdot
.70473 .6758 Mdot
.45189 .96116 Mdot
.92854 .53698 Mdot
.4505 .78253 Mdot
.64961 .59384 Mdot
.98783 .4943 Mdot
.43764 .64244 Mdot
.28805 .81355 Mdot
.9808 .67633 Mdot
.63793 .72696 Mdot
.19238 .93948 Mdot
.99402 .42124 Mdot
.56504 .71266 Mdot
.93241 .78449 Mdot
.91048 .12377 Mdot
.70821 .48798 Mdot
.9177 .62453 Mdot
.27552 .84059 Mdot
.6346 .80603 Mdot
.99172 .08402 Mdot
.30118 .81422 Mdot
.40611 .67368 Mdot
.76656 .86271 Mdot
.76989 .78364 Mdot
.79017 .29649 Mdot
.96065 .64899 Mdot
.55658 .68788 Mdot
.26036 .86871 Mdot
.39758 .92385 Mdot
.66739 .54247 Mdot
.98651 .25512 Mdot
.32722 .73544 Mdot
.45006 .59887 Mdot
.48447 .94493 Mdot
.97057 .75107 Mdot
.75812 .71792 Mdot
.71516 .87741 Mdot
.36549 .78912 Mdot
.69907 .55262 Mdot
.85803 .34771 Mdot
.45648 .87987 Mdot
.71695 .5518 Mdot
.40224 .8424 Mdot
.86381 .84274 Mdot
.33511 .85324 Mdot
0 0 1 r
.19768 .36014 Mdot
.19224 .39285 Mdot
.1067 .26939 Mdot
.09713 .26739 Mdot
.6583 .12031 Mdot
.299 .22958 Mdot
.135 .06116 Mdot
.10627 .86449 Mdot
.84961 .10548 Mdot
.03717 .94618 Mdot
.45424 .01141 Mdot
.45466 .40641 Mdot
.11379 .82569 Mdot
.04207 .94394 Mdot
.42357 .03804 Mdot
.5214 .14311 Mdot
.45314 .08585 Mdot
.87822 .04554 Mdot
.49998 .2361 Mdot
.8411 .09665 Mdot
.04915 .25188 Mdot
.65854 .24829 Mdot
.62063 .21879 Mdot
.03649 .27583 Mdot
.10418 .08063 Mdot
.53725 .16908 Mdot
.14067 .74528 Mdot
.08906 .08817 Mdot
.2575 .7047 Mdot
.71642 .09877 Mdot
.28281 .14655 Mdot
.72193 .04366 Mdot
.1987 .06333 Mdot
.46938 .33401 Mdot
.60963 .21125 Mdot
.06288 .71606 Mdot
.07466 .60611 Mdot
.30997 .35136 Mdot
.15536 .2247 Mdot
.5886 .25753 Mdot
.05744 .76747 Mdot
.00903 .42988 Mdot
.5347 .10082 Mdot
.24911 .50279 Mdot
.47677 .3798 Mdot
.17174 .03339 Mdot
.02899 .67198 Mdot
.33485 .20993 Mdot
.09167 .59743 Mdot
.23948 .29511 Mdot
.00988 .45655 Mdot
.39137 .41771 Mdot
.22743 .18011 Mdot
.08291 .63619 Mdot
.24626 .23941 Mdot
.33519 .51961 Mdot
.00529 .31463 Mdot
.48969 .2687 Mdot
.35424 .41106 Mdot
.13177 .2359 Mdot
.10744 .31476 Mdot
.1071 .00508 Mdot
.74298 .13748 Mdot
.22327 .57681 Mdot
.35948 .02589 Mdot
.26687 .49052 Mdot
.57366 .1062 Mdot
.03904 .42097 Mdot
.07587 .60186 Mdot
.6196 .3462 Mdot
.59745 .0564 Mdot
.37913 .47464 Mdot
.48294 .48726 Mdot
.0246 .4537 Mdot
.44599 .35246 Mdot
.39184 .34059 Mdot
.34098 .32963 Mdot
.0505 .64806 Mdot
.17387 .43933 Mdot
.34476 .34983 Mdot
.08302 .61474 Mdot
.48687 .07084 Mdot
.15084 .73626 Mdot
.40731 .46304 Mdot
.19846 .53309 Mdot
.04786 .6595 Mdot
.04257 .6257 Mdot
.95459 .01591 Mdot
.31747 .25136 Mdot
.54661 .39048 Mdot
.17158 .51015 Mdot
.18418 .41806 Mdot
.75932 .05206 Mdot
.47819 .30394 Mdot
.02321 .07794 Mdot
.21888 .75574 Mdot
.2541 .56446 Mdot
.29128 .66982 Mdot
.23584 .49148 Mdot
.02191 .73078 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003o7@3oool3
o`00ool0oooo0@3oool001`000001Ol00?on00000040oooo00000`000000oooo0?ooo`0I0?ooo`Go
003oH03oool3o`00oiX0oooo0@0000010?ooo`0000<000000?ooo`3oool06@3oool5o`00oel0oooo
1Ol00?n;0?ooo`?o003o2`3oool100000040oooo00000`000000oooo0?ooo`0J0?ooo`?o003oH03o
ool5o`00ohX0oooo1Ol00?l:0?ooo`4000000@3oool000030000003oool0oooo07d0oooo1Ol00?n:
0?ooo`Go003o2P3oool100000040oooo00000`000000oooo0?ooo`1R0?ooo`?o003o6@3oool3o`00
oh/0oooo1Ol00?l:0?ooo`4000000@3oool000030000003oool0oooo0640oooo1Ol00?nW0?ooo`?o
003o2`3oool100000040oooo00000`000000oooo0?ooo`1Q0?ooo`Go003o]@3oool100000040oooo
00000`000000oooo0?ooo`0]0?ooo`?o003o<@3oool5o`00okD0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0;03oool5o`00oc40oooo0ol00?l@0?ooo`?o003oX`3oool100000040oooo00000`00
0000oooo0?ooo`0/0?ooo`Go003o@`3oool5o`00oe40oooo0ol00?m>0?ooo`4000000@3oool00003
0000003oool0oooo02`0oooo1Ol00?m30?ooo`Go003oD03oool5o`00obT0oooo0ol00?lQ0?ooo`40
00000@3oool000030000003oool0oooo02d0oooo0ol00?m40?ooo`Go003oD03oool5o`00obP0oooo
1Ol00?lP0?ooo`4000000@3oool000030000003oool0oooo07D0oooo0ol00?mA0?ooo`Go003o1`3o
ool3o`00oah0oooo1Ol00?lP0?ooo`4000000@3oool000030000003oool0oooo0:L0oooo0ol00?lP
0?ooo`?o003o1`3oool5o`00oad0oooo1Ol00?lP0?ooo`4000000@3oool000030000003oool0oooo
0280oooo0ol00?n10?ooo`Go003o:@3oool5o`00oah0oooo0ol00?lQ0?ooo`4000000@3oool00003
0000003oool0oooo0240oooo1Ol00?l>0?ooo`?o003oK`3oool5o`00obT0oooo1Ol00?m20?ooo`40
00000@3oool000030000003oool0oooo0240oooo1Ol00?l=0?ooo`Go003oKP3oool5o`00obX0oooo
0ol00?m30?ooo`4000000@3oool000030000003oool0oooo0240oooo1Ol00?l=0?ooo`Go003oC`3o
ool3o`00oad0oooo0ol00?ma0?ooo`4000000@3oool000030000003oool0oooo0280oooo0ol00?l>
0?ooo`Go003oCP3oool5o`00oi00oooo0@0000010?ooo`0000<000000?ooo`3oool00P3oool3o`00
obl0oooo0ol00?m?0?ooo`Go003oT03oool100000040oooo000010000000oooo0?ooo`3oool5o`00
oa<0oooo0ol00?mZ0?ooo`Go003oT03oool100000040oooo000010000000oooo0?ooo`3oool5o`00
oa80oooo1Ol00?mZ0?ooo`?o003oSP3oool3ool0004000000@3oool000040000003oool0oooo0?oo
o`Go003o3`3oool8o`00of00oooo0ol00?nG0?ooo`Goo`000@3oool000030000003oool0oooo0080
oooo0ol00?l?0?ooo`Wo003oG`3oool5o`00oiD0oooo1_oo00010?ooo`0000<000000?ooo`3oool0
503oool8o`00of00oooo1Ol00?nD0?ooo`Ooo`000@3oool000030000003oool0oooo01@0oooo1Ol0
0?mS0?ooo`Go003oB03oool3o`00ob00oooo0ol00?lV0?ooo`Koo`000@0000010?ooo`0000<00000
0?ooo`3oool05@3oool3o`00ofD0oooo0ol00?lE0?ooo`?o003o<03oool5o`00oah0oooo1Ol00?lU
0?ooo`Goo`000@3oool100000040oooo00000`000000oooo0?ooo`2D0?ooo`Go003o1`3oool3o`00
obD0oooo1Ol00?lN0?ooo`Oo003o903oool3ool00080oooo0@0000010?ooo`0000<000000?ooo`3o
ool0U03oool5o`00o`H0oooo1Ol00?lT0?ooo`Go003o7P3oool8o`00obP0oooo0@0000010?ooo`00
00<000000?ooo`3oool0U03oool5o`00o`H0oooo1Ol00?lU0?ooo`?o003o803oool7o`00obP0oooo
0@0000010?ooo`0000<000000?ooo`3oool0U@3oool3o`00o`L0oooo1Ol00?m:0?ooo`Go003o:03o
ool100000040oooo00000`000000oooo0?ooo`2P0?ooo`?o003o5@3oool3o`00oc@0oooo0ol00?lY
0?ooo`4000000@3oool000030000003oool0oooo0;L0oooo1Ol00?m40?ooo`?oo`00603oool10000
0040oooo00000`000000oooo0?ooo`2g0?ooo`Go003o@`3oool5ool001L0oooo0@0000010?ooo`00
00<000000?ooo`3oool0]`3oool5o`00od<0oooo1Ooo000G0?ooo`4000000@3oool000030000003o
ool0oooo0;P0oooo0ol00?m40?ooo`Goo`005`3oool100000040oooo00000`000000oooo0?ooo`3@
0?ooo`?o003o;@3oool3ool001P0oooo0@0000010?ooo`0000<000000?ooo`3oool0c`3oool5o`00
odL0oooo0@0000010?ooo`0000<000000?ooo`3oool0T@3oool3o`00oc/0oooo1Ol00?m70?ooo`40
00000@3oool000030000003oool0oooo04`0oooo0ol00?m10?ooo`Go003o>P3oool5o`00odL0oooo
0@0000010?ooo`0000<000000?ooo`3oool0B`3oool5o`00od00oooo1Ol00?lk0?ooo`?o003oB03o
ool100000040oooo00000`000000oooo0?ooo`1;0?ooo`Go003o@03oool5o`00ohH0oooo0@000001
0?ooo`0000<000000?ooo`3oool0B`3oool5o`00od40oooo0ol00?n70?ooo`4000000@3oool00003
0000003oool0oooo04`0oooo0ol00?o<0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo
703oool100000040oooo00000`000000oooo0?ooo`2E0?ooo`?o003oP`3oool100000040oooo0000
0`000000oooo0?ooo`2D0?ooo`Go003oI@3oool3ool001X0oooo0@0000010?ooo`0000<000000?oo
o`3oool0U03oool5o`00of@0oooo1Ooo000I0?ooo`4000000@3oool000030000003oool0oooo09@0
oooo1Ol00?mT0?ooo`Goo`006@3oool100000040oooo00000`000000oooo0?ooo`0m0?ooo`?o003o
E@3oool3o`00ofD0oooo1Ooo000I0?ooo`4000000@3oool000030000003oool0oooo03`0oooo1Ol0
0?nm0?ooo`?oo`006P3oool100000040oooo00000`000000oooo0?ooo`0l0?ooo`Go003ofP3oool1
00000040oooo00000`000000oooo0?ooo`0l0?ooo`Go003ofP3oool100000040oooo00000`000000
oooo0?ooo`0m0?ooo`?o003of`3oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo
0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0
oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`1K0?ooo`?o003o_@3oool10000
0040oooo00000`000000oooo0?ooo`1J0?ooo`Go003oB`3oool3o`00ofh0oooo0@0000010?ooo`00
00<000000?ooo`3oool0FP3oool5o`00odX0oooo1Ol00?m]0?ooo`4000000@3oool000030000003o
ool0oooo05X0oooo1Ol00?m:0?ooo`Oo003oJ`3oool100000040oooo00000`000000oooo0?ooo`0X
0?ooo`?o003o<03oool3o`00od/0oooo2?l00?mZ0?ooo`4000000@3oool000030000003oool0oooo
02L0oooo1Ol00?mn0?ooo`Oo003oJP3oool100000040oooo00000`000000oooo0?ooo`0W0?ooo`Go
003o9@3oool3o`00oeP0oooo1Ol00?mZ0?ooo`4000000@3oool000030000003oool0oooo02L0oooo
1Ol00?lT0?ooo`Go003oF03oool3o`00of/0oooo0@0000010?ooo`0000<000000?ooo`3oool08@3o
ool3o`00o`@0oooo0ol00?lU0?ooo`Go003o=P3oool3o`00ohd0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0803oool5o`00oad0oooo0ol00?l;0?ooo`Go003o=@3oool5o`00oh`0oooo0@000001
0?ooo`0000<000000?ooo`3oool0803oool5o`00oa`0oooo1Ol00?l;0?ooo`?o003o=P3oool5o`00
oh`0oooo0@0000010?ooo`0000<000000?ooo`3oool0803oool5o`00oa`0oooo1Ol00?m40?ooo`Go
003o:@3oool3o`00of00oooo0@0000010?ooo`0000<000000?ooo`3oool02@3oool3o`00oaD0oooo
0ol00?lM0?ooo`Go003o403oool3o`00oc80oooo0ol00?lY0?ooo`Go003oG`3oool100000040oooo
00000`000000oooo0?ooo`080?ooo`Go003o=@3oool3o`00oa00oooo1Ol00?mM0?ooo`Go003oFP3o
ool3ool00080oooo0@0000010?ooo`0000<000000?ooo`3oool0203oool5o`00odP0oooo1Ol00?m:
0?ooo`?o003o403oool5o`00oeT0oooo1Ooo00010?ooo`4000000@3oool000030000003oool0oooo
00P0oooo1Ol00?m80?ooo`Go003oB@3oool5o`00oa00oooo0ol00?mJ0?ooo`Goo`000@3oool10000
0040oooo00000`000000oooo0?ooo`090?ooo`?o003oBP3oool3o`00odX0oooo1Ol00?lm0?ooo`?o
o`00;@3oool5ool00040oooo0@0000010?ooo`0000<000000?ooo`3oool05`3oool6o`00of/0oooo
0ol00?lH0?ooo`Go003o?03oool5ool002d0oooo0ooo00020?ooo`4000000@3oool000030000003o
ool0oooo01H0oooo2?l00?mY0?ooo`Go003o603oool3o`00ocd0oooo1Ooo000b0?ooo`4000000@3o
ool000030000003oool0oooo00H0oooo0ol00?l=0?ooo`So003oJ@3oool5o`00oeP0oooo1Ooo000b
0?ooo`4000000@3oool000030000003oool0oooo00D0oooo1Ol00?l<0?ooo`So003oJ@3oool5o`00
oeT0oooo0ooo000c0?ooo`4000000@3oool000030000003oool0oooo00D0oooo1Ol00?l=0?ooo`Ko
003oJ`3oool3o`00oi00oooo0@0000010?ooo`0000<000000?ooo`3oool01@3oool5o`00omL0oooo
0ooo000g0?ooo`4000000@3oool000030000003oool0oooo00H0oooo0ol00?oG0?ooo`Goo`003@3o
ool3ool002H0oooo0@0000010?ooo`0000<000000?ooo`3oool0h03oool5ool000`0oooo1Ooo000U
0?ooo`4000000@3oool000030000003oool0oooo0400oooo0ol00?nK0?ooo`Ooo`00303oool5ool0
02D0oooo0@0000010?ooo`0000<000000?ooo`3oool0?`3oool5o`00oiT0oooo1ooo000=0?ooo`Go
o`009@3oool100000040oooo00000`000000oooo0?ooo`0o0?ooo`Go003o@03oool3o`00oeH0oooo
1Ooo000@0?ooo`?oo`009P3oool100000040oooo00000`000000oooo0?ooo`0o0?ooo`Go003o?`3o
ool5o`00oeD0oooo1Ooo000i0?ooo`4000000@3oool000030000003oool0oooo0400oooo0ol00?m0
0?ooo`Go003oEP3oool3ool003X0oooo0@0000010?ooo`000_l00?lK0?ooo`?o003oIP3oool5o`00
oi<0oooo0@0000010?ooo`000ol00?lI0?ooo`Go003oIP3oool3o`00oi@0oooo0@0000010?ooo`00
0ol00?lI0?ooo`Go003oo@3oool100000040oooo0003o`00oaT0oooo1Ol00?om0?ooo`4000000@3o
ool000;o003o6`3oool3o`00od00oooo0ol00?nk0?ooo`4000000@3oool000030000003oool0oooo
05`0oooo1Ol00?nj0?ooo`4000000@3oool000030000003oool0oooo05`0oooo1Ol00?lQ0?ooo`?o
003oI@3oool3ool002h0oooo0@0000010?ooo`0000<000000?ooo`3oool0G03oool5o`00ob00oooo
1Ol00?mS0?ooo`Goo`00;@3oool100000040oooo00000`000000oooo0?ooo`1M0?ooo`?o003o303o
ool3o`00oa80oooo1Ol00?mS0?ooo`Goo`00;@3oool100000040oooo00000`000000oooo0?ooo`1[
0?ooo`Go003o4@3oool5o`00obL0oooo0ol00?li0?ooo`Goo`00;@3oool100000040oooo00000`00
0000oooo0?ooo`1N0?ooo`?o003o2P3oool5o`00oa80oooo0ol00?lW0?ooo`Go003o>@3oool3ool0
00@0oooo0ooo000W0?ooo`4000000@3oool000030000003oool0oooo05@0oooo0ol00?l60?ooo`Go
003o2@3oool5o`00o`/0oooo0ol00?l^0?ooo`Go003o?`3oool5ool002H0oooo0@0000010?ooo`00
00<000000?ooo`3oool0D`3oool5o`00o`D0oooo1Ol00?l:0?ooo`?o003o2`3oool5o`00obd0oooo
1Ol00?lo0?ooo`Goo`009P3oool100000040oooo00000`000000oooo0?ooo`0d0?ooo`?o003o703o
ool5o`00o`D0oooo1Ol00?lH0?ooo`Go003o;P3oool3o`00od00oooo1Ooo000V0?ooo`4000000@3o
ool000030000003oool0oooo03<0oooo1Ol00?lK0?ooo`Go003o1P3oool3o`00oaT0oooo1Ol00?mQ
0?ooo`?oo`003P3oool3ool002L0oooo0@0000010?ooo`0000<000000?ooo`3oool0<`3oool5o`00
oa`0oooo0ol00?lT0?ooo`?o003oH@3oool5ool003L0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0<`3oool5o`00ojL0oooo1Ooo000g0?ooo`4000000@3oool000030000003oool0oooo03@0oooo
0ol00?nX0?ooo`Goo`00=`3oool100000040oooo00000`000000oooo0?ooo`3P0?ooo`?oo`00>03o
ool100000040oooo00000`000000oooo0?ooo`240?ooo`?o003oU03oool100000040oooo00000`00
0000oooo0?ooo`230?ooo`Go003oT`3oool100000040oooo00000`000000oooo0?ooo`230?ooo`Go
003oT`3oool100000040oooo00000`000000oooo0?ooo`230?ooo`Go003o403oool3o`00oh00oooo
0@0000010?ooo`0000<000000?ooo`3oool0<P3oool3o`00odl0oooo0ol00?l@0?ooo`Go003oO`3o
ool100000040oooo00000`000000oooo0?ooo`0a0?ooo`Go003oH@3oool5o`00ogl0oooo0@000001
0?ooo`0000<000000?ooo`3oool0<@3oool5o`00of40oooo1Ol00?mo0?ooo`4000000@3oool00003
0000003oool0oooo0340oooo1Ol00?m80?ooo`?o003o5`3oool3o`00oh00oooo0@0000010?ooo`00
00<000000?ooo`3oool0<P3oool3o`00odP0oooo1Ol00?nI0?ooo`4000000@3oool000030000003o
ool0oooo0640oooo0ol00?lI0?ooo`Go003oV@3oool100000040oooo00000`000000oooo0?ooo`1P
0?ooo`Go003o603oool5o`00oiT0oooo0@0000010?ooo`0000<000000?ooo`3oool0<03oool3o`00
obd0oooo1Ol00?l70?ooo`?o003o3`3oool3o`00oiX0oooo0@0000010?ooo`0000<000000?ooo`3o
ool01`3oool3o`00obD0oooo1Ol00?l/0?ooo`Go003o1P3oool5o`00oi/0oooo0ooo000:0?ooo`?o
o`000@0000010?ooo`0000<000000?ooo`3oool01P3oool5o`00ob@0oooo1Ol00?l]0?ooo`?o003o
1`3oool5o`00oiX0oooo1Ooo00080?ooo`Goo`000@3oool000?o003o1P3oool5o`00ob@0oooo1Ol0
0?lg0?ooo`Go003oVP3oool5ool000P0oooo1Ooo00010?ooo`001?l00?l50?ooo`Go003o9@3oool3
o`00ocT0oooo0ol00?nK0?ooo`Goo`00203oool5ool00040oooo0004o`00o`H0oooo0ol00?oo0?oo
o`80oooo0ooo00040?ooo`?oo`000`3oool3ool0004000000@3oool000Co003o;03oool3o`00on40
oooo1Ooo00050?ooo`4000000@3oool000?o003o;03oool5o`00ojd0oooo0ooo000`0?ooo`Goo`00
1@3oool100000040oooo00000`000000oooo0?ooo`0/0?ooo`Go003o[03oool5ool001<0oooo0ooo
000I0?ooo`Goo`001@3oool100000040oooo00000`000000oooo0?ooo`0/0?ooo`Go003o[03oool5
ool00180oooo1Ooo000I0?ooo`?oo`001P3oool100000040oooo00000`000000oooo0?ooo`020?oo
o`?o003o:03oool3o`00oiH0oooo0ooo000D0?ooo`Goo`004P3oool5ool00280oooo0@0000010?oo
o`0000<00000o`00ool00?l01_l00?no0?ooo`Goo`00503oool3ool001<0oooo1Ooo000R0?ooo`40
00000@3oool000Wo003o_`3oool5ool002/0oooo0ooo000S0?ooo`4000000@3oool000Wo003oJP3o
ool3o`00oe80oooo1Ooo001A0?ooo`4000000@3oool000So003oJP3oool5o`00oe80oooo0ooo001B
0?ooo`4000000@3oool0000400000?l00?oo003oo`00ofh0oooo1Ol00?nW0?ooo`4000000@3oool0
00030000003oool0oooo06P0oooo0ol00?l40?ooo`Go003oY`3oool100000040oooo00000`000000
oooo0?ooo`1W0?ooo`Go003o103oool3o`00ojP0oooo0@0000010?ooo`0000<000000?ooo`3oool0
I`3oool5o`00ojl0oooo0@0000010?ooo`0000<000000?ooo`3oool0I`3oool5o`00ojl0oooo0@00
00010?ooo`0000<000000?ooo`3oool0J03oool3o`00oa/0oooo0ol00?lm0?ooo`?oo`00DP3oool1
00000040oooo00000`000000oooo0?ooo`0o0?ooo`?o003o1P3oool3o`00ocX0oooo1Ol00?lk0?oo
o`Goo`00D@3oool100000040oooo00000`000000oooo0?ooo`0n0?ooo`Go003o103oool5o`00ocT0
oooo1Ol00?lk0?ooo`Goo`00C@3oool3ool00040oooo0@0000010?ooo`0000<000000?ooo`3oool0
?P3oool5o`00o`@0oooo1Ol00?li0?ooo`Go003o>`3oool5ool004`0oooo1Ooo000100000040oooo
00000`000000oooo0?ooo`0n0?ooo`So003o00<0ooooo`00ool00?l00ol00?lj0?ooo`?o003o?@3o
ool3ool004d0oooo1Ooo000100000040oooo00000`000000oooo0?ooo`0o0?ooo`So003o00@0oooo
o`00ool00?oo003ob`3oool5ool0004000000@3oool000030000003oool0oooo02d0oooo0ol00?lB
0?ooo`Go003od03oool3ool00040oooo0@0000010?ooo`0000<000000?ooo`3oool0;03oool5o`00
oa40oooo1Ol00?oD0?ooo`4000000@3oool000030000003oool0oooo02`0oooo1Ol00?lB0?ooo`?o
003oe@3oool100000040oooo00000`000000oooo0?ooo`0/0?ooo`Go003o:P3oool3o`00okd0oooo
0@0000010?ooo`0000<000000?ooo`3oool0;@3oool3o`00obX0oooo1Ol00?nl0?ooo`4000000@3o
ool000030000003oool0oooo05X0oooo1Ol00?nl0?ooo`4000000@3oool000030000003oool0oooo
05X0oooo1Ol00?mE0?ooo`?oo`00I03oool100000040oooo00000`000000oooo0?ooo`0d0?ooo`?o
003o903oool3o`00oeD0oooo1Ooo001S0?ooo`4000000@3oool000030000003oool0oooo03<0oooo
1Ol00?mk0?ooo`Goo`00CP3oool3ool00180oooo0@0000010?ooo`0000<000000?ooo`3oool0<`3o
ool5o`00oe40oooo0ooo000W0?ooo`Goo`000`3oool3ool004L0oooo1Ooo000A0?ooo`4000000@3o
ool000030000003oool0oooo03<0oooo1Ol00?m@0?ooo`Goo`009`3oool3ool000<0oooo1Ooo0016
0?ooo`Goo`004@3oool100000040oooo00000`000000oooo0?ooo`0d0?ooo`?o003oD@3oool5ool0
02d0oooo1Ooo00160?ooo`Goo`004@3oool100000040oooo00000`000000oooo0?ooo`280?ooo`Go
o`00;@3oool5ool000D0oooo0ooo00020?ooo`?oo`00>P3oool3ool00180oooo0@0000010?ooo`00
00<000000?ooo`3oool0R@3oool3ool002l0oooo0ooo00050?ooo`[oo`006P3oool3ool00340oooo
0@0000010?ooo`0000<000000?ooo`3oool0``3oool:ool001T0oooo1Ooo000`0?ooo`4000000@3o
ool000030000003oool0oooo0<<0oooo2_oo000I0?ooo`Goo`00<03oool100000040oooo00000`00
0000oooo0?ooo`140?ooo`?o003o<P3oool3ool004P0oooo0ooo00020?ooo`?oo`006P3oool5ool0
0300oooo0@0000010?ooo`0000<000000?ooo`3oool0@`3oool5o`00oc00oooo1Ooo000O0?ooo`?o
o`00B03oool3ool00340oooo0@0000010?ooo`0000<000000?ooo`3oool0@`3oool5o`00oc00oooo
1Ooo000N0?ooo`Goo`00N`3oool100000040oooo00000`000000oooo0?ooo`0k0?ooo`?o003o1@3o
ool5o`00oc00oooo1Ooo000N0?ooo`Goo`00N`3oool100000040oooo00000`000000oooo0?ooo`0j
0?ooo`Go003o1@3oool3o`00oc80oooo0ooo000O0?ooo`Goo`00N`3oool100000040oooo00000`00
0000oooo0?ooo`0j0?ooo`Go003oG@3oool3ool007`0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0>P3oool5o`00ok@0oooo0ooo000U0?ooo`4000000@3oool000030000003oool0oooo03/0oooo
0ol00?nd0?ooo`Goo`00903oool100000040oooo00000`000000oooo0?ooo`2f0?ooo`?oo`00>@3o
ool5ool002@0oooo0@0000010?ooo`0000<000000?ooo`3oool05P3oool3o`00oi`0oooo1Ooo000h
0?ooo`Goo`00903oool100000040oooo00000`000000oooo0?ooo`0E0?ooo`Go003oHP3oool3ool0
03H0oooo1Ooo000i0?ooo`?oo`009@3oool100000040oooo00000`000000oooo0?ooo`0A0?ooo`?o
003o00<0ooooo`00ool00?l00ol00?mQ0?ooo`Goo`00=@3oool5ool00640oooo0@0000010?ooo`00
00<000000?ooo`3oool0403oool:o`00of40oooo1Ooo000f0?ooo`?oo`00HP3oool100000040oooo
00000`000000oooo0?ooo`0@0?ooo`Go003o00@0ooooo`00ool00?oo003oHP3oool5ool00380oooo
0ooo001V0?ooo`4000000@3oool000030000003oool0oooo0100oooo1_l00?mV0?ooo`?oo`00<P3o
ool5ool006D0oooo0@0000010?ooo`0000<000000?ooo`3oool0403oool7o`00oiX0oooo1Ooo001U
0?ooo`4000000@3oool000030000003oool0oooo0140oooo1_l00?nJ0?ooo`Goo`00I@3oool10000
0040oooo00000`000000oooo0?ooo`080?ooo`?o003o1`3oool5o`00oi/0oooo0ooo001=0?ooo`?o
o`005P3oool100000040oooo00000`000000oooo0?ooo`070?ooo`Go003o1`3oool3o`00on/0oooo
1Ooo000E0?ooo`4000000@3oool000030000003oool0oooo00L0oooo1Ol00?oe0?ooo`Goo`002`3o
ool3ool000L0oooo0@0000010?ooo`0000<000000?ooo`3oool01`3oool5o`00o`L0oooo0ol00?o[
0?ooo`Goo`002P3oool5ool000H0oooo0@0000010?ooo`0000<000000?ooo`3oool0203oool3o`00
o`L0oooo1Ol00?o[0?ooo`?oo`002`3oool5ool000H0oooo0@0000010?ooo`0000<000000?ooo`3o
ool04P3oool5o`00of80oooo0ooo002D0?ooo`Goo`001P3oool100000040oooo00000`000000oooo
0?ooo`0B0?ooo`Go003oH@3oool5ool009@0oooo0ooo00070?ooo`4000000@3oool000030000003o
ool0oooo00X0oooo0ol00?l60?ooo`?o003oHP3oool5ool00980oooo0ooo00090?ooo`4000000@3o
ool000030000003oool0oooo00T0oooo1Ol00?mZ0?ooo`Goo`00H03oool3ool002h0oooo1Ooo0008
0?ooo`4000000@3oool000030000003oool0oooo00T0oooo1Ol00?m[0?ooo`?oo`00H03oool5ool0
02d0oooo1Ooo00080?ooo`4000000@3oool000030000003oool0oooo00T0oooo1Ol00?o>0?ooo`Go
o`00;@3oool5ool000P0oooo0@0000010?ooo`0000<000000?ooo`3oool0203oool5o`00ol40oooo
0ooo000;0?ooo`Goo`00;P3oool3ool000T0oooo0@0000010?ooo`0000<000000?ooo`3oool0203o
ool5o`00ol00oooo1Ooo000;0?ooo`?oo`002@3oool3ool002l0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0203oool5o`00od80oooo0ol00?mk0?ooo`Goo`005P3oool5ool002h0oooo0@000001
0?ooo`0000<000000?ooo`3oool0103oool3o`00o`80oooo0ol00?m20?ooo`Go003o7@3oool3ool0
05X0oooo1Ooo000F0?ooo`Goo`00;P3oool100000040oooo00000`000000oooo0?ooo`030?ooo`Go
003oAP3oool5o`00oa`0oooo1Ooo001A0?ooo`?oo`001P3oool3ool001L0oooo1Ooo000X0?ooo`?o
o`000`3oool100000040oooo00000`000000oooo0?ooo`030?ooo`Go003oAP3oool5o`00oa`0oooo
1Ooo001@0?ooo`Goo`00803oool3ool002P0oooo1Ooo00020?ooo`4000000@3oool000030000003o
ool0oooo00<0oooo1Ol00?m70?ooo`?o003o7@3oool5ool00500oooo1Ooo001;0?ooo`Goo`000P3o
ool100000040oooo00000`000000oooo0?ooo`040?ooo`?o003oEP3oool3ool00100oooo0ooo000X
0?ooo`?oo`009P3oool5ool004/0oooo1Ooo00020?ooo`4000000@3oool000030000003oool0oooo
05`0oooo1Ooo000i0?ooo`Goo`009P3oool3ool004d0oooo0ooo00030?ooo`4000000@3oool00003
0000003oool0oooo05`0oooo1Ooo000i0?ooo`Goo`00O03oool100000040oooo00000`000000oooo
0?ooo`1L0?ooo`Goo`00>@3oool5ool007`0oooo0@0000010?ooo`0000<000000?ooo`3oool0G@3o
ool3ool003/0oooo0ooo001m0?ooo`4000000@3oool000030000003oool0oooo04D0oooo0ol00?oC
0?ooo`4000000@3oool000030000003oool0oooo04@0oooo1Ol00?la0?ooo`?oo`00WP3oool10000
0040oooo00000`000000oooo0?ooo`140?ooo`Go003o<03oool5ool001l0oooo0ooo001k0?ooo`40
00000@3oool000030000003oool0oooo00d0oooo0ol00?ld0?ooo`Go003o<03oool5ool001h0oooo
1Ooo00100?ooo`?oo`00:03oool3ool000<0oooo0ooo00060?ooo`4000000@3oool000030000003o
ool0oooo00`0oooo1Ol00?ld0?ooo`?o003o<@3oool5ool001h0oooo1Ooo000d0?ooo`?oo`00203o
ool5ool002H0oooo1Ooo00000`3oooooo`00ool00003ool000D0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0303oool5o`00ofT0oooo0ooo000O0?ooo`Goo`00<`3oool5ool000L0oooo1Ooo000V
0?ooo`Goo`0000<0ooooool00?oo00000ooo00050?ooo`4000000@3oool000030000003oool0oooo
00`0oooo1Ol00?n<0?ooo`?oo`004P3oool3ool001l0oooo1Ooo00070?ooo`Goo`00503oool3ool0
00l0oooo1Ooo00000`3oooooo`00ool00003ool000D0oooo0@0000010?ooo`0000<000000?ooo`3o
ool00P3oool3o`00o`P0oooo0ol00?m[0?ooo`?oo`00<`3oool5ool001h0oooo1Ooo00080?ooo`?o
o`00503oool5ool00080oooo0ooo000:0?ooo`?oo`000`3oool3ool000H0oooo0@0000010?ooo`00
00@000000?ooo`3oool0oooo1Ol00?md0?ooo`Goo`00<P3oool5ool001l0oooo0ooo000P0?ooo`Go
o`0000<0ooooool00?oo00000ooo000H0?ooo`4000000@3oool000040000003oool0oooo0?ooo`Go
003o8@3oool3o`00obl0oooo0ooo000N0?ooo`Goo`000`3oool3ool002`0oooo1Ooo00120?ooo`Go
o`0000<0ooooool00?oo00000ooo000H0?ooo`4000000@3oool000040000003oool0oooo0?ooo`Go
003o803oool5o`00obd0oooo1Ooo000M0?ooo`Goo`000P3oool5ool002`0oooo0ooo00130?ooo`Go
o`0000<0ooooool00?oo00000ooo000H0?ooo`4000000@3oool000030000003oool0oooo0080oooo
0ol00?lQ0?ooo`Go003o;@3oool5ool000T0oooo0ooo000B0?ooo`?oo`000`3oool5ool007<0oooo
0ooo00030?ooo`?oo`006@3oool100000040oooo00000`000000oooo0?ooo`0T0?ooo`Oo003o;@3o
ool5ool000P0oooo1Ooo000G0?ooo`Goo`00U@3oool100000040oooo00000`000000oooo0?ooo`0S
0?ooo`Oo003o;`3oool3ool000T0oooo1Ooo000H0?ooo`?oo`00S@3oool3ool000H0oooo0@000001
0?ooo`0000<000000?ooo`3oool08`3oool5o`00ocd0oooo1Ooo002W0?ooo`Goo`001@3oool10000
0040oooo00000`000000oooo0?ooo`0S0?ooo`Go003o4P3oool3o`00obT0oooo0ooo002X0?ooo`Go
o`001@3oool100000040oooo00000`000000oooo0?ooo`0T0?ooo`?o003o4P3oool5o`00om<0oooo
1Ooo00050?ooo`4000000@3oool000030000003oool0oooo03T0oooo1Ol00?oD0?ooo`?oo`001P3o
ool100000040oooo00000`000000oooo0?ooo`0<0?ooo`?o003o:P3oool5o`00ocP0oooo0ooo002R
0?ooo`4000000@3oool000030000003oool0oooo00/0oooo1Ol00?lZ0?ooo`?o003o>03oool5ool0
0:40oooo0@0000010?ooo`0000<000000?ooo`3oool02`3oool5o`00ofD0oooo1Ooo002Q0?ooo`40
00000@3oool000030000003oool0oooo00/0oooo1Ol00?mU0?ooo`Goo`00X@3oool100000040oooo
00000`000000oooo0?ooo`0<0?ooo`?o003oI`3oool3ool000<0oooo0ooo002L0?ooo`4000000@3o
ool000030000003oool0oooo07/0oooo1Ooo001H0?ooo`?oo`00;03oool3ool00140oooo0@000001
0?ooo`0000<000000?ooo`3oool0I03oool3ool001@0oooo1Ooo001G0?ooo`Goo`00:P3oool5ool0
0100oooo0@0000010?ooo`0000<000000?ooo`3oool0H`3oool5ool001<0oooo1Ooo001G0?ooo`Go
o`00:P3oool5ool00100oooo0@0000010?ooo`0000<000000?ooo`3oool0H`3oool5ool001@0oooo
0ooo001H0?ooo`Goo`00:P3oool5ool00100oooo0@0000010?ooo`0000<000000?ooo`3oool0H`3o
ool5ool00700oooo0ooo000/0?ooo`?oo`004@3oool100000040oooo00000`000000oooo0?ooo`1T
0?ooo`?oo`00]03oool100000040oooo00000`000000oooo0?ooo`2a0?ooo`?oo`00I`3oool10000
0040oooo00000`000000oooo0?ooo`0l0?ooo`?oo`00L@3oool5ool006H0oooo0@0000010?ooo`00
00<000000?ooo`3oool0>`3oool5ool000h0oooo0ooo0000103oooooo`00ool00?oo001K0?ooo`Go
o`00@@3oool3ool00280oooo0@0000010?ooo`0000<000000?ooo`3oool0>`3oool5ool000d0oooo
2Ooo001J0?ooo`Goo`00@03oool5ool00240oooo0@0000010?ooo`0000<000000?ooo`3oool0>`3o
ool5ool000d0oooo2Ooo000i0?ooo`?oo`007`3oool3ool00440oooo1Ooo000Q0?ooo`4000000@3o
ool000030000003oool0oooo03`0oooo0ooo000>0?ooo`Woo`00>03oool5ool00680oooo1Ooo000Q
0?ooo`4000000@3oool000030000003oool0oooo01`0oooo0ol00?l_0?ooo`?oo`0000@0ooooool0
0?oo003oo`00>@3oool5ool006<0oooo0ooo000R0?ooo`4000000@3oool000030000003oool0oooo
01/0oooo1Ol00?m^0?ooo`Goo`00I`3oool3ool001h0oooo0@0000010?ooo`0000<000000?ooo`3o
ool06`3oool5o`00ofl0oooo0ooo001W0?ooo`Goo`007@3oool100000040oooo00000`000000oooo
0?ooo`0K0?ooo`Go003of@3oool5ool00180oooo0ooo00080?ooo`4000000@3oool000030000003o
ool0oooo01`0oooo0ol00?l[0?ooo`?oo`008P3oool3ool008L0oooo1Ooo000A0?ooo`Goo`001`3o
ool100000040oooo00000`000000oooo0?ooo`190?ooo`Goo`00803oool5ool00800oooo0ooo0004
0?ooo`?oo`004P3oool5ool000L0oooo0@0000010?ooo`0000<000000?ooo`3oool0B@3oool5ool0
0200oooo1Ooo001o0?ooo`Goo`00603oool5ool000L0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0B@3oool5ool00200oooo1Ooo001o0?ooo`Goo`006@3oool3ool000P0oooo0@0000010?ooo`00
00<000000?ooo`3oool0BP3oool3ool000h0oooo0ooo000A0?ooo`?oo`00P03oool5ool002@0oooo
0@0000010?ooo`0000<000000?ooo`3oool0FP3oool5ool00140oooo0ooo00200?ooo`?oo`009@3o
ool100000040oooo00000`000000oooo0?ooo`1J0?ooo`Goo`00403oool5ool006<0oooo0ooo0011
0?ooo`4000000@3oool000030000003oool0oooo01X0oooo0ol00?lm0?ooo`Goo`00403oool5ool0
0680oooo1Ooo00100?ooo`4000000@3oool000030000003oool0oooo01T0oooo1Ol00?lX0?ooo`?o
o`004P3oool3ool00140oooo1Ooo001R0?ooo`Goo`00@03oool100000040oooo00000`000000oooo
0?ooo`0I0?ooo`Go003o9`3oool5ool001P0oooo0ooo000;0?ooo`?oo`00H`3oool5ool00400oooo
0@0000010?ooo`0000<000000?ooo`3oool06@3oool5o`00obL0oooo1Ooo000G0?ooo`Goo`00L@3o
ool3ool00440oooo0@0000010?ooo`0000<000000?ooo`3oool06P3oool3o`00obP0oooo1Ooo000G
0?ooo`Goo`00603oool3ool004L0oooo0ooo00070?ooo`?oo`00AP3oool100000040oooo00000`00
0000oooo0?ooo`160?ooo`?oo`00603oool5ool001L0oooo1Ooo00150?ooo`Goo`001@3oool5ool0
04D0oooo0@0000010?ooo`0000<000000?ooo`3oool0HP3oool3ool001P0oooo1Ooo00150?ooo`Go
o`001@3oool5ool004D0oooo0@0000010?ooo`0000<000000?ooo`3oool0O@3oool5ool004D0oooo
1Ooo00050?ooo`Goo`004P3oool3ool00300oooo0@0000010?ooo`0000<000000?ooo`3oool0OP3o
ool3ool004L0oooo0ooo00070?ooo`?oo`004P3oool5ool002l0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0[@3oool3ool003L0oooo1Ooo000_0?ooo`4000000@3oool000030000003oool0oooo
0:`0oooo1Ooo000f0?ooo`Goo`00;`3oool100000040oooo00000`000000oooo0?ooo`2/0?ooo`Go
o`00=`3oool3ool00300oooo0@0000010?ooo`0000<000000?ooo`3oool0@`3oool3ool006H0oooo
1Ooo001Z0?ooo`4000000@3oool000030000003oool0oooo0480oooo1Ooo001V0?ooo`?oo`00J`3o
ool100000040oooo00000`000000oooo0?ooo`120?ooo`Goo`00e03oool100000040oooo00000`00
0000oooo0?ooo`120?ooo`Goo`00Z03oool3ool002T0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0@`3oool3ool00:P0oooo1Ooo000X0?ooo`4000000@3oool000030000003oool0oooo06d0oooo
0ooo001n0?ooo`Goo`00:03oool100000040oooo00000`000000oooo0?ooo`1T0?ooo`?oo`001@3o
ool5ool007d0oooo1Ooo000X0?ooo`4000000@3oool000030000003oool0oooo06<0oooo1Ooo0004
0?ooo`Goo`00OP3oool3ool002T0oooo0@0000010?ooo`0000<000000?ooo`3oool0H`3oool5ool0
00@0oooo1Ooo002Z0?ooo`4000000@3oool000030000003oool0oooo0380oooo0ooo000^0?ooo`Go
o`001@3oool3ool00:/0oooo0@0000010?ooo`0000<000000?ooo`3oool0<@3oool5ool002h0oooo
0ooo001d0?ooo`?oo`00?@3oool100000040oooo00000`000000oooo0?ooo`060?ooo`Co003o9`3o
ool5ool00500oooo0ooo001A0?ooo`Goo`00?03oool100000040oooo00000`000000oooo0?ooo`05
0?ooo`Ko003o9P3oool5ool004l0oooo1Ooo001@0?ooo`Goo`00?03oool100000040oooo00000`00
0000oooo0?ooo`050?ooo`Ko003o9`3oool3ool00500oooo1Ooo001@0?ooo`Goo`00?03oool10000
0040oooo00000`000000oooo0?ooo`050?ooo`Ko003oNP3oool5ool00540oooo0ooo000m0?ooo`40
00000@3oool000030000003oool0oooo00H0oooo1?l00?lA0?ooo`?oo`00J03oool3ool00980oooo
0@0000010?ooo`0000<000000?ooo`3oool06P3oool5ool005h0oooo0ooo002K0?ooo`4000000@3o
ool000030000003oool0oooo01X0oooo1Ooo001M0?ooo`Goo`00VP3oool100000040oooo00000`00
0000oooo0?ooo`0J0?ooo`Goo`00G@3oool5ool00100oooo0ooo00270?ooo`4000000@3oool00003
0000003oool0oooo01/0oooo0ooo001N0?ooo`Goo`003`3oool5ool003L0oooo0ooo001<0?ooo`40
00000@3oool000030000003oool0oooo07d0oooo0ooo000@0?ooo`Goo`00=P3oool5ool004/0oooo
0@0000010?ooo`0000<000000?ooo`3oool0T03oool5ool003H0oooo1Ooo001;0?ooo`4000000@3o
ool000030000003oool0oooo0940oooo0ooo000W0?ooo`?oo`00203oool3ool00080oooo1Ooo001;
0?ooo`4000000@3oool000030000003oool0oooo0;X0oooo1Ooo00060?ooo`Goo`000P3oool3ool0
04`0oooo0@0000010?ooo`0000<000000?ooo`3oool0^P3oool5ool000H0oooo1Ooo001A0?ooo`40
00000@3oool000030000003oool0oooo0;X0oooo1Ooo00060?ooo`Goo`00D@3oool100000040oooo
00000`000000oooo0?ooo`2k0?ooo`?oo`001`3oool4ool00580oooo0@0000010?ooo`0000<00000
0?ooo`3oool0a03oool5ool00580oooo0@0000010?ooo`00a`000005ool005<000000@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Gaussian probability density functions", "Subsection"],

Cell[CellGroupData[{

Cell["Compute Gaussian pdfs", "Subsubsection"],

Cell[BoxData[{
    \(\(pdf1\  = \ gaussian[data1, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(pdf2\  = \ gaussian[data2, {x, y}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Gaussian pdfs", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[pdf1, pdf2, pr, x, y, yS, imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.98077 .18514 m
.95611 .18247 L
.93146 .18141 L
.9068 .1818 L
.88215 .18352 L
.8575 .18645 L
.83284 .19052 L
.82606 .19181 L
.80819 .19573 L
.78353 .202 L
.75888 .20924 L
.73687 .21647 L
.73422 .21741 L
.70957 .22664 L
.68491 .23674 L
.67477 .24112 L
.66026 .24779 L
.6356 .25978 L
.62383 .26578 L
.61095 .27269 L
.58629 .28655 L
.5796 .29043 L
.56164 .30139 L
.5401 .31509 L
.53698 .31716 L
.51233 .33402 L
.50423 .33974 L
.48767 .35193 L
.47127 .3644 L
.46302 .37091 L
.44076 .38905 L
.43836 .39107 L
.41371 .41253 L
.41239 .41371 L
.38905 .43536 L
.38592 .43836 L
.3644 .45969 L
.36115 .46302 L
.33974 .48568 L
.33793 .48767 L
.31617 .51233 L
.31509 .51359 L
.29581 .53698 L
.29043 .54375 L
.27676 .56164 L
.26578 .57657 L
.25893 .58629 L
.24228 .61095 L
.24112 .61273 L
.22691 .6356 L
.21647 .65336 L
.21263 .66026 L
.19955 .68491 L
.19181 .70051 L
.1876 .70957 L
.17685 .73422 L
.16722 .75888 L
.16716 .75904 L
.15891 .78353 L
.15179 .80819 L
.14597 .83284 L
.1425 .85095 L
.14153 .8575 L
.13858 .88215 L
.13719 .9068 L
.1375 .93146 L
.13971 .95611 L
.1425 .97338 L
.14406 .98077 L
.98077 .98077 L
F
0 g
.98077 .18514 m
.95611 .18247 L
.93146 .18141 L
.9068 .1818 L
.88215 .18352 L
.8575 .18645 L
.83284 .19052 L
.82606 .19181 L
.80819 .19573 L
.78353 .202 L
.75888 .20924 L
.73687 .21647 L
.73422 .21741 L
.70957 .22664 L
.68491 .23674 L
.67477 .24112 L
.66026 .24779 L
.6356 .25978 L
.62383 .26578 L
.61095 .27269 L
.58629 .28655 L
.5796 .29043 L
.56164 .30139 L
.5401 .31509 L
.53698 .31716 L
.51233 .33402 L
.50423 .33974 L
.48767 .35193 L
.47127 .3644 L
.46302 .37091 L
.44076 .38905 L
.43836 .39107 L
.41371 .41253 L
.41239 .41371 L
.38905 .43536 L
.38592 .43836 L
.3644 .45969 L
.36115 .46302 L
.33974 .48568 L
.33793 .48767 L
.31617 .51233 L
.31509 .51359 L
.29581 .53698 L
.29043 .54375 L
.27676 .56164 L
.26578 .57657 L
.25893 .58629 L
.24228 .61095 L
.24112 .61273 L
.22691 .6356 L
Mistroke
.21647 .65336 L
.21263 .66026 L
.19955 .68491 L
.19181 .70051 L
.1876 .70957 L
.17685 .73422 L
.16722 .75888 L
.16716 .75904 L
.15891 .78353 L
.15179 .80819 L
.14597 .83284 L
.1425 .85095 L
.14153 .8575 L
.13858 .88215 L
.13719 .9068 L
.1375 .93146 L
.13971 .95611 L
.1425 .97338 L
.14406 .98077 L
Mfstroke
.2 g
.98077 .28583 m
.95611 .27768 L
.93146 .27231 L
.9068 .26926 L
.88215 .26818 L
.8575 .26886 L
.83284 .27112 L
.80819 .27482 L
.78353 .27986 L
.75888 .28616 L
.74429 .29043 L
.73422 .29368 L
.70957 .3024 L
.68491 .31224 L
.67822 .31509 L
.66026 .32324 L
.6356 .33535 L
.62715 .33974 L
.61095 .34862 L
.58629 .36301 L
.58401 .3644 L
.56164 .37864 L
.54613 .38905 L
.53698 .39547 L
.51233 .41359 L
.51217 .41371 L
.48767 .43312 L
.48134 .43836 L
.46302 .45413 L
.45311 .46302 L
.43836 .47677 L
.42713 .48767 L
.41371 .50123 L
.40315 .51233 L
.38905 .52778 L
.38099 .53698 L
.3644 .55679 L
.36051 .56164 L
.34161 .58629 L
.33974 .58883 L
.32424 .61095 L
.31509 .62481 L
.30832 .6356 L
.2938 .66026 L
.29043 .66633 L
.28073 .68491 L
.26904 .70957 L
.26578 .71698 L
.2588 .73422 L
.25 .75888 L
.2427 .78353 L
.24112 .78943 L
.23702 .80819 L
.23302 .83284 L
.23085 .8575 L
.23068 .88215 L
.23278 .9068 L
.2375 .93146 L
.24112 .94445 L
.24538 .95611 L
.25722 .98077 L
.98077 .98077 L
F
0 g
.98077 .28583 m
.95611 .27768 L
.93146 .27231 L
.9068 .26926 L
.88215 .26818 L
.8575 .26886 L
.83284 .27112 L
.80819 .27482 L
.78353 .27986 L
.75888 .28616 L
.74429 .29043 L
.73422 .29368 L
.70957 .3024 L
.68491 .31224 L
.67822 .31509 L
.66026 .32324 L
.6356 .33535 L
.62715 .33974 L
.61095 .34862 L
.58629 .36301 L
.58401 .3644 L
.56164 .37864 L
.54613 .38905 L
.53698 .39547 L
.51233 .41359 L
.51217 .41371 L
.48767 .43312 L
.48134 .43836 L
.46302 .45413 L
.45311 .46302 L
.43836 .47677 L
.42713 .48767 L
.41371 .50123 L
.40315 .51233 L
.38905 .52778 L
.38099 .53698 L
.3644 .55679 L
.36051 .56164 L
.34161 .58629 L
.33974 .58883 L
.32424 .61095 L
.31509 .62481 L
.30832 .6356 L
.2938 .66026 L
.29043 .66633 L
.28073 .68491 L
.26904 .70957 L
.26578 .71698 L
.2588 .73422 L
.25 .75888 L
Mistroke
.2427 .78353 L
.24112 .78943 L
.23702 .80819 L
.23302 .83284 L
.23085 .8575 L
.23068 .88215 L
.23278 .9068 L
.2375 .93146 L
.24112 .94445 L
.24538 .95611 L
.25722 .98077 L
Mfstroke
.3 g
.98077 .36271 m
.95611 .34656 L
.94188 .33974 L
.93146 .33574 L
.9068 .32872 L
.88215 .32465 L
.8575 .323 L
.83284 .32343 L
.80819 .32569 L
.78353 .32962 L
.75888 .33507 L
.7415 .33974 L
.73422 .34196 L
.70957 .35025 L
.68491 .35987 L
.67428 .3644 L
.66026 .3708 L
.6356 .38304 L
.62434 .38905 L
.61095 .3966 L
.58629 .41151 L
.58282 .41371 L
.56164 .42783 L
.54677 .43836 L
.53698 .44561 L
.51472 .46302 L
.51233 .46497 L
.48767 .48605 L
.48586 .48767 L
.46302 .50905 L
.45968 .51233 L
.43836 .53424 L
.43582 .53698 L
.41403 .56164 L
.41371 .56202 L
.39417 .58629 L
.38905 .59302 L
.37609 .61095 L
.3644 .62827 L
.35971 .6356 L
.345 .66026 L
.33974 .66976 L
.33192 .68491 L
.32046 .70957 L
.31509 .72247 L
.31067 .73422 L
.30259 .75888 L
.2963 .78353 L
.29192 .80819 L
.29043 .82129 L
.28964 .83284 L
.28969 .8575 L
.29043 .86722 L
.29244 .88215 L
.29841 .9068 L
.30844 .93146 L
.31509 .94335 L
.32401 .95611 L
.33974 .9733 L
.34823 .98077 L
.98077 .98077 L
F
0 g
.98077 .36271 m
.95611 .34656 L
.94188 .33974 L
.93146 .33574 L
.9068 .32872 L
.88215 .32465 L
.8575 .323 L
.83284 .32343 L
.80819 .32569 L
.78353 .32962 L
.75888 .33507 L
.7415 .33974 L
.73422 .34196 L
.70957 .35025 L
.68491 .35987 L
.67428 .3644 L
.66026 .3708 L
.6356 .38304 L
.62434 .38905 L
.61095 .3966 L
.58629 .41151 L
.58282 .41371 L
.56164 .42783 L
.54677 .43836 L
.53698 .44561 L
.51472 .46302 L
.51233 .46497 L
.48767 .48605 L
.48586 .48767 L
.46302 .50905 L
.45968 .51233 L
.43836 .53424 L
.43582 .53698 L
.41403 .56164 L
.41371 .56202 L
.39417 .58629 L
.38905 .59302 L
.37609 .61095 L
.3644 .62827 L
.35971 .6356 L
.345 .66026 L
.33974 .66976 L
.33192 .68491 L
.32046 .70957 L
.31509 .72247 L
.31067 .73422 L
.30259 .75888 L
.2963 .78353 L
.29192 .80819 L
.29043 .82129 L
Mistroke
.28964 .83284 L
.28969 .8575 L
.29043 .86722 L
.29244 .88215 L
.29841 .9068 L
.30844 .93146 L
.31509 .94335 L
.32401 .95611 L
.33974 .9733 L
.34823 .98077 L
Mfstroke
.4 g
.98077 .60161 m
.97762 .61095 L
.96823 .6356 L
.95692 .66026 L
.95611 .66187 L
.94374 .68491 L
.93146 .7053 L
.92872 .70957 L
.91178 .73422 L
.9068 .74098 L
.89286 .75888 L
.88215 .77177 L
.87184 .78353 L
.8575 .79899 L
.84851 .80819 L
.83284 .8234 L
.82258 .83284 L
.80819 .84544 L
.79361 .8575 L
.78353 .86543 L
.76092 .88215 L
.75888 .88359 L
.73422 .90003 L
.72331 .9068 L
.70957 .91488 L
.68491 .9282 L
.67843 .93146 L
.66026 .94 L
.6356 .95032 L
.61996 .95611 L
.61095 .95914 L
.58629 .96639 L
.56164 .972 L
.53698 .97587 L
.51233 .97782 L
.48767 .97762 L
.46302 .97491 L
.43836 .96914 L
.41371 .95942 L
.40734 .95611 L
.38905 .94403 L
.37509 .93146 L
.3644 .91887 L
.35646 .9068 L
.34509 .88215 L
.33974 .86401 L
.33865 .8575 L
.33593 .83284 L
.33624 .80819 L
.33915 .78353 L
.33974 .77955 L
.34437 .75888 L
.3517 .73422 L
.36101 .70957 L
.3644 .7016 L
.37223 .68491 L
.3853 .66026 L
.38905 .65375 L
.40025 .6356 L
.41371 .61566 L
.41709 .61095 L
.43591 .58629 L
.43836 .58326 L
.45684 .56164 L
.46302 .55482 L
.48006 .53698 L
.48767 .52943 L
.50586 .51233 L
.51233 .50654 L
.53467 .48767 L
.53698 .48581 L
.56164 .467 L
.56717 .46302 L
.58629 .44994 L
.60451 .43836 L
.61095 .43449 L
.6356 .42062 L
.64897 .41371 L
.66026 .40825 L
.68491 .39738 L
.70655 .38905 L
.70957 .388 L
.73422 .38017 L
.75888 .37394 L
.78353 .3694 L
.80819 .3667 L
.83284 .36606 L
.8575 .36778 L
.88215 .37233 L
.9068 .38043 L
.92441 .38905 L
.93146 .39342 L
.95567 .41371 L
.95611 .41418 L
.97387 .43836 L
.98077 .45181 L
F
0 g
.98077 .60161 m
.97762 .61095 L
.96823 .6356 L
.95692 .66026 L
.95611 .66187 L
.94374 .68491 L
.93146 .7053 L
.92872 .70957 L
.91178 .73422 L
.9068 .74098 L
.89286 .75888 L
.88215 .77177 L
.87184 .78353 L
.8575 .79899 L
.84851 .80819 L
.83284 .8234 L
.82258 .83284 L
.80819 .84544 L
.79361 .8575 L
.78353 .86543 L
.76092 .88215 L
.75888 .88359 L
.73422 .90003 L
.72331 .9068 L
.70957 .91488 L
.68491 .9282 L
.67843 .93146 L
.66026 .94 L
.6356 .95032 L
.61996 .95611 L
.61095 .95914 L
.58629 .96639 L
.56164 .972 L
.53698 .97587 L
.51233 .97782 L
.48767 .97762 L
.46302 .97491 L
.43836 .96914 L
.41371 .95942 L
.40734 .95611 L
.38905 .94403 L
.37509 .93146 L
.3644 .91887 L
.35646 .9068 L
.34509 .88215 L
.33974 .86401 L
.33865 .8575 L
.33593 .83284 L
.33624 .80819 L
.33915 .78353 L
Mistroke
.33974 .77955 L
.34437 .75888 L
.3517 .73422 L
.36101 .70957 L
.3644 .7016 L
.37223 .68491 L
.3853 .66026 L
.38905 .65375 L
.40025 .6356 L
.41371 .61566 L
.41709 .61095 L
.43591 .58629 L
.43836 .58326 L
.45684 .56164 L
.46302 .55482 L
.48006 .53698 L
.48767 .52943 L
.50586 .51233 L
.51233 .50654 L
.53467 .48767 L
.53698 .48581 L
.56164 .467 L
.56717 .46302 L
.58629 .44994 L
.60451 .43836 L
.61095 .43449 L
.6356 .42062 L
.64897 .41371 L
.66026 .40825 L
.68491 .39738 L
.70655 .38905 L
.70957 .388 L
.73422 .38017 L
.75888 .37394 L
.78353 .3694 L
.80819 .3667 L
.83284 .36606 L
.8575 .36778 L
.88215 .37233 L
.9068 .38043 L
.92441 .38905 L
.93146 .39342 L
.95567 .41371 L
.95611 .41418 L
.97387 .43836 L
.98077 .45181 L
Mfstroke
.5 g
.73422 .41353 m
.75888 .40807 L
.78353 .40463 L
.80819 .40343 L
.83284 .40485 L
.8575 .40946 L
.87154 .41371 L
.88215 .41824 L
.9068 .43316 L
.91304 .43836 L
.93146 .45944 L
.93377 .46302 L
.94555 .48767 L
.9517 .51233 L
.95373 .53698 L
.95246 .56164 L
.94839 .58629 L
.94182 .61095 L
.93295 .6356 L
.93146 .63929 L
.92191 .66026 L
.90874 .68491 L
.9068 .68824 L
.89344 .70957 L
.88215 .72586 L
.87596 .73422 L
.8575 .75732 L
.85617 .75888 L
.83388 .78353 L
.83284 .78461 L
.80876 .80819 L
.80819 .80872 L
.78353 .83021 L
.78031 .83284 L
.75888 .84944 L
.7477 .8575 L
.73422 .86666 L
.70957 .88202 L
.70935 .88215 L
.68491 .89561 L
.66179 .9068 L
.66026 .90749 L
.6356 .91766 L
.61095 .9261 L
.5919 .93146 L
.58629 .93275 L
.56164 .93748 L
.53698 .94012 L
.51233 .94039 L
.48767 .93787 L
.46302 .93185 L
.46181 .93146 L
.43836 .92111 L
.41795 .9068 L
.41371 .90293 L
.39665 .88215 L
.38905 .8687 L
.38456 .8575 L
.37819 .83284 L
.37599 .80819 L
.37712 .78353 L
.38107 .75888 L
.38752 .73422 L
.38905 .72927 L
.39629 .70957 L
.40723 .68491 L
.41371 .67214 L
.42031 .66026 L
.4355 .6356 L
.43836 .63131 L
.45289 .61095 L
.46302 .59787 L
.47256 .58629 L
.48767 .56917 L
.49473 .56164 L
.51233 .54396 L
.51971 .53698 L
.53698 .52155 L
.54798 .51233 L
.56164 .50151 L
.58038 .48767 L
.58629 .48355 L
.61095 .46752 L
.61839 .46302 L
.6356 .45328 L
.66026 .44076 L
.66537 .43836 L
.68491 .42996 L
.70957 .42086 L
.73353 .41371 L
F
0 g
.73422 .41353 m
.75888 .40807 L
.78353 .40463 L
.80819 .40343 L
.83284 .40485 L
.8575 .40946 L
.87154 .41371 L
.88215 .41824 L
.9068 .43316 L
.91304 .43836 L
.93146 .45944 L
.93377 .46302 L
.94555 .48767 L
.9517 .51233 L
.95373 .53698 L
.95246 .56164 L
.94839 .58629 L
.94182 .61095 L
.93295 .6356 L
.93146 .63929 L
.92191 .66026 L
.90874 .68491 L
.9068 .68824 L
.89344 .70957 L
.88215 .72586 L
.87596 .73422 L
.8575 .75732 L
.85617 .75888 L
.83388 .78353 L
.83284 .78461 L
.80876 .80819 L
.80819 .80872 L
.78353 .83021 L
.78031 .83284 L
.75888 .84944 L
.7477 .8575 L
.73422 .86666 L
.70957 .88202 L
.70935 .88215 L
.68491 .89561 L
.66179 .9068 L
.66026 .90749 L
.6356 .91766 L
.61095 .9261 L
.5919 .93146 L
.58629 .93275 L
.56164 .93748 L
.53698 .94012 L
.51233 .94039 L
.48767 .93787 L
Mistroke
.46302 .93185 L
.46181 .93146 L
.43836 .92111 L
.41795 .9068 L
.41371 .90293 L
.39665 .88215 L
.38905 .8687 L
.38456 .8575 L
.37819 .83284 L
.37599 .80819 L
.37712 .78353 L
.38107 .75888 L
.38752 .73422 L
.38905 .72927 L
.39629 .70957 L
.40723 .68491 L
.41371 .67214 L
.42031 .66026 L
.4355 .6356 L
.43836 .63131 L
.45289 .61095 L
.46302 .59787 L
.47256 .58629 L
.48767 .56917 L
.49473 .56164 L
.51233 .54396 L
.51971 .53698 L
.53698 .52155 L
.54798 .51233 L
.56164 .50151 L
.58038 .48767 L
.58629 .48355 L
.61095 .46752 L
.61839 .46302 L
.6356 .45328 L
.66026 .44076 L
.66537 .43836 L
.68491 .42996 L
.70957 .42086 L
.73353 .41371 L
.73422 .41353 L
Mfstroke
.6 g
.78353 .43807 m
.80158 .43836 L
.80819 .43889 L
.83284 .44326 L
.8575 .45246 L
.87463 .46302 L
.88215 .46931 L
.89776 .48767 L
.9068 .50409 L
.90976 .51233 L
.91539 .53698 L
.91649 .56164 L
.91402 .58629 L
.90852 .61095 L
.9068 .61719 L
.90031 .6356 L
.88958 .66026 L
.88215 .6748 L
.8764 .68491 L
.86077 .70957 L
.8575 .71431 L
.84262 .73422 L
.83284 .7462 L
.82174 .75888 L
.80819 .77326 L
.79781 .78353 L
.78353 .79677 L
.77028 .80819 L
.75888 .81741 L
.73817 .83284 L
.73422 .83559 L
.70957 .85158 L
.69955 .8575 L
.68491 .8655 L
.66026 .87746 L
.64941 .88215 L
.6356 .88746 L
.61095 .89546 L
.58629 .90136 L
.56164 .90498 L
.53698 .90601 L
.51233 .90397 L
.48767 .898 L
.46302 .88641 L
.45666 .88215 L
.43836 .86506 L
.43272 .8575 L
.42033 .83284 L
.41447 .80819 L
.41371 .80131 L
.41318 .78353 L
.41371 .77379 L
.4155 .75888 L
.42086 .73422 L
.42895 .70957 L
.43836 .68737 L
.43957 .68491 L
.45264 .66026 L
.46302 .64329 L
.46815 .6356 L
.48618 .61095 L
.48767 .60906 L
.50693 .58629 L
.51233 .58039 L
.5307 .56164 L
.53698 .55566 L
.55805 .53698 L
.56164 .53401 L
.58629 .51494 L
.58992 .51233 L
.61095 .49816 L
.62818 .48767 L
.6356 .48348 L
.66026 .47079 L
.67758 .46302 L
.68491 .46006 L
.70957 .45131 L
.73422 .44461 L
.75888 .44011 L
.77683 .43836 L
F
0 g
.78353 .43807 m
.80158 .43836 L
.80819 .43889 L
.83284 .44326 L
.8575 .45246 L
.87463 .46302 L
.88215 .46931 L
.89776 .48767 L
.9068 .50409 L
.90976 .51233 L
.91539 .53698 L
.91649 .56164 L
.91402 .58629 L
.90852 .61095 L
.9068 .61719 L
.90031 .6356 L
.88958 .66026 L
.88215 .6748 L
.8764 .68491 L
.86077 .70957 L
.8575 .71431 L
.84262 .73422 L
.83284 .7462 L
.82174 .75888 L
.80819 .77326 L
.79781 .78353 L
.78353 .79677 L
.77028 .80819 L
.75888 .81741 L
.73817 .83284 L
.73422 .83559 L
.70957 .85158 L
.69955 .8575 L
.68491 .8655 L
.66026 .87746 L
.64941 .88215 L
.6356 .88746 L
.61095 .89546 L
.58629 .90136 L
.56164 .90498 L
.53698 .90601 L
.51233 .90397 L
.48767 .898 L
.46302 .88641 L
.45666 .88215 L
.43836 .86506 L
.43272 .8575 L
.42033 .83284 L
.41447 .80819 L
.41371 .80131 L
Mistroke
.41318 .78353 L
.41371 .77379 L
.4155 .75888 L
.42086 .73422 L
.42895 .70957 L
.43836 .68737 L
.43957 .68491 L
.45264 .66026 L
.46302 .64329 L
.46815 .6356 L
.48618 .61095 L
.48767 .60906 L
.50693 .58629 L
.51233 .58039 L
.5307 .56164 L
.53698 .55566 L
.55805 .53698 L
.56164 .53401 L
.58629 .51494 L
.58992 .51233 L
.61095 .49816 L
.62818 .48767 L
.6356 .48348 L
.66026 .47079 L
.67758 .46302 L
.68491 .46006 L
.70957 .45131 L
.73422 .44461 L
.75888 .44011 L
.77683 .43836 L
.78353 .43807 L
Mfstroke
.7 g
.70957 .48099 m
.73422 .47512 L
.75888 .47195 L
.78353 .47192 L
.80819 .47586 L
.83284 .48546 L
.83677 .48767 L
.8575 .50492 L
.8632 .51233 L
.87527 .53698 L
.88005 .56164 L
.87989 .58629 L
.87586 .61095 L
.86852 .6356 L
.85819 .66026 L
.8575 .66173 L
.84501 .68491 L
.83284 .70404 L
.82895 .70957 L
.8099 .73422 L
.80819 .73626 L
.78753 .75888 L
.78353 .7629 L
.76124 .78353 L
.75888 .78556 L
.73422 .80507 L
.72994 .80819 L
.70957 .82189 L
.69119 .83284 L
.68491 .83626 L
.66026 .84832 L
.63733 .8575 L
.6356 .85809 L
.61095 .86551 L
.58629 .87042 L
.56164 .87249 L
.53698 .87116 L
.51233 .86538 L
.49458 .8575 L
.48767 .85293 L
.4673 .83284 L
.46302 .82694 L
.4548 .80819 L
.44974 .78353 L
.4497 .75888 L
.45358 .73422 L
.46077 .70957 L
.46302 .70319 L
.47096 .68491 L
.48402 .66026 L
.48767 .65413 L
.49994 .6356 L
.51233 .61896 L
.51884 .61095 L
.53698 .59052 L
.54105 .58629 L
.56164 .5665 L
.56713 .56164 L
.58629 .54588 L
.59816 .53698 L
.61095 .5281 L
.6356 .51285 L
.6365 .51233 L
.66026 .49993 L
.68491 .48931 L
.68898 .48767 L
F
0 g
.70957 .48099 m
.73422 .47512 L
.75888 .47195 L
.78353 .47192 L
.80819 .47586 L
.83284 .48546 L
.83677 .48767 L
.8575 .50492 L
.8632 .51233 L
.87527 .53698 L
.88005 .56164 L
.87989 .58629 L
.87586 .61095 L
.86852 .6356 L
.85819 .66026 L
.8575 .66173 L
.84501 .68491 L
.83284 .70404 L
.82895 .70957 L
.8099 .73422 L
.80819 .73626 L
.78753 .75888 L
.78353 .7629 L
.76124 .78353 L
.75888 .78556 L
.73422 .80507 L
.72994 .80819 L
.70957 .82189 L
.69119 .83284 L
.68491 .83626 L
.66026 .84832 L
.63733 .8575 L
.6356 .85809 L
.61095 .86551 L
.58629 .87042 L
.56164 .87249 L
.53698 .87116 L
.51233 .86538 L
.49458 .8575 L
.48767 .85293 L
.4673 .83284 L
.46302 .82694 L
.4548 .80819 L
.44974 .78353 L
.4497 .75888 L
.45358 .73422 L
.46077 .70957 L
.46302 .70319 L
.47096 .68491 L
.48402 .66026 L
Mistroke
.48767 .65413 L
.49994 .6356 L
.51233 .61896 L
.51884 .61095 L
.53698 .59052 L
.54105 .58629 L
.56164 .5665 L
.56713 .56164 L
.58629 .54588 L
.59816 .53698 L
.61095 .5281 L
.6356 .51285 L
.6365 .51233 L
.66026 .49993 L
.68491 .48931 L
.68898 .48767 L
.70957 .48099 L
Mfstroke
.8 g
.70957 .51153 m
.73422 .5069 L
.75888 .50582 L
.78353 .5093 L
.79486 .51233 L
.80819 .51947 L
.82755 .53698 L
.83284 .54339 L
.83987 .56164 L
.84368 .58629 L
.84193 .61095 L
.83588 .6356 L
.83284 .64522 L
.82615 .66026 L
.81295 .68491 L
.80819 .69261 L
.79629 .70957 L
.78353 .72559 L
.7759 .73422 L
.75888 .75171 L
.75118 .75888 L
.73422 .77331 L
.72084 .78353 L
.70957 .79136 L
.68491 .80637 L
.68167 .80819 L
.66026 .81859 L
.6356 .82803 L
.62048 .83284 L
.61095 .83459 L
.58629 .83798 L
.56164 .83752 L
.53979 .83284 L
.53698 .83188 L
.51233 .81787 L
.50306 .80819 L
.49018 .78353 L
.48767 .7732 L
.48609 .75888 L
.48761 .73422 L
.48767 .7338 L
.49344 .70957 L
.50302 .68491 L
.51233 .66642 L
.51606 .66026 L
.53257 .6356 L
.53698 .62976 L
.55277 .61095 L
.56164 .60144 L
.57727 .58629 L
.58629 .57832 L
.60733 .56164 L
.61095 .55903 L
.6356 .5429 L
.64586 .53698 L
.66026 .52966 L
.68491 .51918 L
.7061 .51233 L
F
0 g
.70957 .51153 m
.73422 .5069 L
.75888 .50582 L
.78353 .5093 L
.79486 .51233 L
.80819 .51947 L
.82755 .53698 L
.83284 .54339 L
.83987 .56164 L
.84368 .58629 L
.84193 .61095 L
.83588 .6356 L
.83284 .64522 L
.82615 .66026 L
.81295 .68491 L
.80819 .69261 L
.79629 .70957 L
.78353 .72559 L
.7759 .73422 L
.75888 .75171 L
.75118 .75888 L
.73422 .77331 L
.72084 .78353 L
.70957 .79136 L
.68491 .80637 L
.68167 .80819 L
.66026 .81859 L
.6356 .82803 L
.62048 .83284 L
.61095 .83459 L
.58629 .83798 L
.56164 .83752 L
.53979 .83284 L
.53698 .83188 L
.51233 .81787 L
.50306 .80819 L
.49018 .78353 L
.48767 .7732 L
.48609 .75888 L
.48761 .73422 L
.48767 .7338 L
.49344 .70957 L
.50302 .68491 L
.51233 .66642 L
.51606 .66026 L
.53257 .6356 L
.53698 .62976 L
.55277 .61095 L
.56164 .60144 L
.57727 .58629 L
Mistroke
.58629 .57832 L
.60733 .56164 L
.61095 .55903 L
.6356 .5429 L
.64586 .53698 L
.66026 .52966 L
.68491 .51918 L
.7061 .51233 L
.70957 .51153 L
Mfstroke
.9 g
.68491 .55186 m
.70957 .5453 L
.73422 .54297 L
.75888 .54617 L
.78353 .55932 L
.786 .56164 L
.80066 .58629 L
.80356 .61095 L
.79991 .6356 L
.79116 .66026 L
.78353 .67626 L
.77795 .68491 L
.76017 .70957 L
.75888 .71115 L
.73733 .73422 L
.73422 .73715 L
.70957 .75753 L
.70775 .75888 L
.68491 .77372 L
.66629 .78353 L
.66026 .78613 L
.6356 .79506 L
.61095 .80014 L
.58629 .80063 L
.56164 .7946 L
.54423 .78353 L
.53698 .7773 L
.52944 .75888 L
.5261 .73422 L
.52952 .70957 L
.53698 .68745 L
.53806 .68491 L
.55104 .66026 L
.56164 .64433 L
.56856 .6356 L
.58629 .6157 L
.59114 .61095 L
.61095 .59348 L
.62028 .58629 L
.6356 .57588 L
.66026 .56213 L
.66109 .56164 L
F
0 g
.68491 .55186 m
.70957 .5453 L
.73422 .54297 L
.75888 .54617 L
.78353 .55932 L
.786 .56164 L
.80066 .58629 L
.80356 .61095 L
.79991 .6356 L
.79116 .66026 L
.78353 .67626 L
.77795 .68491 L
.76017 .70957 L
.75888 .71115 L
.73733 .73422 L
.73422 .73715 L
.70957 .75753 L
.70775 .75888 L
.68491 .77372 L
.66629 .78353 L
.66026 .78613 L
.6356 .79506 L
.61095 .80014 L
.58629 .80063 L
.56164 .7946 L
.54423 .78353 L
.53698 .7773 L
.52944 .75888 L
.5261 .73422 L
.52952 .70957 L
.53698 .68745 L
.53806 .68491 L
.55104 .66026 L
.56164 .64433 L
.56856 .6356 L
.58629 .6157 L
.59114 .61095 L
.61095 .59348 L
.62028 .58629 L
.6356 .57588 L
.66026 .56213 L
.66109 .56164 L
.68491 .55186 L
s
1 g
.66026 .60232 m
.68491 .59258 L
.70957 .58907 L
.73422 .59275 L
.75052 .61095 L
.75379 .6356 L
.74768 .66026 L
.73422 .68474 L
.73411 .68491 L
.7136 .70957 L
.70957 .71349 L
.68491 .73275 L
.68352 .73422 L
.66026 .74601 L
.6356 .75356 L
.61095 .75462 L
.58629 .74437 L
.5807 .73422 L
.57591 .70957 L
.58176 .68491 L
.58629 .67492 L
.59452 .66026 L
.61095 .63906 L
.61473 .6356 L
.6356 .61735 L
.6442 .61095 L
F
0 g
.66026 .60232 m
.68491 .59258 L
.70957 .58907 L
.73422 .59275 L
.75052 .61095 L
.75379 .6356 L
.74768 .66026 L
.73422 .68474 L
.73411 .68491 L
.7136 .70957 L
.70957 .71349 L
.68491 .73275 L
.68352 .73422 L
.66026 .74601 L
.6356 .75356 L
.61095 .75462 L
.58629 .74437 L
.5807 .73422 L
.57591 .70957 L
.58176 .68491 L
.58629 .67492 L
.59452 .66026 L
.61095 .63906 L
.61473 .6356 L
.6356 .61735 L
.6442 .61095 L
.66026 .60232 L
s
.2 g
.98077 .69066 m
.96929 .70957 L
.95611 .72949 L
.95282 .73422 L
.93465 .75888 L
.93146 .76299 L
.91469 .78353 L
.9068 .79269 L
.89282 .80819 L
.88215 .81945 L
.86886 .83284 L
.8575 .84378 L
.84256 .8575 L
.83284 .86603 L
.81357 .88215 L
.80819 .88646 L
.78353 .90523 L
.78136 .9068 L
.75888 .92244 L
.74509 .93146 L
.73422 .93823 L
.70957 .95264 L
.70327 .95611 L
.68491 .96574 L
.66026 .97748 L
.65281 .98077 L
.98077 .98077 L
F
0 g
.98077 .69066 m
.96929 .70957 L
.95611 .72949 L
.95282 .73422 L
.93465 .75888 L
.93146 .76299 L
.91469 .78353 L
.9068 .79269 L
.89282 .80819 L
.88215 .81945 L
.86886 .83284 L
.8575 .84378 L
.84256 .8575 L
.83284 .86603 L
.81357 .88215 L
.80819 .88646 L
.78353 .90523 L
.78136 .9068 L
.75888 .92244 L
.74509 .93146 L
.73422 .93823 L
.70957 .95264 L
.70327 .95611 L
.68491 .96574 L
.66026 .97748 L
.65281 .98077 L
s
.1 g
.98077 .76753 m
.96832 .78353 L
.95611 .79837 L
.94772 .80819 L
.93146 .82641 L
.92549 .83284 L
.9068 .85215 L
.90142 .8575 L
.88215 .8759 L
.87534 .88215 L
.8575 .8979 L
.84699 .9068 L
.83284 .91833 L
.81602 .93146 L
.80819 .93733 L
.78353 .955 L
.78191 .95611 L
.75888 .97141 L
.74382 .98077 L
.98077 .98077 L
F
0 g
.98077 .76753 m
.96832 .78353 L
.95611 .79837 L
.94772 .80819 L
.93146 .82641 L
.92549 .83284 L
.9068 .85215 L
.90142 .8575 L
.88215 .8759 L
.87534 .88215 L
.8575 .8979 L
.84699 .9068 L
.83284 .91833 L
.81602 .93146 L
.80819 .93733 L
.78353 .955 L
.78191 .95611 L
.75888 .97141 L
.74382 .98077 L
s
.98077 .86822 m
.96751 .88215 L
.95611 .89357 L
.94257 .9068 L
.93146 .91731 L
.91601 .93146 L
.9068 .93961 L
.88756 .95611 L
.88215 .96066 L
.8575 .98037 L
.85698 .98077 L
.98077 .98077 L
F
.98077 .86822 m
.96751 .88215 L
.95611 .89357 L
.94257 .9068 L
.93146 .91731 L
.91601 .93146 L
.9068 .93961 L
.88756 .95611 L
.88215 .96066 L
.8575 .98037 L
.85698 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .89903 m
.04389 .89836 L
.06854 .89617 L
.0932 .89258 L
.11785 .88771 L
.14072 .88215 L
.1425 .88166 L
.16716 .87439 L
.19181 .86605 L
.21455 .8575 L
.21647 .85672 L
.24112 .84626 L
.26578 .8349 L
.27006 .83284 L
.29043 .82247 L
.31509 .80916 L
.31684 .80819 L
.33974 .79477 L
.35809 .78353 L
.3644 .7795 L
.38905 .76319 L
.39538 .75888 L
.41371 .74587 L
.4296 .73422 L
.43836 .72756 L
.46134 .70957 L
.46302 .7082 L
.48767 .6877 L
.49093 .68491 L
.51233 .66603 L
.5187 .66026 L
.53698 .64316 L
.54484 .6356 L
.56164 .61898 L
.56953 .61095 L
.58629 .59339 L
.59287 .58629 L
.61095 .56625 L
.61498 .56164 L
.6356 .5374 L
.63594 .53698 L
.65575 .51233 L
.66026 .50655 L
.6745 .48767 L
.68491 .47344 L
.69226 .46302 L
.70909 .43836 L
.70957 .43764 L
.72484 .41371 L
.73422 .39843 L
.73972 .38905 L
.75366 .3644 L
.75888 .35478 L
.76663 .33974 L
.77872 .31509 L
.78353 .30476 L
.78982 .29043 L
.79998 .26578 L
.80819 .244 L
.80919 .24112 L
.81731 .21647 L
.82444 .19181 L
.83049 .16716 L
.83284 .15628 L
.83535 .1425 L
.83897 .11785 L
.84127 .0932 L
.84214 .06854 L
.84141 .04389 L
.83888 .01923 L
.01923 .01923 L
F
0 g
.01923 .89903 m
.04389 .89836 L
.06854 .89617 L
.0932 .89258 L
.11785 .88771 L
.14072 .88215 L
.1425 .88166 L
.16716 .87439 L
.19181 .86605 L
.21455 .8575 L
.21647 .85672 L
.24112 .84626 L
.26578 .8349 L
.27006 .83284 L
.29043 .82247 L
.31509 .80916 L
.31684 .80819 L
.33974 .79477 L
.35809 .78353 L
.3644 .7795 L
.38905 .76319 L
.39538 .75888 L
.41371 .74587 L
.4296 .73422 L
.43836 .72756 L
.46134 .70957 L
.46302 .7082 L
.48767 .6877 L
.49093 .68491 L
.51233 .66603 L
.5187 .66026 L
.53698 .64316 L
.54484 .6356 L
.56164 .61898 L
.56953 .61095 L
.58629 .59339 L
.59287 .58629 L
.61095 .56625 L
.61498 .56164 L
.6356 .5374 L
.63594 .53698 L
.65575 .51233 L
.66026 .50655 L
.6745 .48767 L
.68491 .47344 L
.69226 .46302 L
.70909 .43836 L
.70957 .43764 L
.72484 .41371 L
.73422 .39843 L
Mistroke
.73972 .38905 L
.75366 .3644 L
.75888 .35478 L
.76663 .33974 L
.77872 .31509 L
.78353 .30476 L
.78982 .29043 L
.79998 .26578 L
.80819 .244 L
.80919 .24112 L
.81731 .21647 L
.82444 .19181 L
.83049 .16716 L
.83284 .15628 L
.83535 .1425 L
.83897 .11785 L
.84127 .0932 L
.84214 .06854 L
.84141 .04389 L
.83888 .01923 L
Mfstroke
.2 g
.01923 .79862 m
.04389 .80253 L
.06854 .80401 L
.0932 .80338 L
.11785 .80092 L
.1425 .7968 L
.16716 .79116 L
.19181 .78414 L
.19377 .78353 L
.21647 .77574 L
.24112 .76608 L
.25782 .75888 L
.26578 .75521 L
.29043 .7431 L
.30722 .73422 L
.31509 .72984 L
.33974 .71537 L
.34915 .70957 L
.3644 .69972 L
.3862 .68491 L
.38905 .68289 L
.41371 .66479 L
.41964 .66026 L
.43836 .6454 L
.45025 .6356 L
.46302 .62468 L
.47851 .61095 L
.48767 .60254 L
.50476 .58629 L
.51233 .57885 L
.52923 .56164 L
.53698 .55347 L
.55211 .53698 L
.56164 .52622 L
.57351 .51233 L
.58629 .49682 L
.59356 .48767 L
.61095 .46491 L
.61234 .46302 L
.62986 .43836 L
.6356 .42992 L
.64619 .41371 L
.66026 .39099 L
.6614 .38905 L
.67543 .3644 L
.68491 .34656 L
.68835 .33974 L
.70011 .31509 L
.70957 .29334 L
.71075 .29043 L
.72016 .26578 L
.72838 .24112 L
.73422 .22083 L
.73533 .21647 L
.7409 .19181 L
.74504 .16716 L
.7476 .1425 L
.74842 .11785 L
.74727 .0932 L
.74382 .06854 L
.73763 .04389 L
.73422 .03455 L
.72797 .01923 L
.01923 .01923 L
F
0 g
.01923 .79862 m
.04389 .80253 L
.06854 .80401 L
.0932 .80338 L
.11785 .80092 L
.1425 .7968 L
.16716 .79116 L
.19181 .78414 L
.19377 .78353 L
.21647 .77574 L
.24112 .76608 L
.25782 .75888 L
.26578 .75521 L
.29043 .7431 L
.30722 .73422 L
.31509 .72984 L
.33974 .71537 L
.34915 .70957 L
.3644 .69972 L
.3862 .68491 L
.38905 .68289 L
.41371 .66479 L
.41964 .66026 L
.43836 .6454 L
.45025 .6356 L
.46302 .62468 L
.47851 .61095 L
.48767 .60254 L
.50476 .58629 L
.51233 .57885 L
.52923 .56164 L
.53698 .55347 L
.55211 .53698 L
.56164 .52622 L
.57351 .51233 L
.58629 .49682 L
.59356 .48767 L
.61095 .46491 L
.61234 .46302 L
.62986 .43836 L
.6356 .42992 L
.64619 .41371 L
.66026 .39099 L
.6614 .38905 L
.67543 .3644 L
.68491 .34656 L
.68835 .33974 L
.70011 .31509 L
.70957 .29334 L
.71075 .29043 L
Mistroke
.72016 .26578 L
.72838 .24112 L
.73422 .22083 L
.73533 .21647 L
.7409 .19181 L
.74504 .16716 L
.7476 .1425 L
.74842 .11785 L
.74727 .0932 L
.74382 .06854 L
.73763 .04389 L
.73422 .03455 L
.72797 .01923 L
Mfstroke
.3 g
.01923 .72575 m
.04048 .73422 L
.04389 .73552 L
.06854 .74124 L
.0932 .74382 L
.11785 .74385 L
.1425 .74168 L
.16716 .73758 L
.18257 .73422 L
.19181 .73173 L
.21647 .72426 L
.24112 .71528 L
.25512 .70957 L
.26578 .70486 L
.29043 .69303 L
.30594 .68491 L
.31509 .67984 L
.33974 .66527 L
.34775 .66026 L
.3644 .64932 L
.38407 .6356 L
.38905 .63198 L
.41371 .61317 L
.4165 .61095 L
.43836 .59282 L
.4459 .58629 L
.46302 .57085 L
.47281 .56164 L
.48767 .5471 L
.49761 .53698 L
.51233 .52138 L
.52054 .51233 L
.53698 .49341 L
.54178 .48767 L
.56147 .46302 L
.56164 .46279 L
.57967 .43836 L
.58629 .42891 L
.59648 .41371 L
.61095 .39076 L
.61197 .38905 L
.6261 .3644 L
.6356 .34644 L
.63895 .33974 L
.65045 .31509 L
.66026 .29144 L
.66064 .29043 L
.66941 .26578 L
.67674 .24112 L
.68254 .21647 L
.68491 .20501 L
.68666 .19181 L
.68894 .16716 L
.68915 .1425 L
.68694 .11785 L
.68491 .10482 L
.68179 .0932 L
.67292 .06854 L
.66026 .04589 L
.65886 .04389 L
.63655 .01923 L
.01923 .01923 L
F
0 g
.01923 .72575 m
.04048 .73422 L
.04389 .73552 L
.06854 .74124 L
.0932 .74382 L
.11785 .74385 L
.1425 .74168 L
.16716 .73758 L
.18257 .73422 L
.19181 .73173 L
.21647 .72426 L
.24112 .71528 L
.25512 .70957 L
.26578 .70486 L
.29043 .69303 L
.30594 .68491 L
.31509 .67984 L
.33974 .66527 L
.34775 .66026 L
.3644 .64932 L
.38407 .6356 L
.38905 .63198 L
.41371 .61317 L
.4165 .61095 L
.43836 .59282 L
.4459 .58629 L
.46302 .57085 L
.47281 .56164 L
.48767 .5471 L
.49761 .53698 L
.51233 .52138 L
.52054 .51233 L
.53698 .49341 L
.54178 .48767 L
.56147 .46302 L
.56164 .46279 L
.57967 .43836 L
.58629 .42891 L
.59648 .41371 L
.61095 .39076 L
.61197 .38905 L
.6261 .3644 L
.6356 .34644 L
.63895 .33974 L
.65045 .31509 L
.66026 .29144 L
.66064 .29043 L
.66941 .26578 L
.67674 .24112 L
.68254 .21647 L
Mistroke
.68491 .20501 L
.68666 .19181 L
.68894 .16716 L
.68915 .1425 L
.68694 .11785 L
.68491 .10482 L
.68179 .0932 L
.67292 .06854 L
.66026 .04589 L
.65886 .04389 L
.63655 .01923 L
Mfstroke
.4 g
.01923 .65369 m
.02595 .66026 L
.04389 .6743 L
.06441 .68491 L
.06854 .68649 L
.0932 .69342 L
.11785 .69655 L
.1425 .69669 L
.16716 .69432 L
.19181 .6898 L
.21137 .68491 L
.21647 .68333 L
.24112 .67506 L
.26578 .66513 L
.27665 .66026 L
.29043 .65358 L
.31509 .64046 L
.32357 .6356 L
.33974 .62578 L
.36234 .61095 L
.3644 .60953 L
.38905 .59164 L
.39602 .58629 L
.41371 .57207 L
.42601 .56164 L
.43836 .55068 L
.45309 .53698 L
.46302 .52732 L
.47775 .51233 L
.48767 .50175 L
.5003 .48767 L
.51233 .4736 L
.52097 .46302 L
.53698 .44234 L
.53992 .43836 L
.55724 .41371 L
.56164 .40709 L
.57301 .38905 L
.58629 .36618 L
.58727 .3644 L
.60002 .33974 L
.61095 .31586 L
.61127 .31509 L
.62097 .29043 L
.62906 .26578 L
.63545 .24112 L
.6356 .24062 L
.63997 .21647 L
.64243 .19181 L
.64252 .16716 L
.6398 .1425 L
.6356 .12353 L
.63352 .11785 L
.62243 .0932 L
.61095 .07647 L
.60385 .06854 L
.58629 .05371 L
.56964 .04389 L
.56164 .04035 L
.53698 .03262 L
.51233 .02888 L
.48767 .02825 L
.46302 .03019 L
.43836 .03435 L
.41371 .04049 L
.40234 .04389 L
.38905 .04845 L
.3644 .0581 L
.34141 .06854 L
.33974 .06936 L
.31509 .08221 L
.29602 .0932 L
.29043 .09661 L
.26578 .11259 L
.25814 .11785 L
.24112 .13017 L
.22508 .1425 L
.21647 .14944 L
.19557 .16716 L
.19181 .17049 L
.16887 .19181 L
.16716 .19348 L
.14455 .21647 L
.1425 .21864 L
.12229 .24112 L
.11785 .2463 L
.10189 .26578 L
.0932 .27696 L
.08319 .29043 L
.06854 .31142 L
.0661 .31509 L
.05056 .33974 L
.04389 .35112 L
.03652 .3644 L
.02398 .38905 L
.01923 .39926 L
F
0 g
.01923 .65369 m
.02595 .66026 L
.04389 .6743 L
.06441 .68491 L
.06854 .68649 L
.0932 .69342 L
.11785 .69655 L
.1425 .69669 L
.16716 .69432 L
.19181 .6898 L
.21137 .68491 L
.21647 .68333 L
.24112 .67506 L
.26578 .66513 L
.27665 .66026 L
.29043 .65358 L
.31509 .64046 L
.32357 .6356 L
.33974 .62578 L
.36234 .61095 L
.3644 .60953 L
.38905 .59164 L
.39602 .58629 L
.41371 .57207 L
.42601 .56164 L
.43836 .55068 L
.45309 .53698 L
.46302 .52732 L
.47775 .51233 L
.48767 .50175 L
.5003 .48767 L
.51233 .4736 L
.52097 .46302 L
.53698 .44234 L
.53992 .43836 L
.55724 .41371 L
.56164 .40709 L
.57301 .38905 L
.58629 .36618 L
.58727 .3644 L
.60002 .33974 L
.61095 .31586 L
.61127 .31509 L
.62097 .29043 L
.62906 .26578 L
.63545 .24112 L
.6356 .24062 L
.63997 .21647 L
.64243 .19181 L
.64252 .16716 L
Mistroke
.6398 .1425 L
.6356 .12353 L
.63352 .11785 L
.62243 .0932 L
.61095 .07647 L
.60385 .06854 L
.58629 .05371 L
.56964 .04389 L
.56164 .04035 L
.53698 .03262 L
.51233 .02888 L
.48767 .02825 L
.46302 .03019 L
.43836 .03435 L
.41371 .04049 L
.40234 .04389 L
.38905 .04845 L
.3644 .0581 L
.34141 .06854 L
.33974 .06936 L
.31509 .08221 L
.29602 .0932 L
.29043 .09661 L
.26578 .11259 L
.25814 .11785 L
.24112 .13017 L
.22508 .1425 L
.21647 .14944 L
.19557 .16716 L
.19181 .17049 L
.16887 .19181 L
.16716 .19348 L
.14455 .21647 L
.1425 .21864 L
.12229 .24112 L
.11785 .2463 L
.10189 .26578 L
.0932 .27696 L
.08319 .29043 L
.06854 .31142 L
.0661 .31509 L
.05056 .33974 L
.04389 .35112 L
.03652 .3644 L
.02398 .38905 L
.01923 .39926 L
Mfstroke
.2 g
.01923 .3272 m
.02688 .31509 L
.04352 .29043 L
.04389 .28991 L
.06153 .26578 L
.06854 .25667 L
.08099 .24112 L
.0932 .22656 L
.10198 .21647 L
.11785 .19901 L
.12465 .19181 L
.1425 .17365 L
.14915 .16716 L
.16716 .15024 L
.17573 .1425 L
.19181 .12856 L
.20473 .11785 L
.21647 .1085 L
.23666 .0932 L
.24112 .08995 L
.26578 .07285 L
.27232 .06854 L
.29043 .05716 L
.31317 .04389 L
.31509 .04282 L
.33974 .02984 L
.36226 .01923 L
.01923 .01923 L
F
0 g
.01923 .3272 m
.02688 .31509 L
.04352 .29043 L
.04389 .28991 L
.06153 .26578 L
.06854 .25667 L
.08099 .24112 L
.0932 .22656 L
.10198 .21647 L
.11785 .19901 L
.12465 .19181 L
.1425 .17365 L
.14915 .16716 L
.16716 .15024 L
.17573 .1425 L
.19181 .12856 L
.20473 .11785 L
.21647 .1085 L
.23666 .0932 L
.24112 .08995 L
.26578 .07285 L
.27232 .06854 L
.29043 .05716 L
.31317 .04389 L
.31509 .04282 L
.33974 .02984 L
.36226 .01923 L
s
.1 g
.01923 .25433 m
.02929 .24112 L
.04389 .2229 L
.04919 .21647 L
.06854 .1939 L
.07039 .19181 L
.09303 .16716 L
.0932 .16699 L
.11726 .1425 L
.11785 .14192 L
.1425 .11851 L
.14323 .11785 L
.16716 .09663 L
.17118 .0932 L
.19181 .07616 L
.20142 .06854 L
.21647 .05703 L
.2344 .04389 L
.24112 .03911 L
.26578 .02247 L
.27083 .01923 L
.01923 .01923 L
F
0 g
.01923 .25433 m
.02929 .24112 L
.04389 .2229 L
.04919 .21647 L
.06854 .1939 L
.07039 .19181 L
.09303 .16716 L
.0932 .16699 L
.11726 .1425 L
.11785 .14192 L
.1425 .11851 L
.14323 .11785 L
.16716 .09663 L
.17118 .0932 L
.19181 .07616 L
.20142 .06854 L
.21647 .05703 L
.2344 .04389 L
.24112 .03911 L
.26578 .02247 L
.27083 .01923 L
s
.01923 .15393 m
.02945 .1425 L
.04389 .12707 L
.0527 .11785 L
.06854 .10173 L
.07717 .0932 L
.0932 .0778 L
.1031 .06854 L
.11785 .05516 L
.13062 .04389 L
.1425 .03361 L
.15993 .01923 L
.01923 .01923 L
F
.01923 .15393 m
.02945 .1425 L
.04389 .12707 L
.0527 .11785 L
.06854 .10173 L
.07717 .0932 L
.0932 .0778 L
.1031 .06854 L
.11785 .05516 L
.13062 .04389 L
.1425 .03361 L
.15993 .01923 L
s
.5 g
.3644 .09277 m
.38905 .08373 L
.41371 .07667 L
.43836 .07178 L
.46302 .06932 L
.48767 .06973 L
.51233 .07368 L
.53698 .08239 L
.55521 .0932 L
.56164 .09837 L
.57922 .11785 L
.58629 .12918 L
.59231 .1425 L
.59933 .16716 L
.60218 .19181 L
.60183 .21647 L
.59885 .24112 L
.59359 .26578 L
.58631 .29043 L
.58629 .29049 L
.57714 .31509 L
.5662 .33974 L
.56164 .34906 L
.55353 .3644 L
.53916 .38905 L
.53698 .39256 L
.52305 .41371 L
.51233 .4288 L
.50516 .43836 L
.48767 .46027 L
.48537 .46302 L
.46351 .48767 L
.46302 .4882 L
.43934 .51233 L
.43836 .51327 L
.41371 .5359 L
.41247 .53698 L
.38905 .55636 L
.38228 .56164 L
.3644 .57484 L
.34772 .58629 L
.33974 .59146 L
.31509 .60627 L
.30666 .61095 L
.29043 .6193 L
.26578 .63053 L
.25325 .6356 L
.24112 .63991 L
.21647 .64733 L
.19181 .65263 L
.16716 .65554 L
.1425 .65569 L
.11785 .65243 L
.0932 .6447 L
.07589 .6356 L
.06854 .63031 L
.04928 .61095 L
.04389 .60334 L
.03504 .58629 L
.02726 .56164 L
.02384 .53698 L
.02375 .51233 L
.02636 .48767 L
.03128 .46302 L
.03828 .43836 L
.04389 .42208 L
.04717 .41371 L
.05786 .38905 L
.06854 .3676 L
.07026 .3644 L
.08439 .33974 L
.0932 .32568 L
.10023 .31509 L
.11785 .29043 L
.11785 .29043 L
.13735 .26578 L
.1425 .25965 L
.15889 .24112 L
.16716 .23227 L
.18269 .21647 L
.19181 .20766 L
.20912 .19181 L
.21647 .18543 L
.23876 .16716 L
.24112 .16532 L
.26578 .14718 L
.27256 .1425 L
.29043 .13089 L
.31246 .11785 L
.31509 .1164 L
.33974 .10369 L
.36334 .0932 L
F
0 g
.3644 .09277 m
.38905 .08373 L
.41371 .07667 L
.43836 .07178 L
.46302 .06932 L
.48767 .06973 L
.51233 .07368 L
.53698 .08239 L
.55521 .0932 L
.56164 .09837 L
.57922 .11785 L
.58629 .12918 L
.59231 .1425 L
.59933 .16716 L
.60218 .19181 L
.60183 .21647 L
.59885 .24112 L
.59359 .26578 L
.58631 .29043 L
.58629 .29049 L
.57714 .31509 L
.5662 .33974 L
.56164 .34906 L
.55353 .3644 L
.53916 .38905 L
.53698 .39256 L
.52305 .41371 L
.51233 .4288 L
.50516 .43836 L
.48767 .46027 L
.48537 .46302 L
.46351 .48767 L
.46302 .4882 L
.43934 .51233 L
.43836 .51327 L
.41371 .5359 L
.41247 .53698 L
.38905 .55636 L
.38228 .56164 L
.3644 .57484 L
.34772 .58629 L
.33974 .59146 L
.31509 .60627 L
.30666 .61095 L
.29043 .6193 L
.26578 .63053 L
.25325 .6356 L
.24112 .63991 L
.21647 .64733 L
.19181 .65263 L
Mistroke
.16716 .65554 L
.1425 .65569 L
.11785 .65243 L
.0932 .6447 L
.07589 .6356 L
.06854 .63031 L
.04928 .61095 L
.04389 .60334 L
.03504 .58629 L
.02726 .56164 L
.02384 .53698 L
.02375 .51233 L
.02636 .48767 L
.03128 .46302 L
.03828 .43836 L
.04389 .42208 L
.04717 .41371 L
.05786 .38905 L
.06854 .3676 L
.07026 .3644 L
.08439 .33974 L
.0932 .32568 L
.10023 .31509 L
.11785 .29043 L
.11785 .29043 L
.13735 .26578 L
.1425 .25965 L
.15889 .24112 L
.16716 .23227 L
.18269 .21647 L
.19181 .20766 L
.20912 .19181 L
.21647 .18543 L
.23876 .16716 L
.24112 .16532 L
.26578 .14718 L
.27256 .1425 L
.29043 .13089 L
.31246 .11785 L
.31509 .1164 L
.33974 .10369 L
.36334 .0932 L
.3644 .09277 L
Mfstroke
.6 g
.38905 .11665 m
.41371 .11072 L
.43836 .10745 L
.46302 .10733 L
.48767 .11119 L
.50734 .11785 L
.51233 .12065 L
.53698 .13961 L
.53954 .1425 L
.55477 .16716 L
.56164 .18791 L
.56229 .19181 L
.56498 .21647 L
.56408 .24112 L
.56164 .25871 L
.56028 .26578 L
.55401 .29043 L
.54551 .31509 L
.53698 .3354 L
.53493 .33974 L
.52237 .3644 L
.51233 .38184 L
.50785 .38905 L
.49134 .41371 L
.48767 .4188 L
.47273 .43836 L
.46302 .4502 L
.45187 .46302 L
.43836 .4776 L
.42848 .48767 L
.41371 .50186 L
.40211 .51233 L
.38905 .52344 L
.37201 .53698 L
.3644 .54267 L
.33974 .55972 L
.33678 .56164 L
.31509 .57468 L
.29315 .58629 L
.29043 .5876 L
.26578 .59846 L
.24112 .60715 L
.22881 .61095 L
.21647 .61352 L
.19181 .61729 L
.16716 .61802 L
.1425 .61494 L
.12676 .61095 L
.11785 .60667 L
.0932 .58992 L
.08956 .58629 L
.07272 .56164 L
.06854 .55286 L
.06429 .53698 L
.06097 .51233 L
.06139 .48767 L
.06478 .46302 L
.06854 .44494 L
.07071 .43836 L
.07889 .41371 L
.08916 .38905 L
.0932 .38042 L
.10142 .3644 L
.11565 .33974 L
.11785 .3362 L
.13187 .31509 L
.1425 .30038 L
.15015 .29043 L
.16716 .26979 L
.17066 .26578 L
.19181 .24299 L
.19365 .24112 L
.21647 .21924 L
.21954 .21647 L
.24112 .19809 L
.249 .19181 L
.26578 .17926 L
.28333 .16716 L
.29043 .16259 L
.31509 .14798 L
.32527 .1425 L
.33974 .13543 L
.3644 .12495 L
.38483 .11785 L
F
0 g
.38905 .11665 m
.41371 .11072 L
.43836 .10745 L
.46302 .10733 L
.48767 .11119 L
.50734 .11785 L
.51233 .12065 L
.53698 .13961 L
.53954 .1425 L
.55477 .16716 L
.56164 .18791 L
.56229 .19181 L
.56498 .21647 L
.56408 .24112 L
.56164 .25871 L
.56028 .26578 L
.55401 .29043 L
.54551 .31509 L
.53698 .3354 L
.53493 .33974 L
.52237 .3644 L
.51233 .38184 L
.50785 .38905 L
.49134 .41371 L
.48767 .4188 L
.47273 .43836 L
.46302 .4502 L
.45187 .46302 L
.43836 .4776 L
.42848 .48767 L
.41371 .50186 L
.40211 .51233 L
.38905 .52344 L
.37201 .53698 L
.3644 .54267 L
.33974 .55972 L
.33678 .56164 L
.31509 .57468 L
.29315 .58629 L
.29043 .5876 L
.26578 .59846 L
.24112 .60715 L
.22881 .61095 L
.21647 .61352 L
.19181 .61729 L
.16716 .61802 L
.1425 .61494 L
.12676 .61095 L
.11785 .60667 L
.0932 .58992 L
Mistroke
.08956 .58629 L
.07272 .56164 L
.06854 .55286 L
.06429 .53698 L
.06097 .51233 L
.06139 .48767 L
.06478 .46302 L
.06854 .44494 L
.07071 .43836 L
.07889 .41371 L
.08916 .38905 L
.0932 .38042 L
.10142 .3644 L
.11565 .33974 L
.11785 .3362 L
.13187 .31509 L
.1425 .30038 L
.15015 .29043 L
.16716 .26979 L
.17066 .26578 L
.19181 .24299 L
.19365 .24112 L
.21647 .21924 L
.21954 .21647 L
.24112 .19809 L
.249 .19181 L
.26578 .17926 L
.28333 .16716 L
.29043 .16259 L
.31509 .14798 L
.32527 .1425 L
.33974 .13543 L
.3644 .12495 L
.38483 .11785 L
.38905 .11665 L
Mfstroke
.7 g
.33974 .16629 m
.3644 .15638 L
.38905 .14909 L
.41371 .14472 L
.43836 .14383 L
.46302 .14742 L
.48767 .15766 L
.50047 .16716 L
.51233 .18088 L
.51845 .19181 L
.5265 .21647 L
.52883 .24112 L
.52714 .26578 L
.52225 .29043 L
.51463 .31509 L
.51233 .32145 L
.50455 .33974 L
.49213 .3644 L
.48767 .37233 L
.47742 .38905 L
.46302 .4101 L
.46035 .41371 L
.44079 .43836 L
.43836 .44121 L
.41845 .46302 L
.41371 .46785 L
.39282 .48767 L
.38905 .491 L
.3644 .51123 L
.36297 .51233 L
.33974 .52885 L
.32708 .53698 L
.31509 .54402 L
.29043 .5568 L
.27995 .56164 L
.26578 .56715 L
.24112 .57493 L
.21647 .57985 L
.19181 .58142 L
.16716 .57873 L
.1425 .56992 L
.12958 .56164 L
.11785 .55004 L
.10923 .53698 L
.10009 .51233 L
.09704 .48767 L
.09819 .46302 L
.10264 .43836 L
.10987 .41371 L
.11785 .39287 L
.1196 .38905 L
.13167 .3644 L
.1425 .34541 L
.14604 .33974 L
.16274 .31509 L
.16716 .30909 L
.18191 .29043 L
.19181 .27886 L
.20381 .26578 L
.21647 .25291 L
.2289 .24112 L
.24112 .23031 L
.25803 .21647 L
.26578 .21056 L
.29043 .19339 L
.29286 .19181 L
.31509 .17864 L
.33781 .16716 L
F
0 g
.33974 .16629 m
.3644 .15638 L
.38905 .14909 L
.41371 .14472 L
.43836 .14383 L
.46302 .14742 L
.48767 .15766 L
.50047 .16716 L
.51233 .18088 L
.51845 .19181 L
.5265 .21647 L
.52883 .24112 L
.52714 .26578 L
.52225 .29043 L
.51463 .31509 L
.51233 .32145 L
.50455 .33974 L
.49213 .3644 L
.48767 .37233 L
.47742 .38905 L
.46302 .4101 L
.46035 .41371 L
.44079 .43836 L
.43836 .44121 L
.41845 .46302 L
.41371 .46785 L
.39282 .48767 L
.38905 .491 L
.3644 .51123 L
.36297 .51233 L
.33974 .52885 L
.32708 .53698 L
.31509 .54402 L
.29043 .5568 L
.27995 .56164 L
.26578 .56715 L
.24112 .57493 L
.21647 .57985 L
.19181 .58142 L
.16716 .57873 L
.1425 .56992 L
.12958 .56164 L
.11785 .55004 L
.10923 .53698 L
.10009 .51233 L
.09704 .48767 L
.09819 .46302 L
.10264 .43836 L
.10987 .41371 L
.11785 .39287 L
Mistroke
.1196 .38905 L
.13167 .3644 L
.1425 .34541 L
.14604 .33974 L
.16274 .31509 L
.16716 .30909 L
.18191 .29043 L
.19181 .27886 L
.20381 .26578 L
.21647 .25291 L
.2289 .24112 L
.24112 .23031 L
.25803 .21647 L
.26578 .21056 L
.29043 .19339 L
.29286 .19181 L
.31509 .17864 L
.33781 .16716 L
.33974 .16629 L
Mfstroke
.8 g
.3644 .18883 m
.38905 .18304 L
.41371 .18119 L
.43836 .18456 L
.45768 .19181 L
.46302 .19623 L
.48091 .21647 L
.48767 .23267 L
.4898 .24112 L
.49179 .26578 L
.4891 .29043 L
.48767 .30047 L
.48283 .31509 L
.47346 .33974 L
.46302 .36126 L
.46124 .3644 L
.44626 .38905 L
.43836 .40051 L
.42841 .41371 L
.41371 .43139 L
.40741 .43836 L
.38905 .45705 L
.38269 .46302 L
.3644 .4788 L
.35311 .48767 L
.33974 .49725 L
.31575 .51233 L
.31509 .5127 L
.29043 .52529 L
.26578 .5349 L
.259 .53698 L
.24112 .54129 L
.21647 .54391 L
.19181 .54161 L
.17344 .53698 L
.16716 .53185 L
.14717 .51233 L
.1425 .50623 L
.13679 .48767 L
.13396 .46302 L
.13604 .43836 L
.14184 .41371 L
.1425 .41131 L
.15075 .38905 L
.16256 .3644 L
.16716 .35598 L
.17712 .33974 L
.19181 .31866 L
.19454 .31509 L
.21505 .29043 L
.21647 .28887 L
.23917 .26578 L
.24112 .26395 L
.26578 .24282 L
.26792 .24112 L
.29043 .2249 L
.30362 .21647 L
.31509 .20995 L
.33974 .19789 L
.35441 .19181 L
F
0 g
.3644 .18883 m
.38905 .18304 L
.41371 .18119 L
.43836 .18456 L
.45768 .19181 L
.46302 .19623 L
.48091 .21647 L
.48767 .23267 L
.4898 .24112 L
.49179 .26578 L
.4891 .29043 L
.48767 .30047 L
.48283 .31509 L
.47346 .33974 L
.46302 .36126 L
.46124 .3644 L
.44626 .38905 L
.43836 .40051 L
.42841 .41371 L
.41371 .43139 L
.40741 .43836 L
.38905 .45705 L
.38269 .46302 L
.3644 .4788 L
.35311 .48767 L
.33974 .49725 L
.31575 .51233 L
.31509 .5127 L
.29043 .52529 L
.26578 .5349 L
.259 .53698 L
.24112 .54129 L
.21647 .54391 L
.19181 .54161 L
.17344 .53698 L
.16716 .53185 L
.14717 .51233 L
.1425 .50623 L
.13679 .48767 L
.13396 .46302 L
.13604 .43836 L
.14184 .41371 L
.1425 .41131 L
.15075 .38905 L
.16256 .3644 L
.16716 .35598 L
.17712 .33974 L
.19181 .31866 L
.19454 .31509 L
.21505 .29043 L
Mistroke
.21647 .28887 L
.23917 .26578 L
.24112 .26395 L
.26578 .24282 L
.26792 .24112 L
.29043 .2249 L
.30362 .21647 L
.31509 .20995 L
.33974 .19789 L
.35441 .19181 L
.3644 .18883 L
Mfstroke
.9 g
.33974 .23258 m
.3644 .22497 L
.38905 .22209 L
.41371 .22571 L
.43723 .24112 L
.43836 .24188 L
.44937 .26578 L
.45135 .29043 L
.44752 .31509 L
.43935 .33974 L
.43836 .3423 L
.42753 .3644 L
.41371 .38674 L
.41203 .38905 L
.39278 .41371 L
.38905 .41795 L
.36904 .43836 L
.3644 .4426 L
.33974 .46252 L
.33909 .46302 L
.31509 .47854 L
.29789 .48767 L
.29043 .49072 L
.26578 .4991 L
.24112 .50292 L
.21647 .50066 L
.19218 .48767 L
.19181 .4872 L
.17737 .46302 L
.17433 .43836 L
.1774 .41371 L
.18496 .38905 L
.19181 .37234 L
.19628 .3644 L
.21121 .33974 L
.21647 .33217 L
.22984 .31509 L
.24112 .30232 L
.25281 .29043 L
.26578 .27862 L
.2816 .26578 L
.29043 .25945 L
.31509 .24415 L
.32002 .24112 L
F
0 g
.33974 .23258 m
.3644 .22497 L
.38905 .22209 L
.41371 .22571 L
.43723 .24112 L
.43836 .24188 L
.44937 .26578 L
.45135 .29043 L
.44752 .31509 L
.43935 .33974 L
.43836 .3423 L
.42753 .3644 L
.41371 .38674 L
.41203 .38905 L
.39278 .41371 L
.38905 .41795 L
.36904 .43836 L
.3644 .4426 L
.33974 .46252 L
.33909 .46302 L
.31509 .47854 L
.29789 .48767 L
.29043 .49072 L
.26578 .4991 L
.24112 .50292 L
.21647 .50066 L
.19218 .48767 L
.19181 .4872 L
.17737 .46302 L
.17433 .43836 L
.1774 .41371 L
.18496 .38905 L
.19181 .37234 L
.19628 .3644 L
.21121 .33974 L
.21647 .33217 L
.22984 .31509 L
.24112 .30232 L
.25281 .29043 L
.26578 .27862 L
.2816 .26578 L
.29043 .25945 L
.31509 .24415 L
.32002 .24112 L
.33974 .23258 L
s
1 g
.31509 .28686 m
.33974 .27633 L
.3644 .27273 L
.38905 .28073 L
.39616 .29043 L
.40138 .31509 L
.39647 .33974 L
.38905 .35724 L
.38554 .3644 L
.36872 .38905 L
.3644 .39438 L
.34551 .41371 L
.33974 .41857 L
.31509 .43591 L
.31032 .43836 L
.29043 .44729 L
.26578 .45227 L
.24112 .44679 L
.23111 .43836 L
.22422 .41371 L
.22804 .38905 L
.23844 .3644 L
.24112 .35894 L
.25399 .33974 L
.26578 .32543 L
.27592 .31509 L
.29043 .30282 L
.308 .29043 L
F
0 g
.31509 .28686 m
.33974 .27633 L
.3644 .27273 L
.38905 .28073 L
.39616 .29043 L
.40138 .31509 L
.39647 .33974 L
.38905 .35724 L
.38554 .3644 L
.36872 .38905 L
.3644 .39438 L
.34551 .41371 L
.33974 .41857 L
.31509 .43591 L
.31032 .43836 L
.29043 .44729 L
.26578 .45227 L
.24112 .44679 L
.23111 .43836 L
.22422 .41371 L
.22804 .38905 L
.23844 .3644 L
.24112 .35894 L
.25399 .33974 L
.26578 .32543 L
.27592 .31509 L
.29043 .30282 L
.308 .29043 L
.31509 .28686 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.625 .731 .924 r
.39716 .60002 .405 .60731 .41811 .60459 .41031 .59731 Mtetra
.612 .729 .928 r
.41031 .59731 .41811 .60459 .43129 .60218 .42352 .59493 Mtetra
.597 .726 .934 r
.42352 .59493 .43129 .60218 .44454 .60011 .43681 .59294 Mtetra
.579 .722 .941 r
.43681 .59294 .44454 .60011 .45786 .59844 .45016 .59138 Mtetra
.556 .719 .949 r
.45016 .59138 .45786 .59844 .47126 .5972 .4636 .59032 Mtetra
.528 .714 .958 r
.4636 .59032 .47126 .5972 .48474 .59641 .47711 .58978 Mtetra
.493 .709 .966 r
.47711 .58978 .48474 .59641 .49831 .59608 .49072 .58978 Mtetra
.451 .703 .975 r
.49072 .58978 .49831 .59608 .51198 .59619 .50442 .59033 Mtetra
.401 .695 .98 r
.50442 .59033 .51198 .59619 .52575 .59669 .51823 .59138 Mtetra
.34 .684 .979 r
.51823 .59138 .52575 .59669 .53963 .59751 .53215 .59286 Mtetra
.27 .668 .969 r
.53215 .59286 .53963 .59751 .55362 .59854 .54619 .59467 Mtetra
.191 .647 .942 r
.54619 .59467 .55362 .59854 .56772 .59965 .56036 .59666 Mtetra
.107 .617 .894 r
.56036 .59666 .56772 .59965 .58194 .60067 .57465 .59867 Mtetra
.026 .58 .823 r
.57465 .59867 .58194 .60067 .59626 .60144 .58905 .60049 Mtetra
0 .539 .734 r
.58905 .60049 .59626 .60144 .61069 .60175 .60358 .6019 Mtetra
.092 0 0 r
.60358 .6019 .61069 .60175 .62522 .60142 .61821 .60268 Mtetra
.118 0 0 r
.61821 .60268 .62522 .60142 .63982 .6003 .63293 .60262 Mtetra
.123 0 0 r
.63293 .60262 .63982 .6003 .65449 .59823 .64773 .60153 Mtetra
.109 0 0 r
.64773 .60153 .65449 .59823 .66922 .59512 .66259 .59925 Mtetra
.08 0 0 r
.66259 .59925 .66922 .59512 .68398 .5909 .67749 .5957 Mtetra
.038 0 0 r
.67749 .5957 .68398 .5909 .69876 .58557 .69241 .59083 Mtetra
0 0 0 r
.69241 .59083 .69876 .58557 .71355 .57917 .70733 .58467 Mtetra
.70733 .58467 .71355 .57917 .72835 .57181 .72225 .57729 Mtetra
.72225 .57729 .72835 .57181 .74314 .56361 .73715 .56883 Mtetra
.73715 .56883 .74314 .56361 .75793 .55474 .75204 .55948 Mtetra
.75204 .55948 .75793 .55474 .77273 .54537 .76692 .54943 Mtetra
.413 .809 .583 r
.76692 .54943 .77273 .54537 .78754 .53571 .78179 .53891 Mtetra
.506 .877 .666 r
.78179 .53891 .78754 .53571 .80238 .52592 .79667 .52815 Mtetra
.59 .933 .749 r
.79667 .52815 .80238 .52592 .81725 .51617 .81157 .51733 Mtetra
.659 .97 .821 r
.81157 .51733 .81725 .51617 .83217 .5066 .82651 .50666 Mtetra
.709 .985 .877 r
.82651 .50666 .83217 .5066 .84716 .49733 .8415 .49628 Mtetra
.738 .98 .915 r
.8415 .49628 .84716 .49733 .86222 .48844 .85657 .4863 Mtetra
.751 .961 .937 r
.85657 .4863 .86222 .48844 .87738 .47997 .87172 .4768 Mtetra
.752 .935 .946 r
.87172 .4768 .87738 .47997 .89263 .47196 .88696 .46784 Mtetra
.745 .906 .948 r
.88696 .46784 .89263 .47196 .90799 .4644 .90231 .45941 Mtetra
.736 .877 .946 r
.90231 .45941 .90799 .4644 .92346 .45726 .91778 .45151 Mtetra
.725 .851 .941 r
.91778 .45151 .92346 .45726 .93904 .45053 .93337 .44411 Mtetra
.714 .828 .936 r
.93337 .44411 .93904 .45053 .95474 .44414 .94908 .43716 Mtetra
.704 .809 .931 r
.94908 .43716 .95474 .44414 .97055 .43807 .96491 .4306 Mtetra
.624 .729 .922 r
.38925 .59261 .39716 .60002 .41031 .59731 .40243 .58988 Mtetra
.612 .726 .927 r
.40243 .58988 .41031 .59731 .42352 .59493 .41569 .5875 Mtetra
.596 .722 .932 r
.41569 .5875 .42352 .59493 .43681 .59294 .429 .58554 Mtetra
.576 .717 .939 r
.429 .58554 .43681 .59294 .45016 .59138 .44239 .58406 Mtetra
.552 .711 .946 r
.44239 .58406 .45016 .59138 .4636 .59032 .45586 .58313 Mtetra
.521 .705 .954 r
.45586 .58313 .4636 .59032 .47711 .58978 .46941 .58279 Mtetra
.484 .696 .962 r
.46941 .58279 .47711 .58978 .49072 .58978 .48305 .58308 Mtetra
.438 .686 .969 r
.48305 .58308 .49072 .58978 .50442 .59033 .49679 .58402 Mtetra
.383 .673 .973 r
.49679 .58402 .50442 .59033 .51823 .59138 .51063 .58557 Mtetra
.316 .656 .971 r
.51063 .58557 .51823 .59138 .53215 .59286 .52459 .58768 Mtetra
.237 .634 .959 r
.52459 .58768 .53215 .59286 .54619 .59467 .53868 .59025 Mtetra
.148 .604 .929 r
.53868 .59025 .54619 .59467 .56036 .59666 .5529 .59314 Mtetra
.054 .567 .878 r
.5529 .59314 .56036 .59666 .57465 .59867 .56726 .59617 Mtetra
0 .521 .801 r
.56726 .59617 .57465 .59867 .58905 .60049 .58174 .59911 Mtetra
0 .473 .705 r
.58174 .59911 .58905 .60049 .60358 .6019 .59636 .60171 Mtetra
.172 0 0 r
.59636 .60171 .60358 .6019 .61821 .60268 .61109 .60373 Mtetra
.203 0 0 r
.61109 .60373 .61821 .60268 .63293 .60262 .62594 .60489 Mtetra
.21 0 0 r
.62594 .60489 .63293 .60262 .64773 .60153 .64087 .60497 Mtetra
.196 0 0 r
.64087 .60497 .64773 .60153 .66259 .59925 .65586 .60375 Mtetra
.167 0 0 r
.65586 .60375 .66259 .59925 .67749 .5957 .67091 .6011 Mtetra
.125 0 0 r
.67091 .6011 .67749 .5957 .69241 .59083 .68598 .59691 Mtetra
.074 0 0 r
.68598 .59691 .69241 .59083 .70733 .58467 .70105 .59119 Mtetra
.013 0 0 r
.70105 .59119 .70733 .58467 .72225 .57729 .7161 .58399 Mtetra
0 0 0 r
.7161 .58399 .72225 .57729 .73715 .56883 .73114 .57544 Mtetra
.73114 .57544 .73715 .56883 .75204 .55948 .74614 .56573 Mtetra
.74614 .56573 .75204 .55948 .76692 .54943 .76111 .55508 Mtetra
.76111 .55508 .76692 .54943 .78179 .53891 .77606 .54375 Mtetra
.77606 .54375 .78179 .53891 .79667 .52815 .791 .53199 Mtetra
.504 .861 .617 r
.791 .53199 .79667 .52815 .81157 .51733 .80594 .52007 Mtetra
.593 .925 .709 r
.80594 .52007 .81157 .51733 .82651 .50666 .8209 .5082 Mtetra
.667 .969 .791 r
.8209 .5082 .82651 .50666 .8415 .49628 .8359 .4966 Mtetra
.719 .988 .857 r
.8359 .4966 .8415 .49628 .85657 .4863 .85096 .48541 Mtetra
.749 .986 .902 r
.85096 .48541 .85657 .4863 .87172 .4768 .8661 .47474 Mtetra
.761 .967 .929 r
.8661 .47474 .87172 .4768 .88696 .46784 .88133 .46468 Mtetra
.761 .94 .941 r
.88133 .46468 .88696 .46784 .90231 .45941 .89667 .45524 Mtetra
.753 .909 .945 r
.89667 .45524 .90231 .45941 .91778 .45151 .91213 .44644 Mtetra
.741 .879 .944 r
.91213 .44644 .91778 .45151 .93337 .44411 .92771 .43825 Mtetra
.729 .852 .94 r
.92771 .43825 .93337 .44411 .94908 .43716 .94342 .43061 Mtetra
.716 .829 .935 r
.94342 .43061 .94908 .43716 .96491 .4306 .95925 .42347 Mtetra
.625 .728 .921 r
.38127 .58506 .38925 .59261 .40243 .58988 .39449 .5823 Mtetra
.612 .724 .925 r
.39449 .5823 .40243 .58988 .41569 .5875 .40778 .57989 Mtetra
.596 .719 .93 r
.40778 .57989 .41569 .5875 .429 .58554 .42113 .57793 Mtetra
.575 .713 .936 r
.42113 .57793 .429 .58554 .44239 .58406 .43456 .57648 Mtetra
.55 .705 .942 r
.43456 .57648 .44239 .58406 .45586 .58313 .44806 .57562 Mtetra
.518 .696 .95 r
.44806 .57562 .45586 .58313 .46941 .58279 .46164 .57542 Mtetra
.479 .684 .957 r
.46164 .57542 .46941 .58279 .48305 .58308 .47531 .57594 Mtetra
.431 .67 .963 r
.47531 .57594 .48305 .58308 .49679 .58402 .48908 .57719 Mtetra
.372 .653 .966 r
.48908 .57719 .49679 .58402 .51063 .58557 .50296 .57918 Mtetra
.301 .631 .963 r
.50296 .57918 .51063 .58557 .52459 .58768 .51696 .58185 Mtetra
.218 .603 .95 r
.51696 .58185 .52459 .58768 .53868 .59025 .53109 .58514 Mtetra
.123 .567 .921 r
.53109 .58514 .53868 .59025 .5529 .59314 .54535 .58889 Mtetra
.022 .525 .871 r
.54535 .58889 .5529 .59314 .56726 .59617 .55976 .59292 Mtetra
0 .475 .797 r
.55976 .59292 .56726 .59617 .58174 .59911 .57432 .597 Mtetra
0 .423 .702 r
.57432 .597 .58174 .59911 .59636 .60171 .58902 .60086 Mtetra
.228 0 0 r
.58902 .60086 .59636 .60171 .61109 .60373 .60386 .6042 Mtetra
.265 0 0 r
.60386 .6042 .61109 .60373 .62594 .60489 .61881 .60673 Mtetra
.275 0 0 r
.61881 .60673 .62594 .60489 .64087 .60497 .63388 .60815 Mtetra
.263 0 0 r
.63388 .60815 .64087 .60497 .65586 .60375 .64902 .60819 Mtetra
.233 0 0 r
.64902 .60819 .65586 .60375 .67091 .6011 .66421 .60666 Mtetra
.191 0 0 r
.66421 .60666 .67091 .6011 .68598 .59691 .67944 .60341 Mtetra
.139 0 0 r
.67944 .60341 .68598 .59691 .70105 .59119 .69467 .59838 Mtetra
.079 0 0 r
.69467 .59838 .70105 .59119 .7161 .58399 .70989 .59159 Mtetra
.012 0 0 r
.70989 .59159 .7161 .58399 .73114 .57544 .72507 .58316 Mtetra
0 0 0 r
.72507 .58316 .73114 .57544 .74614 .56573 .7402 .57326 Mtetra
.7402 .57326 .74614 .56573 .76111 .55508 .75529 .56214 Mtetra
.75529 .56214 .76111 .55508 .77606 .54375 .77033 .55009 Mtetra
.77033 .55009 .77606 .54375 .791 .53199 .78534 .53739 Mtetra
.78534 .53739 .791 .53199 .80594 .52007 .80033 .52435 Mtetra
.52 .858 .587 r
.80033 .52435 .80594 .52007 .8209 .5082 .81532 .51125 Mtetra
.609 .924 .684 r
.81532 .51125 .8209 .5082 .8359 .4966 .83033 .49834 Mtetra
.683 .97 .773 r
.83033 .49834 .8359 .4966 .85096 .48541 .8454 .48583 Mtetra
.734 .991 .843 r
.8454 .48583 .85096 .48541 .8661 .47474 .86052 .47388 Mtetra
.763 .989 .892 r
.86052 .47388 .8661 .47474 .88133 .46468 .87574 .46257 Mtetra
.773 .97 .922 r
.87574 .46257 .88133 .46468 .89667 .45524 .89106 .45199 Mtetra
.769 .942 .937 r
.89106 .45199 .89667 .45524 .91213 .44644 .9065 .44215 Mtetra
.759 .91 .942 r
.9065 .44215 .91213 .44644 .92771 .43825 .92206 .43302 Mtetra
.746 .879 .941 r
.92206 .43302 .92771 .43825 .94342 .43061 .93776 .42458 Mtetra
.731 .852 .938 r
.93776 .42458 .94342 .43061 .95925 .42347 .9536 .41674 Mtetra
.626 .727 .919 r
.37322 .5774 .38127 .58506 .39449 .5823 .38648 .57457 Mtetra
.613 .722 .923 r
.38648 .57457 .39449 .5823 .40778 .57989 .39981 .5721 Mtetra
.597 .716 .928 r
.39981 .5721 .40778 .57989 .42113 .57793 .4132 .57009 Mtetra
.577 .709 .933 r
.4132 .57009 .42113 .57793 .43456 .57648 .42666 .56863 Mtetra
.551 .7 .939 r
.42666 .56863 .43456 .57648 .44806 .57562 .44019 .56779 Mtetra
.518 .689 .945 r
.44019 .56779 .44806 .57562 .46164 .57542 .4538 .56766 Mtetra
.478 .675 .951 r
.4538 .56766 .46164 .57542 .47531 .57594 .4675 .56831 Mtetra
.429 .657 .955 r
.4675 .56831 .47531 .57594 .48908 .57719 .4813 .5698 Mtetra
.369 .636 .957 r
.4813 .5698 .48908 .57719 .50296 .57918 .49521 .57212 Mtetra
.297 .609 .954 r
.49521 .57212 .50296 .57918 .51696 .58185 .50924 .57528 Mtetra
.213 .577 .942 r
.50924 .57528 .51696 .58185 .53109 .58514 .5234 .57918 Mtetra
.117 .538 .916 r
.5234 .57918 .53109 .58514 .54535 .58889 .53771 .58371 Mtetra
.013 .492 .872 r
.53771 .58371 .54535 .58889 .55976 .59292 .55217 .58869 Mtetra
0 .442 .806 r
.55217 .58869 .55976 .59292 .57432 .597 .56679 .59388 Mtetra
0 .39 .72 r
.56679 .59388 .57432 .597 .58902 .60086 .58157 .599 Mtetra
.257 0 0 r
.58157 .599 .58902 .60086 .60386 .6042 .59649 .60372 Mtetra
.303 0 0 r
.59649 .60372 .60386 .6042 .61881 .60673 .61156 .6077 Mtetra
.319 0 0 r
.61156 .6077 .61881 .60673 .63388 .60815 .62675 .6106 Mtetra
.311 0 0 r
.62675 .6106 .63388 .60815 .64902 .60819 .64203 .61209 Mtetra
.282 0 0 r
.64203 .61209 .64902 .60819 .66421 .60666 .65738 .6119 Mtetra
.239 0 0 r
.65738 .6119 .66421 .60666 .67944 .60341 .67278 .60983 Mtetra
.185 0 0 r
.67278 .60983 .67944 .60341 .69467 .59838 .68818 .60575 Mtetra
.124 0 0 r
.68818 .60575 .69467 .59838 .70989 .59159 .70356 .59964 Mtetra
.057 0 0 r
.70356 .59964 .70989 .59159 .72507 .58316 .71891 .59158 Mtetra
0 0 0 r
.71891 .59158 .72507 .58316 .7402 .57326 .7342 .58173 Mtetra
.7342 .58173 .7402 .57326 .75529 .56214 .74942 .57033 Mtetra
.74942 .57033 .75529 .56214 .77033 .55009 .76457 .5577 Mtetra
.76457 .5577 .77033 .55009 .78534 .53739 .77967 .54416 Mtetra
.77967 .54416 .78534 .53739 .80033 .52435 .79473 .53006 Mtetra
.79473 .53006 .80033 .52435 .81532 .51125 .80977 .51573 Mtetra
.551 .867 .578 r
.80977 .51573 .81532 .51125 .83033 .49834 .8248 .50149 Mtetra
.638 .932 .676 r
.8248 .50149 .83033 .49834 .8454 .48583 .83987 .48759 Mtetra
.707 .976 .766 r
.83987 .48759 .8454 .48583 .86052 .47388 .85499 .47424 Mtetra
.754 .995 .837 r
.85499 .47424 .86052 .47388 .87574 .46257 .87019 .46158 Mtetra
.778 .991 .887 r
.87019 .46158 .87574 .46257 .89106 .45199 .88549 .44972 Mtetra
.783 .97 .918 r
.88549 .44972 .89106 .45199 .9065 .44215 .9009 .4387 Mtetra
.777 .94 .933 r
.9009 .4387 .9065 .44215 .92206 .43302 .91644 .42851 Mtetra
.764 .908 .939 r
.91644 .42851 .92206 .43302 .93776 .42458 .93213 .41912 Mtetra
.749 .877 .938 r
.93213 .41912 .93776 .42458 .9536 .41674 .94795 .41048 Mtetra
.628 .726 .918 r
.3651 .56962 .37322 .5774 .38648 .57457 .3784 .5667 Mtetra
.616 .721 .921 r
.3784 .5667 .38648 .57457 .39981 .5721 .39176 .56415 Mtetra
.6 .715 .925 r
.39176 .56415 .39981 .5721 .4132 .57009 .40519 .56206 Mtetra
.579 .706 .929 r
.40519 .56206 .4132 .57009 .42666 .56863 .41869 .56052 Mtetra
.554 .696 .934 r
.41869 .56052 .42666 .56863 .44019 .56779 .43225 .55963 Mtetra
.522 .683 .94 r
.43225 .55963 .44019 .56779 .4538 .56766 .4459 .5595 Mtetra
.482 .667 .944 r
.4459 .5595 .4538 .56766 .4675 .56831 .45963 .5602 Mtetra
.433 .647 .948 r
.45963 .5602 .4675 .56831 .4813 .5698 .47345 .56181 Mtetra
.374 .622 .949 r
.47345 .56181 .4813 .5698 .49521 .57212 .48739 .56437 Mtetra
.303 .593 .945 r
.48739 .56437 .49521 .57212 .50924 .57528 .50145 .56787 Mtetra
.22 .557 .934 r
.50145 .56787 .50924 .57528 .5234 .57918 .51564 .57227 Mtetra
.127 .516 .913 r
.51564 .57227 .5234 .57918 .53771 .58371 .52998 .57747 Mtetra
.025 .47 .877 r
.52998 .57747 .53771 .58371 .55217 .58869 .54449 .58329 Mtetra
0 .42 .823 r
.54449 .58329 .55217 .58869 .56679 .59388 .55916 .58951 Mtetra
0 .37 .752 r
.55916 .58951 .56679 .59388 .58157 .599 .574 .59583 Mtetra
0 .325 .665 r
.574 .59583 .58157 .599 .59649 .60372 .589 .60191 Mtetra
.313 0 0 r
.589 .60191 .59649 .60372 .61156 .6077 .60416 .60737 Mtetra
.341 0 0 r
.60416 .60737 .61156 .6077 .62675 .6106 .61947 .61183 Mtetra
.34 0 0 r
.61947 .61183 .62675 .6106 .64203 .61209 .63489 .61491 Mtetra
.315 0 0 r
.63489 .61491 .64203 .61209 .65738 .6119 .65039 .61625 Mtetra
.272 0 0 r
.65039 .61625 .65738 .6119 .67278 .60983 .66595 .61558 Mtetra
.216 0 0 r
.66595 .61558 .67278 .60983 .68818 .60575 .68154 .61272 Mtetra
.151 0 0 r
.68154 .61272 .68818 .60575 .70356 .59964 .6971 .60757 Mtetra
.081 0 0 r
.6971 .60757 .70356 .59964 .71891 .59158 .71263 .60016 Mtetra
.007 0 0 r
.71263 .60016 .71891 .59158 .7342 .58173 .72808 .59063 Mtetra
0 0 0 r
.72808 .59063 .7342 .58173 .74942 .57033 .74346 .57921 Mtetra
.74346 .57921 .74942 .57033 .76457 .5577 .75875 .56621 Mtetra
.75875 .56621 .76457 .5577 .77967 .54416 .77397 .552 Mtetra
.77397 .552 .77967 .54416 .79473 .53006 .78911 .53695 Mtetra
.78911 .53695 .79473 .53006 .80977 .51573 .80421 .52147 Mtetra
.80421 .52147 .80977 .51573 .8248 .50149 .81929 .50591 Mtetra
.597 .888 .588 r
.81929 .50591 .8248 .50149 .83987 .48759 .83437 .4906 Mtetra
.676 .947 .684 r
.83437 .4906 .83987 .48759 .85499 .47424 .84949 .4758 Mtetra
.737 .984 .77 r
.84949 .4758 .85499 .47424 .87019 .46158 .86467 .4617 Mtetra
.775 .998 .838 r
.86467 .4617 .87019 .46158 .88549 .44972 .87995 .44846 Mtetra
.793 .99 .886 r
.87995 .44846 .88549 .44972 .9009 .4387 .89533 .43613 Mtetra
.793 .967 .915 r
.89533 .43613 .9009 .4387 .91644 .42851 .91085 .42476 Mtetra
.783 .936 .93 r
.91085 .42476 .91644 .42851 .93213 .41912 .92651 .41431 Mtetra
.767 .903 .936 r
.92651 .41431 .93213 .41912 .94795 .41048 .94231 .40474 Mtetra
.63 .726 .916 r
.3569 .56173 .3651 .56962 .3784 .5667 .37025 .55871 Mtetra
.618 .721 .919 r
.37025 .55871 .3784 .5667 .39176 .56415 .38365 .55604 Mtetra
.603 .714 .922 r
.38365 .55604 .39176 .56415 .40519 .56206 .39712 .55383 Mtetra
.583 .705 .926 r
.39712 .55383 .40519 .56206 .41869 .56052 .41065 .55217 Mtetra
.559 .694 .93 r
.41065 .55217 .41869 .56052 .43225 .55963 .42425 .55118 Mtetra
.527 .679 .934 r
.42425 .55118 .43225 .55963 .4459 .5595 .43793 .55096 Mtetra
.489 .661 .938 r
.43793 .55096 .4459 .5595 .45963 .5602 .45169 .55162 Mtetra
.441 .64 .941 r
.45169 .55162 .45963 .5602 .47345 .56181 .46554 .55325 Mtetra
.384 .613 .941 r
.46554 .55325 .47345 .56181 .48739 .56437 .4795 .55591 Mtetra
.316 .581 .937 r
.4795 .55591 .48739 .56437 .50145 .56787 .49359 .55962 Mtetra
.238 .544 .927 r
.49359 .55962 .50145 .56787 .51564 .57227 .50781 .56436 Mtetra
.15 .501 .909 r
.50781 .56436 .51564 .57227 .52998 .57747 .52217 .57007 Mtetra
.054 .455 .881 r
.52217 .57007 .52998 .57747 .54449 .58329 .53671 .57658 Mtetra
0 .408 .84 r
.53671 .57658 .54449 .58329 .55916 .58951 .55142 .58368 Mtetra
0 .361 .787 r
.55142 .58368 .55916 .58951 .574 .59583 .56631 .59108 Mtetra
0 .32 .721 r
.56631 .59108 .574 .59583 .589 .60191 .58138 .59844 Mtetra
0 .288 .645 r
.58138 .59844 .589 .60191 .60416 .60737 .59663 .60535 Mtetra
.332 0 0 r
.59663 .60535 .60416 .60737 .61947 .61183 .61203 .61139 Mtetra
.344 0 0 r
.61203 .61139 .61947 .61183 .63489 .61491 .62758 .61611 Mtetra
.328 0 0 r
.62758 .61611 .63489 .61491 .65039 .61625 .64323 .61912 Mtetra
.288 0 0 r
.64323 .61912 .65039 .61625 .66595 .61558 .65895 .62005 Mtetra
.23 0 0 r
.65895 .62005 .66595 .61558 .68154 .61272 .67471 .61864 Mtetra
.161 0 0 r
.67471 .61864 .68154 .61272 .6971 .60757 .69047 .61473 Mtetra
.085 0 0 r
.69047 .61473 .6971 .60757 .71263 .60016 .70618 .60828 Mtetra
.007 0 0 r
.70618 .60828 .71263 .60016 .72808 .59063 .72183 .59938 Mtetra
0 0 0 r
.72183 .59938 .72808 .59063 .74346 .57921 .73738 .58822 Mtetra
.73738 .58822 .74346 .57921 .75875 .56621 .75283 .57513 Mtetra
.75283 .57513 .75875 .56621 .77397 .552 .76818 .56047 Mtetra
.76818 .56047 .77397 .552 .78911 .53695 .78344 .54467 Mtetra
.78344 .54467 .78911 .53695 .80421 .52147 .79862 .52817 Mtetra
.79862 .52817 .80421 .52147 .81929 .50591 .81375 .51138 Mtetra
.573 .854 .522 r
.81375 .51138 .81929 .50591 .83437 .4906 .82887 .49469 Mtetra
.652 .916 .613 r
.82887 .49469 .83437 .4906 .84949 .4758 .844 .47843 Mtetra
.72 .964 .703 r
.844 .47843 .84949 .4758 .86467 .4617 .85917 .46286 Mtetra
.769 .993 .782 r
.85917 .46286 .86467 .4617 .87995 .44846 .87443 .44816 Mtetra
.797 .999 .845 r
.87443 .44816 .87995 .44846 .89533 .43613 .88979 .43445 Mtetra
.806 .986 .888 r
.88979 .43445 .89533 .43613 .91085 .42476 .90527 .42178 Mtetra
.801 .96 .915 r
.90527 .42178 .91085 .42476 .92651 .41431 .9209 .41016 Mtetra
.787 .929 .928 r
.9209 .41016 .92651 .41431 .94231 .40474 .93668 .39955 Mtetra
.633 .726 .915 r
.34864 .55375 .3569 .56173 .37025 .55871 .36202 .5506 Mtetra
.622 .721 .917 r
.36202 .5506 .37025 .55871 .38365 .55604 .37547 .5478 Mtetra
.607 .714 .92 r
.37547 .5478 .38365 .55604 .39712 .55383 .38897 .54543 Mtetra
.589 .704 .923 r
.38897 .54543 .39712 .55383 .41065 .55217 .40254 .54361 Mtetra
.565 .692 .926 r
.40254 .54361 .41065 .55217 .42425 .55118 .41618 .54246 Mtetra
.535 .677 .929 r
.41618 .54246 .42425 .55118 .43793 .55096 .42989 .54208 Mtetra
.499 .659 .932 r
.42989 .54208 .43793 .55096 .45169 .55162 .44369 .5426 Mtetra
.453 .635 .933 r
.44369 .5426 .45169 .55162 .46554 .55325 .45757 .54413 Mtetra
.399 .607 .933 r
.45757 .54413 .46554 .55325 .4795 .55591 .47156 .54675 Mtetra
.336 .574 .928 r
.47156 .54675 .4795 .55591 .49359 .55962 .48566 .55052 Mtetra
.263 .536 .919 r
.48566 .55052 .49359 .55962 .50781 .56436 .4999 .55544 Mtetra
.181 .493 .904 r
.4999 .55544 .50781 .56436 .52217 .57007 .51429 .56146 Mtetra
.094 .448 .882 r
.51429 .56146 .52217 .57007 .53671 .57658 .52885 .56846 Mtetra
.004 .403 .852 r
.52885 .56846 .53671 .57658 .55142 .58368 .54358 .57626 Mtetra
0 .36 .815 r
.54358 .57626 .55142 .58368 .56631 .59108 .55851 .58457 Mtetra
0 .324 .771 r
.55851 .58457 .56631 .59108 .58138 .59844 .57363 .59305 Mtetra
0 .298 .721 r
.57363 .59305 .58138 .59844 .59663 .60535 .58895 .6013 Mtetra
0 .284 .664 r
.58895 .6013 .59663 .60535 .61203 .61139 .60444 .60884 Mtetra
.31 0 0 r
.60444 .60884 .61203 .61139 .62758 .61611 .62009 .61522 Mtetra
.307 0 0 r
.62009 .61522 .62758 .61611 .64323 .61912 .63588 .61995 Mtetra
.276 0 0 r
.63588 .61995 .64323 .61912 .65895 .62005 .65176 .6226 Mtetra
.22 0 0 r
.65176 .6226 .65895 .62005 .67471 .61864 .66769 .62284 Mtetra
.146 0 0 r
.66769 .62284 .67471 .61864 .69047 .61473 .68363 .62042 Mtetra
.064 0 0 r
.68363 .62042 .69047 .61473 .70618 .60828 .69954 .61522 Mtetra
0 0 0 r
.69954 .61522 .70618 .60828 .72183 .59938 .71538 .60726 Mtetra
.71538 .60726 .72183 .59938 .73738 .58822 .73113 .5967 Mtetra
.73113 .5967 .73738 .58822 .75283 .57513 .74676 .58383 Mtetra
.74676 .58383 .75283 .57513 .76818 .56047 .76227 .56902 Mtetra
.76227 .56902 .76818 .56047 .78344 .54467 .77766 .55272 Mtetra
.77766 .55272 .78344 .54467 .79862 .52817 .79295 .53541 Mtetra
.79295 .53541 .79862 .52817 .81375 .51138 .80816 .51755 Mtetra
.573 .839 .487 r
.80816 .51755 .81375 .51138 .82887 .49469 .82333 .4996 Mtetra
.646 .897 .566 r
.82333 .4996 .82887 .49469 .844 .47843 .83849 .48194 Mtetra
.712 .946 .65 r
.83849 .48194 .844 .47843 .85917 .46286 .85367 .46489 Mtetra
.765 .982 .73 r
.85367 .46489 .85917 .46286 .87443 .44816 .86891 .44871 Mtetra
.8 .999 .8 r
.86891 .44871 .87443 .44816 .88979 .43445 .88425 .43356 Mtetra
.817 .996 .855 r
.88425 .43356 .88979 .43445 .90527 .42178 .89971 .41954 Mtetra
.817 .978 .892 r
.89971 .41954 .90527 .42178 .9209 .41016 .91531 .40666 Mtetra
.805 .95 .915 r
.91531 .40666 .9209 .41016 .93668 .39955 .93106 .39491 Mtetra
.636 .727 .914 r
.34029 .54569 .34864 .55375 .36202 .5506 .35372 .5424 Mtetra
.626 .721 .915 r
.35372 .5424 .36202 .5506 .37547 .5478 .36721 .53944 Mtetra
.612 .714 .918 r
.36721 .53944 .37547 .5478 .38897 .54543 .38076 .5369 Mtetra
.595 .705 .92 r
.38076 .5369 .38897 .54543 .40254 .54361 .39437 .53488 Mtetra
.573 .693 .923 r
.39437 .53488 .40254 .54361 .41618 .54246 .40805 .5335 Mtetra
.545 .677 .925 r
.40805 .5335 .41618 .54246 .42989 .54208 .4218 .5329 Mtetra
.51 .658 .927 r
.4218 .5329 .42989 .54208 .44369 .5426 .43562 .5332 Mtetra
.468 .634 .927 r
.43562 .5332 .44369 .5426 .45757 .54413 .44953 .53452 Mtetra
.418 .606 .925 r
.44953 .53452 .45757 .54413 .47156 .54675 .46355 .53697 Mtetra
.359 .572 .92 r
.46355 .53697 .47156 .54675 .48566 .55052 .47767 .54063 Mtetra
.292 .534 .912 r
.47767 .54063 .48566 .55052 .4999 .55544 .49193 .54554 Mtetra
.219 .491 .898 r
.49193 .54554 .4999 .55544 .51429 .56146 .50634 .55167 Mtetra
.14 .447 .88 r
.50634 .55167 .51429 .56146 .52885 .56846 .52091 .55895 Mtetra
.061 .404 .858 r
.52091 .55895 .52885 .56846 .54358 .57626 .53567 .5672 Mtetra
0 .364 .832 r
.53567 .5672 .54358 .57626 .55851 .58457 .55062 .57619 Mtetra
0 .332 .805 r
.55062 .57619 .55851 .58457 .57363 .59305 .56577 .58558 Mtetra
0 .31 .777 r
.56577 .58558 .57363 .59305 .58895 .6013 .58114 .59496 Mtetra
0 .303 .748 r
.58114 .59496 .58895 .6013 .60444 .60884 .5967 .60387 Mtetra
0 .311 .718 r
.5967 .60387 .60444 .60884 .62009 .61522 .61244 .6118 Mtetra
0 .337 .685 r
.61244 .6118 .62009 .61522 .63588 .61995 .62833 .61823 Mtetra
.219 0 0 r
.62833 .61823 .63588 .61995 .65176 .6226 .64435 .62266 Mtetra
.169 0 0 r
.64435 .62266 .65176 .6226 .66769 .62284 .66044 .62467 Mtetra
.094 0 0 r
.66044 .62467 .66769 .62284 .68363 .62042 .67656 .62393 Mtetra
.006 0 0 r
.67656 .62393 .68363 .62042 .69954 .61522 .69267 .62023 Mtetra
0 0 0 r
.69267 .62023 .69954 .61522 .71538 .60726 .70871 .61353 Mtetra
.70871 .61353 .71538 .60726 .73113 .5967 .72466 .6039 Mtetra
.72466 .6039 .73113 .5967 .74676 .58383 .74049 .5916 Mtetra
.74049 .5916 .74676 .58383 .76227 .56902 .75618 .57699 Mtetra
.75618 .57699 .76227 .56902 .77766 .55272 .77173 .5605 Mtetra
.77173 .5605 .77766 .55272 .79295 .53541 .78715 .54265 Mtetra
.78715 .54265 .79295 .53541 .80816 .51755 .80247 .52396 Mtetra
.6 .849 .487 r
.80247 .52396 .80816 .51755 .82333 .4996 .81771 .50492 Mtetra
.663 .895 .549 r
.81771 .50492 .82333 .4996 .83849 .48194 .83292 .48599 Mtetra
.721 .938 .619 r
.83292 .48599 .83849 .48194 .85367 .46489 .84813 .46756 Mtetra
.77 .973 .692 r
.84813 .46756 .85367 .46489 .86891 .44871 .86338 .44994 Mtetra
.806 .994 .761 r
.86338 .44994 .86891 .44871 .88425 .43356 .8787 .43336 Mtetra
.827 1 .82 r
.8787 .43336 .88425 .43356 .89971 .41954 .89414 .41794 Mtetra
.831 .989 .866 r
.89414 .41794 .89971 .41954 .91531 .40666 .90971 .40375 Mtetra
.823 .967 .897 r
.90971 .40375 .91531 .40666 .93106 .39491 .92543 .3908 Mtetra
.639 .728 .912 r
.33188 .53755 .34029 .54569 .35372 .5424 .34535 .53412 Mtetra
.63 .723 .914 r
.34535 .53412 .35372 .5424 .36721 .53944 .35888 .53099 Mtetra
.618 .715 .916 r
.35888 .53099 .36721 .53944 .38076 .5369 .37247 .52825 Mtetra
.602 .706 .917 r
.37247 .52825 .38076 .5369 .39437 .53488 .38613 .526 Mtetra
.581 .694 .919 r
.38613 .526 .39437 .53488 .40805 .5335 .39984 .52436 Mtetra
.556 .679 .921 r
.39984 .52436 .40805 .5335 .4218 .5329 .41363 .52348 Mtetra
.524 .66 .922 r
.41363 .52348 .4218 .5329 .43562 .5332 .42749 .52347 Mtetra
.485 .636 .921 r
.42749 .52347 .43562 .5332 .44953 .53452 .44144 .52448 Mtetra
.439 .608 .919 r
.44144 .52448 .44953 .53452 .46355 .53697 .45548 .52664 Mtetra
.385 .574 .914 r
.45548 .52664 .46355 .53697 .47767 .54063 .46963 .53004 Mtetra
.324 .536 .905 r
.46963 .53004 .47767 .54063 .49193 .54554 .4839 .53475 Mtetra
.258 .494 .892 r
.4839 .53475 .49193 .54554 .50634 .55167 .49832 .54078 Mtetra
.189 .451 .876 r
.49832 .54078 .50634 .55167 .52091 .55895 .5129 .54809 Mtetra
.119 .409 .858 r
.5129 .54809 .52091 .55895 .53567 .5672 .52767 .55655 Mtetra
.053 .372 .839 r
.52767 .55655 .53567 .5672 .55062 .57619 .54264 .56594 Mtetra
0 .342 .821 r
.54264 .56594 .55062 .57619 .56577 .58558 .55781 .57596 Mtetra
0 .322 .807 r
.55781 .57596 .56577 .58558 .58114 .59496 .5732 .58623 Mtetra
0 .318 .797 r
.5732 .58623 .58114 .59496 .5967 .60387 .58881 .59628 Mtetra
0 .33 .793 r
.58881 .59628 .5967 .60387 .61244 .6118 .60462 .60558 Mtetra
0 .364 .794 r
.60462 .60558 .61244 .6118 .62833 .61823 .6206 .61358 Mtetra
0 .42 .796 r
.6206 .61358 .62833 .61823 .64435 .62266 .63673 .61974 Mtetra
0 .495 .792 r
.63673 .61974 .64435 .62266 .66044 .62467 .65296 .62355 Mtetra
.01 .581 .77 r
.65296 .62355 .66044 .62467 .67656 .62393 .66925 .62461 Mtetra
.105 .659 .725 r
.66925 .62461 .67656 .62393 .69267 .62023 .68554 .62262 Mtetra
0 0 0 r
.68554 .62262 .69267 .62023 .70871 .61353 .70179 .61743 Mtetra
.70179 .61743 .70871 .61353 .72466 .6039 .71795 .60906 Mtetra
.71795 .60906 .72466 .6039 .74049 .5916 .73398 .59768 Mtetra
.73398 .59768 .74049 .5916 .75618 .57699 .74987 .58363 Mtetra
.74987 .58363 .75618 .57699 .77173 .5605 .7656 .56732 Mtetra
.555 .83 .481 r
.7656 .56732 .77173 .5605 .78715 .54265 .78118 .54927 Mtetra
.606 .854 .495 r
.78118 .54927 .78715 .54265 .80247 .52396 .79663 .53004 Mtetra
.655 .881 .523 r
.79663 .53004 .80247 .52396 .81771 .50492 .81198 .51018 Mtetra
.703 .912 .564 r
.81198 .51018 .81771 .50492 .83292 .48599 .82726 .49019 Mtetra
.748 .943 .615 r
.82726 .49019 .83292 .48599 .84813 .46756 .84251 .47053 Mtetra
.788 .971 .674 r
.84251 .47053 .84813 .46756 .86338 .44994 .85778 .45158 Mtetra
.819 .99 .735 r
.85778 .45158 .86338 .44994 .8787 .43336 .87312 .43361 Mtetra
.839 .999 .792 r
.87312 .43361 .8787 .43336 .89414 .41794 .88854 .41682 Mtetra
.846 .994 .84 r
.88854 .41682 .89414 .41794 .90971 .40375 .90409 .40132 Mtetra
.84 .978 .876 r
.90409 .40132 .90971 .40375 .92543 .3908 .91979 .38714 Mtetra
.642 .729 .911 r
.32338 .52934 .33188 .53755 .34535 .53412 .3369 .52577 Mtetra
.634 .724 .912 r
.3369 .52577 .34535 .53412 .35888 .53099 .35047 .52246 Mtetra
.623 .717 .914 r
.35047 .52246 .35888 .53099 .37247 .52825 .36411 .51951 Mtetra
.609 .708 .915 r
.36411 .51951 .37247 .52825 .38613 .526 .37781 .51701 Mtetra
.59 .697 .916 r
.37781 .51701 .38613 .526 .39984 .52436 .39157 .51509 Mtetra
.567 .682 .917 r
.39157 .51509 .39984 .52436 .41363 .52348 .4054 .51387 Mtetra
.538 .663 .918 r
.4054 .51387 .41363 .52348 .42749 .52347 .4193 .5135 Mtetra
.503 .64 .917 r
.4193 .5135 .42749 .52347 .44144 .52448 .43328 .51412 Mtetra
.46 .612 .913 r
.43328 .51412 .44144 .52448 .45548 .52664 .44735 .51586 Mtetra
.412 .579 .908 r
.44735 .51586 .45548 .52664 .46963 .53004 .46152 .51886 Mtetra
.357 .542 .899 r
.46152 .51886 .46963 .53004 .4839 .53475 .47581 .5232 Mtetra
.298 .501 .887 r
.47581 .5232 .4839 .53475 .49832 .54078 .49025 .52893 Mtetra
.236 .459 .872 r
.49025 .52893 .49832 .54078 .5129 .54809 .50484 .53603 Mtetra
.175 .419 .856 r
.50484 .53603 .5129 .54809 .52767 .55655 .51961 .54441 Mtetra
.119 .382 .839 r
.51961 .54441 .52767 .55655 .54264 .56594 .53458 .55391 Mtetra
.069 .353 .825 r
.53458 .55391 .54264 .56594 .55781 .57596 .54976 .56426 Mtetra
.028 .334 .816 r
.54976 .56426 .55781 .57596 .5732 .58623 .56517 .57511 Mtetra
0 .329 .814 r
.56517 .57511 .5732 .58623 .58881 .59628 .5808 .58599 Mtetra
0 .34 .82 r
.5808 .58599 .58881 .59628 .60462 .60558 .59664 .5964 Mtetra
0 .371 .836 r
.59664 .5964 .60462 .60558 .6206 .61358 .61269 .60577 Mtetra
.012 .427 .862 r
.61269 .60577 .6206 .61358 .63673 .61974 .62891 .6135 Mtetra
.062 .508 .895 r
.62891 .6135 .63673 .61974 .65296 .62355 .64526 .61905 Mtetra
.14 .612 .923 r
.64526 .61905 .65296 .62355 .66925 .62461 .66169 .62193 Mtetra
.243 .725 .932 r
.66169 .62193 .66925 .62461 .68554 .62262 .67815 .62175 Mtetra
.355 .823 .904 r
.67815 .62175 .68554 .62262 .70179 .61743 .69459 .61828 Mtetra
.456 .886 .843 r
.69459 .61828 .70179 .61743 .71795 .60906 .71095 .61143 Mtetra
.535 .914 .766 r
.71095 .61143 .71795 .60906 .73398 .59768 .72719 .60131 Mtetra
.592 .921 .694 r
.72719 .60131 .73398 .59768 .74987 .58363 .74329 .58818 Mtetra
.635 .919 .639 r
.74329 .58818 .74987 .58363 .7656 .56732 .75922 .57244 Mtetra
.671 .918 .604 r
.75922 .57244 .7656 .56732 .78118 .54927 .77498 .55458 Mtetra
.702 .921 .588 r
.77498 .55458 .78118 .54927 .79663 .53004 .79059 .53517 Mtetra
.732 .93 .59 r
.79059 .53517 .79663 .53004 .81198 .51018 .80607 .5148 Mtetra
.762 .943 .607 r
.80607 .5148 .81198 .51018 .82726 .49019 .82145 .49403 Mtetra
.792 .959 .637 r
.82145 .49403 .82726 .49019 .84251 .47053 .83678 .47337 Mtetra
.819 .976 .678 r
.83678 .47337 .84251 .47053 .85778 .45158 .8521 .45326 Mtetra
.841 .989 .725 r
.8521 .45326 .85778 .45158 .87312 .43361 .86745 .43404 Mtetra
.856 .997 .773 r
.86745 .43404 .87312 .43361 .88854 .41682 .88288 .41597 Mtetra
.861 .994 .818 r
.88288 .41597 .88854 .41682 .90409 .40132 .89843 .3992 Mtetra
.856 .982 .856 r
.89843 .3992 .90409 .40132 .91979 .38714 .91411 .3838 Mtetra
.646 .73 .91 r
.3148 .52108 .32338 .52934 .3369 .52577 .32836 .51736 Mtetra
.638 .726 .911 r
.32836 .51736 .3369 .52577 .35047 .52246 .34199 .51388 Mtetra
.629 .719 .912 r
.34199 .51388 .35047 .52246 .36411 .51951 .35567 .51071 Mtetra
.616 .711 .913 r
.35567 .51071 .36411 .51951 .37781 .51701 .36942 .50795 Mtetra
.599 .7 .914 r
.36942 .50795 .37781 .51701 .39157 .51509 .38322 .50571 Mtetra
.578 .686 .914 r
.38322 .50571 .39157 .51509 .4054 .51387 .39709 .50413 Mtetra
.552 .668 .914 r
.39709 .50413 .4054 .51387 .4193 .5135 .41104 .50335 Mtetra
.521 .646 .913 r
.41104 .50335 .4193 .5135 .43328 .51412 .42505 .50351 Mtetra
.483 .619 .909 r
.42505 .50351 .43328 .51412 .44735 .51586 .43916 .50476 Mtetra
.439 .588 .903 r
.43916 .50476 .44735 .51586 .46152 .51886 .45336 .50723 Mtetra
.389 .551 .894 r
.45336 .50723 .46152 .51886 .47581 .5232 .46767 .51105 Mtetra
.336 .512 .883 r
.46767 .51105 .47581 .5232 .49025 .52893 .48212 .51627 Mtetra
.282 .471 .868 r
.48212 .51627 .49025 .52893 .50484 .53603 .49672 .52294 Mtetra
.228 .432 .852 r
.49672 .52294 .50484 .53603 .51961 .54441 .51149 .53099 Mtetra
.179 .396 .837 r
.51149 .53099 .51961 .54441 .53458 .55391 .52646 .5403 Mtetra
.137 .366 .824 r
.52646 .5403 .53458 .55391 .54976 .56426 .54163 .55065 Mtetra
.104 .346 .815 r
.54163 .55065 .54976 .56426 .56517 .57511 .55704 .56173 Mtetra
.083 .338 .813 r
.55704 .56173 .56517 .57511 .5808 .58599 .57267 .57311 Mtetra
.076 .345 .819 r
.57267 .57311 .5808 .58599 .59664 .5964 .58854 .5843 Mtetra
.086 .369 .834 r
.58854 .5843 .59664 .5964 .61269 .60577 .60462 .59472 Mtetra
.114 .413 .861 r
.60462 .59472 .61269 .60577 .62891 .6135 .6209 .6038 Mtetra
.164 .479 .897 r
.6209 .6038 .62891 .6135 .64526 .61905 .63734 .61091 Mtetra
.239 .57 .939 r
.63734 .61091 .64526 .61905 .66169 .62193 .65388 .61552 Mtetra
.337 .679 .978 r
.65388 .61552 .66169 .62193 .67815 .62175 .67049 .61717 Mtetra
.452 .794 .998 r
.67049 .61717 .67815 .62175 .69459 .61828 .68709 .61551 Mtetra
.564 .894 .985 r
.68709 .61551 .69459 .61828 .71095 .61143 .70365 .61039 Mtetra
.657 .959 .937 r
.70365 .61039 .71095 .61143 .72719 .60131 .7201 .60181 Mtetra
.721 .988 .869 r
.7201 .60181 .72719 .60131 .74329 .58818 .7364 .58994 Mtetra
.761 .993 .799 r
.7364 .58994 .74329 .58818 .75922 .57244 .75254 .57514 Mtetra
.786 .988 .74 r
.75254 .57514 .75922 .57244 .77498 .55458 .76851 .55787 Mtetra
.803 .98 .699 r
.76851 .55787 .77498 .55458 .79059 .53517 .7843 .53868 Mtetra
.817 .975 .676 r
.7843 .53868 .79059 .53517 .80607 .5148 .79993 .51818 Mtetra
.83 .974 .67 r
.79993 .51818 .80607 .5148 .82145 .49403 .81545 .49697 Mtetra
.844 .978 .678 r
.81545 .49697 .82145 .49403 .83678 .47337 .83088 .4756 Mtetra
.858 .984 .699 r
.83088 .4756 .83678 .47337 .8521 .45326 .84627 .45458 Mtetra
.869 .99 .73 r
.84627 .45458 .8521 .45326 .86745 .43404 .86168 .43431 Mtetra
.877 .993 .767 r
.86168 .43431 .86745 .43404 .88288 .41597 .87714 .41509 Mtetra
.878 .991 .804 r
.87714 .41509 .88288 .41597 .89843 .3992 .89269 .39716 Mtetra
.872 .982 .84 r
.89269 .39716 .89843 .3992 .91411 .3838 .90838 .38061 Mtetra
.648 .732 .91 r
.30614 .51276 .3148 .52108 .32836 .51736 .31975 .5089 Mtetra
.642 .727 .91 r
.31975 .5089 .32836 .51736 .34199 .51388 .33342 .50524 Mtetra
.634 .722 .911 r
.33342 .50524 .34199 .51388 .35567 .51071 .34715 .50186 Mtetra
.623 .714 .912 r
.34715 .50186 .35567 .51071 .36942 .50795 .36094 .49884 Mtetra
.608 .704 .912 r
.36094 .49884 .36942 .50795 .38322 .50571 .3748 .49629 Mtetra
.59 .691 .912 r
.3748 .49629 .38322 .50571 .39709 .50413 .38872 .49433 Mtetra
.567 .674 .911 r
.38872 .49433 .39709 .50413 .41104 .50335 .4027 .4931 Mtetra
.538 .653 .91 r
.4027 .4931 .41104 .50335 .42505 .50351 .41676 .49275 Mtetra
.504 .628 .906 r
.41676 .49275 .42505 .50351 .43916 .50476 .4309 .49344 Mtetra
.465 .598 .9 r
.4309 .49344 .43916 .50476 .45336 .50723 .44514 .49529 Mtetra
.421 .563 .891 r
.44514 .49529 .45336 .50723 .46767 .51105 .45948 .49846 Mtetra
.373 .526 .88 r
.45948 .49846 .46767 .51105 .48212 .51627 .47394 .50302 Mtetra
.325 .486 .866 r
.47394 .50302 .48212 .51627 .49672 .52294 .48855 .50905 Mtetra
.277 .447 .85 r
.48855 .50905 .49672 .52294 .51149 .53099 .50332 .51652 Mtetra
.233 .412 .834 r
.50332 .51652 .51149 .53099 .52646 .5403 .51828 .52536 Mtetra
.197 .382 .82 r
.51828 .52536 .52646 .5403 .54163 .55065 .53344 .53539 Mtetra
.169 .36 .81 r
.53344 .53539 .54163 .55065 .55704 .56173 .54884 .54635 Mtetra
.153 .349 .805 r
.54884 .54635 .55704 .56173 .57267 .57311 .56446 .55785 Mtetra
.149 .35 .807 r
.56446 .55785 .57267 .57311 .58854 .5843 .58033 .56944 Mtetra
.16 .365 .817 r
.58033 .56944 .58854 .5843 .60462 .59472 .59642 .58058 Mtetra
.188 .397 .836 r
.59642 .58058 .60462 .59472 .6209 .6038 .61273 .59066 Mtetra
.233 .445 .862 r
.61273 .59066 .6209 .6038 .63734 .61091 .62922 .59908 Mtetra
.297 .512 .895 r
.62922 .59908 .63734 .61091 .65388 .61552 .64585 .60523 Mtetra
.38 .596 .931 r
.64585 .60523 .65388 .61552 .67049 .61717 .66257 .6086 Mtetra
.478 .693 .962 r
.66257 .6086 .67049 .61717 .68709 .61551 .67932 .60876 Mtetra
.583 .791 .978 r
.67932 .60876 .68709 .61551 .70365 .61039 .69604 .60546 Mtetra
.682 .877 .971 r
.69604 .60546 .70365 .61039 .7201 .60181 .71268 .59861 Mtetra
.763 .94 .941 r
.71268 .59861 .7201 .60181 .7364 .58994 .7292 .58829 Mtetra
.819 .976 .893 r
.7292 .58829 .7364 .58994 .75254 .57514 .74555 .57477 Mtetra
.853 .992 .841 r
.74555 .57477 .75254 .57514 .76851 .55787 .76172 .55847 Mtetra
.872 .994 .794 r
.76172 .55847 .76851 .55787 .7843 .53868 .77771 .53991 Mtetra
.882 .992 .758 r
.77771 .53991 .7843 .53868 .79993 .51818 .79353 .51969 Mtetra
.888 .988 .736 r
.79353 .51969 .79993 .51818 .81545 .49697 .8092 .49842 Mtetra
.892 .986 .727 r
.8092 .49842 .81545 .49697 .83088 .4756 .82476 .4767 Mtetra
.895 .986 .732 r
.82476 .4767 .83088 .4756 .84627 .45458 .84026 .45507 Mtetra
.898 .987 .747 r
.84026 .45507 .84627 .45458 .86168 .43431 .85575 .43401 Mtetra
.898 .987 .77 r
.85575 .43401 .86168 .43431 .87714 .41509 .87126 .41387 Mtetra
.895 .984 .799 r
.87126 .41387 .87714 .41509 .89269 .39716 .88685 .39492 Mtetra
.886 .976 .828 r
.88685 .39492 .89269 .39716 .90838 .38061 .90255 .37735 Mtetra
.651 .733 .909 r
.2974 .50439 .30614 .51276 .31975 .5089 .31105 .5004 Mtetra
.646 .729 .91 r
.31105 .5004 .31975 .5089 .33342 .50524 .32477 .49657 Mtetra
.639 .724 .91 r
.32477 .49657 .33342 .50524 .34715 .50186 .33855 .49298 Mtetra
.629 .717 .91 r
.33855 .49298 .34715 .50186 .36094 .49884 .35239 .4897 Mtetra
.617 .708 .911 r
.35239 .4897 .36094 .49884 .3748 .49629 .3663 .48683 Mtetra
.6 .696 .91 r
.3663 .48683 .3748 .49629 .38872 .49433 .38027 .4845 Mtetra
.58 .681 .909 r
.38027 .4845 .38872 .49433 .4027 .4931 .3943 .48281 Mtetra
.555 .662 .907 r
.3943 .48281 .4027 .4931 .41676 .49275 .4084 .48193 Mtetra
.526 .638 .904 r
.4084 .48193 .41676 .49275 .4309 .49344 .42259 .48201 Mtetra
.491 .61 .898 r
.42259 .48201 .4309 .49344 .44514 .49529 .43686 .48318 Mtetra
.451 .577 .889 r
.43686 .48318 .44514 .49529 .45948 .49846 .45122 .4856 Mtetra
.409 .541 .878 r
.45122 .4856 .45948 .49846 .47394 .50302 .46571 .48938 Mtetra
.365 .503 .864 r
.46571 .48938 .47394 .50302 .48855 .50905 .48033 .4946 Mtetra
.322 .465 .849 r
.48033 .4946 .48855 .50905 .50332 .51652 .4951 .50129 Mtetra
.282 .43 .833 r
.4951 .50129 .50332 .51652 .51828 .52536 .51005 .5094 Mtetra
.249 .399 .818 r
.51005 .5094 .51828 .52536 .53344 .53539 .5252 .51881 Mtetra
.225 .376 .806 r
.5252 .51881 .53344 .53539 .54884 .54635 .54057 .52931 Mtetra
.21 .361 .798 r
.54057 .52931 .54884 .54635 .56446 .55785 .55618 .54057 Mtetra
.208 .358 .795 r
.55618 .54057 .56446 .55785 .58033 .56944 .57202 .55218 Mtetra
.217 .365 .799 r
.57202 .55218 .58033 .56944 .59642 .58058 .58811 .56362 Mtetra
.241 .386 .809 r
.58811 .56362 .59642 .58058 .61273 .59066 .60442 .57434 Mtetra
.279 .42 .826 r
.60442 .57434 .61273 .59066 .62922 .59908 .62093 .58371 Mtetra
.331 .468 .847 r
.62093 .58371 .62922 .59908 .64585 .60523 .63761 .59112 Mtetra
.397 .529 .872 r
.63761 .59112 .64585 .60523 .66257 .6086 .65441 .596 Mtetra
.476 .601 .897 r
.65441 .596 .66257 .6086 .67932 .60876 .67127 .59787 Mtetra
.563 .679 .917 r
.67127 .59787 .67932 .60876 .69604 .60546 .68814 .59639 Mtetra
.652 .758 .927 r
.68814 .59639 .69604 .60546 .71268 .59861 .70495 .59136 Mtetra
.734 .83 .924 r
.70495 .59136 .71268 .59861 .7292 .58829 .72166 .58278 Mtetra
.802 .887 .906 r
.72166 .58278 .7292 .58829 .74555 .57477 .73822 .57083 Mtetra
.853 .927 .877 r
.73822 .57083 .74555 .57477 .76172 .55847 .75461 .55584 Mtetra
.886 .951 .844 r
.75461 .55584 .76172 .55847 .77771 .53991 .77081 .53829 Mtetra
.906 .964 .812 r
.77081 .53829 .77771 .53991 .79353 .51969 .78682 .51875 Mtetra
.916 .971 .787 r
.78682 .51875 .79353 .51969 .8092 .49842 .80267 .49783 Mtetra
.92 .973 .77 r
.80267 .49783 .8092 .49842 .82476 .4767 .8184 .47614 Mtetra
.921 .974 .764 r
.8184 .47614 .82476 .4767 .84026 .45507 .83403 .45427 Mtetra
.919 .975 .768 r
.83403 .45427 .84026 .45507 .85575 .43401 .84962 .43273 Mtetra
.915 .974 .78 r
.84962 .43273 .85575 .43401 .87126 .41387 .86521 .41193 Mtetra
.909 .971 .799 r
.86521 .41193 .87126 .41387 .88685 .39492 .88086 .3922 Mtetra
.898 .965 .822 r
.88086 .3922 .88685 .39492 .90255 .37735 .8966 .37376 Mtetra
.653 .734 .909 r
.28857 .49598 .2974 .50439 .31105 .5004 .30227 .49185 Mtetra
.649 .731 .909 r
.30227 .49185 .31105 .5004 .32477 .49657 .31604 .48787 Mtetra
.643 .727 .909 r
.31604 .48787 .32477 .49657 .33855 .49298 .32987 .48408 Mtetra
.635 .721 .909 r
.32987 .48408 .33855 .49298 .35239 .4897 .34376 .48056 Mtetra
.624 .713 .909 r
.34376 .48056 .35239 .4897 .3663 .48683 .35771 .47739 Mtetra
.611 .702 .909 r
.35771 .47739 .3663 .48683 .38027 .4845 .37173 .47467 Mtetra
.593 .688 .908 r
.37173 .47467 .38027 .4845 .3943 .48281 .38582 .47254 Mtetra
.572 .671 .906 r
.38582 .47254 .3943 .48281 .4084 .48193 .39997 .47113 Mtetra
.545 .649 .902 r
.39997 .47113 .4084 .48193 .42259 .48201 .4142 .47057 Mtetra
.515 .623 .897 r
.4142 .47057 .42259 .48201 .43686 .48318 .42851 .47103 Mtetra
.48 .593 .889 r
.42851 .47103 .43686 .48318 .45122 .4856 .44291 .47265 Mtetra
.442 .559 .878 r
.44291 .47265 .45122 .4856 .46571 .48938 .45742 .47555 Mtetra
.402 .522 .865 r
.45742 .47555 .46571 .48938 .48033 .4946 .47206 .47984 Mtetra
.363 .486 .849 r
.47206 .47984 .48033 .4946 .4951 .50129 .48684 .48557 Mtetra
.327 .45 .833 r
.48684 .48557 .4951 .50129 .51005 .5094 .50179 .49275 Mtetra
.296 .419 .817 r
.50179 .49275 .51005 .5094 .5252 .51881 .51692 .50129 Mtetra
.273 .394 .803 r
.51692 .50129 .5252 .51881 .54057 .52931 .53227 .51102 Mtetra
.259 .376 .793 r
.53227 .51102 .54057 .52931 .55618 .54057 .54784 .52169 Mtetra
.255 .368 .786 r
.54784 .52169 .55618 .54057 .57202 .55218 .56365 .53293 Mtetra
.263 .37 .785 r
.56365 .53293 .57202 .55218 .58811 .56362 .57971 .54429 Mtetra
.281 .382 .788 r
.57971 .54429 .58811 .56362 .60442 .57434 .596 .55523 Mtetra
.312 .405 .797 r
.596 .55523 .60442 .57434 .62093 .58371 .61251 .56516 Mtetra
.354 .439 .81 r
.61251 .56516 .62093 .58371 .63761 .59112 .62921 .57347 Mtetra
.407 .483 .826 r
.62921 .57347 .63761 .59112 .65441 .596 .64605 .57958 Mtetra
.469 .536 .843 r
.64605 .57958 .65441 .596 .67127 .59787 .66299 .58294 Mtetra
.539 .596 .859 r
.66299 .58294 .67127 .59787 .68814 .59639 .67997 .58315 Mtetra
.613 .66 .872 r
.67997 .58315 .68814 .59639 .70495 .59136 .69692 .57992 Mtetra
.687 .724 .878 r
.69692 .57992 .70495 .59136 .72166 .58278 .7138 .57317 Mtetra
.754 .783 .876 r
.7138 .57317 .72166 .58278 .73822 .57083 .73055 .56296 Mtetra
.812 .833 .867 r
.73055 .56296 .73822 .57083 .75461 .55584 .74714 .54956 Mtetra
.857 .873 .85 r
.74714 .54956 .75461 .55584 .77081 .53829 .76356 .53336 Mtetra
.889 .902 .831 r
.76356 .53336 .77081 .53829 .78682 .51875 .77978 .51488 Mtetra
.91 .922 .812 r
.77978 .51488 .78682 .51875 .80267 .49783 .79583 .49471 Mtetra
.922 .935 .797 r
.79583 .49471 .80267 .49783 .8184 .47614 .81174 .47346 Mtetra
.927 .944 .788 r
.81174 .47346 .8184 .47614 .83403 .45427 .82753 .45172 Mtetra
.927 .949 .786 r
.82753 .45172 .83403 .45427 .84962 .43273 .84326 .43005 Mtetra
.923 .951 .791 r
.84326 .43005 .84962 .43273 .86521 .41193 .85896 .4089 Mtetra
.916 .951 .803 r
.85896 .4089 .86521 .41193 .88086 .3922 .8747 .38865 Mtetra
.906 .948 .819 r
.8747 .38865 .88086 .3922 .8966 .37376 .89051 .36957 Mtetra
.655 .735 .908 r
.27966 .48751 .28857 .49598 .30227 .49185 .29341 .48327 Mtetra
.652 .733 .909 r
.29341 .48327 .30227 .49185 .31604 .48787 .30722 .47914 Mtetra
.647 .729 .909 r
.30722 .47914 .31604 .48787 .32987 .48408 .3211 .47517 Mtetra
.64 .724 .909 r
.3211 .47517 .32987 .48408 .34376 .48056 .33504 .47141 Mtetra
.631 .717 .909 r
.33504 .47141 .34376 .48056 .35771 .47739 .34905 .46796 Mtetra
.62 .707 .908 r
.34905 .46796 .35771 .47739 .37173 .47467 .36312 .46489 Mtetra
.605 .695 .907 r
.36312 .46489 .37173 .47467 .38582 .47254 .37725 .46232 Mtetra
.586 .68 .905 r
.37725 .46232 .38582 .47254 .39997 .47113 .39146 .46038 Mtetra
.564 .66 .902 r
.39146 .46038 .39997 .47113 .4142 .47057 .40573 .45921 Mtetra
.537 .637 .896 r
.40573 .45921 .4142 .47057 .42851 .47103 .42009 .45894 Mtetra
.506 .609 .889 r
.42009 .45894 .42851 .47103 .44291 .47265 .43453 .45973 Mtetra
.473 .577 .879 r
.43453 .45973 .44291 .47265 .45742 .47555 .44907 .4617 Mtetra
.437 .543 .866 r
.44907 .4617 .45742 .47555 .47206 .47984 .46373 .46499 Mtetra
.401 .507 .851 r
.46373 .46499 .47206 .47984 .48684 .48557 .47853 .46965 Mtetra
.368 .473 .835 r
.47853 .46965 .48684 .48557 .50179 .49275 .49347 .47574 Mtetra
.339 .441 .819 r
.49347 .47574 .50179 .49275 .51692 .50129 .5086 .48319 Mtetra
.316 .414 .804 r
.5086 .48319 .51692 .50129 .53227 .51102 .52392 .49191 Mtetra
.302 .394 .791 r
.52392 .49191 .53227 .51102 .54784 .52169 .53946 .50169 Mtetra
.296 .382 .781 r
.53946 .50169 .54784 .52169 .56365 .53293 .55524 .51222 Mtetra
.3 .378 .776 r
.55524 .51222 .56365 .53293 .57971 .54429 .57125 .5231 Mtetra
.315 .383 .774 r
.57125 .5231 .57971 .54429 .596 .55523 .5875 .53386 Mtetra
.338 .398 .777 r
.5875 .53386 .596 .55523 .61251 .56516 .60398 .54394 Mtetra
.372 .421 .783 r
.60398 .54394 .61251 .56516 .62921 .57347 .62067 .55276 Mtetra
.414 .453 .792 r
.62067 .55276 .62921 .57347 .64605 .57958 .63753 .55973 Mtetra
.464 .493 .803 r
.63753 .55973 .64605 .57958 .66299 .58294 .65451 .56428 Mtetra
.52 .539 .815 r
.65451 .56428 .66299 .58294 .67997 .58315 .67156 .56596 Mtetra
.581 .589 .826 r
.67156 .56596 .67997 .58315 .69692 .57992 .68862 .56441 Mtetra
.643 .642 .834 r
.68862 .56441 .69692 .57992 .7138 .57317 .70564 .55946 Mtetra
.704 .695 .839 r
.70564 .55946 .7138 .57317 .73055 .56296 .72256 .55108 Mtetra
.76 .745 .838 r
.72256 .55108 .73055 .56296 .74714 .54956 .73935 .53944 Mtetra
.809 .789 .834 r
.73935 .53944 .74714 .54956 .76356 .53336 .75596 .52484 Mtetra
.849 .827 .826 r
.75596 .52484 .76356 .53336 .77978 .51488 .7724 .50774 Mtetra
.879 .857 .816 r
.7724 .50774 .77978 .51488 .79583 .49471 .78866 .48867 Mtetra
.9 .881 .806 r
.78866 .48867 .79583 .49471 .81174 .47346 .80477 .46824 Mtetra
.913 .898 .799 r
.80477 .46824 .81174 .47346 .82753 .45172 .82074 .44702 Mtetra
.919 .91 .796 r
.82074 .44702 .82753 .45172 .84326 .43005 .83663 .42558 Mtetra
.919 .919 .798 r
.83663 .42558 .84326 .43005 .85896 .4089 .85247 .40443 Mtetra
.915 .924 .806 r
.85247 .40443 .85896 .4089 .8747 .38865 .86832 .38396 Mtetra
.906 .925 .818 r
.86832 .38396 .8747 .38865 .89051 .36957 .88423 .3645 Mtetra
.657 .737 .908 r
.27066 .47898 .27966 .48751 .29341 .48327 .28445 .47464 Mtetra
.654 .734 .908 r
.28445 .47464 .29341 .48327 .30722 .47914 .29831 .47038 Mtetra
.65 .731 .908 r
.29831 .47038 .30722 .47914 .3211 .47517 .31224 .46624 Mtetra
.645 .727 .908 r
.31224 .46624 .3211 .47517 .33504 .47141 .32623 .46227 Mtetra
.637 .721 .908 r
.32623 .46227 .33504 .47141 .34905 .46796 .34029 .45855 Mtetra
.628 .713 .907 r
.34029 .45855 .34905 .46796 .36312 .46489 .35442 .45516 Mtetra
.615 .702 .906 r
.35442 .45516 .36312 .46489 .37725 .46232 .36861 .45219 Mtetra
.6 .688 .904 r
.36861 .45219 .37725 .46232 .39146 .46038 .38286 .44975 Mtetra
.581 .671 .901 r
.38286 .44975 .39146 .46038 .40573 .45921 .39719 .44798 Mtetra
.558 .65 .897 r
.39719 .44798 .40573 .45921 .42009 .45894 .41159 .447 Mtetra
.531 .625 .89 r
.41159 .447 .42009 .45894 .43453 .45973 .42608 .44696 Mtetra
.501 .596 .881 r
.42608 .44696 .43453 .45973 .44907 .4617 .44066 .448 Mtetra
.469 .564 .869 r
.44066 .448 .44907 .4617 .46373 .46499 .45535 .45024 Mtetra
.437 .53 .855 r
.45535 .45024 .46373 .46499 .47853 .46965 .47016 .45378 Mtetra
.406 .496 .839 r
.47016 .45378 .47853 .46965 .49347 .47574 .48512 .45866 Mtetra
.378 .464 .822 r
.48512 .45866 .49347 .47574 .5086 .48319 .50024 .46489 Mtetra
.356 .436 .806 r
.50024 .46489 .5086 .48319 .52392 .49191 .51554 .47241 Mtetra
.34 .414 .792 r
.51554 .47241 .52392 .49191 .53946 .50169 .53105 .48105 Mtetra
.333 .398 .78 r
.53105 .48105 .53946 .50169 .55524 .51222 .54678 .49057 Mtetra
.334 .39 .771 r
.54678 .49057 .55524 .51222 .57125 .5231 .56275 .50064 Mtetra
.343 .39 .766 r
.56275 .50064 .57125 .5231 .5875 .53386 .57895 .51085 Mtetra
.361 .398 .764 r
.57895 .51085 .5875 .53386 .60398 .54394 .59539 .52068 Mtetra
.387 .413 .766 r
.59539 .52068 .60398 .54394 .62067 .55276 .61204 .5296 Mtetra
.421 .436 .77 r
.61204 .5296 .62067 .55276 .63753 .55973 .62888 .53702 Mtetra
.461 .465 .776 r
.62888 .53702 .63753 .55973 .65451 .56428 .64587 .54241 Mtetra
.507 .501 .784 r
.64587 .54241 .65451 .56428 .67156 .56596 .66296 .54526 Mtetra
.557 .54 .792 r
.66296 .54526 .67156 .56596 .68862 .56441 .68009 .54517 Mtetra
.609 .583 .799 r
.68009 .54517 .68862 .56441 .70564 .55946 .69722 .54189 Mtetra
.662 .628 .805 r
.69722 .54189 .70564 .55946 .72256 .55108 .71428 .5353 Mtetra
.713 .673 .809 r
.71428 .5353 .72256 .55108 .73935 .53944 .73124 .52548 Mtetra
.761 .716 .81 r
.73124 .52548 .73935 .53944 .75596 .52484 .74805 .51264 Mtetra
.803 .755 .809 r
.74805 .51264 .75596 .52484 .7724 .50774 .76469 .49716 Mtetra
.838 .79 .806 r
.76469 .49716 .7724 .50774 .78866 .48867 .78116 .4795 Mtetra
.865 .82 .803 r
.78116 .4795 .78866 .48867 .80477 .46824 .79747 .46022 Mtetra
.885 .844 .8 r
.79747 .46022 .80477 .46824 .82074 .44702 .81364 .43988 Mtetra
.897 .864 .799 r
.81364 .43988 .82074 .44702 .83663 .42558 .82971 .41904 Mtetra
.903 .879 .801 r
.82971 .41904 .83663 .42558 .85247 .40443 .84572 .39821 Mtetra
.904 .889 .807 r
.84572 .39821 .85247 .40443 .86832 .38396 .86172 .37785 Mtetra
.899 .895 .816 r
.86172 .37785 .86832 .38396 .88423 .3645 .87774 .35829 Mtetra
.659 .738 .908 r
.26157 .47041 .27066 .47898 .28445 .47464 .27541 .46596 Mtetra
.656 .736 .908 r
.27541 .46596 .28445 .47464 .29831 .47038 .28932 .46158 Mtetra
.653 .733 .908 r
.28932 .46158 .29831 .47038 .31224 .46624 .30329 .45729 Mtetra
.649 .729 .908 r
.30329 .45729 .31224 .46624 .32623 .46227 .31734 .45314 Mtetra
.643 .724 .908 r
.31734 .45314 .32623 .46227 .34029 .45855 .33145 .44918 Mtetra
.635 .718 .907 r
.33145 .44918 .34029 .45855 .35442 .45516 .34563 .44549 Mtetra
.625 .709 .906 r
.34563 .44549 .35442 .45516 .36861 .45219 .35987 .44214 Mtetra
.612 .697 .904 r
.35987 .44214 .36861 .45219 .38286 .44975 .37418 .43925 Mtetra
.596 .682 .902 r
.37418 .43925 .38286 .44975 .39719 .44798 .38856 .43691 Mtetra
.576 .663 .897 r
.38856 .43691 .39719 .44798 .41159 .447 .40302 .43527 Mtetra
.553 .641 .891 r
.40302 .43527 .41159 .447 .42608 .44696 .41756 .43444 Mtetra
.527 .615 .883 r
.41756 .43444 .42608 .44696 .44066 .448 .43218 .43456 Mtetra
.499 .585 .872 r
.43218 .43456 .44066 .448 .45535 .45024 .44691 .43576 Mtetra
.47 .554 .859 r
.44691 .43576 .45535 .45024 .47016 .45378 .46174 .43815 Mtetra
.441 .521 .844 r
.46174 .43815 .47016 .45378 .48512 .45866 .47672 .44179 Mtetra
.414 .489 .828 r
.47672 .44179 .48512 .45866 .50024 .46489 .49184 .44671 Mtetra
.392 .46 .812 r
.49184 .44671 .50024 .46489 .51554 .47241 .50713 .45289 Mtetra
.376 .436 .796 r
.50713 .45289 .51554 .47241 .53105 .48105 .52261 .46022 Mtetra
.366 .417 .782 r
.52261 .46022 .53105 .48105 .54678 .49057 .5383 .46851 Mtetra
.364 .405 .771 r
.5383 .46851 .54678 .49057 .56275 .50064 .55422 .4775 Mtetra
.369 .401 .763 r
.55422 .4775 .56275 .50064 .57895 .51085 .57037 .48682 Mtetra
.382 .403 .758 r
.57037 .48682 .57895 .51085 .59539 .52068 .58675 .49604 Mtetra
.402 .412 .755 r
.58675 .49604 .59539 .52068 .61204 .5296 .60335 .50467 Mtetra
.429 .427 .756 r
.60335 .50467 .61204 .5296 .62888 .53702 .62015 .51216 Mtetra
.461 .449 .758 r
.62015 .51216 .62888 .53702 .64587 .54241 .63712 .518 Mtetra
.499 .476 .763 r
.63712 .518 .64587 .54241 .66296 .54526 .65421 .52166 Mtetra
.54 .507 .768 r
.65421 .52166 .66296 .54526 .68009 .54517 .67139 .52274 Mtetra
.584 .542 .774 r
.67139 .52274 .68009 .54517 .69722 .54189 .68859 .5209 Mtetra
.629 .58 .78 r
.68859 .5209 .69722 .54189 .71428 .5353 .70576 .51597 Mtetra
.675 .618 .784 r
.70576 .51597 .71428 .5353 .73124 .52548 .72285 .50793 Mtetra
.718 .657 .788 r
.72285 .50793 .73124 .52548 .74805 .51264 .73983 .49691 Mtetra
.759 .695 .791 r
.73983 .49691 .74805 .51264 .76469 .49716 .75666 .48318 Mtetra
.795 .73 .792 r
.75666 .48318 .76469 .49716 .78116 .4795 .77334 .46714 Mtetra
.825 .762 .793 r
.77334 .46714 .78116 .4795 .79747 .46022 .78986 .44927 Mtetra
.85 .79 .793 r
.78986 .44927 .79747 .46022 .81364 .43988 .80624 .43011 Mtetra
.867 .815 .795 r
.80624 .43011 .81364 .43988 .82971 .41904 .82251 .4102 Mtetra
.879 .835 .798 r
.82251 .4102 .82971 .41904 .84572 .39821 .8387 .39003 Mtetra
.885 .85 .804 r
.8387 .39003 .84572 .39821 .86172 .37785 .85486 .37008 Mtetra
.884 .862 .813 r
.85486 .37008 .86172 .37785 .87774 .35829 .87103 .35073 Mtetra
.66 .738 .908 r
.25239 .46177 .26157 .47041 .27541 .46596 .26627 .45723 Mtetra
.658 .737 .908 r
.26627 .45723 .27541 .46596 .28932 .46158 .28023 .45274 Mtetra
.656 .735 .908 r
.28023 .45274 .28932 .46158 .30329 .45729 .29425 .44832 Mtetra
.652 .732 .908 r
.29425 .44832 .30329 .45729 .31734 .45314 .30835 .444 Mtetra
.647 .728 .907 r
.30835 .444 .31734 .45314 .33145 .44918 .32251 .43983 Mtetra
.641 .722 .907 r
.32251 .43983 .33145 .44918 .34563 .44549 .33674 .43587 Mtetra
.633 .715 .906 r
.33674 .43587 .34563 .44549 .35987 .44214 .35104 .4322 Mtetra
.622 .705 .904 r
.35104 .4322 .35987 .44214 .37418 .43925 .36541 .42888 Mtetra
.609 .692 .902 r
.36541 .42888 .37418 .43925 .38856 .43691 .37985 .42604 Mtetra
.592 .676 .898 r
.37985 .42604 .38856 .43691 .40302 .43527 .39436 .42377 Mtetra
.573 .656 .893 r
.39436 .42377 .40302 .43527 .41756 .43444 .40895 .4222 Mtetra
.551 .633 .886 r
.40895 .4222 .41756 .43444 .43218 .43456 .42362 .42146 Mtetra
.526 .606 .876 r
.42362 .42146 .43218 .43456 .44691 .43576 .43839 .42167 Mtetra
.5 .577 .865 r
.43839 .42167 .44691 .43576 .46174 .43815 .45326 .42292 Mtetra
.473 .546 .851 r
.45326 .42292 .46174 .43815 .47672 .44179 .46826 .42532 Mtetra
.448 .515 .835 r
.46826 .42532 .47672 .44179 .49184 .44671 .48339 .42891 Mtetra
.426 .486 .819 r
.48339 .42891 .49184 .44671 .50713 .45289 .49868 .43369 Mtetra
.409 .461 .802 r
.49868 .43369 .50713 .45289 .52261 .46022 .51414 .4396 Mtetra
.397 .439 .787 r
.51414 .4396 .52261 .46022 .5383 .46851 .5298 .44651 Mtetra
.392 .424 .774 r
.5298 .44651 .5383 .46851 .55422 .4775 .54567 .4542 Mtetra
.394 .415 .764 r
.54567 .4542 .55422 .4775 .57037 .48682 .56177 .46238 Mtetra
.402 .412 .756 r
.56177 .46238 .57037 .48682 .58675 .49604 .57808 .47069 Mtetra
.417 .416 .751 r
.57808 .47069 .58675 .49604 .60335 .50467 .59462 .47868 Mtetra
.438 .426 .748 r
.59462 .47868 .60335 .50467 .62015 .51216 .61137 .48588 Mtetra
.464 .441 .748 r
.61137 .48588 .62015 .51216 .63712 .518 .6283 .49178 Mtetra
.494 .461 .749 r
.6283 .49178 .63712 .518 .65421 .52166 .64537 .49589 Mtetra
.529 .486 .752 r
.64537 .49589 .65421 .52166 .67139 .52274 .66255 .49779 Mtetra
.566 .514 .756 r
.66255 .49779 .67139 .52274 .68859 .5209 .67979 .49711 Mtetra
.605 .545 .761 r
.67979 .49711 .68859 .5209 .70576 .51597 .69703 .49362 Mtetra
.644 .578 .765 r
.69703 .49362 .70576 .51597 .72285 .50793 .71424 .48722 Mtetra
.683 .612 .77 r
.71424 .48722 .72285 .50793 .73983 .49691 .73135 .47795 Mtetra
.721 .646 .774 r
.73135 .47795 .73983 .49691 .75666 .48318 .74836 .46601 Mtetra
.756 .679 .777 r
.74836 .46601 .75666 .48318 .77334 .46714 .76522 .45171 Mtetra
.787 .711 .781 r
.76522 .45171 .77334 .46714 .78986 .44927 .78194 .43544 Mtetra
.813 .741 .784 r
.78194 .43544 .78986 .44927 .80624 .43011 .79853 .4177 Mtetra
.834 .767 .788 r
.79853 .4177 .80624 .43011 .82251 .4102 .81501 .39897 Mtetra
.85 .791 .793 r
.81501 .39897 .82251 .4102 .8387 .39003 .83139 .37976 Mtetra
.86 .81 .8 r
.83139 .37976 .8387 .39003 .85486 .37008 .84774 .36052 Mtetra
.865 .826 .808 r
.84774 .36052 .85486 .37008 .87103 .35073 .86407 .34164 Mtetra
.661 .739 .908 r
.24312 .45306 .25239 .46177 .26627 .45723 .25705 .44845 Mtetra
.659 .738 .908 r
.25705 .44845 .26627 .45723 .28023 .45274 .27105 .44386 Mtetra
.657 .736 .908 r
.27105 .44386 .28023 .45274 .29425 .44832 .28512 .43932 Mtetra
.655 .734 .908 r
.28512 .43932 .29425 .44832 .30835 .444 .29927 .43485 Mtetra
.651 .731 .907 r
.29927 .43485 .30835 .444 .32251 .43983 .31348 .4305 Mtetra
.646 .726 .907 r
.31348 .4305 .32251 .43983 .33674 .43587 .32777 .42631 Mtetra
.639 .72 .906 r
.32777 .42631 .33674 .43587 .35104 .4322 .34212 .42234 Mtetra
.631 .712 .905 r
.34212 .42234 .35104 .4322 .36541 .42888 .35655 .41866 Mtetra
.62 .701 .903 r
.35655 .41866 .36541 .42888 .37985 .42604 .37104 .41536 Mtetra
.607 .687 .9 r
.37104 .41536 .37985 .42604 .39436 .42377 .38561 .41253 Mtetra
.59 .671 .895 r
.38561 .41253 .39436 .42377 .40895 .4222 .40026 .41029 Mtetra
.571 .65 .889 r
.40026 .41029 .40895 .4222 .42362 .42146 .41498 .40875 Mtetra
.55 .627 .881 r
.41498 .40875 .42362 .42146 .43839 .42167 .4298 .40802 Mtetra
.527 .6 .87 r
.4298 .40802 .43839 .42167 .45326 .42292 .44471 .40821 Mtetra
.503 .571 .857 r
.44471 .40821 .45326 .42292 .46826 .42532 .45973 .40941 Mtetra
.48 .542 .843 r
.45973 .40941 .46826 .42532 .48339 .42891 .47489 .41169 Mtetra
.458 .513 .827 r
.47489 .41169 .48339 .42891 .49868 .43369 .49018 .41507 Mtetra
.441 .487 .811 r
.49018 .41507 .49868 .43369 .51414 .4396 .50564 .41952 Mtetra
.427 .464 .795 r
.50564 .41952 .51414 .4396 .5298 .44651 .52128 .42496 Mtetra
.42 .446 .781 r
.52128 .42496 .5298 .44651 .54567 .4542 .53711 .43123 Mtetra
.418 .433 .769 r
.53711 .43123 .54567 .4542 .56177 .46238 .55315 .43809 Mtetra
.422 .426 .759 r
.55315 .43809 .56177 .46238 .57808 .47069 .56941 .44525 Mtetra
.433 .425 .751 r
.56941 .44525 .57808 .47069 .59462 .47868 .58588 .45233 Mtetra
.448 .43 .746 r
.58588 .45233 .59462 .47868 .61137 .48588 .60256 .4589 Mtetra
.469 .44 .743 r
.60256 .4589 .61137 .48588 .6283 .49178 .61943 .46452 Mtetra
.494 .454 .742 r
.61943 .46452 .6283 .49178 .64537 .49589 .63647 .46872 Mtetra
.522 .473 .743 r
.63647 .46872 .64537 .49589 .66255 .49779 .65363 .47108 Mtetra
.553 .496 .745 r
.65363 .47108 .66255 .49779 .67979 .49711 .67088 .47123 Mtetra
.586 .521 .748 r
.67088 .47123 .67979 .49711 .69703 .49362 .68817 .4689 Mtetra
.621 .549 .752 r
.68817 .4689 .69703 .49362 .71424 .48722 .70545 .46392 Mtetra
.655 .578 .756 r
.70545 .46392 .71424 .48722 .73135 .47795 .72267 .45627 Mtetra
.689 .608 .76 r
.72267 .45627 .73135 .47795 .74836 .46601 .73982 .44606 Mtetra
.722 .639 .765 r
.73982 .44606 .74836 .46601 .76522 .45171 .75685 .4335 Mtetra
.752 .669 .77 r
.75685 .4335 .76522 .45171 .78194 .43544 .77376 .41892 Mtetra
.779 .698 .774 r
.77376 .41892 .78194 .43544 .79853 .4177 .79055 .40275 Mtetra
.802 .725 .78 r
.79055 .40275 .79853 .4177 .81501 .39897 .80723 .38541 Mtetra
.82 .75 .786 r
.80723 .38541 .81501 .39897 .83139 .37976 .82382 .36738 Mtetra
.833 .772 .794 r
.82382 .36738 .83139 .37976 .84774 .36052 .84036 .34909 Mtetra
.842 .791 .802 r
.84036 .34909 .84774 .36052 .86407 .34164 .85687 .33094 Mtetra
.662 .74 .908 r
.23375 .44429 .24312 .45306 .25705 .44845 .24773 .4396 Mtetra
.661 .739 .908 r
.24773 .4396 .25705 .44845 .27105 .44386 .26178 .43492 Mtetra
.659 .737 .908 r
.26178 .43492 .27105 .44386 .28512 .43932 .2759 .43028 Mtetra
.657 .736 .908 r
.2759 .43028 .28512 .43932 .29927 .43485 .2901 .42568 Mtetra
.654 .733 .907 r
.2901 .42568 .29927 .43485 .31348 .4305 .30436 .42117 Mtetra
.65 .729 .907 r
.30436 .42117 .31348 .4305 .32777 .42631 .3187 .41678 Mtetra
.645 .724 .906 r
.3187 .41678 .32777 .42631 .34212 .42234 .33311 .41255 Mtetra
.638 .718 .905 r
.33311 .41255 .34212 .42234 .35655 .41866 .34759 .40855 Mtetra
.63 .709 .903 r
.34759 .40855 .35655 .41866 .37104 .41536 .36214 .40485 Mtetra
.619 .698 .901 r
.36214 .40485 .37104 .41536 .38561 .41253 .37677 .40154 Mtetra
.605 .683 .897 r
.37677 .40154 .38561 .41253 .40026 .41029 .39147 .3987 Mtetra
.59 .666 .892 r
.39147 .3987 .40026 .41029 .41498 .40875 .40625 .39644 Mtetra
.571 .646 .885 r
.40625 .39644 .41498 .40875 .4298 .40802 .42112 .39486 Mtetra
.551 .622 .876 r
.42112 .39486 .4298 .40802 .44471 .40821 .43608 .39407 Mtetra
.53 .596 .865 r
.43608 .39407 .44471 .40821 .45973 .40941 .45114 .39415 Mtetra
.509 .569 .851 r
.45114 .39415 .45973 .40941 .47489 .41169 .46632 .39518 Mtetra
.489 .541 .837 r
.46632 .39518 .47489 .41169 .49018 .41507 .48164 .3972 Mtetra
.471 .514 .821 r
.48164 .3972 .49018 .41507 .50564 .41952 .4971 .40022 Mtetra
.457 .49 .805 r
.4971 .40022 .50564 .41952 .52128 .42496 .51272 .40417 Mtetra
.447 .47 .79 r
.51272 .40417 .52128 .42496 .53711 .43123 .52853 .40896 Mtetra
.442 .454 .777 r
.52853 .40896 .53711 .43123 .55315 .43809 .54452 .41439 Mtetra
.443 .444 .765 r
.54452 .41439 .55315 .43809 .56941 .44525 .56073 .42024 Mtetra
.449 .439 .755 r
.56073 .42024 .56941 .44525 .58588 .45233 .57714 .4262 Mtetra
.46 .439 .748 r
.57714 .4262 .58588 .45233 .60256 .4589 .59376 .43189 Mtetra
.476 .444 .743 r
.59376 .43189 .60256 .4589 .61943 .46452 .61056 .43693 Mtetra
.496 .454 .74 r
.61056 .43693 .61943 .46452 .63647 .46872 .62755 .44089 Mtetra
.519 .468 .739 r
.62755 .44089 .63647 .46872 .65363 .47108 .64467 .44338 Mtetra
.545 .485 .739 r
.64467 .44338 .65363 .47108 .67088 .47123 .6619 .44402 Mtetra
.573 .505 .741 r
.6619 .44402 .67088 .47123 .68817 .4689 .67921 .44253 Mtetra
.603 .528 .743 r
.67921 .44253 .68817 .4689 .70545 .46392 .69653 .43871 Mtetra
.633 .553 .747 r
.69653 .43871 .70545 .46392 .72267 .45627 .71384 .43246 Mtetra
.664 .58 .751 r
.71384 .43246 .72267 .45627 .73982 .44606 .7311 .42382 Mtetra
.694 .607 .755 r
.7311 .42382 .73982 .44606 .75685 .4335 .74828 .41294 Mtetra
.722 .635 .76 r
.74828 .41294 .75685 .4335 .77376 .41892 .76536 .40005 Mtetra
.748 .662 .766 r
.76536 .40005 .77376 .41892 .79055 .40275 .78233 .3855 Mtetra
.771 .689 .772 r
.78233 .3855 .79055 .40275 .80723 .38541 .79921 .36967 Mtetra
.791 .714 .779 r
.79921 .36967 .80723 .38541 .82382 .36738 .816 .35298 Mtetra
.806 .737 .788 r
.816 .35298 .82382 .36738 .84036 .34909 .83273 .33584 Mtetra
.817 .758 .797 r
.83273 .33584 .84036 .34909 .85687 .33094 .84944 .31862 Mtetra
.662 .74 .908 r
.22429 .43544 .23375 .44429 .24773 .4396 .23831 .43068 Mtetra
.661 .739 .908 r
.23831 .43068 .24773 .4396 .26178 .43492 .25241 .42593 Mtetra
.66 .738 .908 r
.25241 .42593 .26178 .43492 .2759 .43028 .26658 .42119 Mtetra
.659 .737 .908 r
.26658 .42119 .2759 .43028 .2901 .42568 .28083 .41648 Mtetra
.657 .735 .907 r
.28083 .41648 .2901 .42568 .30436 .42117 .29514 .41183 Mtetra
.654 .732 .907 r
.29514 .41183 .30436 .42117 .3187 .41678 .30954 .40726 Mtetra
.65 .728 .906 r
.30954 .40726 .3187 .41678 .33311 .41255 .324 .40282 Mtetra
.644 .723 .905 r
.324 .40282 .33311 .41255 .34759 .40855 .33854 .39855 Mtetra
.637 .716 .904 r
.33854 .39855 .34759 .40855 .36214 .40485 .35315 .3945 Mtetra
.629 .707 .902 r
.35315 .3945 .36214 .40485 .37677 .40154 .36783 .39076 Mtetra
.618 .695 .899 r
.36783 .39076 .37677 .40154 .39147 .3987 .38259 .3874 Mtetra
.605 .68 .895 r
.38259 .3874 .39147 .3987 .40625 .39644 .39743 .38451 Mtetra
.59 .663 .889 r
.39743 .38451 .40625 .39644 .42112 .39486 .41235 .38218 Mtetra
.573 .642 .881 r
.41235 .38218 .42112 .39486 .43608 .39407 .42736 .3805 Mtetra
.555 .619 .872 r
.42736 .3805 .43608 .39407 .45114 .39415 .44247 .37957 Mtetra
.536 .594 .86 r
.44247 .37957 .45114 .39415 .46632 .39518 .45769 .37945 Mtetra
.517 .568 .846 r
.45769 .37945 .46632 .39518 .48164 .3972 .47303 .3802 Mtetra
.499 .542 .832 r
.47303 .3802 .48164 .3972 .4971 .40022 .4885 .38184 Mtetra
.485 .518 .816 r
.4885 .38184 .4971 .40022 .51272 .40417 .50413 .38435 Mtetra
.473 .496 .801 r
.50413 .38435 .51272 .40417 .52853 .40896 .51992 .38766 Mtetra
.466 .478 .787 r
.51992 .38766 .52853 .40896 .54452 .41439 .53589 .39163 Mtetra
.464 .465 .774 r
.53589 .39163 .54452 .41439 .56073 .42024 .55204 .39609 Mtetra
.467 .456 .763 r
.55204 .39609 .56073 .42024 .57714 .4262 .5684 .40079 Mtetra
.474 .452 .754 r
.5684 .40079 .57714 .4262 .59376 .43189 .58495 .40542 Mtetra
.485 .453 .747 r
.58495 .40542 .59376 .43189 .61056 .43693 .6017 .40964 Mtetra
.501 .459 .742 r
.6017 .40964 .61056 .43693 .62755 .44089 .61862 .41309 Mtetra
.519 .468 .739 r
.61862 .41309 .62755 .44089 .64467 .44338 .6357 .4154 Mtetra
.541 .481 .738 r
.6357 .4154 .64467 .44338 .6619 .44402 .6529 .41622 Mtetra
.565 .497 .738 r
.6529 .41622 .6619 .44402 .67921 .44253 .67019 .41526 Mtetra
.59 .516 .739 r
.67019 .41526 .67921 .44253 .69653 .43871 .68754 .4123 Mtetra
.617 .537 .742 r
.68754 .4123 .69653 .43871 .71384 .43246 .7049 .40719 Mtetra
.644 .56 .745 r
.7049 .40719 .71384 .43246 .7311 .42382 .72225 .39992 Mtetra
.671 .584 .749 r
.72225 .39992 .7311 .42382 .74828 .41294 .73954 .39055 Mtetra
.697 .609 .754 r
.73954 .39055 .74828 .41294 .76536 .40005 .75677 .37927 Mtetra
.721 .634 .76 r
.75677 .37927 .76536 .40005 .78233 .3855 .77391 .36632 Mtetra
.744 .659 .767 r
.77391 .36632 .78233 .3855 .79921 .36967 .79097 .35204 Mtetra
.764 .684 .774 r
.79097 .35204 .79921 .36967 .816 .35298 .80796 .33677 Mtetra
.78 .707 .782 r
.80796 .33677 .816 .35298 .83273 .33584 .82489 .3209 Mtetra
.793 .728 .792 r
.82489 .3209 .83273 .33584 .84944 .31862 .84179 .30477 Mtetra
.663 .74 .908 r
.21474 .42651 .22429 .43544 .23831 .43068 .22881 .42169 Mtetra
.662 .74 .908 r
.22881 .42169 .23831 .43068 .25241 .42593 .24295 .41687 Mtetra
.661 .739 .908 r
.24295 .41687 .25241 .42593 .26658 .42119 .25717 .41205 Mtetra
.66 .738 .908 r
.25717 .41205 .26658 .42119 .28083 .41648 .27146 .40724 Mtetra
.658 .737 .907 r
.27146 .40724 .28083 .41648 .29514 .41183 .28583 .40247 Mtetra
.656 .734 .907 r
.28583 .40247 .29514 .41183 .30954 .40726 .30027 .39775 Mtetra
.653 .731 .907 r
.30027 .39775 .30954 .40726 .324 .40282 .31479 .39312 Mtetra
.649 .727 .906 r
.31479 .39312 .324 .40282 .33854 .39855 .32939 .38862 Mtetra
.644 .722 .905 r
.32939 .38862 .33854 .39855 .35315 .3945 .34405 .38429 Mtetra
.637 .714 .903 r
.34405 .38429 .35315 .3945 .36783 .39076 .3588 .38018 Mtetra
.629 .705 .901 r
.3588 .38018 .36783 .39076 .38259 .3874 .37361 .37638 Mtetra
.618 .693 .897 r
.37361 .37638 .38259 .3874 .39743 .38451 .38851 .37294 Mtetra
.606 .678 .892 r
.38851 .37294 .39743 .38451 .41235 .38218 .40349 .36996 Mtetra
.592 .661 .886 r
.40349 .36996 .41235 .38218 .42736 .3805 .41856 .3675 Mtetra
.576 .641 .878 r
.41856 .3675 .42736 .3805 .44247 .37957 .43372 .36566 Mtetra
.559 .619 .868 r
.43372 .36566 .44247 .37957 .45769 .37945 .44898 .36451 Mtetra
.542 .595 .856 r
.44898 .36451 .45769 .37945 .47303 .3802 .46435 .3641 Mtetra
.526 .57 .843 r
.46435 .3641 .47303 .3802 .4885 .38184 .47985 .36447 Mtetra
.511 .546 .828 r
.47985 .36447 .4885 .38184 .50413 .38435 .49548 .36562 Mtetra
.499 .524 .814 r
.49548 .36562 .50413 .38435 .51992 .38766 .51127 .36751 Mtetra
.491 .505 .799 r
.51127 .36751 .51992 .38766 .53589 .39163 .52722 .37005 Mtetra
.486 .489 .786 r
.52722 .37005 .53589 .39163 .55204 .39609 .54335 .3731 Mtetra
.485 .477 .773 r
.54335 .3731 .55204 .39609 .5684 .40079 .55966 .37647 Mtetra
.489 .47 .763 r
.55966 .37647 .5684 .40079 .58495 .40542 .57616 .37992 Mtetra
.497 .467 .754 r
.57616 .37992 .58495 .40542 .6017 .40964 .59285 .38316 Mtetra
.508 .468 .748 r
.59285 .38316 .6017 .40964 .61862 .41309 .60971 .38589 Mtetra
.523 .474 .743 r
.60971 .38589 .61862 .41309 .6357 .4154 .62674 .38777 Mtetra
.54 .482 .74 r
.62674 .38777 .6357 .4154 .6529 .41622 .6439 .38849 Mtetra
.56 .495 .739 r
.6439 .38849 .6529 .41622 .67019 .41526 .66117 .38776 Mtetra
.582 .51 .739 r
.66117 .38776 .67019 .41526 .68754 .4123 .67852 .38536 Mtetra
.605 .527 .74 r
.67852 .38536 .68754 .4123 .7049 .40719 .69591 .38112 Mtetra
.629 .546 .743 r
.69591 .38112 .7049 .40719 .72225 .39992 .71331 .37496 Mtetra
.653 .567 .746 r
.71331 .37496 .72225 .39992 .73954 .39055 .7307 .36691 Mtetra
.676 .59 .751 r
.7307 .36691 .73954 .39055 .75677 .37927 .74804 .35707 Mtetra
.699 .612 .756 r
.74804 .35707 .75677 .37927 .77391 .36632 .76533 .34563 Mtetra
.72 .636 .763 r
.76533 .34563 .77391 .36632 .79097 .35204 .78256 .33285 Mtetra
.74 .659 .77 r
.78256 .33285 .79097 .35204 .80796 .33677 .79973 .31903 Mtetra
.756 .681 .779 r
.79973 .31903 .80796 .33677 .82489 .3209 .81685 .30448 Mtetra
.77 .703 .788 r
.81685 .30448 .82489 .3209 .84179 .30477 .83394 .28954 Mtetra
.663 .741 .908 r
.20509 .41751 .21474 .42651 .22881 .42169 .2192 .41263 Mtetra
.662 .74 .908 r
.2192 .41263 .22881 .42169 .24295 .41687 .23339 .40773 Mtetra
.23339 .40773 .24295 .41687 .25717 .41205 .24766 .40284 Mtetra
.661 .739 .908 r
.24766 .40284 .25717 .41205 .27146 .40724 .262 .39794 Mtetra
.66 .738 .908 r
.262 .39794 .27146 .40724 .28583 .40247 .27642 .39306 Mtetra
.658 .736 .907 r
.27642 .39306 .28583 .40247 .30027 .39775 .29091 .38822 Mtetra
.656 .734 .907 r
.29091 .38822 .30027 .39775 .31479 .39312 .30549 .38343 Mtetra
.653 .731 .906 r
.30549 .38343 .31479 .39312 .32939 .38862 .32013 .37874 Mtetra
.649 .726 .905 r
.32013 .37874 .32939 .38862 .34405 .38429 .33486 .37416 Mtetra
.644 .721 .904 r
.33486 .37416 .34405 .38429 .3588 .38018 .34966 .36976 Mtetra
.637 .713 .902 r
.34966 .36976 .3588 .38018 .37361 .37638 .36454 .36558 Mtetra
.629 .703 .899 r
.36454 .36558 .37361 .37638 .38851 .37294 .37949 .36168 Mtetra
.619 .692 .896 r
.37949 .36168 .38851 .37294 .40349 .36996 .39453 .35814 Mtetra
.608 .677 .89 r
.39453 .35814 .40349 .36996 .41856 .3675 .40965 .35502 Mtetra
.595 .66 .884 r
.40965 .35502 .41856 .3675 .43372 .36566 .42487 .35239 Mtetra
.58 .641 .875 r
.42487 .35239 .43372 .36566 .44898 .36451 .44018 .35033 Mtetra
.565 .62 .865 r
.44018 .35033 .44898 .36451 .46435 .3641 .45559 .3489 Mtetra
.55 .597 .854 r
.45559 .3489 .46435 .3641 .47985 .36447 .47113 .34812 Mtetra
.536 .575 .841 r
.47113 .34812 .47985 .36447 .49548 .36562 .48678 .34802 Mtetra
.524 .553 .827 r
.48678 .34802 .49548 .36562 .51127 .36751 .50258 .34859 Mtetra
.514 .532 .813 r
.50258 .34859 .51127 .36751 .52722 .37005 .51853 .34976 Mtetra
.508 .515 .799 r
.51853 .34976 .52722 .37005 .54335 .3731 .53464 .35145 Mtetra
.505 .501 .786 r
.53464 .35145 .54335 .3731 .55966 .37647 .55092 .35349 Mtetra
.505 .491 .775 r
.55092 .35349 .55966 .37647 .57616 .37992 .56738 .35572 Mtetra
.51 .485 .765 r
.56738 .35572 .57616 .37992 .59285 .38316 .58402 .35789 Mtetra
.518 .482 .757 r
.58402 .35789 .59285 .38316 .60971 .38589 .60082 .35974 Mtetra
.529 .484 .75 r
.60082 .35974 .60971 .38589 .62674 .38777 .6178 .361 Mtetra
.542 .489 .746 r
.6178 .361 .62674 .38777 .6439 .38849 .63491 .36139 Mtetra
.559 .498 .743 r
.63491 .36139 .6439 .38849 .66117 .38776 .65215 .36064 Mtetra
.577 .509 .742 r
.65215 .36064 .66117 .38776 .67852 .38536 .66949 .35852 Mtetra
.597 .523 .742 r
.66949 .35852 .67852 .38536 .69591 .38112 .6869 .35486 Mtetra
.617 .539 .744 r
.6869 .35486 .69591 .38112 .71331 .37496 .70434 .34956 Mtetra
.639 .557 .746 r
.70434 .34956 .71331 .37496 .7307 .36691 .72179 .34259 Mtetra
.66 .576 .75 r
.72179 .34259 .7307 .36691 .74804 .35707 .73923 .334 Mtetra
.681 .597 .755 r
.73923 .334 .74804 .35707 .76533 .34563 .75664 .32391 Mtetra
.7 .618 .761 r
.75664 .32391 .76533 .34563 .78256 .33285 .77402 .31253 Mtetra
.719 .64 .769 r
.77402 .31253 .78256 .33285 .79973 .31903 .79135 .30009 Mtetra
.735 .661 .777 r
.79135 .30009 .79973 .31903 .81685 .30448 .80865 .28686 Mtetra
.749 .682 .786 r
.80865 .28686 .81685 .30448 .83394 .28954 .82592 .27313 Mtetra
.663 .741 .908 r
.19534 .40841 .20509 .41751 .2192 .41263 .2095 .40348 Mtetra
.2095 .40348 .2192 .41263 .23339 .40773 .22373 .39852 Mtetra
.662 .74 .908 r
.22373 .39852 .23339 .40773 .24766 .40284 .23805 .39355 Mtetra
.23805 .39355 .24766 .40284 .262 .39794 .25244 .38858 Mtetra
.661 .739 .908 r
.25244 .38858 .262 .39794 .27642 .39306 .26691 .38361 Mtetra
.66 .738 .907 r
.26691 .38361 .27642 .39306 .29091 .38822 .28145 .37866 Mtetra
.658 .736 .907 r
.28145 .37866 .29091 .38822 .30549 .38343 .29608 .37374 Mtetra
.656 .733 .907 r
.29608 .37374 .30549 .38343 .32013 .37874 .31078 .36888 Mtetra
.653 .73 .906 r
.31078 .36888 .32013 .37874 .33486 .37416 .32556 .3641 Mtetra
.649 .726 .905 r
.32556 .3641 .33486 .37416 .34966 .36976 .34042 .35945 Mtetra
.644 .72 .903 r
.34042 .35945 .34966 .36976 .36454 .36558 .35536 .35495 Mtetra
.638 .712 .901 r
.35536 .35495 .36454 .36558 .37949 .36168 .37037 .35068 Mtetra
.63 .703 .898 r
.37037 .35068 .37949 .36168 .39453 .35814 .38547 .34666 Mtetra
.621 .691 .894 r
.38547 .34666 .39453 .35814 .40965 .35502 .40065 .34298 Mtetra
.61 .677 .889 r
.40065 .34298 .40965 .35502 .42487 .35239 .41592 .33969 Mtetra
.598 .661 .882 r
.41592 .33969 .42487 .35239 .44018 .35033 .43129 .33685 Mtetra
.586 .643 .874 r
.43129 .33685 .44018 .35033 .45559 .3489 .44675 .33452 Mtetra
.572 .623 .864 r
.44675 .33452 .45559 .3489 .47113 .34812 .46232 .33274 Mtetra
.559 .602 .852 r
.46232 .33274 .47113 .34812 .48678 .34802 .47801 .33153 Mtetra
.548 .581 .84 r
.47801 .33153 .48678 .34802 .50258 .34859 .49383 .3309 Mtetra
.537 .561 .826 r
.49383 .3309 .50258 .34859 .51853 .34976 .50979 .33082 Mtetra
.53 .543 .813 r
.50979 .33082 .51853 .34976 .53464 .35145 .5259 .33121 Mtetra
.525 .527 .8 r
.5259 .33121 .53464 .35145 .55092 .35349 .54216 .33199 Mtetra
.523 .515 .788 r
.54216 .33199 .55092 .35349 .56738 .35572 .55859 .333 Mtetra
.524 .506 .778 r
.55859 .333 .56738 .35572 .58402 .35789 .57519 .33406 Mtetra
.529 .5 .768 r
.57519 .33406 .58402 .35789 .60082 .35974 .59196 .33496 Mtetra
.537 .499 .761 r
.59196 .33496 .60082 .35974 .6178 .361 .60888 .33547 Mtetra
.547 .5 .755 r
.60888 .33547 .6178 .361 .63491 .36139 .62596 .33535 Mtetra
.56 .505 .751 r
.62596 .33535 .63491 .36139 .65215 .36064 .64316 .33435 Mtetra
.575 .513 .748 r
.64316 .33435 .65215 .36064 .66949 .35852 .66048 .33228 Mtetra
.592 .524 .747 r
.66048 .33228 .66949 .35852 .6869 .35486 .67789 .32895 Mtetra
.61 .537 .748 r
.67789 .32895 .6869 .35486 .70434 .34956 .69535 .32425 Mtetra
.628 .552 .75 r
.69535 .32425 .70434 .34956 .72179 .34259 .71285 .31811 Mtetra
.647 .569 .753 r
.71285 .31811 .72179 .34259 .73923 .334 .73037 .31054 Mtetra
.666 .587 .757 r
.73037 .31054 .73923 .334 .75664 .32391 .74788 .30163 Mtetra
.684 .606 .763 r
.74788 .30163 .75664 .32391 .77402 .31253 .76538 .29149 Mtetra
.701 .626 .769 r
.76538 .29149 .77402 .31253 .79135 .30009 .78286 .28033 Mtetra
.717 .645 .777 r
.78286 .28033 .79135 .30009 .80865 .28686 .80032 .26835 Mtetra
.73 .665 .786 r
.80032 .26835 .80865 .28686 .82592 .27313 .81776 .25581 Mtetra
.663 .741 .908 r
.18549 .39923 .19534 .40841 .2095 .40348 .1997 .39424 Mtetra
.1997 .39424 .2095 .40348 .22373 .39852 .21398 .38923 Mtetra
.21398 .38923 .22373 .39852 .23805 .39355 .22834 .38419 Mtetra
.662 .74 .908 r
.22834 .38419 .23805 .39355 .25244 .38858 .24278 .37915 Mtetra
.24278 .37915 .25244 .38858 .26691 .38361 .2573 .3741 Mtetra
.661 .739 .908 r
.2573 .3741 .26691 .38361 .28145 .37866 .27189 .36905 Mtetra
.66 .737 .907 r
.27189 .36905 .28145 .37866 .29608 .37374 .28657 .36402 Mtetra
.658 .736 .907 r
.28657 .36402 .29608 .37374 .31078 .36888 .30133 .35902 Mtetra
.656 .733 .906 r
.30133 .35902 .31078 .36888 .32556 .3641 .31616 .35407 Mtetra
.653 .73 .906 r
.31616 .35407 .32556 .3641 .34042 .35945 .33108 .34921 Mtetra
.649 .725 .904 r
.33108 .34921 .34042 .35945 .35536 .35495 .34607 .34446 Mtetra
.644 .72 .903 r
.34607 .34446 .35536 .35495 .37037 .35068 .36115 .33987 Mtetra
.638 .712 .9 r
.36115 .33987 .37037 .35068 .38547 .34666 .37631 .33547 Mtetra
.631 .703 .897 r
.37631 .33547 .38547 .34666 .40065 .34298 .39155 .33132 Mtetra
.623 .692 .893 r
.39155 .33132 .40065 .34298 .41592 .33969 .40688 .32747 Mtetra
.613 .678 .888 r
.40688 .32747 .41592 .33969 .43129 .33685 .4223 .32398 Mtetra
.603 .663 .881 r
.4223 .32398 .43129 .33685 .44675 .33452 .43782 .32088 Mtetra
.592 .646 .873 r
.43782 .32088 .44675 .33452 .46232 .33274 .45344 .31824 Mtetra
.58 .627 .863 r
.45344 .31824 .46232 .33274 .47801 .33153 .46917 .31606 Mtetra
.569 .608 .852 r
.46917 .31606 .47801 .33153 .49383 .3309 .48502 .31438 Mtetra
.559 .589 .84 r
.48502 .31438 .49383 .3309 .50979 .33082 .501 .31317 Mtetra
.551 .571 .828 r
.501 .31317 .50979 .33082 .5259 .33121 .51711 .31239 Mtetra
.545 .554 .815 r
.51711 .31239 .5259 .33121 .54216 .33199 .53338 .31198 Mtetra
.541 .541 .803 r
.53338 .31198 .54216 .33199 .55859 .333 .54979 .31183 Mtetra
.54 .529 .792 r
.54979 .31183 .55859 .333 .57519 .33406 .56637 .3118 Mtetra
.542 .522 .782 r
.56637 .3118 .57519 .33406 .59196 .33496 .5831 .31172 Mtetra
.547 .517 .774 r
.5831 .31172 .59196 .33496 .60888 .33547 .59999 .31141 Mtetra
.555 .516 .767 r
.59999 .31141 .60888 .33547 .62596 .33535 .61703 .31066 Mtetra
.565 .518 .761 r
.61703 .31066 .62596 .33535 .64316 .33435 .63421 .30927 Mtetra
.577 .523 .758 r
.63421 .30927 .64316 .33435 .66048 .33228 .6515 .30705 Mtetra
.59 .53 .756 r
.6515 .30705 .66048 .33228 .67789 .32895 .6689 .30383 Mtetra
.605 .54 .755 r
.6689 .30383 .67789 .32895 .69535 .32425 .68638 .29949 Mtetra
.621 .552 .756 r
.68638 .29949 .69535 .32425 .71285 .31811 .70391 .29394 Mtetra
.638 .566 .758 r
.70391 .29394 .71285 .31811 .73037 .31054 .72149 .28717 Mtetra
.654 .582 .761 r
.72149 .28717 .73037 .31054 .74788 .30163 .73908 .27921 Mtetra
.671 .599 .766 r
.73908 .27921 .74788 .30163 .76538 .29149 .75669 .27014 Mtetra
.686 .616 .772 r
.75669 .27014 .76538 .29149 .78286 .28033 .77429 .26011 Mtetra
.701 .635 .779 r
.77429 .26011 .78286 .28033 .80032 .26835 .79189 .24928 Mtetra
.714 .653 .787 r
.79189 .24928 .80032 .26835 .81776 .25581 .8095 .23784 Mtetra
.663 .741 .908 r
.17554 .38996 .18549 .39923 .1997 .39424 .18979 .38491 Mtetra
.18979 .38491 .1997 .39424 .21398 .38923 .20412 .37984 Mtetra
.20412 .37984 .21398 .38923 .22834 .38419 .21853 .37475 Mtetra
.21853 .37475 .22834 .38419 .24278 .37915 .23302 .36964 Mtetra
.662 .74 .908 r
.23302 .36964 .24278 .37915 .2573 .3741 .24758 .36451 Mtetra
.662 .739 .908 r
.24758 .36451 .2573 .3741 .27189 .36905 .26223 .35938 Mtetra
.661 .739 .907 r
.26223 .35938 .27189 .36905 .28657 .36402 .27696 .35425 Mtetra
.66 .737 .907 r
.27696 .35425 .28657 .36402 .30133 .35902 .29177 .34913 Mtetra
.658 .735 .907 r
.29177 .34913 .30133 .35902 .31616 .35407 .30666 .34405 Mtetra
.656 .733 .906 r
.30666 .34405 .31616 .35407 .33108 .34921 .32163 .33901 Mtetra
.653 .73 .905 r
.32163 .33901 .33108 .34921 .34607 .34446 .33668 .33406 Mtetra
.65 .725 .904 r
.33668 .33406 .34607 .34446 .36115 .33987 .35182 .3292 Mtetra
.645 .72 .902 r
.35182 .3292 .36115 .33987 .37631 .33547 .36704 .32449 Mtetra
.64 .712 .9 r
.36704 .32449 .37631 .33547 .39155 .33132 .38234 .31996 Mtetra
.633 .704 .897 r
.38234 .31996 .39155 .33132 .40688 .32747 .39773 .31565 Mtetra
.626 .693 .893 r
.39773 .31565 .40688 .32747 .4223 .32398 .41321 .31161 Mtetra
.617 .68 .887 r
.41321 .31161 .4223 .32398 .43782 .32088 .42878 .30789 Mtetra
.608 .666 .881 r
.42878 .30789 .43782 .32088 .45344 .31824 .44445 .30451 Mtetra
.598 .65 .873 r
.44445 .30451 .45344 .31824 .46917 .31606 .46023 .30151 Mtetra
.588 .633 .863 r
.46023 .30151 .46917 .31606 .48502 .31438 .47612 .29892 Mtetra
.579 .616 .853 r
.47612 .29892 .48502 .31438 .501 .31317 .49213 .29672 Mtetra
.571 .598 .842 r
.49213 .29672 .501 .31317 .51711 .31239 .50827 .2949 Mtetra
.564 .582 .83 r
.50827 .2949 .51711 .31239 .53338 .31198 .52455 .29342 Mtetra
.559 .568 .819 r
.52455 .29342 .53338 .31198 .54979 .31183 .54096 .2922 Mtetra
.557 .555 .808 r
.54096 .2922 .54979 .31183 .56637 .3118 .55753 .29113 Mtetra
.557 .545 .798 r
.55753 .29113 .56637 .3118 .5831 .31172 .57425 .2901 Mtetra
.559 .539 .788 r
.57425 .2901 .5831 .31172 .59999 .31141 .59111 .28894 Mtetra
.564 .535 .781 r
.59111 .28894 .59999 .31141 .61703 .31066 .60813 .2875 Mtetra
.571 .534 .774 r
.60813 .2875 .61703 .31066 .63421 .30927 .62528 .2856 Mtetra
.58 .536 .77 r
.62528 .2856 .63421 .30927 .6515 .30705 .64255 .28309 Mtetra
.591 .541 .766 r
.64255 .28309 .6515 .30705 .6689 .30383 .65994 .2798 Mtetra
.604 .548 .765 r
.65994 .2798 .6689 .30383 .68638 .29949 .67743 .27561 Mtetra
.617 .557 .764 r
.67743 .27561 .68638 .29949 .70391 .29394 .69499 .27044 Mtetra
.631 .569 .766 r
.69499 .27044 .70391 .29394 .72149 .28717 .71261 .26425 Mtetra
.646 .582 .768 r
.71261 .26425 .72149 .28717 .73908 .27921 .73027 .25703 Mtetra
.661 .596 .772 r
.73027 .25703 .73908 .27921 .75669 .27014 .74796 .24884 Mtetra
.675 .612 .777 r
.74796 .24884 .75669 .27014 .77429 .26011 .76567 .23977 Mtetra
.688 .628 .783 r
.76567 .23977 .77429 .26011 .79189 .24928 .7834 .22994 Mtetra
.7 .645 .791 r
.7834 .22994 .79189 .24928 .8095 .23784 .80115 .21951 Mtetra
.663 .741 .908 r
.16549 .3806 .17554 .38996 .18979 .38491 .17979 .3755 Mtetra
.17979 .3755 .18979 .38491 .20412 .37984 .19416 .37037 Mtetra
.19416 .37037 .20412 .37984 .21853 .37475 .20862 .36521 Mtetra
.20862 .36521 .21853 .37475 .23302 .36964 .22315 .36004 Mtetra
.663 .74 .908 r
.22315 .36004 .23302 .36964 .24758 .36451 .23777 .35484 Mtetra
.662 .74 .908 r
.23777 .35484 .24758 .36451 .26223 .35938 .25247 .34964 Mtetra
.662 .739 .908 r
.25247 .34964 .26223 .35938 .27696 .35425 .26725 .34442 Mtetra
.661 .738 .907 r
.26725 .34442 .27696 .35425 .29177 .34913 .28211 .3392 Mtetra
.66 .737 .907 r
.28211 .3392 .29177 .34913 .30666 .34405 .29705 .334 Mtetra
.658 .735 .907 r
.29705 .334 .30666 .34405 .32163 .33901 .31208 .32883 Mtetra
.656 .733 .906 r
.31208 .32883 .32163 .33901 .33668 .33406 .32719 .3237 Mtetra
.654 .73 .905 r
.32719 .3237 .33668 .33406 .35182 .3292 .34238 .31863 Mtetra
.65 .725 .904 r
.34238 .31863 .35182 .3292 .36704 .32449 .35766 .31367 Mtetra
.646 .72 .902 r
.35766 .31367 .36704 .32449 .38234 .31996 .37302 .30883 Mtetra
.641 .713 .9 r
.37302 .30883 .38234 .31996 .39773 .31565 .38847 .30414 Mtetra
.635 .705 .896 r
.38847 .30414 .39773 .31565 .41321 .31161 .40401 .29966 Mtetra
.629 .695 .892 r
.40401 .29966 .41321 .31161 .42878 .30789 .41965 .29541 Mtetra
.621 .683 .887 r
.41965 .29541 .42878 .30789 .44445 .30451 .43537 .29143 Mtetra
.613 .67 .881 r
.43537 .29143 .44445 .30451 .46023 .30151 .4512 .28775 Mtetra
.605 .655 .873 r
.4512 .28775 .46023 .30151 .47612 .29892 .46714 .28438 Mtetra
.597 .64 .864 r
.46714 .28438 .47612 .29892 .49213 .29672 .48319 .28134 Mtetra
.589 .625 .855 r
.48319 .28134 .49213 .29672 .50827 .2949 .49936 .27862 Mtetra
.582 .609 .845 r
.49936 .27862 .50827 .2949 .52455 .29342 .51566 .2762 Mtetra
.577 .595 .834 r
.51566 .2762 .52455 .29342 .54096 .2922 .53209 .27401 Mtetra
.573 .582 .824 r
.53209 .27401 .54096 .2922 .55753 .29113 .54866 .272 Mtetra
.572 .571 .814 r
.54866 .272 .55753 .29113 .57425 .2901 .56538 .27006 Mtetra
.572 .562 .804 r
.56538 .27006 .57425 .2901 .59111 .28894 .58223 .26807 Mtetra
.575 .556 .796 r
.58223 .26807 .59111 .28894 .60813 .2875 .59923 .26592 Mtetra
.58 .553 .789 r
.59923 .26592 .60813 .2875 .62528 .2856 .61637 .26346 Mtetra
.586 .553 .784 r
.61637 .26346 .62528 .2856 .64255 .28309 .63363 .26055 Mtetra
.595 .555 .779 r
.63363 .26055 .64255 .28309 .65994 .2798 .65102 .25706 Mtetra
.605 .559 .777 r
.65102 .25706 .65994 .2798 .67743 .27561 .66851 .25287 Mtetra
.616 .566 .775 r
.66851 .25287 .67743 .27561 .69499 .27044 .68608 .24789 Mtetra
.628 .575 .776 r
.68608 .24789 .69499 .27044 .71261 .26425 .70374 .24208 Mtetra
.64 .586 .777 r
.70374 .24208 .71261 .26425 .73027 .25703 .72145 .2354 Mtetra
.653 .598 .78 r
.72145 .2354 .73027 .25703 .74796 .24884 .73922 .22789 Mtetra
.666 .611 .784 r
.73922 .22789 .74796 .24884 .76567 .23977 .75703 .2196 Mtetra
.678 .626 .79 r
.75703 .2196 .76567 .23977 .7834 .22994 .77487 .21061 Mtetra
.689 .641 .796 r
.77487 .21061 .7834 .22994 .80115 .21951 .79274 .20106 Mtetra
.663 .741 .908 r
.15534 .37114 .16549 .3806 .17979 .3755 .16968 .36599 Mtetra
.16968 .36599 .17979 .3755 .19416 .37037 .1841 .3608 Mtetra
.1841 .3608 .19416 .37037 .20862 .36521 .1986 .35559 Mtetra
.1986 .35559 .20862 .36521 .22315 .36004 .21319 .35035 Mtetra
.21319 .35035 .22315 .36004 .23777 .35484 .22785 .34509 Mtetra
.663 .74 .908 r
.22785 .34509 .23777 .35484 .25247 .34964 .2426 .33981 Mtetra
.662 .74 .908 r
.2426 .33981 .25247 .34964 .26725 .34442 .25743 .33452 Mtetra
.662 .739 .908 r
.25743 .33452 .26725 .34442 .28211 .3392 .27234 .32922 Mtetra
.661 .738 .907 r
.27234 .32922 .28211 .3392 .29705 .334 .28734 .32391 Mtetra
.66 .737 .907 r
.28734 .32391 .29705 .334 .31208 .32883 .30242 .31862 Mtetra
.659 .735 .907 r
.30242 .31862 .31208 .32883 .32719 .3237 .31759 .31334 Mtetra
.657 .733 .906 r
.31759 .31334 .32719 .3237 .34238 .31863 .33284 .30811 Mtetra
.654 .73 .905 r
.33284 .30811 .34238 .31863 .35766 .31367 .34818 .30294 Mtetra
.651 .726 .904 r
.34818 .30294 .35766 .31367 .37302 .30883 .3636 .29785 Mtetra
.648 .721 .902 r
.3636 .29785 .37302 .30883 .38847 .30414 .37911 .29286 Mtetra
.643 .714 .899 r
.37911 .29286 .38847 .30414 .40401 .29966 .39471 .28802 Mtetra
.638 .707 .896 r
.39471 .28802 .40401 .29966 .41965 .29541 .4104 .28335 Mtetra
.632 .697 .892 r
.4104 .28335 .41965 .29541 .43537 .29143 .42619 .27888 Mtetra
.626 .687 .887 r
.42619 .27888 .43537 .29143 .4512 .28775 .44208 .27463 Mtetra
.619 .675 .881 r
.44208 .27463 .4512 .28775 .46714 .28438 .45807 .27062 Mtetra
.612 .662 .874 r
.45807 .27062 .46714 .28438 .48319 .28134 .47416 .26688 Mtetra
.605 .648 .866 r
.47416 .26688 .48319 .28134 .49936 .27862 .49038 .26339 Mtetra
.599 .634 .858 r
.49038 .26339 .49936 .27862 .51566 .2762 .50671 .26015 Mtetra
.593 .621 .848 r
.50671 .26015 .51566 .2762 .53209 .27401 .52317 .25713 Mtetra
.589 .608 .839 r
.52317 .25713 .53209 .27401 .54866 .272 .53975 .25426 Mtetra
.586 .597 .83 r
.53975 .25426 .54866 .272 .56538 .27006 .55648 .2515 Mtetra
.586 .587 .821 r
.55648 .2515 .56538 .27006 .58223 .26807 .57334 .24874 Mtetra
.587 .58 .812 r
.57334 .24874 .58223 .26807 .59923 .26592 .59033 .2459 Mtetra
.589 .575 .805 r
.59033 .2459 .59923 .26592 .61637 .26346 .60747 .24285 Mtetra
.594 .572 .799 r
.60747 .24285 .61637 .26346 .63363 .26055 .62473 .23949 Mtetra
.6 .572 .794 r
.62473 .23949 .63363 .26055 .65102 .25706 .64211 .2357 Mtetra
.608 .574 .79 r
.64211 .2357 .65102 .25706 .66851 .25287 .65961 .23138 Mtetra
.617 .578 .788 r
.65961 .23138 .66851 .25287 .68608 .24789 .6772 .22644 Mtetra
.627 .585 .788 r
.6772 .22644 .68608 .24789 .70374 .24208 .69489 .22084 Mtetra
.637 .593 .788 r
.69489 .22084 .70374 .24208 .72145 .2354 .71265 .21453 Mtetra
.648 .603 .79 r
.71265 .21453 .72145 .2354 .73922 .22789 .73048 .20752 Mtetra
.659 .615 .794 r
.73048 .20752 .73922 .22789 .75703 .2196 .74837 .19983 Mtetra
.669 .627 .798 r
.74837 .19983 .75703 .2196 .77487 .21061 .7663 .19154 Mtetra
.679 .64 .804 r
.7663 .19154 .77487 .21061 .79274 .20106 .78429 .18271 Mtetra
.663 .741 .908 r
.14508 .36159 .15534 .37114 .16968 .36599 .15947 .35638 Mtetra
.15947 .35638 .16968 .36599 .1841 .3608 .17394 .35114 Mtetra
.17394 .35114 .1841 .3608 .1986 .35559 .18848 .34587 Mtetra
.18848 .34587 .1986 .35559 .21319 .35035 .20312 .34057 Mtetra
.20312 .34057 .21319 .35035 .22785 .34509 .21783 .33525 Mtetra
.21783 .33525 .22785 .34509 .2426 .33981 .23263 .3299 Mtetra
.663 .74 .908 r
.23263 .3299 .2426 .33981 .25743 .33452 .24751 .32454 Mtetra
.662 .74 .908 r
.24751 .32454 .25743 .33452 .27234 .32922 .26247 .31915 Mtetra
.662 .739 .907 r
.26247 .31915 .27234 .32922 .28734 .32391 .27752 .31376 Mtetra
.661 .738 .907 r
.27752 .31376 .28734 .32391 .30242 .31862 .29266 .30836 Mtetra
.66 .737 .907 r
.29266 .30836 .30242 .31862 .31759 .31334 .30788 .30297 Mtetra
.659 .736 .906 r
.30788 .30297 .31759 .31334 .33284 .30811 .32319 .2976 Mtetra
.657 .733 .906 r
.32319 .2976 .33284 .30811 .34818 .30294 .33858 .29225 Mtetra
.655 .73 .905 r
.33858 .29225 .34818 .30294 .3636 .29785 .35407 .28696 Mtetra
.652 .727 .903 r
.35407 .28696 .3636 .29785 .37911 .29286 .36964 .28174 Mtetra
.649 .722 .902 r
.36964 .28174 .37911 .29286 .39471 .28802 .3853 .27661 Mtetra
.645 .716 .899 r
.3853 .27661 .39471 .28802 .4104 .28335 .40105 .2716 Mtetra
.641 .709 .896 r
.40105 .2716 .4104 .28335 .42619 .27888 .4169 .26673 Mtetra
.636 .701 .893 r
.4169 .26673 .42619 .27888 .44208 .27463 .43285 .26202 Mtetra
.63 .691 .888 r
.43285 .26202 .44208 .27463 .45807 .27062 .44889 .2575 Mtetra
.624 .68 .883 r
.44889 .2575 .45807 .27062 .47416 .26688 .46504 .25317 Mtetra
.619 .669 .876 r
.46504 .25317 .47416 .26688 .49038 .26339 .4813 .24905 Mtetra
.613 .657 .869 r
.4813 .24905 .49038 .26339 .50671 .26015 .49768 .24512 Mtetra
.608 .645 .861 r
.49768 .24512 .50671 .26015 .52317 .25713 .51417 .24137 Mtetra
.604 .633 .853 r
.51417 .24137 .52317 .25713 .53975 .25426 .53079 .23777 Mtetra
.601 .622 .845 r
.53079 .23777 .53975 .25426 .55648 .2515 .54753 .23427 Mtetra
.599 .612 .836 r
.54753 .23427 .55648 .2515 .57334 .24874 .56441 .23081 Mtetra
.599 .604 .828 r
.56441 .23081 .57334 .24874 .59033 .2459 .58142 .22731 Mtetra
.6 .598 .821 r
.58142 .22731 .59033 .2459 .60747 .24285 .59856 .22369 Mtetra
.603 .593 .815 r
.59856 .22369 .60747 .24285 .62473 .23949 .61582 .21986 Mtetra
.607 .591 .809 r
.61582 .21986 .62473 .23949 .64211 .2357 .63322 .21572 Mtetra
.613 .592 .805 r
.63322 .21572 .64211 .2357 .65961 .23138 .65073 .21118 Mtetra
.619 .594 .803 r
.65073 .21118 .65961 .23138 .6772 .22644 .66834 .20618 Mtetra
.627 .598 .801 r
.66834 .20618 .6772 .22644 .69489 .22084 .68606 .20065 Mtetra
.636 .604 .801 r
.68606 .20065 .69489 .22084 .71265 .21453 .70386 .19456 Mtetra
.645 .612 .802 r
.70386 .19456 .71265 .21453 .73048 .20752 .72175 .18789 Mtetra
.654 .621 .804 r
.72175 .18789 .73048 .20752 .74837 .19983 .73971 .18065 Mtetra
.663 .632 .808 r
.73971 .18065 .74837 .19983 .7663 .19154 .75773 .17288 Mtetra
.672 .643 .812 r
.75773 .17288 .7663 .19154 .78429 .18271 .77581 .16464 Mtetra
.664 .741 .908 r
.13472 .35194 .14508 .36159 .15947 .35638 .14915 .34667 Mtetra
.663 .741 .908 r
.14915 .34667 .15947 .35638 .17394 .35114 .16366 .34137 Mtetra
.16366 .34137 .17394 .35114 .18848 .34587 .17826 .33604 Mtetra
.17826 .33604 .18848 .34587 .20312 .34057 .19294 .33069 Mtetra
.19294 .33069 .20312 .34057 .21783 .33525 .2077 .32531 Mtetra
.2077 .32531 .21783 .33525 .23263 .3299 .22255 .3199 Mtetra
.22255 .3199 .23263 .3299 .24751 .32454 .23748 .31446 Mtetra
.663 .74 .908 r
.23748 .31446 .24751 .32454 .26247 .31915 .2525 .30901 Mtetra
.662 .74 .908 r
.2525 .30901 .26247 .31915 .27752 .31376 .2676 .30353 Mtetra
.662 .739 .907 r
.2676 .30353 .27752 .31376 .29266 .30836 .28279 .29805 Mtetra
.661 .739 .907 r
.28279 .29805 .29266 .30836 .30788 .30297 .29807 .29255 Mtetra
.66 .737 .907 r
.29807 .29255 .30788 .30297 .32319 .2976 .31343 .28706 Mtetra
.659 .736 .906 r
.31343 .28706 .32319 .2976 .33858 .29225 .32888 .28158 Mtetra
.658 .734 .906 r
.32888 .28158 .33858 .29225 .35407 .28696 .34443 .27612 Mtetra
.656 .731 .905 r
.34443 .27612 .35407 .28696 .36964 .28174 .36006 .27071 Mtetra
.653 .727 .903 r
.36006 .27071 .36964 .28174 .3853 .27661 .37578 .26535 Mtetra
.651 .723 .902 r
.37578 .26535 .3853 .27661 .40105 .2716 .39159 .26007 Mtetra
.647 .718 .9 r
.39159 .26007 .40105 .2716 .4169 .26673 .4075 .25488 Mtetra
.643 .711 .897 r
.4075 .25488 .4169 .26673 .43285 .26202 .42351 .2498 Mtetra
.639 .704 .893 r
.42351 .2498 .43285 .26202 .44889 .2575 .43961 .24486 Mtetra
.635 .696 .889 r
.43961 .24486 .44889 .2575 .46504 .25317 .45582 .24006 Mtetra
.63 .686 .884 r
.45582 .24006 .46504 .25317 .4813 .24905 .47213 .23541 Mtetra
.625 .676 .879 r
.47213 .23541 .4813 .24905 .49768 .24512 .48856 .23092 Mtetra
.621 .666 .872 r
.48856 .23092 .49768 .24512 .51417 .24137 .50509 .22656 Mtetra
.617 .655 .865 r
.50509 .22656 .51417 .24137 .53079 .23777 .52175 .22234 Mtetra
.614 .645 .858 r
.52175 .22234 .53079 .23777 .54753 .23427 .53853 .2182 Mtetra
.611 .636 .851 r
.53853 .2182 .54753 .23427 .56441 .23081 .55543 .21412 Mtetra
.61 .628 .844 r
.55543 .21412 .56441 .23081 .58142 .22731 .57246 .21003 Mtetra
.61 .621 .837 r
.57246 .21003 .58142 .22731 .59856 .22369 .58962 .20587 Mtetra
.612 .616 .831 r
.58962 .20587 .59856 .22369 .61582 .21986 .60691 .20156 Mtetra
.614 .612 .825 r
.60691 .20156 .61582 .21986 .63322 .21572 .62432 .19705 Mtetra
.618 .611 .821 r
.62432 .19705 .63322 .21572 .65073 .21118 .64185 .19225 Mtetra
.624 .611 .817 r
.64185 .19225 .65073 .21118 .66834 .20618 .65949 .1871 Mtetra
.63 .613 .815 r
.65949 .1871 .66834 .20618 .68606 .20065 .67723 .18154 Mtetra
.636 .618 .814 r
.67723 .18154 .68606 .20065 .70386 .19456 .69508 .17554 Mtetra
.644 .623 .815 r
.69508 .17554 .70386 .19456 .72175 .18789 .71302 .16907 Mtetra
.652 .631 .816 r
.71302 .16907 .72175 .18789 .73971 .18065 .73104 .16214 Mtetra
.659 .639 .819 r
.73104 .16214 .73971 .18065 .75773 .17288 .74914 .15476 Mtetra
.667 .648 .822 r
.74914 .15476 .75773 .17288 .77581 .16464 .76732 .14697 Mtetra
.664 .741 .908 r
.12424 .34218 .13472 .35194 .14915 .34667 .13872 .33686 Mtetra
.13872 .33686 .14915 .34667 .16366 .34137 .15328 .33151 Mtetra
.663 .741 .908 r
.15328 .33151 .16366 .34137 .17826 .33604 .16792 .32612 Mtetra
.16792 .32612 .17826 .33604 .19294 .33069 .18265 .32071 Mtetra
.18265 .32071 .19294 .33069 .2077 .32531 .19746 .31526 Mtetra
.19746 .31526 .2077 .32531 .22255 .3199 .21236 .30979 Mtetra
.21236 .30979 .22255 .3199 .23748 .31446 .22734 .30429 Mtetra
.22734 .30429 .23748 .31446 .2525 .30901 .24241 .29877 Mtetra
.663 .74 .908 r
.24241 .29877 .2525 .30901 .2676 .30353 .25757 .29322 Mtetra
.25757 .29322 .2676 .30353 .28279 .29805 .27281 .28765 Mtetra
.662 .739 .907 r
.27281 .28765 .28279 .29805 .29807 .29255 .28814 .28207 Mtetra
.661 .739 .907 r
.28814 .28207 .29807 .29255 .31343 .28706 .30356 .27647 Mtetra
.661 .738 .907 r
.30356 .27647 .31343 .28706 .32888 .28158 .31907 .27088 Mtetra
.66 .736 .906 r
.31907 .27088 .32888 .28158 .34443 .27612 .33468 .26529 Mtetra
.658 .734 .906 r
.33468 .26529 .34443 .27612 .36006 .27071 .35037 .25971 Mtetra
.657 .732 .905 r
.35037 .25971 .36006 .27071 .37578 .26535 .36615 .25417 Mtetra
.655 .729 .904 r
.36615 .25417 .37578 .26535 .39159 .26007 .38203 .24867 Mtetra
.652 .725 .902 r
.38203 .24867 .39159 .26007 .4075 .25488 .398 .24323 Mtetra
.649 .72 .9 r
.398 .24323 .4075 .25488 .42351 .2498 .41406 .23786 Mtetra
.646 .714 .897 r
.41406 .23786 .42351 .2498 .43961 .24486 .43023 .23258 Mtetra
.643 .708 .894 r
.43023 .23258 .43961 .24486 .45582 .24006 .44649 .2274 Mtetra
.639 .7 .891 r
.44649 .2274 .45582 .24006 .47213 .23541 .46286 .22233 Mtetra
.635 .692 .886 r
.46286 .22233 .47213 .23541 .48856 .23092 .47934 .21737 Mtetra
.631 .684 .881 r
.47934 .21737 .48856 .23092 .50509 .22656 .49593 .21252 Mtetra
.628 .675 .876 r
.49593 .21252 .50509 .22656 .52175 .22234 .51263 .20777 Mtetra
.625 .666 .87 r
.51263 .20777 .52175 .22234 .53853 .2182 .52945 .20309 Mtetra
.622 .658 .864 r
.52945 .20309 .53853 .2182 .55543 .21412 .5464 .19847 Mtetra
.621 .65 .857 r
.5464 .19847 .55543 .21412 .57246 .21003 .56346 .19385 Mtetra
.62 .643 .851 r
.56346 .19385 .57246 .21003 .58962 .20587 .58065 .1892 Mtetra
.621 .637 .845 r
.58065 .1892 .58962 .20587 .60691 .20156 .59796 .18446 Mtetra
.622 .633 .84 r
.59796 .18446 .60691 .20156 .62432 .19705 .6154 .17957 Mtetra
.625 .63 .836 r
.6154 .17957 .62432 .19705 .64185 .19225 .63295 .17448 Mtetra
.629 .629 .832 r
.63295 .17448 .64185 .19225 .65949 .1871 .65062 .16913 Mtetra
.633 .63 .83 r
.65062 .16913 .65949 .1871 .67723 .18154 .66841 .16347 Mtetra
.638 .633 .828 r
.66841 .16347 .67723 .18154 .69508 .17554 .6863 .15747 Mtetra
.644 .637 .828 r
.6863 .15747 .69508 .17554 .71302 .16907 .70429 .1511 Mtetra
.65 .642 .828 r
.70429 .1511 .71302 .16907 .73104 .16214 .72237 .14436 Mtetra
.657 .648 .83 r
.72237 .14436 .73104 .16214 .74914 .15476 .74054 .13724 Mtetra
.663 .656 .833 r
.74054 .13724 .74914 .15476 .76732 .14697 .7588 .12977 Mtetra
.664 .741 .908 r
.11366 .33233 .12424 .34218 .13872 .33686 .12818 .32695 Mtetra
.12818 .32695 .13872 .33686 .15328 .33151 .14279 .32154 Mtetra
.14279 .32154 .15328 .33151 .16792 .32612 .15748 .31609 Mtetra
.663 .741 .908 r
.15748 .31609 .16792 .32612 .18265 .32071 .17226 .31062 Mtetra
.17226 .31062 .18265 .32071 .19746 .31526 .18712 .30512 Mtetra
.18712 .30512 .19746 .31526 .21236 .30979 .20206 .29959 Mtetra
.20206 .29959 .21236 .30979 .22734 .30429 .2171 .29402 Mtetra
.2171 .29402 .22734 .30429 .24241 .29877 .23222 .28843 Mtetra
.23222 .28843 .24241 .29877 .25757 .29322 .24743 .28281 Mtetra
.663 .74 .908 r
.24743 .28281 .25757 .29322 .27281 .28765 .26273 .27717 Mtetra
.26273 .27717 .27281 .28765 .28814 .28207 .27811 .2715 Mtetra
.662 .74 .907 r
.27811 .2715 .28814 .28207 .30356 .27647 .29359 .26582 Mtetra
.662 .739 .907 r
.29359 .26582 .30356 .27647 .31907 .27088 .30916 .26012 Mtetra
.661 .738 .907 r
.30916 .26012 .31907 .27088 .33468 .26529 .32481 .25442 Mtetra
.66 .737 .906 r
.32481 .25442 .33468 .26529 .35037 .25971 .34056 .24871 Mtetra
.659 .735 .906 r
.34056 .24871 .35037 .25971 .36615 .25417 .35641 .24302 Mtetra
.657 .733 .905 r
.35641 .24302 .36615 .25417 .38203 .24867 .37234 .23734 Mtetra
.656 .73 .904 r
.37234 .23734 .38203 .24867 .398 .24323 .38838 .2317 Mtetra
.654 .726 .902 r
.38838 .2317 .398 .24323 .41406 .23786 .40451 .2261 Mtetra
.651 .722 .901 r
.40451 .2261 .41406 .23786 .43023 .23258 .42073 .22055 Mtetra
.649 .717 .898 r
.42073 .22055 .43023 .23258 .44649 .2274 .43706 .21507 Mtetra
.646 .712 .895 r
.43706 .21507 .44649 .2274 .46286 .22233 .45349 .20966 Mtetra
.643 .705 .892 r
.45349 .20966 .46286 .22233 .47934 .21737 .47003 .20432 Mtetra
.64 .699 .888 r
.47003 .20432 .47934 .21737 .49593 .21252 .48667 .19906 Mtetra
.637 .691 .884 r
.48667 .19906 .49593 .21252 .51263 .20777 .50343 .19388 Mtetra
.634 .684 .879 r
.50343 .19388 .51263 .20777 .52945 .20309 .5203 .18876 Mtetra
.632 .677 .874 r
.5203 .18876 .52945 .20309 .5464 .19847 .53729 .18367 Mtetra
.63 .67 .869 r
.53729 .18367 .5464 .19847 .56346 .19385 .55439 .17861 Mtetra
.629 .663 .864 r
.55439 .17861 .56346 .19385 .58065 .1892 .57162 .17352 Mtetra
.629 .657 .859 r
.57162 .17352 .58065 .1892 .59796 .18446 .58897 .16838 Mtetra
.63 .653 .854 r
.58897 .16838 .59796 .18446 .6154 .17957 .60644 .16314 Mtetra
.631 .65 .85 r
.60644 .16314 .6154 .17957 .63295 .17448 .62403 .15775 Mtetra
.634 .648 .846 r
.62403 .15775 .63295 .17448 .65062 .16913 .64174 .15217 Mtetra
.637 .647 .844 r
.64174 .15217 .65062 .16913 .66841 .16347 .65956 .14637 Mtetra
.641 .648 .842 r
.65956 .14637 .66841 .16347 .6863 .15747 .6775 .1403 Mtetra
.645 .651 .841 r
.6775 .1403 .6863 .15747 .70429 .1511 .69554 .13395 Mtetra
.65 .654 .841 r
.69554 .13395 .70429 .1511 .72237 .14436 .71368 .12729 Mtetra
.655 .659 .842 r
.71368 .12729 .72237 .14436 .74054 .13724 .73193 .12034 Mtetra
.661 .665 .844 r
.73193 .12034 .74054 .13724 .7588 .12977 .75026 .11309 Mtetra
.664 .741 .908 r
.10296 .32237 .11366 .33233 .12818 .32695 .11753 .31693 Mtetra
.11753 .31693 .12818 .32695 .14279 .32154 .13219 .31146 Mtetra
.13219 .31146 .14279 .32154 .15748 .31609 .14693 .30596 Mtetra
.14693 .30596 .15748 .31609 .17226 .31062 .16175 .30043 Mtetra
.663 .741 .908 r
.16175 .30043 .17226 .31062 .18712 .30512 .17666 .29487 Mtetra
.17666 .29487 .18712 .30512 .20206 .29959 .19166 .28927 Mtetra
.19166 .28927 .20206 .29959 .2171 .29402 .20674 .28365 Mtetra
.20674 .28365 .2171 .29402 .23222 .28843 .22191 .27799 Mtetra
.22191 .27799 .23222 .28843 .24743 .28281 .23718 .2723 Mtetra
.23718 .2723 .24743 .28281 .26273 .27717 .25253 .26659 Mtetra
.25253 .26659 .26273 .27717 .27811 .2715 .26797 .26085 Mtetra
.663 .74 .908 r
.26797 .26085 .27811 .2715 .29359 .26582 .2835 .25508 Mtetra
.662 .74 .907 r
.2835 .25508 .29359 .26582 .30916 .26012 .29912 .24929 Mtetra
.662 .739 .907 r
.29912 .24929 .30916 .26012 .32481 .25442 .31484 .24349 Mtetra
.661 .738 .907 r
.31484 .24349 .32481 .25442 .34056 .24871 .33065 .23768 Mtetra
.66 .737 .906 r
.33065 .23768 .34056 .24871 .35641 .24302 .34655 .23186 Mtetra
.659 .735 .906 r
.34655 .23186 .35641 .24302 .37234 .23734 .36255 .22604 Mtetra
.658 .733 .905 r
.36255 .22604 .37234 .23734 .38838 .2317 .37865 .22023 Mtetra
.657 .731 .904 r
.37865 .22023 .38838 .2317 .40451 .2261 .39484 .21444 Mtetra
.655 .728 .903 r
.39484 .21444 .40451 .2261 .42073 .22055 .41113 .20868 Mtetra
.653 .724 .901 r
.41113 .20868 .42073 .22055 .43706 .21507 .42752 .20295 Mtetra
.651 .72 .899 r
.42752 .20295 .43706 .21507 .45349 .20966 .44401 .19727 Mtetra
.649 .716 .897 r
.44401 .19727 .45349 .20966 .47003 .20432 .46061 .19163 Mtetra
.646 .71 .894 r
.46061 .19163 .47003 .20432 .48667 .19906 .47731 .18605 Mtetra
.644 .705 .891 r
.47731 .18605 .48667 .19906 .50343 .19388 .49413 .18051 Mtetra
.642 .699 .887 r
.49413 .18051 .50343 .19388 .5203 .18876 .51105 .17502 Mtetra
.64 .693 .883 r
.51105 .17502 .5203 .18876 .53729 .18367 .52809 .16955 Mtetra
.638 .687 .879 r
.52809 .16955 .53729 .18367 .55439 .17861 .54525 .1641 Mtetra
.637 .681 .875 r
.54525 .1641 .55439 .17861 .57162 .17352 .56252 .15864 Mtetra
.637 .676 .87 r
.56252 .15864 .57162 .17352 .58897 .16838 .57992 .15314 Mtetra
.637 .671 .866 r
.57992 .15314 .58897 .16838 .60644 .16314 .59743 .14757 Mtetra
.638 .668 .863 r
.59743 .14757 .60644 .16314 .62403 .15775 .61507 .1419 Mtetra
.639 .665 .859 r
.61507 .1419 .62403 .15775 .64174 .15217 .63282 .13609 Mtetra
.641 .664 .857 r
.63282 .13609 .64174 .15217 .65956 .14637 .65069 .13011 Mtetra
.644 .664 .854 r
.65069 .13011 .65956 .14637 .6775 .1403 .66867 .12393 Mtetra
.647 .665 .853 r
.66867 .12393 .6775 .1403 .69554 .13395 .68677 .11753 Mtetra
.651 .667 .853 r
.68677 .11753 .69554 .13395 .71368 .12729 .70497 .1109 Mtetra
.655 .671 .853 r
.70497 .1109 .71368 .12729 .73193 .12034 .72328 .10402 Mtetra
.659 .675 .854 r
.72328 .10402 .73193 .12034 .75026 .11309 .74169 .09691 Mtetra
.664 .741 .908 r
.09215 .31231 .10296 .32237 .11753 .31693 .10677 .30681 Mtetra
.10677 .30681 .11753 .31693 .13219 .31146 .12147 .30128 Mtetra
.12147 .30128 .13219 .31146 .14693 .30596 .13626 .29572 Mtetra
.13626 .29572 .14693 .30596 .16175 .30043 .15113 .29013 Mtetra
.15113 .29013 .16175 .30043 .17666 .29487 .16609 .2845 Mtetra
.16609 .2845 .17666 .29487 .19166 .28927 .18114 .27885 Mtetra
.663 .741 .908 r
.18114 .27885 .19166 .28927 .20674 .28365 .19627 .27316 Mtetra
.19627 .27316 .20674 .28365 .22191 .27799 .2115 .26744 Mtetra
.2115 .26744 .22191 .27799 .23718 .2723 .22681 .26169 Mtetra
.22681 .26169 .23718 .2723 .25253 .26659 .24222 .2559 Mtetra
.24222 .2559 .25253 .26659 .26797 .26085 .25771 .25009 Mtetra
.25771 .25009 .26797 .26085 .2835 .25508 .2733 .24425 Mtetra
.663 .74 .908 r
.2733 .24425 .2835 .25508 .29912 .24929 .28898 .23838 Mtetra
.662 .74 .907 r
.28898 .23838 .29912 .24929 .31484 .24349 .30475 .23249 Mtetra
.662 .739 .907 r
.30475 .23249 .31484 .24349 .33065 .23768 .32062 .22658 Mtetra
.662 .738 .907 r
.32062 .22658 .33065 .23768 .34655 .23186 .33659 .22065 Mtetra
.661 .737 .907 r
.33659 .22065 .34655 .23186 .36255 .22604 .35265 .21471 Mtetra
.66 .736 .906 r
.35265 .21471 .36255 .22604 .37865 .22023 .3688 .20876 Mtetra
.659 .734 .905 r
.3688 .20876 .37865 .22023 .39484 .21444 .38506 .20282 Mtetra
.658 .732 .904 r
.38506 .20282 .39484 .21444 .41113 .20868 .40141 .19689 Mtetra
.656 .73 .903 r
.40141 .19689 .41113 .20868 .42752 .20295 .41786 .19096 Mtetra
.655 .727 .902 r
.41786 .19096 .42752 .20295 .44401 .19727 .43442 .18506 Mtetra
.653 .723 .9 r
.43442 .18506 .44401 .19727 .46061 .19163 .45108 .17919 Mtetra
.651 .719 .898 r
.45108 .17919 .46061 .19163 .47731 .18605 .46785 .17334 Mtetra
.65 .715 .896 r
.46785 .17334 .47731 .18605 .49413 .18051 .48472 .16751 Mtetra
.648 .71 .893 r
.48472 .16751 .49413 .18051 .51105 .17502 .50171 .16172 Mtetra
.646 .705 .89 r
.50171 .16172 .51105 .17502 .52809 .16955 .5188 .15594 Mtetra
.645 .701 .887 r
.5188 .15594 .52809 .16955 .54525 .1641 .53602 .15016 Mtetra
.644 .696 .883 r
.53602 .15016 .54525 .1641 .56252 .15864 .55335 .14438 Mtetra
.643 .691 .88 r
.55335 .14438 .56252 .15864 .57992 .15314 .57079 .13857 Mtetra
.643 .687 .877 r
.57079 .13857 .57992 .15314 .59743 .14757 .58836 .13271 Mtetra
.643 .684 .873 r
.58836 .13271 .59743 .14757 .61507 .1419 .60604 .12677 Mtetra
.644 .681 .87 r
.60604 .12677 .61507 .1419 .63282 .13609 .62385 .12074 Mtetra
.645 .679 .868 r
.62385 .12074 .63282 .13609 .65069 .13011 .64177 .11457 Mtetra
.647 .679 .866 r
.64177 .11457 .65069 .13011 .66867 .12393 .65981 .10826 Mtetra
.65 .679 .864 r
.65981 .10826 .66867 .12393 .68677 .11753 .67796 .10178 Mtetra
.652 .68 .864 r
.67796 .10178 .68677 .11753 .70497 .1109 .69623 .09511 Mtetra
.655 .682 .863 r
.69623 .09511 .70497 .1109 .72328 .10402 .7146 .08825 Mtetra
.659 .685 .864 r
.7146 .08825 .72328 .10402 .74169 .09691 .73309 .0812 Mtetra
.664 .741 .908 r
.08123 .30213 .09215 .31231 .10677 .30681 .09589 .29658 Mtetra
.09589 .29658 .10677 .30681 .12147 .30128 .11064 .29099 Mtetra
.11064 .29099 .12147 .30128 .13626 .29572 .12548 .28537 Mtetra
.12548 .28537 .13626 .29572 .15113 .29013 .1404 .27972 Mtetra
.1404 .27972 .15113 .29013 .16609 .2845 .15541 .27403 Mtetra
.15541 .27403 .16609 .2845 .18114 .27885 .1705 .26831 Mtetra
.1705 .26831 .18114 .27885 .19627 .27316 .18569 .26256 Mtetra
.663 .741 .908 r
.18569 .26256 .19627 .27316 .2115 .26744 .20097 .25677 Mtetra
.20097 .25677 .2115 .26744 .22681 .26169 .21633 .25096 Mtetra
.21633 .25096 .22681 .26169 .24222 .2559 .23179 .24511 Mtetra
.23179 .24511 .24222 .2559 .25771 .25009 .24734 .23922 Mtetra
.24734 .23922 .25771 .25009 .2733 .24425 .26299 .23331 Mtetra
.26299 .23331 .2733 .24425 .28898 .23838 .27872 .22736 Mtetra
.663 .74 .908 r
.27872 .22736 .28898 .23838 .30475 .23249 .29456 .22139 Mtetra
.663 .74 .907 r
.29456 .22139 .30475 .23249 .32062 .22658 .31048 .21539 Mtetra
.662 .739 .907 r
.31048 .21539 .32062 .22658 .33659 .22065 .32651 .20937 Mtetra
.32651 .20937 .33659 .22065 .35265 .21471 .34263 .20332 Mtetra
.661 .738 .907 r
.34263 .20332 .35265 .21471 .3688 .20876 .35884 .19727 Mtetra
.661 .737 .906 r
.35884 .19727 .3688 .20876 .38506 .20282 .37516 .19119 Mtetra
.66 .735 .906 r
.37516 .19119 .38506 .20282 .40141 .19689 .39158 .18512 Mtetra
.659 .733 .905 r
.39158 .18512 .40141 .19689 .41786 .19096 .40809 .17903 Mtetra
.658 .731 .904 r
.40809 .17903 .41786 .19096 .43442 .18506 .42472 .17296 Mtetra
.656 .729 .903 r
.42472 .17296 .43442 .18506 .45108 .17919 .44144 .16688 Mtetra
.655 .726 .901 r
.44144 .16688 .45108 .17919 .46785 .17334 .45827 .16082 Mtetra
.654 .723 .899 r
.45827 .16082 .46785 .17334 .48472 .16751 .47521 .15477 Mtetra
.652 .719 .897 r
.47521 .15477 .48472 .16751 .50171 .16172 .49226 .14872 Mtetra
.651 .716 .895 r
.49226 .14872 .50171 .16172 .5188 .15594 .50942 .14268 Mtetra
.65 .712 .893 r
.50942 .14268 .5188 .15594 .53602 .15016 .52669 .13664 Mtetra
.649 .708 .89 r
.52669 .13664 .53602 .15016 .55335 .14438 .54408 .13059 Mtetra
.648 .704 .887 r
.54408 .13059 .55335 .14438 .57079 .13857 .56158 .12451 Mtetra
.648 .701 .885 r
.56158 .12451 .57079 .13857 .58836 .13271 .57921 .11839 Mtetra
.648 .698 .882 r
.57921 .11839 .58836 .13271 .60604 .12677 .59695 .11222 Mtetra
.648 .695 .88 r
.59695 .11222 .60604 .12677 .62385 .12074 .61481 .10597 Mtetra
.649 .693 .877 r
.61481 .10597 .62385 .12074 .64177 .11457 .63279 .09962 Mtetra
.65 .692 .876 r
.63279 .09962 .64177 .11457 .65981 .10826 .65089 .09316 Mtetra
.652 .692 .874 r
.65089 .09316 .65981 .10826 .67796 .10178 .6691 .08657 Mtetra
.654 .692 .873 r
.6691 .08657 .67796 .10178 .69623 .09511 .68743 .07983 Mtetra
.656 .693 .873 r
.68743 .07983 .69623 .09511 .7146 .08825 .70588 .07294 Mtetra
.659 .695 .873 r
.70588 .07294 .7146 .08825 .73309 .0812 .72444 .06589 Mtetra
.664 .741 .908 r
.07019 .29185 .08123 .30213 .09589 .29658 .0849 .28624 Mtetra
.0849 .28624 .09589 .29658 .11064 .29099 .09969 .28059 Mtetra
.09969 .28059 .11064 .29099 .12548 .28537 .11458 .27491 Mtetra
.11458 .27491 .12548 .28537 .1404 .27972 .12955 .26919 Mtetra
.12955 .26919 .1404 .27972 .15541 .27403 .14461 .26344 Mtetra
.14461 .26344 .15541 .27403 .1705 .26831 .15975 .25766 Mtetra
.15975 .25766 .1705 .26831 .18569 .26256 .17499 .25185 Mtetra
.17499 .25185 .18569 .26256 .20097 .25677 .19032 .246 Mtetra
.663 .741 .908 r
.19032 .246 .20097 .25677 .21633 .25096 .20574 .24011 Mtetra
.20574 .24011 .21633 .25096 .23179 .24511 .22125 .23419 Mtetra
.22125 .23419 .23179 .24511 .24734 .23922 .23686 .22824 Mtetra
.23686 .22824 .24734 .23922 .26299 .23331 .25256 .22226 Mtetra
.25256 .22226 .26299 .23331 .27872 .22736 .26835 .21624 Mtetra
.26835 .21624 .27872 .22736 .29456 .22139 .28424 .21019 Mtetra
.663 .74 .908 r
.28424 .21019 .29456 .22139 .31048 .21539 .30023 .20411 Mtetra
.30023 .20411 .31048 .21539 .32651 .20937 .31631 .198 Mtetra
.662 .74 .907 r
.31631 .198 .32651 .20937 .34263 .20332 .33249 .19186 Mtetra
.662 .739 .907 r
.33249 .19186 .34263 .20332 .35884 .19727 .34877 .1857 Mtetra
.662 .738 .907 r
.34877 .1857 .35884 .19727 .37516 .19119 .36515 .17952 Mtetra
.661 .737 .906 r
.36515 .17952 .37516 .19119 .39158 .18512 .38163 .17332 Mtetra
.66 .736 .906 r
.38163 .17332 .39158 .18512 .40809 .17903 .39821 .16711 Mtetra
.66 .735 .905 r
.39821 .16711 .40809 .17903 .42472 .17296 .4149 .16088 Mtetra
.659 .733 .904 r
.4149 .16088 .42472 .17296 .44144 .16688 .43169 .15465 Mtetra
.658 .731 .903 r
.43169 .15465 .44144 .16688 .45827 .16082 .44859 .14841 Mtetra
.657 .729 .902 r
.44859 .14841 .45827 .16082 .47521 .15477 .46559 .14216 Mtetra
.656 .726 .901 r
.46559 .14216 .47521 .15477 .49226 .14872 .4827 .13592 Mtetra
.655 .723 .899 r
.4827 .13592 .49226 .14872 .50942 .14268 .49993 .12966 Mtetra
.654 .72 .897 r
.49993 .12966 .50942 .14268 .52669 .13664 .51727 .1234 Mtetra
.653 .717 .895 r
.51727 .1234 .52669 .13664 .54408 .13059 .53472 .11712 Mtetra
.652 .714 .893 r
.53472 .11712 .54408 .13059 .56158 .12451 .55229 .11082 Mtetra
.652 .711 .891 r
.55229 .11082 .56158 .12451 .57921 .11839 .56997 .10448 Mtetra
.652 .709 .889 r
.56997 .10448 .57921 .11839 .59695 .11222 .58777 .09809 Mtetra
.652 .707 .887 r
.58777 .09809 .59695 .11222 .61481 .10597 .6057 .09164 Mtetra
.652 .705 .885 r
.6057 .09164 .61481 .10597 .63279 .09962 .62374 .08512 Mtetra
.653 .703 .884 r
.62374 .08512 .63279 .09962 .65089 .09316 .6419 .07851 Mtetra
.654 .703 .882 r
.6419 .07851 .65089 .09316 .6691 .08657 .66018 .07179 Mtetra
.656 .703 .881 r
.66018 .07179 .6691 .08657 .68743 .07983 .67858 .06496 Mtetra
.657 .703 .881 r
.67858 .06496 .68743 .07983 .70588 .07294 .6971 .05801 Mtetra
.659 .704 .881 r
.6971 .05801 .70588 .07294 .72444 .06589 .71573 .05093 Mtetra
.664 .741 .908 r
.05902 .28146 .07019 .29185 .0849 .28624 .07378 .27578 Mtetra
.07378 .27578 .0849 .28624 .09969 .28059 .08863 .27007 Mtetra
.08863 .27007 .09969 .28059 .11458 .27491 .10356 .26433 Mtetra
.10356 .26433 .11458 .27491 .12955 .26919 .11858 .25855 Mtetra
.11858 .25855 .12955 .26919 .14461 .26344 .13369 .25274 Mtetra
.13369 .25274 .14461 .26344 .15975 .25766 .14888 .2469 Mtetra
.14888 .2469 .15975 .25766 .17499 .25185 .16417 .24102 Mtetra
.16417 .24102 .17499 .25185 .19032 .246 .17956 .2351 Mtetra
.17956 .2351 .19032 .246 .20574 .24011 .19503 .22915 Mtetra
.663 .741 .908 r
.19503 .22915 .20574 .24011 .22125 .23419 .2106 .22316 Mtetra
.2106 .22316 .22125 .23419 .23686 .22824 .22626 .21714 Mtetra
.22626 .21714 .23686 .22824 .25256 .22226 .24201 .21109 Mtetra
.24201 .21109 .25256 .22226 .26835 .21624 .25786 .205 Mtetra
.25786 .205 .26835 .21624 .28424 .21019 .27381 .19887 Mtetra
.27381 .19887 .28424 .21019 .30023 .20411 .28985 .19271 Mtetra
.28985 .19271 .30023 .20411 .31631 .198 .306 .18652 Mtetra
.663 .74 .908 r
.306 .18652 .31631 .198 .33249 .19186 .32224 .1803 Mtetra
.663 .74 .907 r
.32224 .1803 .33249 .19186 .34877 .1857 .33858 .17405 Mtetra
.662 .739 .907 r
.33858 .17405 .34877 .1857 .36515 .17952 .35502 .16777 Mtetra
.35502 .16777 .36515 .17952 .38163 .17332 .37157 .16146 Mtetra
.662 .738 .907 r
.37157 .16146 .38163 .17332 .39821 .16711 .38821 .15514 Mtetra
.661 .737 .906 r
.38821 .15514 .39821 .16711 .4149 .16088 .40496 .14879 Mtetra
.66 .736 .906 r
.40496 .14879 .4149 .16088 .43169 .15465 .42182 .14242 Mtetra
.66 .734 .905 r
.42182 .14242 .43169 .15465 .44859 .14841 .43879 .13603 Mtetra
.659 .733 .904 r
.43879 .13603 .44859 .14841 .46559 .14216 .45586 .12963 Mtetra
.658 .731 .903 r
.45586 .12963 .46559 .14216 .4827 .13592 .47304 .12321 Mtetra
.658 .729 .902 r
.47304 .12321 .4827 .13592 .49993 .12966 .49033 .11678 Mtetra
.657 .727 .901 r
.49033 .11678 .49993 .12966 .51727 .1234 .50773 .11033 Mtetra
.656 .724 .899 r
.50773 .11033 .51727 .1234 .53472 .11712 .52525 .10386 Mtetra
.656 .722 .898 r
.52525 .10386 .53472 .11712 .55229 .11082 .54289 .09737 Mtetra
.655 .72 .896 r
.54289 .09737 .55229 .11082 .56997 .10448 .56064 .09083 Mtetra
.655 .718 .895 r
.56064 .09083 .56997 .10448 .58777 .09809 .57851 .08426 Mtetra
.655 .716 .893 r
.57851 .08426 .58777 .09809 .6057 .09164 .5965 .07763 Mtetra
.655 .714 .892 r
.5965 .07763 .6057 .09164 .62374 .08512 .6146 .07095 Mtetra
.656 .713 .89 r
.6146 .07095 .62374 .08512 .6419 .07851 .63283 .06419 Mtetra
.656 .712 .889 r
.63283 .06419 .6419 .07851 .66018 .07179 .65118 .05734 Mtetra
.657 .712 .888 r
.65118 .05734 .66018 .07179 .67858 .06496 .66965 .05041 Mtetra
.658 .712 .888 r
.66965 .05041 .67858 .06496 .6971 .05801 .68824 .04337 Mtetra
.659 .712 .887 r
.68824 .04337 .6971 .05801 .71573 .05093 .70695 .03623 Mtetra
.664 .741 .908 r
.04774 .27095 .05902 .28146 .07378 .27578 .06255 .26522 Mtetra
.06255 .26522 .07378 .27578 .08863 .27007 .07744 .25944 Mtetra
.07744 .25944 .08863 .27007 .10356 .26433 .09242 .25364 Mtetra
.09242 .25364 .10356 .26433 .11858 .25855 .10749 .2478 Mtetra
.10749 .2478 .11858 .25855 .13369 .25274 .12265 .24192 Mtetra
.12265 .24192 .13369 .25274 .14888 .2469 .1379 .23601 Mtetra
.1379 .23601 .14888 .2469 .16417 .24102 .15324 .23006 Mtetra
.15324 .23006 .16417 .24102 .17956 .2351 .16867 .22408 Mtetra
.16867 .22408 .17956 .2351 .19503 .22915 .1842 .21807 Mtetra
.1842 .21807 .19503 .22915 .2106 .22316 .19982 .21201 Mtetra
.663 .741 .908 r
.19982 .21201 .2106 .22316 .22626 .21714 .21553 .20592 Mtetra
.21553 .20592 .22626 .21714 .24201 .21109 .23135 .1998 Mtetra
.23135 .1998 .24201 .21109 .25786 .205 .24725 .19363 Mtetra
.24725 .19363 .25786 .205 .27381 .19887 .26326 .18744 Mtetra
.26326 .18744 .27381 .19887 .28985 .19271 .27936 .1812 Mtetra
.27936 .1812 .28985 .19271 .306 .18652 .29556 .17493 Mtetra
.29556 .17493 .306 .18652 .32224 .1803 .31187 .16863 Mtetra
.663 .74 .908 r
.31187 .16863 .32224 .1803 .33858 .17405 .32827 .16229 Mtetra
.663 .74 .907 r
.32827 .16229 .33858 .17405 .35502 .16777 .34478 .15592 Mtetra
.34478 .15592 .35502 .16777 .37157 .16146 .36138 .14952 Mtetra
.662 .739 .907 r
.36138 .14952 .37157 .16146 .38821 .15514 .3781 .14309 Mtetra
.3781 .14309 .38821 .15514 .40496 .14879 .39491 .13663 Mtetra
.662 .738 .906 r
.39491 .13663 .40496 .14879 .42182 .14242 .41184 .13015 Mtetra
.661 .737 .906 r
.41184 .13015 .42182 .14242 .43879 .13603 .42887 .12364 Mtetra
.661 .736 .905 r
.42887 .12364 .43879 .13603 .45586 .12963 .44601 .1171 Mtetra
.66 .734 .905 r
.44601 .1171 .45586 .12963 .47304 .12321 .46326 .11054 Mtetra
.66 .733 .904 r
.46326 .11054 .47304 .12321 .49033 .11678 .48062 .10396 Mtetra
.659 .731 .903 r
.48062 .10396 .49033 .11678 .50773 .11033 .49809 .09736 Mtetra
.658 .73 .902 r
.49809 .09736 .50773 .11033 .52525 .10386 .51568 .09072 Mtetra
.658 .728 .901 r
.51568 .09072 .52525 .10386 .54289 .09737 .53338 .08406 Mtetra
.658 .726 .9 r
.53338 .08406 .54289 .09737 .56064 .09083 .5512 .07736 Mtetra
.657 .725 .899 r
.5512 .07736 .56064 .09083 .57851 .08426 .56914 .07062 Mtetra
.657 .723 .897 r
.56914 .07062 .57851 .08426 .5965 .07763 .5872 .06384 Mtetra
.657 .722 .896 r
.5872 .06384 .5965 .07763 .6146 .07095 .60538 .057 Mtetra
.658 .721 .895 r
.60538 .057 .6146 .07095 .63283 .06419 .62368 .05009 Mtetra
.658 .72 .894 r
.62368 .05009 .63283 .06419 .65118 .05734 .6421 .04312 Mtetra
.658 .719 .893 r
.6421 .04312 .65118 .05734 .66965 .05041 .66065 .03607 Mtetra
.659 .719 .893 r
.66065 .03607 .66965 .05041 .68824 .04337 .67931 .02894 Mtetra
.66 .719 .893 r
.67931 .02894 .68824 .04337 .70695 .03623 .6981 .02172 Mtetra
.664 .741 .908 r
.03634 .26033 .04774 .27095 .06255 .26522 .05119 .25453 Mtetra
.05119 .25453 .06255 .26522 .07744 .25944 .06613 .2487 Mtetra
.06613 .2487 .07744 .25944 .09242 .25364 .08116 .24283 Mtetra
.08116 .24283 .09242 .25364 .10749 .2478 .09628 .23692 Mtetra
.09628 .23692 .10749 .2478 .12265 .24192 .11148 .23098 Mtetra
.11148 .23098 .12265 .24192 .1379 .23601 .12679 .225 Mtetra
.12679 .225 .1379 .23601 .15324 .23006 .14218 .21899 Mtetra
.14218 .21899 .15324 .23006 .16867 .22408 .15767 .21294 Mtetra
.15767 .21294 .16867 .22408 .1842 .21807 .17325 .20686 Mtetra
.17325 .20686 .1842 .21807 .19982 .21201 .18892 .20074 Mtetra
.18892 .20074 .19982 .21201 .21553 .20592 .20469 .19458 Mtetra
.20469 .19458 .21553 .20592 .23135 .1998 .22056 .18838 Mtetra
.663 .741 .908 r
.22056 .18838 .23135 .1998 .24725 .19363 .23652 .18215 Mtetra
.23652 .18215 .24725 .19363 .26326 .18744 .25259 .17588 Mtetra
.25259 .17588 .26326 .18744 .27936 .1812 .26875 .16957 Mtetra
.26875 .16957 .27936 .1812 .29556 .17493 .28501 .16322 Mtetra
.28501 .16322 .29556 .17493 .31187 .16863 .30138 .15684 Mtetra
.30138 .15684 .31187 .16863 .32827 .16229 .31784 .15042 Mtetra
.31784 .15042 .32827 .16229 .34478 .15592 .33441 .14397 Mtetra
.663 .74 .908 r
.33441 .14397 .34478 .15592 .36138 .14952 .35108 .13748 Mtetra
.663 .74 .907 r
.35108 .13748 .36138 .14952 .3781 .14309 .36786 .13095 Mtetra
.36786 .13095 .3781 .14309 .39491 .13663 .38475 .12439 Mtetra
.662 .739 .907 r
.38475 .12439 .39491 .13663 .41184 .13015 .40174 .1178 Mtetra
.662 .738 .907 r
.40174 .1178 .41184 .13015 .42887 .12364 .41883 .11118 Mtetra
.662 .738 .906 r
.41883 .11118 .42887 .12364 .44601 .1171 .43604 .10453 Mtetra
.661 .737 .906 r
.43604 .10453 .44601 .1171 .46326 .11054 .45336 .09785 Mtetra
.661 .736 .905 r
.45336 .09785 .46326 .11054 .48062 .10396 .47079 .09114 Mtetra
.66 .735 .905 r
.47079 .09114 .48062 .10396 .49809 .09736 .48834 .0844 Mtetra
.66 .733 .904 r
.48834 .0844 .49809 .09736 .51568 .09072 .506 .07762 Mtetra
.66 .732 .903 r
.506 .07762 .51568 .09072 .53338 .08406 .52377 .07081 Mtetra
.659 .731 .902 r
.52377 .07081 .53338 .08406 .5512 .07736 .54166 .06397 Mtetra
.659 .73 .902 r
.54166 .06397 .5512 .07736 .56914 .07062 .55968 .05708 Mtetra
.659 .729 .901 r
.55968 .05708 .56914 .07062 .5872 .06384 .57781 .05015 Mtetra
.659 .727 .9 r
.57781 .05015 .5872 .06384 .60538 .057 .59606 .04317 Mtetra
.659 .726 .899 r
.59606 .04317 .60538 .057 .62368 .05009 .61443 .03614 Mtetra
.659 .726 .898 r
.61443 .03614 .62368 .05009 .6421 .04312 .63293 .02904 Mtetra
.66 .725 .898 r
.63293 .02904 .6421 .04312 .66065 .03607 .65155 .02188 Mtetra
.66 .725 .897 r
.65155 .02188 .66065 .03607 .67931 .02894 .67029 .01464 Mtetra
.661 .725 .897 r
.67029 .01464 .67931 .02894 .6981 .02172 .68916 .00733 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .795 .945 r
.39701 .60379 .40493 .60922 .4181 .60509 .41023 .59962 Mtetra
.667 .796 .943 r
.41023 .59962 .4181 .60509 .43133 .60086 .42351 .59532 Mtetra
.671 .796 .941 r
.42351 .59532 .43133 .60086 .44463 .59654 .43686 .59091 Mtetra
.673 .794 .939 r
.43686 .59091 .44463 .59654 .45799 .59216 .45027 .5864 Mtetra
.675 .792 .936 r
.45027 .5864 .45799 .59216 .47141 .58772 .46375 .58181 Mtetra
.677 .789 .934 r
.46375 .58181 .47141 .58772 .4849 .58325 .47729 .57717 Mtetra
.678 .785 .931 r
.47729 .57717 .4849 .58325 .49845 .57875 .49089 .57249 Mtetra
.678 .781 .928 r
.49089 .57249 .49845 .57875 .51206 .57424 .50456 .5678 Mtetra
.677 .776 .925 r
.50456 .5678 .51206 .57424 .52574 .56974 .51829 .56311 Mtetra
.676 .772 .923 r
.51829 .56311 .52574 .56974 .53949 .56524 .53208 .55843 Mtetra
.675 .768 .92 r
.53208 .55843 .53949 .56524 .5533 .56077 .54594 .55378 Mtetra
.674 .764 .918 r
.54594 .55378 .5533 .56077 .56718 .55631 .55986 .54917 Mtetra
.673 .76 .916 r
.55986 .54917 .56718 .55631 .58112 .55188 .57386 .54458 Mtetra
.671 .756 .914 r
.57386 .54458 .58112 .55188 .59514 .54746 .58792 .54003 Mtetra
.67 .753 .913 r
.58792 .54003 .59514 .54746 .60922 .54306 .60205 .5355 Mtetra
.669 .751 .912 r
.60205 .5355 .60922 .54306 .62338 .53867 .61626 .53101 Mtetra
.668 .749 .911 r
.61626 .53101 .62338 .53867 .63761 .53429 .63053 .52653 Mtetra
.667 .747 .91 r
.63053 .52653 .63761 .53429 .65191 .52991 .64488 .52207 Mtetra
.666 .746 .91 r
.64488 .52207 .65191 .52991 .66628 .52553 .65931 .51761 Mtetra
.665 .744 .909 r
.65931 .51761 .66628 .52553 .68073 .52115 .6738 .51316 Mtetra
.6738 .51316 .68073 .52115 .69525 .51676 .68838 .50871 Mtetra
.665 .743 .909 r
.68838 .50871 .69525 .51676 .70985 .51235 .70302 .50424 Mtetra
.664 .742 .908 r
.70302 .50424 .70985 .51235 .72452 .50793 .71775 .49977 Mtetra
.71775 .49977 .72452 .50793 .73927 .5035 .73255 .49528 Mtetra
.73255 .49528 .73927 .5035 .75409 .49904 .74743 .49078 Mtetra
.74743 .49078 .75409 .49904 .76899 .49456 .76239 .48625 Mtetra
.76239 .48625 .76899 .49456 .78397 .49006 .77742 .48171 Mtetra
.664 .741 .908 r
.77742 .48171 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47256 Mtetra
.80773 .47256 .81417 .481 .82939 .47644 .823 .46794 Mtetra
.823 .46794 .82939 .47644 .84469 .47185 .83836 .46331 Mtetra
.83836 .46331 .84469 .47185 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.66 .809 .955 r
.389 .59877 .39701 .60379 .41023 .59962 .40226 .59459 Mtetra
.665 .811 .953 r
.40226 .59459 .41023 .59962 .42351 .59532 .4156 .59023 Mtetra
.67 .811 .951 r
.4156 .59023 .42351 .59532 .43686 .59091 .429 .58573 Mtetra
.674 .81 .948 r
.429 .58573 .43686 .59091 .45027 .5864 .44247 .58108 Mtetra
.677 .808 .945 r
.44247 .58108 .45027 .5864 .46375 .58181 .456 .57633 Mtetra
.68 .804 .942 r
.456 .57633 .46375 .58181 .47729 .57717 .46959 .5715 Mtetra
.681 .8 .938 r
.46959 .5715 .47729 .57717 .49089 .57249 .48325 .56661 Mtetra
.682 .795 .935 r
.48325 .56661 .49089 .57249 .50456 .5678 .49697 .5617 Mtetra
.682 .789 .931 r
.49697 .5617 .50456 .5678 .51829 .56311 .51075 .55678 Mtetra
.681 .784 .928 r
.51075 .55678 .51829 .56311 .53208 .55843 .5246 .55188 Mtetra
.68 .778 .925 r
.5246 .55188 .53208 .55843 .54594 .55378 .53851 .54702 Mtetra
.678 .773 .922 r
.53851 .54702 .54594 .55378 .55986 .54917 .55248 .54219 Mtetra
.676 .768 .919 r
.55248 .54219 .55986 .54917 .57386 .54458 .56653 .53742 Mtetra
.675 .763 .917 r
.56653 .53742 .57386 .54458 .58792 .54003 .58064 .53269 Mtetra
.673 .759 .915 r
.58064 .53269 .58792 .54003 .60205 .5355 .59482 .52802 Mtetra
.671 .755 .914 r
.59482 .52802 .60205 .5355 .61626 .53101 .60907 .52338 Mtetra
.67 .752 .912 r
.60907 .52338 .61626 .53101 .63053 .52653 .6234 .51878 Mtetra
.668 .75 .911 r
.6234 .51878 .63053 .52653 .64488 .52207 .6378 .51421 Mtetra
.667 .748 .91 r
.6378 .51421 .64488 .52207 .65931 .51761 .65227 .50967 Mtetra
.666 .746 .91 r
.65227 .50967 .65931 .51761 .6738 .51316 .66682 .50513 Mtetra
.666 .745 .909 r
.66682 .50513 .6738 .51316 .68838 .50871 .68144 .5006 Mtetra
.665 .744 .909 r
.68144 .5006 .68838 .50871 .70302 .50424 .69614 .49608 Mtetra
.665 .743 .909 r
.69614 .49608 .70302 .50424 .71775 .49977 .71091 .49154 Mtetra
.664 .743 .908 r
.71091 .49154 .71775 .49977 .73255 .49528 .72577 .487 Mtetra
.664 .742 .908 r
.72577 .487 .73255 .49528 .74743 .49078 .7407 .48244 Mtetra
.7407 .48244 .74743 .49078 .76239 .48625 .75571 .47787 Mtetra
.75571 .47787 .76239 .48625 .77742 .48171 .7708 .47328 Mtetra
.7708 .47328 .77742 .48171 .79253 .47714 .78597 .46866 Mtetra
.664 .741 .908 r
.78597 .46866 .79253 .47714 .80773 .47256 .80122 .46403 Mtetra
.80122 .46403 .80773 .47256 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.652 .824 .966 r
.38088 .59422 .389 .59877 .40226 .59459 .39419 .59006 Mtetra
.66 .828 .964 r
.39419 .59006 .40226 .59459 .4156 .59023 .40758 .58568 Mtetra
.667 .829 .962 r
.40758 .58568 .4156 .59023 .429 .58573 .42104 .5811 Mtetra
.673 .829 .958 r
.42104 .5811 .429 .58573 .44247 .58108 .43456 .57633 Mtetra
.678 .827 .955 r
.43456 .57633 .44247 .58108 .456 .57633 .44815 .5714 Mtetra
.682 .823 .951 r
.44815 .5714 .456 .57633 .46959 .5715 .46181 .56636 Mtetra
.685 .818 .947 r
.46181 .56636 .46959 .5715 .48325 .56661 .47552 .56123 Mtetra
.687 .813 .942 r
.47552 .56123 .48325 .56661 .49697 .5617 .4893 .55606 Mtetra
.687 .806 .938 r
.4893 .55606 .49697 .5617 .51075 .55678 .50314 .55087 Mtetra
.687 .799 .934 r
.50314 .55087 .51075 .55678 .5246 .55188 .51704 .5457 Mtetra
.686 .792 .93 r
.51704 .5457 .5246 .55188 .53851 .54702 .531 .54056 Mtetra
.684 .785 .927 r
.531 .54056 .53851 .54702 .55248 .54219 .54503 .53548 Mtetra
.682 .778 .924 r
.54503 .53548 .55248 .54219 .56653 .53742 .55913 .53046 Mtetra
.679 .772 .921 r
.55913 .53046 .56653 .53742 .58064 .53269 .57329 .52552 Mtetra
.677 .766 .918 r
.57329 .52552 .58064 .53269 .59482 .52802 .58752 .52064 Mtetra
.675 .761 .916 r
.58752 .52064 .59482 .52802 .60907 .52338 .60182 .51583 Mtetra
.673 .757 .914 r
.60182 .51583 .60907 .52338 .6234 .51878 .6162 .51108 Mtetra
.671 .754 .913 r
.6162 .51108 .6234 .51878 .6378 .51421 .63064 .50638 Mtetra
.669 .751 .912 r
.63064 .50638 .6378 .51421 .65227 .50967 .64516 .50171 Mtetra
.668 .748 .911 r
.64516 .50171 .65227 .50967 .66682 .50513 .65976 .49708 Mtetra
.667 .747 .91 r
.65976 .49708 .66682 .50513 .68144 .5006 .67444 .49246 Mtetra
.666 .745 .909 r
.67444 .49246 .68144 .5006 .69614 .49608 .68919 .48786 Mtetra
.665 .744 .909 r
.68919 .48786 .69614 .49608 .71091 .49154 .70402 .48326 Mtetra
.665 .743 .909 r
.70402 .48326 .71091 .49154 .72577 .487 .71892 .47865 Mtetra
.664 .743 .908 r
.71892 .47865 .72577 .487 .7407 .48244 .73391 .47404 Mtetra
.664 .742 .908 r
.73391 .47404 .7407 .48244 .75571 .47787 .74898 .46941 Mtetra
.74898 .46941 .75571 .47787 .7708 .47328 .76412 .46477 Mtetra
.76412 .46477 .7708 .47328 .78597 .46866 .77935 .4601 Mtetra
.77935 .4601 .78597 .46866 .80122 .46403 .79466 .45542 Mtetra
.664 .741 .908 r
.79466 .45542 .80122 .46403 .81656 .45937 .81005 .45072 Mtetra
.81005 .45072 .81656 .45937 .83197 .45469 .82552 .44599 Mtetra
.82552 .44599 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43646 Mtetra
.85671 .43646 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.64 .84 .977 r
.37265 .59019 .38088 .59422 .39419 .59006 .38601 .58611 Mtetra
.65 .846 .975 r
.38601 .58611 .39419 .59006 .40758 .58568 .39945 .58175 Mtetra
.66 .849 .973 r
.39945 .58175 .40758 .58568 .42104 .5811 .41297 .57711 Mtetra
.669 .85 .969 r
.41297 .57711 .42104 .5811 .43456 .57633 .42655 .57223 Mtetra
.677 .849 .965 r
.42655 .57223 .43456 .57633 .44815 .5714 .4402 .56713 Mtetra
.684 .846 .961 r
.4402 .56713 .44815 .5714 .46181 .56636 .45392 .56187 Mtetra
.688 .841 .956 r
.45392 .56187 .46181 .56636 .47552 .56123 .4677 .55647 Mtetra
.692 .834 .951 r
.4677 .55647 .47552 .56123 .4893 .55606 .48154 .551 Mtetra
.693 .827 .947 r
.48154 .551 .4893 .55606 .50314 .55087 .49544 .54549 Mtetra
.694 .818 .942 r
.49544 .54549 .50314 .55087 .51704 .5457 .5094 .53998 Mtetra
.693 .809 .937 r
.5094 .53998 .51704 .5457 .531 .54056 .52342 .53452 Mtetra
.691 .8 .933 r
.52342 .53452 .531 .54056 .54503 .53548 .53751 .52912 Mtetra
.688 .792 .929 r
.53751 .52912 .54503 .53548 .55913 .53046 .55165 .52381 Mtetra
.685 .783 .925 r
.55165 .52381 .55913 .53046 .57329 .52552 .56587 .51858 Mtetra
.682 .776 .922 r
.56587 .51858 .57329 .52552 .58752 .52064 .58015 .51345 Mtetra
.679 .77 .919 r
.58015 .51345 .58752 .52064 .60182 .51583 .5945 .50842 Mtetra
.677 .764 .917 r
.5945 .50842 .60182 .51583 .6162 .51108 .60893 .50347 Mtetra
.674 .759 .915 r
.60893 .50347 .6162 .51108 .63064 .50638 .62342 .4986 Mtetra
.672 .755 .913 r
.62342 .4986 .63064 .50638 .64516 .50171 .638 .49379 Mtetra
.67 .752 .912 r
.638 .49379 .64516 .50171 .65976 .49708 .65264 .48902 Mtetra
.668 .749 .911 r
.65264 .48902 .65976 .49708 .67444 .49246 .66737 .4843 Mtetra
.667 .747 .91 r
.66737 .4843 .67444 .49246 .68919 .48786 .68217 .4796 Mtetra
.666 .745 .909 r
.68217 .4796 .68919 .48786 .70402 .48326 .69705 .47492 Mtetra
.665 .744 .909 r
.69705 .47492 .70402 .48326 .71892 .47865 .71201 .47024 Mtetra
.665 .743 .909 r
.71201 .47024 .71892 .47865 .73391 .47404 .72705 .46556 Mtetra
.664 .743 .908 r
.72705 .46556 .73391 .47404 .74898 .46941 .74217 .46088 Mtetra
.664 .742 .908 r
.74217 .46088 .74898 .46941 .76412 .46477 .75738 .45618 Mtetra
.75738 .45618 .76412 .46477 .77935 .4601 .77266 .45147 Mtetra
.77266 .45147 .77935 .4601 .79466 .45542 .78802 .44673 Mtetra
.78802 .44673 .79466 .45542 .81005 .45072 .80347 .44198 Mtetra
.664 .741 .908 r
.80347 .44198 .81005 .45072 .82552 .44599 .819 .4372 Mtetra
.819 .4372 .82552 .44599 .84107 .44123 .83462 .4324 Mtetra
.83462 .4324 .84107 .44123 .85671 .43646 .85032 .42757 Mtetra
.85032 .42757 .85671 .43646 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.62 .855 .988 r
.36429 .58673 .37265 .59019 .38601 .58611 .3777 .5828 Mtetra
.632 .864 .986 r
.3777 .5828 .38601 .58611 .39945 .58175 .3912 .57851 Mtetra
.646 .87 .983 r
.3912 .57851 .39945 .58175 .41297 .57711 .40477 .57387 Mtetra
.659 .873 .979 r
.40477 .57387 .41297 .57711 .42655 .57223 .41842 .56891 Mtetra
.671 .874 .975 r
.41842 .56891 .42655 .57223 .4402 .56713 .43214 .56365 Mtetra
.681 .872 .971 r
.43214 .56365 .4402 .56713 .45392 .56187 .44593 .55815 Mtetra
.69 .867 .966 r
.44593 .55815 .45392 .56187 .4677 .55647 .45977 .55247 Mtetra
.696 .861 .961 r
.45977 .55247 .4677 .55647 .48154 .551 .47368 .54666 Mtetra
.7 .852 .955 r
.47368 .54666 .48154 .551 .49544 .54549 .48765 .54078 Mtetra
.701 .842 .95 r
.48765 .54078 .49544 .54549 .5094 .53998 .50168 .53489 Mtetra
.701 .831 .945 r
.50168 .53489 .5094 .53998 .52342 .53452 .51576 .52903 Mtetra
.699 .82 .94 r
.51576 .52903 .52342 .53452 .53751 .52912 .5299 .52324 Mtetra
.696 .809 .935 r
.5299 .52324 .53751 .52912 .55165 .52381 .54411 .51755 Mtetra
.693 .799 .931 r
.54411 .51755 .55165 .52381 .56587 .51858 .55838 .51198 Mtetra
.689 .789 .927 r
.55838 .51198 .56587 .51858 .58015 .51345 .57271 .50653 Mtetra
.685 .781 .923 r
.57271 .50653 .58015 .51345 .5945 .50842 .58712 .50121 Mtetra
.682 .773 .92 r
.58712 .50121 .5945 .50842 .60893 .50347 .60159 .49601 Mtetra
.678 .766 .917 r
.60159 .49601 .60893 .50347 .62342 .4986 .61614 .49092 Mtetra
.675 .761 .915 r
.61614 .49092 .62342 .4986 .638 .49379 .63076 .48592 Mtetra
.673 .756 .913 r
.63076 .48592 .638 .49379 .65264 .48902 .64546 .481 Mtetra
.671 .753 .912 r
.64546 .481 .65264 .48902 .66737 .4843 .66023 .47614 Mtetra
.669 .75 .911 r
.66023 .47614 .66737 .4843 .68217 .4796 .67509 .47133 Mtetra
.668 .747 .91 r
.67509 .47133 .68217 .4796 .69705 .47492 .69002 .46655 Mtetra
.666 .746 .909 r
.69002 .46655 .69705 .47492 .71201 .47024 .70504 .46178 Mtetra
.666 .744 .909 r
.70504 .46178 .71201 .47024 .72705 .46556 .72013 .45703 Mtetra
.665 .743 .909 r
.72013 .45703 .72705 .46556 .74217 .46088 .73531 .45228 Mtetra
.665 .743 .908 r
.73531 .45228 .74217 .46088 .75738 .45618 .75056 .44752 Mtetra
.664 .742 .908 r
.75056 .44752 .75738 .45618 .77266 .45147 .7659 .44275 Mtetra
.7659 .44275 .77266 .45147 .78802 .44673 .78133 .43796 Mtetra
.78133 .43796 .78802 .44673 .80347 .44198 .79683 .43315 Mtetra
.79683 .43315 .80347 .44198 .819 .4372 .81242 .42832 Mtetra
.664 .741 .908 r
.81242 .42832 .819 .4372 .83462 .4324 .8281 .42347 Mtetra
.8281 .42347 .83462 .4324 .85032 .42757 .84386 .4186 Mtetra
.84386 .4186 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.588 .866 .994 r
.35581 .58384 .36429 .58673 .3777 .5828 .36927 .58015 Mtetra
.604 .878 .992 r
.36927 .58015 .3777 .5828 .3912 .57851 .38282 .57602 Mtetra
.621 .888 .989 r
.38282 .57602 .3912 .57851 .40477 .57387 .39645 .57144 Mtetra
.639 .895 .985 r
.39645 .57144 .40477 .57387 .41842 .56891 .41017 .56645 Mtetra
.657 .899 .981 r
.41017 .56645 .41842 .56891 .43214 .56365 .42396 .56106 Mtetra
.673 .899 .977 r
.42396 .56106 .43214 .56365 .44593 .55815 .43781 .55535 Mtetra
.687 .896 .973 r
.43781 .55535 .44593 .55815 .45977 .55247 .45174 .54937 Mtetra
.697 .89 .968 r
.45174 .54937 .45977 .55247 .47368 .54666 .46572 .54319 Mtetra
.704 .881 .963 r
.46572 .54319 .47368 .54666 .48765 .54078 .47976 .5369 Mtetra
.708 .87 .958 r
.47976 .5369 .48765 .54078 .50168 .53489 .49386 .53055 Mtetra
.71 .858 .952 r
.49386 .53055 .50168 .53489 .51576 .52903 .50801 .52423 Mtetra
.709 .844 .947 r
.50801 .52423 .51576 .52903 .5299 .52324 .52222 .51797 Mtetra
.706 .831 .942 r
.52222 .51797 .5299 .52324 .54411 .51755 .53648 .51183 Mtetra
.703 .818 .937 r
.53648 .51183 .54411 .51755 .55838 .51198 .55081 .50582 Mtetra
.698 .806 .932 r
.55081 .50582 .55838 .51198 .57271 .50653 .5652 .49998 Mtetra
.694 .795 .928 r
.5652 .49998 .57271 .50653 .58712 .50121 .57966 .4943 Mtetra
.689 .785 .924 r
.57966 .4943 .58712 .50121 .60159 .49601 .59419 .48878 Mtetra
.684 .776 .921 r
.59419 .48878 .60159 .49601 .61614 .49092 .60878 .48341 Mtetra
.68 .769 .918 r
.60878 .48341 .61614 .49092 .63076 .48592 .62346 .47817 Mtetra
.677 .762 .915 r
.62346 .47817 .63076 .48592 .64546 .481 .63821 .47304 Mtetra
.674 .757 .914 r
.63821 .47304 .64546 .481 .66023 .47614 .65303 .46801 Mtetra
.671 .753 .912 r
.65303 .46801 .66023 .47614 .67509 .47133 .66794 .46305 Mtetra
.669 .75 .911 r
.66794 .46305 .67509 .47133 .69002 .46655 .68292 .45815 Mtetra
.668 .748 .91 r
.68292 .45815 .69002 .46655 .70504 .46178 .69799 .45329 Mtetra
.667 .746 .909 r
.69799 .45329 .70504 .46178 .72013 .45703 .71314 .44844 Mtetra
.666 .745 .909 r
.71314 .44844 .72013 .45703 .73531 .45228 .72837 .44361 Mtetra
.665 .744 .909 r
.72837 .44361 .73531 .45228 .75056 .44752 .74368 .43879 Mtetra
.665 .743 .908 r
.74368 .43879 .75056 .44752 .7659 .44275 .75908 .43395 Mtetra
.664 .742 .908 r
.75908 .43395 .7659 .44275 .78133 .43796 .77456 .42911 Mtetra
.77456 .42911 .78133 .43796 .79683 .43315 .79013 .42424 Mtetra
.79013 .42424 .79683 .43315 .81242 .42832 .80578 .41936 Mtetra
.80578 .41936 .81242 .42832 .8281 .42347 .82151 .41446 Mtetra
.664 .741 .908 r
.82151 .41446 .8281 .42347 .84386 .4186 .83734 .40953 Mtetra
.83734 .40953 .84386 .4186 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38957 Mtetra
.9015 .38957 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.54 .868 .994 r
.34719 .58152 .35581 .58384 .36927 .58015 .36069 .57817 Mtetra
.559 .884 .99 r
.36069 .57817 .36927 .58015 .38282 .57602 .37429 .5743 Mtetra
.581 .898 .985 r
.37429 .5743 .38282 .57602 .39645 .57144 .38799 .56988 Mtetra
.605 .91 .982 r
.38799 .56988 .39645 .57144 .41017 .56645 .40177 .56492 Mtetra
.63 .918 .978 r
.40177 .56492 .41017 .56645 .42396 .56106 .41563 .55947 Mtetra
.654 .923 .975 r
.41563 .55947 .42396 .56106 .43781 .55535 .42957 .55357 Mtetra
.675 .923 .973 r
.42957 .55357 .43781 .55535 .45174 .54937 .44357 .5473 Mtetra
.692 .92 .97 r
.44357 .5473 .45174 .54937 .46572 .54319 .45764 .54074 Mtetra
.705 .912 .967 r
.45764 .54074 .46572 .54319 .47976 .5369 .47176 .53399 Mtetra
.714 .902 .963 r
.47176 .53399 .47976 .5369 .49386 .53055 .48593 .52714 Mtetra
.718 .888 .958 r
.48593 .52714 .49386 .53055 .50801 .52423 .50016 .52027 Mtetra
.719 .874 .953 r
.50016 .52027 .50801 .52423 .52222 .51797 .51444 .51347 Mtetra
.718 .858 .948 r
.51444 .51347 .52222 .51797 .53648 .51183 .52877 .50678 Mtetra
.714 .842 .943 r
.52877 .50678 .53648 .51183 .55081 .50582 .54317 .50025 Mtetra
.709 .827 .938 r
.54317 .50025 .55081 .50582 .5652 .49998 .55762 .49391 Mtetra
.704 .813 .933 r
.55762 .49391 .5652 .49998 .57966 .4943 .57213 .48778 Mtetra
.698 .8 .928 r
.57213 .48778 .57966 .4943 .59419 .48878 .58671 .48186 Mtetra
.692 .789 .924 r
.58671 .48186 .59419 .48878 .60878 .48341 .60136 .47614 Mtetra
.687 .779 .921 r
.60136 .47614 .60878 .48341 .62346 .47817 .61609 .47059 Mtetra
.682 .771 .918 r
.61609 .47059 .62346 .47817 .63821 .47304 .63089 .46521 Mtetra
.678 .764 .916 r
.63089 .46521 .63821 .47304 .65303 .46801 .64577 .45996 Mtetra
.675 .758 .914 r
.64577 .45996 .65303 .46801 .66794 .46305 .66072 .45482 Mtetra
.672 .754 .912 r
.66072 .45482 .66794 .46305 .68292 .45815 .67576 .44976 Mtetra
.67 .751 .911 r
.67576 .44976 .68292 .45815 .69799 .45329 .69088 .44477 Mtetra
.668 .748 .91 r
.69088 .44477 .69799 .45329 .71314 .44844 .70608 .43982 Mtetra
.667 .746 .909 r
.70608 .43982 .71314 .44844 .72837 .44361 .72137 .4349 Mtetra
.666 .745 .909 r
.72137 .4349 .72837 .44361 .74368 .43879 .73674 .42999 Mtetra
.665 .744 .909 r
.73674 .42999 .74368 .43879 .75908 .43395 .75219 .42508 Mtetra
.665 .743 .908 r
.75219 .42508 .75908 .43395 .77456 .42911 .76773 .42018 Mtetra
.664 .742 .908 r
.76773 .42018 .77456 .42911 .79013 .42424 .78336 .41525 Mtetra
.78336 .41525 .79013 .42424 .80578 .41936 .79907 .41032 Mtetra
.79907 .41032 .80578 .41936 .82151 .41446 .81486 .40536 Mtetra
.81486 .40536 .82151 .41446 .83734 .40953 .83075 .40038 Mtetra
.664 .741 .908 r
.83075 .40038 .83734 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38957 .89516 .3802 Mtetra
.89516 .3802 .9015 .38957 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.474 .856 .981 r
.33843 .57971 .34719 .58152 .36069 .57817 .35197 .57683 Mtetra
.493 .874 .973 r
.35197 .57683 .36069 .57817 .37429 .5743 .36562 .57334 Mtetra
.519 .893 .967 r
.36562 .57334 .37429 .5743 .38799 .56988 .37937 .56919 Mtetra
.55 .91 .962 r
.37937 .56919 .38799 .56988 .40177 .56492 .39322 .56438 Mtetra
.583 .925 .96 r
.39322 .56438 .40177 .56492 .41563 .55947 .40716 .55893 Mtetra
.617 .936 .959 r
.40716 .55893 .41563 .55947 .42957 .55357 .42118 .5529 Mtetra
.648 .943 .96 r
.42118 .5529 .42957 .55357 .44357 .5473 .43527 .54637 Mtetra
.675 .945 .961 r
.43527 .54637 .44357 .5473 .45764 .54074 .44942 .53944 Mtetra
.697 .942 .961 r
.44942 .53944 .45764 .54074 .47176 .53399 .46363 .53221 Mtetra
.713 .933 .961 r
.46363 .53221 .47176 .53399 .48593 .52714 .47789 .5248 Mtetra
.724 .921 .959 r
.47789 .5248 .48593 .52714 .50016 .52027 .49221 .51733 Mtetra
.729 .906 .957 r
.49221 .51733 .50016 .52027 .51444 .51347 .50657 .50989 Mtetra
.73 .889 .953 r
.50657 .50989 .51444 .51347 .52877 .50678 .52098 .50255 Mtetra
.727 .871 .948 r
.52098 .50255 .52877 .50678 .54317 .50025 .53544 .4954 Mtetra
.722 .853 .943 r
.53544 .4954 .54317 .50025 .55762 .49391 .54995 .48847 Mtetra
.716 .835 .938 r
.54995 .48847 .55762 .49391 .57213 .48778 .56453 .48179 Mtetra
.709 .819 .933 r
.56453 .48179 .57213 .48778 .58671 .48186 .57917 .47537 Mtetra
.702 .805 .929 r
.57917 .47537 .58671 .48186 .60136 .47614 .59387 .4692 Mtetra
.696 .792 .925 r
.59387 .4692 .60136 .47614 .61609 .47059 .60865 .46327 Mtetra
.689 .782 .921 r
.60865 .46327 .61609 .47059 .63089 .46521 .6235 .45756 Mtetra
.684 .773 .918 r
.6235 .45756 .63089 .46521 .64577 .45996 .63843 .45203 Mtetra
.68 .765 .916 r
.63843 .45203 .64577 .45996 .66072 .45482 .65344 .44665 Mtetra
.676 .759 .914 r
.65344 .44665 .66072 .45482 .67576 .44976 .66853 .4414 Mtetra
.673 .755 .912 r
.66853 .4414 .67576 .44976 .69088 .44477 .6837 .43625 Mtetra
.67 .751 .911 r
.6837 .43625 .69088 .44477 .70608 .43982 .69896 .43117 Mtetra
.668 .748 .91 r
.69896 .43117 .70608 .43982 .72137 .4349 .7143 .42614 Mtetra
.667 .746 .909 r
.7143 .42614 .72137 .4349 .73674 .42999 .72972 .42114 Mtetra
.666 .745 .909 r
.72972 .42114 .73674 .42999 .75219 .42508 .74524 .41615 Mtetra
.665 .744 .909 r
.74524 .41615 .75219 .42508 .76773 .42018 .76083 .41117 Mtetra
.665 .743 .908 r
.76083 .41117 .76773 .42018 .78336 .41525 .77652 .40618 Mtetra
.664 .742 .908 r
.77652 .40618 .78336 .41525 .79907 .41032 .79229 .40118 Mtetra
.79229 .40118 .79907 .41032 .81486 .40536 .80814 .39617 Mtetra
.80814 .39617 .81486 .40536 .83075 .40038 .82409 .39113 Mtetra
.82409 .39113 .83075 .40038 .84672 .39537 .84012 .38608 Mtetra
.664 .741 .908 r
.84012 .38608 .84672 .39537 .86278 .39034 .85625 .38099 Mtetra
.85625 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37075 Mtetra
.88876 .37075 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.386 .824 .953 r
.32953 .57831 .33843 .57971 .35197 .57683 .3431 .57605 Mtetra
.404 .843 .939 r
.3431 .57605 .35197 .57683 .36562 .57334 .3568 .57308 Mtetra
.433 .865 .927 r
.3568 .57308 .36562 .57334 .37937 .56919 .3706 .56934 Mtetra
.47 .887 .92 r
.3706 .56934 .37937 .56919 .39322 .56438 .38452 .5648 Mtetra
.512 .909 .918 r
.38452 .5648 .39322 .56438 .40716 .55893 .39853 .55947 Mtetra
.557 .929 .92 r
.39853 .55947 .40716 .55893 .42118 .5529 .41264 .5534 Mtetra
.601 .945 .925 r
.41264 .5534 .42118 .5529 .43527 .54637 .42682 .54667 Mtetra
.641 .957 .932 r
.42682 .54667 .43527 .54637 .44942 .53944 .44106 .53939 Mtetra
.676 .961 .939 r
.44106 .53939 .44942 .53944 .46363 .53221 .45537 .53169 Mtetra
.703 .96 .946 r
.45537 .53169 .46363 .53221 .47789 .5248 .46973 .5237 Mtetra
.723 .952 .95 r
.46973 .5237 .47789 .5248 .49221 .51733 .48413 .51556 Mtetra
.735 .939 .952 r
.48413 .51556 .49221 .51733 .50657 .50989 .49858 .5074 Mtetra
.74 .922 .952 r
.49858 .5074 .50657 .50989 .52098 .50255 .51308 .49933 Mtetra
.741 .903 .95 r
.51308 .49933 .52098 .50255 .53544 .4954 .52762 .49144 Mtetra
.737 .883 .947 r
.52762 .49144 .53544 .4954 .54995 .48847 .54221 .4838 Mtetra
.731 .862 .943 r
.54221 .4838 .54995 .48847 .56453 .48179 .55685 .47645 Mtetra
.723 .843 .938 r
.55685 .47645 .56453 .48179 .57917 .47537 .57155 .46942 Mtetra
.715 .825 .933 r
.57155 .46942 .57917 .47537 .59387 .4692 .58631 .4627 Mtetra
.707 .809 .929 r
.58631 .4627 .59387 .4692 .60865 .46327 .60114 .45629 Mtetra
.699 .795 .925 r
.60114 .45629 .60865 .46327 .6235 .45756 .61605 .45016 Mtetra
.692 .784 .921 r
.61605 .45016 .6235 .45756 .63843 .45203 .63103 .44428 Mtetra
.686 .774 .918 r
.63103 .44428 .63843 .45203 .65344 .44665 .64609 .43861 Mtetra
.681 .766 .916 r
.64609 .43861 .65344 .44665 .66853 .4414 .66123 .43312 Mtetra
.676 .76 .914 r
.66123 .43312 .66853 .4414 .6837 .43625 .67646 .42777 Mtetra
.673 .755 .912 r
.67646 .42777 .6837 .43625 .69896 .43117 .69177 .42252 Mtetra
.671 .751 .911 r
.69177 .42252 .69896 .43117 .7143 .42614 .70716 .41735 Mtetra
.669 .748 .91 r
.70716 .41735 .7143 .42614 .72972 .42114 .72264 .41224 Mtetra
.667 .746 .909 r
.72264 .41224 .72972 .42114 .74524 .41615 .73821 .40716 Mtetra
.666 .745 .909 r
.73821 .40716 .74524 .41615 .76083 .41117 .75386 .40209 Mtetra
.665 .744 .909 r
.75386 .40209 .76083 .41117 .77652 .40618 .76961 .39703 Mtetra
.665 .743 .908 r
.76961 .39703 .77652 .40618 .79229 .40118 .78544 .39197 Mtetra
.664 .742 .908 r
.78544 .39197 .79229 .40118 .80814 .39617 .80136 .38689 Mtetra
.80136 .38689 .80814 .39617 .82409 .39113 .81736 .3818 Mtetra
.81736 .3818 .82409 .39113 .84012 .38608 .83346 .37669 Mtetra
.83346 .37669 .84012 .38608 .85625 .38099 .84965 .37155 Mtetra
.664 .741 .908 r
.84965 .37155 .85625 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37075 .8823 .36119 Mtetra
.8823 .36119 .88876 .37075 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.281 .77 .909 r
.3205 .5772 .32953 .57831 .3431 .57605 .33409 .57569 Mtetra
.296 .787 .885 r
.33409 .57569 .3431 .57605 .3568 .57308 .34782 .57341 Mtetra
.324 .809 .866 r
.34782 .57341 .3568 .57308 .3706 .56934 .36167 .57024 Mtetra
.365 .836 .854 r
.36167 .57024 .3706 .56934 .38452 .5648 .37565 .56613 Mtetra
.415 .864 .85 r
.37565 .56613 .38452 .5648 .39853 .55947 .38973 .56107 Mtetra
.471 .894 .854 r
.38973 .56107 .39853 .55947 .41264 .5534 .40392 .55508 Mtetra
.529 .922 .864 r
.40392 .55508 .41264 .5534 .42682 .54667 .4182 .54824 Mtetra
.584 .945 .878 r
.4182 .54824 .42682 .54667 .44106 .53939 .43255 .54067 Mtetra
.634 .963 .895 r
.43255 .54067 .44106 .53939 .45537 .53169 .44696 .53252 Mtetra
.676 .972 .911 r
.44696 .53252 .45537 .53169 .46973 .5237 .46142 .52394 Mtetra
.709 .974 .925 r
.46142 .52394 .46973 .5237 .48413 .51556 .47593 .51509 Mtetra
.732 .967 .935 r
.47593 .51509 .48413 .51556 .49858 .5074 .49048 .50615 Mtetra
.746 .954 .942 r
.49048 .50615 .49858 .5074 .51308 .49933 .50507 .49725 Mtetra
.752 .936 .946 r
.50507 .49725 .51308 .49933 .52762 .49144 .5197 .48852 Mtetra
.752 .915 .946 r
.5197 .48852 .52762 .49144 .54221 .4838 .53437 .48005 Mtetra
.747 .893 .945 r
.53437 .48005 .54221 .4838 .55685 .47645 .54908 .47191 Mtetra
.739 .871 .941 r
.54908 .47191 .55685 .47645 .57155 .46942 .56385 .46414 Mtetra
.73 .849 .937 r
.56385 .46414 .57155 .46942 .58631 .4627 .57868 .45676 Mtetra
.72 .83 .933 r
.57868 .45676 .58631 .4627 .60114 .45629 .59357 .44976 Mtetra
.71 .813 .929 r
.59357 .44976 .60114 .45629 .61605 .45016 .60853 .44312 Mtetra
.702 .798 .925 r
.60853 .44312 .61605 .45016 .63103 .44428 .62356 .4368 Mtetra
.694 .785 .921 r
.62356 .4368 .63103 .44428 .64609 .43861 .63867 .43076 Mtetra
.687 .775 .918 r
.63867 .43076 .64609 .43861 .66123 .43312 .65387 .42496 Mtetra
.682 .767 .916 r
.65387 .42496 .66123 .43312 .67646 .42777 .66914 .41935 Mtetra
.677 .76 .914 r
.66914 .41935 .67646 .42777 .69177 .42252 .68451 .4139 Mtetra
.673 .755 .912 r
.68451 .4139 .69177 .42252 .70716 .41735 .69995 .40856 Mtetra
.671 .751 .911 r
.69995 .40856 .70716 .41735 .72264 .41224 .71549 .40331 Mtetra
.669 .748 .91 r
.71549 .40331 .72264 .41224 .73821 .40716 .73111 .39811 Mtetra
.667 .746 .909 r
.73111 .39811 .73821 .40716 .75386 .40209 .74683 .39295 Mtetra
.666 .745 .909 r
.74683 .39295 .75386 .40209 .76961 .39703 .76263 .38781 Mtetra
.665 .743 .909 r
.76263 .38781 .76961 .39703 .78544 .39197 .77852 .38267 Mtetra
.665 .743 .908 r
.77852 .38267 .78544 .39197 .80136 .38689 .7945 .37753 Mtetra
.664 .742 .908 r
.7945 .37753 .80136 .38689 .81736 .3818 .81057 .37237 Mtetra
.81057 .37237 .81736 .3818 .83346 .37669 .82673 .3672 Mtetra
.82673 .3672 .83346 .37669 .84965 .37155 .84298 .36201 Mtetra
.84298 .36201 .84965 .37155 .86593 .36638 .85933 .35678 Mtetra
.664 .741 .908 r
.85933 .35678 .86593 .36638 .8823 .36119 .87576 .35154 Mtetra
.87576 .35154 .8823 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.167 .697 .853 r
.31134 .57618 .3205 .5772 .33409 .57569 .32494 .57559 Mtetra
.176 .71 .817 r
.32494 .57559 .33409 .57569 .34782 .57341 .33868 .57415 Mtetra
.203 .731 .789 r
.33868 .57415 .34782 .57341 .36167 .57024 .35257 .57174 Mtetra
.246 .759 .77 r
.35257 .57174 .36167 .57024 .37565 .56613 .3666 .56824 Mtetra
.302 .793 .763 r
.3666 .56824 .37565 .56613 .38973 .56107 .38076 .56361 Mtetra
.366 .83 .766 r
.38076 .56361 .38973 .56107 .40392 .55508 .39503 .55786 Mtetra
.435 .869 .78 r
.39503 .55786 .40392 .55508 .4182 .54824 .4094 .55105 Mtetra
.505 .906 .8 r
.4094 .55105 .4182 .54824 .43255 .54067 .42386 .54329 Mtetra
.571 .938 .825 r
.42386 .54329 .43255 .54067 .44696 .53252 .43838 .53475 Mtetra
.63 .963 .852 r
.43838 .53475 .44696 .53252 .46142 .52394 .45296 .5256 Mtetra
.679 .978 .878 r
.45296 .5256 .46142 .52394 .47593 .51509 .46759 .51605 Mtetra
.717 .983 .9 r
.46759 .51605 .47593 .51509 .49048 .50615 .48225 .50627 Mtetra
.743 .979 .918 r
.48225 .50627 .49048 .50615 .50507 .49725 .49694 .49647 Mtetra
.759 .966 .93 r
.49694 .49647 .50507 .49725 .5197 .48852 .51167 .48679 Mtetra
.764 .948 .938 r
.51167 .48679 .5197 .48852 .53437 .48005 .52643 .47738 Mtetra
.763 .925 .941 r
.52643 .47738 .53437 .48005 .54908 .47191 .54122 .46832 Mtetra
.757 .901 .941 r
.54122 .46832 .54908 .47191 .56385 .46414 .55607 .45969 Mtetra
.747 .877 .939 r
.55607 .45969 .56385 .46414 .57868 .45676 .57096 .45151 Mtetra
.736 .854 .936 r
.57096 .45151 .57868 .45676 .59357 .44976 .58592 .44379 Mtetra
.725 .833 .932 r
.58592 .44379 .59357 .44976 .60853 .44312 .60093 .43652 Mtetra
.714 .815 .928 r
.60093 .43652 .60853 .44312 .62356 .4368 .61602 .42966 Mtetra
.704 .799 .924 r
.61602 .42966 .62356 .4368 .63867 .43076 .63119 .42316 Mtetra
.695 .786 .921 r
.63119 .42316 .63867 .43076 .65387 .42496 .64643 .41697 Mtetra
.688 .775 .918 r
.64643 .41697 .65387 .42496 .66914 .41935 .66176 .41105 Mtetra
.682 .767 .915 r
.66176 .41105 .66914 .41935 .68451 .4139 .67718 .40534 Mtetra
.677 .76 .913 r
.67718 .40534 .68451 .4139 .69995 .40856 .69268 .39979 Mtetra
.674 .755 .912 r
.69268 .39979 .69995 .40856 .71549 .40331 .70827 .39437 Mtetra
.671 .751 .911 r
.70827 .39437 .71549 .40331 .73111 .39811 .72395 .38904 Mtetra
.669 .748 .91 r
.72395 .38904 .73111 .39811 .74683 .39295 .73972 .38376 Mtetra
.667 .746 .909 r
.73972 .38376 .74683 .39295 .76263 .38781 .75558 .37852 Mtetra
.666 .744 .909 r
.75558 .37852 .76263 .38781 .77852 .38267 .77153 .3733 Mtetra
.665 .743 .908 r
.77153 .3733 .77852 .38267 .7945 .37753 .78757 .36808 Mtetra
.78757 .36808 .7945 .37753 .81057 .37237 .80371 .36286 Mtetra
.664 .742 .908 r
.80371 .36286 .81057 .37237 .82673 .3672 .81993 .35762 Mtetra
.81993 .35762 .82673 .3672 .84298 .36201 .83625 .35237 Mtetra
.83625 .35237 .84298 .36201 .85933 .35678 .85266 .34709 Mtetra
.664 .741 .908 r
.85266 .34709 .85933 .35678 .87576 .35154 .86916 .34178 Mtetra
.86916 .34178 .87576 .35154 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.053 .614 .794 r
.30206 .57504 .31134 .57618 .32494 .57559 .31565 .5755 Mtetra
.055 .621 .747 r
.31565 .5755 .32494 .57559 .33868 .57415 .3294 .57509 Mtetra
.08 .639 .709 r
.3294 .57509 .33868 .57415 .35257 .57174 .34332 .57361 Mtetra
0 0 0 r
.34332 .57361 .35257 .57174 .3666 .56824 .35739 .57092 Mtetra
.35739 .57092 .3666 .56824 .38076 .56361 .3716 .56693 Mtetra
.253 .748 .671 r
.3716 .56693 .38076 .56361 .39503 .55786 .38596 .5616 Mtetra
.331 .796 .684 r
.38596 .5616 .39503 .55786 .4094 .55105 .40042 .55499 Mtetra
.412 .844 .707 r
.40042 .55499 .4094 .55105 .42386 .54329 .41499 .5472 Mtetra
.491 .889 .738 r
.41499 .5472 .42386 .54329 .43838 .53475 .42963 .53838 Mtetra
.566 .929 .773 r
.42963 .53838 .43838 .53475 .45296 .5256 .44433 .52873 Mtetra
.632 .96 .81 r
.44433 .52873 .45296 .5256 .46759 .51605 .45908 .51848 Mtetra
.686 .98 .844 r
.45908 .51848 .46759 .51605 .48225 .50627 .47387 .50786 Mtetra
.728 .989 .875 r
.47387 .50786 .48225 .50627 .49694 .49647 .48868 .4971 Mtetra
.756 .987 .899 r
.48868 .4971 .49694 .49647 .51167 .48679 .50351 .4864 Mtetra
.771 .975 .917 r
.50351 .4864 .51167 .48679 .52643 .47738 .51838 .47593 Mtetra
.777 .956 .929 r
.51838 .47593 .52643 .47738 .54122 .46832 .53327 .46583 Mtetra
.774 .933 .935 r
.53327 .46583 .54122 .46832 .55607 .45969 .54819 .45619 Mtetra
.766 .907 .937 r
.54819 .45619 .55607 .45969 .57096 .45151 .56316 .44708 Mtetra
.754 .882 .937 r
.56316 .44708 .57096 .45151 .58592 .44379 .57819 .43851 Mtetra
.742 .858 .934 r
.57819 .43851 .58592 .44379 .60093 .43652 .59327 .43048 Mtetra
.729 .836 .931 r
.59327 .43048 .60093 .43652 .61602 .42966 .60841 .42296 Mtetra
.717 .816 .927 r
.60841 .42296 .61602 .42966 .63119 .42316 .62363 .41589 Mtetra
.706 .8 .923 r
.62363 .41589 .63119 .42316 .64643 .41697 .63893 .40924 Mtetra
.697 .786 .92 r
.63893 .40924 .64643 .41697 .66176 .41105 .65431 .40292 Mtetra
.689 .775 .917 r
.65431 .40292 .66176 .41105 .67718 .40534 .66978 .39689 Mtetra
.683 .767 .915 r
.66978 .39689 .67718 .40534 .69268 .39979 .68534 .39108 Mtetra
.678 .76 .913 r
.68534 .39108 .69268 .39979 .70827 .39437 .70098 .38545 Mtetra
.674 .755 .912 r
.70098 .38545 .70827 .39437 .72395 .38904 .71672 .37994 Mtetra
.671 .751 .911 r
.71672 .37994 .72395 .38904 .73972 .38376 .73254 .37453 Mtetra
.669 .748 .91 r
.73254 .37453 .73972 .38376 .75558 .37852 .74846 .36917 Mtetra
.667 .746 .909 r
.74846 .36917 .75558 .37852 .77153 .3733 .76447 .36386 Mtetra
.666 .744 .909 r
.76447 .36386 .77153 .3733 .78757 .36808 .78058 .35856 Mtetra
.665 .743 .908 r
.78058 .35856 .78757 .36808 .80371 .36286 .79677 .35326 Mtetra
.79677 .35326 .80371 .36286 .81993 .35762 .81306 .34795 Mtetra
.664 .742 .908 r
.81306 .34795 .81993 .35762 .83625 .35237 .82944 .34263 Mtetra
.82944 .34263 .83625 .35237 .85266 .34709 .84592 .33729 Mtetra
.84592 .33729 .85266 .34709 .86916 .34178 .86249 .33193 Mtetra
.664 .741 .908 r
.86249 .33193 .86916 .34178 .88576 .33645 .87915 .32654 Mtetra
.87915 .32654 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
0 .529 .742 r
.29267 .57353 .30206 .57504 .31565 .5755 .30624 .57517 Mtetra
.056 0 0 r
.30624 .57517 .31565 .5755 .3294 .57509 .31999 .57593 Mtetra
.035 0 0 r
.31999 .57593 .3294 .57509 .34332 .57361 .33391 .57558 Mtetra
0 0 0 r
.33391 .57558 .34332 .57361 .35739 .57092 .34801 .5739 Mtetra
.34801 .5739 .35739 .57092 .3716 .56693 .36228 .57077 Mtetra
.36228 .57077 .3716 .56693 .38596 .5616 .3767 .56609 Mtetra
.3767 .56609 .38596 .5616 .40042 .55499 .39125 .55989 Mtetra
.39125 .55989 .40042 .55499 .41499 .5472 .40593 .55224 Mtetra
.406 .826 .647 r
.40593 .55224 .41499 .5472 .42963 .53838 .42069 .54329 Mtetra
.493 .877 .686 r
.42069 .54329 .42963 .53838 .44433 .52873 .43552 .53326 Mtetra
.572 .922 .729 r
.43552 .53326 .44433 .52873 .45908 .51848 .4504 .52239 Mtetra
.642 .957 .773 r
.4504 .52239 .45908 .51848 .47387 .50786 .46532 .51095 Mtetra
.699 .981 .815 r
.46532 .51095 .47387 .50786 .48868 .4971 .48027 .49921 Mtetra
.742 .993 .852 r
.48027 .49921 .48868 .4971 .50351 .4864 .49523 .48742 Mtetra
.77 .992 .883 r
.49523 .48742 .50351 .4864 .51838 .47593 .5102 .47581 Mtetra
.785 .981 .905 r
.5102 .47581 .51838 .47593 .53327 .46583 .5252 .46455 Mtetra
.789 .962 .92 r
.5252 .46455 .53327 .46583 .54819 .45619 .54022 .45379 Mtetra
.784 .938 .929 r
.54022 .45379 .54819 .45619 .56316 .44708 .55528 .4436 Mtetra
.774 .911 .933 r
.55528 .4436 .56316 .44708 .57819 .43851 .57037 .43404 Mtetra
.761 .885 .934 r
.57037 .43404 .57819 .43851 .59327 .43048 .58552 .42511 Mtetra
.746 .859 .932 r
.58552 .42511 .59327 .43048 .60841 .42296 .60073 .4168 Mtetra
.732 .837 .929 r
.60073 .4168 .60841 .42296 .62363 .41589 .61601 .40905 Mtetra
.719 .817 .926 r
.61601 .40905 .62363 .41589 .63893 .40924 .63136 .40182 Mtetra
.707 .8 .922 r
.63136 .40182 .63893 .40924 .65431 .40292 .6468 .39502 Mtetra
.697 .786 .919 r
.6468 .39502 .65431 .40292 .66978 .39689 .66231 .38859 Mtetra
.689 .775 .917 r
.66231 .38859 .66978 .39689 .68534 .39108 .67792 .38246 Mtetra
.683 .766 .914 r
.67792 .38246 .68534 .39108 .70098 .38545 .69362 .37657 Mtetra
.677 .759 .913 r
.69362 .37657 .70098 .38545 .71672 .37994 .70941 .37085 Mtetra
.674 .754 .911 r
.70941 .37085 .71672 .37994 .73254 .37453 .7253 .36527 Mtetra
.671 .75 .91 r
.7253 .36527 .73254 .37453 .74846 .36917 .74128 .35978 Mtetra
.668 .747 .91 r
.74128 .35978 .74846 .36917 .76447 .36386 .75735 .35435 Mtetra
.667 .745 .909 r
.75735 .35435 .76447 .36386 .78058 .35856 .77351 .34895 Mtetra
.666 .744 .909 r
.77351 .34895 .78058 .35856 .79677 .35326 .78977 .34357 Mtetra
.665 .743 .908 r
.78977 .34357 .79677 .35326 .81306 .34795 .80612 .33819 Mtetra
.664 .742 .908 r
.80612 .33819 .81306 .34795 .82944 .34263 .82257 .33281 Mtetra
.82257 .33281 .82944 .34263 .84592 .33729 .83911 .3274 Mtetra
.83911 .3274 .84592 .33729 .86249 .33193 .85575 .32198 Mtetra
.85575 .32198 .86249 .33193 .87915 .32654 .87248 .31653 Mtetra
.664 .741 .908 r
.87248 .31653 .87915 .32654 .89591 .32112 .88931 .31105 Mtetra
0 .451 .702 r
.2832 .5714 .29267 .57353 .30624 .57517 .29674 .57429 Mtetra
.151 0 0 r
.29674 .57429 .30624 .57517 .31999 .57593 .31046 .57636 Mtetra
.136 0 0 r
.31046 .57636 .31999 .57593 .33391 .57558 .32437 .5773 Mtetra
.095 0 0 r
.32437 .5773 .33391 .57558 .34801 .5739 .33848 .57685 Mtetra
.033 0 0 r
.33848 .57685 .34801 .5739 .36228 .57077 .35278 .57479 Mtetra
0 0 0 r
.35278 .57479 .36228 .57077 .3767 .56609 .36726 .57101 Mtetra
.36726 .57101 .3767 .56609 .39125 .55989 .3819 .56545 Mtetra
.3819 .56545 .39125 .55989 .40593 .55224 .39667 .55817 Mtetra
.39667 .55817 .40593 .55224 .42069 .54329 .41155 .5493 Mtetra
.421 .82 .606 r
.41155 .5493 .42069 .54329 .43552 .53326 .42652 .53904 Mtetra
.51 .875 .65 r
.42652 .53904 .43552 .53326 .4504 .52239 .44154 .52767 Mtetra
.591 .921 .698 r
.44154 .52767 .4504 .52239 .46532 .51095 .4566 .51548 Mtetra
.661 .958 .746 r
.4566 .51548 .46532 .51095 .48027 .49921 .47169 .50279 Mtetra
.718 .983 .793 r
.47169 .50279 .48027 .49921 .49523 .48742 .48679 .4899 Mtetra
.759 .996 .834 r
.48679 .4899 .49523 .48742 .5102 .47581 .50189 .47709 Mtetra
.786 .995 .868 r
.50189 .47709 .5102 .47581 .5252 .46455 .51701 .46458 Mtetra
.799 .984 .895 r
.51701 .46458 .5252 .46455 .54022 .45379 .53214 .45257 Mtetra
.8 .965 .913 r
.53214 .45257 .54022 .45379 .55528 .4436 .54729 .44117 Mtetra
.793 .94 .924 r
.54729 .44117 .55528 .4436 .57037 .43404 .56247 .43048 Mtetra
.781 .912 .929 r
.56247 .43048 .57037 .43404 .58552 .42511 .57769 .42052 Mtetra
.766 .885 .931 r
.57769 .42052 .58552 .42511 .60073 .4168 .59297 .41128 Mtetra
.75 .859 .93 r
.59297 .41128 .60073 .4168 .61601 .40905 .60831 .40273 Mtetra
.734 .836 .927 r
.60831 .40273 .61601 .40905 .63136 .40182 .62372 .3948 Mtetra
.72 .816 .924 r
.62372 .3948 .63136 .40182 .6468 .39502 .63921 .38742 Mtetra
.708 .799 .921 r
.63921 .38742 .6468 .39502 .66231 .38859 .65478 .38051 Mtetra
.698 .785 .918 r
.65478 .38051 .66231 .38859 .67792 .38246 .67044 .37398 Mtetra
.689 .774 .916 r
.67044 .37398 .67792 .38246 .69362 .37657 .68619 .36777 Mtetra
.682 .765 .914 r
.68619 .36777 .69362 .37657 .70941 .37085 .70204 .3618 Mtetra
.677 .758 .912 r
.70204 .3618 .70941 .37085 .7253 .36527 .71798 .35601 Mtetra
.673 .753 .911 r
.71798 .35601 .7253 .36527 .74128 .35978 .73402 .35035 Mtetra
.67 .75 .91 r
.73402 .35035 .74128 .35978 .75735 .35435 .75015 .34479 Mtetra
.668 .747 .909 r
.75015 .34479 .75735 .35435 .77351 .34895 .76637 .33928 Mtetra
.667 .745 .909 r
.76637 .33928 .77351 .34895 .78977 .34357 .78269 .3338 Mtetra
.666 .744 .909 r
.78269 .3338 .78977 .34357 .80612 .33819 .79911 .32834 Mtetra
.665 .743 .908 r
.79911 .32834 .80612 .33819 .82257 .33281 .81562 .32288 Mtetra
.664 .742 .908 r
.81562 .32288 .82257 .33281 .83911 .3274 .83223 .31741 Mtetra
.83223 .31741 .83911 .3274 .85575 .32198 .84894 .31192 Mtetra
.84894 .31192 .85575 .32198 .87248 .31653 .86574 .30641 Mtetra
.86574 .30641 .87248 .31653 .88931 .31105 .88264 .30087 Mtetra
0 .382 .68 r
.27367 .56837 .2832 .5714 .29674 .57429 .28715 .57258 Mtetra
.228 0 0 r
.28715 .57258 .29674 .57429 .31046 .57636 .30083 .57604 Mtetra
.22 0 0 r
.30083 .57604 .31046 .57636 .32437 .5773 .31472 .57842 Mtetra
.182 0 0 r
.31472 .57842 .32437 .5773 .33848 .57685 .32882 .57936 Mtetra
.121 0 0 r
.32882 .57936 .33848 .57685 .35278 .57479 .34313 .57861 Mtetra
.041 0 0 r
.34313 .57861 .35278 .57479 .36726 .57101 .35765 .57597 Mtetra
0 0 0 r
.35765 .57597 .36726 .57101 .3819 .56545 .37235 .57132 Mtetra
.37235 .57132 .3819 .56545 .39667 .55817 .38722 .56467 Mtetra
.38722 .56467 .39667 .55817 .41155 .5493 .40222 .55611 Mtetra
.40222 .55611 .41155 .5493 .42652 .53904 .41731 .54585 Mtetra
.455 .829 .584 r
.41731 .54585 .42652 .53904 .44154 .52767 .43248 .53415 Mtetra
.544 .882 .63 r
.43248 .53415 .44154 .52767 .4566 .51548 .4477 .52134 Mtetra
.622 .928 .68 r
.4477 .52134 .4566 .51548 .47169 .50279 .46294 .50778 Mtetra
.689 .963 .73 r
.46294 .50778 .47169 .50279 .48679 .4899 .47819 .49382 Mtetra
.742 .987 .778 r
.47819 .49382 .48679 .4899 .50189 .47709 .49344 .47978 Mtetra
.779 .998 .822 r
.49344 .47978 .50189 .47709 .51701 .46458 .50868 .46596 Mtetra
.803 .997 .858 r
.50868 .46596 .51701 .46458 .53214 .45257 .52393 .45261 Mtetra
.812 .985 .886 r
.52393 .45261 .53214 .45257 .54729 .44117 .53919 .43989 Mtetra
.811 .965 .906 r
.53919 .43989 .54729 .44117 .56247 .43048 .55447 .42794 Mtetra
.801 .939 .919 r
.55447 .42794 .56247 .43048 .57769 .42052 .56978 .4168 Mtetra
.787 .911 .925 r
.56978 .4168 .57769 .42052 .59297 .41128 .58513 .4065 Mtetra
.77 .884 .928 r
.58513 .4065 .59297 .41128 .60831 .40273 .60053 .397 Mtetra
.752 .857 .927 r
.60053 .397 .60831 .40273 .62372 .3948 .616 .38826 Mtetra
.736 .834 .925 r
.616 .38826 .62372 .3948 .63921 .38742 .63155 .38018 Mtetra
.721 .814 .923 r
.63155 .38018 .63921 .38742 .65478 .38051 .64718 .37269 Mtetra
.708 .797 .92 r
.64718 .37269 .65478 .38051 .67044 .37398 .66289 .36569 Mtetra
.697 .783 .917 r
.66289 .36569 .67044 .37398 .68619 .36777 .6787 .35909 Mtetra
.689 .772 .915 r
.6787 .35909 .68619 .36777 .70204 .3618 .6946 .35281 Mtetra
.682 .764 .913 r
.6946 .35281 .70204 .3618 .71798 .35601 .71059 .34677 Mtetra
.677 .757 .912 r
.71059 .34677 .71798 .35601 .73402 .35035 .72668 .34091 Mtetra
.673 .753 .911 r
.72668 .34091 .73402 .35035 .75015 .34479 .74287 .33519 Mtetra
.67 .749 .91 r
.74287 .33519 .75015 .34479 .76637 .33928 .75916 .32955 Mtetra
.668 .747 .909 r
.75916 .32955 .76637 .33928 .78269 .3338 .77554 .32396 Mtetra
.666 .745 .909 r
.77554 .32396 .78269 .3338 .79911 .32834 .79202 .31841 Mtetra
.665 .744 .908 r
.79202 .31841 .79911 .32834 .81562 .32288 .8086 .31286 Mtetra
.665 .743 .908 r
.8086 .31286 .81562 .32288 .83223 .31741 .82528 .30732 Mtetra
.664 .742 .908 r
.82528 .30732 .83223 .31741 .84894 .31192 .84205 .30176 Mtetra
.84205 .30176 .84894 .31192 .86574 .30641 .85892 .29618 Mtetra
.85892 .29618 .86574 .30641 .88264 .30087 .87589 .29058 Mtetra
0 .326 .674 r
.2641 .56421 .27367 .56837 .28715 .57258 .27752 .56972 Mtetra
.284 0 0 r
.27752 .56972 .28715 .57258 .30083 .57604 .29114 .57463 Mtetra
.285 0 0 r
.29114 .57463 .30083 .57604 .31472 .57842 .30498 .57852 Mtetra
.254 0 0 r
.30498 .57852 .31472 .57842 .32882 .57936 .31905 .58102 Mtetra
.196 0 0 r
.31905 .58102 .32882 .57936 .34313 .57861 .33336 .58177 Mtetra
.114 0 0 r
.33336 .58177 .34313 .57861 .35765 .57597 .3479 .5805 Mtetra
.016 0 0 r
.3479 .5805 .35765 .57597 .37235 .57132 .36265 .57702 Mtetra
0 0 0 r
.36265 .57702 .37235 .57132 .38722 .56467 .37759 .57128 Mtetra
.37759 .57128 .38722 .56467 .40222 .55611 .39269 .56333 Mtetra
.39269 .56333 .40222 .55611 .41731 .54585 .40791 .55332 Mtetra
.40791 .55332 .41731 .54585 .43248 .53415 .42322 .54153 Mtetra
.507 .851 .582 r
.42322 .54153 .43248 .53415 .4477 .52134 .4386 .52829 Mtetra
.591 .899 .627 r
.4386 .52829 .4477 .52134 .46294 .50778 .454 .51399 Mtetra
.663 .94 .675 r
.454 .51399 .46294 .50778 .47819 .49382 .46941 .49903 Mtetra
.723 .971 .724 r
.46941 .49903 .47819 .49382 .49344 .47978 .48481 .48381 Mtetra
.769 .991 .772 r
.48481 .48381 .49344 .47978 .50868 .46596 .50021 .46867 Mtetra
.801 1 .815 r
.50021 .46867 .50868 .46596 .52393 .45261 .51559 .45392 Mtetra
.82 .997 .852 r
.51559 .45392 .52393 .45261 .53919 .43989 .53097 .4398 Mtetra
.825 .983 .881 r
.53097 .4398 .53919 .43989 .55447 .42794 .54636 .42646 Mtetra
.82 .962 .901 r
.54636 .42646 .55447 .42794 .56978 .4168 .56176 .41403 Mtetra
.808 .936 .915 r
.56176 .41403 .56978 .4168 .58513 .4065 .5772 .40253 Mtetra
.791 .908 .922 r
.5772 .40253 .58513 .4065 .60053 .397 .59267 .39196 Mtetra
.772 .88 .925 r
.59267 .39196 .60053 .397 .616 .38826 .60821 .38227 Mtetra
.753 .854 .925 r
.60821 .38227 .616 .38826 .63155 .38018 .62381 .37338 Mtetra
.736 .831 .924 r
.62381 .37338 .63155 .38018 .64718 .37269 .6395 .3652 Mtetra
.72 .811 .921 r
.6395 .3652 .64718 .37269 .66289 .36569 .65527 .35763 Mtetra
.707 .795 .919 r
.65527 .35763 .66289 .36569 .6787 .35909 .67113 .35057 Mtetra
.696 .781 .916 r
.67113 .35057 .6787 .35909 .6946 .35281 .68708 .34391 Mtetra
.688 .771 .914 r
.68708 .34391 .6946 .35281 .71059 .34677 .70313 .33757 Mtetra
.681 .762 .913 r
.70313 .33757 .71059 .34677 .72668 .34091 .71928 .33148 Mtetra
.676 .756 .911 r
.71928 .33148 .72668 .34091 .74287 .33519 .73553 .32556 Mtetra
.672 .752 .91 r
.73553 .32556 .74287 .33519 .75916 .32955 .75187 .31976 Mtetra
.67 .749 .91 r
.75187 .31976 .75916 .32955 .77554 .32396 .76832 .31405 Mtetra
.668 .746 .909 r
.76832 .31405 .77554 .32396 .79202 .31841 .78486 .30839 Mtetra
.666 .745 .909 r
.78486 .30839 .79202 .31841 .8086 .31286 .80151 .30276 Mtetra
.665 .743 .908 r
.80151 .30276 .8086 .31286 .82528 .30732 .81825 .29713 Mtetra
.81825 .29713 .82528 .30732 .84205 .30176 .83509 .2915 Mtetra
.664 .742 .908 r
.83509 .2915 .84205 .30176 .85892 .29618 .85203 .28585 Mtetra
.85203 .28585 .85892 .29618 .87589 .29058 .86908 .28018 Mtetra
0 .285 .681 r
.25451 .55872 .2641 .56421 .27752 .56972 .26786 .56547 Mtetra
.317 0 0 r
.26786 .56547 .27752 .56972 .29114 .57463 .28141 .5718 Mtetra
.329 0 0 r
.28141 .5718 .29114 .57463 .30498 .57852 .29519 .57725 Mtetra
.309 0 0 r
.29519 .57725 .30498 .57852 .31905 .58102 .30921 .58138 Mtetra
.257 0 0 r
.30921 .58138 .31905 .58102 .33336 .58177 .32349 .58378 Mtetra
.176 0 0 r
.32349 .58378 .33336 .58177 .3479 .5805 .33802 .58409 Mtetra
.073 0 0 r
.33802 .58409 .3479 .5805 .36265 .57702 .3528 .58205 Mtetra
0 0 0 r
.3528 .58205 .36265 .57702 .37759 .57128 .36779 .5775 Mtetra
.36779 .5775 .37759 .57128 .39269 .56333 .38298 .57045 Mtetra
.38298 .57045 .39269 .56333 .40791 .55332 .39832 .561 Mtetra
.39832 .561 .40791 .55332 .42322 .54153 .41377 .54939 Mtetra
.486 .833 .558 r
.41377 .54939 .42322 .54153 .4386 .52829 .42929 .53597 Mtetra
.572 .881 .595 r
.42929 .53597 .4386 .52829 .454 .51399 .44486 .52114 Mtetra
.646 .922 .637 r
.44486 .52114 .454 .51399 .46941 .49903 .46044 .50534 Mtetra
.709 .955 .681 r
.46044 .50534 .46941 .49903 .48481 .48381 .47602 .48902 Mtetra
.76 .98 .727 r
.47602 .48902 .48481 .48381 .50021 .46867 .49157 .4726 Mtetra
.798 .995 .772 r
.49157 .4726 .50021 .46867 .51559 .45392 .50711 .45645 Mtetra
.823 1 .814 r
.50711 .45645 .51559 .45392 .53097 .4398 .52263 .44086 Mtetra
.835 .994 .849 r
.52263 .44086 .53097 .4398 .54636 .42646 .53813 .42608 Mtetra
.836 .979 .878 r
.53813 .42608 .54636 .42646 .56176 .41403 .55364 .41223 Mtetra
.827 .957 .898 r
.55364 .41223 .56176 .41403 .5772 .40253 .56917 .39942 Mtetra
.812 .931 .911 r
.56917 .39942 .5772 .40253 .59267 .39196 .58473 .38765 Mtetra
.793 .903 .919 r
.58473 .38765 .59267 .39196 .60821 .38227 .60033 .37689 Mtetra
.772 .875 .922 r
.60033 .37689 .60821 .38227 .62381 .37338 .616 .36707 Mtetra
.753 .849 .923 r
.616 .36707 .62381 .37338 .6395 .3652 .63175 .3581 Mtetra
.735 .827 .922 r
.63175 .3581 .6395 .3652 .65527 .35763 .64757 .34986 Mtetra
.719 .807 .92 r
.64757 .34986 .65527 .35763 .67113 .35057 .66348 .34225 Mtetra
.706 .791 .918 r
.66348 .34225 .67113 .35057 .68708 .34391 .67949 .33515 Mtetra
.695 .779 .915 r
.67949 .33515 .68708 .34391 .70313 .33757 .6956 .32845 Mtetra
.687 .769 .914 r
.6956 .32845 .70313 .33757 .71928 .33148 .7118 .32206 Mtetra
.68 .761 .912 r
.7118 .32206 .71928 .33148 .73553 .32556 .72811 .31592 Mtetra
.675 .755 .911 r
.72811 .31592 .73553 .32556 .75187 .31976 .74451 .30994 Mtetra
.672 .751 .91 r
.74451 .30994 .75187 .31976 .76832 .31405 .76102 .30408 Mtetra
.669 .748 .909 r
.76102 .30408 .76832 .31405 .78486 .30839 .77763 .2983 Mtetra
.667 .746 .909 r
.77763 .2983 .78486 .30839 .80151 .30276 .79434 .29256 Mtetra
.666 .744 .909 r
.79434 .29256 .80151 .30276 .81825 .29713 .81115 .28685 Mtetra
.665 .743 .908 r
.81115 .28685 .81825 .29713 .83509 .2915 .82806 .28113 Mtetra
.665 .742 .908 r
.82806 .28113 .83509 .2915 .85203 .28585 .84507 .27541 Mtetra
.664 .742 .908 r
.84507 .27541 .85203 .28585 .86908 .28018 .86219 .26967 Mtetra
0 .257 .697 r
.24492 .55175 .25451 .55872 .26786 .56547 .2582 .55962 Mtetra
0 .233 .643 r
.2582 .55962 .26786 .56547 .28141 .5718 .27167 .56727 Mtetra
.349 0 0 r
.27167 .56727 .28141 .5718 .29519 .57725 .28538 .57424 Mtetra
.341 0 0 r
.28538 .57424 .29519 .57725 .30921 .58138 .29933 .58004 Mtetra
.299 0 0 r
.29933 .58004 .30921 .58138 .32349 .58378 .31356 .58418 Mtetra
.224 0 0 r
.31356 .58418 .32349 .58378 .33802 .58409 .32806 .58623 Mtetra
.119 0 0 r
.32806 .58623 .33802 .58409 .3528 .58205 .34284 .58583 Mtetra
0 0 0 r
.34284 .58583 .3528 .58205 .36779 .5775 .35786 .58276 Mtetra
.35786 .58276 .36779 .5775 .38298 .57045 .37311 .57691 Mtetra
.37311 .57691 .38298 .57045 .39832 .561 .38855 .56834 Mtetra
.38855 .56834 .39832 .561 .41377 .54939 .40412 .55724 Mtetra
.483 .834 .565 r
.40412 .55724 .41377 .54939 .42929 .53597 .4198 .54393 Mtetra
.57 .879 .59 r
.4198 .54393 .42929 .53597 .44486 .52114 .43553 .52882 Mtetra
.644 .916 .62 r
.43553 .52882 .44486 .52114 .46044 .50534 .45129 .5124 Mtetra
.707 .947 .656 r
.45129 .5124 .46044 .50534 .47602 .48902 .46704 .49515 Mtetra
.758 .971 .695 r
.46704 .49515 .47602 .48902 .49157 .4726 .48277 .47756 Mtetra
.798 .989 .737 r
.48277 .47756 .49157 .4726 .50711 .45645 .49847 .46005 Mtetra
.826 .998 .778 r
.49847 .46005 .50711 .45645 .52263 .44086 .51413 .44301 Mtetra
.843 .998 .816 r
.51413 .44301 .52263 .44086 .53813 .42608 .52977 .42673 Mtetra
.849 .99 .85 r
.52977 .42673 .53813 .42608 .55364 .41223 .5454 .41141 Mtetra
.844 .973 .876 r
.5454 .41141 .55364 .41223 .56917 .39942 .56103 .39719 Mtetra
.832 .95 .896 r
.56103 .39719 .56917 .39942 .58473 .38765 .57668 .38411 Mtetra
.814 .923 .909 r
.57668 .38411 .58473 .38765 .60033 .37689 .59237 .37217 Mtetra
.793 .895 .916 r
.59237 .37217 .60033 .37689 .616 .36707 .60811 .3613 Mtetra
.771 .868 .92 r
.60811 .3613 .616 .36707 .63175 .3581 .62392 .35143 Mtetra
.751 .843 .921 r
.62392 .35143 .63175 .3581 .64757 .34986 .6398 .34243 Mtetra
.733 .821 .92 r
.6398 .34243 .64757 .34986 .66348 .34225 .65577 .33417 Mtetra
.717 .803 .918 r
.65577 .33417 .66348 .34225 .67949 .33515 .67183 .32655 Mtetra
.704 .788 .916 r
.67183 .32655 .67949 .33515 .6956 .32845 .68799 .31943 Mtetra
.693 .776 .914 r
.68799 .31943 .6956 .32845 .7118 .32206 .70425 .3127 Mtetra
.685 .766 .913 r
.70425 .3127 .7118 .32206 .72811 .31592 .72062 .30629 Mtetra
.679 .759 .912 r
.72062 .30629 .72811 .31592 .74451 .30994 .73708 .30009 Mtetra
.674 .754 .911 r
.73708 .30009 .74451 .30994 .76102 .30408 .75365 .29406 Mtetra
.671 .75 .91 r
.75365 .29406 .76102 .30408 .77763 .2983 .77032 .28814 Mtetra
.669 .747 .909 r
.77032 .28814 .77763 .2983 .79434 .29256 .7871 .28229 Mtetra
.667 .745 .909 r
.7871 .28229 .79434 .29256 .81115 .28685 .80397 .27647 Mtetra
.666 .744 .908 r
.80397 .27647 .81115 .28685 .82806 .28113 .82095 .27067 Mtetra
.665 .743 .908 r
.82095 .27067 .82806 .28113 .84507 .27541 .83804 .26487 Mtetra
.664 .742 .908 r
.83804 .26487 .84507 .27541 .86219 .26967 .85522 .25906 Mtetra
0 .243 .718 r
.23536 .54322 .24492 .55175 .2582 .55962 .24857 .55201 Mtetra
0 .214 .671 r
.24857 .55201 .2582 .55962 .27167 .56727 .26196 .56084 Mtetra
0 .208 .634 r
.26196 .56084 .27167 .56727 .28538 .57424 .27558 .56922 Mtetra
.347 0 0 r
.27558 .56922 .28538 .57424 .29933 .58004 .28945 .57663 Mtetra
.318 0 0 r
.28945 .57663 .29933 .58004 .31356 .58418 .30361 .58253 Mtetra
.252 0 0 r
.30361 .58253 .31356 .58418 .32806 .58623 .31806 .5864 Mtetra
.149 0 0 r
.31806 .5864 .32806 .58623 .34284 .58583 .3328 .58782 Mtetra
.017 0 0 r
.3328 .58782 .34284 .58583 .35786 .58276 .34784 .58644 Mtetra
0 0 0 r
.34784 .58644 .35786 .58276 .37311 .57691 .36312 .58208 Mtetra
.36312 .58208 .37311 .57691 .38855 .56834 .37863 .57472 Mtetra
.395 .806 .6 r
.37863 .57472 .38855 .56834 .40412 .55724 .39431 .56447 Mtetra
.501 .856 .604 r
.39431 .56447 .40412 .55724 .4198 .54393 .41012 .55161 Mtetra
.588 .894 .613 r
.41012 .55161 .4198 .54393 .43553 .52882 .42601 .53656 Mtetra
.659 .924 .629 r
.42601 .53656 .43553 .52882 .45129 .5124 .44194 .51979 Mtetra
.717 .948 .652 r
.44194 .51979 .45129 .5124 .46704 .49515 .45787 .50183 Mtetra
.765 .968 .68 r
.45787 .50183 .46704 .49515 .48277 .47756 .47378 .48324 Mtetra
.804 .984 .714 r
.47378 .48324 .48277 .47756 .49847 .46005 .48965 .46451 Mtetra
.832 .994 .75 r
.48965 .46451 .49847 .46005 .51413 .44301 .50548 .44608 Mtetra
.851 .998 .787 r
.50548 .44608 .51413 .44301 .52977 .42673 .52127 .42831 Mtetra
.86 .994 .821 r
.52127 .42831 .52977 .42673 .5454 .41141 .53703 .4115 Mtetra
.86 .983 .852 r
.53703 .4115 .5454 .41141 .56103 .39719 .55278 .3958 Mtetra
.85 .964 .877 r
.55278 .3958 .56103 .39719 .57668 .38411 .56854 .38133 Mtetra
.834 .941 .895 r
.56854 .38133 .57668 .38411 .59237 .37217 .58431 .36811 Mtetra
.813 .914 .907 r
.58431 .36811 .59237 .37217 .60811 .3613 .60013 .3561 Mtetra
.791 .887 .914 r
.60013 .3561 .60811 .3613 .62392 .35143 .616 .34522 Mtetra
.768 .86 .918 r
.616 .34522 .62392 .35143 .6398 .34243 .63195 .33536 Mtetra
.748 .836 .919 r
.63195 .33536 .6398 .34243 .65577 .33417 .64798 .32638 Mtetra
.73 .815 .918 r
.64798 .32638 .65577 .33417 .67183 .32655 .6641 .31815 Mtetra
.714 .798 .917 r
.6641 .31815 .67183 .32655 .68799 .31943 .68031 .31053 Mtetra
.701 .784 .915 r
.68031 .31053 .68799 .31943 .70425 .3127 .69663 .30341 Mtetra
.691 .772 .914 r
.69663 .30341 .70425 .3127 .72062 .30629 .71305 .29668 Mtetra
.684 .764 .912 r
.71305 .29668 .72062 .30629 .73708 .30009 .72957 .29024 Mtetra
.678 .757 .911 r
.72957 .29024 .73708 .30009 .75365 .29406 .7462 .284 Mtetra
.673 .752 .91 r
.7462 .284 .75365 .29406 .77032 .28814 .76294 .27792 Mtetra
.67 .749 .909 r
.76294 .27792 .77032 .28814 .7871 .28229 .77978 .27193 Mtetra
.668 .746 .909 r
.77978 .27193 .7871 .28229 .80397 .27647 .79672 .266 Mtetra
.667 .745 .909 r
.79672 .266 .80397 .27647 .82095 .27067 .81377 .26011 Mtetra
.665 .743 .908 r
.81377 .26011 .82095 .27067 .83804 .26487 .83092 .25422 Mtetra
.83092 .25422 .83804 .26487 .85522 .25906 .84818 .24833 Mtetra
0 .241 .739 r
.22583 .53312 .23536 .54322 .24857 .55201 .23898 .54261 Mtetra
0 .207 .7 r
.23898 .54261 .24857 .55201 .26196 .56084 .25229 .55239 Mtetra
0 .195 .671 r
.25229 .55239 .26196 .56084 .27558 .56922 .26582 .562 Mtetra
0 .209 .655 r
.26582 .562 .27558 .56922 .28945 .57663 .2796 .57088 Mtetra
0 .253 .654 r
.2796 .57088 .28945 .57663 .30361 .58253 .29367 .57846 Mtetra
0 .329 .667 r
.29367 .57846 .30361 .58253 .31806 .5864 .30805 .58417 Mtetra
.157 0 0 r
.30805 .58417 .31806 .5864 .3328 .58782 .32274 .58748 Mtetra
0 .558 .707 r
.32274 .58748 .3328 .58782 .34784 .58644 .33775 .58797 Mtetra
.135 .679 .716 r
.33775 .58797 .34784 .58644 .36312 .58208 .35304 .58535 Mtetra
.292 .779 .71 r
.35304 .58535 .36312 .58208 .37863 .57472 .3686 .57949 Mtetra
.428 .849 .695 r
.3686 .57949 .37863 .57472 .39431 .56447 .38436 .57043 Mtetra
.538 .895 .679 r
.38436 .57043 .39431 .56447 .41012 .55161 .40028 .55839 Mtetra
.624 .925 .668 r
.40028 .55839 .41012 .55161 .42601 .53656 .41632 .54374 Mtetra
.69 .945 .665 r
.41632 .54374 .42601 .53656 .44194 .51979 .43241 .52696 Mtetra
.742 .96 .671 r
.43241 .52696 .44194 .51979 .45787 .50183 .44852 .5086 Mtetra
.784 .973 .685 r
.44852 .5086 .45787 .50183 .47378 .48324 .46461 .48926 Mtetra
.818 .984 .706 r
.46461 .48926 .47378 .48324 .48965 .46451 .48066 .46948 Mtetra
.844 .991 .734 r
.48066 .46948 .48965 .46451 .50548 .44608 .49667 .44979 Mtetra
.862 .995 .765 r
.49667 .44979 .50548 .44608 .52127 .42831 .51262 .43063 Mtetra
.872 .994 .797 r
.51262 .43063 .52127 .42831 .53703 .4115 .52853 .41234 Mtetra
.873 .987 .828 r
.52853 .41234 .53703 .4115 .55278 .3958 .54441 .39517 Mtetra
.866 .973 .856 r
.54441 .39517 .55278 .3958 .56854 .38133 .56028 .37927 Mtetra
.852 .953 .878 r
.56028 .37927 .56854 .38133 .58431 .36811 .57615 .3647 Mtetra
.833 .929 .895 r
.57615 .3647 .58431 .36811 .60013 .3561 .59205 .35146 Mtetra
.81 .903 .906 r
.59205 .35146 .60013 .3561 .616 .34522 .608 .33949 Mtetra
.787 .876 .913 r
.608 .33949 .616 .34522 .63195 .33536 .62402 .32867 Mtetra
.764 .851 .916 r
.62402 .32867 .63195 .33536 .64798 .32638 .6401 .31888 Mtetra
.744 .829 .917 r
.6401 .31888 .64798 .32638 .6641 .31815 .65628 .30997 Mtetra
.726 .809 .916 r
.65628 .30997 .6641 .31815 .68031 .31053 .67255 .30179 Mtetra
.711 .793 .915 r
.67255 .30179 .68031 .31053 .69663 .30341 .68893 .29422 Mtetra
.699 .78 .914 r
.68893 .29422 .69663 .30341 .71305 .29668 .7054 .28712 Mtetra
.689 .769 .913 r
.7054 .28712 .71305 .29668 .72957 .29024 .72199 .28038 Mtetra
.682 .761 .911 r
.72199 .28038 .72957 .29024 .7462 .284 .73868 .27391 Mtetra
.676 .755 .91 r
.73868 .27391 .7462 .284 .76294 .27792 .75548 .26764 Mtetra
.672 .751 .91 r
.75548 .26764 .76294 .27792 .77978 .27193 .77238 .2615 Mtetra
.67 .748 .909 r
.77238 .2615 .77978 .27193 .79672 .266 .78939 .25545 Mtetra
.668 .746 .909 r
.78939 .25545 .79672 .266 .81377 .26011 .80651 .24945 Mtetra
.666 .744 .908 r
.80651 .24945 .81377 .26011 .83092 .25422 .82373 .24347 Mtetra
.665 .743 .908 r
.82373 .24347 .83092 .25422 .84818 .24833 .84106 .23749 Mtetra
0 .25 .758 r
.21635 .52152 .22583 .53312 .23898 .54261 .22944 .53143 Mtetra
0 .211 .724 r
.22944 .53143 .23898 .54261 .25229 .55239 .24268 .5419 Mtetra
0 .193 .701 r
.24268 .5419 .25229 .55239 .26582 .562 .25613 .55249 Mtetra
0 .2 .693 r
.25613 .55249 .26582 .562 .2796 .57088 .26981 .56263 Mtetra
0 .236 .702 r
.26981 .56263 .2796 .57088 .29367 .57846 .28379 .57174 Mtetra
0 .307 .729 r
.28379 .57174 .29367 .57846 .30805 .58417 .29807 .57919 Mtetra
0 .413 .77 r
.29807 .57919 .30805 .58417 .32274 .58748 .31269 .58439 Mtetra
0 .548 .814 r
.31269 .58439 .32274 .58748 .33775 .58797 .32764 .58683 Mtetra
.156 .691 .843 r
.32764 .58683 .33775 .58797 .35304 .58535 .34292 .58612 Mtetra
.326 .812 .843 r
.34292 .58612 .35304 .58535 .3686 .57949 .35848 .58201 Mtetra
.475 .894 .818 r
.35848 .58201 .3686 .57949 .38436 .57043 .3743 .57446 Mtetra
.59 .94 .782 r
.3743 .57446 .38436 .57043 .40028 .55839 .39031 .56359 Mtetra
.674 .963 .748 r
.39031 .56359 .40028 .55839 .41632 .54374 .40647 .54973 Mtetra
.734 .973 .724 r
.40647 .54973 .41632 .54374 .43241 .52696 .42271 .53331 Mtetra
.779 .979 .71 r
.42271 .53331 .43241 .52696 .44852 .5086 .43899 .51491 Mtetra
.813 .983 .708 r
.43899 .51491 .44852 .5086 .46461 .48926 .45526 .49512 Mtetra
.84 .987 .715 r
.45526 .49512 .46461 .48926 .48066 .46948 .4715 .47456 Mtetra
.86 .99 .731 r
.4715 .47456 .48066 .46948 .49667 .44979 .48768 .45382 Mtetra
.875 .992 .753 r
.48768 .45382 .49667 .44979 .51262 .43063 .50381 .43341 Mtetra
.884 .992 .779 r
.50381 .43341 .51262 .43063 .52853 .41234 .51988 .41374 Mtetra
.886 .987 .808 r
.51988 .41374 .52853 .41234 .54441 .39517 .5359 .39514 Mtetra
.881 .977 .835 r
.5359 .39514 .54441 .39517 .56028 .37927 .55189 .37781 Mtetra
.869 .961 .86 r
.55189 .37781 .56028 .37927 .57615 .3647 .56788 .36187 Mtetra
.851 .941 .88 r
.56788 .36187 .57615 .3647 .59205 .35146 .58387 .34735 Mtetra
.829 .917 .895 r
.58387 .34735 .59205 .35146 .608 .33949 .59991 .33421 Mtetra
.805 .891 .905 r
.59991 .33421 .608 .33949 .62402 .32867 .61599 .32237 Mtetra
.781 .865 .911 r
.61599 .32237 .62402 .32867 .6401 .31888 .63215 .31169 Mtetra
.759 .842 .914 r
.63215 .31169 .6401 .31888 .65628 .30997 .64839 .30202 Mtetra
.739 .82 .915 r
.64839 .30202 .65628 .30997 .67255 .30179 .66472 .29322 Mtetra
.721 .802 .915 r
.66472 .29322 .67255 .30179 .68893 .29422 .68115 .28513 Mtetra
.707 .787 .914 r
.68115 .28513 .68893 .29422 .7054 .28712 .69768 .27761 Mtetra
.696 .775 .913 r
.69768 .27761 .7054 .28712 .72199 .28038 .71432 .27054 Mtetra
.687 .766 .912 r
.71432 .27054 .72199 .28038 .73868 .27391 .73108 .26381 Mtetra
.68 .759 .911 r
.73108 .26381 .73868 .27391 .75548 .26764 .74794 .25732 Mtetra
.675 .754 .91 r
.74794 .25732 .75548 .26764 .77238 .2615 .7649 .25101 Mtetra
.671 .75 .909 r
.7649 .25101 .77238 .2615 .78939 .25545 .78198 .24481 Mtetra
.669 .747 .909 r
.78198 .24481 .78939 .25545 .80651 .24945 .79917 .23869 Mtetra
.667 .745 .909 r
.79917 .23869 .80651 .24945 .82373 .24347 .81646 .23261 Mtetra
.666 .744 .908 r
.81646 .23261 .82373 .24347 .84106 .23749 .83386 .22655 Mtetra
0 .266 .774 r
.20691 .50856 .21635 .52152 .22944 .53143 .21996 .5186 Mtetra
0 .225 .744 r
.21996 .5186 .22944 .53143 .24268 .5419 .23315 .52945 Mtetra
0 .201 .724 r
.23315 .52945 .24268 .5419 .25613 .55249 .24652 .54071 Mtetra
0 .2 .719 r
.24652 .54071 .25613 .55249 .26981 .56263 .26012 .55183 Mtetra
0 .227 .731 r
.26012 .55183 .26981 .56263 .28379 .57174 .27399 .56222 Mtetra
0 .286 .764 r
.27399 .56222 .28379 .57174 .29807 .57919 .28817 .57124 Mtetra
0 .38 .815 r
.28817 .57124 .29807 .57919 .31269 .58439 .3027 .57823 Mtetra
.024 .51 .876 r
.3027 .57823 .31269 .58439 .32764 .58683 .31757 .58261 Mtetra
.182 .662 .93 r
.31757 .58261 .32764 .58683 .34292 .58612 .3328 .58388 Mtetra
.358 .804 .953 r
.3328 .58388 .34292 .58612 .35848 .58201 .34834 .5817 Mtetra
.517 .907 .936 r
.34834 .5817 .35848 .58201 .3743 .57446 .36418 .57592 Mtetra
.639 .965 .891 r
.36418 .57592 .3743 .57446 .39031 .56359 .38025 .56656 Mtetra
.724 .989 .84 r
.38025 .56656 .39031 .56359 .40647 .54973 .3965 .55385 Mtetra
.78 .996 .796 r
.3965 .55385 .40647 .54973 .42271 .53331 .41287 .53819 Mtetra
.819 .996 .764 r
.41287 .53819 .42271 .53331 .43899 .51491 .4293 .52013 Mtetra
.846 .993 .745 r
.4293 .52013 .43899 .51491 .45526 .49512 .44574 .50026 Mtetra
.866 .991 .737 r
.44574 .50026 .45526 .49512 .4715 .47456 .46216 .47926 Mtetra
.881 .99 .74 r
.46216 .47926 .4715 .47456 .48768 .45382 .47853 .45774 Mtetra
.891 .989 .752 r
.47853 .45774 .48768 .45382 .50381 .43341 .49483 .43629 Mtetra
.897 .987 .77 r
.49483 .43629 .50381 .43341 .51988 .41374 .51107 .41541 Mtetra
.898 .983 .793 r
.51107 .41541 .51988 .41374 .5359 .39514 .52724 .39548 Mtetra
.894 .976 .818 r
.52724 .39548 .5359 .39514 .55189 .37781 .54337 .37678 Mtetra
.883 .964 .843 r
.54337 .37678 .55189 .37781 .56788 .36187 .55948 .35949 Mtetra
.867 .947 .864 r
.55948 .35949 .56788 .36187 .58387 .34735 .57558 .34368 Mtetra
.847 .926 .882 r
.57558 .34368 .58387 .34735 .59991 .33421 .59171 .32935 Mtetra
.823 .902 .896 r
.59171 .32935 .59991 .33421 .61599 .32237 .60788 .31643 Mtetra
.798 .878 .905 r
.60788 .31643 .61599 .32237 .63215 .31169 .6241 .3048 Mtetra
.774 .854 .91 r
.6241 .3048 .63215 .31169 .64839 .30202 .64041 .29432 Mtetra
.752 .832 .913 r
.64041 .29432 .64839 .30202 .66472 .29322 .6568 .28483 Mtetra
.733 .812 .914 r
.6568 .28483 .66472 .29322 .68115 .28513 .67329 .27616 Mtetra
.716 .795 .914 r
.67329 .27616 .68115 .28513 .69768 .27761 .68988 .26818 Mtetra
.703 .782 .913 r
.68988 .26818 .69768 .27761 .71432 .27054 .70658 .26073 Mtetra
.692 .771 .912 r
.70658 .26073 .71432 .27054 .73108 .26381 .72339 .25369 Mtetra
.684 .763 .911 r
.72339 .25369 .73108 .26381 .74794 .25732 .74032 .24696 Mtetra
.678 .756 .91 r
.74032 .24696 .74794 .25732 .7649 .25101 .75735 .24045 Mtetra
.674 .752 .91 r
.75735 .24045 .7649 .25101 .78198 .24481 .77449 .2341 Mtetra
.67 .748 .909 r
.77449 .2341 .78198 .24481 .79917 .23869 .79175 .22784 Mtetra
.668 .746 .909 r
.79175 .22784 .79917 .23869 .81646 .23261 .80911 .22165 Mtetra
.667 .744 .908 r
.80911 .22165 .81646 .23261 .83386 .22655 .82659 .21549 Mtetra
0 .289 .787 r
.1975 .49442 .20691 .50856 .21996 .5186 .21054 .50429 Mtetra
0 .245 .76 r
.21054 .50429 .21996 .5186 .23315 .52945 .22369 .51522 Mtetra
0 .217 .74 r
.22369 .51522 .23315 .52945 .24652 .54071 .237 .52681 Mtetra
0 .209 .734 r
.237 .52681 .24652 .54071 .26012 .55183 .25052 .53858 Mtetra
0 .225 .745 r
.25052 .53858 .26012 .55183 .27399 .56222 .2643 .54994 Mtetra
0 .269 .773 r
.2643 .54994 .27399 .56222 .28817 .57124 .27838 .56025 Mtetra
0 .346 .821 r
.27838 .56025 .28817 .57124 .3027 .57823 .2928 .56883 Mtetra
.063 .456 .882 r
.2928 .56883 .3027 .57823 .31757 .58261 .30758 .57502 Mtetra
.204 .593 .946 r
.30758 .57502 .31757 .58261 .3328 .58388 .32272 .57826 Mtetra
.369 .736 .989 r
.32272 .57826 .3328 .58388 .34834 .5817 .33822 .5781 Mtetra
.529 .858 .996 r
.33822 .5781 .34834 .5817 .36418 .57592 .35404 .57426 Mtetra
.66 .938 .966 r
.35404 .57426 .36418 .57592 .38025 .56656 .37013 .56667 Mtetra
.752 .979 .916 r
.37013 .56667 .38025 .56656 .3965 .55385 .38644 .55546 Mtetra
.812 .995 .864 r
.38644 .55546 .3965 .55385 .41287 .53819 .40291 .54095 Mtetra
.85 .997 .82 r
.40291 .54095 .41287 .53819 .4293 .52013 .41947 .52363 Mtetra
.874 .994 .788 r
.41947 .52363 .4293 .52013 .44574 .50026 .43607 .50409 Mtetra
.89 .99 .767 r
.43607 .50409 .44574 .50026 .46216 .47926 .45266 .48301 Mtetra
.901 .986 .759 r
.45266 .48301 .46216 .47926 .47853 .45774 .46921 .46105 Mtetra
.908 .983 .76 r
.46921 .46105 .47853 .45774 .49483 .43629 .48569 .43886 Mtetra
.911 .98 .769 r
.48569 .43886 .49483 .43629 .51107 .41541 .5021 .41699 Mtetra
.91 .977 .785 r
.5021 .41699 .51107 .41541 .52724 .39548 .51844 .3959 Mtetra
.906 .971 .806 r
.51844 .3959 .52724 .39548 .54337 .37678 .53472 .37596 Mtetra
.896 .962 .828 r
.53472 .37596 .54337 .37678 .55948 .35949 .55095 .35739 Mtetra
.881 .948 .849 r
.55095 .35739 .55948 .35949 .57558 .34368 .56717 .34032 Mtetra
.862 .931 .869 r
.56717 .34032 .57558 .34368 .59171 .32935 .5834 .3248 Mtetra
.839 .91 .885 r
.5834 .3248 .59171 .32935 .60788 .31643 .59966 .31078 Mtetra
.815 .888 .896 r
.59966 .31078 .60788 .31643 .6241 .3048 .61596 .29817 Mtetra
.79 .864 .904 r
.61596 .29817 .6241 .3048 .64041 .29432 .63234 .28683 Mtetra
.766 .842 .909 r
.63234 .28683 .64041 .29432 .6568 .28483 .64879 .2766 Mtetra
.745 .821 .912 r
.64879 .2766 .6568 .28483 .67329 .27616 .66534 .26732 Mtetra
.726 .804 .912 r
.66534 .26732 .67329 .27616 .68988 .26818 .682 .25882 Mtetra
.711 .789 .912 r
.682 .25882 .68988 .26818 .70658 .26073 .69876 .25095 Mtetra
.699 .777 .912 r
.69876 .25095 .70658 .26073 .72339 .25369 .71563 .24357 Mtetra
.689 .767 .911 r
.71563 .24357 .72339 .25369 .74032 .24696 .73262 .23656 Mtetra
.682 .76 .91 r
.73262 .23656 .74032 .24696 .75735 .24045 .74972 .22984 Mtetra
.676 .754 .91 r
.74972 .22984 .75735 .24045 .77449 .2341 .76693 .22331 Mtetra
.672 .75 .909 r
.76693 .22331 .77449 .2341 .79175 .22784 .78425 .21691 Mtetra
.669 .747 .909 r
.78425 .21691 .79175 .22784 .80911 .22165 .80168 .21059 Mtetra
.667 .745 .909 r
.80168 .21059 .80911 .22165 .82659 .21549 .81923 .20432 Mtetra
.061 .316 .799 r
.1881 .47935 .1975 .49442 .21054 .50429 .20116 .48877 Mtetra
.002 .27 .773 r
.20116 .48877 .21054 .50429 .22369 .51522 .2143 .49944 Mtetra
0 .238 .753 r
.2143 .49944 .22369 .51522 .237 .52681 .22757 .51102 Mtetra
0 .224 .744 r
.22757 .51102 .237 .52681 .25052 .53858 .24103 .52307 Mtetra
0 .23 .749 r
.24103 .52307 .25052 .53858 .2643 .54994 .25472 .53504 Mtetra
0 .261 .77 r
.25472 .53504 .2643 .54994 .27838 .56025 .2687 .54631 Mtetra
.015 .318 .806 r
.2687 .54631 .27838 .56025 .2928 .56883 .28302 .55618 Mtetra
.101 .404 .857 r
.28302 .55618 .2928 .56883 .30758 .57502 .29769 .56398 Mtetra
.219 .515 .913 r
.29769 .56398 .30758 .57502 .32272 .57826 .31274 .56906 Mtetra
.362 .64 .961 r
.31274 .56906 .32272 .57826 .33822 .5781 .32816 .57089 Mtetra
.51 .761 .987 r
.32816 .57089 .33822 .5781 .35404 .57426 .34393 .56908 Mtetra
.643 .857 .981 r
.34393 .56908 .35404 .57426 .37013 .56667 .36001 .56344 Mtetra
.745 .921 .95 r
.36001 .56344 .37013 .56667 .38644 .55546 .37635 .554 Mtetra
.815 .956 .907 r
.37635 .554 .38644 .55546 .40291 .54095 .39288 .54098 Mtetra
.86 .971 .863 r
.39288 .54098 .40291 .54095 .41947 .52363 .40955 .52479 Mtetra
.888 .976 .826 r
.40955 .52479 .41947 .52363 .43607 .50409 .42628 .506 Mtetra
.905 .976 .798 r
.42628 .506 .43607 .50409 .45266 .48301 .44302 .48525 Mtetra
.915 .974 .781 r
.44302 .48525 .45266 .48301 .46921 .46105 .45974 .46323 Mtetra
.92 .972 .773 r
.45974 .46323 .46921 .46105 .48569 .43886 .47639 .44064 Mtetra
.922 .969 .775 r
.47639 .44064 .48569 .43886 .5021 .41699 .49298 .41807 Mtetra
.92 .966 .783 r
.49298 .41807 .5021 .41699 .51844 .3959 .50948 .39608 Mtetra
.915 .962 .798 r
.50948 .39608 .51844 .3959 .53472 .37596 .52591 .37507 Mtetra
.906 .955 .816 r
.52591 .37507 .53472 .37596 .55095 .35739 .54229 .35535 Mtetra
.893 .945 .836 r
.54229 .35535 .55095 .35739 .56717 .34032 .55864 .33712 Mtetra
.875 .932 .856 r
.55864 .33712 .56717 .34032 .5834 .3248 .57498 .32045 Mtetra
.854 .914 .873 r
.57498 .32045 .5834 .3248 .59966 .31078 .59133 .30535 Mtetra
.83 .894 .887 r
.59133 .30535 .59966 .31078 .61596 .29817 .60772 .29174 Mtetra
.804 .872 .897 r
.60772 .29174 .61596 .29817 .63234 .28683 .62417 .27952 Mtetra
.78 .851 .904 r
.62417 .27952 .63234 .28683 .64879 .2766 .6407 .26852 Mtetra
.757 .83 .908 r
.6407 .26852 .64879 .2766 .66534 .26732 .65731 .25858 Mtetra
.737 .812 .91 r
.65731 .25858 .66534 .26732 .682 .25882 .67403 .24952 Mtetra
.72 .796 .911 r
.67403 .24952 .682 .25882 .69876 .25095 .69085 .2412 Mtetra
.706 .782 .911 r
.69085 .2412 .69876 .25095 .71563 .24357 .70779 .23345 Mtetra
.694 .772 .911 r
.70779 .23345 .71563 .24357 .73262 .23656 .72484 .22614 Mtetra
.686 .763 .91 r
.72484 .22614 .73262 .23656 .74972 .22984 .742 .21917 Mtetra
.679 .757 .91 r
.742 .21917 .74972 .22984 .76693 .22331 .75928 .21244 Mtetra
.674 .752 .909 r
.75928 .21244 .76693 .22331 .78425 .21691 .77667 .20588 Mtetra
.671 .749 .909 r
.77667 .20588 .78425 .21691 .80168 .21059 .79417 .19943 Mtetra
.668 .746 .909 r
.79417 .19943 .80168 .21059 .81923 .20432 .81179 .19305 Mtetra
.127 .347 .811 r
.17871 .46359 .1881 .47935 .20116 .48877 .1918 .47232 Mtetra
.07 .3 .785 r
.1918 .47232 .20116 .48877 .2143 .49944 .20496 .48242 Mtetra
.028 .264 .764 r
.20496 .48242 .2143 .49944 .22757 .51102 .21822 .49365 Mtetra
.004 .244 .751 r
.21822 .49365 .22757 .51102 .24103 .52307 .23164 .50561 Mtetra
0 .242 .75 r
.23164 .50561 .24103 .52307 .25472 .53504 .24527 .51781 Mtetra
.02 .26 .762 r
.24527 .51781 .25472 .53504 .2687 .54631 .25916 .52965 Mtetra
.064 .301 .787 r
.25916 .52965 .2687 .54631 .28302 .55618 .27337 .54047 Mtetra
.135 .365 .823 r
.27337 .54047 .28302 .55618 .29769 .56398 .28794 .54956 Mtetra
.231 .45 .866 r
.28794 .54956 .29769 .56398 .31274 .56906 .30288 .55625 Mtetra
.349 .551 .909 r
.30288 .55625 .31274 .56906 .32816 .57089 .3182 .55993 Mtetra
.477 .657 .94 r
.3182 .55993 .32816 .57089 .34393 .56908 .33389 .56012 Mtetra
.601 .754 .951 r
.33389 .56012 .34393 .56908 .36001 .56344 .34993 .55652 Mtetra
.707 .831 .941 r
.34993 .55652 .36001 .56344 .37635 .554 .36626 .54903 Mtetra
.787 .885 .916 r
.36626 .54903 .37635 .554 .39288 .54098 .38282 .53778 Mtetra
.844 .918 .883 r
.38282 .53778 .39288 .54098 .40955 .52479 .39955 .52307 Mtetra
.881 .937 .85 r
.39955 .52307 .40955 .52479 .42628 .506 .41638 .50541 Mtetra
.904 .946 .822 r
.41638 .50541 .42628 .506 .44302 .48525 .43326 .48541 Mtetra
.918 .95 .801 r
.43326 .48541 .44302 .48525 .45974 .46323 .45013 .46375 Mtetra
.925 .952 .788 r
.45013 .46375 .45974 .46323 .47639 .44064 .46695 .44113 Mtetra
.927 .952 .783 r
.46695 .44113 .47639 .44064 .49298 .41807 .4837 .41823 Mtetra
.926 .951 .786 r
.4837 .41823 .49298 .41807 .50948 .39608 .50037 .39561 Mtetra
.922 .949 .795 r
.50037 .39561 .50948 .39608 .52591 .37507 .51696 .37378 Mtetra
.913 .945 .809 r
.51696 .37378 .52591 .37507 .54229 .35535 .53349 .35311 Mtetra
.901 .938 .826 r
.53349 .35311 .54229 .35535 .55864 .33712 .54997 .33384 Mtetra
.885 .928 .844 r
.54997 .33384 .55864 .33712 .57498 .32045 .56642 .31612 Mtetra
.865 .914 .862 r
.56642 .31612 .57498 .32045 .59133 .30535 .58288 .29999 Mtetra
.842 .897 .877 r
.58288 .29999 .59133 .30535 .60772 .29174 .59937 .28543 Mtetra
.818 .878 .889 r
.59937 .28543 .60772 .29174 .62417 .27952 .6159 .27232 Mtetra
.793 .857 .898 r
.6159 .27232 .62417 .27952 .6407 .26852 .6325 .26054 Mtetra
.769 .837 .904 r
.6325 .26054 .6407 .26852 .65731 .25858 .64919 .24991 Mtetra
.748 .819 .908 r
.64919 .24991 .65731 .25858 .67403 .24952 .66597 .24028 Mtetra
.729 .802 .91 r
.66597 .24028 .67403 .24952 .69085 .2412 .68286 .23147 Mtetra
.713 .788 .91 r
.68286 .23147 .69085 .2412 .70779 .23345 .69986 .22332 Mtetra
.7 .776 .91 r
.69986 .22332 .70779 .23345 .72484 .22614 .71697 .21569 Mtetra
.69 .767 .91 r
.71697 .21569 .72484 .22614 .742 .21917 .7342 .20845 Mtetra
.683 .76 .91 r
.7342 .20845 .742 .21917 .75928 .21244 .75154 .20151 Mtetra
.677 .754 .909 r
.75154 .20151 .75928 .21244 .77667 .20588 .769 .19477 Mtetra
.673 .75 .909 r
.769 .19477 .77667 .20588 .79417 .19943 .78658 .18817 Mtetra
.67 .747 .909 r
.78658 .18817 .79417 .19943 .81179 .19305 .80427 .18166 Mtetra
.189 .38 .822 r
.1693 .44742 .17871 .46359 .1918 .47232 .18245 .45522 Mtetra
.135 .332 .796 r
.18245 .45522 .1918 .47232 .20496 .48242 .19564 .46451 Mtetra
.093 .294 .774 r
.19564 .46451 .20496 .48242 .21822 .49365 .20892 .47507 Mtetra
.068 .268 .758 r
.20892 .47507 .21822 .49365 .23164 .50561 .22232 .48659 Mtetra
.061 .259 .752 r
.22232 .48659 .23164 .50561 .24527 .51781 .23591 .49863 Mtetra
.074 .267 .755 r
.23591 .49863 .24527 .51781 .25916 .52965 .24975 .51064 Mtetra
.108 .294 .77 r
.24975 .51064 .25916 .52965 .27337 .54047 .26387 .522 Mtetra
.165 .34 .794 r
.26387 .522 .27337 .54047 .28794 .54956 .27833 .53202 Mtetra
.243 .404 .825 r
.27833 .53202 .28794 .54956 .30288 .55625 .29315 .54 Mtetra
.339 .483 .858 r
.29315 .54 .30288 .55625 .3182 .55993 .30837 .54529 Mtetra
.446 .57 .886 r
.30837 .54529 .3182 .55993 .33389 .56012 .32397 .54734 Mtetra
.555 .657 .904 r
.32397 .54734 .33389 .56012 .34993 .55652 .33993 .54574 Mtetra
.655 .735 .908 r
.33993 .54574 .34993 .55652 .36626 .54903 .35621 .54029 Mtetra
.74 .799 .899 r
.35621 .54029 .36626 .54903 .38282 .53778 .37277 .53099 Mtetra
.806 .846 .88 r
.37277 .53099 .38282 .53778 .39955 .52307 .38953 .51804 Mtetra
.854 .879 .857 r
.38953 .51804 .39955 .52307 .41638 .50541 .40643 .50186 Mtetra
.886 .9 .834 r
.40643 .50186 .41638 .50541 .43326 .48541 .42341 .48299 Mtetra
.907 .914 .814 r
.42341 .48299 .43326 .48541 .45013 .46375 .4404 .4621 Mtetra
.919 .922 .8 r
.4404 .4621 .45013 .46375 .46695 .44113 .45737 .43987 Mtetra
.925 .927 .791 r
.45737 .43987 .46695 .44113 .4837 .41823 .47428 .41699 Mtetra
.926 .93 .79 r
.47428 .41699 .4837 .41823 .50037 .39561 .49111 .39411 Mtetra
.923 .931 .794 r
.49111 .39411 .50037 .39561 .51696 .37378 .50786 .37175 Mtetra
.917 .93 .804 r
.50786 .37175 .51696 .37378 .53349 .35311 .52454 .35036 Mtetra
.906 .926 .818 r
.52454 .35036 .53349 .35311 .54997 .33384 .54116 .33025 Mtetra
.892 .919 .834 r
.54116 .33025 .54997 .33384 .56642 .31612 .55774 .31162 Mtetra
.874 .909 .851 r
.55774 .31162 .56642 .31612 .58288 .29999 .57432 .29457 Mtetra
.853 .896 .867 r
.57432 .29457 .58288 .29999 .59937 .28543 .5909 .2791 Mtetra
.829 .879 .88 r
.5909 .2791 .59937 .28543 .6159 .27232 .60753 .26515 Mtetra
.805 .861 .891 r
.60753 .26515 .6159 .27232 .6325 .26054 .62421 .2526 Mtetra
.78 .843 .899 r
.62421 .2526 .6325 .26054 .64919 .24991 .64097 .24129 Mtetra
.758 .824 .904 r
.64097 .24129 .64919 .24991 .66597 .24028 .65782 .23107 Mtetra
.738 .808 .907 r
.65782 .23107 .66597 .24028 .68286 .23147 .67478 .22175 Mtetra
.721 .793 .909 r
.67478 .22175 .68286 .23147 .69986 .22332 .69184 .21318 Mtetra
.707 .781 .91 r
.69184 .21318 .69986 .22332 .71697 .21569 .70902 .2052 Mtetra
.695 .771 .91 r
.70902 .2052 .71697 .21569 .7342 .20845 .72631 .19768 Mtetra
.686 .763 .91 r
.72631 .19768 .7342 .20845 .75154 .20151 .74372 .1905 Mtetra
.68 .757 .909 r
.74372 .1905 .75154 .20151 .769 .19477 .76125 .18357 Mtetra
.675 .752 .909 r
.76125 .18357 .769 .19477 .78658 .18817 .7789 .17681 Mtetra
.671 .749 .909 r
.7789 .17681 .78658 .18817 .80427 .18166 .79667 .17017 Mtetra
.248 .415 .832 r
.15983 .43107 .1693 .44742 .18245 .45522 .17307 .43779 Mtetra
.197 .367 .808 r
.17307 .43779 .18245 .45522 .19564 .46451 .18633 .44604 Mtetra
.155 .326 .785 r
.18633 .44604 .19564 .46451 .20892 .47507 .19964 .45567 Mtetra
.127 .296 .766 r
.19964 .45567 .20892 .47507 .22232 .48659 .21307 .46643 Mtetra
.116 .28 .755 r
.21307 .46643 .22232 .48659 .23591 .49863 .22665 .47794 Mtetra
.123 .28 .752 r
.22665 .47794 .23591 .49863 .24975 .51064 .24044 .48973 Mtetra
.149 .295 .758 r
.24044 .48973 .24975 .51064 .26387 .522 .25449 .50122 Mtetra
.193 .327 .772 r
.25449 .50122 .26387 .522 .27833 .53202 .26886 .51175 Mtetra
.255 .375 .793 r
.26886 .51175 .27833 .53202 .29315 .54 .28358 .52065 Mtetra
.333 .435 .816 r
.28358 .52065 .29315 .54 .30837 .54529 .29868 .52723 Mtetra
.421 .505 .84 r
.29868 .52723 .30837 .54529 .32397 .54734 .31417 .53089 Mtetra
.514 .579 .858 r
.31417 .53089 .32397 .54734 .33993 .54574 .33003 .53115 Mtetra
.606 .651 .868 r
.33003 .53115 .33993 .54574 .35621 .54029 .34625 .5277 Mtetra
.688 .715 .869 r
.34625 .5277 .35621 .54029 .37277 .53099 .36276 .52043 Mtetra
.758 .769 .862 r
.36276 .52043 .37277 .53099 .38953 .51804 .37952 .50942 Mtetra
.813 .812 .849 r
.37952 .50942 .38953 .51804 .40643 .50186 .39645 .49499 Mtetra
.853 .843 .834 r
.39645 .49499 .40643 .50186 .42341 .48299 .4135 .4776 Mtetra
.882 .867 .819 r
.4135 .4776 .42341 .48299 .4404 .4621 .43059 .45784 Mtetra
.902 .883 .806 r
.43059 .45784 .4404 .4621 .45737 .43987 .44768 .4364 Mtetra
.913 .895 .797 r
.44768 .4364 .45737 .43987 .47428 .41699 .46473 .41395 Mtetra
.918 .903 .794 r
.46473 .41395 .47428 .41699 .49111 .39411 .48172 .39116 Mtetra
.919 .908 .795 r
.48172 .39116 .49111 .39411 .50786 .37175 .49862 .36861 Mtetra
.915 .91 .802 r
.49862 .36861 .50786 .37175 .52454 .35036 .51545 .34679 Mtetra
.907 .91 .812 r
.51545 .34679 .52454 .35036 .54116 .33025 .53221 .32608 Mtetra
.895 .907 .826 r
.53221 .32608 .54116 .33025 .55774 .31162 .54893 .30673 Mtetra
.879 .9 .842 r
.54893 .30673 .55774 .31162 .57432 .29457 .56562 .2889 Mtetra
.86 .891 .857 r
.56562 .2889 .57432 .29457 .5909 .2791 .58232 .27263 Mtetra
.838 .878 .871 r
.58232 .27263 .5909 .2791 .60753 .26515 .59904 .2579 Mtetra
.814 .862 .883 r
.59904 .2579 .60753 .26515 .62421 .2526 .61581 .24462 Mtetra
.791 .845 .893 r
.61581 .24462 .62421 .2526 .64097 .24129 .63265 .23265 Mtetra
.768 .828 .899 r
.63265 .23265 .64097 .24129 .65782 .23107 .64957 .22184 Mtetra
.747 .812 .904 r
.64957 .22184 .65782 .23107 .67478 .22175 .6666 .21202 Mtetra
.728 .797 .907 r
.6666 .21202 .67478 .22175 .69184 .21318 .68373 .20301 Mtetra
.713 .785 .908 r
.68373 .20301 .69184 .21318 .70902 .2052 .70097 .19466 Mtetra
.7 .774 .909 r
.70097 .19466 .70902 .2052 .72631 .19768 .71833 .18684 Mtetra
.69 .766 .909 r
.71833 .18684 .72631 .19768 .74372 .1905 .73581 .17941 Mtetra
.683 .759 .909 r
.73581 .17941 .74372 .1905 .76125 .18357 .75341 .17227 Mtetra
.677 .754 .909 r
.75341 .17227 .76125 .18357 .7789 .17681 .77113 .16535 Mtetra
.673 .75 .909 r
.77113 .16535 .7789 .17681 .79667 .17017 .78897 .15856 Mtetra
.303 .45 .842 r
.15029 .41476 .15983 .43107 .17307 .43779 .16363 .4203 Mtetra
.254 .403 .819 r
.16363 .4203 .17307 .43779 .18633 .44604 .17698 .42735 Mtetra
.213 .361 .796 r
.17698 .42735 .18633 .44604 .19964 .45567 .19037 .43584 Mtetra
.184 .328 .776 r
.19037 .43584 .19964 .45567 .21307 .46643 .20383 .44556 Mtetra
.168 .306 .761 r
.20383 .44556 .21307 .46643 .22665 .47794 .21743 .45623 Mtetra
.169 .298 .753 r
.21743 .45623 .22665 .47794 .24044 .48973 .23121 .46742 Mtetra
.186 .304 .752 r
.23121 .46742 .24044 .48973 .25449 .50122 .24522 .47864 Mtetra
.22 .324 .758 r
.24522 .47864 .25449 .50122 .26886 .51175 .25952 .48928 Mtetra
.269 .358 .77 r
.25952 .48928 .26886 .51175 .28358 .52065 .27415 .49867 Mtetra
.331 .404 .786 r
.27415 .49867 .28358 .52065 .29868 .52723 .28914 .50616 Mtetra
.404 .459 .804 r
.28914 .50616 .29868 .52723 .31417 .53089 .30451 .51112 Mtetra
.483 .52 .82 r
.30451 .51112 .31417 .53089 .33003 .53115 .32027 .513 Mtetra
.563 .583 .831 r
.32027 .513 .33003 .53115 .34625 .5277 .33639 .5114 Mtetra
.639 .643 .838 r
.33639 .5114 .34625 .5277 .36276 .52043 .35283 .50612 Mtetra
.708 .698 .838 r
.35283 .50612 .36276 .52043 .37952 .50942 .36955 .49713 Mtetra
.766 .745 .833 r
.36955 .49713 .37952 .50942 .39645 .49499 .38648 .48462 Mtetra
.813 .783 .825 r
.38648 .48462 .39645 .49499 .4135 .4776 .40356 .46897 Mtetra
.849 .814 .815 r
.40356 .46897 .4135 .4776 .43059 .45784 .42072 .45068 Mtetra
.875 .838 .806 r
.42072 .45068 .43059 .45784 .44768 .4364 .43791 .43038 Mtetra
.892 .856 .799 r
.43791 .43038 .44768 .4364 .46473 .41395 .45508 .40874 Mtetra
.903 .87 .795 r
.45508 .40874 .46473 .41395 .48172 .39116 .4722 .38641 Mtetra
.908 .88 .796 r
.4722 .38641 .48172 .39116 .49862 .36861 .48925 .36402 Mtetra
.908 .886 .8 r
.48925 .36402 .49862 .36861 .51545 .34679 .50622 .34209 Mtetra
.903 .89 .808 r
.50622 .34209 .51545 .34679 .53221 .32608 .52313 .32105 Mtetra
.894 .891 .82 r
.52313 .32105 .53221 .32608 .54893 .30673 .53998 .30121 Mtetra
.88 .888 .834 r
.53998 .30121 .54893 .30673 .56562 .2889 .5568 .28278 Mtetra
.864 .882 .849 r
.5568 .28278 .56562 .2889 .58232 .27263 .57361 .26586 Mtetra
.844 .872 .863 r
.57361 .26586 .58232 .27263 .59904 .2579 .59043 .25045 Mtetra
.822 .86 .876 r
.59043 .25045 .59904 .2579 .61581 .24462 .6073 .23651 Mtetra
.799 .846 .886 r
.6073 .23651 .61581 .24462 .63265 .23265 .62422 .22392 Mtetra
.776 .831 .894 r
.62422 .22392 .63265 .23265 .64957 .22184 .64122 .21255 Mtetra
.755 .815 .9 r
.64122 .21255 .64957 .22184 .6666 .21202 .65832 .20222 Mtetra
.736 .801 .904 r
.65832 .20222 .6666 .21202 .68373 .20301 .67552 .19278 Mtetra
.719 .788 .906 r
.67552 .19278 .68373 .20301 .70097 .19466 .69284 .18407 Mtetra
.706 .777 .908 r
.69284 .18407 .70097 .19466 .71833 .18684 .71027 .17593 Mtetra
.695 .768 .908 r
.71027 .17593 .71833 .18684 .73581 .17941 .72782 .16824 Mtetra
.686 .761 .909 r
.72782 .16824 .73581 .17941 .75341 .17227 .74549 .16089 Mtetra
.679 .755 .909 r
.74549 .16089 .75341 .17227 .77113 .16535 .76328 .15378 Mtetra
.675 .751 .909 r
.76328 .15378 .77113 .16535 .78897 .15856 .78119 .14684 Mtetra
.355 .485 .852 r
.14066 .39869 .15029 .41476 .16363 .4203 .15411 .40298 Mtetra
.309 .439 .831 r
.15411 .40298 .16363 .4203 .17698 .42735 .16757 .40873 Mtetra
.268 .397 .808 r
.16757 .40873 .17698 .42735 .19037 .43584 .18105 .41591 Mtetra
.237 .361 .787 r
.18105 .41591 .19037 .43584 .20383 .44556 .19459 .4244 Mtetra
.218 .335 .77 r
.19459 .4244 .20383 .44556 .21743 .45623 .20823 .43396 Mtetra
.213 .32 .757 r
.20823 .43396 .21743 .45623 .23121 .46742 .22203 .44425 Mtetra
.222 .318 .751 r
.22203 .44425 .23121 .46742 .24522 .47864 .23602 .45483 Mtetra
.247 .329 .751 r
.23602 .45483 .24522 .47864 .25952 .48928 .25028 .46516 Mtetra
.284 .352 .756 r
.25028 .46516 .25952 .48928 .27415 .49867 .26483 .47465 Mtetra
.334 .385 .766 r
.26483 .47465 .27415 .49867 .28914 .50616 .27973 .48264 Mtetra
.394 .428 .778 r
.27973 .48264 .28914 .50616 .30451 .51112 .295 .48851 Mtetra
.46 .478 .79 r
.295 .48851 .30451 .51112 .32027 .513 .31064 .49169 Mtetra
.529 .531 .801 r
.31064 .49169 .32027 .513 .33639 .5114 .32665 .49172 Mtetra
.598 .585 .809 r
.32665 .49172 .33639 .5114 .35283 .50612 .34301 .48828 Mtetra
.663 .636 .813 r
.34301 .48828 .35283 .50612 .36955 .49713 .35966 .48127 Mtetra
.72 .684 .814 r
.35966 .48127 .36955 .49713 .38648 .48462 .37656 .47076 Mtetra
.77 .725 .811 r
.37656 .47076 .38648 .48462 .40356 .46897 .39363 .457 Mtetra
.81 .761 .807 r
.39363 .457 .40356 .46897 .42072 .45068 .41083 .44042 Mtetra
.842 .79 .802 r
.41083 .44042 .42072 .45068 .43791 .43038 .42809 .42157 Mtetra
.865 .814 .797 r
.42809 .42157 .43791 .43038 .45508 .40874 .44535 .40107 Mtetra
.881 .833 .795 r
.44535 .40107 .45508 .40874 .4722 .38641 .46258 .37958 Mtetra
.891 .848 .795 r
.46258 .37958 .4722 .38641 .48925 .36402 .47976 .35769 Mtetra
.895 .859 .798 r
.47976 .35769 .48925 .36402 .50622 .34209 .49687 .33598 Mtetra
.894 .867 .805 r
.49687 .33598 .50622 .34209 .52313 .32105 .51391 .3149 Mtetra
.888 .871 .815 r
.51391 .3149 .52313 .32105 .53998 .30121 .5309 .29483 Mtetra
.878 .872 .827 r
.5309 .29483 .53998 .30121 .5568 .28278 .54784 .27602 Mtetra
.864 .87 .841 r
.54784 .27602 .5568 .28278 .57361 .26586 .56477 .25861 Mtetra
.847 .864 .855 r
.56477 .25861 .57361 .26586 .59043 .25045 .5817 .24266 Mtetra
.827 .855 .868 r
.5817 .24266 .59043 .25045 .6073 .23651 .59866 .22816 Mtetra
.805 .843 .88 r
.59866 .22816 .6073 .23651 .62422 .22392 .61568 .21502 Mtetra
.783 .83 .889 r
.61568 .21502 .62422 .22392 .64122 .21255 .63277 .20313 Mtetra
.762 .817 .896 r
.63277 .20313 .64122 .21255 .65832 .20222 .64994 .19233 Mtetra
.742 .803 .901 r
.64994 .19233 .65832 .20222 .67552 .19278 .66722 .18247 Mtetra
.725 .791 .904 r
.66722 .18247 .67552 .19278 .69284 .18407 .6846 .17338 Mtetra
.711 .78 .906 r
.6846 .17338 .69284 .18407 .71027 .17593 .70211 .16493 Mtetra
.699 .771 .907 r
.70211 .16493 .71027 .17593 .72782 .16824 .71973 .15698 Mtetra
.689 .763 .908 r
.71973 .15698 .72782 .16824 .74549 .16089 .73747 .1494 Mtetra
.682 .757 .908 r
.73747 .1494 .74549 .16089 .76328 .15378 .75534 .1421 Mtetra
.676 .753 .908 r
.75534 .1421 .76328 .15378 .78119 .14684 .77333 .13501 Mtetra
.402 .518 .861 r
.1309 .383 .14066 .39869 .15411 .40298 .14448 .38602 Mtetra
.359 .475 .842 r
.14448 .38602 .15411 .40298 .16757 .40873 .15806 .39042 Mtetra
.32 .434 .821 r
.15806 .39042 .16757 .40873 .18105 .41591 .17166 .39622 Mtetra
.288 .396 .8 r
.17166 .39622 .18105 .41591 .19459 .4244 .18529 .40332 Mtetra
.266 .367 .781 r
.18529 .40332 .19459 .4244 .20823 .43396 .19901 .41157 Mtetra
.255 .347 .765 r
.19901 .41157 .20823 .43396 .22203 .44425 .21285 .4207 Mtetra
.258 .338 .755 r
.21285 .4207 .22203 .44425 .23602 .45483 .22686 .43034 Mtetra
.274 .34 .75 r
.22686 .43034 .23602 .45483 .25028 .46516 .2411 .44002 Mtetra
.302 .353 .749 r
.2411 .44002 .25028 .46516 .26483 .47465 .25561 .4492 Mtetra
.341 .377 .753 r
.25561 .4492 .26483 .47465 .27973 .48264 .27044 .45729 Mtetra
.39 .41 .761 r
.27044 .45729 .27973 .48264 .295 .48851 .28561 .46368 Mtetra
.445 .449 .769 r
.28561 .46368 .295 .48851 .31064 .49169 .30114 .46778 Mtetra
.504 .493 .778 r
.30114 .46778 .31064 .49169 .32665 .49172 .31704 .46912 Mtetra
.565 .54 .786 r
.31704 .46912 .32665 .49172 .34301 .48828 .33329 .4673 Mtetra
.624 .587 .792 r
.33329 .4673 .34301 .48828 .35966 .48127 .34986 .46213 Mtetra
.679 .631 .795 r
.34986 .46213 .35966 .48127 .37656 .47076 .36669 .45356 Mtetra
.728 .673 .796 r
.36669 .45356 .37656 .47076 .39363 .457 .38374 .44176 Mtetra
.771 .71 .795 r
.38374 .44176 .39363 .457 .41083 .44042 .40094 .42704 Mtetra
.806 .743 .794 r
.40094 .42704 .41083 .44042 .42809 .42157 .41823 .40987 Mtetra
.834 .771 .792 r
.41823 .40987 .42809 .42157 .44535 .40107 .43556 .3908 Mtetra
.855 .794 .791 r
.43556 .3908 .44535 .40107 .46258 .37958 .45288 .37044 Mtetra
.869 .813 .792 r
.45288 .37044 .46258 .37958 .47976 .35769 .47017 .34939 Mtetra
.877 .829 .796 r
.47017 .34939 .47976 .35769 .49687 .33598 .4874 .32821 Mtetra
.88 .84 .802 r
.4874 .32821 .49687 .33598 .51391 .3149 .50457 .30741 Mtetra
.878 .849 .81 r
.50457 .30741 .51391 .3149 .5309 .29483 .52168 .28737 Mtetra
.872 .853 .822 r
.52168 .28737 .5309 .29483 .54784 .27602 .53875 .26841 Mtetra
.861 .855 .834 r
.53875 .26841 .54784 .27602 .56477 .25861 .5558 .25071 Mtetra
.846 .852 .848 r
.5558 .25071 .56477 .25861 .5817 .24266 .57285 .23439 Mtetra
.828 .847 .861 r
.57285 .23439 .5817 .24266 .59866 .22816 .58991 .21945 Mtetra
.809 .839 .873 r
.58991 .21945 .59866 .22816 .61568 .21502 .60702 .20585 Mtetra
.788 .828 .883 r
.60702 .20585 .61568 .21502 .63277 .20313 .6242 .1935 Mtetra
.767 .816 .891 r
.6242 .1935 .63277 .20313 .64994 .19233 .64146 .18227 Mtetra
.748 .804 .897 r
.64146 .18227 .64994 .19233 .66722 .18247 .65881 .17202 Mtetra
.73 .792 .902 r
.65881 .17202 .66722 .18247 .6846 .17338 .67627 .16259 Mtetra
.715 .782 .904 r
.67627 .16259 .6846 .17338 .70211 .16493 .69385 .15383 Mtetra
.703 .773 .906 r
.69385 .15383 .70211 .16493 .71973 .15698 .71154 .14561 Mtetra
.693 .765 .907 r
.71154 .14561 .71973 .15698 .73747 .1494 .72936 .1378 Mtetra
.685 .759 .908 r
.72936 .1378 .73747 .1494 .75534 .1421 .7473 .13031 Mtetra
.678 .754 .908 r
.7473 .13031 .75534 .1421 .77333 .13501 .76536 .12305 Mtetra
.444 .551 .87 r
.121 .36778 .1309 .383 .14448 .38602 .13472 .36956 Mtetra
.405 .511 .853 r
.13472 .36956 .14448 .38602 .15806 .39042 .14844 .37262 Mtetra
.368 .471 .833 r
.14844 .37262 .15806 .39042 .17166 .39622 .16216 .37699 Mtetra
.336 .433 .813 r
.16216 .37699 .17166 .39622 .18529 .40332 .17591 .38264 Mtetra
.311 .401 .793 r
.17591 .38264 .18529 .40332 .19901 .41157 .18972 .38946 Mtetra
.297 .377 .776 r
.18972 .38946 .19901 .41157 .21285 .4207 .20364 .39724 Mtetra
.294 .362 .762 r
.20364 .39724 .21285 .4207 .22686 .43034 .2177 .40569 Mtetra
.302 .357 .753 r
.2177 .40569 .22686 .43034 .2411 .44002 .23195 .41442 Mtetra
.322 .362 .748 r
.23195 .41442 .2411 .44002 .25561 .4492 .24644 .42296 Mtetra
.352 .377 .748 r
.24644 .42296 .25561 .4492 .27044 .45729 .26121 .43076 Mtetra
.39 .401 .75 r
.26121 .43076 .27044 .45729 .28561 .46368 .27631 .43727 Mtetra
.436 .431 .756 r
.27631 .43727 .28561 .46368 .30114 .46778 .29175 .44192 Mtetra
.486 .467 .762 r
.29175 .44192 .30114 .46778 .31704 .46912 .30754 .44421 Mtetra
.539 .507 .768 r
.30754 .44421 .31704 .46912 .33329 .4673 .32368 .44371 Mtetra
.592 .548 .774 r
.32368 .44371 .33329 .4673 .34986 .46213 .34015 .44014 Mtetra
.643 .589 .779 r
.34015 .44014 .34986 .46213 .36669 .45356 .3569 .43339 Mtetra
.691 .629 .782 r
.3569 .43339 .36669 .45356 .38374 .44176 .37389 .4235 Mtetra
.733 .666 .784 r
.37389 .4235 .38374 .44176 .40094 .42704 .39106 .41069 Mtetra
.77 .699 .785 r
.39106 .41069 .40094 .42704 .41823 .40987 .40836 .39533 Mtetra
.801 .73 .785 r
.40836 .39533 .41823 .40987 .43556 .3908 .42573 .37789 Mtetra
.825 .756 .786 r
.42573 .37789 .43556 .3908 .45288 .37044 .44311 .35891 Mtetra
.844 .778 .789 r
.44311 .35891 .45288 .37044 .47017 .34939 .46049 .33898 Mtetra
.856 .797 .792 r
.46049 .33898 .47017 .34939 .4874 .32821 .47782 .31864 Mtetra
.863 .813 .798 r
.47782 .31864 .4874 .32821 .50457 .30741 .49511 .29839 Mtetra
.865 .824 .807 r
.49511 .29839 .50457 .30741 .52168 .28737 .51235 .27866 Mtetra
.862 .833 .817 r
.51235 .27866 .52168 .28737 .53875 .26841 .52954 .2598 Mtetra
.854 .837 .829 r
.52954 .2598 .53875 .26841 .5558 .25071 .54671 .24202 Mtetra
.842 .839 .842 r
.54671 .24202 .5558 .25071 .57285 .23439 .56386 .22549 Mtetra
.827 .836 .854 r
.56386 .22549 .57285 .23439 .58991 .21945 .58104 .21026 Mtetra
.81 .831 .867 r
.58104 .21026 .58991 .21945 .60702 .20585 .59825 .19632 Mtetra
.791 .823 .878 r
.59825 .19632 .60702 .20585 .6242 .1935 .61552 .1836 Mtetra
.771 .814 .886 r
.61552 .1836 .6242 .1935 .64146 .18227 .63286 .172 Mtetra
.752 .803 .893 r
.63286 .172 .64146 .18227 .65881 .17202 .6503 .1614 Mtetra
.735 .793 .899 r
.6503 .1614 .65881 .17202 .67627 .16259 .66784 .15164 Mtetra
.72 .783 .902 r
.66784 .15164 .67627 .16259 .69385 .15383 .68549 .14259 Mtetra
.706 .774 .905 r
.68549 .14259 .69385 .15383 .71154 .14561 .70326 .13411 Mtetra
.696 .766 .906 r
.70326 .13411 .71154 .14561 .72936 .1378 .72115 .12608 Mtetra
.687 .76 .907 r
.72115 .12608 .72936 .1378 .7473 .13031 .73917 .1184 Mtetra
.68 .755 .908 r
.73917 .1184 .7473 .13031 .76536 .12305 .75731 .11096 Mtetra
.483 .581 .877 r
.11095 .35308 .121 .36778 .13472 .36956 .12481 .3537 Mtetra
.448 .544 .862 r
.12481 .3537 .13472 .36956 .14844 .37262 .13867 .35546 Mtetra
.413 .507 .845 r
.13867 .35546 .14844 .37262 .16216 .37699 .15253 .35842 Mtetra
.381 .47 .826 r
.15253 .35842 .16216 .37699 .17591 .38264 .16641 .3626 Mtetra
.356 .437 .807 r
.16641 .3626 .17591 .38264 .18972 .38946 .18034 .36792 Mtetra
.338 .409 .788 r
.18034 .36792 .18972 .38946 .20364 .39724 .19435 .37424 Mtetra
.329 .389 .773 r
.19435 .37424 .20364 .39724 .2177 .40569 .20848 .38133 Mtetra
.331 .379 .76 r
.20848 .38133 .2177 .40569 .23195 .41442 .22277 .38889 Mtetra
.344 .377 .752 r
.22277 .38889 .23195 .41442 .24644 .42296 .23727 .39649 Mtetra
.365 .384 .747 r
.23727 .39649 .24644 .42296 .26121 .43076 .25202 .40369 Mtetra
.396 .4 .746 r
.25202 .40369 .26121 .43076 .27631 .43727 .26707 .40996 Mtetra
.433 .423 .748 r
.26707 .40996 .27631 .43727 .29175 .44192 .28243 .41478 Mtetra
.475 .451 .752 r
.28243 .41478 .29175 .44192 .30754 .44421 .29813 .41764 Mtetra
.52 .484 .756 r
.29813 .41764 .30754 .44421 .32368 .44371 .31417 .41811 Mtetra
.567 .519 .761 r
.31417 .41811 .32368 .44371 .34015 .44014 .33053 .41587 Mtetra
.613 .555 .766 r
.33053 .41587 .34015 .44014 .3569 .43339 .34719 .41071 Mtetra
.658 .592 .77 r
.34719 .41071 .3569 .43339 .37389 .4235 .36411 .40259 Mtetra
.699 .627 .773 r
.36411 .40259 .37389 .4235 .39106 .41069 .38123 .39164 Mtetra
.736 .661 .776 r
.38123 .39164 .39106 .41069 .40836 .39533 .3985 .37813 Mtetra
.768 .692 .778 r
.3985 .37813 .40836 .39533 .42573 .37789 .41588 .36243 Mtetra
.795 .72 .781 r
.41588 .36243 .42573 .37789 .44311 .35891 .4333 .34502 Mtetra
.816 .744 .784 r
.4333 .34502 .44311 .35891 .46049 .33898 .45074 .32642 Mtetra
.832 .766 .789 r
.45074 .32642 .46049 .33898 .47782 .31864 .46816 .30716 Mtetra
.843 .784 .795 r
.46816 .30716 .47782 .31864 .49511 .29839 .48555 .28773 Mtetra
.848 .799 .803 r
.48555 .28773 .49511 .29839 .51235 .27866 .5029 .26857 Mtetra
.848 .81 .812 r
.5029 .26857 .51235 .27866 .52954 .2598 .5202 .25004 Mtetra
.844 .818 .824 r
.5202 .25004 .52954 .2598 .54671 .24202 .53749 .23241 Mtetra
.836 .823 .836 r
.53749 .23241 .54671 .24202 .56386 .22549 .55476 .21586 Mtetra
.824 .824 .849 r
.55476 .21586 .56386 .22549 .58104 .21026 .57204 .20049 Mtetra
.809 .822 .861 r
.57204 .20049 .58104 .21026 .59825 .19632 .58935 .18633 Mtetra
.791 .817 .872 r
.58935 .18633 .59825 .19632 .61552 .1836 .60672 .17335 Mtetra
.773 .81 .882 r
.60672 .17335 .61552 .1836 .63286 .172 .62415 .16146 Mtetra
.755 .801 .889 r
.62415 .16146 .63286 .172 .6503 .1614 .64168 .15055 Mtetra
.738 .792 .895 r
.64168 .15055 .6503 .1614 .66784 .15164 .6593 .14051 Mtetra
.723 .783 .9 r
.6593 .14051 .66784 .15164 .68549 .14259 .67703 .13119 Mtetra
.71 .775 .903 r
.67703 .13119 .68549 .14259 .70326 .13411 .69488 .12247 Mtetra
.699 .767 .905 r
.69488 .12247 .70326 .13411 .72115 .12608 .71285 .11422 Mtetra
.689 .761 .906 r
.71285 .11422 .72115 .12608 .73917 .1184 .73094 .10634 Mtetra
.682 .756 .907 r
.73094 .10634 .73917 .1184 .75731 .11096 .74916 .09874 Mtetra
.516 .608 .883 r
.10074 .33893 .11095 .35308 .12481 .3537 .11474 .33846 Mtetra
.485 .576 .871 r
.11474 .33846 .12481 .3537 .13867 .35546 .12874 .33901 Mtetra
.454 .541 .856 r
.12874 .33901 .13867 .35546 .15253 .35842 .14274 .34063 Mtetra
.424 .506 .839 r
.14274 .34063 .15253 .35842 .16641 .3626 .15676 .34336 Mtetra
.398 .473 .821 r
.15676 .34336 .16641 .3626 .18034 .36792 .17082 .34718 Mtetra
.378 .444 .802 r
.17082 .34718 .18034 .36792 .19435 .37424 .18494 .352 Mtetra
.365 .42 .785 r
.18494 .352 .19435 .37424 .20848 .38133 .19916 .35764 Mtetra
.362 .405 .771 r
.19916 .35764 .20848 .38133 .22277 .38889 .21352 .36386 Mtetra
.368 .397 .76 r
.21352 .36386 .22277 .38889 .23727 .39649 .22806 .37033 Mtetra
.382 .398 .752 r
.22806 .37033 .23727 .39649 .25202 .40369 .24282 .37665 Mtetra
.405 .406 .747 r
.24282 .37665 .25202 .40369 .26707 .40996 .25784 .38237 Mtetra
.434 .422 .746 r
.25784 .38237 .26707 .40996 .28243 .41478 .27315 .387 Mtetra
.469 .443 .747 r
.27315 .387 .28243 .41478 .29813 .41764 .28878 .39008 Mtetra
.507 .469 .749 r
.28878 .39008 .29813 .41764 .31417 .41811 .30472 .39118 Mtetra
.548 .499 .753 r
.30472 .39118 .31417 .41811 .33053 .41587 .32099 .38992 Mtetra
.59 .53 .756 r
.32099 .38992 .33053 .41587 .34719 .41071 .33755 .38608 Mtetra
.631 .563 .76 r
.33755 .38608 .34719 .41071 .36411 .40259 .35438 .37953 Mtetra
.67 .596 .764 r
.35438 .37953 .36411 .40259 .38123 .39164 .37143 .37031 Mtetra
.706 .628 .768 r
.37143 .37031 .38123 .39164 .3985 .37813 .38866 .35858 Mtetra
.738 .658 .772 r
.38866 .35858 .3985 .37813 .41588 .36243 .40602 .34464 Mtetra
.766 .687 .775 r
.40602 .34464 .41588 .36243 .4333 .34502 .42346 .32889 Mtetra
.789 .713 .78 r
.42346 .32889 .4333 .34502 .45074 .32642 .44094 .31178 Mtetra
.807 .736 .785 r
.44094 .31178 .45074 .32642 .46816 .30716 .45843 .29379 Mtetra
.821 .756 .791 r
.45843 .29379 .46816 .30716 .48555 .28773 .4759 .27539 Mtetra
.829 .773 .799 r
.4759 .27539 .48555 .28773 .5029 .26857 .49334 .25702 Mtetra
.833 .788 .809 r
.49334 .25702 .5029 .26857 .5202 .25004 .51076 .23905 Mtetra
.832 .798 .82 r
.51076 .23905 .5202 .25004 .53749 .23241 .52815 .22177 Mtetra
.826 .806 .831 r
.52815 .22177 .53749 .23241 .55476 .21586 .54553 .20539 Mtetra
.817 .81 .844 r
.54553 .20539 .55476 .21586 .57204 .20049 .56292 .19005 Mtetra
.805 .811 .856 r
.56292 .19005 .57204 .20049 .58935 .18633 .58034 .17581 Mtetra
.79 .808 .867 r
.58034 .17581 .58935 .18633 .60672 .17335 .5978 .16267 Mtetra
.774 .804 .877 r
.5978 .16267 .60672 .17335 .62415 .16146 .61533 .15057 Mtetra
.757 .797 .886 r
.61533 .15057 .62415 .16146 .64168 .15055 .63294 .13943 Mtetra
.741 .79 .892 r
.63294 .13943 .64168 .15055 .6593 .14051 .65065 .12915 Mtetra
.726 .782 .897 r
.65065 .12915 .6593 .14051 .67703 .13119 .66846 .1196 Mtetra
.712 .774 .901 r
.66846 .1196 .67703 .13119 .69488 .12247 .68639 .11065 Mtetra
.701 .768 .904 r
.68639 .11065 .69488 .12247 .71285 .11422 .70444 .10221 Mtetra
.692 .762 .905 r
.70444 .10221 .71285 .11422 .73094 .10634 .72261 .09414 Mtetra
.684 .757 .906 r
.72261 .09414 .73094 .10634 .74916 .09874 .74091 .08638 Mtetra
.545 .632 .888 r
.09036 .32532 .10074 .33893 .11474 .33846 .10449 .32387 Mtetra
.519 .604 .879 r
.10449 .32387 .11474 .33846 .12874 .33901 .11863 .32329 Mtetra
.491 .574 .866 r
.11863 .32329 .12874 .33901 .14274 .34063 .13278 .32367 Mtetra
.463 .541 .851 r
.13278 .32367 .14274 .34063 .15676 .34336 .14694 .32504 Mtetra
.438 .509 .834 r
.14694 .32504 .15676 .34336 .17082 .34718 .16114 .32741 Mtetra
.416 .479 .817 r
.16114 .32741 .17082 .34718 .18494 .352 .17539 .33073 Mtetra
.401 .453 .8 r
.17539 .33073 .18494 .352 .19916 .35764 .18972 .33488 Mtetra
.393 .434 .784 r
.18972 .33488 .19916 .35764 .21352 .36386 .20417 .33969 Mtetra
.393 .421 .771 r
.20417 .33969 .21352 .36386 .22806 .37033 .21877 .34488 Mtetra
.402 .416 .76 r
.21877 .34488 .22806 .37033 .24282 .37665 .23357 .35012 Mtetra
.417 .418 .753 r
.23357 .35012 .24282 .37665 .25784 .38237 .24859 .35504 Mtetra
.44 .427 .748 r
.24859 .35504 .25784 .38237 .27315 .387 .26387 .3592 Mtetra
.468 .442 .747 r
.26387 .3592 .27315 .387 .28878 .39008 .27944 .36217 Mtetra
.5 .462 .747 r
.27944 .36217 .28878 .39008 .30472 .39118 .29531 .36355 Mtetra
.535 .486 .748 r
.29531 .36355 .30472 .39118 .32099 .38992 .31149 .36295 Mtetra
.572 .513 .751 r
.31149 .36295 .32099 .38992 .33755 .38608 .32796 .36012 Mtetra
.608 .542 .754 r
.32796 .36012 .33755 .38608 .35438 .37953 .3447 .35487 Mtetra
.644 .572 .758 r
.3447 .35487 .35438 .37953 .37143 .37031 .36167 .34717 Mtetra
.679 .601 .762 r
.36167 .34717 .37143 .37031 .38866 .35858 .37885 .3371 Mtetra
.71 .63 .766 r
.37885 .3371 .38866 .35858 .40602 .34464 .39618 .32486 Mtetra
.738 .658 .771 r
.39618 .32486 .40602 .34464 .42346 .32889 .41361 .31078 Mtetra
.762 .684 .776 r
.41361 .31078 .42346 .32889 .44094 .31178 .43111 .29523 Mtetra
.783 .708 .782 r
.43111 .29523 .44094 .31178 .45843 .29379 .44863 .27863 Mtetra
.798 .73 .788 r
.44863 .27863 .45843 .29379 .4759 .27539 .46617 .26142 Mtetra
.809 .749 .796 r
.46617 .26142 .4759 .27539 .49334 .25702 .48369 .24402 Mtetra
.815 .765 .806 r
.48369 .24402 .49334 .25702 .51076 .23905 .5012 .22679 Mtetra
.817 .778 .816 r
.5012 .22679 .51076 .23905 .52815 .22177 .51869 .21005 Mtetra
.815 .788 .827 r
.51869 .21005 .52815 .22177 .54553 .20539 .53618 .19402 Mtetra
.808 .795 .839 r
.53618 .19402 .54553 .20539 .56292 .19005 .55368 .17887 Mtetra
.799 .798 .851 r
.55368 .17887 .56292 .19005 .58034 .17581 .5712 .16468 Mtetra
.786 .799 .863 r
.5712 .16468 .58034 .17581 .5978 .16267 .58876 .1515 Mtetra
.772 .796 .873 r
.58876 .1515 .5978 .16267 .61533 .15057 .60639 .13929 Mtetra
.757 .792 .882 r
.60639 .13929 .61533 .15057 .63294 .13943 .62409 .128 Mtetra
.742 .786 .889 r
.62409 .128 .63294 .13943 .65065 .12915 .64189 .11753 Mtetra
.727 .78 .895 r
.64189 .11753 .65065 .12915 .66846 .1196 .65979 .10778 Mtetra
.714 .774 .899 r
.65979 .10778 .66846 .1196 .68639 .11065 .6778 .09865 Mtetra
.703 .767 .902 r
.6778 .09865 .68639 .11065 .70444 .10221 .69593 .09001 Mtetra
.693 .762 .904 r
.69593 .09001 .70444 .10221 .72261 .09414 .71418 .08178 Mtetra
.686 .757 .906 r
.71418 .08178 .72261 .09414 .74091 .08638 .73256 .07386 Mtetra
.57 .654 .893 r
.0798 .31219 .09036 .32532 .10449 .32387 .09406 .30988 Mtetra
.547 .63 .885 r
.09406 .30988 .10449 .32387 .11863 .32329 .10834 .30831 Mtetra
.523 .603 .875 r
.10834 .30831 .11863 .32329 .13278 .32367 .12263 .30755 Mtetra
.499 .574 .862 r
.12263 .30755 .13278 .32367 .14694 .32504 .13693 .30766 Mtetra
.475 .544 .847 r
.13693 .30766 .14694 .32504 .16114 .32741 .15127 .30866 Mtetra
.453 .514 .831 r
.15127 .30866 .16114 .32741 .17539 .33073 .16566 .31055 Mtetra
.436 .488 .815 r
.16566 .31055 .17539 .33073 .18972 .33488 .18012 .31325 Mtetra
.425 .466 .798 r
.18012 .31325 .18972 .33488 .20417 .33969 .19467 .31661 Mtetra
.421 .449 .784 r
.19467 .31661 .20417 .33969 .21877 .34488 .20936 .32045 Mtetra
.423 .439 .772 r
.20936 .32045 .21877 .34488 .23357 .35012 .22421 .3245 Mtetra
.433 .436 .762 r
.22421 .3245 .23357 .35012 .24859 .35504 .23926 .32843 Mtetra
.449 .439 .755 r
.23926 .32843 .24859 .35504 .26387 .3592 .25454 .33188 Mtetra
.471 .448 .751 r
.25454 .33188 .26387 .3592 .27944 .36217 .27008 .33447 Mtetra
.497 .462 .749 r
.27008 .33447 .27944 .36217 .29531 .36355 .2859 .33582 Mtetra
.527 .481 .748 r
.2859 .33582 .29531 .36355 .31149 .36295 .302 .33556 Mtetra
.558 .503 .75 r
.302 .33556 .31149 .36295 .32796 .36012 .31839 .33342 Mtetra
.591 .527 .752 r
.31839 .33342 .32796 .36012 .3447 .35487 .33504 .32918 Mtetra
.624 .554 .755 r
.33504 .32918 .3447 .35487 .36167 .34717 .35194 .32276 Mtetra
.656 .58 .759 r
.35194 .32276 .36167 .34717 .37885 .3371 .36905 .31415 Mtetra
.686 .608 .763 r
.36905 .31415 .37885 .3371 .39618 .32486 .38633 .30349 Mtetra
.713 .634 .768 r
.38633 .30349 .39618 .32486 .41361 .31078 .40374 .291 Mtetra
.738 .66 .773 r
.40374 .291 .41361 .31078 .43111 .29523 .42124 .277 Mtetra
.759 .684 .779 r
.42124 .277 .43111 .29523 .44863 .27863 .43879 .26185 Mtetra
.776 .706 .786 r
.43879 .26185 .44863 .27863 .46617 .26142 .45637 .24593 Mtetra
.789 .726 .794 r
.45637 .24593 .46617 .26142 .48369 .24402 .47396 .22963 Mtetra
.797 .744 .803 r
.47396 .22963 .48369 .24402 .5012 .22679 .49155 .21329 Mtetra
.802 .758 .813 r
.49155 .21329 .5012 .22679 .51869 .21005 .50913 .19724 Mtetra
.802 .77 .824 r
.50913 .19724 .51869 .21005 .53618 .19402 .52672 .18172 Mtetra
.798 .779 .836 r
.52672 .18172 .53618 .19402 .55368 .17887 .54432 .1669 Mtetra
.791 .785 .847 r
.54432 .1669 .55368 .17887 .5712 .16468 .56194 .1529 Mtetra
.781 .788 .859 r
.56194 .1529 .5712 .16468 .58876 .1515 .5796 .13979 Mtetra
.768 .788 .869 r
.5796 .13979 .58876 .1515 .60639 .13929 .59733 .12757 Mtetra
.755 .786 .878 r
.59733 .12757 .60639 .13929 .62409 .128 .61512 .1162 Mtetra
.741 .782 .886 r
.61512 .1162 .62409 .128 .64189 .11753 .63301 .10561 Mtetra
.728 .777 .892 r
.63301 .10561 .64189 .11753 .65979 .10778 .651 .09572 Mtetra
.715 .772 .897 r
.651 .09572 .65979 .10778 .6778 .09865 .66909 .08642 Mtetra
.704 .766 .9 r
.66909 .08642 .6778 .09865 .69593 .09001 .68731 .07763 Mtetra
.695 .761 .903 r
.68731 .07763 .69593 .09001 .71418 .08178 .70565 .06924 Mtetra
.687 .757 .905 r
.70565 .06924 .71418 .08178 .73256 .07386 .72411 .06117 Mtetra
.59 .672 .896 r
.06907 .2995 .0798 .31219 .09406 .30988 .08345 .29645 Mtetra
.572 .652 .89 r
.08345 .29645 .09406 .30988 .10834 .30831 .09786 .294 Mtetra
.552 .629 .882 r
.09786 .294 .10834 .30831 .12263 .30755 .11228 .29223 Mtetra
.53 .604 .872 r
.11228 .29223 .12263 .30755 .13693 .30766 .12673 .2912 Mtetra
.508 .576 .859 r
.12673 .2912 .13693 .30766 .15127 .30866 .14121 .29096 Mtetra
.488 .549 .845 r
.14121 .29096 .15127 .30866 .16566 .31055 .15574 .29151 Mtetra
.47 .522 .829 r
.15574 .29151 .16566 .31055 .18012 .31325 .17033 .29282 Mtetra
.457 .499 .814 r
.17033 .29282 .18012 .31325 .19467 .31661 .185 .29478 Mtetra
.449 .48 .799 r
.185 .29478 .19467 .31661 .20936 .32045 .19979 .29726 Mtetra
.447 .466 .785 r
.19979 .29726 .20936 .32045 .22421 .3245 .21471 .30004 Mtetra
.452 .458 .774 r
.21471 .30004 .22421 .3245 .23926 .32843 .22981 .30287 Mtetra
.462 .456 .765 r
.22981 .30287 .23926 .32843 .25454 .33188 .24512 .30545 Mtetra
.478 .459 .758 r
.24512 .30545 .25454 .33188 .27008 .33447 .26065 .30744 Mtetra
.499 .468 .754 r
.26065 .30744 .27008 .33447 .2859 .33582 .27644 .3085 Mtetra
.523 .482 .752 r
.27644 .3085 .2859 .33582 .302 .33556 .29249 .3083 Mtetra
.55 .499 .752 r
.29249 .3083 .302 .33556 .31839 .33342 .30881 .30655 Mtetra
.579 .519 .752 r
.30881 .30655 .31839 .33342 .33504 .32918 .32539 .30303 Mtetra
.608 .542 .755 r
.32539 .30303 .33504 .32918 .35194 .32276 .34222 .2976 Mtetra
.637 .566 .758 r
.34222 .2976 .35194 .32276 .36905 .31415 .35926 .29022 Mtetra
.665 .59 .762 r
.35926 .29022 .36905 .31415 .38633 .30349 .37648 .28095 Mtetra
.691 .615 .766 r
.37648 .28095 .38633 .30349 .40374 .291 .39386 .26994 Mtetra
.715 .639 .772 r
.39386 .26994 .40374 .291 .42124 .277 .41134 .25742 Mtetra
.736 .663 .778 r
.41134 .25742 .42124 .277 .43879 .26185 .4289 .2437 Mtetra
.754 .685 .785 r
.4289 .2437 .43879 .26185 .45637 .24593 .44651 .2291 Mtetra
.768 .705 .793 r
.44651 .2291 .45637 .24593 .47396 .22963 .46415 .21396 Mtetra
.779 .724 .802 r
.46415 .21396 .47396 .22963 .49155 .21329 .48181 .19863 Mtetra
.785 .74 .811 r
.48181 .19863 .49155 .21329 .50913 .19724 .49947 .18339 Mtetra
.787 .753 .822 r
.49947 .18339 .50913 .19724 .52672 .18172 .51715 .16849 Mtetra
.786 .764 .833 r
.51715 .16849 .52672 .18172 .54432 .1669 .53484 .15414 Mtetra
.781 .772 .845 r
.53484 .15414 .54432 .1669 .56194 .1529 .55256 .14045 Mtetra
.774 .777 .856 r
.55256 .14045 .56194 .1529 .5796 .13979 .57033 .12752 Mtetra
.763 .779 .866 r
.57033 .12752 .5796 .13979 .59733 .12757 .58815 .11538 Mtetra
.752 .779 .875 r
.58815 .11538 .59733 .12757 .61512 .1162 .60604 .10401 Mtetra
.739 .777 .883 r
.60604 .10401 .61512 .1162 .63301 .10561 .62402 .09336 Mtetra
.727 .774 .89 r
.62402 .09336 .63301 .10561 .651 .09572 .6421 .08337 Mtetra
.715 .769 .895 r
.6421 .08337 .651 .09572 .66909 .08642 .66028 .07396 Mtetra
.705 .765 .899 r
.66028 .07396 .66909 .08642 .68731 .07763 .67858 .06504 Mtetra
.696 .761 .902 r
.67858 .06504 .68731 .07763 .70565 .06924 .69701 .05651 Mtetra
.688 .757 .904 r
.69701 .05651 .70565 .06924 .72411 .06117 .71556 .0483 Mtetra
.607 .687 .899 r
.05816 .28719 .06907 .2995 .08345 .29645 .07266 .2835 Mtetra
.592 .671 .894 r
.07266 .2835 .08345 .29645 .09786 .294 .08718 .28029 Mtetra
.575 .652 .888 r
.08718 .28029 .09786 .294 .11228 .29223 .10174 .27764 Mtetra
.557 .63 .88 r
.10174 .27764 .11228 .29223 .12673 .2912 .11633 .27562 Mtetra
.538 .606 .869 r
.11633 .27562 .12673 .2912 .14121 .29096 .13095 .27427 Mtetra
.519 .581 .857 r
.13095 .27427 .14121 .29096 .15574 .29151 .14561 .2736 Mtetra
.502 .556 .843 r
.14561 .2736 .15574 .29151 .17033 .29282 .16034 .27362 Mtetra
.488 .532 .829 r
.16034 .27362 .17033 .29282 .185 .29478 .17513 .27425 Mtetra
.478 .512 .814 r
.17513 .27425 .185 .29478 .19979 .29726 .19003 .27541 Mtetra
.472 .495 .801 r
.19003 .27541 .19979 .29726 .21471 .30004 .20505 .27693 Mtetra
.473 .483 .788 r
.20505 .27693 .21471 .30004 .22981 .30287 .22022 .27861 Mtetra
.478 .477 .778 r
.22022 .27861 .22981 .30287 .24512 .30545 .23557 .28021 Mtetra
.489 .476 .769 r
.23557 .28021 .24512 .30545 .26065 .30744 .25112 .28144 Mtetra
.504 .48 .763 r
.25112 .28144 .26065 .30744 .27644 .3085 .2669 .282 Mtetra
.524 .488 .759 r
.2669 .282 .27644 .3085 .29249 .3083 .28292 .28161 Mtetra
.546 .501 .757 r
.28292 .28161 .29249 .3083 .30881 .30655 .2992 .27999 Mtetra
.57 .517 .756 r
.2992 .27999 .30881 .30655 .32539 .30303 .31572 .27691 Mtetra
.596 .536 .757 r
.31572 .27691 .32539 .30303 .34222 .2976 .33248 .27221 Mtetra
.622 .556 .759 r
.33248 .27221 .34222 .2976 .35926 .29022 .34945 .2658 Mtetra
.648 .578 .763 r
.34945 .2658 .35926 .29022 .37648 .28095 .36662 .2577 Mtetra
.672 .601 .767 r
.36662 .2577 .37648 .28095 .39386 .26994 .38395 .24798 Mtetra
.695 .623 .772 r
.38395 .24798 .39386 .26994 .41134 .25742 .40141 .23683 Mtetra
.716 .646 .778 r
.40141 .23683 .41134 .25742 .4289 .2437 .41897 .22446 Mtetra
.734 .667 .785 r
.41897 .22446 .4289 .2437 .44651 .2291 .4366 .21115 Mtetra
.749 .688 .792 r
.4366 .21115 .44651 .2291 .46415 .21396 .45428 .19721 Mtetra
.76 .706 .801 r
.45428 .19721 .46415 .21396 .48181 .19863 .47199 .18292 Mtetra
.768 .723 .81 r
.47199 .18292 .48181 .19863 .49947 .18339 .48972 .16857 Mtetra
.773 .738 .821 r
.48972 .16857 .49947 .18339 .51715 .16849 .50748 .1544 Mtetra
.773 .75 .831 r
.50748 .1544 .51715 .16849 .53484 .15414 .52526 .1406 Mtetra
.771 .759 .842 r
.52526 .1406 .53484 .15414 .55256 .14045 .54307 .12733 Mtetra
.765 .766 .853 r
.54307 .12733 .55256 .14045 .57033 .12752 .56093 .11468 Mtetra
.757 .77 .863 r
.56093 .11468 .57033 .12752 .58815 .11538 .57885 .1027 Mtetra
.747 .771 .873 r
.57885 .1027 .58815 .11538 .60604 .10401 .59684 .09141 Mtetra
.737 .771 .881 r
.59684 .09141 .60604 .10401 .62402 .09336 .61491 .08077 Mtetra
.725 .769 .888 r
.61491 .08077 .62402 .09336 .6421 .08337 .63308 .07073 Mtetra
.715 .766 .893 r
.63308 .07073 .6421 .08337 .66028 .07396 .65135 .06124 Mtetra
.705 .763 .897 r
.65135 .06124 .66028 .07396 .67858 .06504 .66974 .05221 Mtetra
.696 .759 .901 r
.66974 .05221 .67858 .06504 .69701 .05651 .68825 .04357 Mtetra
.689 .756 .903 r
.68825 .04357 .69701 .05651 .71556 .0483 .70689 .03524 Mtetra
.621 .7 .901 r
.04709 .27518 .05816 .28719 .07266 .2835 .06169 .27095 Mtetra
.609 .687 .898 r
.06169 .27095 .07266 .2835 .08718 .28029 .07633 .26711 Mtetra
.595 .671 .893 r
.07633 .26711 .08718 .28029 .10174 .27764 .091 .26371 Mtetra
.58 .653 .886 r
.091 .26371 .10174 .27764 .11633 .27562 .10572 .26082 Mtetra
.564 .633 .878 r
.10572 .26082 .11633 .27562 .13095 .27427 .12047 .25849 Mtetra
.547 .61 .868 r
.12047 .25849 .13095 .27427 .14561 .2736 .13527 .25675 Mtetra
.531 .588 .856 r
.13527 .25675 .14561 .2736 .16034 .27362 .15013 .2556 Mtetra
.517 .565 .843 r
.15013 .2556 .16034 .27362 .17513 .27425 .16505 .25502 Mtetra
.505 .544 .83 r
.16505 .25502 .17513 .27425 .19003 .27541 .18007 .25493 Mtetra
.498 .526 .816 r
.18007 .25493 .19003 .27541 .20505 .27693 .19519 .25523 Mtetra
.495 .512 .804 r
.19519 .25523 .20505 .27693 .22022 .27861 .21044 .25576 Mtetra
.496 .502 .792 r
.21044 .25576 .22022 .27861 .23557 .28021 .22586 .25633 Mtetra
.503 .497 .783 r
.22586 .25633 .23557 .28021 .25112 .28144 .24145 .2567 Mtetra
.513 .496 .775 r
.24145 .2567 .25112 .28144 .2669 .282 .25724 .25663 Mtetra
.528 .5 .769 r
.25724 .25663 .2669 .282 .28292 .28161 .27326 .25586 Mtetra
.546 .509 .765 r
.27326 .25586 .28292 .28161 .2992 .27999 .28951 .25413 Mtetra
.566 .52 .763 r
.28951 .25413 .2992 .27999 .31572 .27691 .30598 .25124 Mtetra
.588 .535 .763 r
.30598 .25124 .31572 .27691 .33248 .27221 .32269 .24701 Mtetra
.611 .552 .764 r
.32269 .24701 .33248 .27221 .34945 .2658 .33961 .24133 Mtetra
.634 .571 .766 r
.33961 .24133 .34945 .2658 .36662 .2577 .35673 .23416 Mtetra
.657 .591 .77 r
.35673 .23416 .36662 .2577 .38395 .24798 .37402 .22554 Mtetra
.678 .612 .774 r
.37402 .22554 .38395 .24798 .40141 .23683 .39145 .21558 Mtetra
.698 .633 .78 r
.39145 .21558 .40141 .23683 .41897 .22446 .40899 .20444 Mtetra
.716 .653 .786 r
.40899 .20444 .41897 .22446 .4366 .21115 .42663 .19236 Mtetra
.731 .673 .793 r
.42663 .19236 .4366 .21115 .45428 .19721 .44433 .17957 Mtetra
.743 .691 .802 r
.44433 .17957 .45428 .19721 .47199 .18292 .46209 .16634 Mtetra
.752 .708 .811 r
.46209 .16634 .47199 .18292 .48972 .16857 .47988 .15291 Mtetra
.758 .723 .821 r
.47988 .15291 .48972 .16857 .50748 .1544 .49771 .13952 Mtetra
.76 .736 .831 r
.49771 .13952 .50748 .1544 .52526 .1406 .51557 .12635 Mtetra
.759 .747 .841 r
.51557 .12635 .52526 .1406 .54307 .12733 .53347 .11357 Mtetra
.756 .755 .852 r
.53347 .11357 .54307 .12733 .56093 .11468 .55142 .10127 Mtetra
.75 .76 .862 r
.55142 .10127 .56093 .11468 .57885 .1027 .56943 .08953 Mtetra
.742 .764 .871 r
.56943 .08953 .57885 .1027 .59684 .09141 .58752 .07838 Mtetra
.733 .765 .879 r
.58752 .07838 .59684 .09141 .61491 .08077 .60568 .06781 Mtetra
.723 .764 .886 r
.60568 .06781 .61491 .08077 .63308 .07073 .62394 .05778 Mtetra
.713 .763 .891 r
.62394 .05778 .63308 .07073 .65135 .06124 .64231 .04825 Mtetra
.704 .76 .896 r
.64231 .04825 .65135 .06124 .66974 .05221 .66079 .03915 Mtetra
.696 .758 .899 r
.66079 .03915 .66974 .05221 .68825 .04357 .67939 .03042 Mtetra
.689 .755 .902 r
.67939 .03042 .68825 .04357 .70689 .03524 .69812 .02198 Mtetra
.632 .71 .903 r
.03585 .2634 .04709 .27518 .06169 .27095 .05054 .25873 Mtetra
.622 .7 .9 r
.05054 .25873 .06169 .27095 .07633 .26711 .06528 .25436 Mtetra
.612 .687 .897 r
.06528 .25436 .07633 .26711 .091 .26371 .08007 .25033 Mtetra
.599 .673 .892 r
.08007 .25033 .091 .26371 .10572 .26082 .0949 .24671 Mtetra
.586 .656 .885 r
.0949 .24671 .10572 .26082 .12047 .25849 .10978 .24354 Mtetra
.571 .637 .877 r
.10978 .24354 .12047 .25849 .13527 .25675 .12471 .24086 Mtetra
.557 .616 .867 r
.12471 .24086 .13527 .25675 .15013 .2556 .1397 .23869 Mtetra
.544 .596 .856 r
.1397 .23869 .15013 .2556 .16505 .25502 .15475 .23701 Mtetra
.532 .575 .844 r
.15475 .23701 .16505 .25502 .18007 .25493 .16989 .23578 Mtetra
.523 .557 .832 r
.16989 .23578 .18007 .25493 .19519 .25523 .18512 .23494 Mtetra
.518 .541 .819 r
.18512 .23494 .19519 .25523 .21044 .25576 .20047 .23436 Mtetra
.516 .529 .808 r
.20047 .23436 .21044 .25576 .22586 .25633 .21596 .23389 Mtetra
.519 .521 .797 r
.21596 .23389 .22586 .25633 .24145 .2567 .23161 .23337 Mtetra
.525 .517 .789 r
.23161 .23337 .24145 .2567 .25724 .25663 .24744 .23257 Mtetra
.536 .517 .782 r
.24744 .23257 .25724 .25663 .27326 .25586 .26347 .23128 Mtetra
.549 .521 .776 r
.26347 .23128 .27326 .25586 .28951 .25413 .27971 .22928 Mtetra
.566 .529 .773 r
.27971 .22928 .28951 .25413 .30598 .25124 .29616 .22637 Mtetra
.584 .54 .771 r
.29616 .22637 .30598 .25124 .32269 .24701 .31283 .22237 Mtetra
.604 .553 .771 r
.31283 .22237 .32269 .24701 .33961 .24133 .32971 .21718 Mtetra
.624 .569 .772 r
.32971 .21718 .33961 .24133 .35673 .23416 .34678 .21071 Mtetra
.644 .586 .775 r
.34678 .21071 .35673 .23416 .37402 .22554 .36403 .20297 Mtetra
.664 .605 .778 r
.36403 .20297 .37402 .22554 .39145 .21558 .38143 .19401 Mtetra
.683 .624 .783 r
.38143 .19401 .39145 .21558 .40899 .20444 .39896 .18396 Mtetra
.7 .643 .789 r
.39896 .18396 .40899 .20444 .42663 .19236 .4166 .17299 Mtetra
.715 .661 .796 r
.4166 .17299 .42663 .19236 .44433 .17957 .43432 .16128 Mtetra
.727 .679 .804 r
.43432 .16128 .44433 .17957 .46209 .16634 .45211 .14906 Mtetra
.737 .696 .812 r
.45211 .14906 .46209 .16634 .47988 .15291 .46995 .13655 Mtetra
.743 .711 .821 r
.46995 .13655 .47988 .15291 .49771 .13952 .48784 .12395 Mtetra
.747 .725 .831 r
.48784 .12395 .49771 .13952 .51557 .12635 .50578 .11146 Mtetra
.748 .736 .841 r
.50578 .11146 .51557 .12635 .53347 .11357 .52376 .09921 Mtetra
.746 .745 .851 r
.52376 .09921 .53347 .11357 .55142 .10127 .5418 .08733 Mtetra
.741 .752 .86 r
.5418 .08733 .55142 .10127 .56943 .08953 .5599 .07589 Mtetra
.735 .756 .869 r
.5599 .07589 .56943 .08953 .58752 .07838 .57808 .06494 Mtetra
.728 .759 .877 r
.57808 .06494 .58752 .07838 .60568 .06781 .59634 .05448 Mtetra
.719 .759 .884 r
.59634 .05448 .60568 .06781 .62394 .05778 .61469 .0445 Mtetra
.711 .759 .89 r
.61469 .0445 .62394 .05778 .64231 .04825 .63315 .03497 Mtetra
.703 .758 .895 r
.63315 .03497 .64231 .04825 .66079 .03915 .65172 .02583 Mtetra
.695 .756 .898 r
.65172 .02583 .66079 .03915 .67939 .03042 .67042 .01703 Mtetra
.688 .753 .901 r
.67042 .01703 .67939 .03042 .69812 .02198 .68923 .00851 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`006P3ooonD000003<0ooooU?l0000K0?ooo`006P3o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool0T03o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo0340oooo00?o00000?ooo`3oool0T03oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool0503oool2o`00
00d0oooo0ol0000;0?ooo`;o00009`3oool2000000`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0E0?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo08d0
00000`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo01<0000000?o000001TI6@0I
6AT0300I6AT00ol00000<c<c03<c<`0903<c<`?o00003P1<C4`<00000140C4a<00<0000003<c<`0c
<c<02@0c<c<00`0000006ATI01TI6@0=01TI6@0300000?l0003o000001;o00000`3oool00ol00000
oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`2=000000<0oooo00<000000?ooo`3oool0
<@3oool00ol00000oooo0?ooo`0A000000;o00003P0I6AT00ol00000<c<c03<c<`0803<c<`;o0000
3P1<C4`3000000`0IVIV1000000>04a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I6AT0
3@0I6AT00`00003o0000o`00000Ao`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<0
00000?ooo`3oool0S@0000030?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool04000
00000ol000006ATI01TI6@0<01TI6@;o00002@0c<c<2o`0000/0C4a<1@00000C06IVIP<00000301<
C4`00`000000<c<c03<c<`0803<c<`03o`00000I6AT06ATI00d06ATI00<00000o`000?l000004Ol0
00030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo08d000000`3oool0
0`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00l0000000?o000001TI6@0I6AT0300I6AT0
0ol00000<c<c03<c<`0803<c<`03o`00001<C4`0C4a<00T0C4a<0P00000K06IVIP030000001<C4`0
C4a<00T0C4a<00?o000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0=01TI6@0300000?l0003o
0000017o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`2=0000
00<0oooo00<000000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0>00000003o`00000I6AT06ATI
00`06ATI00?o000003<c<`0c<c<01`0c<c<2o`0000T0C4a<0`00000N06IVIP8000002@1<C4`00`00
0000<c<c03<c<`0803<c<`030000000I6AT06ATI00d06ATI00<00000o`000?l000004Ol000030?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo08d000000`3oool00`000000
oooo0?ooo`0a0?ooo`03o`00003oool0oooo00d0000000?o000001TI6@0I6AT0300I6AT00ol00000
<c<c03<c<`0703<c<`03o`00001<C4`0C4a<00L0C4a<0P00000S06IVIP030000001<C4`0C4a<00L0
C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0<01TI6@0300000?l0003o0000017o
00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`2=000000<0oooo
00<000000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0<00000003o`00000I6AT06ATI00/06ATI
0_l0000703<c<`?o0000201<C4`2000000`0IVIV3000000>06IVIP030000001<C4`0C4a<00L0C4a<
00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0<01TI6@0300000?l0003o0000017o0000
0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`2=000000<0oooo00<0
00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0:000000;o0000300I6AT2o`0000P0<c<c00?o
000004a<C01<C4`01`1<C4`2000000X0IVIV1000000<07moO`<00000301VIVH00ol00000C4a<04a<
C00604a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT0300I6AT00`00003o0000o`00
000Ao`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0S@000003
0?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool02@0000000ol000006ATI01TI6@0;
01TI6@03o`00000c<c<0<c<c00L0<c<c00?o000004a<C01<C4`01P1<C4`2000000T0IVIV0`00000C
07moO`@00000201VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00L0<c<c00<00000
01TI6@0I6AT02P0I6AT00`00003o0000o`00000Bo`0000<0oooo00?o00000?ooo`3oool06@3oool0
01X0oooo00<000000?ooo`3oool0S@0000030?ooo`030000003oool0oooo0340oooo00?o00000?oo
o`3oool0200000000ol000006ATI01TI6@0;01TI6@03o`00000c<c<0<c<c00L0<c<c00?o000004a<
C01<C4`01P1<C4`00ol00000IVIV06IVIP0506IVIP0400000?l0003o0000000001X0Ogmo00?o0000
06IVIP1VIVH01P1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00L0<c<c00<00000
01TI6@0I6AT02P0I6AT00`00003o0000o`00000Bo`0000<0oooo00?o00000?ooo`3oool06@3oool0
01X0oooo00<000000?ooo`3oool0S@0000030?ooo`030000003oool0oooo0340oooo00?o00000?oo
o`3oool0200000000ol000006ATI01TI6@0:01TI6@;o0000200c<c<00ol00000C4a<04a<C00504a<
C08000001`1VIVH00`000000Ogmo07moO`0L07moO`030000001VIVH0IVIV00H0IVIV00<0000004a<
C01<C4`01P1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00X06ATI00<00000o`00
0?l000004_l000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo08d0
00000`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00L0000000?o000001TI6@0I
6AT02P0I6AT00ol00000<c<c03<c<`0703<c<`03o`00001<C4`0C4a<00@0C4a<0P00000706IVIP80
0000801oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c
<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@0300000?l0003o000001;o00000`3oool00ol00000
oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`2=000000<0oooo00<000000?ooo`3oool0
<@3oool00ol00000oooo0?ooo`0600000003o`00000I6AT06ATI00X06ATI00?o000003<c<`0c<c<0
1P0c<c<2o`0000H0C4a<00?o000006IVIP1VIVH01@1VIVH2000000X0Ogmo4000000907moO`030000
001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0603<c<`030000
000I6AT06ATI00X06ATI00<00000o`000?l000004_l000030?ooo`03o`00003oool0oooo01T0oooo
000J0?ooo`030000003oool0oooo08d000000`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003o
ool0oooo00D0000000?o000001TI6@0I6AT02P0I6AT00ol00000<c<c03<c<`0603<c<`03o`00001<
C4`0C4a<00@0C4a<0P00000606IVIP8000002@1oOgl00`00003o00000000000@09VIV@03o`00001o
Ogl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c
<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT00`00003o0000o`00000Bo`0000<0oooo00?o
00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0S@0000030?ooo`030000003oool0
oooo0340oooo00?o00000?ooo`3oool0100000000ol000006ATI01TI6@0:01TI6@03o`00000c<c<0
<c<c00H0<c<c00?o000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0
Ogmo00H0Ogmo0`00000C09VIV@800000201oOgl00`000000IVIV06IVIP0506IVIP03o`00001<C4`0
C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@0300000?l0003o
000001;o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`2=0000
00<0oooo00<000000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0300000003o`00000I6AT06ATI
00X06ATI00?o000003<c<`0c<c<01P0c<c<00ol00000C4a<04a<C00404a<C0030000001VIVH0IVIV
00@0IVIV0P00000707moO`800000602IVIT2000000L0Ogmo00<0000006IVIP1VIVH0101VIVH00`00
0000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT00`00
003o0000o`00000Bo`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3o
ool0S@0000030?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool00P0000000ol00000
6ATI01TI6@0:01TI6@03o`00000c<c<0<c<c00H0<c<c00?o000004a<C01<C4`0101<C4`00`000000
IVIV06IVIP0406IVIP030000001oOgl0Ogmo00D0Ogmo0P00000L09VIV@03o`00001oOgl0Ogmo00@0
Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0
<c<c00<0000001TI6@0I6AT02P0I6AT00`00003o0000o`00000Bo`0000<0oooo00?o00000?ooo`3o
ool06@3oool001X0oooo00<000000?ooo`3oool0S@0000030?ooo`030000003oool0oooo0340oooo
00Go00000?ooo`3oool00000o`00000<01TI6@03o`00000c<c<0<c<c00H0<c<c00?o000004a<C01<
C4`0101<C4`00ol00000IVIV06IVIP0206IVIP0300000?l00000000000H0Ogmo0P00000:09VIV@/0
00002@2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<
C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI00<00000o`000?l0
00004_l000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo08d00000
0`3oool00`000000oooo0?ooo`0a0?ooo`04o`00003oool0ooooo`0000`06ATI00?o000003<c<`0c
<c<01@0c<c<2o`0000D0C4a<0P00000406IVIP030000001oOgl0Ogmo00D0Ogmo0P00000909VIV@<0
00002`2c/k<2000000L0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0406IVIP03
0000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@03
00000?l0003o000001;o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo
0?ooo`2=000000<0oooo00<000000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0<01TI6@03o`00
000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000
001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01@2IVIT400000100/k>c0P00000609VIV@030000
001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000
000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02P0I6AT00`00003o0000o`00000Co`0000<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0S@0000030?ooo`030000003o
ool0oooo0340oooo00?o00000?ooo`3oool02`0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<
C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`0300000?l0
0000000000D0VIVI00<00000o`00000000005P2c/k<00`000000VIVI09VIV@0409VIV@030000001o
Ogl0Ogmo00@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c
<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02P0I6ATFo`0000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00<000000?ooo`3oool0S@0000030?ooo`030000003oool0oooo0340oooo00?o0000
0?ooo`3oool02P0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<00<00000
06IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00@0VIVI0P00000I
0;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP03
06IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:
01TI6@0300000?l0003o000001?o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`00
0000oooo0?ooo`2=000000<0oooo00<000000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0901TI
6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IV
IP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT2000000`0/k>c1@00000;0;>c
/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IV
IP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI
6@0300000?l0003o000001?o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000
oooo0?ooo`21000000P06ATI1@0000020?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3o
ool0200I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<00<0000006IVIP1V
IVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c
/k<02@2c/k<3000000D0c<c<0`0000080;>c/`030000002IVIT0VIVI00@0VIVI00?o000007moO`1o
Ogl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01@0c<c<00`0000006ATI01TI6@0901TI6@0300000?l0003o000001Co00000`3oool00ol00000
oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`1g00000003o`00000000006ATI01<06ATI
0`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00L06ATI00?o000003<c<`0c<c<0
1@0c<c<00ol00000C4a<04a<C00404a<C0030000001VIVH0IVIV0080IVIV00<00000o`00001oOgl0
0`1oOgl2000000@0VIVI0P0000070;>c/`D000002`3<c<`00ol00000/k>c0;>c/`060;>c/`030000
002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000
001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@030000
0?l0003o000001Co00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?oo
o`1e000001P06ATI0`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00L06ATI00?o
000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00404a<C0030000001VIVH0IVIV0080IVIV00<0
000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00D0/k>c0P00
000A0<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07mo
O`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c
<`0503<c<`030000000I6AT06ATI00T06ATI00<00000o`000?l000005?l000030?ooo`03o`00003o
ool0oooo01T0oooo000J0?ooo`030000003oool0oooo06l000007P0I6AT30?ooo`030000003oool0
oooo0340oooo00?o00000?ooo`3oool01P0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0
C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0
VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<2000001@0c<c<00<000000;>c/`2c/k<0102c/k<0
0`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH0
0`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I6AT0
0`00003o0000o`00000Do`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?oo
o`3oool0KP00000O01TI6@<0oooo00<000000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0501TI
6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IV
IP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`040;>c
/`030000003<c<`0c<c<01D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0309VI
V@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<
C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT02@0I6AT00`00003o0000o`00000Eo`00
00<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0J`00000R01TI6@<0
oooo00<000000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0401TI6@03o`00000c<c<0<c<c00D0
<c<c00?o000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080
Ogmo00<0000009VIV@2IVIT00P2IVIT00`00003o00000;>c/`040;>c/`0300000?l00000c<c<00T0
c<c<1?l0000;0<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000
Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000
<c<c03<c<`0503<c<`030000000I6AT06ATI00T06ATI00<00000o`000?l000005Ol000030?ooo`03
o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo06L000009P0I6AT30?ooo`030000
003oool0oooo0340oooo00?o00000?ooo`3oool00`0I6AT2o`0000H0<c<c00?o000004a<C01<C4`0
0`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT0
0P2IVIT00`000000/k>c0;>c/`030;>c/`800000203<c<`4o`0000@0i^KV0ol000080<c<c0030000
002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0207moO`030000
001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`030000
000I6AT06ATI00T06ATI00<00000o`000?l000005Ol000030?ooo`03o`00003oool0oooo01T0oooo
000J0?ooo`030000003oool0oooo06@00000:@0I6AT30?ooo`030000003oool0oooo0340oooo00?o
00000?ooo`3oool00P0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00<0C4a<00<0
000006IVIP1VIVH00P1VIVH2000000@0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c
/`020;>c/`8000001`3<c<`3o`0000/0i^KV00?o00000<c<c03<c<`01P3<c<`00ol00000/k>c0;>c
/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IV
IP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI
6@0901TI6@0300000?l0003o000001Ko00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0`000000oooo0?ooo`1S000002X06ATI0`3oool00`000000oooo0?ooo`0a0?ooo`05o`00003oool0
oooo01TI6Ol000001`0c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV0080IVIV00<0
000007moO`1oOgl00P1oOgl00ol00000000009VIV@0309VIV@03o`00002c/k<0/k>c0080/k>c00<0
00000<c<c03<c<`01@3<c<`2o`0000l0i^KV00?o00000<c<c03<c<`01@3<c<`00`000000/k>c0;>c
/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IV
IP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI
6@0901TI6@0300000?l0003o000001Ko00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0`000000oooo0?ooo`1O000002h06ATI0`3oool00`000000oooo0?ooo`0a0?ooo`05o`00003oool0
oooo01TI6Ol000001P0c<c<00ol00000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0
000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080/k>c00<0
00000<c<c03<c<`0103<c<`2o`000140i^KV00?o00000<c<c03<c<`01@3<c<`00`000000/k>c0;>c
/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IV
IP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI
6@0901TI6AWo00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`1M
000003006ATI0`3oool00`000000oooo0?ooo`0a0?ooo`04o`00003oool0ooooo`0000H0<c<c00?o
000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0
000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00@0c<c<00?o
00000>KViP3Vi^H04P3Vi^H00ol00000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00<0/k>c00D0
000009VIV@2IVIT0VIVI0000000507moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0
0`1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00T06ATI00<00000o`000?l00000
5_l000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo05X0000000?o
000001TI6@0I6AT0<00I6AT30?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool01`0c
<c<00ol00000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1o
Ogl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<
c<`2o`0001D0i^KV00?o00000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`020;>c/`030000002I
VIT0VIVI0080VIVI00?o000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<
C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@0300000?l0
003o000001Oo00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`1J
000001l06ATI3000000801TI6@<0oooo00<000000?ooo`3oool0<@3oool00ol00000oooo0?ooo`06
03<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`02
07moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c003
0<c<c003o`00003Vi^H0i^KV01H0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`02
0;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP02
06IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@08
01TI6@0300000?l0003o000001So00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`00
0000oooo0?ooo`1H000001X06ATI1`00000<03<c<`@00000100I6AT30?ooo`030000003oool0oooo
0340oooo00?o00000?ooo`3oool01P0c<c<00ol00000C4a<04a<C00204a<C0030000001VIVH0IVIV
0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c
0080/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP060>KViPSo00002@3Vi^H00ol0
0000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`00
0000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`00
0000<c<c03<c<`0503<c<`030000000I6AT06ATI00P06ATI00<00000o`000?l000006?l000030?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo05H000006@0I6AT3000001L0
<c<c0`0000001@0I6AT0oooo0?ooo`3oool0000003<0oooo00?o00000?ooo`3oool01@0c<c<00ol0
0000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`00
0000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<c<`2o`00
00L0i^KV0_l000080?ooo`03o`00003Vi^H0i^KV00H0i^KV00?o00000<c<c03<c<`00`3<c<`00`00
0000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@000000101oOgl00`000000IVIV06IVIP02
06IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@08
01TI6@0300000?l0003o000001Wo00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`00
0000oooo0?ooo`1C00000003o`00000I6AT06ATI01@06ATI00?o00000000000000000P00000M03<c
<`8000000P3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00<0<c<c0_l0000404a<
C0030000001VIVH0IVIV0080IVIV0P00000307moO`030000002IVIT0VIVI0080VIVI00?o00000;>c
/`2c/k<00P2c/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00D0i^KV0_l0000;0?oo
o`03o`00003Vi^H0i^KV00D0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c
/`050000002IVIT0VIVI09VIV@000000101oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0
C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@0300000?l0003o
000001Wo00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`1B0000
01D06ATI0`00000S03<c<`<0oooo00<000000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0303<c
<`03o`00001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207mo
O`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<01@000000c<c<0<c<c03<c<co
000000L0i^KV00?o00000?ooo`3oool02`3oool00ol00000i^KV0>KViP050>KViP03o`00003<c<`0
c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo00<0
000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C003o`00000c<c<0<c<c00@0<c<c00?o
000001TI6@0I6AT02@0I6AT00`00003o0000o`00000Io`0000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00<000000?ooo`3oool0D@00000C01TI6@<000009P0c<c<30?ooo`030000003oool0
oooo0340oooo00?o00000?ooo`3oool00P0c<c<00ol00000C4a<04a<C00304a<C0030000001VIVH0
IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0
/k>c0080/k>c00D000000<c<c03<c<`0c<c<o`0000070>KViP03o`00003oool0oooo00`0oooo00?o
00000>KViP3Vi^H01@3Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00D0
000009VIV@2IVIT0VIVI0000000407moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0
0`1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00P06ATI00<00000o`000?l00000
6_l000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo04l00000500I
6AT00`000000<c<c03<c<`0W03<c<`<0oooo00<000000?ooo`3oool0<@3oool00ol00000oooo0?oo
o`0203<c<`03o`00001<C4`0C4a<0080C4a<00?o000006IVIP1VIVH00`1VIVH01@000000Ogmo07mo
O`1oOgl0000000@0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0020<c<c003o`00
003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool03P3oool00ol00000i^KV0>KViP040>KViP03o`00
003<c<`0c<c<00<0c<c<00D000000;>c/`2c/k<0/k>c0000000309VIV@030000001oOgl0Ogmo0080
Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0
<c<c00<0000001TI6@0I6AT02@0I6AT00`00003o0000o`00000Jo`0000<0oooo00?o00000?ooo`3o
ool06@3oool001X0oooo00<000000?ooo`3oool0C@00000C01TI6@80000000?o000003<c<`0c<c<0
:00c<c<30?ooo`030000003oool0oooo0340oooo00Go00000?ooo`3oool0<c<co`00000504a<C003
0000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@03o`00002c/k<0/k>c
0080/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP040>KViP03o`00003oool0oooo
00l0oooo00?o00000>KViP3Vi^H0103Vi^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c
0080/k>c00Go000009VIV@2IVIT0VIVI0000000407moO`030000001VIVH0IVIV0080IVIV00<00000
04a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00P06ATI7_l00003
0?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo04/000004P0I6AT30000
01H0<c<c3000000;03<c<`<0oooo00<000000?ooo`3oool0<@3oool01Ol00000oooo0?ooo`0c<c?o
000000D0C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI00D0
00000;>c/`2c/k<0/k>co`0000050<c<c003o`00003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool0
403oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0
/k>c0000000409VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000
C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AT00`00003o
0000o`00000Ko`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0
BP00000A01TI6@8000004P0c<c<7000000`0C4a<0`00000803<c<`<0oooo00<000000?ooo`3oool0
<@3oool01?l00000oooo0?ooool0000504a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1o
Ogl0Ogmo0000000409VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<c<`00ol0
0000i^KV0>KViP030>KViP03o`00003oool0oooo0140oooo00?o00000>KViP3Vi^H0103Vi^H00ol0
0000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT00`000000Ogmo07moO`02
07moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`04
03<c<`030000000I6AT06ATI00T06ATI00<00000o`000?l000006ol000030?ooo`03o`00003oool0
oooo01T0oooo000J0?ooo`030000003oool0oooo04P0000000?o000001TI6@0I6AT03`0I6AT00ol0
0000<c<c03<c<`0?03<c<`<000005P1<C4`2000000H0<c<c0`3oool00`000000oooo0?ooo`0a0?oo
o`03o`00003oool0oooo00H0C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`030000002IVIT0
VIVI00<0VIVI00D000000;>c/`2c/k<0/k>c000000040<c<c003o`00003Vi^H0i^KV00<0i^KV00?o
00000?ooo`3oool04@3oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<0080c<c<00D0
00000;>c/`2c/k<0/k>c0000000409VIV@03o`00001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0
0P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0
200I6AT00`00003o0000o`00000Lo`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<0
00000?ooo`3oool0B000000@01TI6@8000003@0c<c<300000003o`0000000000C4a<01X0C4a<00?o
00000000000c<c<00`0c<c<30?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool01@1<
C4`01Ol00000IVIV06IVIP1VIVH0000000@0Ogmo00Ko000009VIV@2IVIT0VIVIo`00000000030;>c
/`030000003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0B0?oo
o`03o`00003Vi^H0i^KV00<0i^KV0_l000040<c<c0050000002c/k<0/k>c0;>c/`000000102IVIT0
1@000000Ogmo07moO`1oOgoo000000@0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c
<`0403<c<`030000000I6AT06ATI00T06ATI00<00000o`000?l000007?l000030?ooo`03o`00003o
ool0oooo01T0oooo000J0?ooo`030000003oool0oooo04H00000400I6AT2000000`0<c<c0`00000R
04a<C08000000P0c<c<30?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool0101<C4`0
0`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVI0000
00040;>c/`030000003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H00P3Vi^H00ol00000oooo0?oo
o`0C0?ooo`03o`00003Vi^H0i^KV00<0i^KV00?o00000<c<c03<c<`00`3<c<`01@000000/k>c0;>c
/`2c/k<0000000@0VIVI00@0000007moO`1oOgl000001@1VIVH00`000000C4a<04a<C00204a<C003
o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT0200I6AT00`00003o0000o`00000Mo`0000<0
oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0A000000@01TI6@800000
3@0c<c<00`000000C4a<04a<C00U04a<C08000000`3oool00`000000oooo0?ooo`0a0?ooo`03o`00
003oool0oooo00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`050000
002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV0080
i^KV00?o00000?ooo`3oool04`3oool00ol00000i^KV0>KViP030>KViP03o`00003<c<`0c<c<00<0
c<c<00D000000;>c/`2c/k<0/k>c0000000409VIV@050000001oOgl0Ogmo07moO`000000101VIVH0
0`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AT0
0`00003o0000o`00000No`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?oo
o`3oool0@P0000000ol000006ATI01TI6@0=01TI6@8000002`0c<c<4000002X0C4a<00@000000?oo
o`3oool00000<`3oool00ol00000oooo0?ooo`0204a<C0030000001VIVH0IVIV0080IVIV00<00000
07moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00?o00000<c<c03<c<`00P3<
c<`00ol00000i^KV0>KViP030>KViP03o`00003oool0oooo01<0oooo00?o00000>KViP3Vi^H00`3V
i^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/ol00000102IVIT01@000000Ogmo
07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`03
0000000I6AT06ATI00T06ATI8Ol000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000
003oool0oooo048000003`0I6AT00`000000<c<c03<c<`0903<c<`800000401<C4`B000000`0C4a<
0`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo0080C4a<00<0000006IVIP1VIVH0
0P1VIVH00ol00000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIV@000000102c/k<01@000000
c<c<0<c<c03<c<co000000H0i^KV00?o00000?ooo`3oool04`3oool00ol00000i^KV0>KViP030>KV
iP03o`00003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0/k>c0000000409VIV@050000001oOgl0
Ogmo07moO`000000101VIVH00ol00000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0
000001TI6@0I6AT02@0I6AT00`00003o0000o`00000No`0000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00<000000?ooo`3oool0@@00000>01TI6@8000002P0c<c<2000000h0C4a<1000000B
06IVIP030000001<C4`0C4a<00T0C4a<0`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0
oooo0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI00D0
00000;>c/`2c/k<0/k>c000000040<c<c003o`00003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool0
4P3oool00ol00000i^KV0>KViP030>KViP03o`00003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<0
0P2c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000
C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT02@0I6AT00`00003o
0000o`00000Oo`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0
@000000>01TI6@030000000c<c<0<c<c00T0<c<c00?o000004a<C01<C4`02P1<C4`4000001L0IVIV
0`00000804a<C0<0oooo00<000000?ooo`3oool0<@3oool01Ol00000oooo0?ooo`1<C4`0000000@0
IVIV00<0000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00D000000<c<
c03<c<`0c<c<o`0000060>KViP03o`00003oool0oooo0180oooo00?o00000>KViP3Vi^H0103Vi^H0
0ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT00ol00000Ogmo07mo
O`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c
<`0403<c<`030000000I6AT06ATI00T06ATI00<00000o`000?l000007ol000030?ooo`03o`00003o
ool0oooo01T0oooo000J0?ooo`030000003oool0oooo03h0000000?o000001TI6@0I6AT0300I6AT0
0ol00000<c<c03<c<`0803<c<`8000002P1<C4`3000001h0IVIV00?o000004a<C01<C4`01@1<C4`3
0?ooo`030000003oool0oooo0340oooo00Go00000?ooo`3oool0C4a<o`00000406IVIP050000001o
Ogl0Ogmo07moOol000000`2IVIT00ol0000000000;>c/`020;>c/`030000003<c<`0c<c<0080c<c<
00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0A0?ooo`03o`00003Vi^H0i^KV00@0i^KV
00?o00000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000@0VIVI00D0000007moO`1o
Ogl0Ogmo0000000406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`00
00006ATI01TI6@0901TI6@0300000?l0003o0000023o00000`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00`000000oooo0?ooo`0m000000h06ATI0P00000903<c<`8000002@1<C4`300000280
IVIV0P00000504a<C0<0oooo00<000000?ooo`3oool0<@3oool01?l00000oooo0?ooool0000506IV
IP050000001oOgl0Ogmo07moO`0000000`2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0
c<c<0080c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0@0?ooo`;o00001@3Vi^H0
0ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0VIVI0000
000407moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c
<`0403<c<`030000000I6AT06ATI00P06ATI9?l000030?ooo`03o`00003oool0oooo01T0oooo000J
0?ooo`030000003oool0oooo03`000003@0I6AT2000000T0<c<c0P00000904a<C08000003P1VIVH;
000000h0IVIV00<0000004a<C01<C4`00P1<C4`30?ooo`030000003oool0oooo0340oooo00?o0000
0?ooo`3oool01@1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00<000000;>c/`2c/k<00P2c
/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool0403o
ool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<0080c<c<00?o00000;>c/`2c/k<00P2c
/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<
04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AT00`00003o0000
o`00000Ro`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0>`00
000=01TI6@0300000?l00000<c<c00P0<c<c00<0000004a<C01<C4`01P1<C4`3000000T0IVIV00<0
0000o`00000000001000000;07moO`D000002P1VIVH01?l00000C4a<04a<C01<C4`30?ooo`030000
003oool0oooo0340oooo00?o00000?ooo`3oool0101VIVH00`000000Ogmo07moO`0207moO`050000
002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00@0
i^KV00?o00000?ooo`3oool03`3oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<0080
c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIWo000000@0Ogmo00<0000006IV
IP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI
6@0I6AT0200I6AT00`00003o0000o`00000So`0000<0oooo00?o00000?ooo`3oool06@3oool001X0
oooo00<000000?ooo`3oool0>P00000=01TI6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<
C4`01P1<C4`00`000000IVIV06IVIP0806IVIP8000005`1oOgl2000000P0IVIV00@0000004a<C01<
C4`0C4a<0`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00@0IVIV00<0000007mo
O`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`00P3<c<`0
0ol00000i^KV0>KViP040>KViP03o`00003oool0oooo00d0oooo0_l000060>KViP03o`00003<c<`0
c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo00<0
000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0
000001TI6@0I6AT0200I6AT00`00003o0000o`00000So`0000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00<000000?ooo`3oool0>@00000=01TI6@030000000c<c<0<c<c00P0<c<c00<00000
04a<C01<C4`01@1<C4`2000000T0IVIV0P00000K07moO`030000001VIVH0IVIV00H0IVIV00<00000
04a<C01<C4`00`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00@0IVIV00D00000
07moO`1oOgl0Ogmo0000000409VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<
c<`00ol00000i^KV0>KViP040>KViP03o`00003oool0oooo00`0oooo00?o00000>KViP3Vi^H01@3V
i^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0VIVI
0000000407moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c
03<c<`0403<c<`030000000I6AT06ATI00P06ATI00<00000o`000?l000009?l000030?ooo`03o`00
003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo03P000003@0I6AT00ol00000<c<c03<c
<`0703<c<`8000001`1<C4`00`000000IVIV06IVIP0606IVIP<000007P1oOgl00ol00000IVIV06IV
IP0606IVIP030000001<C4`0oooo0080oooo00<000000?ooo`3oool0<@3oool00ol00000oooo0?oo
o`0406IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT00`000000/k>c0;>c/`020;>c/`030000
003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H01@3Vi^H00ol00000oooo0?ooo`0:0?ooo`03o`00
003Vi^H0i^KV00D0i^KV00?o00000<c<c03<c<`00`3<c<`00ol00000/k>c0;>c/`020;>c/`050000
002IVIT0VIVI09VIV@000000101oOgl00ol00000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0
C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@0300000?l0003o000002Co
00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0g000000`06ATI
0P00000803<c<`03o`0000000000C4a<00D0C4a<00<00000o`00000000001@1VIVH01000003o0000
00000000000:07moO`@000000_l0000200000004o`00000000000000000000`0Ogmo00<0000006IV
IP1VIVH01P1VIVH01@000000oooo0?ooo`3oool0000003<0oooo00?o00000?ooo`3oool00`1VIVH0
1@000000Ogmo07moO`1oOgl0000000@0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<
c0030<c<c003o`00003Vi^H0i^KV00D0i^KV00?o00000?ooo`3oool0203oool2o`0000L0i^KV00?o
00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`05o`00002IVIT0VIVI09VIV@000000
101oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0
100c<c<00ol000006ATI01TI6@0901TI6@0300000?l0003o000002Go00000`3oool00ol00000oooo
0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0f000000`06ATI00<0000003<c<`0c<c<01`0c
<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00@0IVIV0P00000:07moO`@00000302I
VIT3000000X0Ogmo00<0000006IVIP1VIVH01@1VIVH01@000000oooo0?ooo`3oool0000003<0oooo
00?o00000?ooo`3oool00`1VIVH01@000000Ogmo07moO`1oOgoo000000@0VIVI00<000000;>c/`2c
/k<00P2c/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00H0i^KV0ol000030?ooo`Co
0000203Vi^H2o`0000@0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@03
0000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C003
0000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT02@0I6AT00`00003o0000o`00000Uo`0000<0
oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0=@00000<01TI6@030000
000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`0101<C4`2000000H0IVIV00<0000007moO`1oOgl0
1`1oOgl3000001<0VIVI0P00000907moO`030000001VIVH0IVIV00D0IVIV00@000000?ooo`3oool0
0000<`3oool00ol00000oooo0?ooo`0306IVIP050000001oOgl0Ogmo07moO`000000102IVIT00`00
0000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H02@3Vi^H3o`00
00/0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI
0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<
0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@0300000?l0003o0000
02Ko00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0c00000003
o`00000I6AT06ATI00/06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C003
0000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl01P1oOgl2000001P0VIVI00<0000007moO`1o
Ogl01`1oOgl00ol00000IVIV06IVIP0406IVIP<0oooo00<000000?ooo`3oool0<@3oool00ol00000
oooo0?ooo`0206IVIP030000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVI000000050;>c
/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H05P3Vi^H00ol00000c<c<0<c<c0030<c<
c003o`00002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207mo
O`03o`00001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0503<c
<`030000000I6AT06ATI00T06ATI00<00000o`000?l000009_l000030?ooo`03o`00003oool0oooo
01T0oooo000J0?ooo`030000003oool0oooo03<00000300I6AT2000000L0<c<c00<00000o`00001<
C4`0101<C4`2000000D0IVIV00<00000o`00000000001`1oOgl00`00003o000009VIV@0J09VIV@80
00001`1oOgl00`000000IVIV06IVIP0406IVIP<0oooo00<000000?ooo`3oool0<@3oool00ol00000
oooo0?ooo`0206IVIP030000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVI000000050;>c
/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H0503Vi^H2o`0000D0c<c<00<000000;>c
/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IV
IP1VIVH00P1VIVH2000000@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI
6@0300000?l0003o000002Oo00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000
oooo0?ooo`0b000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C003
0000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl3000000/0VIVI2000000<09VIV@03
0000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH30?ooo`030000003oool0oooo0340
oooo00?o00000?ooo`3oool00P1VIVH00`000000Ogmo07moO`0207moO`050000002IVIT0VIVI09VI
V@0000001@2c/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV0180i^KV0_l000060<c<
c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207mo
O`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0403<c
<`030000000I6AT06ATI00T06ATI:ol000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
0000003oool0oooo03400000300I6AT00ol00000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0
C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`8000001`2IVIT7000000P0
/k>c1000000909VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH00`1VIVH30?ooo`03
0000003oool0oooo0340oooo00Go00000?ooo`3oool0IVIV0000000407moO`030000002IVIT0VIVI
0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0040<c<c003o`00003Vi^H0i^KV
00l0i^KV0_l000060<c<c0800000102c/k<00`000000VIVI09VIV@0209VIV@03o`00001oOgl0Ogmo
0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c
00@0<c<c00<0000001TI6@0I6AT02@0I6AT00`00003o0000o`00000Yo`0000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00<000000?ooo`3oool0<000000<01TI6@030000000c<c<0<c<c00D0
<c<c00<00000o`00001<C4`0101<C4`2000000D0IVIV00?o00000000001oOgl0101oOgl00ol00000
000009VIV@0609VIV@8000004`2c/k<00ol00000000009VIV@0709VIV@030000001oOgl0Ogmo00@0
Ogmo00<0000006IVIP1VIVH00P1VIVH30?ooo`030000003oool0oooo0340oooo00Go00000?ooo`3o
ool0IVIV0000000407moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`00
0000c<c<0<c<c0050<c<c0;o00003P3Vi^H00ol00000c<c<0<c<c0050<c<c0030000002c/k<0/k>c
00<0/k>c00?o000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV
0080IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI
00T06ATI00<00000o`000?l00000:_l000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
0000003oool0oooo030000002`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0
C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00D0
VIVI0P0000000ol00000/k>c0;>c/`0D0;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1o
Ogl0101oOgl00`000000IVIV06IVIP0206IVIP<0oooo00<000000?ooo`3oool0<@3oool01Ol00000
oooo0?ooo`1VIVH0000000@0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c
/`030000003<c<`0c<c<00L0c<c<0_l000090>KViP?o00001`3<c<`00`000000/k>c0;>c/`030;>c
/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IV
IP030000001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI
6@0300000?l0003o000002[o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000
oooo0?ooo`0_000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C003
0000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl00`1oOgl2000000D0VIVI0`00000J0;>c/`03
0000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IVIP<0
oooo00<000000?ooo`3oool0<@3oool01Ol00000oooo0?ooo`1VIVH0000000@0Ogmo00<0000009VI
V@2IVIT00P2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00P0c<c<0ol000020>KV
iPCo0000203<c<`2000000D0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0307mo
O`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c
<`030000000I6AT06ATI00T06ATI00<00000o`000?l00000:ol000030?ooo`03o`00003oool0oooo
01T0oooo000J0?ooo`030000003oool0oooo02h000002`0I6AT00`000000<c<c03<c<`0503<c<`03
o`00001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0307moO`03
0000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0202c/k<9000000/0/k>c00?o000009VIV@2I
VIT0102IVIT00ol00000Ogmo07moO`0407moO`040000001VIVH0IVIV06IVIP<0oooo00<000000?oo
o`3oool0<@3oool01Ol00000oooo0?ooo`1VIVH0000000@0Ogmo00<0000009VIV@2IVIT00`2IVIT0
0`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00/0c<c<0_l0000:0<c<c08000001P2c/k<0
0`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH0
0`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I6AT0
0`00003o0000o`00000/o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?oo
o`3oool0;00000000ol000006ATI01TI6@0901TI6@030000000c<c<0<c<c00D0<c<c0P00000504a<
C003o`00001VIVH0IVIV00<0IVIV0P00000407moO`03o`0000000000VIVI00<0VIVI00<00000o`00
00000000202c/k<00`00003o0000000000090<c<c0@00000202c/k<00`000000VIVI09VIV@0409VI
V@030000001oOgl0Ogmo00<0Ogmo00@0000006IVIP1VIVH0IVIV0`3oool00`000000oooo0?ooo`0a
0?ooo`05o`00003oool0oooo06IVIP000000101oOgl00`000000VIVI09VIV@0309VIV@030000002c
/k<0/k>c00@0/k>c00?o00000<c<c03<c<`0503<c<`2000000D0/k>c0P0000000ol00000VIVI09VI
V@0209VIV@030000001oOgl0Ogmo0080Ogmo00<00000o`00001VIVH00`1VIVH00`000000C4a<04a<
C00304a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I6AT`o`0000<0oooo00?o
00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0;000000;01TI6@030000000c<c<0
<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0
Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`060;>c/`<00000403<c<`0
0`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl0
10000000IVIV06IVIP1VIVH30?ooo`030000003oool0oooo0340oooo00Go00000?ooo`3oool0IVIV
0000000407moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<
0<c<c00B0<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo
07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00ol00000<c<c
03<c<`0503<c<`030000000I6AT06ATI00X06ATI00<00000o`000?l00000;Ol000030?ooo`03o`00
003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo02/000002`0I6AT00`000000<c<c03<c
<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07mo
O`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<01@2c/k<2000001@0c<c<00<0
00000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo00@0
000006IVIP1VIVH0IVIV0`3oool00`000000oooo0?ooo`0a0?ooo`05o`00003oool0oooo06IVIP00
0000101oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<
c<`03P3<c<`3000000H0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0207moO`03
0000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0403<c<`03
0000000I6AT06ATI00X06ATI00<00000o`000?l00000;_l000030?ooo`03o`00003oool0oooo01T0
oooo000J0?ooo`030000003oool0oooo02/000002`0I6AT00`000000<c<c03<c<`0403<c<`03o`00
001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0307moO`030000
002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<2000001L0c<c<00<000000;>c/`2c/k<0
102c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo00@0000006IVIP1VIVH0
IVIV0`3oool00`000000oooo0?ooo`0a0?ooo`05o`00003oool0oooo06IVIP0000001@1oOgl00`00
0000VIVI09VIV@0309VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`02`3<c<`00ol0
000000000;>c/`070;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00P1oOgl00ol0
0000IVIV06IVIP0406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`00
00006ATI01TI6@0901TI6@0300000?l0003o000002oo00000`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00`000000oooo0?ooo`0Y00000003o`00000I6AT06ATI00T06ATI00<0000003<c<`0c
<c<01@0c<c<00`000000C4a<04a<C00304a<C0800000101VIVH00`000000Ogmo07moO`0207moO`03
00000?l00000VIVI00<0VIVI0P0000040;>c/`<000002P3<c<`5o`0000/0c<c<00?o00000;>c/`2c
/k<0102c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00@0000006IVIP1V
IVH0IVIV0`3oool00`000000oooo0?ooo`0a0?ooo`05o`00003oool0oooo06IVIP0000001@1oOgl0
0`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00L0/k>c00?o00000000000000000P000003
0<c<c0D00000202c/k<2000000@0VIVI0P0000000ol00000Ogmo07moO`0207moO`800000101VIVH2
000000D0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@0300000?l0003o
0000033o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0Y0000
00/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV
00<0IVIV00?o000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@8000001@2c/k<00`00
0000c<c<0<c<c0080<c<c0?o00001@3Vi^H3o`0000P0c<c<00<000000;>c/`2c/k<0102c/k<00`00
0000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00@0000006IVIP1VIVH0IVIV0`3oool0
0`000000oooo0?ooo`0a0?ooo`05o`00003oool0oooo06IVIP0000001@1oOgl00`000000VIVI09VI
V@0409VIV@03o`00002c/k<0/k>c00/0/k>c0`00000;0;>c/`8000001@2IVIT00`000000Ogmo07mo
O`0307moO`8000001@1VIVH00`000000C4a<04a<C00304a<C00300000?l00000<c<c00H0<c<c00<0
000001TI6@0I6AT02@0I6AT00`00003o0000o`00000ao`0000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00<000000?ooo`3oool0:000000;01TI6@03o`00000c<c<0<c<c00D0<c<c00<00000
04a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<00000
09VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<1?l0000;
0>KViP03o`00003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@03
09VIV@030000001oOgl0Ogmo0080Ogmo00@0000006IVIP1VIVH0IVIV0`3oool00`000000oooo0?oo
o`0a0?ooo`05o`00003oool0oooo06IVIP0000001@1oOgl00`000000VIVI09VIV@0509VIV@030000
002c/k<0/k>c01D0/k>c0`00000609VIV@030000001oOgl0Ogmo00<0Ogmo00?o000006IVIP1VIVH0
101VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT0
2@0I6AT00`00003o0000o`00000bo`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<0
00000?ooo`3oool09`00000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<
C4`00ol00000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00?o000009VIV@2IVIT00P2I
VIT00`000000/k>c0;>c/`030;>c/`03o`0000000000c<c<00@0c<c<0ol0000@0>KViP03o`00003<
c<`0c<c<00D0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@030000001o
Ogl0Ogmo0080Ogmo00@0000006IVIP1VIVH0IVIV0`3oool00`000000oooo0?ooo`0a0?ooo`05o`00
003oool0oooo06IVIP0000001P1oOgl00ol00000VIVI09VIV@0509VIV@8000004`2c/k<2000000H0
VIVI0P0000000ol00000Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV00?o000004a<C01<
C4`00`1<C4`00`000000<c<c03<c<`0603<c<`03o`00000I6AT06ATI00T06ATI00<00000o`000?l0
0000<ol000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo02H00000
300I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH0
0`1VIVH00ol00000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00?o00000;>c/`2c/k<0
0P2c/k<00`000000c<c<0<c<c0030<c<c0;o00004`3Vi^H00ol00000c<c<0<c<c0050<c<c0030000
002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0207moO`040000
001VIVH0IVIV06IVIP<0oooo00<000000?ooo`3oool0<@3oool01Ol00000oooo0?ooo`1VIVH00000
00H0Ogmo00<0000009VIV@2IVIT01`2IVIT2000000h0/k>c0`00000709VIV@030000001oOgl0Ogmo
00D0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c
00D0<c<c00<0000001TI6@0I6AT02P0I6ATfo`0000<0oooo00?o00000?ooo`3oool06@3oool001X0
oooo00<000000?ooo`3oool09@00000<01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<
C4`00P1<C4`00`000000IVIV06IVIP0406IVIP050000001oOgl0Ogmo07moO`0000001@2IVIT00`00
0000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H0503Vi^H00ol0
0000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00`2IVIT00`00
0000Ogmo07moO`0207moO`040000001VIVH0IVIV06IVIP<0oooo00<000000?ooo`3oool0<@3oool0
1Ol00000oooo0?ooo`1VIVH0000000L0Ogmo00<0000009VIV@2IVIT0202IVIT2000000T0/k>c0`00
000809VIV@8000001P1oOgl2000000D0IVIV0P00000604a<C0030000000c<c<0<c<c00D0<c<c00<0
000001TI6@0I6AT02P0I6AT00`00003o0000o`00000do`0000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00<000000?ooo`3oool09@00000;01TI6@030000000c<c<0<c<c00D0<c<c00<00000
04a<C01<C4`00P1<C4`00`000000IVIV06IVIP0406IVIP050000001oOgl0Ogmo07moO`0000001@2I
VIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H05P3V
i^H00ol00000c<c<0<c<c0040<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2I
VIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV0`3oool00`000000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo0080IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VI
V@0:09VIV@T000002P2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00@0IVIV00<0
000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00X06ATI00<0
0000o`000?l00000=Ol000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0
oooo02@000002`0I6AT00`000000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00<0C4a<00?o0000
06IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`06o`00002IVIT0VIVI09VIVOl000000000
102c/k<00ol00000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00T0i^KV1?l0000;0>KViP03o`00
003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@030000
001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH30?ooo`030000003oool0oooo0340oooo
00?o00000?ooo`3oool00P1VIVH00`000000Ogmo07moO`0507moO`0300000?l00000VIVI01X0VIVI
0P00000707moO`03o`00001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`2000000L0<c<c
00?o000001TI6@0I6AT02P0I6AT00`00003o0000o`00000fo`0000<0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00<000000?ooo`3oool09000000;01TI6@030000000c<c<0<c<c00@0<c<c00<0
000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00D0
000009VIV@2IVIT0VIVI000000050;>c/`030000003<c<`0c<c<0080c<c<0_l000080>KViPCo0000
103oool2o`0000T0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000
002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP<0oooo
00<000000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0306IVIP030000001oOgl0Ogmo00H0Ogmo
00<0000009VIV@2IVIT05P2IVIT2000000L0Ogmo0P00000506IVIP0300000?l00000C4a<00@0C4a<
0P00000803<c<`030000000I6AT06ATI00X06ATI>_l000030?ooo`03o`00003oool0oooo01T0oooo
000J0?ooo`030000003oool0oooo02<000002`0I6AT00`000000<c<c03<c<`0403<c<`030000001<
C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`050000002I
VIT0VIVI09VIV@000000102c/k<2000000@0c<c<00?o00000>KViP3Vi^H01@3Vi^H3o`0000X0oooo
00?o00000>KViP3Vi^H01P3Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c
00D0000009VIV@2IVIT0VIVI0000000407moO`030000001VIVH0IVIV00<0IVIV00Co00000?ooo`3o
ool00000<`3oool00ol00000oooo0?ooo`0406IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VI
V@2IVIT04P2IVIT3000000L0Ogmo0P00000606IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c
<`0c<c<01P0c<c<2000000`06ATI00<00000o`000?l00000>?l000030?ooo`03o`00003oool0oooo
01T0oooo000J0?ooo`030000003oool0oooo0240000000?o000001TI6@0I6AT02@0I6AT00`000000
<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00ol00000
Ogmo07moO`0207moO`050000002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<c0030<c<
c003o`00003Vi^H0i^KV00@0i^KV0_l0000>0?ooo`03o`00003Vi^H0i^KV00D0i^KV00?o00000<c<
c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIVOl00000101oOgl0
0`000000IVIV06IVIP0306IVIP040000003oool0oooo000003<0oooo00?o00000?ooo`3oool0101V
IVH00ol00000Ogmo07moO`0707moO`@00000302IVIT200000003o`0000000000Ogmo00L0Ogmo00<0
0000o`00001VIVH01@1VIVH00ol00000000004a<C00504a<C0030000000c<c<0<c<c00H0<c<c00<0
000001TI6@0I6AT02`0I6AT00`00003o0000o`00000io`0000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00<000000?ooo`3oool08P00000:01TI6@030000000c<c<0<c<c00D0<c<c00<00000
04a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00D00000
09VIV@2IVIT0VIVI000000040;>c/`030000003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H0103V
i^H00ol00000oooo0?ooo`0>0?ooo`03o`00003Vi^H0i^KV00D0i^KV00?o00000<c<c03<c<`00`3<
c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@000000101oOgl00`000000IVIV
06IVIP0306IVIP040000003oool0oooo000003<0oooo00?o00000?ooo`3oool01@1VIVH00`000000
Ogmo07moO`0:07moO``000002`1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0
C4a<00<00000o`00000c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6@0300000?l0003o000003[o
00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0Q000000X06ATI
00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0050000001VIVH0IVIV06IVIP00
00001@1oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`00`3<c<`00ol0
0000i^KV0>KViP030>KViP03o`00003oool0oooo00l0oooo00?o00000>KViP3Vi^H01@3Vi^H00ol0
0000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0VIVI00000004
07moO`030000001VIVH0IVIV0080IVIV00D000000?ooo`3oool0oooo0000000c0?ooo`03o`00003o
ool0oooo00H0IVIV00<0000007moO`1oOgl07@1oOgl3000000L0IVIV00<0000004a<C01<C4`01@1<
C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00/06ATI00<00000o`000?l00000>ol0
00030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo020000002`0I6AT0
0`000000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV0000
000507moO`030000002IVIT0VIVI0080VIVI00D000000;>c/`2c/k<0/k>c000000050<c<c003o`00
003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool04@3oool00ol00000i^KV0>KViP040>KViP03o`00
003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000@0
Ogmo00<0000006IVIP1VIVH00`1VIVH01@000000oooo0?ooo`3oool0000003<0oooo00?o00000?oo
o`3oool01`1VIVH00`000000Ogmo07moO`0I07moO`<00000201VIVH2000000L0C4a<00<0000003<c
<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6@0300000?l0003o000003co00000`3oool00ol0
0000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0O000000/06ATI00<0000003<c<`0c
<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00?o000007moO`1o
Ogl00P1oOgl00`000000VIVI09VIV@0209VIV@050000002c/k<0/k>c0;>c/ol000001@3<c<`00ol0
0000i^KV0>KViP030>KViP03o`00003oool0oooo0180oooo00?o00000>KViP3Vi^H0103Vi^H00ol0
0000c<c<0<c<c0020<c<c003o`00002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0VIVI00000004
07moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C03oool00P3oool00`000000oooo0?ooo`0a
0?ooo`03o`00003oool0oooo00P0IVIV00?o00000000000000005P1oOgl2000000T0IVIV0P000007
04a<C003o`0000000000<c<c00H0<c<c0P00000=01TI6@0300000?l0003o000003go00000`3oool0
0ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0O000000/06ATI00<0000003<c
<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00D0000007mo
O`1oOgl0Ogmoo`00000509VIV@050000002c/k<0/k>c0;>c/`000000103<c<`00ol00000i^KV0>KV
iP040>KViP03o`00003oool0oooo0180oooo00?o00000>KViP3Vi^H0103Vi^H01Ol00000c<c<0<c<
c03<c<`0000000D0/k>c00D0000009VIV@2IVIT0VIVI0000000407moO`030000001VIVH0IVIV0080
IVIV00<0000004a<C03oool00P3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00/0
IVIV0P00000B07moO`8000002@1VIVH2000000P0C4a<00<0000003<c<`0c<c<01P0c<c<00`000000
6ATI01TI6@0<01TI6D7o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo
0?ooo`0N000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000
001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@050000
002c/k<0/k>c0;>c/`0000001@3<c<`00ol00000i^KV0>KViP030>KViP03o`00003oool0oooo01<0
oooo00?o00000>KViP3Vi^H00`3Vi^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080
/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080
IVIV00<0000004a<C03oool00P3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00d0
IVIV00<0000007moO`1oOgl02`1oOgl4000000X0IVIV00<0000004a<C01<C4`01P1<C4`2000000T0
<c<c00<0000001TI6@0I6AT02`0I6AT00`00003o0000o`00000oo`0000<0oooo00?o00000?ooo`3o
ool06@3oool001X0oooo00<000000?ooo`3oool07@0000000ol000006ATI01TI6@0901TI6@030000
000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0306IVIP050000
001oOgl0Ogmo07moO`000000102IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<0080
c<c<00?o00000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0C0?ooo`03o`00003Vi^H0i^KV00@0
i^KV00Go00000<c<c03<c<`0c<c<000000050;>c/`050000002IVIT0VIVI09VIV@000000101oOgl0
0`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0oooo00<000000?ooo`3oool0<@3oool0
1?l00000oooo0?ooool0000=06IVIPd00000301VIVH2000000P0C4a<00<0000003<c<`0c<c<0200c
<c<00`0000006ATI01TI6@0;01TI6@0300000?l0003o0000043o00000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00`000000oooo0?ooo`0M000000/06ATI00?o000003<c<`0c<c<01@0c<c<0
0ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl0
1@000000VIVI09VIV@2IVIWo000000@0/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KV
iP030>KViP03o`00003oool0oooo01@0oooo00?o00000>KViP3Vi^H00`3Vi^H00ol00000c<c<0<c<
c0020<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07mo
O`1oOgl0000000@0IVIV00@00000o`00001<C4`0C4a<0`3oool00`000000oooo0?ooo`0a0?ooo`04
o`00003oool0oooo04a<C0800000801VIVH4000000L0C4a<00<00000o`0000000000200c<c<00`00
003o00000000000=01TI6@0300000?l0003o0000047o00000`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00`000000oooo0?ooo`0M000000/06ATI00<0000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00404a<C0050000001VIVH0IVIV06IVI_l000001@1oOgl01@000000VIVI09VIV@2IVIT0
000000<0/k>c00?o00000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP030>KViP03o`00003oool0
oooo01@0oooo00?o00000>KViP3Vi^H00`3Vi^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0
/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00@0
000004a<C01<C4`0C4a<0`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00<0C4a<
00<0000006IVIP1VIVH06`1VIVH2000000X0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI
01TI6@0<01TI6@0300000?l0003o000004?o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3o
ool00`000000oooo0?ooo`0L000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<
C00304a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl01@000000VIVI09VI
V@2IVIT0000000@0/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP030>KViP03o`00
003oool0oooo01@0oooo00?o00000>KViP3Vi^H00`3Vi^H00ol00000c<c<0<c<c0020<c<c0030000
002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT01Ol00000Ogmo07moO`1oOgl0000000@0
IVIV00<0000004a<C01<C4`00P1<C4`30?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3o
ool0101<C4`3000001P0IVIV0P00000;04a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I
6AT0300I6AT00`00003o0000o`000014o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo
00<000000?ooo`3oool06`00000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0
0`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0
VIVI000000040;>c/`030000003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000
oooo0?ooo`0C0?ooo`03o`00003Vi^H0i^KV00<0i^KV00?o00000<c<c03<c<`00P3<c<`00ol00000
/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00D0000007moO`1oOgl0Ogmoo`00000506IV
IP030000001<C4`0C4a<0080C4a<0`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo
00L0C4a<00?o000006IVIP1VIVH04@1VIVH01000003o000000000000000:04a<C00300000?l00000
000000T0<c<c0P00000>01TI6@0300000?l0003o000004Go00000`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00`000000oooo0?ooo`0K000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`00
0000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmoo`000004
09VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP04
0>KViP03o`00003oool0oooo01<0oooo00?o00000>KViP3Vi^H00`3Vi^H00ol00000c<c<0<c<c002
0<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1o
Ogl0000000D0IVIV00<0000004a<C01<C4`00P1<C4`01?l00000oooo0?ooo`00000c0?ooo`03o`00
003oool0oooo00L0C4a<0`00000>06IVIP<00000301<C4`2000000/0<c<c00<0000001TI6@0I6AT0
3@0I6AT00`00003o0000o`000016o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<0
00000?ooo`3oool06P00000<01TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<
C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVI
000000050;>c/`030000003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo
0?ooo`0B0?ooo`03o`00003Vi^H0i^KV00<0i^KV00?o00000<c<c03<c<`00`3<c<`01@000000/k>c
0;>c/`2c/k<0000000@0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP03
0000001<C4`0C4a<00<0C4a<00Co00000?ooo`3oool00000<`3oool00ol00000oooo0?ooo`0:04a<
C0h000003@1<C4`2000000/0<c<c0P00000?01TI6@0300000?l0003o000004Oo00000`3oool00ol0
0000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0I00000003o`00000I6AT06ATI00T0
6ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080
IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@030000002c/k<0/k>c0080/k>c00<000000<c<
c03<c<`00P3<c<`00ol00000i^KV0>KViP040>KViP03o`00003oool0oooo0180oooo00?o00000>KV
iP3Vi^H0103Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/ol00000102IVIT0
0`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00`1<C4`0
1Ol00000oooo0?ooo`3oool0000003<0oooo00?o00000?ooo`3oool0901<C4`00`000000<c<c03<c
<`0:03<c<`030000000I6AT06ATI00h06ATI00<00000o`000?l00000B?l000030?ooo`03o`00003o
ool0oooo01T0oooo000J0?ooo`030000003oool0oooo01X000002`0I6AT00ol00000<c<c03<c<`04
03<c<`030000001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`02
07moO`030000002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c002
0<c<c003o`00003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool0403oool2o`0000H0i^KV00?o0000
0<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIVOl00000101o
Ogl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00?o000003<c<`3oool00P3o
ool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo0280C4a<00<00000o`00000c<c<02`0c
<c<00`0000006ATI01TI6@0=01TI6@800000Bol000030?ooo`03o`00003oool0oooo01T0oooo000J
0?ooo`030000003oool0oooo01X000002P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0
C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0
VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0
i^KV00@0i^KV00?o00000?ooo`3oool03`3oool00ol00000i^KV0>KViP050>KViP03o`00003<c<`0
c<c<0080c<c<00<000000;>c/`2c/k<00`2c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo00<0
000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C003o`00000c<c<0oooo0080oooo00<0
00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0O04a<C0<00000300c<c<00`00003o000001TI
6@0>01TI6@0300000?l0003o000004_o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0`000000oooo0?ooo`0I000000/06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C004
04a<C0050000001VIVH0IVIV06IVIP0000001@1oOgl00`000000VIVI09VIV@0209VIV@050000002c
/k<0/k>c0;>c/`0000001@3<c<`00ol00000i^KV0>KViP040>KViP03o`00003oool0oooo00h0oooo
00?o00000>KViP3Vi^H01@3Vi^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c00<0/k>c
00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<
C4`00`1<C4`00ol00000<c<c03<c<`030?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3o
ool00P00000I04a<C0@000003@0c<c<2000001006ATI00<00000o`000?l00000C?l000030?ooo`03
o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo01T000002P0I6AT00`000000<c<c
03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo
07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<
0<c<c0020<c<c003o`00003Vi^H0i^KV00D0i^KV00?o00000?ooo`3oool03@3oool00ol00000i^KV
0>KViP050>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI
09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<
04a<C00204a<C004o`00000c<c<0<c<c03<c<`<0oooo00<000000?ooo`3oool0<@3oool00ol00000
oooo0?ooo`0203<c<`030000001<C4`0C4a<01@0C4a<0P00000@03<c<`030000000I6AT06ATI00l0
6ATI00<00000o`000?l00000COl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000
003oool0oooo01P000002`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<
00<0000006IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI
00<000000;>c/`2c/k<00P2c/k<00ol00000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00D0i^KV
00?o00000?ooo`3oool02`3oool2o`0000H0i^KV0_l000050<c<c0030000002c/k<0/k>c0080/k>c
00@0000009VIV@2IVIT0VIVI0P00000407moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<
C4`00`1<C4`01?l00000<c<c03<c<`0c<c<30?ooo`030000003oool0oooo0340oooo00?o00000?oo
o`3oool00`0c<c<01?l00000000000000000000=04a<C0@0000000?o000003<c<`0c<c<03P0c<c<0
0`00003o000001TI6@0?01TI6@0300000?l0003o000004oo00000`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00`000000oooo0?ooo`0H000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`00
0000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`00
0000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<c<`00ol0
0000i^KV0>KViP060>KViP;o00001`3oool4o`0000L0i^KV00?o00000<c<c03<c<`0103<c<`00`00
0000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@0000001@1oOgl00`000000IVIV06IVIP02
06IVIP030000001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<00P0c<c<30?ooo`030000003oool0
oooo0340oooo00?o00000?ooo`3oool01`0c<c<=000001<0<c<c0P00000@01TI6@800000D_l00003
0?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo01L000002`0I6AT00`00
0000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`00
0000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`00
0000c<c<0<c<c0040<c<c003o`00003Vi^H0i^KV00L0i^KV0_l000020?ooo`?o00002P3Vi^H00ol0
0000c<c<0<c<c0030<c<c0800000102c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo
0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C003o`00000c<c<0<c<c
00<0<c<c0`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo02D0<c<c0P00000A01TI
6@0300000?l0003o000005;o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000
oooo0?ooo`0G000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C003
0000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@03
0000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`0103<c<`00ol00000i^KV0>KViP090>KViP;o
00002`3Vi^H2o`0000D0c<c<00<000000;>c/`2c/k<00`2c/k<00ol00000VIVI09VIV@0209VIV@03
0000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C003
o`00000c<c<0<c<c00@0<c<c0`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo0280
<c<c00<00000o`00000000004P0I6AT00`00003o0000o`00001Co`0000<0oooo00?o00000?ooo`3o
ool06@3oool001X0oooo00<000000?ooo`3oool05`00000;01TI6@030000000c<c<0<c<c00D0<c<c
00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo
00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00@0c<c<
00?o00000>KViP3Vi^H05@3Vi^H00ol00000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00<0/k>c
00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV0080IVIV
00<0000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`04o`00003oool0oooo000003<0
oooo00?o00000?ooo`3oool07`0c<c<3000001<06ATI00<00000o`000?l00000EOl000030?ooo`03
o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo01L000002`0I6AT00`000000<c<c
03<c<`0503<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo
07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<
0<c<c0040<c<c003o`00003Vi^H0i^KV0180i^KV0_l000060<c<c0030000002c/k<0/k>c00<0/k>c
00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV0080IVIV
00<0000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0503<c<`04o`00003oool0oooo000003<0
oooo00?o00000?ooo`3oool07P0c<c<00`0000006ATI01TI6@0C01TI6@0300000?l0003o000005Ko
00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0F000000/06ATI
00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV
00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c
00<000000<c<c03<c<`0103<c<`00ol00000i^KV0>KViP0A0>KViP03o`00003<c<`0c<c<00D0c<c<
00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo
00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C003o`00000c<c<0<c<c00D0<c<c
00Go00000?ooo`3oool0oooo0000000c0?ooo`03o`00003oool0oooo01`0<c<c0P00000E01TI6@03
00000?l0003o000005Oo00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo
0?ooo`0F000000/06ATI00?o000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C003o`00
001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000
002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<c<`3o`0000`0i^KV1?l000060<c<c0800000
102c/k<2000000@0VIVI00<0000007moO`1oOgl00P1oOgl00`00003o000006IVIP0306IVIP030000
001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI0?ooo`020?ooo`030000
003oool0oooo0340oooo00?o00000?ooo`3oool0600c<c<01000003o000000000000000E01TI6@03
00000?l0003o000005Wo00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo
0?ooo`0F000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000
001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000
002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0203<c<`3o`0000H0i^KV0ol000080<c<c0800000
1@2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0
0`1VIVH00`000000C4a<04a<C00304a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT0
0`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo01@0<c<c1000000F01TI6@<00000
G?l000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo01D00000300I
6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00P1V
IVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00`2c
/k<00`000000c<c<0<c<c00:0<c<c0Ko00002P3<c<`00`000000/k>c0;>c/`040;>c/`030000002I
VIT0VIVI0080VIVI0P00000407moO`030000001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`00`1<
C4`00ol00000<c<c03<c<`0503<c<`04o`00000I6AT06ATI01TI6@<0oooo00<000000?ooo`3oool0
<@3oool00ol00000oooo0?ooo`03000000X0<c<c1`00000I01TI6@0300000?l0003o000005go0000
0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0D000000`06ATI00<0
000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV0080IVIV00<0
000007moO`1oOgl00`1oOgl00ol00000VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<0
00000<c<c03<c<`05P3<c<`200000003o`00002c/k<0/k>c0080/k>c0P0000000ol00000VIVI09VI
V@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<
C00304a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT00P0I6AT30?ooo`030000003o
ool0oooo0340oooo00?o00000?ooo`3oool00`0I6AT:000001l06ATI00<00000o`000?l00000G_l0
00030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo01@00000300I6AT0
0`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00P1VIVH0
0`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<0
0`000000c<c<0<c<c00E0<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT01@2IVIT0
0`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`0
0ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00806ATI0`3oool00`000000oooo0?ooo`0a
0?ooo`03o`00003oool0oooo02X06ATI00<00000o`000?l00000H?l000030?ooo`03o`00003oool0
oooo01T0oooo000J0?ooo`030000003oool0oooo01@00000300I6AT00`000000<c<c03<c<`0503<c
<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0307mo
O`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<200000180c<c<0`0000060;>c
/`030000002IVIT0VIVI00@0VIVI0P00000407moO`030000001VIVH0IVIV00<0IVIV00<0000004a<
C01<C4`0101<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00<06ATI0`3oool00`00
0000oooo0?ooo`0a0?ooo`03o`00003oool0oooo02L06ATI0`00001So`0000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00<000000?ooo`3oool05000000;01TI6@030000000c<c<0<c<c00H0
<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00<0
Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`060;>c/`8000003@3<c<`3000000P0
/k>c00<0000009VIV@2IVIT00`2IVIT2000000D0Ogmo00<0000006IVIP1VIVH00`1VIVH00ol00000
C4a<04a<C00404a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT0100I6AT30?ooo`03
0000003oool0oooo0340oooo00?o00000?ooo`3oool09P0I6AT00`00003o0000o`00001To`0000<0
oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool05000000;01TI6@030000
000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0406IVIP030000
001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0102IVIT00ol00000/k>c0;>c/`070;>c/`<00000
1P3<c<`300000003o`00002c/k<0/k>c00H0/k>c0P0000000ol00000VIVI09VIV@0209VIV@800000
1@1oOgl2000000D0IVIV00<0000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0503<c<`03o`00
000I6AT06ATI00D06ATI0`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo02<06ATI
00<00000o`0000000000Iol000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003o
ool0oooo01@000002`0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00<0C4a<00<0
000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00D0VIVI00<0
00000;>c/`2c/k<02@2c/k<6000000X0/k>c0P00000609VIV@030000001oOgl0Ogmo00@0Ogmo00<0
000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C003o`00000c<c<0<c<c00D0<c<c00?o
000001TI6@0I6AT01P0I6AT30?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool08@0I
6AT2000006[o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0C
000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0
IVIV00@0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0
/k>c01H0/k>c0P00000709VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH0
0`000000C4a<04a<C00404a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT01`0I6AT3
0?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool07`0I6AT2000006co00000`3oool0
0ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0B00000003o`00000I6AT06ATI
00X06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV
00@0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c
01@0/k>c00<0000009VIV@2IVIT01P2IVIT00ol00000Ogmo07moO`0407moO`030000001VIVH0IVIV
00@0IVIV00<0000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI
00P06ATI0`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo01d06ATI0P00001^o`00
00<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool04`00000<01TI6@03
0000000c<c<0<c<c00H0<c<c00?o000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP03
0000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01P2IVIT00ol0000000000;>c/`0@0;>c/`80
000000?o000009VIV@2IVIT01@2IVIT2000000D0Ogmo0P00000506IVIP8000001@1<C4`2o`0000L0
<c<c00?o000001TI6@0I6AT02@0I6AT30?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3o
ool06`0I6AT20000073o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo
0?ooo`0C000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C003o`00
001VIVH0IVIV00@0IVIV00?o000007moO`1oOgl0101oOgl00ol00000000009VIV@0809VIV@<00000
1`2c/k<7000000P0VIVI0P00000507moO`8000001@1VIVH2000000H0C4a<00?o000003<c<`0c<c<0
1P0c<c<00ol000006ATI01TI6@0:01TI6@04o`00003oool0oooo000003<0oooo00?o00000?ooo`3o
ool0600I6AT3000007;o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo
0?ooo`0C000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000
001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0909VIV@L00000
3@2IVIT2000000D0Ogmo0P00000606IVIP030000001<C4`0C4a<00D0C4a<00?o000003<c<`0c<c<0
1P0c<c<00ol000006ATI01TI6@0:01TI6@05o`00003oool0oooo0?ooo`000000<`3oool00ol00000
oooo0?ooo`0D01TI6@@00000MOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000
003oool0oooo01<00000300I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<
00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI01P0VIVI
1000000507moO`8000001P1VIVH2000000L0C4a<00?o000003<c<`0c<c<01P0c<c<00ol000006ATI
01TI6@0:01TI6@03o`0000000000oooo0080oooo00<000000?ooo`3oool0<@3oool00ol00000oooo
0?ooo`0@01TI6@@00000NOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`030000003o
ool0oooo01<00000300I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<00<0
000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0607moO`03o`0000000000VIVI01D0VIVI0P00
000807moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01@1<C4`2o`0000P0<c<c00?o
000001TI6@0I6AT02P0I6AT00ol000000000000000030?ooo`030000003oool0oooo0340oooo00?o
00000?ooo`3oool03@0I6AT3000007go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0`000000oooo0?ooo`0C000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C005
04a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01`1oOgl200000100VIVI10000008
07moO`8000001`1VIVH00`000000C4a<04a<C00504a<C003o`00000c<c<0<c<c00L0<c<c00?o0000
01TI6@0I6AT02P0I6AT01?l0000000000000000000030?ooo`030000003oool0oooo0340oooo00?o
00000?ooo`3oool01P0I6AT70000083o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0`000000oooo0?ooo`0B000000d06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C005
04a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl0201oOgl6000000L0VIVI0`00000:
07moO`8000001`1VIVH2000000L0C4a<00?o000003<c<`0c<c<01P0c<c<2o`0000`06ATI00?o0000
0000000000000P0000030?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool01P000027
o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool04P00000=01TI
6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0606IV
IP03o`0000000000Ogmo00h0Ogmo1`00000:07moO`<000001`1VIVH2000000L0C4a<0_l0000803<c
<`03o`00000I6AT06ATI00/06ATI00?o00000000000000000`0000030?ooo`030000003oool0oooo
0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
0000003oool0oooo018000003@0I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00H0
C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0J07moO`<00000201VIVH2000000P0
C4a<00?o000003<c<`0c<c<01`0c<c<00ol000006ATI01TI6@0;01TI6@03o`0000000000000000@0
00000`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000
oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0B000000h06ATI00<0000003<c<`0c<c<0
1`0c<c<00`000000C4a<04a<C00604a<C0030000001VIVH0IVIV00L0IVIV0`00000H07moO`030000
001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`01P1<C4`2o`0000P0<c<c0_l0000=01TI6@03o`00
00000000000000D000000`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go0000
0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0B000000h06ATI00<0
000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C00704a<C003o`00001VIVH0IVIV00T0IVIV0P00
000B07moO`04o`00000000000000000000P0IVIV0P0000000ol00000C4a<04a<C00504a<C0;o0000
2@0c<c<00ol000006ATI01TI6@0<01TI6@03o`0000000000000000H000000`3oool00`000000oooo
0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3o
ool00`000000oooo0?ooo`0B000000h06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<
C00804a<C0030000001VIVH0IVIV00T0IVIV00?o00000000000000001000000607moO`H000002`1V
IVH00`000000C4a<04a<C00604a<C0;o00002@0c<c<2o`0000h06ATI00?o00000000000000001`00
00030?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003o
ool0oooo01T0oooo000J0?ooo`030000003oool0oooo018000003`0I6AT00`000000<c<c03<c<`07
03<c<`030000001<C4`0C4a<00P0C4a<0P00000@06IVIPH000003P1VIVH3000000P0C4a<00?o0000
03<c<`0c<c<0200c<c<00ol000006ATI01TI6@0<01TI6@;o00002P0000030?ooo`030000003oool0
oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?oo
o`030000003oool0oooo01<000003P0I6AT00`000000<c<c03<c<`0803<c<`030000001<C4`0C4a<
00T0C4a<00<0000006IVIP1VIVH07P1VIVH3000000X0C4a<00?o000003<c<`0c<c<0200c<c<00ol0
00006ATI01TI6@0<01TI6@03o`0000000000000000X000000`3oool00`000000oooo0?ooo`0a0?oo
o`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000
oooo0?ooo`0C000000h06ATI00<0000003<c<`0c<c<02@0c<c<00`000000C4a<04a<C00904a<C003
0000001VIVH0IVIV01`0IVIV00?o000004a<C01<C4`0201<C4`3o`0000T0<c<c0_l0000>01TI6@03
o`0000000000000000/000000`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go
00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0C000000h06ATI
00<0000003<c<`0c<c<02@0c<c<00`000000C4a<04a<C00:04a<C003o`0000000000000001P0IVIV
0`00000904a<C0;o00002`0c<c<00ol000006ATI01TI6@0=01TI6@;o00003@0000030?ooo`030000
003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo
000J0?ooo`030000003oool0oooo01<000003`0I6AT00`000000<c<c03<c<`0903<c<`030000001<
C4`0C4a<00`0C4a<0`00000>06IVIPL000002P1<C4`2o`0000/0<c<c0_l0000?01TI6@03o`000000
0000000000d000000`3oool00`000000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0B00000003o`00000I6AT0
6ATI00d06ATI00<0000003<c<`0c<c<02P0c<c<00ol00000C4a<04a<C00>04a<C0h00000401<C4`0
0ol00000<c<c03<c<`0:03<c<`03o`00000I6AT06ATI00h06ATI00?o00000000000000003P000003
0?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0
oooo01T0oooo000J0?ooo`030000003oool0oooo0180000000?o000001TI6@0I6AT03P0I6AT00`00
0000<c<c03<c<`0:03<c<`03o`00001<C4`0C4a<02X0C4a<00?o000003<c<`0c<c<02P0c<c<00ol0
00006ATI01TI6@0>01TI6@03o`0000000000000000l000000`3oool00`000000oooo0?ooo`0a0?oo
o`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo0340oooo00?o00000?ooo`3oool0T03oool00ol00000
oooo0?ooo`0I0?ooo`006P3ooonD000003<0ooooU?l0000K0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Q@3oool2o`000<D0oooo0_l000120?ooo`00PP3o
ool3o`0000030?ooool00000oooo0<40oooo0ol000000`3ooooo00000?ooo`110?ooo`00P03oool2
o`0000<0oooo00?oZKWUo`000?l00000_`3oool2o`0000@0oooo0_l000110?ooo`00O@3oool3o`00
00<0oooo0onY^ND00ol00000ooooo`00002k0?ooo`?o0000103oool2ok30iP03o`00003ooooo0000
0400oooo001j0?ooo`?o0000103oool2ojRii@?oZKWU00?o00000?ooool00000^03oool3o`0000@0
oooo00?o/L7Uok30i_n``>H00_n``>H00ol00000ooooo`0000100?ooo`00N03oool2o`0000@0oooo
1_nX^ND2ojVii@04o`00003oool0ooooo`000;D0oooo0_l000060?ooo`?o/L7U0on``>H01?l0003o
/<7V0?ooool0000o0?ooo`00M@3oool3o`0000<0oooo2?nX^ND3ojRhi005o`000?nX^>@0oooo0?oo
ool00000/@3oool3o`0000H0oooo0_nc`^D4ok71i@03ok30i_n``NKo000000;o/<7V00<0ooooo`00
003oool0?@3oool007<0oooo0_l000040?ooo`WoZ;WU1?nX^>@01Ol0003oZ;STojRhi03ooooo0000
0:l0oooo0_l000060?ooo`03okK2honc`^Go/l;U00?o/l;U0_na`ND02?nb`^Ko/<7Vok31i_l0003o
/<7Vok31i`3ooooo0000?P3oool00700oooo0ol000040?ooo`;oZ;WV1_nX^ND7ojRhi006o`000?nX
^>CoZ;KSojRfh`3ooooo0000Z`3oool3o`0000H0oooo1?nf`^<3ok?2i@03okC2iOnb`^Ko//;V00;o
//;V00?o/<7Vo`000?n``NL00_n``NL00`3ooooo00000?ooo`0l0?ooo`00KP3oool2o`0000@0oooo
0_nX^^H4ojRiiP;oZ;WU2?nX^>@2ojRfh`03o`000?nX]^?oZ;KS00;oZ;KS00?o00000?ooo`3oool0
Y`3oool2o`0000L0oooo00?o^<;RokK2honf`^<00onf`^<00onc`^Go]<;UokC2i@02okC2i@Co//;V
00Ko0000ok31ion``NOo/<7W0?ooool0000m0?ooo`00J`3oool3o`000080oooo1onX^^H2ojRiiP03
ojRhiOnX^>CoZ;ST00GoZ;ST1OnX]^<01ol0003oZ;KSojRfhonX]^?oZ;CQ0?ooool00000Y@3oool3
o`0000P0oooo0onh`^83okK2h`;o]/?T1?nd`^D4ok;2iP03o`000?n``NOo/<7W00;o/<7W00<0oooo
o`00003oool0>`3oool006P0oooo0ol000020?ooo`WoZ;[V1OnX^>D5ojRhi0KoZ;KS00?o0000ojRf
honX]>400onX]>400`3ooooo00000?ooo`2P0?ooo`?o00002@3oool2ok[2h0Co^<;R00?o]/;SokK3
i?nf`n@00_nf`n@2okC2i@;o]<?U0onb`^H00ol0003o/<7Wok31i`03ok31i`030?ooool00000oooo
03X0oooo001V0?ooo`;o0000103oool8ojRjiPSoZ;SU0_nX^>@00onW]^?oZ;KSojRfh`05ojRfh`03
ojRchOl0003oZ;CQ00?oZ;CQ00<0ooooo`00003oool0WP3oool2o`0000/0oooo1?nj`^02okS2hP;o
^L?R0onf`n@00onga>Co]<?UokC3i@03okC3i@?o//;V00Oo0000ok31ion``NOo/<7Wojo1i`3ooooo
000003/0oooo001S0?ooo`?o0000103oool2ojRkiPKoZ;[V0_nX^ND6ojRhi@KoYkKS0_nX]^<2ojNc
h@?oZ;?Q00Go0000ojRchOnX]>7oZ;CQojRag`020?ooo`03o`00003oool0oooo09T0oooo0ol0000;
0?ooo`03okc1g_nj`^3o^/;P00;o^/;P00?o^l?QokW3h_ni`n800oni`n801?nf`nCo]lCTokO4i?ng
a>@2okC3i@;o]<?V0onb`^H00ol0003o//;Vok31i`03ojo1i`030?ooool00000oooo03T0oooo001Q
0?ooo`;o0000103oool2ojRki`CoZ;_V0_nX^^H2ojRiiPCoZ;WU0_nX^>D00onW]^CoYkKSojNfh`05
ojNfh`KoYk?Q0_nX/n400ol0003oYk7OojRag`03ojRag`80oooo00?o00000?ooo`3oool0UP3oool2
o`0000`0oooo1?nl`Mh00onj`^3o^l?Qok_3h@02ok_3h@?o^L?R00Go^LCSokO4i?nga>Co]lCTokO4
i@05okC3iP;o//;V00?o0000ok72ion_`NL00on_`NL20?ooo`03o`00003oool0oooo03L0oooo001N
0?ooo`?o00000P3oool7ojRki`;oZ;_V1_nX^NH2ojRii@03ojNgi?nW]^CoYkKT00;oYkKT0onW]^<0
0onW/n;oYk?QojNch@06ojNch@03ojRchOnW/Moo000000;oYk7O1?nX/Ml00`3ooooo00000?ooo`2D
0?ooo`?o0000303oool2okg0g0?o_<7N00?o_L?Nok_3hOnk`n400onk`n400oni`n;o^LCSokW4h`02
okW4h`04okO4i?nga>Go]lCUokO4i@?o]<?V0_nda>H01?na`^Oo0000ok72iona`^L4ojo1i`030?oo
ool00000oooo03P0oooo001L0?ooo`;o00000P3oool00onX_>OoZ;_WojRki`06ojRki`03ojRji_nX
^NKoZ;WV00GoZ;WV00?oYkOUojNgi?nW]n@00_nW]n@4ojNfi004ojNfhonW/n;oYk?RojNchPKoYk?Q
0onW/Ml00ol0003oYk7OojNag`02ojRag`;oZ:oM0P3oool00ol00000oooo0?ooo`2@0?ooo`;o0000
3P3oool4okg0g004okc1g_nm`mko_L?Nokg3gP?o^l?Q0_nlaN43okW4h`;o^/KS1?nga>D00ond`nKo
]<CVokC4iP02okC4iP04o`000?na`^Oo/L?Wok73i`Co[l7W00<0ooooo`00003oool0=`3oool005T0
oooo0ol000030?ooo`?oZ;cW1OnX^nL4ojRjiPCoZ;WV1?nW]nD4ojNgi0;oYkKT0_nV]>84ojNchP;o
Yk?Q00?oY[7OojNagonW/Ml00onW/Ml00ol0003oYk7OojN^g005ojR_g@80oooo00?o00000?ooo`3o
ool0S03oool3o`0000h0oooo0_nn_]T3okg0g003oko2g?nm`mko_L?N00?o_L?N00?o^l?Qokc5hOnl
aN400_nlaN400onia>?o^/KSok[6h`02ok[6h`;o]lCU0_ngaND3okC4iP03ok?4i_l0003o/L?W00?o
/L?W0on_`NL20?ooo`03o`00003oool0oooo03D0oooo001G0?ooo`;o0000103oool2ojVli`CoZ;cW
0_nX^nL6ojRjiP;oZ;WV0_nW^>D4ojNgi@;oYkOT0_nV]><5ojJdhP;oYk?R00?oY[7PojJagonV/Ml0
0_nV/Ml3ojNag`03ojJ^gOl0003oYjkL00;oYjkL1?nX[md20?ooo`03o`00003oool0oooo08X0oooo
0_l0000@0?ooo`Co_[kI00Co_L3Loko2g?no`]co_l;L0onm`mh2oko5g`?o_<GQ00?o_LKRok[6honj
a^<00_nja^<00onja^Co]lGUokO5i@03okO5i@04okC4i_nca>Ko/lCVo`0000Co/L?W1?n_`NL00`3o
oooo00000?ooo`0f0?ooo`00E03oool3o`0000<0oooo1_nY_>L2ojRli`;oZ;_W1_nX^^H6ojNhi@;o
YkOU0_nV]N<4ojJdh`;oY[CR1_nV/N04ojJag`04ojNagonV[]goYZkMo`0000CoYjkL0_nX[md01OnX
[=X0oooo0?ooo`3ooooo000008P0oooo0ol0000@0?ooo`03oknleonn_]Wo_[kI00;o_[kI00?o`L7J
oko2g?no`]`00ono`]`00onm`mko_lGOoko5g`02oko5g`05okc5hOnma^;o_LKRokg6h_nja^<01?nj
a^@3okO5i@05okK6i_nca>Ko/lCVok?4i_l000001Ona`nL2ojo1i`;o[/7X00<0ooooo`00003oool0
=@3oool00540oooo0ol000030?ooo`SoZKcW1_nX^nL2ojRjiP;oYkWV1_nW^>D00onV]^CoY[GSojJe
h`03ojJeh`;oY[CS00?oYK7QojJah?nV/N001_nV/N02ojJag`;oYZgM0onV[]d01Ol0003oYZkMojN^
g?nW[]coYj_J00CoZ:cJ0`3oool00ol00000oooo0?ooo`220?ooo`?o00004@3oool4oknle`;o_[kI
0oo1`MX3oko2g003ol75g?noaMoo_lGO00;o_lGO00Co`<OOokg6h_nma^;o_LKR0_nmb>84ok[6i003
okO5iOnfa^Ko]/KV00;o]/KV0_nca>H00ol0003o/lCWok73i`02ok73i`03ok32ion^`NSo[/7X00?o
[/7X00<0ooooo`00003oool0=03oool004l0oooo0_l000030?ooo`;oZKcX1_nY_>L8ojRki`;oZ;[V
1?nW^NH2ojNhi@GoY[KT0onV]N<00onU/^7oYK7QojFah@02ojFah@KoY[7P00?oYJgMojJ]gOnV[Md0
0onV[Md2ojJ^g@03o`000?nVZ][oYj_J00?oYj_J1?nX[=X20?ooo`03o`00003oool0oooo0800oooo
0_l0000C0?ooo`Go_kcG00?o_[kIol71f_o1`MX00_o1`MX00ono`]co`LGLol75g002ol75g003oko5
goo0amoo`<OO00;o`<OO00?o_LKRokg8h_nmb>800_nmb>82ok[6i0;o^/OU1Onfa^H01Onca>Oo0000
ok?4ionca>Oo/L?W00?o/<;W1?n^`NP00`3ooooo00000?ooo`0d0?ooo`00C03oool3o`000080oooo
00?oZKgXojVlj?nY_>P00onY_>P3ojVli`OoZ;_W1_nX^^H2ojNiiP03ojNgiOnV]^CoY[KT00KoY[KT
00CoY[GSojFbhOnU/^7oYK;Q1?nU/N42ojJah003ojF]g_nU[MgoYJgM00;oYJgM0onV[Md01?nUZ][o
YZ[JojJZf_l00002ojJZfP?oYj_J0_nX[=X2ojVZf0<0oooo00?o00000?ooo`3oool0O03oool3o`00
01@0oooo0_no^M@3oknle`;o`[oG0oo1`MX2ol?4fP?o`LGL0_o3amd3ol37g`;o`LWP0onmb>82okg9
h`Co^/OU1Onfa^H00ol0003o/lCWok;4i`05ok32i`Co[/7X00<0ooooo`00003oool0<`3oool004X0
oooo0_l000040?ooo`?oZKgX0onY_>P5ojVli`CoZ;_W1onX^^H00onW^>GoYkOUojNgi@02ojNgi@Ko
Y[KT0_nU/n84ojFbh@;oYK7Q00?oY:kNojF]g_nU[Mh00_nU[Mh4ojF]g@06ojJ]gOnUZ][oYJ[JojFZ
f_nVZ][o00000_nVZ]X2ojN[fP03ojNXeonYZ]SoZJ[H00?oZJ[H0P3oool00ol00000oooo0?ooo`1j
0?ooo`;o00005P3oool4oknie003oknleoo2_mOo`[oG00;o`[oG00?o`L7Jol?4f_o3a=X00_o3a=X0
0oo1aMco`lOMol?7g@02ol?7g@03ol37goo1bN3o`LWP00;o`LWP00?o_LSRokg9honmbN<00_nmbN<2
ok[7i@03okW8iOnfa^Ko]/KV00;o]/KV00?o]LKWo`000?nba>L00_nba>L2ok32i`;o[l;X0on^`NP0
0on]`NP0ooooo`00000d0?ooo`00A`3oool3o`0000@0oooo1_nY_NP00onY_>SoZKcWojVli`05ojVl
i`CoZ;_W1OnX^^H3ojNhi@CoYkOU0_nV]^@00onU]>?oYK?RojFchP03ojFchP;oYK;Q00?oY:oOojB^
g_nT[]h00_nT[]h4ojF]gP;oYJgM00?oY:WJojFZf_nUZ]X00onUZ]X00ol0003oYZ[JojJWe`04ojNX
e`CoZJ[H0`3oool00ol00000oooo0?ooo`1f0?ooo`?o00005P3oool2okjfdP?o_kWD00?o`[cDol:o
eoo2_mL00oo2_mL5ol?4fP04olK6foo3amgo`lOMol?7g@;oa<WN0oo1bN000oo1b^7o_LWSokg9h`02
okg9h`03okg:i?nib>Go^LSU00;o^LSU00Go]/KVokG6ionea^Oo]LKWo`000004ok;4i`Co[l;X00Ko
[/7Xojg1j?n]`NSo[L7X0?ooool0000c0?ooo`00A@3oool2o`0000@0oooo2?nY_NP7ojVli`KoZ;_W
0_nX^^H2ojNiiPCoYkSU0_nW]nD2ojJeh`CoYKCS0_nU/n82ojB_h0CoY:oO1?nT[]h2ojF]gP03ojBY
fonTZM[oY:WJ00;oY:WJ0onUZ]X00onUY]Oo0000ojJWe`02ojJWe`CoYjSG0_nYZ]P00onYYmD0oooo
0?ooo`020?ooo`03o`00003oool0oooo07<0oooo0_l0000H0?ooo`Co_[KB00Co_kWDol:le?o2_=Co
`[cD0oo2_mL2olG2e`?o`lCJ0oo6a]/00oo3amgoa<WNolC9gP02olC9gP05ol79h?o1b^7o`L[Qol7:
hOnmbN<01?nmb^@2okW8i@;o^LSV0onea^L00ol0003o]<KWok;4i`03ok;4i`Co[l;X1?n]`NP00`3o
oooo00000?ooo`0a0?ooo`00@P3oool3o`0000<0oooo2OnY_NP6ojVli`SoZ;_W1_nW^NH2ojNhi@;o
Y[KT1?nV]N<2ojFdh`03ojB`hOnT[n3oY:oP00?oY:oP0onT[ml2ojB^gP;oXj[K1?nTZM/4ojBYfP04
ojFZf_nUY]OoYJKGo`0000CoYZOG0_nWZ=L00onXYMCoZJOEojVWe@02ojVWe@<0oooo00?o00000?oo
o`3oool0L03oool3o`0001P0oooo00?o_;;?okjfd_nn]]800onn]]85ol:le003ol:oeoo5`]OoaL;G
00;oaL;G00?o`lCJolK6foo6a]/00_o6a]/4olC9gP04olG;goo1b^7o`L[Qol7:h@;o`LcR1?nmb^@0
0onib>Go^LSVokW8iP02okW8iP03okG6ionda^Oo000000;o]<KW0_nba>L00ona`nSo[l;Xojo2j003
ojo2j0;o[L7X00?o[L3X0?ooool00000<P3oool003l0oooo0ol000030?ooo`goZKgX0_nY_>L2ojRl
i`KoZ;_W0_nX^^H6ojNiiP;oY[OU1?nV]^@2ojJeh`03ojBbh_nT/>7oY;3Q00;oY;3Q1?nT[n02ojB_
g`03oj>[g?nSZ]_oXj[K00?oXj[K0onTZM/2ojBYfP;oY:GG0onUY]L00ol0003oYZOGojJWe`02ojJT
d`CoZ:GD1?nYYmD30?ooo`03o`00003oool0oooo06`0oooo0ol0000J0?ooo`?o_;;?0onn]]82ol:i
dP?o`[cD0_o5_m@3olG2e`;oalGH0oo6a]/2olO9f`;oa<WN0oo5bml00oo1b^7o`LcRol7<hP02ol7<
hP;o_L[T0_nlb^D3okW8iP06okS8i_nda^Oo]<KWo`000?nda^Oo/lGW1?na`nP2ojo2j0;o[/7X1?n]
`>P00`3ooooo00000?ooo`0`0?ooo`00?@3oool2o`0000<0oooo3onY_NP2ojVli`CoZ;cW1?nX^nL4
ojRjiP;oYkWV0_nV^>D4ojJgi@;oY[KT00?oYK?SojBbh_nT/^800_nT/^84ojB`h@;oY:oP00?oXj_M
oj>[g?nSZm`00_nSZm`4oj>Zf`;oY:WK00?oXjGHojBUeonTYML00onTYML2ojFVe`03o`000?nVY=?o
YZCC00?oYZCC1?nXYM@2ojVWe@03ojZUdP3oool0oooo0080oooo00?o00000?ooo`3oool0J@3oool2
o`0001/0oooo00?o^Zg=okbbconl//l00onl//l00onn]];o`[WBol:idP02ol:idP03ol:le?o5_mCo
aKoD00;oaKoD00?oaL;GolO5f?o7aMP00_o7aMP01Oo6a]_oalWKolO9foo7bM_oa<WN00CoaL_O00Co
a/gPol7<h_o1c>;o`LcR0_o1cN<4okc:i@06okW8i_nhb>Ko^<SVokS8i_nda^Oo00000oncaNL2ok73
j0;o/<?X1?n^`NP2ojg0j0;o[<3X00<0ooooo`00003oool0;`3oool003X0oooo0ol000020?ooo`oo
ZKgX0_nY_>P4ojVli`;oZ;cW1_nX^nL2ojRjiP;oYkWV1?nV^>D2ojJgi@03ojFdhonU/n?oYK?S00;o
YK?S1?nT/^82ojB`h@03oj>]g_nSZmgoXj_M00;oXj_M1?nSZm`2oj>Zf`03oj:Uf?nSYMSoXjGH00;o
XjGH1?nTYML01?nUY]OoY:?Co`000?nTXm<4ojJTd`;oZ:GD0_nXXm44ojZUdP<0oooo00?o00000?oo
o`3oool0IP3oool3o`0001`0oooo0onj[Ld3okbbc`03ol2ecoo2^M;o`[WB00?o`[WB1Oo5_m@4olO5
f004ol[8f?o7bM_oalWKolO9f`;obLcL0oo5bml3olK=h003ol7<h_o1cN?o`LgS00;o`LgS0_nlb^D0
1?nlbnKo^<SVokS8i_nhb>H2okO8i`05o`000?ncaNOo/lGWok?5iona`nP01?n``nP2ojk1j003ojg1
j?n/`>So[<3X00?o[<3X00?o00000?ooo`3oool0;P3oool003P0oooo0_l000040?ooo`ooZKgX1?nY
_>P2ojVli`;oZ;cW1_nX^nL6ojNiiP;oY[SU00?oYKGTojFdhonU]><00_nU]><4ojFch`;oY;;R00?o
XjkOoj>]g_nS[Mh00_nS[Mh4oj>[g@;oXj_L00?oXJKIoj:Uf?nRYMP00_nRYMP4oj>Uf0;oY:GG00Go
Xj;CojBSdonTXm?o0000ojBSd`03ojJTd`03ojJQd?nXXm7oZ:?A00?oZ:?A0onZYM840?ooo`03o`00
003oool0oooo06<0oooo0_l0000M0?ooo`03okNYbonj[Lgo^Zg=00?o^Zg=00Co_;;?ol2ecoo0]Loo
`;G?0oo2^M82olFldP?oaKoD0_o9`mD00oo7aMSob/SHol[8f002ol[8f003olO9foo9c=cobLcL00;o
bLcL00GoaL_OolK=h?o6cN3oa/gPolG?h@04ol7=h`03ol3=i?nlbnKo_<_V00;o_<_V00Go^<SVokO8
iongb>Oo]lSWo`000002ok?5i`;o//GX0on``nP00on_`^So[L7Xojg1j002ojg1j0;o[<3X0_n/_nP0
0`3ooooo00000?ooo`0^0?ooo`00=@3oool3o`0000@0oooo4_nY_NP2ojVlj0KoZ;cW0_nX^nL00onW
^^OoYkWVojNiiP05ojNiiP03ojJgiOnU]NCoYKGT00;oYKGT1?nU]><2ojFch`03oj>_hOnS[]ooXjkO
00;oXjkO1?nS[Mh2oj>[g@03oj6Wf_nQY]WoXJKI00;oXJKI1?nRYMP2oj>Uf003oj:Qe?nSX]?oXj;C
00;oXj;C00GoY:?Co`000?nTXm?oY:?CojJTd`03ojJQd0CoZ:?A0_nZYM800on/Y<l0oooo0?ooo`03
0?ooo`03o`00003oool0oooo05l0oooo0ol0000M0?ooo`?o]jW;1?nj[Ld00onn/<go`;G?ol2ec`03
ol2ec`03ol:id_o5_=;oaKcB00;oaKcB00GoaKoDolW3eOo9`mGobL?Eolc7eP03ol[8f0;oc<cI0oo9
c=`3ol[>g@05olK=h?o5cn7oaLoQolG?hOo1cN<01?o0cN@2okc;iP?o^/[V0_ngb>L00ol0003o//GX
ok;5j003ok;5j004ok33j?n_`^So[l;Xojo2j0Co[L7X1?n/_nP00`3ooooo00000?ooo`0]0?ooo`00
<`3oool2o`0000@0oooo5?nY_NP00onY_>OoZ;cWojRli`05ojRli`03ojRkionW^^OoYk[W00;oYk[W
0onW^NH00onV^>GoY[OUojJgi@02ojJgi@CoYKGT0_nU]><00onS/N;oXjoQoj>_h@02oj>_h@?oXjkO
0_nS[Mh2oj6Xf`CoXJOJ1?nQY]T2oj:Uf003oj6Qe?nRXMCoXZ7D00;oXZ7D1?nSX]<00ol0003oY:?C
ojBOd004ojJQd0?oZ:?A00?oZJ7>ojbTcon/Y<l00_n/Y<l40?ooo`03o`00003oool0oooo05d0oooo
0_l0000N0?ooo`03ok>TbOngZL_o]jW;00?o]jW;0_nj[Ld3okj`c@?o`;G?00?oa;W?olFld_o5_=80
0_o5_=801?o9`=;obL?EolW3eOo9`mD3olc7eP03ol[8f?o<c=Woc<cI00;oc<cI00?obLcLol[>gOo:
c]d00_o:c]d3olG?h@;oaM3R0oo0cN@2oko=i@?o^/[V00Go^L[WokK7ionfanOo0000okK7i`02ok;5
j0;o/LCX0on_`^P2ojk2j0Co[L7X0_n/_nP00on[_nP0ooooo`00000^0?ooo`00<03oool3o`0000<0
oooo5_nY_NP3ojVli`GoZ;cW0onX^nL4ojNji`04ojNii_nV^>GoY[SUojJhi@?oY[OU0_nU]N@2ojBb
h`CoXk7R0_nS[n400onQZmkoXJWMoj6Yg@02oj6Yg@CoXJSK0onQYmX2oj6Vf@;oWj7F1?nQXM@4oj:Q
e0;oXj;C00?oXYk@o`000?nTWm000_nTWm04ojJQd004ojRSdOnYXLkoZJ7>ojVQcPCo[:C?103oool0
0ol00000oooo0?ooo`1I0?ooo`?o00007`3oool3ok>Tb@Co]jW;00?o^Zg=okj`cOnn/<d00_nn/<d0
0oo0]Looa;W?olBic`02olBic`03olFld_o9`=;obL3B00;obL3B00?obL?Eolc7e_o<amH00_o<amH0
1?o>bmKoc<cIolc<fOo<c=T2olk?f`?ob/kM0_o:dMl00oo5cn7oaM3RolG@hP02olG@hP03ol3=i?no
cNGo_lgU00;o_lgU00Ko^/[VokW:ionib^Oo^L[WokK7iol00002okC6j0Co/LCX00?o[l;Xojk2j?n^
`^P00_n^`^P2ojg1j003ojc0j?n[_nSoZkoX00;oZkoX00<0ooooo`00003oool0;03oool002d0oooo
0ol000030?oooaOoZKgX0_nY_>P4ojVli`;oZ;cW1_nX^nL2ojNji`03ojNii_nV^>GoY[SU00;oY[SU
0_nV]nD2ojBdi0CoY;;S0_nS/N800onQ[MooXJ_Noj6[gP02oj6[gPCoXJWM0_nQZ=/01?nNXmSoWj;G
oinReonOX]L5oinQeP?oXJ7D0_nRXM@2oj6Ld0?oXYk@00?o0000ojBOd?nTWm000_nTWm02ojJQd003
ojNNcOnYXLkoZJ7>00;oZJ7>0on/Y<l00on]Xld0oooo0?ooo`020?ooo`03o`00003oool0oooo05H0
oooo0ol0000P0?ooo`03ojjOb?ncY<Wo/jC900;o/jC90ongZL/00onk[<_o_[3=okj`c@03okj`c@Go
a;W?1Oo9`=801?o=aM;oc<OFolc7e_o<amH3olk;eP03olc<fOo>cm_oc/oK00;oc/oK00Gob/kMol[A
goo:dMoob]7Ool[Bh003olG@hP;oa=3T0onocND01?nmcNKo^L[WokW:ionib^L2okS9i`04o`000?nd
a^So]<KXokC6j0;o/LCX0_n`a>P3ojk2j003ojk1j?n/`>So[<3X00;o[<3X1?n[_nP00ol00000oooo
0?ooo`0[0?ooo`00:`3oool2o`0000<0oooo6OnY_NP4ojVlj0;oZKcW0_nX_>L6ojRki`03ojNji_nW
^NKoYkWV00;oYkWV0_nV^>D2ojFei0CoY;CT0_nT/^<00onR[n7oXJgOoj6]g`02oj6]g`CoXJ_N0_nQ
ZMd00onNY=WoWZ?HoijSf002oijSf0?oWj;G1?nOXMH2oj6Qe003oinLdOnQW=3oXIc@00?oXIc@0onR
W]001?l0003oY9o@ojFLcOnUW<d4ojNNc@CoZJ7>00Co[:C?ojfScOn]Xlgo[J?=103oool00ol00000
oooo0?ooo`1C0?ooo`;o00008P3oool3ojjOb0Co/jC900Co]jW;ok^/bonk[<_o^jc;0onn/<d2ol:d
c@?oa;W?0_o8_Ll3olW0dP?ocLGB00?oc<OFolk;e_o>bmH00_o>bmH4olk?f`04oloBg?o:dMoob]7O
ol[Ag`?ob];P00?oaM3RolC@i?o4d>@00_o4d>@01OnocNGo_LgVokg=i_nmcNKo^L[W00Co^<WW00?o
0000okC6j?nca^P01On`a>P01?n^`^So[/7Xojk1j?n^`NP2ojc0j0;o[;oX1?n[_nP00ol00000oooo
0?ooo`0Z0?ooo`00:03oool3o`000080oooo7OnY_NP2ojVlj0;oZKcW1?nX_>L2ojRki`03ojNjionW
^^KoYk[V00;oYk[V0_nW^NH2ojJgi@CoYKGT0_nT]>@00onS/>;oXZoQoj:_h@02oj:_h@CoXJgO0_nQ
Zmh00onNY]_oWZCIoijTf@02oijTf@?oWZ?H1?nOX]L2oinQeP03oijLd_nOW=7oWicA00;oWicA1?nQ
W=02oj:Nd003oj:JcOl0003oYIc=00;oYIc=1?nWW/d2ojVQcP;oZj3<1?n]Xld50?ooo`03o`00003o
ool0oooo04l0oooo0ol0000R0?ooo`03ojVJaon^WlSo[Yo800;o[Yo80oncY<T00ongYlWo^jc;ok^/
b`03ok^/b`03okj`cOo2]<go`[C=00;o`[C=00?oa;W?olRmcoo8_Ll00_o8_Ll00oo9`=;ocLGBolg5
dP02olg5dP04om39doo>bmKoc/_Folk;eP;odLoH00?oc/oKoloBg?o?d]`00_o?d]`01Oo:dMoob];P
ol[Bh?o:d^3obM?R00Coa=3T00Co`m7Uokg=i_nmcNKo_LgV0_nlcNL3okS9i`03okK8j?l0003o/lKX
00;o/lKX0_n`a>P2ojo3j0?o[/7X00?o[L7Xojboj?n/_nP00on/_nP2oj^oj003oj^nj03ooooo0000
02/0oooo000V0?ooo`;o00000P3ooolOojVmj0;oZKcX1?nY_>L2ojRli`03ojRkionW^^OoYk[W00;o
Yk[W0_nW^^H2ojJhiPCoY[OU0_nU]N@00onS/^?oXk3Roj>`hP02oj>`hPCoXZoQ0_nQ[Ml00onOZ=go
WZKKoijVf`02oijVf`CoWZCI0onNXmP2oinRe`03oifLdonNW=;oWYcB00;oWYcB1?nOW=42oj6Ld005
oj2IcOnRV/goXY[=oj:JcOl000001?nUW<d2ojNNc@03ojRMbon[X<coZj3<00?oZj3<0_n]Xld00on`
Y</0oooo0?ooo`030?ooo`03o`00003oool0oooo04d0oooo0_l0000T0?ooo`?oZI[71?n^WlP01?nc
Y<Wo]jO9okNWbOngYlT3ok^/b`03okn`b_o2]<go`[C=00?o`[C=1Oo8_Ll01?o=`]3ocLGBolg5d_o=
aM83om39d`05olk;e_oAcmSodLoHom7?f?oBd]T00oo?d]`3oloDg@05ol[Bh?o9dn;obM?RolWCh_o4
d>@01?o3dND00onmcNKo_<gWokc=i`02okc=i`04okS9ionfb>So]/SXo`0000;o/lKX0_naaNP4ojo3
j004ojk1j?n]`NSo[L7Xojg1j0;o[;oX0_n[_nP4oj^nj003o`00003oool0oooo02T0oooo000S0?oo
o`?o00000`3ooolOojVmj0CoZKcX0_nY_>L5ojRki`;oYk[W0_nW^NH4ojJhiP;oY[OU0_nT]>@3oj>b
h`CoXk3R0_nR[n400onOZ]koWjSMoinXg@02oinXg@CoWZKK0_nNY=T01?nLW]KoW9gDoibMe?nLWM@4
oifLd`CoWYcB0_nOW=400onNV<goX9W=oj2Ic@02oj2Ic@;oXY[=00?o0000ojFLcOnUW<d00_nUW<d0
1?nWW/goZ9g;ojRMbonXWL/4oj^Pc004ojfScOn`Y<_o/:C;ok2Tb`D0oooo00?o00000?ooo`3oool0
B@3oool3o`0002@0oooo00?oY9K6ojVJaonYV/L00_nYV/L3ojjOb003ok:RaongYlWo]jO900?o]jO9
00Co^jc;okn`b_no/<[o_k3:0oo2]<d2olNic@?ob;g?0oo=`]000oo=aM;od<WCom39d`02om39d`?o
dLoH0ooBd]T00oo?d]cocmCMoloDg@02oloDg@?obM?R0_o8e><3ol?Ai@?o`M3V0_nlcNL01_njc>So
]/SXokK8j?nfb>So0000okC7j0Co/LGX0_n_`nP01?n^`^So[L7Xojg1j?n]`NP2ojc0j0CoZkoX0_n[
_^P00onZ_^P0ooooo`00000Z0?ooo`008@3oool2o`0000@0oooo8_nY_NP2ojVlj0;oZ;cW1OnX^nL2
ojNji`CoYkWV0_nV^>H2ojFfi@CoY;CT0onS/^<2oj>`hP03oj2/h?nOZ]koWj[N00;oWj[N1?nOZ=d2
oijVf`04oibPf?nLW]KoW9kFoibNePCoW9gD1?nMW=<2oijLdP03oibGc_nNV<goWYS=00;oWYS=0onP
VLd2oj:Jc@05o`000?nRV/goYIc=ojFLcOnUV/X01?nXWL/3oj^Pc003ojfPb_n`Y<_o/:C;00;o/:C;
1P3oool00ol00000oooo0?ooo`160?ooo`;o0000903oool00onOTLGoY9K6ojBFaP02ojBFaPCoZI[7
00Co[Yo8ok:RaonbX/Oo/Z;71?ngYlT5okn`bP03ol:dcOo7^LgoakW=00;oakW=00?ob;g?olg2d?o=
`]000_o=`]001?oAam3od<WCom39doo@bM<2om?>e003om7?f?oBd]Wod];I00;od];I00CodmKJoloD
gOo?e=gocmCM0_o?e]l00oo9dn;ob=CSolSDh`02olSDh`05ol?AiOo1d>Ko`M3Vol7@i_nocnL01?nj
c>P00onfb>So]<OXo`000002okC7j0;o/LGX00?o/<CXojk2j?n^`^P00_n^`^P00on]`NSo[<3Xojc0
j002ojc0j0?oZkoX1?nZ_^P00`3ooooo00000?ooo`0X0?ooo`007P3oool3o`0000@0oooo8onY_NP2
ojVlj0CoZ;cW0onX^nL4ojNji`;oYkWV0_nV]nD4ojFfi@;oY;CT00CoX[7Roj6_hOnQ[n7oXJoQ1?nP
[>03oinZgP;oWjSM0_nLX]T4oibPf0?oW9kF0onLWM@2oifLd`;oViO?0onLUlh4oijHc@CoX9W=00?o
XY[=o`000?nSUlT01?nUV/X4ojRMb`04oj^Pc?n]X<[o[J3:ojfPbPCo/:C;1@3oool00ol00000oooo
0?ooo`130?ooo`?o00008`3oool00onJSLGoWi75oinAa@02oinAa@?oY9K60onYV/L00on]W<Ko/Z;7
ok:Ra`02ok:Ra`?o]jO90_nkZ/P4okn`bPGoakW=00Coc;k=olg2d?o=`]3ocL;@0ooAam001Oo@bM?o
dlkDom?>e?oCc]Coe];F00?od];I0ooCe]X00oo?e=gocmKOoloFg`02olkGh@?ob=CS0_o6e>@00oo1
d>Ko_loWoko?i`02oko?i`;o^/cX0_nhbnP01?ndanSo0000okC7j?nca^P4ok34j0;o[/;X0_n]`NP3
ojc0j003ojboj?n[_nSoZkoX00;oZkoX1?nZ_^P00ol00000oooo0?ooo`0W0?ooo`00703oool2o`00
00@0oooo8onY_NP6ojVlj0;oZ;cW1OnX^nL2ojNji`;oY[SV1?nV]nD2ojFfi@03oj>ci?nR/N;oX[7R
00;oX[7R0onQ[n42oj2/h003oifWgOnMYM_oWJGK00;oWJGK1?nLX]T3oibPf0?oW9kF0_nLWM@00onJ
Um3oViO?oi^Gc`02oi^Gc`CoW9O>1?nNV<d2oj2Ic@03oj2EbOnSUlWo000000;oXiO91?nUV/X2ojRM
b`03ojZLb?n]X<[o[J3:00;o[J3:0on`Y</00oncYLX0oooo0?ooo`040?ooo`03o`00003oool0oooo
0400oooo0_l0000S0?ooo`04oiF:aOnJSLGoVXg5oiZ=a@CoWi751?nTU/H01?nYV/Oo[Ic6ojfLa_n]
W<H4ok:Ra`04okNWbOnkZ/So^j[8ok^Zb0?o_k3:0_o4]</3olNic@?oc;k=00GocL;@om77d?oAam3o
dLO@omC<d@03om?>e0?oe];F00?od];Iom?Ff_oCe]X00_oCe]X00ooCf=cocmKOolkGh@03olkGh@03
olSDhoo6e>Coa]CT00;oa=?V0onocnL2okc>j0Co^<_X00Co0000ok?6j?nca^So/lKX0_n`a>P2ojo3
j0Co[L7X00Co[<3Xojboj?n/_nSo[;oX0_n[_nP2oj^nj0CoZ[kX00?o00000?ooo`3oool09P3oool0
01T0oooo0ol000030?ooobGoZKgX1_nY_>P00onX_>OoZ;_WojRki`04ojRki`;oYkWV1?nV^>H2ojJg
i@03ojBei?nS/nCoXk?T00;oXk?T0onR/N82oj6_h@03oijZgonMYmgoWJOM00;oWJOM1?nMYM/3oibR
f@;oW:3H00CoVI[CoiVId_nIVM;oVIWB1?nJUm04oi^Gc`?oW9O>0_nNV<d2oifCb@?oX9G900CoXiO9
o`000?nSUlWoXiO90onUV/X00onWVLOoZYc8ojZLb002ojZLb0Co[J3:00Co/:C;ok>Ub_ncYL[o/jG:
1P3oool00ol00000oooo0?ooo`0l0?ooo`?o00008P3oool01?n@QlGoUH[5oiF:aOnER/D4oiZ=a@Co
Wi750_nTU/H00onXUlGo[Ic6ojfLaP02ojfLaP?o/Z;700?o]jG7ok^Zb?nkZ/P00onkZ/P00ono/<[o
a;C;olBdb`02olBdb`05olNicOo<_/goc;k=olbncOo@`lh00ooAam03omC<d@03om?>e?oFd]Koe];F
00;oe];F00CoemKGom?Ff_oCe][odmKJ0_oCf=`01?oCf]koc]OQolkGhOo>en42olcHhP03olKDi?o4
dnKoa=?V00;oa=?V00?o_loWokc>j?nlc^P00_nlc^P2okS;j004okK9j?l0003o/lKXok?6j0;o/LGY
1?n_`nP4ojg1j0;o[;oX0_n[_nP4oj^nj0?oZ[kX00<0ooooo`00003oool09P3oool001H0oooo0ol0
00030?ooobWoZKgX0_nY_>P5ojRli`;oZ;_W0_nW^^L4ojNiiP;oY[SV0_nU]^D3ojBei0?oXk?T0_nR
/N82oin]h@?oWZ[O1?nMYmd2oifUf`04oiVOf?nIW=KoVIcFoiVLePCoVI[C0onIVM84oiZGd0?oViO?
0_nLUlh00onKT/[oWI?9oifCb@02oifCb@CoX9G900Go0000oj>GbOnSUlWoXiO9ojFJbP02ojNIa`Go
ZYc80_n]X<X00on`X<So/jG:ok>UbP02ok>UbPH0oooo00?o00000?ooo`3oool0>@3oool3o`0001H0
oooo00CoQ8O>ohB5c?n4QLcoQ8G<0on6Q<T3ohV4b0?oS8G60on@QlD4oiF:a@?oVXg50onOTLD01?nR
T/CoZ9O5ojRGaOnXUlD5ojfLaP04ok:RaongYLOo]jG7okNUa`?o^j[800?o`Jo8olBdboo4]</00oo4
]</3olbnc@?od<?>00?odLO@omC<dOoDc=400_oDc=401?oHdM;oe];FomKBe_oFd]H3omOFe`03om?F
f_oCf=codmSL00?odm[N00?oc]OQolcHh_o<f>800_o:f>@3olCCiP03ol;Bionlc^So_<kX00;o_<kX
00Go^/gXokK9j?nfbNSo]/WXo`000005ok75j@;o[l?X00Go[/;Xojg1j?n]`NSo[L7Xojc0j005oj^o
j0;oZkkX1OnZ_^P00ol00000oooo0?ooo`0U0?ooo`00503oool2o`0000@0oooo:_nY_NP2ojVlj0Go
Z;cW0_nX^nL4ojNji`;oYkWV0_nV^>H4ojFfi@?oY;GT00?oXk?Toj6_h_nQ[n801?nO[N43oijZg`;o
WJOM00?oVZ;JoiVOf?nIWmP00_nIWmP3oiVLeP?oVI[C1?nIVM82oiZGd004oiRBc?nIT/_oVI;;oiVB
b`CoVi;:1?nMTlT3oj2Eb@04o`000?nSUlWoXiK6oj>FaPCoYiW70onZW<P00on/W<Ko/:38ok2Pb002
ok2Pb0;o/jG:00?o]ZO90?ooo`3oool01@3oool00ol00000oooo0?ooo`0f0?ooo`;o00002`3oool0
1?n>WMgoRiSKoh^Hfon;V=/3ohRCf0;oQHkD0on4R]44ohB7cP?oQ8G<0on6Q<T2ohV4b0?oS8G61?n@
QlD3oiF:a@?oVXg500CoWi75oj:Ba?nRT/CoXY;41?nXUlD3ojfLaP03ok6OaOngYLOo]jG700?o]jG7
00Co^j[8ol6_b?o1[lSo`Jo80oo4]</2olVib`03olbncOo@`lkod<?>00;od<?>00CoeLW?omC<dOoD
c=7oe<cA0ooHdM801?oFd]KoemKGomOFeooGe]L2omSJf@04om?Hg?oCf]kodm[Nom?JgP;od]cP00?o
c=SRol[Hi?o:f>@00_o:f>@01Oo4dnKo`];Wol;Bioo2d^Oo_<kX00Co^/gX00Co]/WXokC8jOl0003o
]<SY0_naaNT2ok34j@Co[/;X00Co[L7Xojc0j?n/`>So[<3X1?n[_nP7ojZnj0030?ooool00000oooo
02D0oooo000A0?ooo`?o00000`3oool/ojVmj0CoZKcX0onX_>L4ojRki`;oYk[W0_nV^NH4ojJhiP;o
YKKU00CoXkCToj:bhonR/^?oX[;S1?nQ[n82oin]h@04oibXg_nKYMcoVjGLoi^Ug0CoVZ;J0onIWmP4
oiVLeP?oVI[C0_nIVM800onFTlkoV9;<oiRBc002oiRBc0?oVI;;0onKT/X4oifCb@;oX9G90_l00003
oj>FaPCoYiW700CoZYc8ojbLa_n/W<Ko[9c61?n`X<P01?ncYL[o]ZO9okJWbOnfYlT70?ooo`03o`00
003oool0oooo0380oooo0ol000080?ooo`04oiJWh_nBXn3oTZ?Poi:Sh0?oSYgM0on;V=/3ohRCf0;o
QHkD0on4R]43ohB7cP?oQ8G<0on6Q<T3ohV4b0?oS8G60on@QlD3oiF:a@;oVXg500?oW8g3oj:Ba?nR
T/@00onRT/@3ojRGa@04ojfLa_naWlGo/Io5ok6Oa@Co]jG700?o_:W7ol6_b?o1[lP00oo1[lP01?o4
]<_obKW;olViboo9^L/5om33cP;oeLW?00?oe<cAomSAd_oHdM800_oHdM82om[Fe004omOFeooHf]Wo
f=[IomSJf@;of=gJ00Godm[Nom;Lh?oBg>3od]cPom3LhP03ol[Hi0;oamOV0_o2d^L3okoAj0;o^/gX
00Co^<_YokC8jOl0003o00000_nba^T4ok34j@;o[/;X00Co[L7Xojc0j?n/`>So[<3X1_n[_nP7ojZn
j0030?ooool00000oooo02@0oooo000@0?ooo`;o00000P3oool`ojVmj0;oZKcX1OnX_>L2ojRki`;o
Yk[W1?nV^NH2ojJhiP03ojBfiOnS]>CoXkCT00;oXkCT0onR/^<2oj6_hP03oij[h?nLZ=koW:SN00;o
W:SN0onKYM`4oiZRfP?oVIoH0_nIW=H01?nFU];oUYC?oiJDconFU<l4oiJCcP?oV9;<0onIT//4oi^B
bP;oWI?90ol000000onPTlKo0000oj>FaP03oj>FaP;oYiW700?oZIS5ojbLa_n/W<H00on/W<H2ok2P
b003ok>RaonfYlWo]ZO900?o]ZO91P3oool00ol00000oooo0?ooo`0a0?ooo`;o0000103oool00onL
[nGoVJcToiV/i002oiV/i0?oUZOR0onBXn03ohjMg@?oRiSK0on8TmP2ohF>e0?oQ8[A0on4Qlh2ohB5
c0?oQXC90on9Q<P3ohb5aP?oT8O50_nER/D00onFR<?oW8g3oib=``02oib=``CoXY;40_nXUlD00on/
VLCo/Io5ok6Oa@03ok6Oa@;o]jG70onlZLL3ol6_b004olJdbOo9^L_obKW;olVib`;ocko;0oo@`lh3
omG9c`04omW?cooHdM;of=7BomSAdP?of]KD0ooHf]T3omSMfP?od]cP0oo@g>800oo:f>CoamOVolOG
iP02olCFi`?o_m7X00?o_<oXokS;jOl000000_l000000ondb>Wo0000ok;6j@02ok;6j@;o/<CY00?o
[l?Yojg1j?n]`NP00_n]`NP00on/`>SoZkoXoj^oj004oj^oj003oj^nj?nZ_^SoZ[kX00KoZ[kX00?o
00000?ooo`3oool08`3oool00100oooo00?o0000ojVmj?nY_NP0<?nY_NP2ojVlj0GoZ;cW0_nX^nL4
ojNji`;oY[WV0_nU]nH3ojBfi@?oXkCT0_nR/^<2oin^hP?oWZ_P1?nLZ=h3oi^Ug0;oVZ;J00CoUY_F
oiJHe?nFV=CoUYSD0onFU]84oiJDc`?oUY?>1?nHT/`3oiVBb`;oVi;:0ol00002oif@aP?oX9?600Go
0000oj>Fa_nSU/KoXiK6ojNIa`03ojVHa@Co[9c600Co/:38ok>RaoncX/Oo/j;71?nfYlT70?ooo`03
o`00003oool0oooo0300oooo00Co00000?ooool00000oooo0_nO/nH2oib_i@CoVJcT0onFYn82oi:S
h0;oSYgM00CoQiKKohB@eon4T=OoQ93G0on1Rm@2ogn6d0?oOX?=0omnP<X3oh1ob0?oQXC900?oRHC8
ohMoa?n;P/<00_n;P/<3oi25``CoUXS30onLSL<4oj:Ba004ojRGaOn/VLCo[9W4ojbIa0Co/Io500?o
]jG7okbYaonlZLL00_nlZLL00oo1[lSoa[C9olJdb@02olJdb@03olViboo?_l_ocko;00;ocko;00?o
d<?>omG9cooEbLl00_oEbLl2omW?c`04omSAd_oJe]Cof]KDom[Fe0;og=[E00Cof=[IomSMf_oHgM[o
f=gJ0_oHgm`01?oBg>3od=cRom3Lh_o@g>82olkLi003olOGi_o4e^Ooa=KW00;oa=KW00Co_m7Xo`00
0?l0003o00000_nhbnT3okK9j@03o`000?nba^Wo/LGY00Co[l?Y0_n]`NP3ojc1j0?oZkoX1?n[_^P8
ojZnj003o`00003oool0oooo0280oooo000@0?ooo`03o`000?nY_NSoZKgX02ooZKgX1?nY_>P00onX
_>OoZ;_WojRki`04ojRki`;oYk[W0_nV^NH4ojFgiP;oY;KU0_nS]>@2oj6`h`CoWjkR0onNZn02oibX
gP04oiVRfonGW]WoUikIoiNNf@CoUY_F0onFV=@3oiJFdP?oUYC?1?nFTlh2oiRBc003oiJ=b?nHS/Oo
V8k700?o00000_nJSlH3oif@aPCoX9?600?o0000oj>Fa_nUU<@01?nYV<D3ojbLaP03ojnMaOncX/Oo
/j;700;o/j;70onfYlT00onjZ/T0oooo0?ooo`050?ooo`03o`00003oool0oooo0300oooo00?o0000
oj6eionQ]NL01?nO/nH2oib_i@;oVJcT00CoU:ORoi2Rh?n@X^3oT:;P0_n<W=h4ohNFf`?oQ93G0_n1
Rm@3ogn6d0?oOX?=0omnP<X2oh1ob0?oPgk60on7Ol@3oh^2``?oT8G30onFR<<4oib=``;oXY;400?o
YI?3ojbIa?n/VL@00_n/VL@3ok6Oa@03okNSaOnlZLOo_:W700?o_:W71Oo6]<T5olnob`04omC5c?oE
bLooeLW?omG9c`?ofLo?0ooJe]@3omcJe@;ogMkG00?of=gJomSOg?oHgm`00ooFh=h00oo@g>;oc]cT
olkLi002ol_Ki@;oa=KW0ol00002okc?j0;o^LgY0onfbNT00oncb>Wo/LGYo`000002ok75j@;o[l?Y
0_n^`^T3ojc1j003ojc0j?n[_nSoZkoX00;oZkoX0_n[_^P8ojZnj003ojVmj?l00000oooo02<0oooo
000@0?ooo`03o`00003oooooZKgX033oZKgX0_nY_>P00onX_>OoZ;_WojRki`04ojRki`;oYk[W1?nV
^NH2ojFgiP04ojBeiOnR/nCoX[?Toj:ci0CoXK3S0_nO[^801?nLZMooVZGMoiZUgOnJYMd4oiVRf`?o
UikI0onFVmH3oiJHe0?oUYKB0_nFU<l00onCS/_oU8g9oiB=b@02oiB=b@;oUXg80ol000000onHS/Oo
VXo6oiZ?aP02oiZ?aPCoWI360_nPTlH00onQTLCoYIC4o`000002ojFDa0CoZIS500Co[9c6ojnMaOn_
WLGo[ig51?ncX/L01?nfYlWo^Z[9okZZbOnjZ/T70?ooo`03o`00003oool0oooo02l0oooo00Co0000
oj6eionQ]NOoXKGW0_nO/nH01?nK[nGoV:_ToiR[i?nHZn@3oiBWhP?oT:;P0_n<W=h3ohNFf`?oQ93G
0on1Rm@2ogn6d0?oOX?=0omnP<X2oh1ob0?oPgk60on7Ol@3oh^2``?oT8G31?nFR<<2oib=``03oin>
`_nUTl?oYI?300;oYI?31?n/VL@01?naWlGo]j?5okNSaOngXlD3okbYa`;o`Zo71?o6]<T01?o<^/Wo
cko;olnoboo?_l/3omC5c003omG9cooIcloofLo?00;ofLo?00?og=GAom[Fe?oLf]D00_oLf]D3omgN
e`03omgQfOoHgmcoe^3N00?oe^3N00Coe>7QolkLi?o;fnGobm_U0ol00002ol7Dj0;o_];Y1?nicNT0
1_nfbNWo/lSYok?8jOncb>Wo/LGYo`0000;o[lCY1?n^`^T01?n/`NSo[<3Xojc0j?n/`>P2oj^oj003
oj^nj?nZ_^SoZ[kX00KoZ[kX1?nY_NP00ol00000oooo0?ooo`0Q0?ooo`003`3oool01?l00000oooo
0?ooo`3oool_ojVmj0;oZKcX0onX_>L2ojRki`;oYk_W1?nW^^L2ojJiiP03ojFgi_nT]NGoY;GU00;o
Y;GU0onR/n@2oj6`h`03oij/hOnLZMooW:WO00;oW:WO0onJYMd3oiVRf`?oUikI0_nFVmH01?nBU=;o
TY;@oi:Bd?nBT]03oi:?c@CoThk;0_nDSLT3o`0000;oUXg80onHS/L4oiZ?aP;oWI3600?oWHk3oj6A
a?nQTL@00_nQTL@00ol0003oYIC4ojFDa003ojVHa@03oj^Ia?n_WLGo[ig500;o[ig50oncX/L00ong
YLKo^Z[9okZZb@02okZZb@P0oooo00?o00000?ooo`3oool0;@3oool01?l00000oooo0?oooonQ]NL2
oijciP?oVjoU0onHZn@3oiBWhP?oT:;P0_n<W=h3ohNFf`?oQ93G0_n1Rm@3ogn6d0;oOX?=0omnP<X3
oh1ob0?oPgk60_n7Ol@3oh^2``CoT8G30_nFR<<00onHRL7oWhk2oin>`P02oin>`P?oYI?30on/VL@0
0on`WLCo]j?5okNSa@03okNSa@04okbYaoo2[lOo`Zo7ol:_a`?oa[C90oo<^/T00oo?_l_oe<G<omC5
c002omC5c004omW<cOoIcloofLo?omW?c`;og=GA0_oOf]801?oLf]GogMkGomgNeooMg]L2omgQf@04
omcTfooFh=koe^3NomKPgP;oe>7Q0ol000001?o;fnGoamWWolOIioo1e>P4okkBj@;o^LgY0_ngbnT2
ok?8j@;o//KY00Co0000ojo4jOn_a>Wo[lCY0_n^`^T2ojg1j0;o[<3X00?oZkoXoj^nj?n[_^P00_n[
_^P8ojZnj0?oZKgX00<0ooooo`00003oool08@3oool000l0oooo00?o00000?ooo`3oool00P3oool]
ojVmj0CoZKcX00?oZ;cWojRkionX^nL01?nW^nL2ojNji`03ojJhi_nU]nKoYKOV00;oYKOV0onT]ND2
oj:ci0;oX:oS0onN[>43oibYg`?oVZGM0_nIX]/01?nDVmSoTiSEoi>HeOnCV=D4oi:DdP?oTY;@0onB
Sld2oi>>b`?o00000_nDSLT3oiJ=b0?oV8k70_nJSlH2oiZ<``?oWHk31?nQTL@01OnUU<Co0000ojFD
a?nUU<CoZIS500?oZiW41?n_WLD01?ncX/Oo]jG6okNUa_ngYLH2okZZb@;o_jk91`3oool00ol00000
oooo0?ooo`0]0?ooo`04o`00003oool0oooo0?ooo`?oW[?V0onK[nD00onHZnCoTjKSohjQh@02ohjQ
h@?oRI_N0_n4U=/3oh2>e`?oO8SD0_mjPm03ogQnc@?oNG_90omnP<X2oh1ob0?oPgk60on7Ol@3oh^2
``;oT8G300?oTHC1oiR9`OnHRL400_nHRL43oin>`PCoYI?300Co[9W4ok2Ma?n`WLCo/9g41?ngXlD5
ol:_a`03olJdbOo<^/Woc;[900;oc;[900Cod/7:omC5c?oDaLcoe<G<0ooIc<d00ooIcloog=GAomcE
d@03omoJdP;oh=oC00?ogMkGomgQfOoMhMT00ooLi=/01?oFh=ko0000o`000?l00002om7Ph`03ol_K
iOo7fNOoamWW00;oa=OX0onnd^T01?nkcnWo]l_YokO;jOngbnT2okC9j@Co//KY00Co0000ojo4jOn^
`^Wo[/;Y0_n]`NP00on/`>SoZkoXoj^oj002oj^oj0;oZkkX2?nZ_^P00onZ_NSoZKgXojVmj002ojVm
j003o`00003oool0oooo0200oooo000?0?ooo`03o`00003oool0oooo00<0oooo;OnY_NP2ojVlj003
ojRlionX^nOoZ;_W00;oZ;_W0_nW^nL2ojJji`?oY[SV0_nU]nH00onS]>GoXK;Toj6bi002oj6bi0Co
X:oS0onN[>400onLZMooV:?MoiJOfP03oiJOfP?oU9_H0onCV=D3oi:DdP?oTY;@0_nBSld3o`0000;o
Thk;0onDSLT2oiJ=b004oiB9aOnGR/CoUh[4oiN:a0CoVXc31?nMS/<4oj6Aa003ojFDa?l0003oYiC2
00CoZiW40on_WLD00oncX<Co]jG6okNUaP02okNUaP03okZZbOno[/Wo_jk900;o_jk91`3oool00ol0
0000oooo0?ooo`0/0?ooo`03o`00003oool0oooo0080oooo00?oW[?Voi^_i_nGZn@00onGZn@2oi>V
h`?oSZ7Q0on9Vmh2ohBDf`?oP8kG0omlR=@2ogZ3d0?oN7k=0_miNlT3ogYja`;oOGW40on1N/<3ohIl
`P?oRh311?nAQ<43oiR9`@?oWhk20onUTl<00onZUl?o/9g4ok2Ma002ok2Ma0?o]j?50_nlZ<D4ol:_
a`04olReb?o<^/Woc;[9olbjb@?od/7:00?oe<G<omW<cOoIc<d00_oIc<d00ooMd/kog=GAomoJdP02
omoJdP?oh=oC00CohN?EomgQfOoLi=_og>CK0ol000001?oDhN7odN3Som7PhooAh><2olgOi@03olOI
ioo4enSoa=OX00;oa=OX00Go_];Yok_?jOnkcnWo^loYokO;j@04okC9j@;o//KY00Go/<CYojk2jOl0
003o[/;Yojg1j@04ojc0j0CoZkoX1onZ_^P4ojZmj0?oZKgX00<0ooooo`00003oool0803oool000l0
oooo00?o00000?ooo`3oool0103oool[ojVmj0;oZ;cX0onX_>L2ojRki`;oYk[W1?nV^^L00onV^>Ko
Y;KVojBfiP03oj>di@CoXK;T0_nP[n<01?nLZn7oVZOOoiZWgonJYml3oiRSg@CoUYoJ0onDVmP3oi>H
e@?oTYCB00KoTY;@o`000?l0003o0000oi:?cOn?RLT3oi28a`?oTXS61?nDRLD3oiN:a0CoVXc30onM
S/<2oj6Aa0;oXi320_nWU<800ol0003oZiW4oj^Ia003oj^Ia004ojnMaOncX<Co/j34ok>Pa0;o]jG6
00?o_:W6okn^bOno[/T00ono[/T80?ooo`03o`00003oool0oooo02/0oooo00?o00000?ooo`3oool0
0`3oool2oi^_iPCoUj_T0_nCY^<3ohjQh@?oRI_N0_n4U=/3oh2>e`;oO8SD0_mjPm03ogQnc@?oNG_9
0_mjN/L3ogeia0?oPG[30on6O<83oh^0`@?oTHC10onHRL44oin>`P04ojFC`onZUl?oZYO3ojZG``Co
/9g400Co]j?5okbXaOnlZ<Go_:S50oo2[lL3olReb003olbjbOoB`L[od/7:00;od/7:00CoelS;omW<
cOoIc<gofLc=0_oMd/h2on3Ic`03omoJd_oPgm?oh=oC00;oh=oC00CohN?Eo`000?l0003o00000_oJ
iMd3omOUh003om7Phoo=gnGocMoU00?ob]gW0_o4enP2ol3Dj@;o^loY0onhcNX2okC9j@03ok;7jOn`
a>Wo/<CY00;o/<CY00Co[/;Yo`000?n]`NWo[L7Y0_n/`>P6oj^oj0OoZ[kX0_nZ_NP5ojVmj0030?oo
ool00000oooo01l0oooo000?0?ooo`03o`00003oool0oooo00D0oooo:OnY_NP4ojRlj003ojRlionX
^nOoZ;_W00CoYk[W0_nV^^L00onU^>KoY;KVojBfiP02ojBfiP?oXkCU0_nQ/^@00onN[^?oW:_Qoib[
h@02oib[h@?oVZOO0onHXmd2oiJOfP04oi:Ieon@U=CoT9CDoi2De0?oSi7A0_n>S/h2o`0000;oSX_<
1?n?RLT3oi28a`?oTXS60onDRLD3oiN:a0CoVXc30_nMS/<00onNSL7oXi32oj>@`P02oj>@`P;oYiC2
00?o0000ojND`_n[VL@00_n[VL@00on_Vl?o/j34ok>Pa002ok>Pa004okNUa_nlZLKo_:W6okbYaP?o
_jk90_o5/lT70?ooo`03o`00003oool0oooo02/0oooo00?o00000?ooo`3oool0103oool2oi^_iP;o
Uj_T00?oTZKSohfQhOn=XN400on7V]l3oh:Cf`;oO8cH0omhQM@2ogAod0?oLW[<0omhO/d2ogUkb@?o
NW[70_mmNL@3oh5j``?oQWc20on;P<43oi64`@CoV8W10_nOS/800onST<;oZYO3ojZG``02ojZG``?o
/9g400?o]Z;4okbXaOnlZ<D00onlZ<D00oo2[lOob;G8olReb002olReb0God/7:0_oGb</01?oIc<go
gM;>omgBc_oMd/h2on3Ic`04on?Nd?oPgm?oh=oCon3Od`;o00000_oQi]L00ooOj=Wof^GMomOUh002
omOUh0;oe>CS00GocMoUol[Mioo:gNOob]gWolKJj003ol3Dj@;o_M7Z0onhcNX00onfbn[o//OYok;7
j@02ok;7j@;o/<CY0_n_`nT01?l0003o[L7Yojc1jOn/`NT6oj^oj0SoZ[kX2?nY_NP00ol00000oooo
0?ooo`0N0?ooo`003`3oool00ol00000oooo0?ooo`060?ooobWoZKgX0_nX_>P00onX_>OoZ;_WojRk
i`02ojRki`;oYk[W0_nV^NL3ojFhiP;oY;KV0_nR]>D3oj6ai0?oWZkS0onLZn42oiZWg`04oiJRg?nD
WM[oU9gJoiBMfPCoTYWG0on@U=@01?n?TM7o0000o`000?l00002ohj>cP?oSX_<0on?RLT3oi28a`?o
TXS60onDRLD4oiN:a0;oVXc300?oVX[1oij=`OnNSL400_nNSL44oj>@`P;oYiC200?o0000oj^Ia?n_
Vl<00_n_Vl<4ok>Pa0Go_:W600Co_jk9olFcbOo5/lWoaK?9203oool00ol00000oooo0?ooo`0Z0?oo
o`03o`00003oool0oooo00@0oooo0onG[>D3oi:Vh`;oSJ7Q0on7V]l3oh:Cf`;oO8cH0omhQM@2ogAo
d0;oLW[<0ombMlP3og=eaP;oNW[70_mmNL@3oh5j``?oQWc20on;P<44oi64`@;oV8W100?oVh[1oj>@
`_nST<800_nST<84ojZG``04ok2Ma?nfX/Co]Z;4okJRa0?o_:S500?o`jo6olReb?o8]LP00oo8]LP0
1?o>_<Sod/7:om;1b_oB`LX3omO8b`?ogM;>0ooPfLl01OoSg]3o0000o`000?l0003ohN?E00;ohNKG
0_oOj=T2omgYg003omOUh?oDi>?oe>CS00?od>?U00Gob]gWolKJj?o6f^Soa][Xol3Dj@04okgAjP04
okS=j_nfbn[o]/_ZokK;jP;o//OY00Co/<GYojo3jOn_`nWo[l?Y0_n]`^T01?l0003o[<7Yojc1jOn/
`NT3oj^oj0_oZ[kX2?nY_NP00ol00000oooo0?ooo`0M0?ooo`003P3oool00ol00000oooo0?ooo`08
0?ooobOoZKgX0_nX_>P3ojRli`;oZ;_W0_nW^^L4ojJii`03ojFhi_nT]^KoY;KV00CoX[CU0onQ/N@0
0onN[^?oVj[QoiVVg`03oiVVg`?oUZ;L0onDWMX3oi:Ie`04oi2De?l0003o0000o`0000;oSi7A0on>
S/h4ohj;c0?oShW90on@R<L3oi:8aP?oU8W50_nGR/@00onGQl7oVX[1oiZ:`@02oiZ:`@?oWXg11?nS
T<82ojND`P03ojZF`Ol0003o[i_300?o[i_30_ncX<@2okRSa0Co_:W61?o5/lT90?ooo`03o`00003o
ool0oooo02P0oooo00?o00000?ooo`3oool01P3oool3oiN/i@?oTZKS0_n=XN43ohNJg`;oPY?K0oml
S=P2ogR5e0;oM7o@0ombN/`3og9gb0;oLgG60_mfM<<3ogYe`P?oPG[30on6O<83oh^0`@;oTHC100?o
U8C0oi^:`OnKR/400_nKR/43oj>@`P?oZYO300?o[i_3okJRa?nfX/@00onfX/@01?nlZ<Go`jo6ol>_
a_o3[lH3olReb0?oc[c800Cod/7:omO8booGb<_oelS;0_oLd<`00ooMd/koh=W?on3Ic`03o`000003
on?Nd?oTi=7ohN?E00;ohNKG0_oOj=T3omgYg003om[YgooDi>?od>?U00;od>?U0_o<h>L2olKJj0?o
`]OY0_nmdNX2okW?jP;o]/_Z00?o/lSZok35jOn`aNT00_n`aNT00on_`nWo[L;Yojg2j@02ojg2j@03
o`000?n/`NWo[<3X00CoZkoX2OnZ_^P:ojVmj003o`00003oool0oooo01`0oooo000>0?ooo`03o`00
003oool0oooo00T0oooo8onY_NP2ojVlj0CoZ;cX00?oZ;cWojRkionX^nL01?nW^^L2ojJii`03ojFh
i_nT]^KoY;KV00;oY;KV0_nR]>D01?nP/NCoWJkSoif^honM[^<3oi^Zh@CoVJKO0onFX]`3oiBMfP?o
00000on@U=@3ohnAd@?oSXk>0_n>Rl`01?n:QLSoS8C6ohb4a_n<Q<H3ohj4a0?oT8C20onCQL84oiN7
`@?oVX[10onNSL43oj>@`P03ojFA`?nZU/7oZYK100;oZYK100Go0000ojnK`on_Vl?o[i_3ok>Pa003
okRSa0?o_:W60_o1[/L2olFcb@;obk[:203oool00ol00000oooo0?ooo`0X0?ooo`03o`00003oool0
oooo00H0oooo0_nG[>D01?nAYnCoS:7RohbQh_n<XN82ohFJg`?oOi;L0_miRmP3og>3e0?oKgc@0_md
Om02og9jc0?oLWO80_mcMLH3ogId``;oNWG20omoMl43ohEk`0?oS7o01?nDQ<03oi^:`@CoXi3200Co
ZYO3ojnK`on_Vl?o[i_31?nfX/@5ol>_aP03olReb?o>_<Soc[c800;oc[c80ooGb</3omc@c0?o0000
0ooSg]02onCTd@;oiNSC00?oi>_EomoXfOoMjM`00_oMjM`2om[Yg`;oe^SR00?od>?UolcPioo<h>L0
0_o7gNT3ol;Gj@05okkDj_nicn[o^LoZokW?j_nfc>X01?ncb>X2ok35j@?o[lCY0_n]`^T00on/`NWo
[<3Xo`000002ojc0j0;oZkoX00?oZkkXojZnj?nZ_^P01_nZ_^P;ojVmj003o`00003oool0oooo01`0
oooo000>0?ooo`03o`00003oool0oooo00/0oooo8?nY_NP4ojVlj0?oZ;cX1?nX^nL2ojNji`03ojJi
ionU^>KoYKSV00;oYKSV0_nT]^H2oj:di@?oX;7T0onM[^<3oi^Zh@;oVJKO00CoU:3Loi6Kf_nAVm[o
TI_J0ol00003ohfBd`?oRhg@0on:R/d3ohZ7bP?oRXG80on<Q<H3ohj4a0?oT8C21?nCQL83oiN7`@?o
VX[11?nNSL401?nST<;oYI70ojFA`?nUTL03ojZF`@04o`000?n_Vl?o[i_3ok>N`PGo^:?400Go_:W6
ol6^aoo1[/Oo`Jk7olFcb@04ol^jbPP0oooo00?o00000?ooo`3oool09`3oool00ol00000oooo0?oo
o`070?ooo`?oTJOT0on<XN82ohFJg`?oOi;L0_miRmP3og>3e0;oKgc@0_m/Ml`3of]bb0;oLWO80omc
MLH2ogId``?oNWG20omoMl43ohEk`0?oS7o00onDQ<04oi^:`@;oXi3200?oYiC2ojnK`on_Vl<00_n_
Vl<3okJRa0;o_:S51?o3[lH01?o9]/Ooc[c8oljlb?o>_<P2omC4b@03omO8booLd<co000000;o0000
0_oQeld2onCMcP03on?Nd?oTi=7oi>CA00?oiNSC00Coi>_Eon;]f?oRkMSogNWL0ooJjMl2omKXhP03
om;ViOo<h>OoamgY00?oamgY00Go`]OYokkDj_nne>[o_]CZokW?jP03okK<jP;o/lSZ0onaa^T2ojo4
j@03ojk2jOn/`NWo[<7Y00;o[<7Y00?o0000ojc0j?n[_nP01?n[_^P8ojZnj0_oZKgX00?o00000?oo
o`3oool06`3oool000h0oooo00?o00000?ooo`3oool0303ooolPojVmj0;oZKcX1OnX_>P2ojRki`;o
Yk[W0onV^NL2ojFhiP;oXkKV1?nR]>D2oj2ai0;oWJkS00?oVZWQoiNUgonGYMl00_nGYMl2oiBPg0?o
000000CoTI_JohnFeon?U]OoSiKG0on=T]<3oh^=d0?oRX[=0_n:QlX4ohZ5b0?oS8C60on>Q<@3oi24
`P?oThG20onGQl44oiZ:`@;oWXg100?oX8foojFA`?nUTL000_nUTL04ojZF`@04o`000?ncW/;o/ik2
ok>N`P?o^:?400?o_JS5ol6^aoo1[/L00_o1[/L5ol^jbPT0oooo00?o00000?ooo`3oool09P3oool0
0ol00000oooo0?ooo`080?ooo`?oTJOT0_n<XN83ohFJg`?oOi;L0_miRmP2og>3e0;oKgc@0om/Ml`2
of]bb0?oK7350_mcMLH2ogId``?oNWG20omoMl43ohEk`0?oS7o00onDQ<03oi^:`@03oin=`OnWU<;o
YiC200;oYiC21?n_Vl<01?nfX/Co_:S5okbXaOnlZ<D3ol>_aP?obKK700?oc[c8omC4bOoDa<T00ol0
00000ooLd<cohMO=on7Gc@02on7Gc@;oi=g>00?oin?>onCTdOoUj=<00_oUj=<01?oTjmGoh^gHon;]
f?oRkMP2omo^f`03om[YgooFj>;oe^SR00;od^KU00Coc^CWolOMjOo7gNWoamgY0_o3fNX2okkDjP?o
^]3[00?o]/cZokC9j_ndbNX00onaa^T00on_a>Wo[/;Yojk2j@02ojk2j@;o[<7Y00?o[<3Xoj^oj?l0
00000_n[_nP2oj^nj0SoZ[kX3?nY_NP00`3ooooo00000?ooo`0K0?ooo`003P3oool00ol00000oooo
0?ooo`0=0?oooakoZKgX0_nY_>P5ojRlj0;oYk_W1?nW^^L00onV^NOoYKSVojFhiP04oj>fiP;oX[CU
00CoWk7Toib]honL[N?oW:gS0onJZN42oiNUg`?o00000_nDX=`2oi6KfP?oSiKG0on=T]<3oh^=d0?o
RX[=0on:QlX3ohZ5b0?oS8C60on>Q<@3oi24`PCoThG20onGQl42oiZ:`@03oib9_onPSKooX8fo00;o
X8fo0onUTL03ojZF`@03ojjH`OncW/;o000000?o/ik200Co^:?4okfXaOnmZ<Go_JS50_o1[/L2olNd
b0?obk[:0_oA`/`80?ooo`03o`00003oool0oooo02H0oooo00?o00000?ooo`3oool02@3oool3oh^Q
h`;oQ9[Q0_mmT]d3ogJ:f@;oL8;E0omZN]42ofmld0;oK7O<0om[L/P2ofa`a@;oKVo30omfM<<2ogYe
`P?oOgO10on5Nl04ohao`0?oU8C000?oVh[1oin=`OnOSL401?nWU<83ojnK``03okFQa?nlZ<Go_:S5
00?o_:S500?o`jo6olVfaoo9]/L00_o9]/L3o`0000?oflc:00Coh=C;on7GcOoQelgohMO=0ooTgLh0
1OoWhlkoj>S?onSXcooUj=?oi>_E00?oh^gH0ooOk]/00ooLk]koe^SRom;Vi@02om;Vi@;oc^CW00?o
amgYol?Ij_o3fNX00_noe^/3ok[@j`03okO=jondbN[o]<WZ00;o]<WZ00Co/LKYojo4jOn_a>Wo[lCY
0_n^`^T00on]`NWo[<3Xojc0j002ojc0j003oj^oj?l0003oZkoX00;oZkoX1onZ_^P>ojVmj003o`00
003oool0oooo01X0oooo000>0?ooo`03o`00003oool0oooo00h0oooo7OnY_NP3ojVlj0CoZ;cX0onW
^nL2ojNji`03ojJiionU^>KoYKSV00;oYKSV0_nS]^H2oj6ci@?oWk7T0onL[N<01_nJZN7o0000o`00
0?l0003oUjGOoi:Og@?oSi[J0_n<U=L3ohV?d`?oQh_@0on6Q/`3ohF3b@?oQX770on:QLP3ohb4aP?o
SXC40on@Q<82oi>5`P;oTh>o0onGQ[l3oib9_`CoX8fo1?nUTL001OnZU/7o[YS1ojjH`On^V<7o0000
00?o/ik21?nmZ<D00oo1[/OoakC8olNdb002olNdb004ol^jb_oA`/codL;<om72c0T0oooo00?o0000
0?ooo`3oool09@3oool00ol00000oooo0?ooo`0:0?ooo`?oRj7S0_n4V^42ogfBg@?oMX[I0_m`P]D2
ofYjd@;oIW?<0_m/Ml`3of]bb0;oK7350_m^Kl<3og9``@?oN7;00omoMl43ohEk`0;oS7o000CoSX2o
oiN6`?nGQ/3oUhK01?nOSL44ojND`P04ojnK`oneXLCo]J74okFQa0?o_:S500?oa:o6olVfaoo9]/L0
0ol000000oo@_/Soe<C9om_<bP03om_<bP;oh=C;00CohMO=onCMc_oTgLkoi=g>0_oWhlh2onSXc`04
onO]dOoVl=?oi_3Con;]f0?ognkK00Gog>kNomS]hOoHkN7of>gQom;Vi@02olkTi`;obN3Y00?o`mWZ
okoFjonoe^/00_noe^/01?njd>_o]lg[okO=jongcN/2okC9jP;o/LOZ0_n_a>T00on^`nWo[L7Yojg1
j@02ojg1j@;o[<3X0_n[_nP00ol0003oZkoXoj^oj007ojZnj0ooZKgX00<0ooooo`00003oool06P3o
ool000d0oooo00?o00000?ooo`3oool0403ooolKojVmj0;oZKcX1OnX_>P2ojNki`CoYk[W0_nV^NL2
ojFhiP;oXkKV1?nQ/nD2oinai004oib]hol0003o0000o`0000?oUZCO0onBWmd3ohnJfP;oS9CG0on9
Sm<3ohN;d0?oQXK<0on5PlT2ohJ1a`?oQgo40on9Ol83ohao`@?oSh701?nCPkl3oiN6_`CoW8Vo1?nP
SKl2ojFA`003ojRC_on^V<7o[YS100;o[YS100Co/ik2o`000?ncW/;o^:;31?nmZ<D5olNdb0?odL;<
0_oGb/d80?ooo`03o`00003oool0oooo02@0oooo00?o00000?ooo`3oool02`3oool3ohBKhP;oO9?N
0omdR]/2ogJ:f@;oL8;E0_mZN]42ofIcc0?oI6o80om[L/P2ofa`a@;oKVo30ombL<42ogQb`0?oOgJo
0on6Nkl3ohj0_`?oUhK01?nOSL43ojND`P03ojfI`oneXLCo]J7400;o]J7400?o_:S5olB_a_o4[lH0
0ol000001Oo9]/Ood;k8om2nb?o@_/Sof<O900?oflc:0ooPe</2onGKc003onCMc_oWhlkoin?>00;o
j>S?0_oWkM42onK`d`;oi?7F00?ognkKomc^g_oHkN400_oHkN42omCZi@03olkTioo9h>WobN3Y00?o
a=c[0_noe^/2ok_Bj`;o]lg[0_ndb^/2ok77jP;o/<GY0on^`nT2ojg1j@?o[<3Y0on[_nP00ol0003o
Z[kXojZnj004ojZnj1;oZKgX00?o00000?ooo`3oool06@3oool000d0oooo00?o00000?ooo`3oool0
403ooolJojVmj0CoZKcX0onX_>P4ojNki`;oYk[W00CoY[WWojBhionT^>OoY;SW1?nS]^H2oj6ci@04
oij`i?nL[N?o0000o`0000CoVJWQ0onFY=l2oi:Og@?oSi[J0on<U=L3ohV?d`;oQh_@0on6Q/`3ohF3
b@?oQX770on7Ol@3ohUo`P?oS7o10on?PL04oi>3_`?oUhJo0onLRKl2oj2=_`;oXhjn0onXTkl5ojjH
`@04ok>N`_l0003o^:;3okRR``;o_JS50_o3[lH3olNdb0;oc[c900GodL;<omO:cOoGb/goel[=omgC
cP080?ooo`03o`00003oool0oooo02<0oooo00?o00000?ooo`3oool0303oool3ohBKhP;oO9?N0_md
R]/2ofb1eP?oIGWB0_mZN]42ofIcc0;oI6o80omTJlD2ofIZ`P;oKVo30ombL<43ogQb`0;oOgJo0on6
Nkl4ohj0_`?oUhK00onOSL401?nWU<;o[IW3ojfI`on]VL<4okFQa003olB_a_l0003o000000;oa:o6
00?obKK7om2nb?o@_/P00_o@_/P2omS7b@03om_<b_oPe<_oh=C;00;oh=C;0_oUfl`01?oXh/coin?>
onSXcooXj<l2onO]d@;oi_3C0ooTlMH01?oQl]WogO;MomgbgOoHkN42omCZi@;ocnOW00CobN3YolCL
joo4g>_oa=c[0_o0en/2ok_Bj`04okS>jondb^_o]<[[okC:j`;o//OZ1?n`aNT01?n^`nWo[L7Yojg1
jOn]`NT2ojc0j@GoZkoX00?o0000ojZnj?nZ_^P01?nZ_^PBojVmj003o`00003oool0oooo01P0oooo
000=0?ooo`03o`00003oool0oooo0140oooo6_nY_NP2ojVlj0GoZ;cX0_nW^nL2ojNji`?oY[WW0onT
^>L2oj>fiP03oj6ciOnN/>Co000000;o00000onL[N<2oiVYh@04oiBTgon@W]goT9kMoi2Ng@;oS9SJ
0on9TmL3ohJ=d`?oPhS@0on2Pl`3ohJ6c0?oQH?90_n6PLL3ohMoa0?oRGo20on<Ol43ohn1`0CoTh>o
0onGQ[l2oib9_`03oif9__nSS[koXhjn00;oXhjn1?nXTkl3ojjH`@06ok:L`OnhX/?o^:;3o`000?nh
X/?o_JS51?o3[lH01?o7]<Soc[c9oljlbOo>_<T3omO:c@?ogM?>203oool00ol00000oooo0?ooo`0R
0?ooo`03o`00003oool0oooo00d0oooo0on4Vn82ogbCgP;oM8[K0_m/PMH2ofEidP;oH77=0_mVLl`3
ofA_b0;oI6_50_mVJ/83ofY[`0;oLW310omhL/03ogmf_`?oQW^o0on>P;l3oiN6`0;oWhg100?oY9;2
ojfI`on]VL<00on]VL<01?neXLCo0000o`000?l00004olB_aP04ol^haoo@_/Sod;k8om2nb0?of<O9
00Cog]3:on3DbooPe<_oh=C;0_oUfl`2onSRc0;oj^S=00Coj^k=onO]dOoVl=?oi_3C0ooTlMH01_oQ
l]WogO;MomgbgOoMl]gofO3QomCZi@?ocnOW0_o:hnT00oo4g>_o`=O[ol3Gj`02okcCk0?o^<k[00?o
]<[[ok;7j_nbanX00_nbanX2ok35j@05ojk3jOn]`NWo[L7Yojg1jOn/`>T01_n[_nP2ojZnj003o`00
0?nZ_^SoZ[kX00?oZ[kX4onY_NP00ol00000oooo0?ooo`0G0?ooo`003@3oool00ol00000oooo0?oo
o`0B0?oooa[oZKgX1OnX_>P2ojNki`CoYk[W00?oY[WWojBhionT^>L00onS]^H3o`0000;oW[3T00?o
VjgSoiRXh_nHZ>800_nHZ>83oiBTg`?oT9kM0_n<V=X3ohVCe`?oQXgC0_n3R=03oh:3c0?oPH390on1
OLH3oh9l``?oQgo40on9Ol83ohao`@?oSh700onCPkl2oiN6_`03oiR5_OnMRKkoWHVn00;oWHVn1?nS
S[h3ojRC_`03ojjH`OnbW<7o/Yc100;o/Yc100?o^:;3o`000?nnZ<@01Oo3[lH4oljlb@03omG5booG
b/gogM?>00?ogM?>00?oh]c@0?ooo`3oool01@3oool00ol00000oooo0?ooo`0R0?ooo`03o`00003o
ool0oooo00d0oooo0omkU>02og:;g0?oJH7H00GoK87FofEid_mUNM;oIGWBof1ac@03oee[b0;oI6o8
0omTJlD2ofIZ`P;oJV_00om`KKl2ogQb`0?oOgJo0on6Nkl3ohj0_`;oUhK000?oVh[1ojBB`_nTT/80
0_nTT/82ojfI``?o00000onlZ<D3olB_aP?obkS700?od;k8omS7bOoHalT00_oHalT2omk@bP03on3D
booUflcoiM_<00?oj>;<0_oZj<d00ooZk/gojO7?onWac`02onOdd003onCae_oQl]WogO;M00;ogO;M
00GofO3QomG]iOoEkNGoeNgUoloWi`02ol[Sj@;oaMk[00?o`=O[okcCk?nldn`00_nldn`01?nhc^_o
]<_[okC;jondbn/2ok;7jP03ok35j_n^`nWo[/?Y00;o[/?Y00Co[L7Yojc0jOn/`>Wo[<3Y0on[_nP4
ojZnj003o`000?nZ_^SoZ[kX00CoZ[kX4_nY_NP00ol00000oooo0?ooo`0G0?ooo`003@3oool00ol0
0000oooo0?ooo`0C0?oooa[oZKgX0onX_>P4ojNki`;oYk[W00CoY[WWojBhionT^>OoY;SW0ol00000
1?nS]^KoXK?UoijaiOnN/ND3oi^]h`CoV:SR0_nDY=l3oi2Ng@?oS9SJ0on9TmL2ohJ=d`?oPhS@0_n2
Pl`3oh60b@?oPGg60on2O<<3ohAk`@?oQg^o0on:OKh3ohmo_P?oTh:m1?nHQKd3oif9_PCoXhjn0_nX
Tkl00on]Ul3o/Yc1ok:L`@03ok:L`@04okRR`onnZ<Co0000okjXa0?o`jo60_o:]/L2oljlb@;oeLG;
00Cog<o<omgCc_oMdlkogM?>0_oRg=000ooViM00oooo0?ooo`050?ooo`03o`00003oool0oooo0240
oooo00?o00000?ooo`3oool03P3oool3og^Dh0;oLX_L0_mYPMP2of5hd`;oIGWB0_mPLLd2oee[b0?o
G6O50_mTJlD2ofIZ`P?oJV_00_m`KKl3ogMa_`;oOgJo0on6Nkl2ohj0_`03oi:3`?nKR/7oVh[100;o
Vh[10_nTT/83o`000003ojfI`ondX<Co_:S500Co_:S500?oa:o6ol^haoo;^<L00_o;^<L01?oC`LWo
f<O9omS7bOoHalT3omk@bP03onCIbooUflcoj>;<00;oj>;<0_oZj<d2on[^c@;ojO7?0_oWm=001OoU
m]?oh_KGon;feooMl]gofO3Q00?oeNgU00?od>WXol_Uj_o5g^/00_o5g^/3ol3Ik0;o_=?/0_nhcn/2
okC;j`03ok;8j_n`aN[o/<GZ00;o/<GZ0_n^`nT2ojg2j@;o[<3Y1On[_nP4ojZnj003o`000?nZ_^So
Z[kX00;oZ[kX5?nY_NP00ol00000oooo0?ooo`0F0?ooo`003@3oool00ol00000oooo0?ooo`0E0?oo
oaOoZKgX1OnX_>P2ojNki`;oYk[W0_nV^NL3o`0000;oXkKV0_nQ/nH4oijai@?oVjgS0_nHZ>800onC
Y>3oSikNohnNgP03ohZHf`?oQY7G0on2Rm<3ogn6d0;oPhS@0on2Pl`3oh60b@?oPGg60_n2O<<3ohAk
`@?oQg^o1?n:OKh3ohmo_P?oTh:m0onHQKd3oif9_P?oXhjn00?oYi6nojfG`?n]Ul000_n]Ul04ok:L
`@?o_ZS400?o0000okjXa?o3[lH00oo:]/L01?o>_<WoeLG;omG5booEaL/2omc?c003omgCc_oRg=3o
h]c@00;oi^G@00?oincA0?ooo`3oool01@3oool00ol00000oooo0?ooo`0P0?ooo`03o`00003oool0
oooo00l0oooo0_mkU>02og:;g0?oJH7H00GoHGSCoe]_c_mKKlkoFfo>of1ac@03oee[b0;oG6O50_mN
IL82ofIZ`P?oJV_00_m`KKl3ogMa_`;oOgJo0on8O;l4oi:3`0;oVh[10ol00002ojBB`P04ojfI`ond
X<Co]:34okBPa0Co_:S500Coa;77ol^haoo;^<OobkS70ooC`LT00ooHalWog]3:omk@bP02omk@bP04
onCIbooXhL_oj>7;onSRc0;oj^S=0_oZk/d2onWac`;oioC@00?oiOKCon;feooRm]L00_oNm]`2om[c
h003omG]iOo@jNSobnGZ00;obnGZ00GoaMk[ol3Ik?o0fNco`=W/okcDk003okS?j`03okG<jonbb>[o
//SZ00;o//SZ0_n`aNX2ojk3j@;o[L;Y00?o[<7Yoj^oj?n[_nP01?n[_nP6ojZnj004o`000?nZ_^So
Z[kXojZnj1GoZKgX00?o00000?ooo`3oool05@3oool000`0oooo00?o00000?ooo`3oool05`3ooolE
ojVmj0GoZ;cX0_nW^nP2ojNji`?o00000_nT^>L4oj>fiP;oXK?V0_nN/ND2oi^]i0;oUjWR1?nCY>02
ohnNgP?oRYSK0on6TML2oh:;d`?oOhK@0_mmPL`3ogamb@?oPH390on1OLH3oh9l``?oQ7_10on7Nkl3
ohYm_P?oSgnn0onCP[d3oiR5_@CoWHVn00CoXhjnojNA__nWTKkoYi6n0on]Ul03ok:L`@;o^:;20onn
Z<@00ol0003ob[K7olZfa`02olZfa`?oeLG;0ooLcl`00ooRfLgoh]c@onKUd002onKUd003onO/dOoW
l]40oooo00D0oooo00?o00000?ooo`3oool07`3oool00ol00000oooo0?ooo`0A0?ooo`04og6=g_mW
P][oIh;JofN2fP;oJH7H0_mQN=<2oe]_cP;oEVS90_mMJlP2oeaWa@;oGVG20omQIL02ofY[`0?oL6fo
0_mgLKl3ogmf_`?oR7bo0_nBPl03o`000005oi^:`OnTT/;oY9;2ojBB`_n[V<<01?ndX<@3okbXa@?o
a;7700?obkS7om?1bOoC`LT00_oC`LT01?oJbl[og]3:omk@b_oNd<X2onCIb`;oj>7;0_o[j</2onc^
b`05on[^cOoYlLooioC@onOdd?oUm]<00_oRm]L2omkfg0;of_?P0_oEl>D2om3/j005ol_Uj_o5gnco
aMo/olGOk?o0fN`00onle>`01?nhcn_o]Lc[okG<jonec>/2ok;8jP;o/<KZ0_n^`nT2ojg2j@?o[<7Y
1?n[_nP8ojZnj003o`000?nZ_^SoZKgX01GoZKgX00?o00000?ooo`3oool05@3oool000`0oooo00?o
00000?ooo`3oool0603ooolEojVmj0CoZ;cX00KoYk_Xo`000?l0003o0000ojNjionV^NL4ojBhi`;o
XkKV00CoXKCVoijaiOnN/NGoW[7U1?nK[N@2oiNYhP?oTjCP0on?W]h3ohZHf`;oQY7G0on2Rm<3ogn6
d0;oOH7<0_mlOLT3ogaja@?oOGS30on2O<<3ohAk`@?oQg^o0on:OKh3ohmo_P?oTh:m1?nHQKd2oif9
_P03oj6;__nWTKkoYi6n00;oYi6n1?n]Ul001?nbW<7o^:;2okRR`_nhX/83okjXa004o`000?o5/<Go
b[K7olZfa`;odKo900?oeLG;omc?c?oLcl`00_oLcl`01OoRfLgoi^G@onKUd?oViM3oincA00;oio;A
00?oiOOBon;id`3oool0103oool00ol00000oooo0?ooo`0N0?ooo`03o`00003oool0oooo0180oooo
00?oLHgNofN2f_mWP]X00_mNN=D3oeI^d003oe]_c_mFJ<WoEVS900?oE6?50_mLIlD2oeiU`P;oHFG0
0omWIkl2og1]_`?oMg6o0_moM[l2ohQl_`?o000000?oTX?0oi^:`OnKR/400_nKR/401?nTT/;oZiS3
oj^H`on[V<<4okBPa003okbXaOo4/LOoa;7700;oa;771OoC`LT2om[;bP03omk@b_oTfL_oi=W;00?o
j>7;0_o[j</2onc^b`04oncbbooZm/coj_K<onOhcP;oi?WA00CohO[Eomkfg?oJln3of_?P0_oEl>D2
om3/j0;obnO[0_o5gn`2ol3Jk0;o_=C/0_nhd>`2okG<j`?o//S[00?o/<KZojk4jOn^a>T01?n]`^T0
0on/`NWoZl3Yoj_0j@04oj^oj0OoZ[kX00?o0000ojVmj?nY_NP05_nY_NP00ol00000oooo0?ooo`0D
0?ooo`00303oool00ol00000oooo0?ooo`0I0?oooa;oZKgX1?nX_>P3o`0000CoYk_W0_nV^NL2ojBh
i`;oXkKW0onQ]>H3oijai@;oVjgT00CoUjWSoi:ThOnBY>7oTZCQ0on>W]l2ohVHg0?oQ97H0_moR]@3
ogb4d0?oOhK@0_mmPL`3ogamb@?oO7[50_mmN<<3ogmg`@?oPWNo0on7Nkl4ohYm_P?oSgnn0onCP[d2
oiR5_@03oiZ6_OnQRkkoXH^n00;oXH^n0onWTKh3ojfG`003ok:K`OnhX/;o^:;200?o^:;200Go_ZS4
olF`aOo5/<Go0000olZfa`03om6ob@04omW:booLclcog<o<omc?c0;oh]W=00?oin?>onKUd?oWk=40
0_oWl]42onGgdP03on;idooOnmL0oooo00@0oooo00?o00000?ooo`3oool07@3oool00ol00000oooo
0?ooo`0B0?ooo`;oIXCL0_mWP]X2oeihe@;oEVk@00CoCfK;oe]_c_mFJ<WoEVS90_mDHlD2oeAQ`P;o
GVG20omQIL02ofMW_`;oKfbn0omgLKl01OmoM[oo0000o`000?l0003oR7bo00CoTX?00_nKR/400onQ
T<;oZiS3oj^H``02oj^H``?o]:3400?o_:W6olBaaoo4/LL00oo4/LL01?o=^/Sodl79om?1bOoC`LT3
om[;bP03on7EbooTfL_oj>7;00;oj>7;0_o[j</3onc^b`04oncbbooZm/coj_K<onOhcP;oi?WA00Go
hO[EomgifooMnM_ofOKPomG`i@02om3/j0;obnO[0_o5hN`2ol3Jk0?o_=G/00Co^=3/okG<jonec>_o
]Lc[0_nbb>/00on`a^[o[/CYojk4j@02ojk4j@;o[L;Y0_n/`NT3oj_0j@;oZkoX2OnZ_^P00ol0003o
ZKgXojVmj00FojVmj003o`00003oool0oooo01<0oooo000<0?ooo`03o`00003oool0oooo01X0oooo
4_nY_NP00onX_>So0000o`000004ojNkj0;oYk_W00?oY[[WojBhionT^>L00_nT^>L3oj>fi`03oj6d
i_nN/NKoW[7V00?oVZkU0onGZN<3oi:Th@?oSYkO0_n9V=`3ohBAf0;oOh[D0_mlQ=03ogUnc@?oMg[9
0_mlOLT3ogaja@?oOGS30omoMl42oh9g_`?oQGVn1?n:Nkd3ohmn_@?oU8:m1?nJQ[d3oj6;_PCoYi6n
00Co[IO0ok:K`OnbVl7o/Y_10onhX/800onoZLCoaK35olF`a@02olF`a@03o`000?oA_lWodKo900?o
fL[;00?og<o<on;IcOoRfLd00_oWhlh00ooZk<koj_?=onObd@02onGgdP;oh_WC00?ogo_Gom_kfooG
n^000`3oool00ol00000oooo0?ooo`0M0?ooo`03o`00003oool0oooo01<0oooo00GoIXCLoe]ieomK
NMOoFgWGoeihe@03oeI^d003odmVbomFJ<WoEVS900;oE6?50_mDHL82oeQP`0?oHFG00_mWIkl2ofm/
_P;oN76o0_l00002ogmf_`?oR7bo0_nBPl000onGQl7oXI32oj6@`P02oj6@`PCoZiS300Co]:34okbY
a_nlZLKo_:W60oo4/LL3olfjb003om?1bOoJbl[of/_:00;of/_:00CohMG;onONbooWg/_oj>7;0_o[
j</3onc^b`04oncbbooZm/coj_K<onOhcP;oi?WA00CohO[EomgifooMnM_ofOKP0_oDlnD2olo^j@05
ol_Wjoo5hNcoaN7/olGQk?o0fnd00onleN`01Onhd>co]Lc[okG<jonec>_o//W[00Co/<KZ0_n^a>T2
ojg2j@;o[<7Y00?oZl3Yoj^oj?n[_nP00_n[_nP9ojZnj0;oZKgX00?o0000ojVmj?nY_NP05OnY_NP0
0ol00000oooo0?ooo`0C0?ooo`00303oool00ol00000oooo0?ooo`0L0?ooo`koZKgX0ol00003ojRl
j0CoYk_X0onV^^L2ojBhi`;oXkOW0_nQ]>H4oijaiP?oVZkU0_nGZN<2oi:Th@04ohfOh?n7V=goQiSM
ohNHg@;oPY7I0on4TMP3ogn:e0;oO8C@0omiO/d2ogMjb@?oMWO60_mlN/D3ogeh``?oOgO10on2Mkl3
ohEi_P?oRW^m0on?O[d3oiB2_@CoVXJm1?nQRkh2ojNA_P03oj^E_onbVl7o/Y_100?o/Y_100Co^:;2
oknYa?noZLCo_jW40_o5/<D2olfia`03o`000?oIb/_ofL[;00;ofL[;00CohMG<on;IcOoWhlkoin?>
0_oZk<h00ooZllgoj?S<onGgdP02on;id`05omokeooKnm_ofo_KomOjh?oBmnD00`3oool00ol00000
oooo0?ooo`0L0?ooo`03o`00003oool0oooo01<0oooo0_mVQ=`2oe]ie`;oDFoB0_mFK]001?m?I/_o
C636odaPa_m<H<H2oeASa@;oE6720_mHH<02of5U`0?oIfNo0ol000001?mhLKooPGRooh5h_on1N;l3
ohao`0CoUhO10onQT<83oj^H``03ok:PaOnlZLKo_:W600?o_:W600?oa;77olfjb?o=^/P00_o=^/P0
1?oEaL[of/_:om[;b_oJblX2on7Eb`;oimk;0_o[il/2ong^bP05onc^boo/l/_oj_K<on[fc?oWn<h0
0_oTnM401?oQn]GogOWKomgifooIm^02omCci@;ocnkY0oo:j>`01Oo5hNco`=_]ol3KkOo0fngo_=G/
00?o^=3/00Co]Lc[ok;9jonbbN_o//W[0_n`a^X2ojk4jP;o[L;Y00?o[<7Yoj_0jOn[`>T00_n[`>T2
oj^oj0SoZ[kX1OnY_NP00ol0003oZKgXojVmj00EojVmj003o`00003oool0oooo0180oooo000<0?oo
o`03o`00003oool0oooo01`0oooo2onY_NP3o`0000GoZ;cX1_nW^nP00onV^^OoY;WWojBii`04oj>g
i`;oXKCV0_nN/NH01?nJ[^GoUj[ToiNZi?nGZ^@3oi:UhP?oSIoP0on7V=d01?n2TMWoOH[Fogf:e_mm
R]H3ogR3dP?oM7g>0_miO/d3ogMjb@;oMWO60omgM<<3ogeh``;oOgO10on2Mkl3ohEi_PCoRW^m0on?
O[d3oiB2_@?oVXJm0onQRkh01?nTSkkoZiFooj^E_on[UKl4ok:K`@03okRR`_noZLCo_jW400;o_jW4
00GoaK35olfiaoo=^LOocKW7o`000003omW:b`;ohMG<00Coin7=onOSc_oZk<koj^c>0_oZlld01ooX
n<coiO_<onGkc?oPoLgog?kAom_kfooGn^000_oBmnD01?o>ln[obNg]olW]kOl0000N0?ooo`03o`00
003oool0oooo01<0oooo0omJO=X2oe]ie`05oe5_d_m9ILcoBFG<odUUc?m?I//00_m<H<H2od]L``;o
E6720_mHH<02oeeR_`?o00000_m_K;h3ogQa_`?oPGRo0on<Ol03oiN7`@CoXI3200CoZiS3ok:PaOnb
X<Go/Z350onlZLH2olFbb0?ocK[80ooEaLX00ooJbl[ohMG;on7Eb`03onONb`;ojnO;0_o]k/X01?o]
llWojoO8on_gb?oXn/P2onGkb`04on;lc_oOo=?ogocComckfP;of?WP00?odoCUolo^jOo:j>`00_o:
j>`2olGRk@;o`=_]0_nke^d2okS@k0;o]<c/0_nbbN/2ok36jP;o[/CZ0_n]`^T3ojc1j@;oZl3Y0_n[
_nP:ojZnj0CoZKgX00?o0000ojVmj?nY_NP05OnY_NP00ol00000oooo0?ooo`0B0?ooo`00303oool0
0ol00000oooo0?ooo`0M0?ooo`OoZKgX0ol00004ojVmj0?oZ;cX1_nW^nP00onV^^OoY;WWojBii`02
ojBii`;oXkOW00CoXKGWoijbi_nN/^KoW[;V0onJ[^D3oiNZi0?oTZGR0on=Wn02ohNHg@;oPY7I0omm
R]H3ogR3dP;oM7g>0ombN<X2ogMjb@?oMWO60_mgM<<3ogUc`@?oO7>o0_n2Mkl3ohEi_PCoRW^m0on?
O[d3oiB2_@CoVXJm00?oXH^nojB?__nTSkh01?n[UKl2ok:K`@;o^:;21?noZL@4olfia`03omG4bOl0
003ofL[;00?ohMG<00?oin7=on_[c?oZk<h00_oZlld2onShc008onGkc?oPoLgog?kAomcndOoHo]Oo
e?gMom;giOo>lnX2olW]k@;oa>O_00?o00000?ooo`3oool06`3oool00ol00000oooo0?ooo`0D0?oo
o`;oFWcJ0_m?L=@2oe5_dP;oBFG<00GoA5g7odaPa_m<H<KoC636od]L``02odeK`005oeQP`?l0003o
0000o`000?mMH[l00_mUI[h2ofm/_P?oN76o0on1N;l3ohao`0CoUhO10_nQT<800onXUlGo/Z35ok:P
a@03ok:Pa@03okbYa_o5//SoaK;800;oaK;800CocK[8omG5b_oEaL[oeLG:0_oMd<`01?oQeL_oimk;
onONbooWg//2on_Wb`;okNk:0_o]llT2on_gb0;oiO_;0_oRo<h01?oOo=?og?_Jomckf_oHnN02om?d
i@;oc^oZ00?ob^S/olGRkOo5h^d00_nofnh2ok_Fk@?o^=7]00Go]<c/ok;9jonbbN_o//W[ok36jP02
ojk4jPCo[L;Y00?o[<7Yoj_0jOn[`>T01?n[_nP8ojZnj0KoZKgX00?o0000ojVmj?nY_NP05OnY_NP0
0ol00000oooo0?ooo`0A0?ooo`002`3oool00ol00000oooo0?ooo`0O0?ooo`?oZKgX0ol00006ojVm
j0GoZ;cX1OnW^nP2ojJji`;oY;WW0_nS]nL3oj6ei`?oW[;V00?oVZkUoiN[iOnGZnD00onBY^<2ohbP
h@?oQYWN0_n0T]/3ogZ:e`?oOH[F0_mhPm82ogAmcP?oLWS:0omaM<H2ogIgaP;oMgC30omiLl43ogac
_`?oP7Fm0on5NKh3ohYk_@?oSgjm0onDP[d2oiZ6_@;oWHVm1?nTSkh3oj^E_`03ok:K`OnhX/;o^:;2
00;o^:;20_noZL@2olNbaP;ocKW70ooEa<T00ol0003ohMG<on7Ec002onOQc@07on_[c?o/ll[ok??:
on[ccOoXn<coiO_<on3mc@02omcnd@03omSneooDoMgodO[T00;ocOGZ00?obNg]olCWkoo4inl00_no
h?000ol00000oooo0?ooo`0I0?ooo`03o`00003oool0oooo01H0oooo0_mJO=X01Om?L=CoA6G>odAU
c_m4ILkoBFG<00;oA5g70_m<H<H01?m;G<?o0000o`000?l00002oeQP`0;oGF:o0_mUI[h3ofi/_`;o
N76o0on1N;l4ohao`0;oUhO100?oW8k4ojRGaOnXUlD00_nXUlD4ok:Pa@GoaK;80ooEaLX3omg@c0;o
i=_<00?oimk;on_Wboo[il/00_o]k/X2ongcb@;ojoO80_oUnl/2on;lcP04omoldooLnm[og?_JomSi
h0;odoCU0_o>knX01Oo9jNcoa>;^olCRk_o4h^ko_m_^00?o^mK]0_nhdNd01Ondc>co//W[ok;9jonb
bN_o/<K[00Co[/CZ0_n]`^T00on/`NWoZl3Yoj_0j@02oj_0j@;oZkoX2OnZ_^P7ojVmj003o`000?nY
_NSoZKgX01GoZKgX00?o00000?ooo`3oool0403oool000/0oooo00?o00000?ooo`3oool07`3oool3
o`0000WoZKgX1onX_>P2ojNkj003ojJjj?nU^NOoYKWW00;oYKWW0onS]nL00onQ]NOoW[?Woijci`02
oi^_iPCoUj_U0onBY^<2ohbPh@?oQYWN0_n0T]/2ogZ:e`?oMH?C0om`O<l2ogAmcP;oLWS:0omaM<H3
og5a``;oMgC30omiLl43ogac_`;oP7Fm0on4Mkd3ohYk_0?oT7nl0onGQ;d4oif9_@CoY8nn0_n[UKl0
0onaVl7o^:;2okRR`P03okRR`P03oknYa?o7//Koak;600;oak;600KocKW7omG4bOoEa<WoeLC9omg@
bol00002onOQc@;ojn_<0_o/llX02?oZnLOoiOc5on3na?oKolGog?kAomSneooDoMgodO[T0_o=mNX2
olS_kP05olCWkonoh?3o_n3`ok_Jl?l000006`3oool00ol00000oooo0?ooo`0F0?ooo`?oCG?G00Ko
Cg3DodAUc_m4ILko?5c9odUUc?m4GLL3o`000003od]L`om=Fl3oCE_000;oDUbo0omMH[l2ofEV_P;o
KVbo0omiLl03oh5h_`;oS7o000?oTHC2oib>a?nLS/@00_nLS/@3ojRGa@?o/Z350_nkZ/P3olFbb0;o
c[k;00?oeLG:omg@c?oMd<`00_oMd<`2onCKc0;ojNG<00CojnO;ong^b_o]llWokO?90_o[mlP2onGl
a@;oh_g700?ogok<omcnd_oIoMT00_oFn^02om7fiP03olg`joo9jNcoa>;^00;oa>;^00Go_]_^ok_F
kOnke^go^mK]okO@k@04okC<k004ok;9jon`a^_o/<K[ok36j`;o[/CZ00?o[L;Yojc1jOn/`NT00_n/
`NT2oj_0j@;oZkoX2OnZ_^P9ojVmj003o`000?nY_NSoZKgX01CoZKgX00?o00000?ooo`3oool0403o
ool000/0oooo00?o00000?ooo`3oool0703oool3o`0000<0oooo2?nY_NP7ojRlj0;oYk_X0onV^^P2
ojFii`;oXkSW0_nQ]^L4oijci`;oVjoV0_nGZnD01?nBYnCoSJ;RohfRh_n=X^82ohJKh0?oOi?M0on0
T]/2ogZ:e`;oMH?C0om`O<l2ofefb`?oLWS:0_maM<H3og5a``;oLW310omiLl43ogac_`?oP7Fm0on4
Mkd3ohYk_0?oT7nl0onGQ;d4oif9_@?oY8nn00CoZiFook6K`OnaVl7o/I_11?nhX/85olNbaP?oeLC9
0_oMd</01?l0003oin7=on_[c?o[jl`2onccbP;oj_W700?oiOc5on3na?oKolD00_oCom400ooAo][o
c_cSolgejP02olS_kP;o`nS`00Go_n3`ok_Jl?nkf_3o^m[`o`00000J0?ooo`03o`00003oool0oooo
01L0oooo0_m=LmL2od5Wd@05odAUc_l0003o0000o`000?m4GLL00_m1F<<01?m2E/7oCE_0odeK`?m=
Fl02oe9L_`;oGF:o0_mUI[h3ofi/_`;oNG?00on5Nl44oi64`P?oW8k41?nXUlD00onbX<Go^j[8ok^Z
b002ok^Zb005olFbb?o>_/_oc[k;oljnbooGb/d00ooMd<`3onCKc0;ojNG<00?ok>g:ongcb?o]llP0
0_o/n<H01ooYn/CoiOc5onGlaOoRoLOogok<omcnd_oIoMT00_oFn^02om7fiP;ocO3[0_o7jNd01Oo4
h^ko_]_^okkKk_nnfnko^mK]00?o]m3]0_ndc>`2ok79j`;o/<K[0_n^a>X3ojg2j@;o[<7Y0_n[`>T2
oj^oj0SoZ[kX2onY_NP00ol0003oZKgXojVmj00EojVmj003o`00003oool0oooo00l0oooo000;0?oo
o`03o`00003oool0oooo01T0oooo0ol000070?ooo`KoZKgX1onX_>P4ojNkj003ojJjj?nU^NSoYKWX
00CoXkSW0_nQ]^L2oijci`04oi^ai_nG[NGoUjgUoiN]i@?oTZOT0on=X^82ohJKh0?oOi?M0_miRmT3
og:3e@;oMH?C0_m`O<l2ofefb`?oJg;70omaM<H2og5a``;oLW310omeL;l3ogac_`?oP7Fm0on4Mkd3
ohYk_0?oT7nl0onGQ;d4oif9_@;oY8nn00?oZIC0ok6K`OnaVl400_naVl43okRR`P;o`:_50oo7//H2
om2mb009omG4bOoMd<_ogM3;omg@booUgLco0000on_Xboo[jlcok??:00;oj_W700?oiOc5on3na?oK
olD00_oCom401OoAo][oc_cSol_gj_o;mn[ob>o^00;o`nS`0_nnhO02ok_Jl0;o]mC_00?o00000?oo
o`3oool05`3oool00ol00000oooo0?ooo`0H0?ooo`06odeceol0003o0000o`000?m4ILko?5c90_lg
ELD2od5H``;o@UK10_m=Fl02oe9L_`;oFV2o0_mUI[h3ofi/_`?oNG?00on5Nl43oi64`PCoW8k40_nX
UlD00on`XLSo^j[8ok^Zb002ok^Zb003olFeboo>_/_oc[k;00;oc[k;0_oGb/d01?oMd<coi=_<onCK
c?oTfl`3onWUc005onc]b_o]llSokO?8oncha_oYn/@00_oUo<D01?oRoLOogok<omWobOoGom02omGn
f@04om?khOoAm^KocO3[olg`j`;oanW]0_o2h^l2okkKkP;o^]K^0_ngd>d3okC<k005ok79jon_a^_o
[lK[ojo6jon^a>X00_n]`^T3ojc1j@;oZl3Y00?oZkoXojZnj?nZ_^P02OnZ_^P;ojVmj003o`000?nY
_NSoZKgX01CoZKgX0_l0000@0?ooo`002`3oool00ol00000oooo0?ooo`0F0?ooo`?o00002`3oool6
ojVmj0OoZ;cX0_nW^nP00onV^nSoYKWXojFij002ojFij0;oXkSW00CoX[OWoindionO]>OoWkCW0onK
/NH3oiN]i@?oTZOT0_n=X^83ohJKh0?oOi?M0_miRmT2og:3e@;oKGcA0om`O<l2ofefb`;oJg;70om[
K/@3og5a``;oLW310_meL;l3ogUa_P03ogac_on0MKgoP7Fm00?oQ7Nm0on:Nk`3oi1o_0CoUhBm0_nM
RKd00onRSKooZIC0ojVD`002ojVD`0Co/I_100?o^:;2ol2[aOo0ZlD00_o0ZlD01?o7//Kod;g8om2m
b?o@_LP3omg@b`;oiMg<00cojnS;o`000?o]l/WojoW4on[iaooUo<Goh?k4om_oaOo>o/;odooAom7n
f_o>o><2ol_gjP03olK`k_o2j?7o`^Sa00;o_^7`0_njf_02okODk`03okC?k_l00000oooo01P0oooo
00?o00000?ooo`3oool05P3oool3o`000004ocmZe?m1Im7o@FOAocILb`;o?5c90_lgELD2od5H``03
od9F`Om6EkooAUNo00;oDUbo0_mJH;l3of=V_`;oKVbo0omiLl03ohEk`@?oTHC20onLS/@00onTU/Oo
/:78ok2Qb002ok2Qb0;o^j[80oo5]L/2oljnb`?oel[=0_oOe/h01OoTflcojNG<onWUc?oYiLcok>g:
00;okO?800Ook?S6onWja?oYn/CoiOc5omom`?oLo/?ofOo900;oeoo@00CoeOkIom?khOoCnn7ocoOW
0_o;l>`00oo7jNgo`^;_ol;Rk`03okgKk`04ok[Fk_nfd>go]]3]okK@k@;o]<c/0_nab>/2ojo6j`03
ojk4j_n]`^Wo[L;Y00;o[L;Y00?o[<7Yoj_0jOn[`>T00on[_nP9ojZnj0goZKgX00?o0000ojVmj?nY
_NP05?nY_NP00ol00000oooo0?ooo`0>0?ooo`002`3oool00ol00000oooo0?ooo`0D0?ooo`;o0000
3`3oool7ojVmj0CoZ;cX0onW^nP2ojJkj0;oYKWX0_nT^>P3oj:gi`?oWkCW00?oVk7VoiR^i_nH[^H0
0onCZND2ohfTi0?oQYgR0_moUMl3ogR=f`;oL8GH0ombPmD01?m]O=7oJ7K=ofQfcOmXM/d2ofefb`?o
Jg;70_m[K/@2ofa]`P03og5a`ombL<7oLW3100?oMG2o0omiLKh3ogid_@?oQ7Nm0on:Nk`3oi1o_0;o
UhBm00?oVXNnoj:=_onRSKl00_nRSKl3ojVD`0?o/I_100?o^:?3ol2[aOo0ZlD00_o0ZlD01?o9]/Oo
d;g8om2mb?o@_LP2omW:b`03omg@booUgLcoiMg<00?ojnS;00Wo0000on_ia?oUo;oog_fjomOm^Oo>
o/;oc?o<olcof?o;oN800_o8n>/00oo6l>ko`^Saol;Xl@02okgQl@;o^][`0_nfdnl2okC?kP03o`00
003oool0oooo01L0oooo00?o00000?ooo`3oool0503oool2o`0000<0oooo00Co?f[Doc9Mc_lbGLko
=Uc;0_l_DlH2ocMEa@;o=U710_m2E/42odIG_`;oDUbo0_mJH;l2of=V_`?oKfk10omiLl03ohEk`@?o
THC200?oW8k4ojBFaonTU/L01?n`XLP00onkZ/SoaKG;olFeb`02olFeb`03oljnbooGb/goel[=00;o
el[=0_oOe/h2onKRcP05onWUc?o/kL[okO?8ongcb?o[n<D00_oXnl801?oToL3ogog0omcn`ooIolT2
omOod004omGnfOoCnn7odo_Qologi`;obo3/0_o6jNh2ol7Qk`;o_M__0_nieNh2okK@k@;o/lc/0_na
b>/00on_a^_o[/CZojk4jP02ojk4jP;o[L;Y00?o[<7Yoj_0jOn[`>T00_n[`>T00on[_nSoZ[kXojZn
j008ojZnj0koZKgX00?o0000ojVmj?nY_NP04_nY_NP00`3ooooo00000?ooo`0?0?ooo`002P3oool0
0ol00000oooo0?ooo`0B0?ooo`?o00004P3oool5ojVmj0GoZ;cX0_nW^nP2ojJkj0?oYK[X0onT^>P0
0onR]nOoWkGWoinei`03oibbi`?oV:kV0onCZND2ohfTi0?oQYgR0_moUMl3ogR=f`04og25f?mYOM?o
JGgCofUmd`;oKGcA0_mXM/d3ofE`b@;oJg;70om[K/@2ofa]`P;oLW310omeL;l3ogUa_P?oOWBm0on4
Mkd3oh]l_@?oTX6m1?nJQkh3oj:=_`CoZIC000Co/I_1okRS`onhXl?o^:?30_o0ZlD3olVfa`04om2m
b?oIb/_ofL[;omW:b`;oh]S<00coiMg<on_Xboo[j<_okO;9o`000?oUo;oog_fjomOm^Oo>o/;oc?o<
olcof?o;oN82olShj`;oa?7_00Co`^SaokgQlOnmhO7o^MW`0onfdnl30?ooo`03o`00003oool0oooo
01H0oooo00?o00000?ooo`3oool04P3oool3o`0000H0oooo00Co?f[Doc9Mc_lbGLko=Uc;0_l_DlH0
0olgELGo=U71ocIA`@02ocQA`0;oAUNo0_m=F[l2oeYP_`?oHfJo0_m_K/43ogag``?oRH740onGS<H4
ojBFa`;o/:7800?o^Zc;olFeboo5]L/00oo5]L/01?o?`/koel[=omO:cOoGb/d3omoFcP;oi^;>00?o
jnc<onccbOo/llT00_o[n<D2onSk`P03omom`?oLo/?oe?jo00;odoo70_oAomX00oo?o>;oc?OYolcg
j@02olS`k@03olKYk_o1hNoo`N7_00;o_=[_0_nieNh01Oned>go/lc/ok?<k?ncc>co/LS[00Co[lK[
0_n^a>X2ojg2j@?o[<7Y0_n[`>T2oj^oj0WoZ[kX3onY_NP00ol0003oZKgXojVmj00=ojVmj0H0oooo
00?o00000?ooo`3oool03P3oool000X0oooo00?o00000?ooo`3oool03`3oool3o`0001H0oooo0onY
_NP5ojRlj0;oYkcX1?nV^nP00onU^^SoY;WXojBij003oj:gj0?oWkGW00?oW;;WoiV`ionI/>L00_nD
ZnH3ohjVi@?oQioS0_n0V>42ogR@gP?oN8gK0_m`QMP2ofUmd`?oI7G?0_mXM/d2ofE`b@?oI6c60_m[
K/@2ofa]`P?oKVc00_meL;l4ogUa_P;oOWBm0on4Mkd3oh]l_@CoTX6m0onJQkh3oj:=_`?oZIC000?o
/9_2okRS`onhXl<00_nhXl<00oo0ZlGobKK7olVfa`02olVfa`?ofL[;0ooRf<`03OoYiLcojnS;ongb
bOo[nLCoiOboo`000?oGoKWoaOVaol?k^_o4o/Soa_oFolOmhoo8n>/00_o4lNl2ol3Xl@05okgQlOni
fO3o^MW`okWIl?nfdnl01@3oool00ol00000oooo0?ooo`0E0?ooo`03o`00003oool0oooo00l0oooo
0ol000090?ooo`;o<67B00Ko<Ug>obMCb?l_DlKo;e?6ob]>`_lgELD2ocIA`@;o>57000?oAUNoodeJ
_om=F[l00_mGH<03of=V_`;oKfk10omlMl<3ohV1a0?oUhc61?nTU/L01?n`XLSo^Zc;okZ/bonj[</3
olFeb`?ocl;>00Coel[=omoFc_oOe/kogmK>0ooVh/h01?o[k<cok??9onccbOo[n<D2onSk`P03omcm
^ooHoK_oe?jo00;odoo70_oAomX00oo?o>;oc?OYolcgj@02olS`k@;oa>S_00Go`N7_okcJkonlf^oo
_=[_okSDkP03okG@k@04ok?<k?nab>_o/LS[ok78j`;o[lK[0on^`nX00on]`^Wo[<7Yojc1j@03oj_0
j@;oZkoX2?nZ_^PBojVmj003o`000?nY_NSoZKgX00WoZKgX2P3oool00ol00000oooo0?ooo`0=0?oo
o`002P3oool00ol00000oooo0?ooo`0<0?ooo`?o00006P3oool3ojVmj0?oZ;cX1?nW_>P2ojJkj003
ojJjj?nT^NSoY;WX00;oY;WX00?oX[OXoj2fj?nP]^P00_nM/nL4oiV`i`;oU:_V0on>Y^D3ohNOh`;o
P9SQ0_mhT=h2ofn7fP?oIgkF0_mYOM<2ofAec`?oH6o;00CoIG39ofA/a_mTK<KoI6c60_mTJ/<3ofa]
`P;oKVc00ombK[h3ogUa_P?oOWBm0on4Mkd3oh]l_@?oTX6m0onJQkh4oj:=_`04ojVD`?n`Vl;o/9_2
ok2K`P;o^:?300?o`Jg6olVfaoo9]/L00oo9]/L00ooC`l_ofL[;on;Hc003on;Hc00<onWUc?o]lLWo
joW3onGl^ooKnk;odOV]o`000?o3nk[oa?k8olKoe_o7oN?oaOS/0_o2l?02ol3Xl@;o_>3b0_nifO07
0?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool0303oool3o`0000d0oooo00Co<67B
ob9DbolbGLko9e?80_l_DlH00ol[C/;o=U71ocIA`@02ocQA`004ocmD`?m6EkooCEZoodeJ_`;oEf30
0_mSI[l3ofm^`@?oO7O30on9PL@3oiN<aP;oY9K700?o[J7;okZ/bonj[</00onj[</00oo5]L_ocl;>
olo2cP02olo2cP;ofM3@00GogmK>onKRc_oVh/koi^;>on_/c002onccb@03on_haOoXnl;oj?_200;o
g?fk00Cof?fkom?oaooColOocOo@0_o=om/01?o<nnGobOK[olWfjoo8l>d2olCXk`?o_n3`00Go_=[_
okSDk_nhe>ko^=C^okG@k@03ok;;k004ok78jon_aN_o[lG[ojo5j`;o[/?Z00?o[<;Yojc1jOn/`NT0
0_n/`NT00on[`>WoZkoXoj^oj00:ojZnj1;oZKgX00?o0000ojVmj?nY_NP01OnY_NP=0?ooo`03o`00
003oool0oooo00d0oooo000:0?ooo`03o`00003oool0oooo00T0oooo0ol0000N0?ooo`03ojVmj?nX
_>SoZ;cX00?oZ;cX0_nW_>P3ojNkj0;oY[[X0_nT^NP00onS^>SoX;KXoj2fj002oj2fj0;oWK?W0_nI
/>L01?nF[^OoT:SVoi2Xi_n@Z>H3ohVSi@;oPI_S0_miTn43ogR@gP;oKhOJ0_mWO]H3of1fdP06ofAe
comPKl_oH6o;of1_bomMJ/SoIG390_mTK<H3ofAZ``;oK6g20om^K<02og9^_P?oN72n0omnM;d3ohAg
_@?oRgbm0onBPKd4oiZ7_P;oXXfo00?oYi?1ok2K`_n`Vl800_n`Vl801?nhXl?o`Jg6ol6]a_o1[LH3
olVfa`;odl?;00CogM7=on;Hc?oRf<coh]S<0_oYiL`02_o]lLWojoW3onGl^ooKnk;obOR/o`000?o4
o/Soa_oFolOmhoo5n>`2ol;`l0;o_^Ob0_nlh?8:0?ooo`03o`00003oool0oooo01D0oooo00?o0000
0?ooo`3oool02@3oool3o`000100oooo0_l`HM800olRE<_o9e?8ob1;a002ob1;a0;o:dc00_lhDL02
ocmD`0;oCEZo0_mGH<03of=X`P;oKfk10omlMl<3ohV1a0?oUhc600CoY9K7ojfQbon]XL_o[J7;0onj
[</2olFic`?ocl;>0ooId=02on7Md@05onKRc_o[k<cok??9onccbOoZnLL00_oVo<800ooQoKgog?fk
omSm^`02olcm_004olgod?o=om_ocOoKolcki@;obOK[0_o6k^l2ol7Vl0;o_n3`0_njfNl2okSDkP;o
]<o]0_nbbn`2ok38j`;o[lG[00?o[L?Zojc2jOn/`^T00_n/`^T2ojc1j@;oZkoY0on[_nP5ojZnj003
ojVnj?nY_NSoZKgX01?oZKgX00?o0000ojVmj?nY_NP00_nY_NP@0?ooo`03o`00003oool0oooo00d0
oooo000:0?ooo`03o`00003oool0oooo00H0oooo0ol0000R0?ooo`CoZ;cX0onW_>P2ojNkj003ojJk
j?nU^^SoYK[X00;oYK[X0_nS^>P2oj2fj004oijdj?nJ/NSoV[7XoiZaj0?oUZkW0on@Z>H3ohVSi@;o
PI_S0_miTn42ofn;g@?oIX7I0_mWO]H2of1fdP04oe]_c_mTMLooH6o;of1_b`;oGF[80omTK<H2ofAZ
``?oIVW10_m^K<03og9^_P;oN72n0omnM;d3ohAg_@?oRgbm1?nBPKd2oiZ7_P04oij<`?nWTl7oYi?1
ojNC`@Co/9_21Oo1[LH01?o9]/Oodl?;om?3booC`l/2omgAc@0?on;Hc?oYiLcojNG<ongabOo[nL?o
iObkom_k/_o9n:co]_:VokSf/ol0003o`OkFol?mi?o2mngo`_3`00;o_^Ob3@3oool00ol00000oooo
0?ooo`0E0?ooo`03o`00003oool0oooo00H0oooo0ol0000C0?ooo`;o85S?00?o8UC;oaM;a_lGBlH0
0_lPBl@00ol[C/;o:dc0ob]<`002ocQA`003ocmD`?m8F/7oB5[100?oEf300_mSJ<82og5ba0?oO7O3
0on9PL@2oiN<aP03oinFb_n]XL_o[J7;00?o[J7;00?o^Zc;olFicoo5^Ll00_o5^Ll01?o?`/kofM3@
omW@d?oId=03on7Md@03onSYd?o[llgojo?=00;oj_W70_oVo<801ooLoK_odO^dolcm_?o<oKcoa?g5
olOod_o9o]h00_o8nnL2olKdk@03olK^koo1i_3o`NK`00;o_Mk`0_njfNl2okOCkP;o]<o]0_nbb^`2
ok38j`03ojk5jon]`n[o[L?Z00;o[L?Z0_n/`^T2oj_0j@;oZkoY00?oZkoXojZnj?nZ_^P01OnZ_^P3
ojVnj1GoZKgX00?o00000?ooo`3oool04@3oool00ol00000oooo0?ooo`0=0?ooo`002P3oool00ol0
0000oooo0?ooo`030?ooo`?o00009P3oool4ojRlj003ojNlj?nW^nSoYk_X00?oY[_X0_nU^^P00onS
^NSoXKOXoj6gj002oj6gj0;oW[CX0onJ/NP00onF[^OoTZ_Woi:[i`03oh^ViP;oPioU0_mjUn<3ogVC
h@;oKh_M0_mVPMT2oeiie@;oH7KB0_mKKlh3of1_b`04oeeZb?mMIlGoGFO5oeeWa@;oI6[30omVJL42
ofYZ`0?oLVjn0omhL;h2ogid_@?oQGVn0on=O[h4oiJ5_`?oWXc01?nWTl42ok2K`P;o^:G60oo1[LH0
1?o;^/[odl?;om?3booC`l/3omgAc@0=onKQc_oYiLcokO79on_i`ooUo;_ofo^bokoaWOnhl9ko]_:V
okckaOo1o]Ko0000ol;gk@02ol3_lPl0oooo00?o00000?ooo`3oool05@3oool00ol00000oooo0?oo
o`030?ooo`?o00005`3oool2ob1Hc`05ob9DbolGBlKo5d_6ob1;a?lMAl400_l[C<001?l_CL3o>570
ocmD`?loE<02odQJ`@;oEf300_mSJ<82og5ba0?oPGk70on@R/T4oinFbP?o[J7;00?o^:o@olFicoo5
^Ll00oo5^Ll2om38d`04omW@d?oQgM7ohMgAon7Md@;oj>W@0_o[lld01?oZnLOoi_c2onKl`_oGo;L2
om7k]004olcm_?o4oLGoaooBolWngP;ob?_W0_o6m>d2ol?/l0;o_nCa00Go_Mk`okWGl?nieo3o^MO`
okOCkP03ok?>k@03ok;:k?n_an_o[lO[00?o[/G[0_n]`nX2ojc1j@;oZl3Y00?oZkoYoj^oj?n[_nP0
0_n[_nP7ojZnj003ojVnj?nY_NSoZKgX013oZKgX1@3oool00ol00000oooo0?ooo`0@0?ooo`03o`00
003oool0oooo00d0oooo00090?ooo`04o`00003oool0oooo0?ooo`?o0000:P3oool3ojRlj0CoYk_X
00?oY[_XojFjj?nU^^P00onS^NP2oj6gj004oinfj?nL/nSoW;?Xoibcj0?oUk3X0onBZnL3oh^ViP;o
PioU0_mjUn<2og6?h0;oIXGM0omVPMT01OmNNMGoEW3AoeI`dOmPM];oFfo>00?oEfW:0_mMJ/P2oeeW
a@;oGVK300?oI6[3ofIY`OmVJL400omZJ/02og9^_P?oN72n0omnM;d3ohEi_P?oSGjn0onFQKl4oij<
`0?oYi?100?o/9_2okRUa_nhYLH00_nhYLH01Oo1[LKobk[:ol^jb_o;^/[odl?;00?ogM7=0_oVhLh0
3Oo/klcojoW5onCl^_oHnZgob_FSokoaWOnflZKo]?W4ok_meonoo>Ko`?K_o`000?o0ko80403oool0
0ol00000oooo0?ooo`0D0?ooo`04o`00003oool0oooo0?ooo`?o00006`3oool01olPF<oo4Dc8oa5<
b?lGBlKo4DC2ob1;a?lMAl400_l[C<000ol_CL3o?eC0ocmD`002odQJ`@?oEF;40_mSJ<82og5ba0?o
PGk70on@R/T4oinFbP04ojfQbonh[m3o^:o@okR_d0?oaKW?0oo@b=<2om[Ge@03on7MdOoXjM3oj>W@
00;ojo?=00?oj_W7onKl`_oVo<800_oGo;L01_oAnkCo`_Raol;j^_nmo<Oo`_kEolGmhP;oaOWZ0_o3
l_000oo3k?3o_nCaokoTl@02ok_Ll@;o^MO`0_nedNh2ok?>k@03ok79k?n_an_o[lO[00;o[lO[00Go
[/G[ojg3j_n]`n[o[L?Zojc1j@02oj_0j@?oZkoY0_n[_nP7ojZnj0;oZKkX3onY_NP90?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool03@3oool000T0oooo1?l0000_0?ooo`;oZ;cX0_nW
^nP2ojJkj0?oYK[X00?oXkWXoj:hj?nR^>P00onO]^P3oibcj003oiN`j?nD[^SoU:kX00;oSZWX0on6
XnL2ogfLi@?oLi?S0_maSn001?mVQMgoG7cIoealfOmLO=T2oeiie@;oEW3A0_mKKlh2oeMYbP;oEFG7
0omMIlD2oeiV``?oIVW10_mZJ/03og1]_`;oN72n0omnM;d3ohEi_P?oSGjn1?nFQKl3oij<`0;oYi?1
00?o[Yc5okRUa_nhYLH00onhYLH4ol^jbP;oe/[>00gogM7=onKQc_oVhLkoi^7>onc_c?o[nLGoi?bj
omSj[OnolIgoYNF@okCia?nkoMOo_ocV00;o`?K_00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`0D0?ooo`Co00007P3oool01ol?D<co85S?oa5<b?l7@l?o5d_6oa54`_lMAl400_lOAl000ol_
CL3o>5;2ocQB`P03odQJ`@;oEF;40_mTKLL2og5ba0?oPGk71?n@R/T2oinFbP03ojVRd?nh[m3o^:o@
00?o^:o@00?oaKW?om38doo@b=<00_o@b=<2om[Ge@05on;VeOoXjM3ojo?=on_ccOoWnL`00_oSoL@0
2?oMoKcoeobgom7k]?o2n;7o`_Zjokglaoo2o]GoaOgR0_o5nNX2ol?bl0;o`>[b00?o_nCaok_LlOnk
g?400_ngeO02okGAkP03ok;<kOnabNco/LW/00;o/LW/0_n_an/2ojk4j`;o[L?Z00?o[<7Yoj_0jOn[
`>T00_n[`>T01?n[_nWoZ[oXojZoj?nZ_nP6ojZnj0;oZKkX3OnY_NP<0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool03@3oool000T0oooo0_l0000a0?ooo`CoYkcX0onV^nP3ojBjj0?o
X[SX00?oWkKXoifejOnM]NT00_nI/^P4oiB^j0;oSZWX0on6XnL2ogfLi@;oLi?S0_mXR^02ofJ5g@;o
G7cI0omCLmD01?mFL=7oD6W=oe1YcOm@JLd2oeMYbP;oEFG70_mMIlD2oeiV``;oHFO200?oIVW1ofYZ
`?mZJ/000om`KKl3ogI`_`;oOWBm0on5NKh3ohen_PCoUXFo0_nNS<000onTTl?o[Yc5ojjLa@02ojjL
a@?o^:G60_o2/LX2ol^jbP?oe/[>0ooVhLh02Oo/klcojoW5onCl^_oHnZgob_FSojGUT?n^n<Go^?cK
okcjjP040?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool04`3oool2o`000240oooo
00Go3e3<oa5<b?lAC<So1d?3oa54`P02o`m2`0;o7dO000?o;dg0ocQB`_lhD/800_m8F/42oeERa0;o
I6g70omeN/X3oh5na`;oT8[900?oVIG?ojVRd?nYX]000_nYX]03okR_d0;oa;kE0oo@b=<3om[Ge@03
on;VeOoWl];oio;B00;oioW<0_oSoL@00ooGo;Oob?V_ol;h/@02okgla`04okgnf_o1o>Ko`OcVol;g
kP;o`>ob0_o0j_82okcRlP;o^=[a00?o]mG`okC@k_ndd>h00onbc>d2ok79k0;o[lK[0_n^a>/2ojc2
jP?o[<7Y0_n[`>T2oj^oj@;oZ[oX1_nZ_^P00onY_^SoZKgXojVmj00;ojVmj0l0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`0<0?ooo`002`3oool00ol00000oooo0?ooo`0_0?ooo`;o
YkcX00?oYk_XojJkj?nV^nP00_nV^nP00onT^^SoXkWXoj>ij003oj6gj0?oWKGY0_nI/^P2oiB^j004
oi6/jOn9YnSoRJOXohVWj0?oPJ3W0_mgVNH2og>Ch`;oJ8[P0_mMP=d2oealf@;oDg?E0_m;Jm42oe1Y
c@;oCFC:0_mEILL2oeESa@?oGVK30_mQIl83ofYZ`0;oL6fo0omfL;l3ogif_`?oQGVn0on=O[h2oiJ5
_`03oiZ;`_nTTl?oY9?300;oY9?31?n^W<D01OnhYLKo`[7:ol:ab_o2/L[obk[:00Coe/[>00CohM_@
onKQc_o/klcojoW50_oTo;X01Oo3lI_oYNF@ojkhaOnho=_o_?[Z00H0oooo00?o00000?ooo`3oool0
3P3oool00ol00000oooo0?ooo`0E0?ooo`03o`00003oool0oooo01l0oooo00Go3e3<o`15aOl0ALGo
0Ck0oa54`P02o`m2`004oam7`?lVBl;o>5;2ocQB`P?oA5_50_mEH/@2ofA]a`;oMG[:0on7Qld4oiVE
c`CoZJ;@00?o^:o@olBneOo4_]D00_o4_]D01?o@b=?of]OEom[GeOoJemD2on;Ve@;oio;B00WoioW<
on?ma?oSoLCod?^eolSi[ondlZOo/?JjokOkbonmo]X00_o1o>H00oo2mnko`>obol3_lP03okgWl`04
okcRl_nhf_7o^=[aokGCl0Co]=3^00Go//c]ok38k?n`b>co/<S/ojo6j`03ojg4jP03ojc2j_n/`NWo
[<7Y00?oZl3Y0_n[_nT00onZ_nSoZ[kXojZnj005ojZnj0?oZKkX2OnY_NPC0?ooo`03o`00003oool0
oooo00h0oooo00?o00000?ooo`3oool0303oool000`0oooo00?o00000?ooo`3oool0<03oool2ojNk
j0;oY[_X0_nU^^P3oj>ij003oj6gj?nO]^WoWkKY00;oVkCY1?nG/>T2oi6/j@?oRJOX0on1X>L00omg
VNKoJi3Tof^@i003oen6h@04oef0gOmBMmWoDWOIoe9gf@;oDg?E0_m;Jm401?m@JLgoCFC:odeTb_m=
I<X2oeEUa`;oEF?50_mNI/<2of5W`P?oIVW10om`KKl2ogI`_`?oOWJo0on7O<03oi23`@CoVX_20onT
Tl<3ojjLa@03okNXbOo2/L[o`[7:00;o`[7:00CocL7?omK:c_oFb/koe/[>0_oQfm002OoXk<ooj_S9
on?l_?oSo;coe?V[oi;FO?nKk:ooZ_S:okGlh0080?ooo`03o`00003oool0oooo00d0oooo00?o0000
0?ooo`3oool05P3oool00ol00000oooo0?ooo`0N0?ooo`;o04W900?o04G5o`M3`ol1?/000_l?@/00
0olBA<7o7dO0obI;`P02ocQB`P;oA5_500CoE6O9oeERa?mTKLOoI6g70omeN/X3ohN7c@?oVIG?0onY
X]02okFbeP?oa;kE0oo@cmT00ooJemGoh^KEon;Ve@02onObdP0:onOic?oSoLCohog4om3k]Oo8nJoo
]?:WojW`[?nYmKko/__@ok[mg`;o__[[00?o__Caokg/lonmk?<00_nmio<2ok[NlP04okSJlOnedo3o
]M?`okGCl0;o]=3^0_nabnd2ok38k0;o[/G[0_n]a>X00on/`^[o[<7Yojc1j@02ojc1j@04oj_0jOn[
_nWoZkoYoj^oj@;oZ[oX1onZ_^P00onY_^SoZKgXojVmj002ojVmj1X0oooo00?o00000?ooo`3oool0
3@3oool00ol00000oooo0?ooo`0<0?ooo`003@3oool00ol00000oooo0?ooo`0_0?ooo`CoY[_X00?o
YK[XojBjj?nT^^P00onR^>T3oinfj@;oVkCY0_nG/>T01?nC[nWoSJ_Yohf[jOn=ZnT2ohFUj@?oNikX
0_m`U^L2of^@i0;oGhKQ0_mCO=d2oe9gf@;oB6kE0_m;Jm401?m5I<goD6W=odeTb_m=I<X2od]Qa`;o
EF?50_mGHl@3of5W`P;oIVW10_m]KL401?m`KKooMW2oogI`_omfL;l2ogif_`CoQgc00on@Pl43oiZ;
`PCoY9?300Co[Yc5okNXbOngZ<Wo]jS90_o2/LX3olg1c`03omK:c_oQfm3ohM_@00;oj>c?00Ooj_S9
on?l_?oSo;coVMUlohgMTonZn<[o]OcP00T0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo
0?ooo`0G0?ooo`03o`00003oool0oooo01h0oooo00?o04W9o`0n`_l0ALD00_l1?/001?l?@/3o4TC1
oa94`OlVBl82oc5Ca@;oA5_50_mDIlT2ofA]a`?oMG[:0on7Qld4oiVEc`03ojVRd?ne/]Ko]K;F00;o
]K;F00Coa;kEom3?fOo@cmWod<oI0_oJhM/01?oRi]Goio;BonObd_oSnM<2omonb@07om3k]OnmmJ_o
]o:VojW`[?nYmKko/__@ok[mg`02okkjj`03okkdlOnmk??o_Ncc00?o^^?c00Go^]kbokKGlOnfeo7o
]]OaokGCl003ok;>kP06ok7;kOn_anco[lO/ojo7k?n^aN_o[L?Z1?n/`^X2ojc1j@;oZl3Y0_n[_nT7
ojZnj0KoZKgX703oool00ol00000oooo0?ooo`0=0?ooo`03o`00003oool0oooo00`0oooo000>0?oo
o`;o0000<03oool2ojJkj003ojFkj?nT^^SoY;[X00;oY;[X00?oX[SYoj6hjOnQ^>T00_nM]^T4oiVc
j@;oTjoY0on=ZnT2ohFUj@?oNikX0_m`U^L2of>=i0;oGhKQ00GoDgcModIbfOm6L]WoDWOIodQ^e@02
ocmVd@03od][dOm5I<goCFC:00;oCFC:0_m;HLL01?mEHlGoEf?4oeMSa?mGHl@2of5W`P?oIVW10_m]
KL43ogI`_`?oOWJo0on7O<03oi23`@CoVX_20_nTTl<00on/W/So]jS9okNXb@02okNXb@03ol:ab_o=
`LoocL7?00;ocL7?00GofM?Con7Kd?oXk<ooj>c?on[hb@02on?l_003ojOQQOn=gI?oZ?SB00`0oooo
00?o00000?ooo`3oool0303oool00ol00000oooo0?ooo`0H0?ooo`;o00007`3oool02Ol0A<Ko03k2
o`0l`?l1?/3o03foo`m2`?lBA<7o6d_5obI;`P02oc5Ca@;oA5_500CoE6O9ofMecOmWMLgoIgG=0ome
N/X3ohN7c@;oVIG?0_nSY=H3okFbeP04ol;4g?o@cmWod<oIom3?f@?of^7K0_oQkmT2on?id`07omon
bOo7n[Go_OF[okObY_nOkJkoZOFnojojf002okOkiP03ok_gkonll??o_?3c00;o^^Od0_njho<2okOK
lP;o]]Oa0_ncdNl2ok;>kP;o/<W]0_n_an`2ojg5j`;o[L?Z0_n/`^X2oj_1j@;oZl3Y00?oZ[oXojZn
j?nZ_^P02?nZ_^P2ojVmj200oooo00?o00000?ooo`3oool0303oool00ol00000oooo0?ooo`0<0?oo
o`00403oool00ol00000oooo0?ooo`0_0?ooo`;oYK_X0_nT^^P00onS^NWoXKSYoj6hj@02oj6hj@;o
WKKY0_nI/nT01?nG/^[oTJkZoi6^j_nA[^X2ohVYj`?oP:?Z0_meW>T3ofVDj003of>=i?mFPn;oEX?R
00;oB7SN0_m6L]T2odQ^e@;o?fKA00CoAFC=od9Pbom2H<_o@V3;0_m;HLL01?m<H<KoEF?5oeMSa?mG
Hl@3oeaU``;oIVW10_m]KL43ogIb`P?oOWJo0on7O<04oi23`@;oVX_200?oXIC7ojbNb?n/W/P00_n/
W/P2okNXb@;o`[O?0oo=`Ll2omWCd`07on?Ve?oXk<ooj_S9on[hbOoSo;co^njGoiO/]@0?0?ooo`03
o`00003oool0oooo00/0oooo00?o00000?ooo`3oool06P3oool00ol00000oooo0?ooo`0M0?ooo`05
o`14a_l0=kgo03Nmo`0i__l0?Kl00_lBA<400olKBlGo<E?5oc5Ca@02od5Ob`;oE6O90_mWMLd3og^5
d@?oT9GD1OnSY=H01One/]Ko`/CLol;4g?o2a=cod<oI00?of^7K0_oQkmT2on?id`07omonbOo7n[Go
_OF[ojS/XOn;hJ7oY?C5ojgjh002okGik0;o^O?c00?o_?3cok[Wm?njio@00_nhgo<2okOKlP;o]=Ca
0_ncdNl2ok7<kP;o/<W]0_n^a^`2ojg5j`03ojc2j_n/`NWo[<7Y00;o[<7Y00?oZl7Yoj^ojOn[_nT0
0onZ_nP8ojZnj2@0oooo00?o00000?ooo`3oool02`3oool00ol00000oooo0?ooo`0<0?ooo`004@3o
ool00ol00000oooo0?ooo`0_0?ooo`?oYK[X0_nS^NT2oj6hj@03oingjOnK]N[oVkGZ00;oVkGZ0_nG
/^X3oi6^jP;oRJW[0on0XnX2ogFLj@;oJICX0_mKR^H2oeJ3hP;oB7SN0_m6L]T2oc]Ye@03ocmVdOli
H<ko>F3>00;o@V3;0_m1G/T01?m;HLOoC636oeMSa?mGHl@3oeaU``;oHfW40om]KL42ogIb`P?oOgW3
0on:PL@01?n7O<3oT8?1oi23`OnER/H3oj6Da`Co[9k800?o]jS9ol:gcoo2]ll00_o2]ll01Oo=`Loo
fM?ComWCdooIdm?ohnKD00;oioK?00?ohOg2om7i[Ol000004@3oool00ol00000oooo0?ooo`0:0?oo
o`03o`00003oool0oooo01/0oooo00?o00000?ooo`3oool0703oool2o`0o`P;o03Nm00?o03Vno`E2
`ol5@/<00_lKBlD2oc5Ca@04od5ObomEKm3oEFo@oeE_d0;oIgG=0omkQM43oi2Ee0?oXjCF00Co/;ON
ol;4g?o2a=co`/CL0oo>f>400ooJhM_ohNoIon7_f@02on?id`07omWodOoAo/?o/?6ZojS/XOn;hJ7o
XOG?ojgjh002okGik0;o^O?c00Go^N_eokOSmOnghoGo]n?eokSOl`03okGHlP05okCDlOnbcnoo//o_
ok;?konac>h00on_b>`00on^a^co[LC[ojg4j`03ojc2jP;o[<7Y0_n[`>T3oj^oj@03ojZoj?nZ_^So
Z[kX00;oZ[kX:P3oool00ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo00`0oooo000B0?oo
o`03o`00003oool0oooo02l0oooo00?oYK[XojBjjOnT^^T00onR^NT2oingj@;oVkGZ00CoV[CZoiBa
jonD/N_oU;7[0on>[N/2ohJXk0;oO:;[0om`Vn/2of:Bj@;oFh[V0_m<P><01Om8N=ko>VkJocY^f_lj
K][o>fWE00;o<V7A0_liH<h2od9Pb`;o@Ek900CoC636oe1Ra_m@H/KoEf?40_mLIL<3of=Ya0;oKFg1
0omfL/83ogmi``?oRX740onER/H4oj6Da`;o[9k800?o]Zc?ol:gcoo2]ll00oo2]ll3omWCd`06on?V
e?oWm/ooioK?onOfcooQoL;o00004P3oool00ol00000oooo0?ooo`0;0?ooo`03o`00003oool0oooo
01/0oooo00?o00000?ooo`3oool0703oool2o`0o`P03o`0g_Ol0>Kko03Zo00;o1D;300?o6d_5obYG
bolZEl/00_m1Gl/2oeE_d0?oJh7G0omkQM43oi2Ee005oj>Te_n`]mko/;ONok2gg_o2a=`00oo>f>43
omS[hP;og?SL00KofOoAom7n`on`lJ[oZ>bQoh_QXOnQm]X2ojghj@03ok?el_nfk_Ko]^kf00;o]^Kf
0_nghoD2okGKl`;o]MSb0_nbdO02ok;?k`;o/<[]0_n_b>`2ojg5j`?o[LC[00?o[<;Zoj_1jOn[`NT0
0_n[`>T00on[_nWoZ[oXojZoj002ojZoj0;oZ[kX;03oool00ol00000oooo0?ooo`0;0?ooo`03o`00
003oool0oooo00/0oooo000C0?ooo`;o0000<03oool3ojBjj@03oj:ijOnQ^NWoXKWY00?oW[OZ0_nJ
]>X3oiBaj`03ohj]jon;[NcoRjg/00;oPZS]0_mlX^/3og2Kj`05of:BjOmBRNOoDXWWoe:9iom<P><0
0_llMMl2ocY^fP05obeUe_lkJMGo<V7Aoc9QdOliH<h00_leG<`2od5Nb@04od=Nb?m<H<KoD6;6oe1R
aP?oG6G30_mSJL@3of]_a@;oMW;20omoNL<3ohZ1a0CoUH[60onQU<L01?n/W/So]Zc?okJ/conf[<l3
ol:gc`;oclWE00?ofM?Con?Ve?oWm/l00_oWm/l00ooQoL;o00000?ooo`0C0?ooo`03o`00003oool0
oooo00X0oooo00?o00000?ooo`3oool0703oool2o`0001d0oooo00Wo03o2o`0f^Ol0<kWo03Vno`0j
_ol5@/?o44g9oa];aOlZEl/00_lnIm<3oeE_d0;oJh7G0on3U=/3oi^VgP?o/;ON0onmc>H01?o>f>7o
f>_RomS[h_oHjn82omchg005omWodOoAo/?o/?6Zoi7QUon2gjH00_nRm^D01?n]m_3o/_7fok;am_nf
k_H2okKVmP?o]Mke00Go]M_cok?DlOnce?7o/mCaok;Al003ok3<kP03ok3:kOn^anco[/O/00;o[LG[
00?o[<?Zojc2j_n/`^X00_n/`^X00on[`NWoZl3Yoj_0j@03oj^oj@;oZ[oX<03oool00ol00000oooo
0?ooo`0:0?ooo`03o`00003oool0oooo00/0oooo000E0?ooo`03o`00003oool0oooo02h0oooo0onS
^^T3oj6ij@03oijgj_nL]^_oV;C[00?oV;C[0_nB/N`3oh^]k0;oPZS]0_mgX^d2of^Kk0;oFi;[0_mB
RNL2od9ni0;o?7GO00?o;6_KocY^f_l]IMH00_lbHM401?l[G<oo>F3>ocELc?leG<`2od5Nb@03od=N
b?m@H/KoD6;600?oEVG60_mSJL@3of]_a@?oMWO60_moNL<4ohZ1a0?oUH[60_nQU<L00onYX<ko]Zc?
okJ/c`03okJ/c`05ol:gcoo?bMGoclWEolo9eOoKgmT00_oRlmP00ooWm/oohOg2o`00000F0?ooo`03
o`00003oool0oooo00T0oooo00?o00000?ooo`3oool07P3oool00ol00000oooo0?ooo`0L0?ooo`03
o`0f^Ol0<kWo03Zo00;o04;500?o44g9obYGbolZEl/00_lnIm<2oeE_d0?oJh7G0on3U=/3oi^VgP04
ok2gg_nmc>Ko_LcVokg<iP?obN;Z00Sof>_Romchg?oLn=cocokMolOnbonOk:_oO=F>oi;`d`;oX_KU
00?o[OK`ok;am_nblOH00_ndjOL2okCQmP;o]Mke0_nceo<2ok?Dl@;o/Lo_0_n`c>h2ojo8k@03ojk7
k?n]a>_o[LC[00?o[<?Z0_n/`^X5oj_0j@03oj^oj@3oool0oooo0380oooo00?o00000?ooo`3oool0
2@3oool00ol00000oooo0?ooo`0;0?ooo`005P3oool00ol00000oooo0?ooo`0^0?ooo`03oj>jjOnR
^^WoX[[Y00?oX;SZ0_nL]^/2oiRdj`04oiJdk?n@/NgoT;7]oi2ak@;oR:g]0omoZ>h2og>RkP;oJi_/
0_mKT^/2odZ8j@;o@WkT0_l`Ln001_l/Jm_o;FGFobeUe_lSGM;o<V7Aob]Lc`;o=Ec<0_leFl/2od=N
b0;oD6;60_mFILH2oem[b003of=Ya?m[KlGoJfo500?oMWO60on1P<P3ohZ1a0;oUH[600?oViG<ojVP
c_nYX<h00_nYX<h3okJ/c`04ol:ne_o?bMGoclWEolo9e@;ofmoI0_oRlmP00ooOo/_o00000?ooo`0G
0?ooo`03o`00003oool0oooo00P0oooo00?o00000?ooo`3oool07`3oool00ol00000oooo0?ooo`0K
0?ooo`04o`0n]ol0=;?o03>ho`0i_P;o04;50_lRGM82ociWd`?oEW_K0om[PML2oh>Df`;oVjKN0onW
_>P01?nmc>KobN;ZolWRj_o9h^X3om3dj004olongOo7o/_oaok;oh7Wc0;oUO7P00CoY?C^ojcam_n/
lOKo/N_h0onbhoL01OndhOKo/m[dok?Jm?ncf_Co/mOc00?o/M7a00?o/Lo_ojo:k_n_b^h00_n_b>d2
ojg5k0?o[LC[00Go[<?Zoj_1jOn[`NWoZl7Yoj_0j@0j0?ooo`03o`00003oool0oooo00P0oooo00?o
00000?ooo`3oool02`3oool001L0oooo00?o00000?ooo`3oool0;P3oool3oj:jj@03oj2hj_nO^>[o
VkK[00?oVkK[0_nF]>`3oi2ak@;oR:g]0omoZ>h2og>RkP;oIY_^0_mFT^d2odZ8j@;o>7gU00?o<7?P
oaiXfolNJ=/00_lNHMH01OlSGM;o:ec?obMIc_lWFLko=Ec<00;o=E_;00?o@ek8odMQbOm7HLT00omF
ILH2oem[b0?oJfo50_mfMlH3oh60b0?oSX[:1?nKUL`4ojVPcP05okJ/coo2_]Ko`[kFol:ne_o?bMD0
0_oKgmT2on;cf003omonbon>e7/0oooo01P0oooo00?o00000?ooo`3oool0203oool00ol00000oooo
0?ooo`0P0?ooo`03o`00003oool0oooo01/0oooo00Ko03jgo`0d/ol0<kSo03Vno`12aOl3DLh2ob9M
dP;o?VOC0omFNm/2og:AhP?oSZSW0onW_>P3okCDl005olWRj_o@m>Sod?CXom3dj?o?o]d00_o7o//0
1?n7k=goVO7/oiWak?nUlOD2ojc/n@;o[nGi0_nbhoL2ok;LmP;o/m[d0_nado82ok7Al@;o[lc_00Go
[l[^ojk7k?n^anco[/O/ojg5k002ojc3j`?o[<;Z0_n[`NTl0?ooo`03o`00003oool0oooo00P0oooo
00?o00000?ooo`3oool02`3oool001P0oooo0_l0000_0?ooo`?oX[WZ0_nO^>X2oi^fj`03oiZfk?nE
]>goUKC]00;oUKC]0_n?/Nh3ohJ]k`;oOJW`0_m`Xo02of:Ll0;oEY;]0_m3RN/00olhONGo8g;Qob=b
h@02oaiXf`04oaiQe_lAF]?o4E[CoaYHd0;o9eW>0_leFl/01?lgGLco@ek8odMQbOm7HLT2oeIUaP;o
Gf_80omYLlX3ogIgaP?oPH380on>R/X4oi^Ec0;oZJ3>00Co];7Fol:ne_o2_]Ko`[kF0oo?eMd01?oK
gmWoh_?Homonbon[jiXK0?ooo`03o`00003oool0oooo00L0oooo00?o00000?ooo`3oool08@3oool2
o`0001d0oooo00Go036[o`0c/Ol0>[_o04C5o`=AcP02ob9MdP;o>g?M0omFNm/2og:AhP?oSZSW00Co
YkcXokCDl?nde?3o]=C`0onnjo<01Oo@m>So`?[ZokWmeon0fi[oS^g[00;oWNoe0_nWk?T00on/k?Wo
[nGiojoUn@03ok3Mm`05ok;Lm_naeO?o/MGcok7Elonado800_n_c_02ojo<k`;o[/S]0_n^an`00on/
a>_o[<?[ojc3j`02ojc3j`03ojc2jP3oool0oooo03h0oooo00?o00000?ooo`3oool01`3oool00ol0
0000oooo0?ooo`0;0?ooo`006P3oool00ol00000oooo0?ooo`0]0?ooo`03oj:ij_nQ^N[oXKWZ00?o
W[S[0_nJ]^`2oiFdk@04oiBdkOn=/^ooSK;_ohfbk`;oQJk`0omkZ_42ofjUlP;oHYc`0_m@U>l2ocb;
k@04obiniolSL^7o8g;Qo`mWf`;o3EoF0_lAF]<01_lJF=3o9eW>obIIc_lVFLko=E_;ocMMc0;oAf79
0om?Il`2oem[b0;oJG?:0omfO/d4oh60b0?oSX[:0_nKUL`00onTY=Go];7FokBaeP02okBaeP04ol:n
e_o?eMgocmGMoloEg@;of^gP00?of_gGolWl_@3oool0703oool00ol00000oooo0?ooo`070?ooo`03
o`00003oool0oooo0280oooo00?o00000?ooo`3oool06`3oool01Ol0<J_o03>ao`0j^ol0A<Go05SB
00;o6FOK0_lkLmd2oeV=j0?oNZS`1?nI`O<01?nde?3o_^_cokk[lonnjo<2ol3jjP03okWmeol0003o
UNce00?oXN_j00?oYnciojcVn_n/i_X00_n^goP2ok3Mm`;o/=Od0_naeO<2ojo@l@05ojo>l?n^bNko
[/W^ojk9k_n^b>d00on]aN`2ojc4j`;o[<?[@`3oool00ol00000oooo0?ooo`070?ooo`03o`00003o
ool0oooo00X0oooo000K0?ooo`03o`00003oool0oooo02d0oooo0onQ^NX00onN^>_oWKS[oiVgk003
oiVgk0;oU;C]0on=/^l2ohF^l0?oNj[a0_m^YO82oenOlP;oCIOa00Ko?8_]obJ0j?lVP>So9X3XoaQb
hOl?Im/2o`eOeP04o`1Gd_l7EM3o5EK@oaEFd0;o9UW>00Co=eg<oceRcolmH/ooAf790_m?Il`2oeY`
c`?oJG?:0_mfO/d4ohF9d0?oU9KC1?nTY=D2okBaeP?o`LSP00KocmGMom[]h?oJkN3of_gGolWl_On[
jiXN0?ooo`03o`00003oool0oooo00H0oooo00?o00000?ooo`3oool08`3oool00ol00000oooo0?oo
o`0L0?ooo`04o`0eX_l0BL?o04W3o`1HdP;o6FOK0_lhPnT2oeV=j0?oNZS`0_nI`O<3ojCKn`05okk[
loo0n^[o`?[ZoiO`b?n<j?H00_nJj?/2oj7[nP05ojSVnon[goWoZmoioj_OnOn^goP00on_f?H00on`
eoCo[m7bojoAlP02ojo@l@;o[/__0_n^bNh2ojg6k0;o[LG/B@3oool00ol00000oooo0?ooo`060?oo
o`03o`00003oool0oooo00X0oooo000L0?ooo`03o`00003oool0oooo02d0oooo0onP^N/2oifhj`;o
VKO/00?oV;O]oi>ek_nC]Nh00_nC]Nh2ohfcl0?oQ;3a0_mj[?<3offXm004oejRm?m=Uo7oCIOaocR>
k`;o9X3X0_l=M>401Ol1Im[o05gDo`1Me?l0Em;o1eG@00;o5EK@00?o9UW>obQMdOlXGM400_lmH/l2
odmWc0?oFW3?0_mYLlX3ogInc@?oQHW@1?nDU]<3ojBTe@03okBae_o1b>3o`LSP00;o`LSP00GocN?W
om[]h?oJoMOobObmoj;[X`0O0?ooo`03o`00003oool0oooo00H0oooo00?o00000?ooo`3oool0903o
ool00ol00000oooo0?ooo`0M0?ooo`;o04W300Co067@oa1dhOl@M>7o>8?Y0omLXoH4oh;2o0;oY=_k
0_nXl?L00onSmnCoU>GloiCUo002oikSo@;oXnGl0_nXgoX2oj_On@03ojgImon]doCo[M?d00;o[];c
0_n^cO43ojk<l005ojk;kon]ango[LO]ojg7kOn]a^`0C03oool00ol00000oooo0?ooo`060?ooo`03
o`00003oool0oooo00X0oooo000M0?ooo`03o`00003oool0oooo02d0oooo00?oX;W[oj2jjonP^^/0
0onL^>`2oiRgk@;oTkG^00CoTkK_ohbdlOn<]?7oS;Ca0_n4/_<2ogZ_m0?oKZ_f0_mOYoL3odbKm007
ocJClOlPQ>Wo3GCQo`edhOl0J=Oo05c@o`1DcP02o`1BcP03o`1Dd?lCF=7o4eSA00;o:5gA00Co?F;?
odM[dom7Jm?oCfO<0_mJL<l3ofQkd`;oMWk=1?n5RM03oiBFd`;oY:CE0_n_^N03ol78h0;ocN?W00?o
dOWTol;nc?nRjj<08@3oool00ol00000oooo0?ooo`050?ooo`03o`00003oool0oooo02D0oooo00?o
00000?ooo`3oool07P3oool01Ol0C[[o067@oa1dhOl@M>7o=9Ob00?oG:?f0_n2`_`2ohOKoP;oQ>S_
00GoNNCAoi[PoOnJh?goV^3moikSo@02ojGNn`;oZ=Wi0_n[fOP2ojcDm@05ojgCm?n]c_7o[Lkaojg>
lOn^cO400_n]bNl3ojg8kP;o[LO]C`3oool00ol00000oooo0?ooo`050?ooo`03o`00003oool0oooo
00X0oooo000N0?ooo`;o0000;P3oool00onP^^_oWk[[oinjj`03oibik0?oV;S^0_nC]^l3ohbdl@;o
Q;;c0_mj[o@3ofj[mP;oGjOg0om=XOH01olgV_?o7HWZo`Ihh?l6N>3o06SGo`1Ld?l0E<h00_l0D/h0
1?l0E=3o4eSAoa=HdOlXGM42oc1UeP;oAf_C0omJL<l2ofQkd`?oN8WG0on5RM02oiBFd`;oW:SO1?n_
^N001_o1b>3ocN?WolgSiooAnNCo`_k<oj;[Xb<0oooo00?o00000?ooo`3oool0103oool00ol00000
oooo0?ooo`0V0?ooo`;o00008@3oool01?l0JLGo1X;Po`J2h?l^ZNh2oejlo@;oFlgc0_mCcmL2oiKM
oP;oV^3m00GoXMglojKHnOnVf?WoY]SiojSIn@03oj[DmP03ojcDmOn/co;o[<ob00;o[Lka0_n/b^l3
ojg9k`03ojg8kP3oool0oooo0540oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`0:
0?ooo`00803oool00ol00000oooo0?ooo`0]0?ooo`;oWk[[00?oW;W/oibikOnL^Nd00onH^>h3oi>g
l0;oSKKb0_n5]?@3og^bmP;oL:oh0omR[?T2oe2Wn0;o?:;e00?o7i7[o`=mgol0Jm800_l0G<T01_l0
D/Go057<o`1Ac?l0Em7o5UkEobQMd@;o<6GF0_m7Jm<2oeAgf0?oJ7_C0omhRML3ohVHf`CoW:SO0_n_
^N02ok_Dk003olgSiooAnNCo^?cN02D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?oo
o`0X0?ooo`03o`00003oool0oooo02T0oooo0_nNf_`2oj?GnP;oY]Si0_nXdoH2oj[DmP;oZloc00Go
[<obojc;l?n/bo3o[<_`ojc:k`1H0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0
2P3oool00240oooo00?o00000?ooo`3oool0;03oool3oinjk0?oW;W]00?oV;S^oiRikonH^Nl00onD
^?02ohjhlP?oQkKe0_mn]OL3og>cn@;oI[7j0omG[oX00om5ZoSo9I[]obFJk@02o`fAh006o`1N`?l0
DKSo057<o`1Ac?l0Em7o5UkE0_l`IMH3oc]ag004oeAgf?mUQmooIHOOofF7g`CoN8WG0on9V=/2oibX
g`;oY/;]0_nke>`00oo3l?3o^?cNokSlgP0W0?ooo`03o`00003oool0oooo00<0oooo00?o00000?oo
o`3oool0:@3oool00ol00000oooo0?ooo`0Z0?ooo`05oj?Gn_nVd_OoY];gojKBmonXdoH00onZco<0
0on[co?oZl_`oj_;l002ojc;l5/0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0:
0?ooo`008P3oool00ol00000oooo0?ooo`0/0?ooo`04oinjk?nO^ncoWk_/oinkk0;oW;[]0onH^Nl0
0onD^?00oooo0?ooo`0C0?ooo`;o6igT0_l6U=800ol0CKoo05kFo`1NeP02oaeYg0;o>g7L0_m<PnD3
ofF7g`?oNIWU0on@[NX3ojK2k@;o[^3h00?o`o3`okSlg_nho=h0:@3oool00ol00000oooo0?ooo`03
0?ooo`03o`00003oool0oooo02T0oooo00?o00000?ooo`3oool0;03oool2ojS?m0;oZ/oc0_nZbo40
0on[bo00oooo0?ooo`1M0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool02@3oool0
02<0oooo0_l0000]0?ooo`;oWk_/8@3oool00ol0B:Wo05kFo`1NeP02oaeYg004obUjiOlkLMcoC8?U
odb3i@?oIHOO0omiVND3oi2]jP03ojK2kOn^h?So[^3h00;oZ?G_;03oool00ol00000oooo0?ooo`02
0?ooo`03o`00003oool0oooo02X0oooo0_l0000]0?ooo`?oZL_a00?oZ/_a0?ooo`3oool0H03oool0
0ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo00T0oooo000U0?ooo`03o`00003oool0oooo
02X0oooo00?o00000?ooo`3oool08`3oool01?l0GL_o0fgLo`=]g?lYN^D3odb3i@;oHIS^1?mj/OH3
oiG:nP03ojkPn?nXmNooZ?G_02d0oooo00?o00000?ooo`3oool00P3oool00ol00000oooo0?ooo`0/
0?ooo`03o`00003oool0oooo02X0oooo00?o00000?ooo`3oool0H`3oool00ol00000oooo0?ooo`02
0?ooo`03o`00003oool0oooo00T0oooo000V0?ooo`03o`00003oool0oooo02T0oooo00?o00000?oo
o`3oool09P3oool00ol0Jl_o3h;Uo`n2i@02ocfAl0;oEZgj0_mj/OH3og?;o`;oT>Cl<03oool01Ol0
0000oooo0?ooo`3ooooo000002l0oooo00?o00000?ooo`3oool0:@3oool00ol00000oooo0?ooo`1T
0?ooo`05o`00003oool0oooo0?ooool000002`3oool002L0oooo00?o00000?ooo`3oool0:03oool0
0ol00000oooo0?ooo`0Y0?ooo`03o`1nb_lSW>co8ic/00?oEZgj0_mcbol00omJd^L0oooo0?ooo`0a
0?ooo`04o`00003oool0ooooo`000300oooo00?o00000?ooo`3oool0:03oool00ol00000oooo0?oo
o`1U0?ooo`04o`00003oool0ooooo`0000/0oooo000X0?ooo`;o0000:03oool00ol00000oooo0?oo
o`1V0?ooo`03o`00003ooooo00000340oooo0_l0000X0?ooo`03o`00003oool0oooo06H0oooo00?o
00000?ooool000002`3oool002X0oooo00?o00000?ooo`3oool09@3oool00ol00000oooo0?ooo`1V
0?ooo`03o`00003ooooo000003<0oooo00?o00000?ooo`3oool09@3oool00ol00000oooo0?ooo`1V
0?ooo`03o`00003ooooo000000/0oooo000[0?ooo`03o`00003oool0oooo02@0oooo00?o00000?oo
o`3oool0I`3oool00ol00000ooooo`00000c0?ooo`03o`00003oool0oooo02@0oooo00?o00000?oo
o`3oool0I`3oool00ol00000ooooo`00000:0?ooo`00;03oool00ol00000oooo0?ooo`0S0?ooo`03
o`00003oool0oooo06P0oooo0_l0000d0?ooo`03o`00003oool0oooo02<0oooo00?o00000?ooo`3o
ool0J03oool2o`0000X0oooo000]0?ooo`;o00008`3oool00ol00000oooo0?ooo`1W0?ooo`?o0000
=@3oool2o`0002<0oooo00?o00000?ooo`3oool0I`3oool3o`0000X0oooo000_0?ooo`03o`00003o
ool0oooo0200oooo00?o00000?ooo`3oool0H`3oool4o`0003X0oooo00?o00000?ooo`3oool0803o
ool00ol00000oooo0?ooo`1S0?ooo`Co00003@3oool00300oooo00?o00000?ooo`3oool07`3oool0
0ol00000oooo0?ooo`1P0?ooo`?o0000?`3oool00ol00000oooo0?ooo`0O0?ooo`03o`00003oool0
oooo0600oooo0ol0000A0?ooo`00<@3oool00ol00000oooo0?ooo`0N0?ooo`03o`00003oool0oooo
05`0oooo1?l000130?ooo`03o`00003oool0oooo01h0oooo00?o00000?ooo`3oool0G03oool4o`00
01@0oooo000b0?ooo`;o00007P3oool00ol00000oooo0?ooo`1H0?ooo`Co0000B03oool2o`0001h0
oooo00?o00000?ooo`3oool0F03oool4o`0001P0oooo000d0?ooo`03o`00003oool0oooo01/0oooo
00?o00000?ooo`3oool0E03oool4o`0004h0oooo00?o00000?ooo`3oool06`3oool00ol00000oooo
0?ooo`1D0?ooo`Co0000703oool003D0oooo00?o00000?ooo`3oool06P3oool00ol00000oooo0?oo
o`1A0?ooo`?o0000D`3oool00ol00000oooo0?ooo`0J0?ooo`03o`00003oool0oooo0540oooo0ol0
000P0?ooo`00=P3oool00ol00000oooo0?ooo`0I0?ooo`03o`00003oool0oooo04d0oooo1?l0001G
0?ooo`03o`00003oool0oooo01T0oooo00?o00000?ooo`3oool0C@3oool4o`0002<0oooo000g0?oo
o`;o00006@3oool00ol00000oooo0?ooo`190?ooo`Co0000G03oool2o`0001T0oooo00?o00000?oo
o`3oool0B@3oool4o`0002L0oooo000i0?ooo`03o`00003oool0oooo01H0oooo00?o00000?ooo`3o
ool0A@3oool4o`000680oooo00?o00000?ooo`3oool05P3oool00ol00000oooo0?ooo`150?ooo`Co
0000:`3oool003X0oooo00?o00000?ooo`3oool0503oool00ol00000oooo0?ooo`130?ooo`?o0000
I`3oool00ol00000oooo0?ooo`0D0?ooo`03o`00003oool0oooo04<0oooo0ol0000_0?ooo`00>`3o
ool00ol00000oooo0?ooo`0C0?ooo`03o`00003oool0oooo03l0oooo1?l0001[0?ooo`03o`00003o
ool0oooo01<0oooo00?o00000?ooo`3oool0?`3oool4o`000380oooo000l0?ooo`;o00004`3oool0
0ol00000oooo0?ooo`0k0?ooo`Co0000L03oool2o`0001<0oooo00?o00000?ooo`3oool0>`3oool4
o`0003H0oooo000n0?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3oool0=`3oool4o`00
07H0oooo00?o00000?ooo`3oool0403oool00ol00000oooo0?ooo`0g0?ooo`Co0000>P3oool003l0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0c0?ooo`Co0000N`3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo03<0oooo1?l0000n0?ooo`00@03oool00ol00000oooo
0?ooo`0>0?ooo`03o`00003oool0oooo0300oooo0ol000200?ooo`03o`00003oool0oooo00h0oooo
00?o00000?ooo`3oool0<03oool3o`000480oooo00110?ooo`03o`00003oool0oooo00d0oooo00?o
00000?ooo`3oool0;03oool4o`0008@0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?oo
o`0/0?ooo`Co0000A@3oool00480oooo0_l0000=0?ooo`03o`00003oool0oooo02P0oooo1?l00029
0?ooo`;o00003@3oool00ol00000oooo0?ooo`0X0?ooo`Co0000B@3oool004@0oooo00?o00000?oo
o`3oool02P3oool00ol00000oooo0?ooo`0T0?ooo`Co0000S`3oool00ol00000oooo0?ooo`0:0?oo
o`03o`00003oool0oooo02@0oooo1?l0001=0?ooo`00A@3oool00ol00000oooo0?ooo`090?ooo`03
o`00003oool0oooo0240oooo0ol0002D0?ooo`03o`00003oool0oooo00T0oooo00?o00000?ooo`3o
ool08@3oool3o`000540oooo00160?ooo`03o`00003oool0oooo00P0oooo00?o00000?ooo`3oool0
7@3oool4o`0009P0oooo00?o00000?ooo`3oool0203oool00ol00000oooo0?ooo`0M0?ooo`Co0000
E03oool004L0oooo0_l000080?ooo`03o`00003oool0oooo01T0oooo1?l0002M0?ooo`;o0000203o
ool00ol00000oooo0?ooo`0I0?ooo`Co0000F03oool004T0oooo00?o00000?ooo`3oool01@3oool0
0ol00000oooo0?ooo`0E0?ooo`Co0000X`3oool00ol00000oooo0?ooo`050?ooo`03o`00003oool0
oooo01D0oooo1?l0001L0?ooo`00BP3oool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo
0180oooo0ol0002X0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool04P3oool3o`00
0600oooo001;0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool03P3oool4o`000:`0
oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0>0?ooo`Co0000H`3oool004`0oooo
0_l000030?ooo`03o`00003oool0oooo00X0oooo1?l0002a0?ooo`;o00000`3oool00ol00000oooo
0?ooo`0:0?ooo`Co0000I`3oool004h0oooo00Co00000?ooo`3ooooo0000203oool4o`000;L0oooo
00Co00000?ooo`3ooooo0000203oool4o`0006/0oooo001?0?ooo`03o`00003ooooo000000D0oooo
0ol0002l0?ooo`03o`00003ooooo000000D0oooo0ol0001_0?ooo`00D03oool2o`0000030?ooool0
003o000000;o0000`03oool2o`0000030?ooool0003o000000;o0000LP3oool00540oooo0_l00035
0?ooo`;o0000MP3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-1.41844, \
-1.14991, 0.01418, 0.01418}, {{208.5, 389.375}, {315.688, 169}} -> {-4.23892, \
-1.14991, 0.01418, 0.01418}, {{9.625, 190.438}, {154.375, 7.6875}} -> \
{-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, 389.375}, {154.375, \
7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoClassificationRegions[pdf1, pdf2, pr, x, y, classColors, gd, 
        Axes \[Rule] False, Frame \[Rule] True, FS];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.03395 .99505 m
.07294 .9509 L
.11546 .9034 L
.1554 .85937 L
.1938 .81754 L
.23468 .77354 L
.27403 .73168 L
.31586 .6877 L
.35615 .64581 L
.39492 .60594 L
.43616 .56396 L
.47587 .52396 L
.51405 .48587 L
.55471 .4457 L
.59383 .40741 L
.63543 .36707 L
.67551 .32857 L
.71405 .29187 L
.75507 .25314 L
.79455 .21617 L
.83652 .17722 L
.87695 .13999 L
.91585 .10445 L
.95723 .06695 L
.99505 .03292 L
s
.03395 .99505 m
.07294 .99505 L
.11546 .99505 L
.1554 .99505 L
.1938 .99505 L
.23468 .99505 L
.27403 .99505 L
.31586 .99505 L
.35615 .99505 L
.39492 .99505 L
.43616 .99505 L
.47587 .99505 L
.51405 .99505 L
.55471 .99505 L
.59383 .99505 L
.63543 .99505 L
.67551 .99505 L
.71405 .99505 L
.75507 .99505 L
.79455 .99505 L
.83652 .99505 L
.87695 .99505 L
.91585 .99505 L
.95723 .99505 L
.99505 .99505 L
s
1 1 .5 r
.03395 .99505 m
.07294 .9509 L
.11546 .9034 L
.1554 .85937 L
.1938 .81754 L
.23468 .77354 L
.27403 .73168 L
.31586 .6877 L
.35615 .64581 L
.39492 .60594 L
.43616 .56396 L
.47587 .52396 L
.51405 .48587 L
.55471 .4457 L
.59383 .40741 L
.63543 .36707 L
.67551 .32857 L
.71405 .29187 L
.75507 .25314 L
.79455 .21617 L
.83652 .17722 L
.87695 .13999 L
.91585 .10445 L
.95723 .06695 L
.99505 .03292 L
.99505 .99505 L
.95723 .99505 L
.91585 .99505 L
.87695 .99505 L
.83652 .99505 L
.79455 .99505 L
.75507 .99505 L
.71405 .99505 L
.67551 .99505 L
.63543 .99505 L
.59383 .99505 L
.55471 .99505 L
.51405 .99505 L
.47587 .99505 L
.43616 .99505 L
.39492 .99505 L
.35615 .99505 L
.31586 .99505 L
.27403 .99505 L
.23468 .99505 L
.1938 .99505 L
.1554 .99505 L
.11546 .99505 L
.07294 .99505 L
.03395 .99505 L
F
0 g
.03395 .99505 m
.07294 .9509 L
.11546 .9034 L
.1554 .85937 L
.1938 .81754 L
.23468 .77354 L
.27403 .73168 L
.31586 .6877 L
.35615 .64581 L
.39492 .60594 L
.43616 .56396 L
.47587 .52396 L
.51405 .48587 L
.55471 .4457 L
.59383 .40741 L
.63543 .36707 L
.67551 .32857 L
.71405 .29187 L
.75507 .25314 L
.79455 .21617 L
.83652 .17722 L
.87695 .13999 L
.91585 .10445 L
.95723 .06695 L
.99505 .03292 L
s
.03395 .99505 m
.07294 .99505 L
.11546 .99505 L
.1554 .99505 L
.1938 .99505 L
.23468 .99505 L
.27403 .99505 L
.31586 .99505 L
.35615 .99505 L
.39492 .99505 L
.43616 .99505 L
.47587 .99505 L
.51405 .99505 L
.55471 .99505 L
.59383 .99505 L
.63543 .99505 L
.67551 .99505 L
.71405 .99505 L
.75507 .99505 L
.79455 .99505 L
.83652 .99505 L
.87695 .99505 L
.91585 .99505 L
.95723 .99505 L
.99505 .99505 L
s
.00495 .00495 m
.00613 .00495 L
.00741 .00495 L
.00862 .00495 L
.00977 .00495 L
.01101 .00495 L
.0122 .00495 L
.01346 .00495 L
.01467 .00495 L
.01584 .00495 L
.01709 .00495 L
.01829 .00495 L
.01944 .00495 L
.02067 .00495 L
.02185 .00495 L
.0231 .00495 L
.02431 .00495 L
.02547 .00495 L
.02671 .00495 L
.0279 .00495 L
.02917 .00495 L
.03039 .00495 L
.03156 .00495 L
.03281 .00495 L
.03395 .00495 L
s
.00495 .99505 m
.00613 .99505 L
.00741 .99505 L
.00862 .99505 L
.00977 .99505 L
.01101 .99505 L
.0122 .99505 L
.01346 .99505 L
.01467 .99505 L
.01584 .99505 L
.01709 .99505 L
.01829 .99505 L
.01944 .99505 L
.02067 .99505 L
.02185 .99505 L
.0231 .99505 L
.02431 .99505 L
.02547 .99505 L
.02671 .99505 L
.0279 .99505 L
.02917 .99505 L
.03039 .99505 L
.03156 .99505 L
.03281 .99505 L
.03395 .99505 L
s
.5 1 1 r
.00495 .00495 m
.00613 .00495 L
.00741 .00495 L
.00862 .00495 L
.00977 .00495 L
.01101 .00495 L
.0122 .00495 L
.01346 .00495 L
.01467 .00495 L
.01584 .00495 L
.01709 .00495 L
.01829 .00495 L
.01944 .00495 L
.02067 .00495 L
.02185 .00495 L
.0231 .00495 L
.02431 .00495 L
.02547 .00495 L
.02671 .00495 L
.0279 .00495 L
.02917 .00495 L
.03039 .00495 L
.03156 .00495 L
.03281 .00495 L
.03395 .00495 L
.03395 .99505 L
.03281 .99505 L
.03156 .99505 L
.03039 .99505 L
.02917 .99505 L
.0279 .99505 L
.02671 .99505 L
.02547 .99505 L
.02431 .99505 L
.0231 .99505 L
.02185 .99505 L
.02067 .99505 L
.01944 .99505 L
.01829 .99505 L
.01709 .99505 L
.01584 .99505 L
.01467 .99505 L
.01346 .99505 L
.0122 .99505 L
.01101 .99505 L
.00977 .99505 L
.00862 .99505 L
.00741 .99505 L
.00613 .99505 L
.00495 .99505 L
F
0 g
.00495 .00495 m
.00613 .00495 L
.00741 .00495 L
.00862 .00495 L
.00977 .00495 L
.01101 .00495 L
.0122 .00495 L
.01346 .00495 L
.01467 .00495 L
.01584 .00495 L
.01709 .00495 L
.01829 .00495 L
.01944 .00495 L
.02067 .00495 L
.02185 .00495 L
.0231 .00495 L
.02431 .00495 L
.02547 .00495 L
.02671 .00495 L
.0279 .00495 L
.02917 .00495 L
.03039 .00495 L
.03156 .00495 L
.03281 .00495 L
.03395 .00495 L
s
.00495 .99505 m
.00613 .99505 L
.00741 .99505 L
.00862 .99505 L
.00977 .99505 L
.01101 .99505 L
.0122 .99505 L
.01346 .99505 L
.01467 .99505 L
.01584 .99505 L
.01709 .99505 L
.01829 .99505 L
.01944 .99505 L
.02067 .99505 L
.02185 .99505 L
.0231 .99505 L
.02431 .99505 L
.02547 .99505 L
.02671 .99505 L
.0279 .99505 L
.02917 .99505 L
.03039 .99505 L
.03156 .99505 L
.03281 .99505 L
.03395 .99505 L
s
.03395 .00495 m
.07294 .00495 L
.11546 .00495 L
.1554 .00495 L
.1938 .00495 L
.23468 .00495 L
.27403 .00495 L
.31586 .00495 L
.35615 .00495 L
.39492 .00495 L
.43616 .00495 L
.47587 .00495 L
.51405 .00495 L
.55471 .00495 L
.59383 .00495 L
.63543 .00495 L
.67551 .00495 L
.71405 .00495 L
.75507 .00495 L
.79455 .00495 L
.83652 .00495 L
.87695 .00495 L
.91585 .00495 L
.95723 .00495 L
.99505 .00495 L
s
.03395 .99505 m
.07294 .9509 L
.11546 .9034 L
.1554 .85937 L
.1938 .81754 L
.23468 .77354 L
.27403 .73168 L
.31586 .6877 L
.35615 .64581 L
.39492 .60594 L
.43616 .56396 L
.47587 .52396 L
.51405 .48587 L
.55471 .4457 L
.59383 .40741 L
.63543 .36707 L
.67551 .32857 L
.71405 .29187 L
.75507 .25314 L
.79455 .21617 L
.83652 .17722 L
.87695 .13999 L
.91585 .10445 L
.95723 .06695 L
.99505 .03292 L
s
.5 1 1 r
.03395 .00495 m
.07294 .00495 L
.11546 .00495 L
.1554 .00495 L
.1938 .00495 L
.23468 .00495 L
.27403 .00495 L
.31586 .00495 L
.35615 .00495 L
.39492 .00495 L
.43616 .00495 L
.47587 .00495 L
.51405 .00495 L
.55471 .00495 L
.59383 .00495 L
.63543 .00495 L
.67551 .00495 L
.71405 .00495 L
.75507 .00495 L
.79455 .00495 L
.83652 .00495 L
.87695 .00495 L
.91585 .00495 L
.95723 .00495 L
.99505 .00495 L
.99505 .03292 L
.95723 .06695 L
.91585 .10445 L
.87695 .13999 L
.83652 .17722 L
.79455 .21617 L
.75507 .25314 L
.71405 .29187 L
.67551 .32857 L
.63543 .36707 L
.59383 .40741 L
.55471 .4457 L
.51405 .48587 L
.47587 .52396 L
.43616 .56396 L
.39492 .60594 L
.35615 .64581 L
.31586 .6877 L
.27403 .73168 L
.23468 .77354 L
.1938 .81754 L
.1554 .85937 L
.11546 .9034 L
.07294 .9509 L
.03395 .99505 L
F
0 g
.03395 .00495 m
.07294 .00495 L
.11546 .00495 L
.1554 .00495 L
.1938 .00495 L
.23468 .00495 L
.27403 .00495 L
.31586 .00495 L
.35615 .00495 L
.39492 .00495 L
.43616 .00495 L
.47587 .00495 L
.51405 .00495 L
.55471 .00495 L
.59383 .00495 L
.63543 .00495 L
.67551 .00495 L
.71405 .00495 L
.75507 .00495 L
.79455 .00495 L
.83652 .00495 L
.87695 .00495 L
.91585 .00495 L
.95723 .00495 L
.99505 .00495 L
s
.03395 .99505 m
.07294 .9509 L
.11546 .9034 L
.1554 .85937 L
.1938 .81754 L
.23468 .77354 L
.27403 .73168 L
.31586 .6877 L
.35615 .64581 L
.39492 .60594 L
.43616 .56396 L
.47587 .52396 L
.51405 .48587 L
.55471 .4457 L
.59383 .40741 L
.63543 .36707 L
.67551 .32857 L
.71405 .29187 L
.75507 .25314 L
.79455 .21617 L
.83652 .17722 L
.87695 .13999 L
.91585 .10445 L
.95723 .06695 L
.99505 .03292 L
s
1 0 0 r
.02 w
.44081 .70898 Mdot
.95172 .71652 Mdot
.66962 .9822 Mdot
.96441 .83576 Mdot
.79787 .36357 Mdot
.8004 .71449 Mdot
.73514 .66175 Mdot
.77847 .94028 Mdot
.43862 .56594 Mdot
.25006 .90803 Mdot
.36445 .9263 Mdot
.56164 .56768 Mdot
.64559 .53024 Mdot
.79094 .44468 Mdot
.86216 .58501 Mdot
.35727 .8738 Mdot
.82809 .66661 Mdot
.11216 .96082 Mdot
.46859 .73536 Mdot
.82651 .88855 Mdot
.902 .17263 Mdot
.52127 .97074 Mdot
.87073 .44545 Mdot
.70694 .45352 Mdot
.79998 .28585 Mdot
.90447 .72806 Mdot
.40798 .85976 Mdot
.22388 .81044 Mdot
.70424 .99452 Mdot
.44366 .73074 Mdot
.42835 .76586 Mdot
.97229 .71613 Mdot
.97182 .43634 Mdot
.62097 .89687 Mdot
.8851 .72456 Mdot
.4934 .54176 Mdot
.74969 .87772 Mdot
.51616 .82067 Mdot
.72931 .97163 Mdot
.7063 .98337 Mdot
.88759 .82958 Mdot
.81625 .26376 Mdot
.85995 .2901 Mdot
.63821 .61027 Mdot
.3715 .7434 Mdot
.88357 .7276 Mdot
.85039 .91778 Mdot
.94715 .42374 Mdot
.33961 .68795 Mdot
.87525 .81391 Mdot
.82317 .55571 Mdot
.98672 .09126 Mdot
.96783 .63298 Mdot
.83247 .33529 Mdot
.78655 .65407 Mdot
.70473 .6758 Mdot
.45189 .96116 Mdot
.92854 .53698 Mdot
.4505 .78253 Mdot
.64961 .59384 Mdot
.98783 .4943 Mdot
.43764 .64244 Mdot
.28805 .81355 Mdot
.9808 .67633 Mdot
.63793 .72696 Mdot
.19238 .93948 Mdot
.99402 .42124 Mdot
.56504 .71266 Mdot
.93241 .78449 Mdot
.91048 .12377 Mdot
.70821 .48798 Mdot
.9177 .62453 Mdot
.27552 .84059 Mdot
.6346 .80603 Mdot
.99172 .08402 Mdot
.30118 .81422 Mdot
.40611 .67368 Mdot
.76656 .86271 Mdot
.76989 .78364 Mdot
.79017 .29649 Mdot
.96065 .64899 Mdot
.55658 .68788 Mdot
.26036 .86871 Mdot
.39758 .92385 Mdot
.66739 .54247 Mdot
.98651 .25512 Mdot
.32722 .73544 Mdot
.45006 .59887 Mdot
.48447 .94493 Mdot
.97057 .75107 Mdot
.75812 .71792 Mdot
.71516 .87741 Mdot
.36549 .78912 Mdot
.69907 .55262 Mdot
.85803 .34771 Mdot
.45648 .87987 Mdot
.71695 .5518 Mdot
.40224 .8424 Mdot
.86381 .84274 Mdot
.33511 .85324 Mdot
0 0 1 r
.19768 .36014 Mdot
.19224 .39285 Mdot
.1067 .26939 Mdot
.09713 .26739 Mdot
.6583 .12031 Mdot
.299 .22958 Mdot
.135 .06116 Mdot
.10627 .86449 Mdot
.84961 .10548 Mdot
.03717 .94618 Mdot
.45424 .01141 Mdot
.45466 .40641 Mdot
.11379 .82569 Mdot
.04207 .94394 Mdot
.42357 .03804 Mdot
.5214 .14311 Mdot
.45314 .08585 Mdot
.87822 .04554 Mdot
.49998 .2361 Mdot
.8411 .09665 Mdot
.04915 .25188 Mdot
.65854 .24829 Mdot
.62063 .21879 Mdot
.03649 .27583 Mdot
.10418 .08063 Mdot
.53725 .16908 Mdot
.14067 .74528 Mdot
.08906 .08817 Mdot
.2575 .7047 Mdot
.71642 .09877 Mdot
.28281 .14655 Mdot
.72193 .04366 Mdot
.1987 .06333 Mdot
.46938 .33401 Mdot
.60963 .21125 Mdot
.06288 .71606 Mdot
.07466 .60611 Mdot
.30997 .35136 Mdot
.15536 .2247 Mdot
.5886 .25753 Mdot
.05744 .76747 Mdot
.00903 .42988 Mdot
.5347 .10082 Mdot
.24911 .50279 Mdot
.47677 .3798 Mdot
.17174 .03339 Mdot
.02899 .67198 Mdot
.33485 .20993 Mdot
.09167 .59743 Mdot
.23948 .29511 Mdot
.00988 .45655 Mdot
.39137 .41771 Mdot
.22743 .18011 Mdot
.08291 .63619 Mdot
.24626 .23941 Mdot
.33519 .51961 Mdot
.00529 .31463 Mdot
.48969 .2687 Mdot
.35424 .41106 Mdot
.13177 .2359 Mdot
.10744 .31476 Mdot
.1071 .00508 Mdot
.74298 .13748 Mdot
.22327 .57681 Mdot
.35948 .02589 Mdot
.26687 .49052 Mdot
.57366 .1062 Mdot
.03904 .42097 Mdot
.07587 .60186 Mdot
.6196 .3462 Mdot
.59745 .0564 Mdot
.37913 .47464 Mdot
.48294 .48726 Mdot
.0246 .4537 Mdot
.44599 .35246 Mdot
.39184 .34059 Mdot
.34098 .32963 Mdot
.0505 .64806 Mdot
.17387 .43933 Mdot
.34476 .34983 Mdot
.08302 .61474 Mdot
.48687 .07084 Mdot
.15084 .73626 Mdot
.40731 .46304 Mdot
.19846 .53309 Mdot
.04786 .6595 Mdot
.04257 .6257 Mdot
.95459 .01591 Mdot
.31747 .25136 Mdot
.54661 .39048 Mdot
.17158 .51015 Mdot
.18418 .41806 Mdot
.75932 .05206 Mdot
.47819 .30394 Mdot
.02321 .07794 Mdot
.21888 .75574 Mdot
.2541 .56446 Mdot
.29128 .66982 Mdot
.23584 .49148 Mdot
.02191 .73078 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003o7@3oool3
o`00ool0oooo0@3oool00?oo00008?l000010?ooo`007?l00005o`00of3o00000ol00?nKo`000040
oooo00000ol00000Oooo07ooo`0I07ooo`Go003oG`1oool5o`00oh/0Oooo0ol00?l:07ooo`40oooo
0Ol000010?ooo`0000?o000007ooo`1oool06P1oool3o`00of00Oooo1Ol00?n:07ooo`Go003o2@1o
ool10?ooo`7o00000@3oool00003o`00001oool0Oooo07d0Oooo1Ol00?n:07ooo`Go003o2@1oool1
0?ooo`7o00000@3oool00003o`00001oool0Oooo0680Oooo0ol00?lI07ooo`?o003oR`1oool5o`00
o`T0Oooo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1Q07ooo`Go003oY`1oool3o`00o`X0
Oooo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1Q07ooo`Go003o]01oool10?ooo`7o0000
0@3oool00003o`00001oool0Oooo02d0Oooo0ol00?la07ooo`Go003o]01oool10?ooo`7o00000@3o
ool00003o`00001oool0Oooo02`0Oooo1Ol00?la07ooo`?o003o401oool3o`00oj40Oooo0ol00001
0?ooo`0000?o000007ooo`1oool0;01oool5o`00od<0Oooo1Ol00?mA07ooo`?o003oB`1oool01?l0
0000oomo0?ooool000010?ooo`0000?o000007ooo`1oool0;01oool5o`00od<0Oooo1Ol00?m@07oo
o`Go003o:@1oool3o`00oad0Oooo00Go00000?ooO`3oogl0ooooo`0000010?ooo`0000?o000007oo
o`1oool0;@1oool3o`00od@0Oooo1Ol00?m@07ooo`Go003o:01oool5o`00oa/0Oooo00Ko00000?oo
O`3oogl0oomo0?ooool000010?ooo`0000?o000007ooo`1oool0M@1oool3o`00oe40Oooo1Ol00?l7
07ooo`?o003o7P1oool5o`00oaX0Oooo00?o00000?ooO`3oogl00P3oogl10?ooo`7o00000@3oool0
0003o`00001oool0Oooo0:L0Oooo0ol00?lP07ooo`?o003o1`1oool5o`00oad0Oooo1Ol00?lI07oo
o`03o`00003oogl0oomo00<0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0R07ooo`?o
003oP@1oool5o`00obT0Oooo1Ol00?lN07ooo`?o003o6@1oool00ol00000oomo0?ooO`040?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool08@1oool5o`00o`h0Oooo0ol00?m_07ooo`Go003o
:@1oool5o`00ocT0Oooo00?o00000?ooO`3oogl01@3oogl10?ooo`7o00000@3oool00003o`00001o
ool0Oooo0240Oooo1Ol00?l=07ooo`Go003oKP1oool5o`00obX0Oooo0ol00?li07ooo`03o`00003o
ogl0oomo00H0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0Q07ooo`Go003o3@1oool5
o`00odl0Oooo0ol00?lM07ooo`?o003oIP1oool00ol00000oomo0?ooO`070?ooO`40oooo0Ol00001
0?ooo`0000?o000007ooo`1oool08P1oool3o`00o`h0Oooo1Ol00?m>07ooo`Go003oP`1oool2o`00
00X0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0207ooo`?o003o;`1oool3o`00odl0
Oooo1Ol00?n207ooo`03o`00003oogl0oomo00X0oomo0@3oool1o`000040oooo00001?l00000Oooo
07ooo`1oool5o`00oa<0Oooo0ol00?mZ07ooo`Go003oP@1oool00ol00000oomo0?ooO`0;0?ooO`40
oooo0Ol000010?ooo`0000Co000007ooo`1oool0Oooo1Ol00?lB07ooo`Go003oJP1oool3o`00oh40
Oooo00?o00000?ooO`3oogl02P3oogl3ool0007o00000@3oool00004o`00001oool0Oooo07ooo`Go
003o3`1oool8o`00of00Oooo0ol00?n:07ooo`03o`00003oogl0oomo00X0oomo1?oo0001o`000040
oooo00000ol00000Oooo07ooo`0207ooo`?o003o3`1oool9o`00oel0Oooo1Ol00?n807ooo`03o`00
003oogl0oomo00X0oomo1Ooo0001o`000040oooo00000ol00000Oooo07ooo`0D07ooo`So003oH01o
ool5o`00ohL0Oooo00?o00000?ooO`3oogl02P3oogl6ool0007o00000@3oool00003o`00001oool0
Oooo01@0Oooo1Ol00?mS07ooo`Go003oB01oool3o`00ob00Oooo0ol00?lH07ooo`03o`00003oogl0
oomo00/0oomo1_oo0001o`000040oooo00000ol00000Oooo07ooo`0E07ooo`?o003oI@1oool3o`00
oaD0Oooo0ol00?l`07ooo`Go003o7P1oool5o`00oaH0Oooo00?o00000?ooO`3oogl0303oogl5ool0
0040oooo0Ol000010?ooo`0000?o000007ooo`1oool0U01oool5o`00o`L0Oooo0ol00?lU07ooo`Go
003o7P1oool7o`00oa<0Oooo00?o00000?ooO`3oogl03P3oogl3ool000030?ooO`3ooooo00000040
oooo00000ol00000Oooo07ooo`2D07ooo`Go003o1P1oool5o`00ob@0Oooo1Ol00?lN07ooo`So003o
4@1oool00ol00000oomo0?ooO`0C0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0U01o
ool5o`00o`H0Oooo1Ol00?lU07ooo`?o003o801oool7o`00o`l0Oooo0_l0000F0?ooO`40oooo0Ol0
00010?ooo`0000?o000007ooo`1oool0U@1oool3o`00o`L0Oooo1Ol00?m:07ooo`Go003o3P1oool0
0ol00000oomo0?ooO`0F0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0X01oool3o`00
oaD0Oooo0ol00?ld07ooo`?o003o3P1oool00ol00000oomo0?ooO`0G0?ooO`40oooo0Ol000010?oo
o`0000?o000007ooo`1oool0]`1oool5o`00od<0Oooo00Co0000ool00?oo003oo`005`3oogl10?oo
o`7o00000@3oool00003o`00001oool0Oooo0;L0Oooo1Ol00?m207ooo`03o`000?oo003oo`0000?o
o`005P3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0;L0Oooo1Ol00?m107ooo`03o`00
003oogooo`0000Coo`005P3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0;P0Oooo0ol0
0?m107ooo`03o`00003oogl0oomo00Goo`005P3oogl10?ooo`7o00000@3oool00003o`00001oool0
Oooo0=00Oooo0ol00?lX07ooo`03o`00003oogl0oomo0080oomo0ooo000G0?ooO`40oooo0Ol00001
0?ooo`0000?o000007ooo`1oool0c`1oool5o`00obH0Oooo00?o00000?ooO`3oogl07@3oogl10?oo
o`7o00000@3oool00003o`00001oool0Oooo0940Oooo0ol00?lk07ooo`Go003o9@1oool00ol00000
oomo0?ooO`0N0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0C01oool3o`00od40Oooo
1Ol00?lj07ooo`Go003o8`1oool2o`000240oomo0@3oool1o`000040oooo00000ol00000Oooo07oo
o`1;07ooo`Go003o@01oool5o`00oc/0Oooo0ol00?lS07ooo`03o`00003oogl0oomo0240oomo0@3o
ool1o`000040oooo00000ol00000Oooo07ooo`1;07ooo`Go003o@01oool5o`00of00Oooo00?o0000
0?ooO`3oogl08P3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo04/0Oooo1Ol00?m107oo
o`?o003oH01oool00ol00000oomo0?ooO`0S0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1o
ool0C01oool3o`00oj@0Oooo00?o00000?ooO`3oogl0903oogl10?ooo`7o00000@3oool00003o`00
001oool0Oooo0?40Oooo0_l0000W0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0U@1o
ool3o`00oeP0Oooo00?o00000?ooO`3oogl09`3oogl10?ooo`7o00000@3oool00003o`00001oool0
Oooo09@0Oooo1Ol00?mF07ooo`03o`00003oogl0oomo00`0oomo0ooo000I0?ooO`40oooo0Ol00001
0?ooo`0000?o000007ooo`1oool0U01oool5o`00oeD0Oooo00?o00000?ooO`3oogl0303oogl5ool0
01P0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`2D07ooo`Go003oE01oool00ol00000
oomo0?ooO`0=0?ooO`Goo`00603oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo03d0Oooo
0ol00?mE07ooo`?o003oE01oool00ol00000oomo0?ooO`0>0?ooO`Goo`00603oogl10?ooo`7o0000
0@3oool00003o`00001oool0Oooo03`0Oooo1Ol00?nZ07ooo`03o`00003oogl0oomo0100oomo0ooo
000I0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0?01oool5o`00ojT0Oooo00?o0000
0?ooO`3oogl0;@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo03`0Oooo1Ol00?nX07oo
o`03o`00003oogl0oomo02h0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0m07ooo`?o
003oZ01oool00ol00000oomo0?ooO`0_0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0
i`1oool00ol00000oomo0?ooO`0`0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0iP1o
ool00ol00000oomo0?ooO`0a0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0i@1oool0
0ol00000oomo0?ooO`0b0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0F`1oool3o`00
ohH0Oooo00?o00000?ooO`3oogl0<`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo05X0
Oooo1Ol00?m;07ooo`?o003o=P1oool00ol00000oomo0?ooO`0d0?ooO`40oooo0Ol000010?ooo`00
00?o000007ooo`1oool0FP1oool5o`00odX0Oooo1Ol00?ld07ooo`03o`00003oogl0oomo03D0oomo
0@3oool1o`000040oooo00000ol00000Oooo07ooo`1J07ooo`Go003oBP1oool7o`00oc40Oooo00?o
00000?ooO`3oogl0=P3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo02P0Oooo0ol00?l`
07ooo`?o003oB`1oool8o`00obh0Oooo0_l0000i0?ooO`40oooo0Ol000010?ooo`0000?o000007oo
o`1oool09`1oool5o`00ogh0Oooo1ol00?l]07ooo`03o`00003oogl0oomo03T0oomo0@3oool1o`00
0040oooo00000ol00000Oooo07ooo`0W07ooo`Go003o9@1oool3o`00oeP0Oooo1Ol00?l/07ooo`03
o`00003oogl0oomo03X0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0W07ooo`Go003o
901oool5o`00oeP0Oooo0ol00?l/07ooo`03o`00003oogl0oomo03/0oomo0@3oool1o`000040oooo
00000ol00000Oooo07ooo`0Q07ooo`?o003o101oool3o`00obD0Oooo1Ol00?lf07ooo`?o003oC@1o
ool00ol00000oomo0?ooO`0l0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0801oool5
o`00oad0Oooo0ol00?l;07ooo`Go003o=@1oool5o`00od/0Oooo00?o00000?ooO`3oogl0?@3oogl1
0?ooo`7o00000@3oool00003o`00001oool0Oooo0200Oooo1Ol00?lL07ooo`Go003o2`1oool3o`00
ocH0Oooo1Ol00?m:07ooo`03o`00003oogl0oomo03h0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`0P07ooo`Go003o701oool5o`00od@0Oooo1Ol00?lY07ooo`?o003o7@1oool00ol00000
oomo0?ooO`0o0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool02@1oool3o`00oaD0Oooo
0ol00?lM07ooo`Go003o401oool3o`00oc80Oooo0ol00?lY07ooo`Go003o6`1oool00ol00000oomo
0?ooO`100?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0201oool5o`00ocD0Oooo0ol0
0?l@07ooo`Go003oG@1oool5o`00oaX0Oooo00?o00000?ooO`3oogl0?@3oogl3ool000030?ooO`3o
oooo00000040oooo00000ol00000Oooo07ooo`0807ooo`Go003oB01oool5o`00odX0Oooo0ol00?l@
07ooo`Go003o601oool2o`0003l0oomo1Ooo00010?ooo`7o00000@3oool00003o`00001oool0Oooo
00P0Oooo1Ol00?m807ooo`Go003oB@1oool5o`00oa00Oooo0ol00?lH07ooo`03o`00003oogl0oomo
03l0oomo1Ooo00010?ooo`7o00000@3oool00003o`00001oool0Oooo00T0Oooo0ol00?m:07ooo`?o
003oBP1oool5o`00obX0Oooo00?o00000?ooO`3oogl0403oogl3ool002d0oomo1Ooo00010?ooo`7o
00000@3oool00003o`00001oool0Oooo01L0Oooo1_l00?m[07ooo`?o003o601oool5o`00obT0Oooo
00?o00000?ooO`3oogl0403oogl5ool002d0oomo0ooo00000`3oogl0ooooo`0000010?ooo`0000?o
000007ooo`1oool05P1oool8o`00ofT0Oooo1Ol00?lH07ooo`?o003o:@1oool00ol00000oomo0?oo
O`0A0?ooO`Goo`00<@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo00H0Oooo0ol00?l=
07ooo`So003oJ@1oool5o`00od<0Oooo00?o00000?ooO`3oogl04P3oogl5ool00340oomo0@3oool1
o`000040oooo00000ol00000Oooo07ooo`0507ooo`Go003o301oool8o`00ofT0Oooo1Ol00?m207oo
o`03o`00003oogl0oomo01@0oomo0ooo000b0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1o
ool01@1oool5o`00o`d0Oooo1_l00?m[07ooo`?o003o@P1oool00ol00000oomo0?ooO`1:0?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool01@1oool5o`00ol80Oooo00?o00000?ooO`3oogl0
4P3oogl3ool003H0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0607ooo`?o003o`P1o
ool00ol00000oomo0?ooO`0B0?ooO`Goo`003@3oogl3ool002D0oomo0@3oool1o`000040oooo0000
0ol00000Oooo07ooo`3:07ooo`03o`00003oogl0oomo01<0oomo1Ooo000<0?ooO`Goo`00903oogl1
0?ooo`7o00000@3oool00003o`00001oool0Oooo0400Oooo0ol00?n607ooo`03o`00003oogl0oomo
0180oomo1ooo000<0?ooO`Goo`00903oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo03l0
Oooo1Ol00?n407ooo`03o`00003oogl0oomo0180oomo1ooo000=0?ooO`Goo`00903oogl10?ooo`7o
00000@3oool00003o`00001oool0Oooo03l0Oooo1Ol00?m007ooo`?o003o@01oool00ol00000oomo
0?ooO`0C0?ooO`Goo`00403oogl3ool002D0oomo0@3oool1o`000040oooo00000ol00000Oooo07oo
o`0o07ooo`Go003o?`1oool5o`00och0Oooo00?o00000?ooO`3oogl0503oogl5ool003P0oomo0@3o
ool1o`000040oooo00000ol00000Oooo07ooo`1007ooo`?o003o@01oool5o`00ocd0Oooo00?o0000
0?ooO`3oogl05P3oogl3ool003T0oomo0@3oool1o`000040oooo00000ol0003o003o07ooo`0J07oo
o`?o003oIP1oool5o`00oc`0Oooo00?o00000?ooO`3oogl0D`3oogl10?ooo`7o00000@3oool00003
o`000?l00?oo003o01T0Oooo1Ol00?mV07ooo`?o003o?01oool00ol00000oomo0?ooO`1D0?ooO`40
oooo0Ol000010?ooo`0000?o0000o`00ool00?l06@1oool5o`00oj@0Oooo00?o00000?ooO`3oogl0
E@3oogl10?ooo`7o00000@3oool00003o`000?l00?oo003o01T0Oooo1Ol00?nS07ooo`03o`00003o
ogl0oomo05H0oomo0@3oool1o`000040oooo00000ol0003o003o07ooo`0J07ooo`?o003o@01oool3
o`00of00Oooo00?o00000?ooO`3oogl0E`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo
05`0Oooo1Ol00?mN07ooo`03o`00003oogl0oomo05P0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`1L07ooo`Go003o8@1oool3o`00ocT0Oooo00?o00000?ooO`3oogl0:@3oogl3ool002d0
oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1L07ooo`Go003o801oool5o`00ocL0Oooo
00?o00000?ooO`3oogl0:@3oogl5ool002`0oomo0@3oool1o`000040oooo00000ol00000Oooo07oo
o`1M07ooo`?o003o301oool3o`00oa80Oooo1Ol00?lf07ooo`03o`00003oogl0oomo02X0oomo1Ooo
000/0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0J`1oool5o`00oa40Oooo1Ol00?lW
07ooo`?o003o2`1oool00ol00000oomo0?ooO`0[0?ooO`Goo`00;03oogl10?ooo`7o00000@3oool0
0003o`00001oool0Oooo05h0Oooo0ol00?l:07ooo`Go003o4P1oool3o`00obL0Oooo1Ol00?l907oo
o`03o`00003oogl0oomo02d0oomo0ooo00040?ooO`?oo`009P3oogl10?ooo`7o00000@3oool00003
o`00001oool0Oooo05@0Oooo0ol00?l607ooo`Go003o2@1oool5o`00o`/0Oooo0ol00?l^07ooo`Go
003o201oool00ol00000oomo0?ooO`0d0?ooO`Goo`009@3oogl10?ooo`7o00000@3oool00003o`00
001oool0Oooo05<0Oooo1Ol00?l507ooo`Go003o2P1oool3o`00o`/0Oooo1Ol00?l]07ooo`Go003o
1`1oool00ol00000oomo0?ooO`0e0?ooO`Goo`009@3oogl10?ooo`7o00000@3oool00003o`00001o
ool0Oooo03@0Oooo0ol00?lL07ooo`Go003o1@1oool5o`00oaP0Oooo1Ol00?l^07ooo`?o003o1`1o
ool00ol00000oomo0?ooO`0f0?ooO`Goo`009@3oogl10?ooo`7o00000@3oool00003o`00001oool0
Oooo03<0Oooo1Ol00?lK07ooo`Go003o1P1oool3o`00oaT0Oooo1Ol00?lg07ooo`03o`00003oogl0
oomo02L0oomo0ooo000>0?ooO`?oo`009P3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo
03<0Oooo1Ol00?lL07ooo`?o003o901oool3o`00ocL0Oooo00?o00000?ooO`3oogl09`3oogl5ool0
03H0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0c07ooo`Go003oO01oool00ol00000
oomo0?ooO`0X0?ooO`Goo`00=P3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo03@0Oooo
0ol00?mk07ooo`;o0000:`3oogl5ool003H0oomo0@3oool1o`000040oooo00000ol00000Oooo07oo
o`2a07ooo`03o`00003oogl0oomo02`0oomo0ooo000g0?ooO`40oooo0Ol000010?ooo`0000?o0000
07ooo`1oool0Q01oool3o`00obT0Oooo00?o00000?ooO`3oogl0I`3oogl10?ooo`7o00000@3oool0
0003o`00001oool0Oooo08<0Oooo1Ol00?lW07ooo`03o`00003oogl0oomo06P0oomo0@3oool1o`00
0040oooo00000ol00000Oooo07ooo`2307ooo`Go003o9P1oool00ol00000oomo0?ooO`1Y0?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool0P`1oool5o`00oa00Oooo0ol00?lB07ooo`03o`00
003oogl0oomo06X0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0b07ooo`?o003oC`1o
ool3o`00oa00Oooo1Ol00?l@07ooo`03o`00003oogl0oomo06/0oomo0@3oool1o`000040oooo0000
0ol00000Oooo07ooo`0a07ooo`Go003oH@1oool5o`00o`l0Oooo00?o00000?ooO`3oogl0K03oogl1
0?ooo`7o00000@3oool00003o`00001oool0Oooo0340Oooo1Ol00?mQ07ooo`Go003o3P1oool00ol0
0000oomo0?ooO`1]0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0<@1oool5o`00odP0
Oooo0ol00?lG07ooo`?o003o3P1oool00ol00000oomo0?ooO`1^0?ooO`40oooo0Ol000010?ooo`00
00?o000007ooo`1oool0<P1oool3o`00odP0Oooo1Ol00?lV07ooo`03o`00003oogl0oomo06l0oomo
0@3oool1o`000040oooo00000ol00000Oooo07ooo`1Q07ooo`?o003o6@1oool5o`00obD0Oooo00?o
00000?ooO`3oogl0L03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0600Oooo1Ol00?lH
07ooo`Go003o901oool00ol00000oomo0?ooO`1a0?ooO`40oooo0Ol000010?ooo`0000?o000007oo
o`1oool0<01oool3o`00obd0Oooo1Ol00?l707ooo`?o003o3`1oool3o`00ob@0Oooo00?o00000?oo
O`3oogl0LP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo00L0Oooo0ol00?lU07ooo`Go
003o;01oool5o`00o`H0Oooo1Ol00?ld07ooo`03o`00003oogl0oomo06@0oomo0ooo000:0?ooO`?o
o`000Ol000010?ooo`0000?o000007ooo`1oool01P1oool5o`00ob@0Oooo1Ol00?l]07ooo`?o003o
1`1oool5o`00oc<0Oooo00?o00000?ooO`3oogl0I03oogl5ool000P0oomo1?oo0001o`000040oooo
00000ol0003o003oo`00o`0607ooo`Go003o901oool5o`00ocL0Oooo1Ol00?lb07ooo`03o`00003o
ogl0oomo06D0oomo1Ooo00080?ooO`Coo`000Ol000010?ooo`0000Co0000o`00ool00?oo003o1@1o
ool5o`00obD0Oooo0ol00?li07ooo`?o003o<P1oool00ol00000oomo0?ooO`1V0?ooO`Goo`00203o
ogl4ool0007o00000@3oool00004o`000?l00?oo003oo`00o`H0Oooo0ol00?nF07ooo`03o`00003o
ogl0oomo06P0oomo0ooo00040?ooO`?oo`000`3oogl3ool0007o00000@3oool00004o`000?l00?oo
003oo`00ob`0Oooo0ol00?m_07ooo`03o`00003oogl0oomo06l0oomo1Ooo00040?ooO`40oooo0Ol0
00010?ooo`0000?o0000o`00ool00?l0;01oool5o`00ofd0Oooo00?o00000?ooO`3oogl0?@3oogl3
ool00300oomo1Ooo00040?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0;01oool5o`00
of`0Oooo00?o00000?ooO`3oogl0?@3oogl5ool001<0oomo0ooo000I0?ooO`Goo`00103oogl10?oo
o`7o00000@3oool00003o`00001oool0Oooo02`0Oooo1Ol00?m[07ooo`03o`00003oogl0oomo03h0
oomo1Ooo000B0?ooO`Goo`006@3oogl3ool000D0oomo0@3oool1o`000040oooo00000ol00000Oooo
07ooo`0207ooo`?o003o:01oool3o`00of/0Oooo00?o00000?ooO`3oogl0:03oogl3ool001@0oomo
1Ooo000B0?ooO`Goo`008@3oogl10?ooo`7o00000@3oool00003o`000?l00?oo003o00Ko003oU01o
ool00ol00000oomo0?ooO`0X0?ooO`Goo`00503oogl3ool001<0oomo1Ooo000Q0?ooO`40oooo0Ol0
00010?ooo`0000?o0000o`00ool00?l01_l00?nC07ooo`03o`00003oogl0oomo02T0oomo1Ooo000[
0?ooO`?oo`008P3oogl10?ooo`7o00000@3oool00003o`000?l00?oo003o00Ko003oJP1oool3o`00
obD0Oooo00?o00000?ooO`3oogl0:P3oogl5ool00500oomo0@3oool1o`000040oooo00000ol0003o
003oo`00o`05o`00ofX0Oooo1Ol00?lS07ooo`03o`00003oogl0oomo02`0oomo0ooo001A0?ooO`40
oooo0Ol000010?ooo`0000Co0000o`00ool00?oo003oKP1oool5o`00ob80Oooo00?o00000?ooO`3o
ogl0P@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo06P0Oooo0ol00?l407ooo`Go003o
8@1oool00ol00000oomo0?ooO`220?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0I`1o
ool5o`00o`@0Oooo0ol00?lQ07ooo`03o`00003oogl0oomo08<0oomo0@3oool1o`000040oooo0000
0ol00000Oooo07ooo`1W07ooo`Go003o9`1oool00ol00000oomo0?ooO`240?ooO`40oooo0Ol00001
0?ooo`0000?o000007ooo`1oool0I`1oool5o`00obH0Oooo00?o00000?ooO`3oogl0Q@3oogl10?oo
o`7o00000@3oool00003o`00001oool0Oooo06P0Oooo0ol00?lK07ooo`?o003o201oool00ol00000
oomo0?ooO`0b0?ooO`?oo`00D@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo03l0Oooo
0ol00?l607ooo`?o003o>P1oool5o`00o`H0Oooo00?o00000?ooO`3oogl0<P3oogl5ool00500oomo
0@3oool1o`000040oooo00000ol00000Oooo07ooo`0n07ooo`Go003o101oool5o`00ocT0Oooo1Ol0
0?l507ooo`03o`00003oogl0oomo03<0oomo1Ooo001=0?ooO`?oo`000@3oool1o`000040oooo0000
0ol00000Oooo07ooo`0n07ooo`Go003o101oool5o`00ocT0Oooo1Ol00?l407ooo`03o`00003oogl0
oomo03@0oomo1Ooo001<0?ooO`Goo`000Ol000010?ooo`0000?o000007ooo`1oool0?P1oool8o`00
o`0307ooool00?oo003o00?o003o>P1oool3o`00o`@0Oooo00?o00000?ooO`3oogl0=P3oogl3ool0
04d0oomo1Ooo0001o`000040oooo00000ol00000Oooo07ooo`0o07ooo`So003o00@0Ooooo`00ool0
0?oo003o@@1oool00ol00000oomo0?ooO`270?ooO`Goo`000Ol000010?ooo`0000?o000007ooo`1o
ool0;@1oool3o`00oa80Oooo1Ol00?m407ooo`03o`00003oogl0oomo08T0oomo0ooo00010?ooo`7o
00000@3oool00003o`00001oool0Oooo02`0Oooo1Ol00?lA07ooo`Go003o@`1oool00ol00000oomo
0?ooO`2=0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0;01oool5o`00oa80Oooo0ol0
0?m307ooo`03o`00003oogl0oomo08h0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0/
07ooo`Go003o:P1oool3o`00obX0Oooo00?o00000?ooO`3oogl0S`3oogl10?ooo`7o00000@3oool0
0003o`00001oool0Oooo02d0Oooo0ol00?lZ07ooo`Go003o:01oool00ol00000oomo0?ooO`2@0?oo
O`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0FP1oool5o`00obL0Oooo00?o00000?ooO`3o
ogl0T@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo05X0Oooo1Ol00?lV07ooo`03o`00
003oogl0oomo02`0oomo0ooo001S0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0=01o
ool3o`00ob@0Oooo0ol00?lV07ooo`03o`00003oogl0oomo02`0oomo1Ooo001R0?ooO`40oooo0Ol0
00010?ooo`0000?o000007ooo`1oool0<`1oool5o`00od/0Oooo00?o00000?ooO`3oogl0;@3oogl5
ool004h0oomo0ooo000A0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0<`1oool5o`00
odX0Oooo00?o00000?ooO`3oogl0103oogl3ool002L0oomo1Ooo00030?ooO`?oo`00A`3oogl5ool0
0100oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0c07ooo`Go003oB@1oool00ol00000
oomo0?ooO`040?ooO`Goo`009`3oogl3ool000<0oomo1Ooo00160?ooO`Goo`00403oogl10?ooo`7o
00000@3oool00003o`00001oool0Oooo03@0Oooo0ol00?m907ooo`03o`00003oogl0oomo00D0oomo
1Ooo000]0?ooO`Goo`00AP3oogl5ool00100oomo0@3oool1o`000040oooo00000ol00000Oooo07oo
o`1o07ooo`03o`00003oogl0oomo00H0oomo1Ooo000]0?ooO`Goo`001@3oogl3ool00080oomo0ooo
000j0?ooO`?oo`004@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo07h0Oooo00?o0000
0?ooO`3oogl0203oogl3ool002l0oomo0ooo00050?ooO`[oo`006P3oogl3ool00300oomo0@3oool1
o`000040oooo00000ol00000Oooo07ooo`1m07ooo`03o`00003oogl0oomo04<0oomo2_oo000I0?oo
O`Goo`00;`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo07`0Oooo00?o00000?ooO`3o
ogl0A03oogl:ool001T0oomo1Ooo000_0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0
A01oool3o`00oc80Oooo0ooo00180?ooO`?oo`000P3oogl3ool001X0oomo1Ooo000_0?ooO`40oooo
0Ol000010?ooo`0000?o000007ooo`1oool0@`1oool5o`00oc00Oooo1Ooo000O0?ooO`?oo`00B03o
ogl3ool00300oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1307ooo`Go003o<01oool5
ool001h0oomo1Ooo001j0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0>`1oool3o`00
o`D0Oooo1Ol00?l`07ooo`Goo`007P3oogl5ool007X0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`0j07ooo`Go003o1@1oool3o`00oc00Oooo00?o00000?ooOooo00000_oo000O0?ooO`Go
o`00NP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo03X0Oooo1Ol00?lg07ooo`03o`00
003oogl0oomo02<0oomo0ooo001k0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0>P1o
ool5o`00ocH0Oooo00?o00000?ooO`3oogl0N`3oogl3ool002@0oomo0@3oool1o`000040oooo0000
0ol00000Oooo07ooo`0k07ooo`?o003o=P1oool00ol00000oomo0?ooO`1k0?ooO`Goo`008`3oogl1
0?ooo`7o00000@3oool00003o`00001oool0Oooo07<0Oooo00?o00000?ooO`3oogl0@03oogl3ool0
03T0oomo1Ooo000S0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool05P1oool3o`00oeT0
Oooo00?o00000?ooO`3oogl0@03oogl5ool003P0oomo1Ooo000S0?ooO`40oooo0Ol000010?ooo`00
00?o000007ooo`1oool05@1oool5o`00oeL0Oooo00?o00000?ooO`3oogl0203oogl3ool003H0oomo
1Ooo000i0?ooO`?oo`00903oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0140Oooo0ol0
0?l00`1ooooo003oo`00o`03o`00oeH0Oooo00?o00000?ooO`3oogl0203oogl5ool003D0oomo1Ooo
001P0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0401oool:o`00oeD0Oooo00?o0000
0?ooO`3oogl02@3oogl5ool003H0oomo0ooo001Q0?ooO`40oooo0Ol000010?ooo`0000?o000007oo
o`1oool0401oool5o`00o`0407ooool00?oo003oo`00oeD0Oooo00?o00000?ooO`3oogl02P3oogl5
ool00380oomo0ooo001U0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0401oool6o`00
oeP0Oooo00?o00000?ooO`3oogl02`3oogl3ool00380oomo1Ooo001T0?ooO`40oooo0Ol000010?oo
o`0000?o000007ooo`1oool0401oool7o`00oeH0Oooo00?o00000?ooO`3oogl0@@3oogl5ool006@0
oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0A07ooo`Ko003oE@1oool00ol00000oomo
0?ooO`120?ooO`Goo`00I03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo00P0Oooo0ol0
0?l707ooo`Go003oE01oool00ol00000oomo0?ooO`140?ooO`?oo`00C@3oogl3ool001D0oomo0@3o
ool1o`000040oooo00000ol00000Oooo07ooo`0707ooo`Go003o1`1oool3o`00oe@0Oooo00?o0000
0?ooO`3oogl0U03oogl5ool001@0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0707oo
o`Go003oG@1oool00ol00000oomo0?ooO`2E0?ooO`Goo`002`3oogl3ool000H0oomo0@3oool1o`00
0040oooo00000ol00000Oooo07ooo`0707ooo`Go003o1`1oool3o`00oe80Oooo00?o00000?ooO`3o
ogl0UP3oogl5ool000X0oomo1Ooo00050?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0
201oool3o`00o`L0Oooo1Ol00?m@07ooo`03o`00003oogl0oomo09P0oomo0ooo000;0?ooO`Goo`00
1@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0180Oooo1Ol00?m?07ooo`03o`00003o
ogl0oomo0100oomo0ooo002D0?ooO`Goo`001@3oogl10?ooo`7o00000@3oool00003o`00001oool0
Oooo0180Oooo1Ol00?m>07ooo`03o`00003oogl0oomo0100oomo1Ooo002D0?ooO`?oo`001P3oogl1
0?ooo`7o00000@3oool00003o`00001oool0Oooo00X0Oooo0ol00?l607ooo`?o003oCP1oool00ol0
0000oomo0?ooO`0A0?ooO`Goo`00TP3oogl3ool000P0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`0907ooo`Go003oE@1oool00ol00000oomo0?ooO`0B0?ooO`Goo`00H03oogl3ool002h0
oomo1Ooo00070?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool02@1oool5o`00oe@0Oooo
00?o00000?ooO`3oogl0503oogl3ool00600oomo1Ooo000]0?ooO`Goo`001`3oogl10?ooo`7o0000
0@3oool00003o`00001oool0Oooo00T0Oooo1Ol00?mC07ooo`03o`00003oogl0oomo07P0oomo1Ooo
000]0?ooO`Goo`001`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo00P0Oooo1Ol00?mC
07ooo`03o`00003oogl0oomo06/0oomo0ooo000;0?ooO`Goo`00;P3oogl3ool000P0oomo0@3oool1
o`000040oooo00000ol00000Oooo07ooo`0807ooo`Go003oDP1oool00ol00000oomo0?ooO`1[0?oo
O`Goo`002`3oogl3ool000T0oomo0ooo000^0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1o
ool0201oool5o`00od80Oooo0ol00?l<07ooo`03o`00003oogl0oomo06`0oomo1Ooo000F0?ooO`Go
o`00;@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo00@0Oooo0ol00?l207ooo`?o003o
@P1oool5o`00o`X0Oooo00?o00000?ooO`3oogl0403oogl3ool005X0oomo1Ooo000F0?ooO`Goo`00
;@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo00<0Oooo1Ol00?m607ooo`Go003o2@1o
ool00ol00000oomo0?ooO`0@0?ooO`Goo`00D@3oogl3ool000H0oomo0ooo000G0?ooO`Goo`00:03o
ogl3ool00080oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0307ooo`Go003oAP1oool5
o`00o`P0Oooo00?o00000?ooO`3oogl04@3oogl5ool00500oomo1Ooo000P0?ooO`?oo`00:03oogl5
ool000030?ooO`3ooooo00000040oooo00000ol00000Oooo07ooo`0307ooo`Go003oA`1oool3o`00
o`P0Oooo00?o00000?ooO`3oogl04P3oogl5ool00500oomo1Ooo001;0?ooO`Goo`0000<0oomo0?oo
ool000000@3oool00003o`00001oool0Oooo00@0Oooo0ol00?mB07ooo`04o`00003oogl0oomo0?oo
O`?oo`00403oogl3ool002P0oomo0ooo000V0?ooO`Goo`00B`3oogl5ool000030?ooO`3ooooo0000
0040oooo00000ol00000Oooo07ooo`1H07ooo`04o`00003oogl0oomo0?ooO`Goo`00>@3oogl5ool0
02H0oomo0ooo001=0?ooO`?oo`000P3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo05L0
Oooo00?o00000?ooO`3oogl00P3oogl5ool003T0oomo1Ooo001k0?ooO`40oooo0Ol000010?ooo`00
00?o000007ooo`1oool0EP1oool00ol00000oomo0?ooO`030?ooO`Goo`00>@3oogl5ool007/0oomo
0@3oool1o`000040oooo00000ol00000Oooo07ooo`1E07ooo`03o`00003oogl0oomo00D0oomo0ooo
000k0?ooO`?oo`00O03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo04D0Oooo0ol00?l<
07ooo`03o`00003oogl0oomo0<<0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1407oo
o`Go003o2P1oool00ol00000oomo0?ooO`0T0?ooO`?oo`00W@3oogl10?ooo`7o00000@3oool00003
o`00001oool0Oooo04@0Oooo1Ol00?l907ooo`03o`00003oogl0oomo02@0oomo1Ooo000O0?ooO`?o
o`00NP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo00d0Oooo0ol00?ld07ooo`Go003o
201oool00ol00000oomo0?ooO`0U0?ooO`Goo`007P3oogl5ool00400oomo0ooo000X0?ooO`?oo`00
0`3oogl3ool000D0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0<07ooo`Go003o=01o
ool3o`00o`P0Oooo00?o00000?ooO`3oogl09P3oogl5ool001h0oomo1Ooo000d0?ooO`?oo`00203o
ogl5ool002H0oomo1Ooo00000`3oogooo`00ool00003ool000@0oomo0@3oool1o`000040oooo0000
0ol00000Oooo07ooo`0<07ooo`Go003o?P1oool00ol00000oomo0?ooO`0X0?ooO`?oo`007`3oogl5
ool003<0oomo1Ooo00070?ooO`Goo`009P3oogl5ool000030?ooOooo003oo`0000?oo`00103oogl1
0?ooo`7o00000@3oool00003o`00001oool0Oooo00`0Oooo1Ol00?lm07ooo`03o`00003oogl0oomo
04`0oomo0ooo000B0?ooO`?oo`007`3oogl5ool000L0oomo1Ooo000D0?ooO`?oo`003`3oogl5ool0
00030?ooOooo003oo`0000?oo`00103oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0080
Oooo0ol00?l807ooo`?o003o?@1oool00ol00000oomo0?ooO`0[0?ooO`?oo`00<`3oogl5ool001h0
oomo1Ooo00080?ooO`?oo`00503oogl5ool00080oomo0ooo000:0?ooO`?oo`000`3oogl3ool000D0
oomo0@3oool1o`000040oooo00001?l00000Oooo07ooo`1oool5o`00odH0Oooo00?o00000?ooO`3o
ogl0:`3oogl5ool00380oomo1Ooo000O0?ooO`?oo`00803oogl5ool000030?ooOooo003oo`0000?o
o`005`3oogl10?ooo`7o00000@3oool00004o`00001oool0Oooo07ooo`Go003o8@1oool3o`00ob40
Oooo00?o00000?ooO`3oogl02`3oogl3ool001h0oomo1Ooo00030?ooO`?oo`00;03oogl5ool00480
oomo1Ooo00000`3oogooo`00ool00003ool001L0oomo0@3oool1o`000040oooo00001?l00000Oooo
07ooo`1oool5o`00ob00Oooo1Ol00?lP07ooo`03o`00003oogl0oomo00X0oomo1Ooo000M0?ooO`Go
o`000P3oogl5ool002`0oomo0ooo00130?ooO`Goo`0000<0oomoool00?oo00000ooo000G0?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool00P1oool3o`00ob40Oooo1Ol00?lO07ooo`03o`00
003oogl0oomo00/0oomo1Ooo00090?ooO`?oo`004P3oogl3ool000<0oomo1Ooo001c0?ooO`?oo`00
0`3oogl3ool001P0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0T07ooo`Oo003o7P1o
ool00ol00000oomo0?ooO`0<0?ooO`Goo`00203oogl5ool001L0oomo1Ooo002D0?ooO`40oooo0Ol0
00010?ooo`0000?o000007ooo`1oool08`1oool7o`00oah0Oooo00?o00000?ooO`3oogl03P3oogl3
ool000T0oomo1Ooo000H0?ooO`?oo`00S@3oogl3ool000D0oomo0@3oool1o`000040oooo00000ol0
0000Oooo07ooo`0S07ooo`Go003o7`1oool00ol00000oomo0?ooO`0K0?ooO`Goo`00Y`3oogl5ool0
00@0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0S07ooo`Go003o4P1oool3o`00o`T0
Oooo00?o00000?ooO`3oogl07@3oogl3ool00:P0oomo1Ooo00040?ooO`40oooo0Ol000010?ooo`00
00?o000007ooo`1oool0901oool3o`00oa80Oooo1Ol00?l707ooo`03o`00003oogl0oomo0<T0oomo
1Ooo00040?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0>@1oool5o`00o`H0Oooo00?o
00000?ooO`3oogl0b`3oogl3ool000D0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0<
07ooo`?o003o:P1oool5o`00o`D0Oooo00?o00000?ooO`3oogl0<03oogl3ool00:40oomo0@3oool1
o`000040oooo00000ol00000Oooo07ooo`0;07ooo`Go003o:P1oool3o`00o`D0Oooo00?o00000?oo
O`3oogl0<03oogl5ool00:00oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0;07ooo`Go
003o<@1oool00ol00000oomo0?ooO`0a0?ooO`Goo`00X03oogl10?ooo`7o00000@3oool00003o`00
001oool0Oooo00/0Oooo1Ol00?l`07ooo`03o`00003oogl0oomo0380oomo1Ooo002P0?ooO`40oooo
0Ol000010?ooo`0000?o000007ooo`1oool0301oool3o`00oc40Oooo00?o00000?ooO`3oogl0<`3o
ogl3ool000<0oomo0ooo002K0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0?`1oool0
0ol00000oomo0?ooO`0i0?ooO`Goo`00F03oogl3ool002`0oomo0ooo000@0?ooO`40oooo0Ol00001
0?ooo`0000?o000007ooo`1oool0?P1oool00ol00000oomo0?ooO`0S0?ooO`?oo`00503oogl5ool0
05L0oomo1Ooo000Z0?ooO`Goo`003`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo03d0
Oooo00?o00000?ooO`3oogl08`3oogl5ool001<0oomo1Ooo001G0?ooO`Goo`00:P3oogl5ool000l0
oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0l07ooo`03o`00003oogl0oomo02@0oomo
1Ooo000D0?ooO`?oo`00F03oogl5ool002X0oomo1Ooo000?0?ooO`40oooo0Ol000010?ooo`0000?o
000007ooo`1oool0>`1oool00ol00000oomo0?ooO`0U0?ooO`Goo`00L03oogl3ool002`0oomo0ooo
000@0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0>P1oool00ol00000oomo0?ooO`0W
0?ooO`?oo`00/`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo03T0Oooo00?o00000?oo
O`3oogl0M@3oogl3ool006H0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0h07ooo`04
o`00003oogl0oomo0?ooO`?oo`00L@3oogl5ool006D0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`0g07ooo`04o`00003oogl0oomo0?ooO`Goo`003P3oogl3ool000040?ooOooo003oo`00
ool005/0oomo1Ooo00110?ooO`?oo`008@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo
03H0Oooo00?o00000?ooO`3oogl00P3oogl5ool000d0oomo2Ooo001J0?ooO`Goo`00@03oogl5ool0
0200oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0e07ooo`03o`00003oogl0oomo00<0
oomo1Ooo000=0?ooO`Woo`00>@3oogl3ool001l0oomo0ooo00110?ooO`Goo`00803oogl10?ooo`7o
00000@3oool00003o`00001oool0Oooo03@0Oooo00?o00000?ooO`3oogl01@3oogl3ool000h0oomo
2Ooo000h0?ooO`Goo`00HP3oogl5ool00200oomo0@3oool1o`000040oooo00000ol00000Oooo07oo
o`0L07ooo`?o003o5@1oool00ol00000oomo0?ooO`0G0?ooO`?oo`0000@0oomoool00?oo003oo`00
>@3oogl5ool006<0oomo0ooo000Q0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool06`1o
ool5o`00oa<0Oooo00?o00000?ooO`3oogl0F03oogl5ool006L0oomo0ooo000M0?ooO`40oooo0Ol0
00010?ooo`0000?o000007ooo`1oool06`1oool5o`00oa80Oooo00?o00000?ooO`3oogl0FP3oogl3
ool006L0oomo1Ooo000L0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool06`1oool5o`00
oa40Oooo00?o00000?ooO`3oogl0a@3oogl5ool00180oomo0ooo00070?ooO`40oooo0Ol000010?oo
o`0000?o000007ooo`1oool0701oool3o`00oa40Oooo00?o00000?ooO`3oogl05`3oogl3ool00280
oomo0ooo00270?ooO`Goo`004@3oogl5ool000H0oomo0@3oool1o`000040oooo00000ol00000Oooo
07ooo`0_07ooo`03o`00003oogl0oomo01L0oomo1Ooo000P0?ooO`Goo`00P03oogl3ool000@0oomo
0ooo000B0?ooO`Goo`001P3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo02h0Oooo00?o
00000?ooO`3oogl0603oogl5ool00200oomo1Ooo001o0?ooO`Goo`00603oogl5ool000H0oomo0@3o
ool1o`000040oooo00000ol00000Oooo07ooo`0]07ooo`03o`00003oogl0oomo01T0oomo1Ooo000P
0?ooO`Goo`00O`3oogl5ool001T0oomo0ooo00070?ooO`40oooo0Ol000010?ooo`0000?o000007oo
o`1oool0;01oool00ol00000oomo0?ooO`0K0?ooO`?oo`003P3oogl3ool00140oomo0ooo00200?oo
O`Goo`008`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo02/0Oooo00?o00000?ooO`3o
ogl0;03oogl5ool00140oomo0ooo00200?ooO`?oo`00903oogl10?ooo`7o00000@3oool00003o`00
001oool0Oooo02X0Oooo00?o00000?ooO`3oogl0;@3oogl5ool00100oomo1Ooo001S0?ooO`?oo`00
@03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo01X0Oooo0ol00?l<07ooo`03o`00003o
ogl0oomo02h0oomo1Ooo000@0?ooO`Goo`00HP3oogl5ool003l0oomo0@3oool1o`000040oooo0000
0ol00000Oooo07ooo`0I07ooo`Go003o2`1oool00ol00000oomo0?ooO`0J0?ooO`?oo`004P3oogl3
ool00140oomo1Ooo001R0?ooO`Goo`00?`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo
01T0Oooo1Ol00?l:07ooo`03o`00003oogl0oomo01X0oomo1Ooo000H0?ooO`?oo`002`3oogl3ool0
06<0oomo1Ooo000o0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool06@1oool5o`00o`T0
Oooo00?o00000?ooO`3oogl06`3oogl5ool001L0oomo1Ooo001a0?ooO`?oo`00@03oogl10?ooo`7o
00000@3oool00003o`00001oool0Oooo01X0Oooo0ol00?l907ooo`03o`00003oogl0oomo01`0oomo
1Ooo000G0?ooO`Goo`00603oogl3ool004L0oomo0ooo00070?ooO`?oo`00A@3oogl10?ooo`7o0000
0@3oool00003o`00001oool0Oooo02D0Oooo00?o00000?ooO`3oogl07P3oogl3ool001P0oomo1Ooo
000G0?ooO`Goo`00A@3oogl5ool000D0oomo1Ooo00140?ooO`40oooo0Ol000010?ooo`0000?o0000
07ooo`1oool0901oool00ol00000oomo0?ooO`0k0?ooO`?oo`00603oogl5ool004D0oomo1Ooo0005
0?ooO`Goo`00A03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo02<0Oooo00?o00000?oo
O`3oogl0E`3oogl5ool004D0oomo1Ooo00050?ooO`Goo`004P3oogl3ool002l0oomo0@3oool1o`00
0040oooo00000ol00000Oooo07ooo`0S07ooo`03o`00003oogl0oomo05P0oomo0ooo00170?ooO`?o
o`001`3oogl3ool00180oomo1Ooo000^0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0
8P1oool00ol00000oomo0?ooO`280?ooO`?oo`00=`3oogl5ool002h0oomo0@3oool1o`000040oooo
00000ol00000Oooo07ooo`0Q07ooo`03o`00003oogl0oomo08P0oomo1Ooo000f0?ooO`Goo`00;P3o
ogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0200Oooo00?o00000?ooO`3oogl0R@3oogl5
ool003L0oomo0ooo000_0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool07`1oool00ol0
0000oomo0?ooO`0Q0?ooO`?oo`00IP3oogl5ool006T0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`0N07ooo`03o`00003oogl0oomo0240oomo1Ooo001V0?ooO`?oo`00JP3oogl10?ooo`7o
00000@3oool00003o`00001oool0Oooo01h0Oooo00?o00000?ooO`3oogl08@3oogl5ool00=<0oomo
0@3oool1o`000040oooo00000ol00000Oooo07ooo`0M07ooo`03o`00003oogl0oomo0280oomo1Ooo
002X0?ooO`?oo`00:03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo01`0Oooo00?o0000
0?ooO`3oogl0903oogl3ool00:P0oomo1Ooo000W0?ooO`40oooo0Ol000010?ooo`0000?o000007oo
o`1oool06`1oool00ol00000oomo0?ooO`1?0?ooO`?oo`00OP3oogl5ool002L0oomo0@3oool1o`00
0040oooo00000ol00000Oooo07ooo`0J07ooo`03o`00003oogl0oomo04L0oomo0ooo00050?ooO`Go
o`00O@3oogl5ool002L0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0I07ooo`03o`00
003oogl0oomo04L0oomo1Ooo00040?ooO`Goo`00OP3oogl3ool002P0oomo0@3oool1o`000040oooo
00000ol00000Oooo07ooo`0H07ooo`03o`00003oogl0oomo04P0oomo1Ooo00040?ooO`Goo`00Z@3o
ogl10?ooo`7o00000@3oool00003o`00001oool0Oooo01L0Oooo00?o00000?ooO`3oogl0603oogl3
ool002h0oomo1Ooo00050?ooO`?oo`00ZP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo
01H0Oooo00?o00000?ooO`3oogl0603oogl5ool002h0oomo0ooo001d0?ooO`?oo`00?03oogl10?oo
o`7o00000@3oool00003o`00001oool0Oooo00H0Oooo1?l00?l;07ooo`03o`00003oogl0oomo01T0
oomo1Ooo001@0?ooO`?oo`00D@3oogl5ool003/0oomo0@3oool1o`000040oooo00000ol00000Oooo
07ooo`0507ooo`Ko003o2@1oool00ol00000oomo0?ooO`0J0?ooO`Goo`00C`3oogl5ool00500oomo
1Ooo000k0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool01@1oool6o`00o`P0Oooo00?o
00000?ooO`3oogl0703oogl3ool00500oomo1Ooo001@0?ooO`Goo`00>`3oogl10?ooo`7o00000@3o
ool00003o`00001oool0Oooo00D0Oooo1_l00?l707ooo`03o`00003oogl0oomo0700oomo1Ooo001A
0?ooO`?oo`00?03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo00H0Oooo1?l00?l807oo
o`03o`00003oogl0oomo00H0oomo0ooo001X0?ooO`?oo`00T@3oogl10?ooo`7o00000@3oool00003
o`00001oool0Oooo0140Oooo00?o00000?ooO`3oogl01P3oogl5ool005h0oomo0ooo002J0?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool0401oool00ol00000oomo0?ooO`070?ooO`Goo`00
G@3oogl5ool009T0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0?07ooo`03o`00003o
ogl0oomo00P0oomo1Ooo001M0?ooO`Goo`00403oogl3ool008H0oomo0@3oool1o`000040oooo0000
0ol00000Oooo07ooo`0>07ooo`03o`00003oogl0oomo00X0oomo0ooo001N0?ooO`Goo`003`3oogl5
ool003L0oomo0ooo001;0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool03@1oool00ol0
0000oomo0?ooO`1]0?ooO`?oo`00403oogl5ool003H0oomo1Ooo001:0?ooO`40oooo0Ol000010?oo
o`0000?o000007ooo`1oool0301oool00ol00000oomo0?ooO`210?ooO`Goo`00=P3oogl5ool004X0
oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0;07ooo`03o`00003oogl0oomo08<0oomo
0ooo000W0?ooO`?oo`00203oogl3ool00080oomo1Ooo001:0?ooO`40oooo0Ol000010?ooo`0000?o
000007ooo`1oool02P1oool00ol00000oomo0?ooO`2]0?ooO`Goo`001P3oogl5ool00080oomo0ooo
001;0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool02@1oool00ol00000oomo0?ooO`2^
0?ooO`Goo`001P3oogl5ool00500oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0807oo
o`03o`00003oogl0oomo0:l0oomo1Ooo00060?ooO`Goo`00D03oogl10?ooo`7o00000@3oool00003
o`00001oool0Oooo00L0Oooo00?o00000?ooO`3oogl0/@3oogl3ool000L0oomo1?oo001A0?ooO`40
oooo0Ol000010?ooo`00aol00005ool005?o00000@3oool00?oo00008?l000010?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-6, -5.00005*^-6, \
0.00348436, 0.00348436}, {{0, 287}, {287, 0}} -> {-1.01089, -1.01089, \
0.00704453, 0.00704453}, {{0, 287}, {287, 0}} -> {-1.01089, -1.01089, \
0.00704453, 0.00704453}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example C: Gaussian distributions", "Section"],

Cell[CellGroupData[{

Cell["Generate data from two Gaussian classes", "Subsection"],

Cell[CellGroupData[{

Cell["Definition of Gaussians", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Mu]1\  = \ { .3,  .3};\)\), "\n", 
    \(\(\[CapitalSigma]1\  = \  .07 {{1. , \(- .5\)}, {\(- .5\),  \
.5}};\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(\[Mu]2\  = \ {\(- .5\), \(- .5\)};\)\), "\n", 
    \(\(\[CapitalSigma]2\  = \  .04 {{1. , \(- .5\)}, {\(- .5\),  \
.5}};\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 100;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = \ 
        Table[rgBounded[{\[Mu]1, \ \[CapitalSigma]1}, pr], {n1}];\)\), "\n", 
    \(\(data2\  = \ 
        Table[rgBounded[{\[Mu]2, \ \[CapitalSigma]2}, 
            pr], {n2}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, gd2, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.55676 .77478 Mdot
.69324 .76004 Mdot
.80651 .59963 Mdot
.67742 .72344 Mdot
.68349 .68561 Mdot
.6236 .74701 Mdot
.65643 .67193 Mdot
.58307 .5608 Mdot
.5293 .6864 Mdot
.65901 .66775 Mdot
.56166 .67502 Mdot
.59273 .67935 Mdot
.67422 .72241 Mdot
.64316 .69539 Mdot
.66342 .65434 Mdot
.81891 .58245 Mdot
.85002 .5272 Mdot
.64933 .64285 Mdot
.63797 .56244 Mdot
.72284 .6246 Mdot
.68774 .67438 Mdot
.67935 .60815 Mdot
.62783 .64837 Mdot
.63848 .66001 Mdot
.53592 .74599 Mdot
.84379 .61737 Mdot
.66455 .70688 Mdot
.73316 .62295 Mdot
.63211 .75769 Mdot
.62184 .70497 Mdot
.59747 .67047 Mdot
.6502 .66762 Mdot
.52138 .81673 Mdot
.38316 .87114 Mdot
.59115 .5631 Mdot
.94571 .5486 Mdot
.60136 .73023 Mdot
.71728 .6042 Mdot
.94133 .58313 Mdot
.8838 .43988 Mdot
.69075 .58066 Mdot
.47923 .67369 Mdot
.62459 .70122 Mdot
.53018 .78476 Mdot
.76887 .57231 Mdot
.84614 .51692 Mdot
.65087 .73158 Mdot
.83044 .49027 Mdot
.72797 .59202 Mdot
.82319 .52875 Mdot
.70748 .58152 Mdot
.84587 .58067 Mdot
.98376 .52223 Mdot
.1587 .97177 Mdot
.63853 .53974 Mdot
.74522 .6337 Mdot
.67767 .56762 Mdot
.75715 .66654 Mdot
.39887 .74406 Mdot
.65031 .77292 Mdot
.49344 .66956 Mdot
.61838 .70507 Mdot
.64349 .58219 Mdot
.64158 .728 Mdot
.60883 .59889 Mdot
.70148 .55064 Mdot
.83988 .52999 Mdot
.62934 .62075 Mdot
.69287 .67215 Mdot
.49681 .69294 Mdot
.56408 .63866 Mdot
.56887 .78254 Mdot
.85922 .57118 Mdot
.80285 .57533 Mdot
.61461 .72099 Mdot
.64863 .63891 Mdot
.42682 .68759 Mdot
.79747 .54691 Mdot
.58937 .64708 Mdot
.66063 .70405 Mdot
.35935 .83956 Mdot
.53494 .59905 Mdot
.70629 .54521 Mdot
.60852 .69324 Mdot
.67342 .52372 Mdot
.54288 .77401 Mdot
.50785 .73208 Mdot
.50463 .66882 Mdot
.77359 .52647 Mdot
.61837 .64151 Mdot
.64836 .71348 Mdot
.46526 .79031 Mdot
.69289 .55757 Mdot
.64567 .50819 Mdot
.95133 .48829 Mdot
.46931 .81207 Mdot
.66136 .67984 Mdot
.72914 .6186 Mdot
.65209 .54406 Mdot
.48686 .76072 Mdot
0 0 1 r
.28869 .21599 Mdot
.27905 .18211 Mdot
.13672 .25346 Mdot
.13693 .37485 Mdot
.28868 .19825 Mdot
.10183 .25907 Mdot
.2985 .18952 Mdot
.25843 .27046 Mdot
.20228 .25681 Mdot
.33473 .31044 Mdot
.32388 .17207 Mdot
.25046 .20996 Mdot
.34554 .20108 Mdot
.42917 .1414 Mdot
.16469 .34957 Mdot
.23118 .256 Mdot
.16485 .28625 Mdot
.30886 .22002 Mdot
.16762 .15652 Mdot
.25214 .23443 Mdot
.39891 .22744 Mdot
.19809 .26867 Mdot
.26021 .2906 Mdot
.32762 .12785 Mdot
.24954 .3728 Mdot
.26565 .23738 Mdot
.3206 .19101 Mdot
.23139 .41358 Mdot
.07459 .45413 Mdot
.21125 .3652 Mdot
.04275 .20578 Mdot
.08664 .31604 Mdot
.18984 .27116 Mdot
.38693 .17474 Mdot
.15452 .39662 Mdot
.34313 .27904 Mdot
.4767 .19632 Mdot
.1963 .35775 Mdot
.31123 .2871 Mdot
.41261 .19535 Mdot
.31788 .15578 Mdot
.26556 .13498 Mdot
.3206 .2818 Mdot
.26196 .27529 Mdot
.16993 .25939 Mdot
.25435 .3129 Mdot
.22563 .32623 Mdot
.39645 .22435 Mdot
.28407 .30012 Mdot
.25617 .24143 Mdot
.48719 .15723 Mdot
.24627 .21723 Mdot
.2758 .28045 Mdot
.34203 .2014 Mdot
.39132 .19762 Mdot
.25447 .21901 Mdot
.19451 .29681 Mdot
.10771 .32152 Mdot
.34631 .26056 Mdot
.06927 .39426 Mdot
.28716 .22649 Mdot
.12267 .24024 Mdot
.29382 .21614 Mdot
.3637 .15727 Mdot
.18597 .19798 Mdot
.32256 .19923 Mdot
.2176 .24266 Mdot
.27206 .2602 Mdot
.27894 .40062 Mdot
.19782 .23581 Mdot
.32564 .24225 Mdot
.25912 .30985 Mdot
.28871 .2688 Mdot
.137 .26679 Mdot
.24367 .28345 Mdot
.24374 .24308 Mdot
.17967 .26772 Mdot
.28146 .15447 Mdot
.29522 .22011 Mdot
.13476 .26358 Mdot
.23364 .2392 Mdot
.32651 .20264 Mdot
.10665 .28038 Mdot
.20781 .19675 Mdot
.15057 .33353 Mdot
.2856 .24843 Mdot
.31395 .25839 Mdot
.22864 .27283 Mdot
.21712 .26377 Mdot
.19637 .25262 Mdot
.08248 .24607 Mdot
.38278 .19393 Mdot
.4309 .13012 Mdot
.33049 .23157 Mdot
.22998 .27816 Mdot
.16775 .34381 Mdot
.36978 .17072 Mdot
.24491 .31364 Mdot
.2724 .21271 Mdot
.32053 .17654 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`00000P00000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`00
00<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703o
ool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?oo
o`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040
oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3o
oolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`00
0000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`40
00000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?oo
o`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool0
00030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0
oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003o
ool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@000001
0?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0
oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool1
00000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo
00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL
0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000
oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`400000
0@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o
0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0F@3oool3o`00oa/0oooo0ol00?nQ0?oo
o`4000000@3oool000030000003oool0oooo05P0oooo1Ol00?lI0?ooo`Go003oX03oool100000040
oooo00000`000000oooo0?ooo`170?ooo`?o003o3P3oool5o`00oaT0oooo1Ol00?nP0?ooo`400000
0@3oool000030000003oool0oooo04H0oooo1Ol00?l=0?ooo`Go003o6@3oool5o`00oj00oooo0@00
00010?ooo`0000<000000?ooo`3oool0AP3oool5o`00o`h0oooo0ol00?lI0?ooo`Go003oX@3oool1
00000040oooo00000`000000oooo0?ooo`160?ooo`Go003o:P3oool5o`00oj40oooo0@0000010?oo
o`0000<000000?ooo`3oool0A`3oool3o`00ob/0oooo1Ol00?nQ0?ooo`4000000@3oool000030000
003oool0oooo04`0oooo0ol00?lW0?ooo`?o003oXP3oool100000040oooo00000`000000oooo0?oo
o`0[0?ooo`?o003o7@3oool5o`00o`H0oooo0ol00?l;0?ooo`?o003o803oool3o`00oi40oooo0@00
00010?ooo`0000<000000?ooo`3oool0:P3oool5o`00oa`0oooo1Ol00?l50?ooo`Go003o2@3oool5
o`00oah0oooo1Ol00?n@0?ooo`4000000@3oool000030000003oool0oooo02X0oooo1Ol00?lL0?oo
o`Go003o1@3oool5o`00o`T0oooo1Ol00?lN0?ooo`Go003oT03oool100000040oooo00000`000000
oooo0?ooo`0Z0?ooo`Go003o7@3oool3o`00o`H0oooo1Ol00?l90?ooo`Go003o7P3oool5o`00oi00
oooo0@0000010?ooo`0000<000000?ooo`3oool0:`3oool3o`00obP0oooo1Ol00?l90?ooo`Co003o
7`3oool3o`00oi40oooo0@0000010?ooo`0000<000000?ooo`3oool0E`3oool5o`00o`P0oooo1Ol0
0?l0103ooooo003oo`00ool00?n^0?ooo`4000000@3oool000030000003oool0oooo05L0oooo1Ol0
0?l80?ooo`[o003o[@3oool100000040oooo00000`000000oooo0?ooo`1;0?ooo`?o003o203oool6
o`00o`P0oooo2_l00?n]0?ooo`4000000@3oool000030000003oool0oooo04X0oooo1Ol00?l70?oo
o`Go003o2P3oool3o`00o`030?ooool00?oo003o00?o003o[@3oool100000040oooo00000`000000
oooo0?ooo`1:0?ooo`Go003o0P3oool3o`00o`80oooo1Ol00?l?0?ooo`?o003o[P3oool100000040
oooo00000`000000oooo0?ooo`1:0?ooo`Go003o00<0ooooo`00ool00?l00ol00?l20?ooo`?o003o
`@3oool100000040oooo00000`000000oooo0?ooo`0g0?ooo`?o003o4@3oool3o`00o`80oooo1Ol0
0?l00`3ooooo003oo`00o`03o`00o`h0oooo0ol00?l60?ooo`?o003o3`3oool3o`00oi@0oooo0@00
00010?ooo`0000<000000?ooo`3oool0<@3oool3o`00o`80oooo1Ol00?lC0?ooo`Oo003o00<0oooo
o`00ool00?l00ol00?l=0?ooo`Oo003o0P3oool5o`00o`d0oooo1Ol00?nC0?ooo`4000000@3oool0
00030000003oool0oooo0300oooo1Ol00?l00`3ooooo003oo`00o`03o`00oa80oooo1ol00?l20?oo
o`Ko003o00<0ooooo`00ool00?l00_l00?l70?ooo`So003o00<0ooooo`00ool00?l00ol00?l=0?oo
o`Go003oT`3oool100000040oooo00000`000000oooo0?ooo`080?ooo`?o003o9@3oool5o`00o`03
0?ooool00?oo003o00?o003o4P3oool5o`00o`D0oooo2ol00?l60?ooo`So003o00<0ooooo`00ool0
0?l00ol00?l=0?ooo`Go003oT`3oool100000040oooo00000`000000oooo0?ooo`070?ooo`Go003o
903oool5o`00o`80oooo0ol00?l90?ooo`?o003o1`3oool5o`00o`D0oooo2ol00?l70?ooo`Oo003o
0P3oool3o`00o`l0oooo0ol00?nD0?ooo`4000000@3oool000030000003oool0oooo00L0oooo1Ol0
0?lU0?ooo`?o003o3P3oool5o`00o`80oooo0ol00?l20?ooo`?o003o1`3oool:o`00o`X0oooo0ol0
0?n/0?ooo`4000000@3oool000030000003oool0oooo00L0oooo1Ol00?lf0?ooo`Go003o00<0oooo
o`00ool00?l00ol00?l00`3ooooo003oo`00o`03o`00o`H0oooo0ol00?l00`3ooooo003oo`00o`02
o`00okX0oooo0@0000010?ooo`0000<000000?ooo`3oool0203oool3o`00ocH0oooo1_l00?l00`3o
oooo003oo`00o`0=o`00ol@0oooo0@0000010?ooo`0000<000000?ooo`3oool0@@3ooolGo`00oaD0
oooo0ol00?n[0?ooo`4000000@3oool000030000003oool0oooo0440oooo1ol00?l01@3ooooo003o
o`00ool00?l0oooo00_o003o503oool5o`00ojX0oooo0@0000010?ooo`0000<000000?ooo`3oool0
@P3oool6o`00o`D0oooo2ol00?l20?ooo`?o003o3`3oool6o`00ojT0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0A03oool3o`00o`H0oooo1_l00?l0103ooooo003oo`00ool00?l20?ooo`Go003o
3P3oool6o`00ojT0oooo0@0000010?ooo`0000<000000?ooo`3oool0=03oool3o`00o``0oooo1ol0
0?l30?ooo`Go003o1`3oool5o`00o`l0oooo1Ol00?nY0?ooo`4000000@3oool000030000003oool0
oooo01h0oooo0ol00?lB0?ooo`Go003o1P3oool3o`00o`80oooo2?l00?l30?ooo`?o003o203oool5
o`00oa00oooo0ol00?nZ0?ooo`4000000@3oool000030000003oool0oooo01<0oooo0ol00?l70?oo
o`Go003o4@3oool5o`00o`80oooo4Ol00?l=0?ooo`Go003o_P3oool100000040oooo00000`000000
oooo0?ooo`0B0?ooo`Go003o1P3oool5o`00oa40oooo1Ol00?l00`3ooooo003oo`00o`0@o`00o`80
oooo0ol00?l80?ooo`Go003o_P3oool100000040oooo00000`000000oooo0?ooo`0B0?ooo`Go003o
1P3oool5o`00oa80oooo0ol00?l20?oooa7o003o0P3oool5o`00o`L0oooo1Ol00?nn0?ooo`400000
0@3oool000030000003oool0oooo0180oooo1Ol00?l70?ooo`?o003o0P3oool3o`00o`d0oooo1Ol0
0?l00`3ooooo003oo`00o`0=o`00o`@0oooo1Ol00?l80?ooo`?o003o_`3oool100000040oooo0000
0`000000oooo0?ooo`0C0?ooo`?o003o0`3oool3o`00o`H0oooo1Ol00?l50?ooo`?o003o103oool5
o`00o`80oooo2_l00?l80?ooo`Go003o103oool3o`00ol<0oooo0@0000010?ooo`0000<000000?oo
o`3oool0603oool5o`00o`D0oooo1Ol00?l40?ooo`Go003o0`3oool6o`00o`@0oooo1Ol00?l70?oo
o`?o003o00@0ooooo`00ool00?oo003o103oool5o`00o`H0oooo0ol00?ni0?ooo`4000000@3oool0
00030000003oool0oooo01P0oooo1Ol00?l50?ooo`Go003o103oool5o`00o`@0oooo1Ol00?l00`3o
oooo003oo`00o`06o`00o`H0oooo1Ol00?l70?ooo`Go003o1@3oool5o`00okP0oooo0@0000010?oo
o`0000<000000?ooo`3oool0603oool5o`00o`@0oooo1_l00?l40?ooo`Oo003o0P3oool=o`00o`@0
oooo2?l00?l0103ooooo003oo`00ool00?l30?ooo`Go003o1@3oool5o`00okP0oooo0@0000010?oo
o`0000<000000?ooo`3oool06@3oool3o`00o`D0oooo1_l00?l50?ooo`co003o00<0ooooo`00ool0
0?l01Ol00?l40?ooo`ko003o0`3oool3o`00o`H0oooo1Ol00?nh0?ooo`4000000@3oool000030000
003oool0oooo0240oooo1_l00?l70?ooo`[o003o00<0ooooo`00ool00?l01_l00?l30?ooo`So003o
00<0ooooo`00ool00?l00ol00?l=0?ooo`?o003o^@3oool100000040oooo00000`000000oooo0?oo
o`0J0?ooo`?o003o1@3oool4o`00o`P0oooo2_l00?l20?ooo`Oo003o0`3oool>o`00o``0oooo0ol0
0?nj0?ooo`4000000@3oool000030000003oool0oooo01T0oooo1Ol00?lA0?ooo`So003o1@3oool8
o`00o`030?ooool00?oo003o00[o003o1P3oool3o`00o`<0oooo1Ol00?ni0?ooo`4000000@3oool0
00030000003oool0oooo01T0oooo1Ol00?l=0?ooo`?o003o103oool3o`00o`L0oooo4_l00?l70?oo
o`Ko003o0P3oool5o`00okT0oooo0@0000010?ooo`0000<000000?ooo`3oool06@3oool5o`00o``0
oooo1Ol00?l=0?ooo`Wo003o00<0ooooo`00ool00?l01_l00?l60?ooo`Oo003o0P3oool5o`00okT0
oooo0@0000010?ooo`0000<000000?ooo`3oool06P3oool3o`00o`d0oooo1Ol00?l>0?oooa3o003o
1`3oool7o`00o`<0oooo0ol00?nj0?ooo`4000000@3oool000030000003oool0oooo02X0oooo1Ol0
0?l40?ooo`?o003o2`3oool3o`00o`030?ooool00?oo003o00?o003o2P3oool6o`00ol40oooo0@00
00010?ooo`0000<000000?ooo`3oool0:`3oool3o`00o`@0oooo1Ol00?l>0?ooo`Go003o0`3oool3
o`00o`D0oooo0ol00?o30?ooo`4000000@3oool000030000003oool0oooo0380oooo1Ol00?l?0?oo
o`?o003o0`3oool5o`00olX0oooo0@0000010?ooo`0000<000000?ooo`3oool0<P3oool5o`00oaD0
oooo1Ol00?o:0?ooo`4000000@3oool000030000003oool0oooo03<0oooo0ol00?l@0?ooo`?o003o
0`3oool5o`00o`X0oooo0ol00?nm0?ooo`4000000@3oool000030000003oool0oooo0480oooo2?l0
0?l30?ooo`?o003o2P3oool5o`00ok`0oooo0@0000010?ooo`0000<000000?ooo`3oool0503oool3
o`00obX0oooo2Ol00?l@0?ooo`Go003o_03oool100000040oooo00000`000000oooo0?ooo`0C0?oo
o`Go003o0P3oool3o`00ob@0oooo2Ol00?l@0?ooo`Go003o_03oool100000040oooo00000`000000
oooo0?ooo`0C0?ooo`Go003o00<0ooooo`00ool00?l00ol00?lN0?ooo`?o003o0P3oool8o`00oa80
oooo0ol00?nm0?ooo`4000000@3oool000030000003oool0oooo01<0oooo1Ol00?l00`3ooooo003o
o`00o`03o`00oad0oooo1Ol00?l20?ooo`Go003oe03oool100000040oooo00000`000000oooo0?oo
o`0D0?ooo`?o003o0P3oool5o`00oad0oooo1Ol00?oK0?ooo`4000000@3oool000030000003oool0
oooo01X0oooo0ol00?l90?ooo`?o003o4P3oool5o`00om/0oooo0@0000010?ooo`0000<000000?oo
o`3oool09@3oool5o`00oa80oooo0ol00?oL0?ooo`4000000@3oool000030000003oool0oooo02D0
oooo1Ol00?oa0?ooo`4000000@3oool000030000003oool0oooo02D0oooo1Ol00?l0103ooooo003o
o`00ool00?o]0?ooo`4000000@3oool000030000003oool0oooo02H0oooo0ol00?l00`3ooooo003o
o`00o`03o`00on`0oooo0@0000010?ooo`0000<000000?ooo`3oool0:P3oool5o`00on`0oooo0@00
00010?ooo`0000<000000?ooo`3oool0:P3oool5o`00on`0oooo0@0000010?ooo`0000<000000?oo
o`3oool0:P3oool5o`00o`D0oooo0ol00?oT0?ooo`4000000@3oool000030000003oool0oooo02/0
oooo0ol00?l50?ooo`Go003oh`3oool100000040oooo00000`000000oooo0?ooo`0c0?ooo`So003o
h03oool100000040oooo00000`000000oooo0?ooo`0c0?ooo`Wo003og`3oool100000040oooo0000
0`000000oooo0?ooo`0S0?ooo`?o003o3P3oool8o`00o`L0oooo0ol00?oE0?ooo`4000000@3oool0
00030000003oool0oooo0280oooo1Ol00?l@0?ooo`Go003o1P3oool5o`00om@0oooo0@0000010?oo
o`0000<000000?ooo`3oool08P3oool5o`00oa40oooo0ol00?l70?ooo`Go003oe03oool100000040
oooo00000`000000oooo0?ooo`0R0?ooo`Go003o6`3oool5o`00om@0oooo0@0000010?ooo`0000<0
00000?ooo`3oool08`3oool3o`00oad0oooo0ol00?oE0?ooo`4000000@3oool000030000003oool0
oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`0?0?ooo`?o003oo`3oool:0?oo
o`4000000@3oool000030000003oool0oooo00h0oooo1Ol00?lE0?ooo`?o003ol03oool100000040
oooo00000`000000oooo0?ooo`0>0?ooo`Go003o503oool5o`00oal0oooo0ol00?o=0?ooo`400000
0@3oool000030000003oool0oooo00h0oooo1Ol00?lD0?ooo`Go003o7P3oool5o`00ol`0oooo0@00
00010?ooo`0000<000000?ooo`3oool03`3oool3o`00oaD0oooo1Ol00?lN0?ooo`Go003oc03oool1
00000040oooo00000`000000oooo0?ooo`0X0?ooo`?o003o7`3oool5o`00ol`0oooo0@0000010?oo
o`0000<000000?ooo`3oool0?P3oool3o`00o`X0oooo0ol00?o=0?ooo`4000000@3oool000030000
003oool0oooo03d0oooo1Ol00?oI0?ooo`4000000@3oool000030000003oool0oooo03d0oooo1Ol0
0?oI0?ooo`4000000@3oool000030000003oool0oooo03d0oooo1Ol00?oI0?ooo`4000000@3oool0
00030000003oool0oooo03h0oooo0ol00?oJ0?ooo`4000000@3oool000030000003oool0oooo0?l0
oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0n@3oool3ool001l0oooo0@0000010?ooo`0000<000000?ooo`3oool0n03oool5
ool001h0oooo0@0000010?ooo`0000<000000?ooo`3oool0n03oool5ool001h0oooo0@0000010?oo
o`0000<000000?ooo`3oool0n03oool5ool001h0oooo0@0000010?ooo`0000<000000?ooo`3oool0
4@3oool3o`00onD0oooo0ooo000O0?ooo`4000000@3oool000030000003oool0oooo0100oooo1Ol0
0?oo0?ooo`L0oooo0@0000010?ooo`0000<000000?ooo`3oool0403oool5o`00ool0oooo1`3oool1
00000040oooo00000`000000oooo0?ooo`0@0?ooo`Go003oo`3oool70?ooo`4000000@3oool00003
0000003oool0oooo0140oooo0ol00?oo0?ooo`P0oooo0@0000010?ooo`0000<000000?ooo`3oool0
o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo0000
0`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?oo
o`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo
0?ooo`3o0?ooo`d0oooo0ooo000<0?ooo`4000000@3oool000030000003oool0oooo0>T0oooo0ooo
000O0?ooo`Goo`002`3oool100000040oooo00000`000000oooo0?ooo`3X0?ooo`Goo`007P3oool5
ool000/0oooo0@0000010?ooo`0000<000000?ooo`3oool0j03oool5ool001h0oooo1Ooo000;0?oo
o`4000000@3oool000030000003oool0oooo0>P0oooo1Ooo000O0?ooo`?oo`00303oool100000040
oooo00000`000000oooo0?ooo`3Y0?ooo`?oo`00;`3oool100000040oooo00000`000000oooo0?oo
o`2d0?ooo`?oo`00I03oool100000040oooo00000`000000oooo0?ooo`2c0?ooo`Goo`00H`3oool1
00000040oooo00000`000000oooo0?ooo`2c0?ooo`Goo`00=P3oool3ool002X0oooo0@0000010?oo
o`0000<000000?ooo`3oool0/`3oool5ool003D0oooo1Ooo000Y0?ooo`4000000@3oool000030000
003oool0oooo0;@0oooo0ooo00050?ooo`?oo`00;P3oool5ool002<0oooo0ooo00030?ooo`400000
0@3oool000030000003oool0oooo0;/0oooo1Ooo000I0?ooo`?oo`004@3oool5ool00280oooo1Ooo
00020?ooo`4000000@3oool000030000003oool0oooo0;/0oooo1Ooo000H0?ooo`Goo`002P3oool3
ool00080oooo1ooo000Q0?ooo`Goo`000P3oool100000040oooo00000`000000oooo0?ooo`2k0?oo
o`Goo`00603oool5ool000T0oooo3Ooo000Q0?ooo`Goo`000P3oool100000040oooo00000`000000
oooo0?ooo`2l0?ooo`?oo`006@3oool5ool000T0oooo3Ooo000R0?ooo`?oo`000`3oool100000040
oooo00000`000000oooo0?ooo`2b0?ooo`?oo`00903oool3ool000X0oooo3?oo000Y0?ooo`400000
0@3oool000030000003oool0oooo0;40oooo2?oo000=0?ooo`?oo`007P3oool3ool00080oooo0ooo
000/0?ooo`4000000@3oool000030000003oool0oooo0;40oooo2Ooo000;0?ooo`Goo`005P3oool3
ool002L0oooo0ooo000>0?ooo`4000000@3oool000030000003oool0oooo0;40oooo2Ooo000:0?oo
o`Koo`005@3oool5ool002D0oooo1Ooo000=0?ooo`4000000@3oool000030000003oool0oooo0;80
oooo2?oo00090?ooo`Ooo`005@3oool5ool002D0oooo1Ooo000=0?ooo`4000000@3oool000030000
003oool0oooo0;H0oooo0ooo00090?ooo`Ooo`005P3oool5ool002D0oooo1Ooo000=0?ooo`400000
0@3oool000030000003oool0oooo0:<0oooo1Ooo000:0?ooo`?oo`00303oool7ool001P0oooo0ooo
000W0?ooo`?oo`003P3oool100000040oooo00000`000000oooo0?ooo`2R0?ooo`Ooo`00203oool5
ool000/0oooo1_oo001D0?ooo`4000000@3oool000030000003oool0oooo0:80oooo1ooo00080?oo
o`Goo`00203oool8ool005D0oooo0@0000010?ooo`0000<000000?ooo`3oool0XP3oool7ool000P0
oooo1Ooo00070?ooo`Soo`004`3oool3ool001L0oooo0ooo000V0?ooo`4000000@3oool000030000
003oool0oooo0:<0oooo1Ooo000:0?ooo`?oo`00203oool5ool001D0oooo1Ooo00060?ooo`?oo`00
303oool5ool002D0oooo0@0000010?ooo`0000<000000?ooo`3oool0_@3oool7ool001<0oooo1Ooo
00050?ooo`Goo`00203oool8ool002D0oooo0@0000010?ooo`0000<000000?ooo`3oool0]03oool3
ool000L0oooo1ooo0000103oooooo`00ool00?oo000>0?ooo`Goo`001@3oool8ool000@0oooo2Ooo
000C0?ooo`?oo`003`3oool100000040oooo00000`000000oooo0?ooo`2c0?ooo`Goo`00203oool:
ool000h0oooo0ooo00060?ooo`Woo`000`3oool8ool001<0oooo1Ooo000>0?ooo`4000000@3oool0
00030000003oool0oooo0;<0oooo1Ooo00080?ooo`[oo`00603oool8ool000<0oooo1Ooo000F0?oo
o`Goo`003P3oool100000040oooo00000`000000oooo0?ooo`2c0?ooo`Goo`002@3oool3ool00003
0?oooooo003oo`0000?oo`000P3oool3ool001H0oooo1Ooo00040?ooo`?oo`005`3oool5ool000h0
oooo0@0000010?ooo`0000<000000?ooo`3oool0]03oool3ool000l0oooo0ooo00020?ooo`Goo`00
5P3oool3ool00200oooo0ooo000?0?ooo`4000000@3oool000030000003oool0oooo09D0oooo0ooo
000B0?ooo`?oo`007P3oool5ool001<0oooo0ooo000e0?ooo`4000000@3oool000030000003oool0
oooo09@0oooo1Ooo000@0?ooo`Goo`006`3oool7ool00180oooo1Ooo000d0?ooo`4000000@3oool0
00030000003oool0oooo09@0oooo1Ooo000@0?ooo`Goo`00403oool3ool000L0oooo1ooo000C0?oo
o`Goo`00=03oool100000040oooo00000`000000oooo0?ooo`2D0?ooo`Goo`00403oool5ool000l0
oooo1Ooo00060?ooo`Goo`005@3oool5ool003@0oooo0@0000010?ooo`0000<000000?ooo`3oool0
U@3oool3ool00180oooo0ooo000@0?ooo`Goo`001P3oool5ool001H0oooo0ooo000e0?ooo`400000
0@3oool000030000003oool0oooo0;d0oooo1Ooo00070?ooo`Koo`007P3oool3ool002/0oooo0@00
00010?ooo`0000<000000?ooo`3oool0/03oool3ool000/0oooo0ooo000:0?ooo`Goo`00703oool5
ool002X0oooo0@0000010?ooo`0000<000000?ooo`3oool0[`3oool5ool001L0oooo1_oo000K0?oo
o`Goo`00:P3oool100000040oooo00000`000000oooo0?ooo`2_0?ooo`Goo`005P3oool8ool001X0
oooo1Ooo000Z0?ooo`4000000@3oool000030000003oool0oooo0:l0oooo1Ooo000F0?ooo`Soo`00
6`3oool3ool002/0oooo0@0000010?ooo`0000<000000?ooo`3oool0/03oool3ool001L0oooo2_oo
00170?ooo`4000000@3oool000030000003oool0oooo09d0oooo0ooo000E0?ooo`?oo`004`3oool:
ool004H0oooo0@0000010?ooo`0000<000000?ooo`3oool0W03oool5ool000`0oooo0ooo00040?oo
o`Goo`005`3oool5ool004H0oooo0@0000010?ooo`0000<000000?ooo`3oool0W03oool5ool000<0
oooo0ooo00050?ooo`Goo`000`3oool6ool001H0oooo1Ooo00160?ooo`4000000@3oool000030000
003oool0oooo09`0oooo1Ooo00020?ooo`Goo`00103oool6ool00080oooo1_oo000G0?ooo`?oo`00
A`3oool100000040oooo00000`000000oooo0?ooo`2M0?ooo`?oo`000`3oool5ool000@0oooo1ooo
00020?ooo`Goo`00H@3oool100000040oooo00000`000000oooo0?ooo`2S0?ooo`Goo`001@3oool6
ool000<0oooo0ooo0000103oooooo`00ool00?oo001N0?ooo`4000000@3oool000030000003oool0
oooo0:@0oooo0ooo00070?ooo`Ooo`00103oool5ool005d0oooo0@0000010?ooo`0000<000000?oo
o`3oool0[`3oool7ool000<0oooo1Ooo001M0?ooo`4000000@3oool000030000003oool0oooo0;40
oooo3Ooo000F0?ooo`?oo`00A03oool100000040oooo00000`000000oooo0?ooo`290?ooo`Koo`00
603oool3ool000L0oooo3?oo000F0?ooo`Goo`00@`3oool100000040oooo00000`000000oooo0?oo
o`250?ooo`_oo`00303oool3ool000L0oooo1Ooo00070?ooo`[oo`001@3oool4ool000h0oooo1Ooo
00130?ooo`4000000@3oool000030000003oool0oooo08@0oooo3?oo000;0?ooo`Goo`001P3oool5
ool000X0oooo1ooo00040?ooo`Koo`003@3oool5ool004<0oooo0@0000010?ooo`0000<000000?oo
o`3oool0Q03oool<ool000/0oooo1Ooo00050?ooo`Koo`002`3oool6ool000@0oooo1_oo000>0?oo
o`?oo`00A03oool100000040oooo00000`000000oooo0?ooo`240?ooo`_oo`00303oool5ool000@0
oooo1_oo000=0?ooo`Koo`000`3oool6ool005D0oooo0@0000010?ooo`0000<000000?ooo`3oool0
MP3oool3ool000`0oooo0ooo000;0?ooo`?oo`001P3oool3ool000D0oooo1Ooo000?0?ooo`Goo`00
0P3oool6ool005H0oooo0@0000010?ooo`0000<000000?ooo`3oool0M@3oool5ool001P0oooo1Ooo
000=0?ooo`Goo`003`3oool5ool000030?oooooo003oo`0000?oo`00F03oool100000040oooo0000
0`000000oooo0?ooo`1e0?ooo`Goo`00403oool3ool000D0oooo1Ooo000>0?ooo`?oo`000P3oool3
ool000L0oooo0ooo00020?ooo`?oo`000P3oool5ool005P0oooo0@0000010?ooo`0000<000000?oo
o`3oool0M@3oool5ool000l0oooo1Ooo00040?ooo`Goo`004P3oool5ool000D0oooo1Ooo00060?oo
o`Goo`00F03oool100000040oooo00000`000000oooo0?ooo`1f0?ooo`?oo`00403oool5ool000D0
oooo0ooo000C0?ooo`Soo`000P3oool5ool000L0oooo0ooo001I0?ooo`4000000@3oool000030000
003oool0oooo08T0oooo1Ooo000K0?ooo`Woo`0000<0ooooool00?oo00000ooo0000103oooooo`00
ool00?oo001O0?ooo`4000000@3oool000030000003oool0oooo08X0oooo0ooo000M0?ooo`Soo`00
0P3oool3ool000030?oooooo003oo`0000?oo`00GP3oool100000040oooo00000`000000oooo0?oo
o`2/0?ooo`Koo`001P3oool6ool005d0oooo0@0000010?ooo`0000<000000?ooo`3oool0[03oool6
ool000<0oooo2Ooo001M0?ooo`4000000@3oool000030000003oool0oooo0:d0oooo1?oo00030?oo
o`[oo`00G@3oool100000040oooo00000`000000oooo0?ooo`2/0?ooo`?oo`001@3oool5ool00003
0?oooooo003oo`0000Goo`00FP3oool100000040oooo00000`000000oooo0?ooo`2[0?ooo`Goo`00
103oool5ool000<0oooo1_oo001I0?ooo`4000000@3oool000030000003oool0oooo0:P0oooo2?oo
00030?ooo`Goo`00103oool6ool005T0oooo0@0000010?ooo`0000<000000?ooo`3oool0S@3oool3
ool001L0oooo2Ooo00020?ooo`Ooo`000`3oool6ool005T0oooo0@0000010?ooo`0000<000000?oo
o`3oool0S03oool5ool001H0oooo2?oo00030?ooo`Soo`000`3oool4ool005X0oooo0@0000010?oo
o`0000<000000?ooo`3oool0S03oool5ool001H0oooo1Ooo00060?ooo`Soo`00H@3oool100000040
oooo00000`000000oooo0?ooo`1^0?ooo`?oo`006`3oool5ool001L0oooo0ooo00080?ooo`Ooo`00
H@3oool100000040oooo00000`000000oooo0?ooo`1]0?ooo`Goo`006`3oool3ool000D0oooo0ooo
000F0?ooo`?oo`001@3oool3ool00680oooo0@0000010?ooo`0000<000000?ooo`3oool0K@3oool5
ool00280oooo1Ooo000D0?ooo`Goo`00J@3oool100000040oooo00000`000000oooo0?ooo`1]0?oo
o`Goo`008P3oool5ool001@0oooo1Ooo001Y0?ooo`4000000@3oool000030000003oool0oooo06h0
oooo0ooo000S0?ooo`Goo`00503oool7ool006L0oooo0@0000010?ooo`0000<000000?ooo`3oool0
Q`3oool3ool000/0oooo0ooo000F0?ooo`Ooo`003@3oool3ool005H0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0QP3oool5ool002D0oooo1Ooo000<0?ooo`Goo`00E@3oool100000040oooo0000
0`000000oooo0?ooo`260?ooo`Goo`009@3oool5ool000`0oooo1Ooo001E0?ooo`4000000@3oool0
00030000003oool0oooo08H0oooo1Ooo000V0?ooo`?oo`003@3oool5ool005D0oooo0@0000010?oo
o`0000<000000?ooo`3oool0Q`3oool3ool000d0oooo0ooo0000103oooooo`00ool00?oo000H0?oo
o`?oo`002@3oool3ool005H0oooo0@0000010?ooo`0000<000000?ooo`3oool0UP3oool9ool001H0
oooo1Ooo001Q0?ooo`4000000@3oool000030000003oool0oooo09H0oooo2ooo000D0?ooo`Goo`00
H@3oool100000040oooo00000`000000oooo0?ooo`2C0?ooo`ooo`004`3oool5ool00640oooo0@00
00010?ooo`0000<000000?ooo`3oool0TP3oool8ool000030?oooooo003oo`0000Goo`00503oool3
ool00680oooo0@0000010?ooo`0000<000000?ooo`3oool0P@3oool3ool000h0oooo1Ooo00060?oo
o`Goo`00N@3oool100000040oooo00000`000000oooo0?ooo`200?ooo`Goo`003@3oool5ool000L0
oooo0ooo001j0?ooo`4000000@3oool000030000003oool0oooo0800oooo1Ooo000>0?ooo`?oo`00
Q@3oool100000040oooo00000`000000oooo0?ooo`200?ooo`Goo`00UP3oool100000040oooo0000
0`000000oooo0?ooo`210?ooo`?oo`00U`3oool100000040oooo00000`000000oooo0?ooo`3o0?oo
oa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0PP3oool3ool009H0oooo0@0000010?ooo`00
00<000000?ooo`3oool0P@3oool5ool000/0oooo0ooo00270?ooo`4000000@3oool000030000003o
ool0oooo0840oooo1Ooo000:0?ooo`Goo`00QP3oool100000040oooo00000`000000oooo0?ooo`21
0?ooo`Goo`002P3oool5ool008H0oooo0@0000010?ooo`0000<000000?ooo`3oool0PP3oool3ool0
00/0oooo1Ooo00260?ooo`4000000@3oool000030000003oool0oooo0940oooo0ooo00270?ooo`40
00000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?oo
o`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0HP3oool3ool00;H0oooo0@000001
0?ooo`0000<000000?ooo`3oool0H@3oool5ool00;D0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0H@3oool5ool00;D0oooo0@0000010?ooo`0000<000000?ooo`3oool0H@3oool5ool00;D0oooo
0@0000010?ooo`0000<000000?ooo`3oool0HP3oool3ool00;H0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool10000
0040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0
o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo06T0oooo0ooo002_0?ooo`4000000@3o
ool000030000003oool0oooo06P0oooo1Ooo002^0?ooo`4000000@3oool000030000003oool0oooo
06P0oooo1Ooo002^0?ooo`4000000@3oool000030000003oool0oooo06P0oooo1Ooo002^0?ooo`40
00000@3oool000030000003oool0oooo06T0oooo0ooo002_0?ooo`4000000@3oool000030000003o
ool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@000001
0?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0
oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool1
00000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo
00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL
0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000
oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`400000
0@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o
0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool00003
0000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo
0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0
oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?oo
o`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo02T0oooo
0ooo003_0?ooo`4000000@3oool000030000003oool0oooo02P0oooo1Ooo003^0?ooo`4000000@3o
ool000030000003oool0oooo02P0oooo1Ooo003^0?ooo`4000000@3oool000030000003oool0oooo
02P0oooo1Ooo003^0?ooo`4000000@3oool000030000003oool0oooo02T0oooo0ooo003_0?ooo`40
00000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?oo
o`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool0
00030000003oool0oooo0?l0oooo703oool100000040oooo003o0000020000000@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Gaussian probability density functions", "Subsection"],

Cell[CellGroupData[{

Cell["Compute Gaussian pdfs", "Subsubsection"],

Cell[BoxData[{
    \(\(pdf1\  = \ gaussian[data1, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(pdf2\  = \ gaussian[data2, {x, y}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Gaussian pdfs", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[pdf1, pdf2, pr, x, y, yS, imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.8575 .43691 m
.88215 .43609 L
.90463 .43836 L
.9068 .43882 L
.93146 .44824 L
.94483 .46302 L
.9512 .48767 L
.94725 .51233 L
.93721 .53698 L
.93146 .54899 L
.92289 .56164 L
.9068 .58454 L
.90534 .58629 L
.88412 .61095 L
.88215 .61322 L
.86018 .6356 L
.8575 .63819 L
.83386 .66026 L
.83284 .66107 L
.80819 .68187 L
.80454 .68491 L
.78353 .70042 L
.77202 .70957 L
.75888 .71762 L
.73699 .73422 L
.73422 .73534 L
.70957 .7509 L
.69799 .75888 L
.68491 .76457 L
.66026 .78018 L
.65479 .78353 L
.6356 .79127 L
.61095 .80508 L
.60509 .80819 L
.58629 .81437 L
.56164 .82555 L
.54449 .83284 L
.53698 .83446 L
.51233 .84167 L
.48767 .84882 L
.46302 .85423 L
.43836 .85735 L
.43609 .8575 L
.41371 .85759 L
.41211 .8575 L
.38905 .85381 L
.3644 .8422 L
.35662 .83284 L
.34894 .80819 L
.35221 .78353 L
.36159 .75888 L
.3644 .75238 L
.3758 .73422 L
.38905 .71453 L
.3931 .70957 L
.41361 .68491 L
.41371 .68479 L
.43736 .66026 L
.43836 .65926 L
.46302 .63604 L
.46351 .6356 L
.48767 .6153 L
.49285 .61095 L
.51233 .59648 L
.52505 .58629 L
.53698 .57897 L
.55967 .56164 L
.56164 .56085 L
.58629 .5454 L
.59841 .53698 L
.61095 .5315 L
.6356 .51575 L
.64114 .51233 L
.66026 .50449 L
.68491 .49048 L
.69014 .48767 L
.70957 .4811 L
.73422 .46964 L
.7494 .46302 L
.75888 .46086 L
.78353 .45319 L
.80819 .44571 L
.83284 .44 L
.84251 .43836 L
F
0 g
.8575 .43691 m
.88215 .43609 L
.90463 .43836 L
.9068 .43882 L
.93146 .44824 L
.94483 .46302 L
.9512 .48767 L
.94725 .51233 L
.93721 .53698 L
.93146 .54899 L
.92289 .56164 L
.9068 .58454 L
.90534 .58629 L
.88412 .61095 L
.88215 .61322 L
.86018 .6356 L
.8575 .63819 L
.83386 .66026 L
.83284 .66107 L
.80819 .68187 L
.80454 .68491 L
.78353 .70042 L
.77202 .70957 L
.75888 .71762 L
.73699 .73422 L
.73422 .73534 L
.70957 .7509 L
.69799 .75888 L
.68491 .76457 L
.66026 .78018 L
.65479 .78353 L
.6356 .79127 L
.61095 .80508 L
.60509 .80819 L
.58629 .81437 L
.56164 .82555 L
.54449 .83284 L
.53698 .83446 L
.51233 .84167 L
.48767 .84882 L
.46302 .85423 L
.43836 .85735 L
.43609 .8575 L
.41371 .85759 L
.41211 .8575 L
.38905 .85381 L
.3644 .8422 L
.35662 .83284 L
.34894 .80819 L
.35221 .78353 L
Mistroke
.36159 .75888 L
.3644 .75238 L
.3758 .73422 L
.38905 .71453 L
.3931 .70957 L
.41361 .68491 L
.41371 .68479 L
.43736 .66026 L
.43836 .65926 L
.46302 .63604 L
.46351 .6356 L
.48767 .6153 L
.49285 .61095 L
.51233 .59648 L
.52505 .58629 L
.53698 .57897 L
.55967 .56164 L
.56164 .56085 L
.58629 .5454 L
.59841 .53698 L
.61095 .5315 L
.6356 .51575 L
.64114 .51233 L
.66026 .50449 L
.68491 .49048 L
.69014 .48767 L
.70957 .4811 L
.73422 .46964 L
.7494 .46302 L
.75888 .46086 L
.78353 .45319 L
.80819 .44571 L
.83284 .44 L
.84251 .43836 L
.8575 .43691 L
Mfstroke
.2 g
.75888 .48668 m
.78353 .48049 L
.80819 .47561 L
.83284 .47323 L
.8575 .47466 L
.88215 .48385 L
.88655 .48767 L
.89791 .51233 L
.89455 .53698 L
.884 .56164 L
.88215 .56546 L
.86811 .58629 L
.8575 .60062 L
.84843 .61095 L
.83284 .62803 L
.8252 .6356 L
.80819 .65167 L
.79856 .66026 L
.78353 .67269 L
.76859 .68491 L
.75888 .69183 L
.73537 .70957 L
.73422 .71022 L
.70957 .72622 L
.69763 .73422 L
.68491 .74091 L
.66026 .7558 L
.65497 .75888 L
.6356 .76777 L
.61095 .78042 L
.60453 .78353 L
.58629 .7902 L
.56164 .79996 L
.53784 .80819 L
.53698 .80838 L
.51233 .81415 L
.48767 .81861 L
.46302 .82045 L
.43836 .81815 L
.41587 .80819 L
.41371 .80607 L
.40236 .78353 L
.40484 .75888 L
.41371 .73631 L
.41479 .73422 L
.43033 .70957 L
.43836 .69825 L
.44973 .68491 L
.46302 .66998 L
.47267 .66026 L
.48767 .64583 L
.49899 .6356 L
.51233 .62443 L
.52862 .61095 L
.53698 .60493 L
.56144 .58629 L
.56164 .58618 L
.58629 .57015 L
.59886 .56164 L
.61095 .55521 L
.6356 .54015 L
.64097 .53698 L
.66026 .52798 L
.68491 .5151 L
.69054 .51233 L
.70957 .50518 L
.73422 .49512 L
.7548 .48767 L
F
0 g
.75888 .48668 m
.78353 .48049 L
.80819 .47561 L
.83284 .47323 L
.8575 .47466 L
.88215 .48385 L
.88655 .48767 L
.89791 .51233 L
.89455 .53698 L
.884 .56164 L
.88215 .56546 L
.86811 .58629 L
.8575 .60062 L
.84843 .61095 L
.83284 .62803 L
.8252 .6356 L
.80819 .65167 L
.79856 .66026 L
.78353 .67269 L
.76859 .68491 L
.75888 .69183 L
.73537 .70957 L
.73422 .71022 L
.70957 .72622 L
.69763 .73422 L
.68491 .74091 L
.66026 .7558 L
.65497 .75888 L
.6356 .76777 L
.61095 .78042 L
.60453 .78353 L
.58629 .7902 L
.56164 .79996 L
.53784 .80819 L
.53698 .80838 L
.51233 .81415 L
.48767 .81861 L
.46302 .82045 L
.43836 .81815 L
.41587 .80819 L
.41371 .80607 L
.40236 .78353 L
.40484 .75888 L
.41371 .73631 L
.41479 .73422 L
.43033 .70957 L
.43836 .69825 L
.44973 .68491 L
.46302 .66998 L
.47267 .66026 L
Mistroke
.48767 .64583 L
.49899 .6356 L
.51233 .62443 L
.52862 .61095 L
.53698 .60493 L
.56144 .58629 L
.56164 .58618 L
.58629 .57015 L
.59886 .56164 L
.61095 .55521 L
.6356 .54015 L
.64097 .53698 L
.66026 .52798 L
.68491 .5151 L
.69054 .51233 L
.70957 .50518 L
.73422 .49512 L
.7548 .48767 L
.75888 .48668 L
Mfstroke
.3 g
.73422 .51137 m
.75888 .50441 L
.78353 .49908 L
.80819 .4965 L
.83284 .4981 L
.85749 .51233 L
.8575 .51234 L
.86445 .53698 L
.85804 .56164 L
.8575 .56357 L
.8444 .58629 L
.83284 .60322 L
.82589 .61095 L
.80819 .6307 L
.80318 .6356 L
.78353 .65414 L
.77653 .66026 L
.75888 .67474 L
.74599 .68491 L
.73422 .69326 L
.71138 .70957 L
.70957 .71064 L
.68491 .72594 L
.67144 .73422 L
.66026 .7399 L
.6356 .75311 L
.62427 .75888 L
.61095 .76435 L
.58629 .77472 L
.56235 .78353 L
.56164 .78372 L
.53698 .7903 L
.51233 .79519 L
.48767 .79719 L
.46302 .79447 L
.44397 .78353 L
.43836 .77416 L
.43547 .75888 L
.43836 .74225 L
.44109 .73422 L
.4542 .70957 L
.46302 .69579 L
.47233 .68491 L
.48767 .66728 L
.49469 .66026 L
.51233 .64329 L
.52099 .6356 L
.53698 .62228 L
.55116 .61095 L
.56164 .60341 L
.58532 .58629 L
.58629 .58571 L
.61095 .57025 L
.62477 .56164 L
.6356 .55605 L
.66026 .54262 L
.67112 .53698 L
.68491 .53118 L
.70957 .52053 L
.7309 .51233 L
F
0 g
.73422 .51137 m
.75888 .50441 L
.78353 .49908 L
.80819 .4965 L
.83284 .4981 L
.85749 .51233 L
.8575 .51234 L
.86445 .53698 L
.85804 .56164 L
.8575 .56357 L
.8444 .58629 L
.83284 .60322 L
.82589 .61095 L
.80819 .6307 L
.80318 .6356 L
.78353 .65414 L
.77653 .66026 L
.75888 .67474 L
.74599 .68491 L
.73422 .69326 L
.71138 .70957 L
.70957 .71064 L
.68491 .72594 L
.67144 .73422 L
.66026 .7399 L
.6356 .75311 L
.62427 .75888 L
.61095 .76435 L
.58629 .77472 L
.56235 .78353 L
.56164 .78372 L
.53698 .7903 L
.51233 .79519 L
.48767 .79719 L
.46302 .79447 L
.44397 .78353 L
.43836 .77416 L
.43547 .75888 L
.43836 .74225 L
.44109 .73422 L
.4542 .70957 L
.46302 .69579 L
.47233 .68491 L
.48767 .66728 L
.49469 .66026 L
.51233 .64329 L
.52099 .6356 L
.53698 .62228 L
.55116 .61095 L
.56164 .60341 L
Mistroke
.58532 .58629 L
.58629 .58571 L
.61095 .57025 L
.62477 .56164 L
.6356 .55605 L
.66026 .54262 L
.67112 .53698 L
.68491 .53118 L
.70957 .52053 L
.7309 .51233 L
.73422 .51137 L
Mfstroke
.4 g
.70957 .53317 m
.73422 .52489 L
.75888 .51854 L
.78353 .51506 L
.80819 .51511 L
.83284 .53012 L
.83656 .53698 L
.83615 .56164 L
.83284 .57104 L
.82523 .58629 L
.80819 .61088 L
.80802 .61095 L
.78576 .6356 L
.78353 .63787 L
.75918 .66026 L
.75888 .66051 L
.73422 .68028 L
.72804 .68491 L
.70957 .69776 L
.69192 .70957 L
.68491 .71368 L
.66026 .72815 L
.64932 .73422 L
.6356 .74079 L
.61095 .75234 L
.59553 .75888 L
.58629 .76204 L
.56164 .76996 L
.53698 .7759 L
.51233 .77888 L
.48767 .77834 L
.46427 .75888 L
.46329 .73422 L
.47354 .70957 L
.48767 .68617 L
.49027 .68491 L
.51205 .66026 L
.51233 .65996 L
.53698 .63671 L
.53829 .6356 L
.56164 .61657 L
.56902 .61095 L
.58629 .59876 L
.60464 .58629 L
.61095 .58253 L
.6356 .56782 L
.64655 .56164 L
.66026 .55494 L
.68491 .54311 L
.6989 .53698 L
F
0 g
.70957 .53317 m
.73422 .52489 L
.75888 .51854 L
.78353 .51506 L
.80819 .51511 L
.83284 .53012 L
.83656 .53698 L
.83615 .56164 L
.83284 .57104 L
.82523 .58629 L
.80819 .61088 L
.80802 .61095 L
.78576 .6356 L
.78353 .63787 L
.75918 .66026 L
.75888 .66051 L
.73422 .68028 L
.72804 .68491 L
.70957 .69776 L
.69192 .70957 L
.68491 .71368 L
.66026 .72815 L
.64932 .73422 L
.6356 .74079 L
.61095 .75234 L
.59553 .75888 L
.58629 .76204 L
.56164 .76996 L
.53698 .7759 L
.51233 .77888 L
.48767 .77834 L
.46427 .75888 L
.46329 .73422 L
.47354 .70957 L
.48767 .68617 L
.49027 .68491 L
.51205 .66026 L
.51233 .65996 L
.53698 .63671 L
.53829 .6356 L
.56164 .61657 L
.56902 .61095 L
.58629 .59876 L
.60464 .58629 L
.61095 .58253 L
.6356 .56782 L
.64655 .56164 L
.66026 .55494 L
.68491 .54311 L
.6989 .53698 L
Mistroke
.70957 .53317 L
Mfstroke
.5 g
.73422 .53672 m
.75888 .53196 L
.78353 .5311 L
.80236 .53698 L
.80819 .54149 L
.81537 .56164 L
.80819 .58581 L
.80796 .58629 L
.79219 .61095 L
.78353 .62257 L
.77059 .6356 L
.75888 .64727 L
.74393 .66026 L
.73422 .66824 L
.7122 .68491 L
.70957 .68673 L
.68491 .70313 L
.67448 .70957 L
.66026 .71751 L
.6356 .73054 L
.62811 .73422 L
.61095 .74148 L
.58629 .75088 L
.56164 .75799 L
.55742 .75888 L
.53698 .76213 L
.51233 .76181 L
.50234 .75888 L
.48767 .7463 L
.48466 .73422 L
.48767 .71821 L
.49099 .70957 L
.50617 .68491 L
.51233 .67614 L
.5273 .66026 L
.53698 .65032 L
.55351 .6356 L
.56164 .62878 L
.58475 .61095 L
.58629 .60986 L
.61095 .59316 L
.62188 .58629 L
.6356 .57847 L
.66026 .56516 L
.66726 .56164 L
.68491 .55393 L
.70957 .54419 L
.73298 .53698 L
F
0 g
.73422 .53672 m
.75888 .53196 L
.78353 .5311 L
.80236 .53698 L
.80819 .54149 L
.81537 .56164 L
.80819 .58581 L
.80796 .58629 L
.79219 .61095 L
.78353 .62257 L
.77059 .6356 L
.75888 .64727 L
.74393 .66026 L
.73422 .66824 L
.7122 .68491 L
.70957 .68673 L
.68491 .70313 L
.67448 .70957 L
.66026 .71751 L
.6356 .73054 L
.62811 .73422 L
.61095 .74148 L
.58629 .75088 L
.56164 .75799 L
.55742 .75888 L
.53698 .76213 L
.51233 .76181 L
.50234 .75888 L
.48767 .7463 L
.48466 .73422 L
.48767 .71821 L
.49099 .70957 L
.50617 .68491 L
.51233 .67614 L
.5273 .66026 L
.53698 .65032 L
.55351 .6356 L
.56164 .62878 L
.58475 .61095 L
.58629 .60986 L
.61095 .59316 L
.62188 .58629 L
.6356 .57847 L
.66026 .56516 L
.66726 .56164 L
.68491 .55393 L
.70957 .54419 L
.73298 .53698 L
.73422 .53672 L
s
.6 g
.70957 .55473 m
.73422 .54795 L
.75888 .54387 L
.78353 .5515 L
.79316 .56164 L
.79121 .58629 L
.78353 .60159 L
.77751 .61095 L
.75888 .63517 L
.75666 .6356 L
.73422 .65712 L
.72998 .66026 L
.70957 .67642 L
.69737 .68491 L
.68491 .69313 L
.66026 .70801 L
.65746 .70957 L
.6356 .72074 L
.61095 .73168 L
.60579 .73422 L
.58629 .7402 L
.56164 .74646 L
.53698 .74984 L
.51233 .739 L
.50825 .73422 L
.50809 .70957 L
.51233 .69969 L
.52097 .68491 L
.53698 .66139 L
.54125 .66026 L
.56164 .64 L
.56743 .6356 L
.58629 .62032 L
.59948 .61095 L
.61095 .60322 L
.6356 .588 L
.63861 .58629 L
.66026 .57494 L
.68491 .56367 L
.68901 .56164 L
F
0 g
.70957 .55473 m
.73422 .54795 L
.75888 .54387 L
.78353 .5515 L
.79316 .56164 L
.79121 .58629 L
.78353 .60159 L
.77751 .61095 L
.75888 .63517 L
.75666 .6356 L
.73422 .65712 L
.72998 .66026 L
.70957 .67642 L
.69737 .68491 L
.68491 .69313 L
.66026 .70801 L
.65746 .70957 L
.6356 .72074 L
.61095 .73168 L
.60579 .73422 L
.58629 .7402 L
.56164 .74646 L
.53698 .74984 L
.51233 .739 L
.50825 .73422 L
.50809 .70957 L
.51233 .69969 L
.52097 .68491 L
.53698 .66139 L
.54125 .66026 L
.56164 .64 L
.56743 .6356 L
.58629 .62032 L
.59948 .61095 L
.61095 .60322 L
.6356 .588 L
.63861 .58629 L
.66026 .57494 L
.68491 .56367 L
.68901 .56164 L
.70957 .55473 L
s
.7 g
.73422 .56048 m
.75654 .56164 L
.75888 .56232 L
.77397 .58629 L
.7629 .61095 L
.75888 .62074 L
.7431 .6356 L
.73422 .64548 L
.71635 .66026 L
.70957 .66585 L
.68491 .68362 L
.68267 .68491 L
.66026 .69876 L
.63927 .70957 L
.6356 .71126 L
.61095 .72205 L
.58629 .73046 L
.56164 .73339 L
.53698 .72948 L
.52586 .70957 L
.53577 .68491 L
.53698 .68154 L
.55487 .66026 L
.56164 .65236 L
.58102 .6356 L
.58629 .63113 L
.61095 .61273 L
.614 .61095 L
.6356 .59728 L
.6563 .58629 L
.66026 .58439 L
.68491 .57319 L
.70957 .56449 L
.72628 .56164 L
F
0 g
.73422 .56048 m
.75654 .56164 L
.75888 .56232 L
.77397 .58629 L
.7629 .61095 L
.75888 .62074 L
.7431 .6356 L
.73422 .64548 L
.71635 .66026 L
.70957 .66585 L
.68491 .68362 L
.68267 .68491 L
.66026 .69876 L
.63927 .70957 L
.6356 .71126 L
.61095 .72205 L
.58629 .73046 L
.56164 .73339 L
.53698 .72948 L
.52586 .70957 L
.53577 .68491 L
.53698 .68154 L
.55487 .66026 L
.56164 .65236 L
.58102 .6356 L
.58629 .63113 L
.61095 .61273 L
.614 .61095 L
.6356 .59728 L
.6563 .58629 L
.66026 .58439 L
.68491 .57319 L
.70957 .56449 L
.72628 .56164 L
.73422 .56048 L
s
.8 g
.68491 .58352 m
.70957 .57493 L
.73422 .57526 L
.75182 .58629 L
.74793 .61095 L
.73422 .62977 L
.72943 .6356 L
.70957 .65426 L
.70267 .66026 L
.68491 .67452 L
.66714 .68491 L
.66026 .68898 L
.6356 .70282 L
.61787 .70957 L
.61095 .71154 L
.58629 .71934 L
.56164 .71761 L
.5493 .70957 L
.55106 .68491 L
.56164 .66911 L
.56856 .66026 L
.58629 .64304 L
.59464 .6356 L
.61095 .62205 L
.62933 .61095 L
.6356 .6071 L
.66026 .59281 L
.67635 .58629 L
F
0 g
.68491 .58352 m
.70957 .57493 L
.73422 .57526 L
.75182 .58629 L
.74793 .61095 L
.73422 .62977 L
.72943 .6356 L
.70957 .65426 L
.70267 .66026 L
.68491 .67452 L
.66714 .68491 L
.66026 .68898 L
.6356 .70282 L
.61787 .70957 L
.61095 .71154 L
.58629 .71934 L
.56164 .71761 L
.5493 .70957 L
.55106 .68491 L
.56164 .66911 L
.56856 .66026 L
.58629 .64304 L
.59464 .6356 L
.61095 .62205 L
.62933 .61095 L
.6356 .6071 L
.66026 .59281 L
.67635 .58629 L
.68491 .58352 L
s
.9 g
.66026 .60343 m
.68491 .5951 L
.70957 .59068 L
.7293 .61095 L
.71425 .6356 L
.70957 .64033 L
.68722 .66026 L
.68491 .66223 L
.66026 .67821 L
.65147 .68491 L
.6356 .69207 L
.61095 .69974 L
.58629 .70278 L
.56516 .68491 L
.58401 .66026 L
.58629 .6578 L
.61005 .6356 L
.61095 .6348 L
.6356 .61794 L
.64503 .61095 L
F
0 g
.66026 .60343 m
.68491 .5951 L
.70957 .59068 L
.7293 .61095 L
.71425 .6356 L
.70957 .64033 L
.68722 .66026 L
.68491 .66223 L
.66026 .67821 L
.65147 .68491 L
.6356 .69207 L
.61095 .69974 L
.58629 .70278 L
.56516 .68491 L
.58401 .66026 L
.58629 .6578 L
.61005 .6356 L
.61095 .6348 L
.6356 .61794 L
.64503 .61095 L
.66026 .60343 L
s
1 g
.68491 .61034 m
.69568 .61095 L
.70012 .6356 L
.68491 .64631 L
.67119 .66026 L
.66026 .66516 L
.6356 .67756 L
.61095 .68352 L
.60005 .66026 L
.61095 .65147 L
.6267 .6356 L
.6356 .63115 L
.66026 .61781 L
.68106 .61095 L
F
0 g
.68491 .61034 m
.69568 .61095 L
.70012 .6356 L
.68491 .64631 L
.67119 .66026 L
.66026 .66516 L
.6356 .67756 L
.61095 .68352 L
.60005 .66026 L
.61095 .65147 L
.6267 .6356 L
.6356 .63115 L
.66026 .61781 L
.68106 .61095 L
.68491 .61034 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.31509 .11686 m
.33974 .11438 L
.3644 .11152 L
.38905 .11116 L
.41371 .11433 L
.42686 .11785 L
.43836 .12374 L
.45857 .1425 L
.46302 .15036 L
.46758 .16716 L
.4668 .19181 L
.46302 .20866 L
.45989 .21647 L
.44633 .24112 L
.43836 .25472 L
.42923 .26578 L
.41371 .28407 L
.40733 .29043 L
.38905 .3072 L
.37998 .31509 L
.3644 .326 L
.34679 .33974 L
.33974 .34259 L
.31509 .35852 L
.30584 .3644 L
.29043 .37229 L
.26578 .38179 L
.25031 .38905 L
.24112 .39223 L
.21647 .3966 L
.19181 .40301 L
.16716 .4069 L
.1425 .40764 L
.11785 .40465 L
.0932 .39657 L
.08056 .38905 L
.06854 .37852 L
.06207 .3644 L
.05802 .33974 L
.06202 .31509 L
.06854 .29163 L
.07106 .29043 L
.0868 .26578 L
.0932 .25585 L
.10621 .24112 L
.11785 .22841 L
.1304 .21647 L
.1425 .2065 L
.15995 .19181 L
.16716 .1879 L
.19181 .16985 L
.19569 .16716 L
.21647 .15784 L
.24112 .1429 L
.24184 .1425 L
.26578 .13233 L
.29043 .125 L
.3109 .11785 L
F
0 g
.31509 .11686 m
.33974 .11438 L
.3644 .11152 L
.38905 .11116 L
.41371 .11433 L
.42686 .11785 L
.43836 .12374 L
.45857 .1425 L
.46302 .15036 L
.46758 .16716 L
.4668 .19181 L
.46302 .20866 L
.45989 .21647 L
.44633 .24112 L
.43836 .25472 L
.42923 .26578 L
.41371 .28407 L
.40733 .29043 L
.38905 .3072 L
.37998 .31509 L
.3644 .326 L
.34679 .33974 L
.33974 .34259 L
.31509 .35852 L
.30584 .3644 L
.29043 .37229 L
.26578 .38179 L
.25031 .38905 L
.24112 .39223 L
.21647 .3966 L
.19181 .40301 L
.16716 .4069 L
.1425 .40764 L
.11785 .40465 L
.0932 .39657 L
.08056 .38905 L
.06854 .37852 L
.06207 .3644 L
.05802 .33974 L
.06202 .31509 L
.06854 .29163 L
.07106 .29043 L
.0868 .26578 L
.0932 .25585 L
.10621 .24112 L
.11785 .22841 L
.1304 .21647 L
.1425 .2065 L
.15995 .19181 L
.16716 .1879 L
Mistroke
.19181 .16985 L
.19569 .16716 L
.21647 .15784 L
.24112 .1429 L
.24184 .1425 L
.26578 .13233 L
.29043 .125 L
.3109 .11785 L
.31509 .11686 L
Mfstroke
.2 g
.31509 .14066 m
.33974 .13732 L
.3644 .13655 L
.38905 .14 L
.39781 .1425 L
.41371 .15087 L
.42656 .16716 L
.43229 .19181 L
.42775 .21647 L
.41651 .24112 L
.41371 .24648 L
.39902 .26578 L
.38905 .27763 L
.37612 .29043 L
.3644 .30072 L
.34686 .31509 L
.33974 .31956 L
.31509 .33618 L
.30943 .33974 L
.29043 .34838 L
.26578 .36065 L
.25733 .3644 L
.24112 .36853 L
.21647 .37535 L
.19181 .3801 L
.16716 .38162 L
.1425 .37897 L
.11785 .36969 L
.1106 .3644 L
.09531 .33974 L
.09457 .31509 L
.1025 .29043 L
.11628 .26578 L
.11785 .26322 L
.13633 .24112 L
.1425 .23448 L
.16187 .21647 L
.16716 .21238 L
.19181 .19349 L
.19417 .19181 L
.21647 .17915 L
.23694 .16716 L
.24112 .16585 L
.26578 .15591 L
.29043 .14643 L
.30224 .1425 L
F
0 g
.31509 .14066 m
.33974 .13732 L
.3644 .13655 L
.38905 .14 L
.39781 .1425 L
.41371 .15087 L
.42656 .16716 L
.43229 .19181 L
.42775 .21647 L
.41651 .24112 L
.41371 .24648 L
.39902 .26578 L
.38905 .27763 L
.37612 .29043 L
.3644 .30072 L
.34686 .31509 L
.33974 .31956 L
.31509 .33618 L
.30943 .33974 L
.29043 .34838 L
.26578 .36065 L
.25733 .3644 L
.24112 .36853 L
.21647 .37535 L
.19181 .3801 L
.16716 .38162 L
.1425 .37897 L
.11785 .36969 L
.1106 .3644 L
.09531 .33974 L
.09457 .31509 L
.1025 .29043 L
.11628 .26578 L
.11785 .26322 L
.13633 .24112 L
.1425 .23448 L
.16187 .21647 L
.16716 .21238 L
.19181 .19349 L
.19417 .19181 L
.21647 .17915 L
.23694 .16716 L
.24112 .16585 L
.26578 .15591 L
.29043 .14643 L
.30224 .1425 L
.31509 .14066 L
s
.3 g
.29043 .16105 m
.31509 .1553 L
.33974 .15261 L
.3644 .15419 L
.38905 .16304 L
.3946 .16716 L
.4088 .19181 L
.40742 .21647 L
.39715 .24112 L
.38905 .25551 L
.38019 .26578 L
.3644 .28318 L
.35651 .29043 L
.33974 .30419 L
.32508 .31509 L
.31509 .32103 L
.29043 .33552 L
.28248 .33974 L
.26578 .34616 L
.24112 .35531 L
.21647 .36194 L
.20113 .3644 L
.19181 .3651 L
.16716 .36448 L
.16652 .3644 L
.1425 .35817 L
.12232 .33974 L
.11785 .32807 L
.11655 .31509 L
.11785 .30477 L
.12212 .29043 L
.13557 .26578 L
.1425 .25552 L
.15549 .24112 L
.16716 .22951 L
.18231 .21647 L
.19181 .20955 L
.21647 .1926 L
.21773 .19181 L
.24112 .17998 L
.26578 .16847 L
.26877 .16716 L
F
0 g
.29043 .16105 m
.31509 .1553 L
.33974 .15261 L
.3644 .15419 L
.38905 .16304 L
.3946 .16716 L
.4088 .19181 L
.40742 .21647 L
.39715 .24112 L
.38905 .25551 L
.38019 .26578 L
.3644 .28318 L
.35651 .29043 L
.33974 .30419 L
.32508 .31509 L
.31509 .32103 L
.29043 .33552 L
.28248 .33974 L
.26578 .34616 L
.24112 .35531 L
.21647 .36194 L
.20113 .3644 L
.19181 .3651 L
.16716 .36448 L
.16652 .3644 L
.1425 .35817 L
.12232 .33974 L
.11785 .32807 L
.11655 .31509 L
.11785 .30477 L
.12212 .29043 L
.13557 .26578 L
.1425 .25552 L
.15549 .24112 L
.16716 .22951 L
.18231 .21647 L
.19181 .20955 L
.21647 .1926 L
.21773 .19181 L
.24112 .17998 L
.26578 .16847 L
.26877 .16716 L
.29043 .16105 L
s
.4 g
.31509 .16654 m
.33974 .16554 L
.35313 .16716 L
.3644 .16948 L
.38852 .19181 L
.38905 .19325 L
.39087 .21647 L
.38905 .22422 L
.38207 .24112 L
.36531 .26578 L
.3644 .26693 L
.3408 .29043 L
.33974 .29132 L
.31509 .30981 L
.30703 .31509 L
.29043 .32408 L
.26578 .33603 L
.25728 .33974 L
.24112 .34434 L
.21647 .35001 L
.19181 .35224 L
.16716 .34934 L
.14749 .33974 L
.1425 .33387 L
.13479 .31509 L
.13801 .29043 L
.1425 .27945 L
.15047 .26578 L
.16716 .24412 L
.17051 .24112 L
.19181 .22179 L
.19874 .21647 L
.21647 .20458 L
.23806 .19181 L
.24112 .19045 L
.26578 .17986 L
.29043 .17149 L
.31031 .16716 L
F
0 g
.31509 .16654 m
.33974 .16554 L
.35313 .16716 L
.3644 .16948 L
.38852 .19181 L
.38905 .19325 L
.39087 .21647 L
.38905 .22422 L
.38207 .24112 L
.36531 .26578 L
.3644 .26693 L
.3408 .29043 L
.33974 .29132 L
.31509 .30981 L
.30703 .31509 L
.29043 .32408 L
.26578 .33603 L
.25728 .33974 L
.24112 .34434 L
.21647 .35001 L
.19181 .35224 L
.16716 .34934 L
.14749 .33974 L
.1425 .33387 L
.13479 .31509 L
.13801 .29043 L
.1425 .27945 L
.15047 .26578 L
.16716 .24412 L
.17051 .24112 L
.19181 .22179 L
.19874 .21647 L
.21647 .20458 L
.23806 .19181 L
.24112 .19045 L
.26578 .17986 L
.29043 .17149 L
.31031 .16716 L
.31509 .16654 L
s
.5 g
.26578 .18905 m
.29043 .18134 L
.31509 .17699 L
.33974 .17726 L
.3644 .187 L
.36831 .19181 L
.376 .21647 L
.36877 .24112 L
.3644 .25305 L
.35216 .26578 L
.33974 .27953 L
.32679 .29043 L
.31509 .29927 L
.29043 .31486 L
.29003 .31509 L
.26578 .32639 L
.24112 .33513 L
.21933 .33974 L
.21647 .34011 L
.19181 .34061 L
.18556 .33974 L
.16716 .33332 L
.15159 .31509 L
.15191 .29043 L
.1635 .26578 L
.16716 .25951 L
.18389 .24112 L
.19181 .2335 L
.21362 .21647 L
.21647 .2146 L
.24112 .20003 L
.25808 .19181 L
F
0 g
.26578 .18905 m
.29043 .18134 L
.31509 .17699 L
.33974 .17726 L
.3644 .187 L
.36831 .19181 L
.376 .21647 L
.36877 .24112 L
.3644 .25305 L
.35216 .26578 L
.33974 .27953 L
.32679 .29043 L
.31509 .29927 L
.29043 .31486 L
.29003 .31509 L
.26578 .32639 L
.24112 .33513 L
.21933 .33974 L
.21647 .34011 L
.19181 .34061 L
.18556 .33974 L
.16716 .33332 L
.15159 .31509 L
.15191 .29043 L
.1635 .26578 L
.16716 .25951 L
.18389 .24112 L
.19181 .2335 L
.21362 .21647 L
.21647 .2146 L
.24112 .20003 L
.25808 .19181 L
.26578 .18905 L
s
.6 g
.29043 .19021 m
.31509 .18701 L
.33974 .19043 L
.34411 .19181 L
.36173 .21647 L
.35652 .24112 L
.34017 .26578 L
.33974 .26632 L
.31509 .2896 L
.31368 .29043 L
.29043 .30594 L
.27263 .31509 L
.26578 .31781 L
.24112 .32621 L
.21647 .33077 L
.19181 .33057 L
.16878 .31509 L
.16716 .3108 L
.16509 .29043 L
.16716 .28302 L
.1755 .26578 L
.19181 .24241 L
.19612 .24112 L
.21647 .22381 L
.22784 .21647 L
.24112 .20894 L
.26578 .19747 L
.27985 .19181 L
F
0 g
.29043 .19021 m
.31509 .18701 L
.33974 .19043 L
.34411 .19181 L
.36173 .21647 L
.35652 .24112 L
.34017 .26578 L
.33974 .26632 L
.31509 .2896 L
.31368 .29043 L
.29043 .30594 L
.27263 .31509 L
.26578 .31781 L
.24112 .32621 L
.21647 .33077 L
.19181 .33057 L
.16878 .31509 L
.16716 .3108 L
.16509 .29043 L
.16716 .28302 L
.1755 .26578 L
.19181 .24241 L
.19612 .24112 L
.21647 .22381 L
.22784 .21647 L
.24112 .20894 L
.26578 .19747 L
.27985 .19181 L
.29043 .19021 L
s
.7 g
.26578 .20582 m
.29043 .19819 L
.31509 .19393 L
.33974 .20661 L
.34679 .21647 L
.34443 .24112 L
.33974 .25023 L
.32858 .26578 L
.31509 .28097 L
.30064 .29043 L
.29043 .29708 L
.26578 .31002 L
.24995 .31509 L
.24112 .3175 L
.21647 .32087 L
.19181 .31515 L
.1917 .31509 L
.17799 .29043 L
.18721 .26578 L
.19181 .25477 L
.20816 .24112 L
.21647 .2336 L
.24112 .21726 L
.24254 .21647 L
F
0 g
.26578 .20582 m
.29043 .19819 L
.31509 .19393 L
.33974 .20661 L
.34679 .21647 L
.34443 .24112 L
.33974 .25023 L
.32858 .26578 L
.31509 .28097 L
.30064 .29043 L
.29043 .29708 L
.26578 .31002 L
.24995 .31509 L
.24112 .3175 L
.21647 .32087 L
.19181 .31515 L
.1917 .31509 L
.17799 .29043 L
.18721 .26578 L
.19181 .25477 L
.20816 .24112 L
.21647 .2336 L
.24112 .21726 L
.24254 .21647 L
.26578 .20582 L
s
.8 g
.26578 .21462 m
.29043 .20722 L
.31509 .20482 L
.32823 .21647 L
.33256 .24112 L
.31655 .26578 L
.31509 .26777 L
.29043 .28765 L
.28781 .29043 L
.26578 .30177 L
.24112 .31163 L
.21647 .30961 L
.19201 .29043 L
.19868 .26578 L
.21647 .245 L
.22014 .24112 L
.24112 .22433 L
.26008 .21647 L
F
0 g
.26578 .21462 m
.29043 .20722 L
.31509 .20482 L
.32823 .21647 L
.33256 .24112 L
.31655 .26578 L
.31509 .26777 L
.29043 .28765 L
.28781 .29043 L
.26578 .30177 L
.24112 .31163 L
.21647 .30961 L
.19201 .29043 L
.19868 .26578 L
.21647 .245 L
.22014 .24112 L
.24112 .22433 L
.26008 .21647 L
.26578 .21462 L
s
.9 g
.24112 .23515 m
.26578 .22415 L
.29043 .21873 L
.31509 .22743 L
.31827 .24112 L
.31509 .2491 L
.30498 .26578 L
.29043 .27717 L
.26899 .29043 L
.26578 .29161 L
.24112 .30216 L
.21647 .29536 L
.20727 .29043 L
.21182 .26578 L
.21647 .25933 L
.23384 .24112 L
F
0 g
.24112 .23515 m
.26578 .22415 L
.29043 .21873 L
.31509 .22743 L
.31827 .24112 L
.31509 .2491 L
.30498 .26578 L
.29043 .27717 L
.26899 .29043 L
.26578 .29161 L
.24112 .30216 L
.21647 .29536 L
.20727 .29043 L
.21182 .26578 L
.21647 .25933 L
.23384 .24112 L
.24112 .23515 L
s
1 g
.26578 .23561 m
.29043 .23352 L
.29911 .24112 L
.29043 .26256 L
.28742 .26578 L
.26578 .27976 L
.24112 .28514 L
.22832 .26578 L
.24112 .25002 L
.25356 .24112 L
F
0 g
.26578 .23561 m
.29043 .23352 L
.29911 .24112 L
.29043 .26256 L
.28742 .26578 L
.26578 .27976 L
.24112 .28514 L
.22832 .26578 L
.24112 .25002 L
.25356 .24112 L
.26578 .23561 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.663 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59245 Mtetra
.41047 .59245 .41826 .59977 .43147 .59582 .42372 .58845 Mtetra
.42372 .58845 .43147 .59582 .44474 .59185 .43703 .58445 Mtetra
.43703 .58445 .44474 .59185 .45807 .58786 .4504 .58043 Mtetra
.663 .741 .909 r
.4504 .58043 .45807 .58786 .47147 .58386 .46385 .57641 Mtetra
.662 .742 .909 r
.46385 .57641 .47147 .58386 .48494 .57985 .47735 .57239 Mtetra
.661 .742 .91 r
.47735 .57239 .48494 .57985 .49847 .57583 .49093 .56838 Mtetra
.661 .743 .911 r
.49093 .56838 .49847 .57583 .51207 .5718 .50458 .56436 Mtetra
.66 .744 .912 r
.50458 .56436 .51207 .5718 .52574 .56774 .51829 .56033 Mtetra
.66 .746 .914 r
.51829 .56033 .52574 .56774 .53948 .56364 .53207 .55628 Mtetra
.661 .748 .915 r
.53207 .55628 .53948 .56364 .55329 .55951 .54593 .55218 Mtetra
.662 .751 .916 r
.54593 .55218 .55329 .55951 .56716 .55534 .55985 .54801 Mtetra
.664 .752 .916 r
.55985 .54801 .56716 .55534 .58111 .55113 .57385 .54377 Mtetra
.665 .753 .916 r
.57385 .54377 .58111 .55113 .59513 .54689 .58791 .53946 Mtetra
.666 .752 .915 r
.58791 .53946 .59513 .54689 .60921 .54262 .60204 .53509 Mtetra
.666 .751 .914 r
.60204 .53509 .60921 .54262 .62337 .53833 .61625 .53069 Mtetra
.666 .749 .912 r
.61625 .53069 .62337 .53833 .6376 .53403 .63053 .52628 Mtetra
.666 .747 .911 r
.63053 .52628 .6376 .53403 .6519 .52972 .64488 .52186 Mtetra
.665 .745 .91 r
.64488 .52186 .6519 .52972 .66627 .52539 .6593 .51744 Mtetra
.665 .744 .909 r
.6593 .51744 .66627 .52539 .68072 .52104 .6738 .51302 Mtetra
.664 .743 .909 r
.6738 .51302 .68072 .52104 .69524 .51668 .68837 .5086 Mtetra
.664 .742 .908 r
.68837 .5086 .69524 .51668 .70984 .5123 .70302 .50417 Mtetra
.70302 .50417 .70984 .5123 .72452 .5079 .71775 .49971 Mtetra
.664 .741 .908 r
.71775 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.663 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59245 .40261 .58505 Mtetra
.40261 .58505 .41047 .59245 .42372 .58845 .41589 .58102 Mtetra
.41589 .58102 .42372 .58845 .43703 .58445 .42925 .57698 Mtetra
.42925 .57698 .43703 .58445 .4504 .58043 .44266 .57293 Mtetra
.662 .741 .909 r
.44266 .57293 .4504 .58043 .46385 .57641 .45615 .56889 Mtetra
.661 .741 .909 r
.45615 .56889 .46385 .57641 .47735 .57239 .4697 .56486 Mtetra
.66 .741 .91 r
.4697 .56486 .47735 .57239 .49093 .56838 .48332 .56086 Mtetra
.658 .742 .912 r
.48332 .56086 .49093 .56838 .50458 .56436 .49701 .55689 Mtetra
.657 .744 .915 r
.49701 .55689 .50458 .56436 .51829 .56033 .51077 .55296 Mtetra
.656 .748 .918 r
.51077 .55296 .51829 .56033 .53207 .55628 .5246 .54903 Mtetra
.656 .752 .921 r
.5246 .54903 .53207 .55628 .54593 .55218 .5385 .54506 Mtetra
.657 .757 .924 r
.5385 .54506 .54593 .55218 .55985 .54801 .55247 .54101 Mtetra
.66 .762 .926 r
.55247 .54101 .55985 .54801 .57385 .54377 .56652 .53684 Mtetra
.663 .766 .927 r
.56652 .53684 .57385 .54377 .58791 .53946 .58064 .53252 Mtetra
.666 .768 .926 r
.58064 .53252 .58791 .53946 .60204 .53509 .59482 .52806 Mtetra
.669 .767 .924 r
.59482 .52806 .60204 .53509 .61625 .53069 .60908 .5235 Mtetra
.67 .764 .921 r
.60908 .5235 .61625 .53069 .63053 .52628 .6234 .51889 Mtetra
.67 .76 .918 r
.6234 .51889 .63053 .52628 .64488 .52186 .6378 .51426 Mtetra
.669 .755 .915 r
.6378 .51426 .64488 .52186 .6593 .51744 .65227 .50965 Mtetra
.667 .75 .912 r
.65227 .50965 .6593 .51744 .6738 .51302 .66681 .50507 Mtetra
.666 .747 .911 r
.66681 .50507 .6738 .51302 .68837 .5086 .68143 .50052 Mtetra
.665 .745 .909 r
.68143 .50052 .68837 .5086 .70302 .50417 .69613 .496 Mtetra
.664 .743 .909 r
.69613 .496 .70302 .50417 .71775 .49971 .71091 .49147 Mtetra
.664 .742 .908 r
.71091 .49147 .71775 .49971 .73255 .49524 .72577 .48695 Mtetra
.72577 .48695 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.664 .741 .908 r
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.663 .741 .908 r
.38141 .58164 .38939 .58906 .40261 .58505 .39467 .57759 Mtetra
.39467 .57759 .40261 .58505 .41589 .58102 .408 .57352 Mtetra
.408 .57352 .41589 .58102 .42925 .57698 .42139 .56944 Mtetra
.42139 .56944 .42925 .57698 .44266 .57293 .43485 .56536 Mtetra
.662 .741 .909 r
.43485 .56536 .44266 .57293 .45615 .56889 .44838 .56128 Mtetra
.661 .741 .909 r
.44838 .56128 .45615 .56889 .4697 .56486 .46198 .55723 Mtetra
.658 .741 .911 r
.46198 .55723 .4697 .56486 .48332 .56086 .47564 .55325 Mtetra
.655 .741 .913 r
.47564 .55325 .48332 .56086 .49701 .55689 .48937 .54935 Mtetra
.652 .743 .916 r
.48937 .54935 .49701 .55689 .51077 .55296 .50317 .54555 Mtetra
.648 .746 .921 r
.50317 .54555 .51077 .55296 .5246 .54903 .51705 .54184 Mtetra
.645 .753 .927 r
.51705 .54184 .5246 .54903 .5385 .54506 .531 .53818 Mtetra
.644 .762 .934 r
.531 .53818 .5385 .54506 .55247 .54101 .54503 .53447 Mtetra
.646 .774 .941 r
.54503 .53447 .55247 .54101 .56652 .53684 .55913 .53062 Mtetra
.652 .786 .946 r
.55913 .53062 .56652 .53684 .58064 .53252 .5733 .52651 Mtetra
.659 .795 .947 r
.5733 .52651 .58064 .53252 .59482 .52806 .58755 .5221 Mtetra
.667 .8 .946 r
.58755 .5221 .59482 .52806 .60908 .5235 .60186 .51741 Mtetra
.673 .799 .942 r
.60186 .51741 .60908 .5235 .6234 .51889 .61623 .51251 Mtetra
.677 .793 .936 r
.61623 .51251 .6234 .51889 .6378 .51426 .63068 .5075 Mtetra
.677 .783 .929 r
.63068 .5075 .6378 .51426 .65227 .50965 .64519 .50249 Mtetra
.675 .772 .923 r
.64519 .50249 .65227 .50965 .66681 .50507 .65978 .49754 Mtetra
.672 .762 .918 r
.65978 .49754 .66681 .50507 .68143 .50052 .67445 .49269 Mtetra
.67 .754 .914 r
.67445 .49269 .68143 .50052 .69613 .496 .68919 .48794 Mtetra
.667 .749 .911 r
.68919 .48794 .69613 .496 .71091 .49147 .70402 .48325 Mtetra
.666 .745 .91 r
.70402 .48325 .71091 .49147 .72577 .48695 .71892 .47862 Mtetra
.665 .743 .909 r
.71892 .47862 .72577 .48695 .7407 .4824 .73391 .474 Mtetra
.664 .742 .908 r
.73391 .474 .7407 .4824 .75571 .47784 .74897 .46938 Mtetra
.74897 .46938 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.664 .741 .908 r
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.37336 .57414 .38141 .58164 .39467 .57759 .38666 .57005 Mtetra
.663 .741 .908 r
.38666 .57005 .39467 .57759 .408 .57352 .40003 .56595 Mtetra
.40003 .56595 .408 .57352 .42139 .56944 .41347 .56183 Mtetra
.41347 .56183 .42139 .56944 .43485 .56536 .42697 .5577 Mtetra
.662 .741 .908 r
.42697 .5577 .43485 .56536 .44838 .56128 .44054 .55358 Mtetra
.661 .74 .909 r
.44054 .55358 .44838 .56128 .46198 .55723 .45418 .5495 Mtetra
.658 .739 .91 r
.45418 .5495 .46198 .55723 .47564 .55325 .46789 .5455 Mtetra
.653 .739 .913 r
.46789 .5455 .47564 .55325 .48937 .54935 .48166 .54164 Mtetra
.647 .739 .917 r
.48166 .54164 .48937 .54935 .50317 .54555 .49551 .53798 Mtetra
.639 .741 .923 r
.49551 .53798 .50317 .54555 .51705 .54184 .50943 .53456 Mtetra
.629 .747 .932 r
.50943 .53456 .51705 .54184 .531 .53818 .52342 .53135 Mtetra
.621 .759 .944 r
.52342 .53135 .531 .53818 .54503 .53447 .5375 .52827 Mtetra
.616 .777 .958 r
.5375 .52827 .54503 .53447 .55913 .53062 .55167 .52513 Mtetra
.617 .801 .97 r
.55167 .52513 .55913 .53062 .5733 .52651 .56591 .52172 Mtetra
.625 .827 .978 r
.56591 .52172 .5733 .52651 .58755 .5221 .58022 .51783 Mtetra
.64 .849 .98 r
.58022 .51783 .58755 .5221 .60186 .51741 .59461 .51334 Mtetra
.658 .861 .977 r
.59461 .51334 .60186 .51741 .61623 .51251 .60905 .50827 Mtetra
.676 .861 .97 r
.60905 .50827 .61623 .51251 .63068 .5075 .62355 .50277 Mtetra
.687 .849 .961 r
.62355 .50277 .63068 .5075 .64519 .50249 .63811 .49705 Mtetra
.691 .829 .95 r
.63811 .49705 .64519 .50249 .65978 .49754 .65273 .49134 Mtetra
.688 .807 .938 r
.65273 .49134 .65978 .49754 .67445 .49269 .66743 .48578 Mtetra
.683 .786 .928 r
.66743 .48578 .67445 .49269 .68919 .48794 .68221 .48044 Mtetra
.676 .769 .92 r
.68221 .48044 .68919 .48794 .70402 .48325 .69707 .47534 Mtetra
.671 .757 .915 r
.69707 .47534 .70402 .48325 .71892 .47862 .71202 .47042 Mtetra
.668 .75 .912 r
.71202 .47042 .71892 .47862 .73391 .474 .72706 .46561 Mtetra
.666 .745 .91 r
.72706 .46561 .73391 .474 .74897 .46938 .74217 .46087 Mtetra
.665 .743 .909 r
.74217 .46087 .74897 .46938 .76412 .46474 .75737 .45616 Mtetra
.664 .742 .908 r
.75737 .45616 .76412 .46474 .77935 .46009 .77266 .45144 Mtetra
.77266 .45144 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.664 .741 .908 r
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44197 Mtetra
.80347 .44197 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.663 .741 .908 r
.37858 .56245 .38666 .57005 .40003 .56595 .39199 .55831 Mtetra
.39199 .55831 .40003 .56595 .41347 .56183 .40547 .55415 Mtetra
.40547 .55415 .41347 .56183 .42697 .5577 .41902 .54997 Mtetra
.662 .741 .908 r
.41902 .54997 .42697 .5577 .44054 .55358 .43263 .54581 Mtetra
.661 .74 .909 r
.43263 .54581 .44054 .55358 .45418 .5495 .44631 .54167 Mtetra
.658 .739 .909 r
.44631 .54167 .45418 .5495 .46789 .5455 .46006 .53762 Mtetra
.653 .737 .911 r
.46006 .53762 .46789 .5455 .48166 .54164 .47388 .53375 Mtetra
.644 .735 .915 r
.47388 .53375 .48166 .54164 .49551 .53798 .48777 .53015 Mtetra
.631 .734 .922 r
.48777 .53015 .49551 .53798 .50943 .53456 .50173 .52695 Mtetra
.614 .735 .932 r
.50173 .52695 .50943 .53456 .52342 .53135 .51577 .52422 Mtetra
.593 .742 .948 r
.51577 .52422 .52342 .53135 .5375 .52827 .5299 .52195 Mtetra
.569 .759 .968 r
.5299 .52195 .5375 .52827 .55167 .52513 .54412 .51996 Mtetra
.546 .789 .988 r
.54412 .51996 .55167 .52513 .56591 .52172 .55844 .51791 Mtetra
.527 .827 .999 r
.55844 .51791 .56591 .52172 .58022 .51783 .57284 .51539 Mtetra
.52 .866 .991 r
.57284 .51539 .58022 .51783 .59461 .51334 .58732 .51197 Mtetra
.533 .898 .968 r
.58732 .51197 .59461 .51334 .60905 .50827 .60185 .50742 Mtetra
.572 .924 .953 r
.60185 .50742 .60905 .50827 .62355 .50277 .61644 .50176 Mtetra
.627 .941 .956 r
.61644 .50176 .62355 .50277 .63811 .49705 .63106 .49525 Mtetra
.676 .938 .966 r
.63106 .49525 .63811 .49705 .65273 .49134 .64572 .48832 Mtetra
.703 .911 .967 r
.64572 .48832 .65273 .49134 .66743 .48578 .66045 .48137 Mtetra
.708 .871 .958 r
.66045 .48137 .66743 .48578 .68221 .48044 .67524 .47474 Mtetra
.7 .83 .944 r
.67524 .47474 .68221 .48044 .69707 .47534 .69012 .46857 Mtetra
.689 .796 .931 r
.69012 .46857 .69707 .47534 .71202 .47042 .70509 .46287 Mtetra
.679 .773 .921 r
.70509 .46287 .71202 .47042 .72706 .46561 .72016 .45755 Mtetra
.672 .758 .915 r
.72016 .45755 .72706 .46561 .74217 .46087 .73532 .45249 Mtetra
.668 .75 .911 r
.73532 .45249 .74217 .46087 .75737 .45616 .75057 .44759 Mtetra
.666 .745 .909 r
.75057 .44759 .75737 .45616 .77266 .45144 .7659 .44276 Mtetra
.664 .743 .909 r
.7659 .44276 .77266 .45144 .78802 .44671 .78133 .43795 Mtetra
.664 .742 .908 r
.78133 .43795 .78802 .44671 .80347 .44197 .79683 .43314 Mtetra
.664 .741 .908 r
.79683 .43314 .80347 .44197 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42347 Mtetra
.8281 .42347 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.663 .741 .908 r
.38388 .5506 .39199 .55831 .40547 .55415 .3974 .54639 Mtetra
.3974 .54639 .40547 .55415 .41902 .54997 .41099 .54218 Mtetra
.41099 .54218 .41902 .54997 .43263 .54581 .42464 .53795 Mtetra
.662 .74 .908 r
.42464 .53795 .43263 .54581 .44631 .54167 .43837 .53375 Mtetra
.659 .739 .909 r
.43837 .53375 .44631 .54167 .46006 .53762 .45216 .52963 Mtetra
.654 .736 .91 r
.45216 .52963 .46006 .53762 .47388 .53375 .46603 .52566 Mtetra
.645 .732 .913 r
.46603 .52566 .47388 .53375 .48777 .53015 .47996 .52201 Mtetra
.629 .727 .918 r
.47996 .52201 .48777 .53015 .50173 .52695 .49396 .51886 Mtetra
.605 .721 .927 r
.49396 .51886 .50173 .52695 .51577 .52422 .50805 .51643 Mtetra
.571 .718 .942 r
.50805 .51643 .51577 .52422 .5299 .52195 .52222 .51487 Mtetra
.522 .72 .963 r
.52222 .51487 .5299 .52195 .54412 .51996 .53649 .51415 Mtetra
.456 .733 .987 r
.53649 .51415 .54412 .51996 .55844 .51791 .55087 .514 Mtetra
.364 .751 .988 r
.55087 .514 .55844 .51791 .57284 .51539 .56537 .51384 Mtetra
.249 .745 .908 r
.56537 .51384 .57284 .51539 .58732 .51197 .57997 .51287 Mtetra
.155 .696 .739 r
.57997 .51287 .58732 .51197 .60185 .50742 .59464 .51036 Mtetra
0 0 0 r
.59464 .51036 .60185 .50742 .61644 .50176 .60935 .50584 Mtetra
.60935 .50584 .61644 .50176 .63106 .49525 .62409 .4993 Mtetra
.62409 .4993 .63106 .49525 .64572 .48832 .63883 .4912 Mtetra
.486 .885 .731 r
.63883 .4912 .64572 .48832 .66045 .48137 .65359 .48229 Mtetra
.637 .965 .872 r
.65359 .48229 .66045 .48137 .67524 .47474 .66839 .47334 Mtetra
.713 .959 .946 r
.66839 .47334 .67524 .47474 .69012 .46857 .68325 .46495 Mtetra
.725 .903 .958 r
.68325 .46495 .69012 .46857 .70509 .46287 .69821 .4574 Mtetra
.71 .844 .946 r
.69821 .4574 .70509 .46287 .72016 .45755 .71327 .45071 Mtetra
.693 .8 .931 r
.71327 .45071 .72016 .45755 .73532 .45249 .72844 .44475 Mtetra
.68 .773 .921 r
.72844 .44475 .73532 .45249 .75057 .44759 .74372 .4393 Mtetra
.672 .757 .914 r
.74372 .4393 .75057 .44759 .7659 .44276 .7591 .43415 Mtetra
.668 .748 .911 r
.7591 .43415 .7659 .44276 .78133 .43795 .77457 .42917 Mtetra
.665 .744 .909 r
.77457 .42917 .78133 .43795 .79683 .43314 .79013 .42425 Mtetra
.664 .742 .908 r
.79013 .42425 .79683 .43314 .81242 .42831 .80578 .41936 Mtetra
.80578 .41936 .81242 .42831 .8281 .42347 .82151 .41445 Mtetra
.664 .741 .908 r
.82151 .41445 .8281 .42347 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.663 .741 .908 r
.38925 .53857 .3974 .54639 .41099 .54218 .40288 .53431 Mtetra
.40288 .53431 .41099 .54218 .42464 .53795 .41658 .53003 Mtetra
.662 .74 .908 r
.41658 .53003 .42464 .53795 .43837 .53375 .43035 .52577 Mtetra
.661 .739 .908 r
.43035 .52577 .43837 .53375 .45216 .52963 .44419 .52154 Mtetra
.657 .737 .909 r
.44419 .52154 .45216 .52963 .46603 .52566 .4581 .51745 Mtetra
.649 .732 .91 r
.4581 .51745 .46603 .52566 .47996 .52201 .47208 .51362 Mtetra
.634 .724 .913 r
.47208 .51362 .47996 .52201 .49396 .51886 .48613 .51031 Mtetra
.608 .712 .919 r
.48613 .51031 .49396 .51886 .50805 .51643 .50025 .50784 Mtetra
.566 .697 .929 r
.50025 .50784 .50805 .51643 .52222 .51487 .51446 .50657 Mtetra
.502 .678 .945 r
.51446 .50657 .52222 .51487 .53649 .51415 .52877 .50675 Mtetra
.402 .659 .963 r
.52877 .50675 .53649 .51415 .55087 .514 .54321 .50841 Mtetra
.241 .63 .959 r
.54321 .50841 .55087 .514 .56537 .51384 .55779 .51108 Mtetra
0 .545 .827 r
.55779 .51108 .56537 .51384 .57997 .51287 .5725 .51384 Mtetra
.221 0 0 r
.5725 .51384 .57997 .51287 .59464 .51036 .58734 .51538 Mtetra
.283 0 0 r
.58734 .51538 .59464 .51036 .60935 .50584 .60225 .51441 Mtetra
.25 0 0 r
.60225 .51441 .60935 .50584 .62409 .4993 .61718 .51009 Mtetra
.174 0 0 r
.61718 .51009 .62409 .4993 .63883 .4912 .63209 .50234 Mtetra
.063 0 0 r
.63209 .50234 .63883 .4912 .65359 .48229 .64694 .4919 Mtetra
0 0 0 r
.64694 .4919 .65359 .48229 .66839 .47334 .66177 .48002 Mtetra
.66177 .48002 .66839 .47334 .68325 .46495 .6766 .46803 Mtetra
.584 .927 .731 r
.6766 .46803 .68325 .46495 .69821 .4574 .6915 .45693 Mtetra
.723 .979 .915 r
.6915 .45693 .69821 .4574 .71327 .45071 .7065 .44725 Mtetra
.737 .915 .954 r
.7065 .44725 .71327 .45071 .72844 .44475 .72162 .43907 Mtetra
.715 .844 .943 r
.72162 .43907 .72844 .44475 .74372 .4393 .73688 .43213 Mtetra
.693 .796 .929 r
.73688 .43213 .74372 .4393 .7591 .43415 .75226 .42608 Mtetra
.679 .768 .918 r
.75226 .42608 .7591 .43415 .77457 .42917 .76776 .42059 Mtetra
.671 .753 .913 r
.76776 .42059 .77457 .42917 .79013 .42425 .78337 .41541 Mtetra
.667 .746 .91 r
.78337 .41541 .79013 .42425 .80578 .41936 .79907 .41036 Mtetra
.665 .743 .909 r
.79907 .41036 .80578 .41936 .82151 .41445 .81486 .40537 Mtetra
.664 .742 .908 r
.81486 .40537 .82151 .41445 .83733 .40953 .83074 .40038 Mtetra
.83074 .40038 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.664 .741 .908 r
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Mtetra
.663 .741 .908 r
.38103 .53067 .38925 .53857 .40288 .53431 .3947 .52637 Mtetra
.3947 .52637 .40288 .53431 .41658 .53003 .40845 .52205 Mtetra
.40845 .52205 .41658 .53003 .43035 .52577 .42226 .51772 Mtetra
.662 .74 .908 r
.42226 .51772 .43035 .52577 .44419 .52154 .43615 .5134 Mtetra
.659 .738 .908 r
.43615 .5134 .44419 .52154 .4581 .51745 .4501 .50917 Mtetra
.653 .734 .909 r
.4501 .50917 .4581 .51745 .47208 .51362 .46413 .50513 Mtetra
.641 .726 .91 r
.46413 .50513 .47208 .51362 .48613 .51031 .47822 .50151 Mtetra
.619 .712 .912 r
.47822 .50151 .48613 .51031 .50025 .50784 .49239 .49866 Mtetra
.579 .689 .916 r
.49239 .49866 .50025 .50784 .51446 .50657 .50664 .4971 Mtetra
.514 .655 .923 r
.50664 .4971 .51446 .50657 .52877 .50675 .52098 .49737 Mtetra
.41 .608 .93 r
.52098 .49737 .52877 .50675 .54321 .50841 .53545 .49994 Mtetra
.239 .541 .925 r
.53545 .49994 .54321 .50841 .55779 .51108 .55008 .50484 Mtetra
0 .423 .843 r
.55008 .50484 .55779 .51108 .5725 .51384 .56488 .51145 Mtetra
.381 0 0 r
.56488 .51145 .5725 .51384 .58734 .51538 .57988 .51836 Mtetra
.514 0 0 r
.57988 .51836 .58734 .51538 .60225 .51441 .59501 .52355 Mtetra
.479 .025 .095 r
.59501 .52355 .60225 .51441 .61718 .51009 .61022 .52495 Mtetra
.402 .017 .19 r
.61022 .52495 .61718 .51009 .63209 .50234 .62541 .52112 Mtetra
.318 0 .216 r
.62541 .52112 .63209 .50234 .64694 .4919 .64051 .51187 Mtetra
.227 0 .196 r
.64051 .51187 .64694 .4919 .66177 .48002 .65547 .49827 Mtetra
.116 0 .128 r
.65547 .49827 .66177 .48002 .6766 .46803 .67033 .48228 Mtetra
0 0 0 r
.67033 .48228 .6766 .46803 .6915 .45693 .68515 .46602 Mtetra
.68515 .46602 .6915 .45693 .7065 .44725 .70003 .45111 Mtetra
.591 .914 .674 r
.70003 .45111 .7065 .44725 .72162 .43907 .71502 .43843 Mtetra
.743 .982 .91 r
.71502 .43843 .72162 .43907 .73688 .43213 .73016 .4281 Mtetra
.741 .903 .95 r
.73016 .4281 .73688 .43213 .75226 .42608 .74548 .41977 Mtetra
.711 .829 .938 r
.74548 .41977 .75226 .42608 .76776 .42059 .76096 .41289 Mtetra
.688 .785 .924 r
.76096 .41289 .76776 .42059 .78337 .41541 .77657 .40693 Mtetra
.675 .761 .915 r
.77657 .40693 .78337 .41541 .79907 .41036 .79231 .40147 Mtetra
.669 .75 .911 r
.79231 .40147 .79907 .41036 .81486 .40537 .80815 .39627 Mtetra
.666 .745 .909 r
.80815 .39627 .81486 .40537 .83074 .40038 .82409 .39116 Mtetra
.664 .742 .908 r
.82409 .39116 .83074 .40038 .84672 .39537 .84012 .38608 Mtetra
.84012 .38608 .84672 .39537 .86278 .39034 .85625 .38099 Mtetra
.664 .741 .908 r
.85625 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Mtetra
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51836 Mtetra
.663 .741 .908 r
.38644 .51836 .3947 .52637 .40845 .52205 .40023 .51399 Mtetra
.40023 .51399 .40845 .52205 .42226 .51772 .41409 .5096 Mtetra
.41409 .5096 .42226 .51772 .43615 .5134 .42802 .50522 Mtetra
.661 .739 .908 r
.42802 .50522 .43615 .5134 .4501 .50917 .44203 .50086 Mtetra
.658 .737 .908 r
.44203 .50086 .4501 .50917 .46413 .50513 .4561 .49662 Mtetra
.65 .73 .908 r
.4561 .49662 .46413 .50513 .47822 .50151 .47024 .49265 Mtetra
.633 .718 .908 r
.47024 .49265 .47822 .50151 .49239 .49866 .48446 .48927 Mtetra
.602 .695 .908 r
.48446 .48927 .49239 .49866 .50664 .4971 .49875 .48698 Mtetra
.547 .657 .908 r
.49875 .48698 .50664 .4971 .52098 .49737 .51312 .4865 Mtetra
.457 .598 .904 r
.51312 .4865 .52098 .49737 .53545 .49994 .52761 .48865 Mtetra
.316 .514 .891 r
.52761 .48865 .53545 .49994 .55008 .50484 .54226 .4941 Mtetra
.095 .393 .85 r
.54226 .4941 .55008 .50484 .56488 .51145 .5571 .50302 Mtetra
0 .212 .713 r
.5571 .50302 .56488 .51145 .57988 .51836 .57219 .51459 Mtetra
.58 .016 0 r
.57219 .51459 .57988 .51836 .59501 .52355 .58751 .52685 Mtetra
.654 .142 .015 r
.58751 .52685 .59501 .52355 .61022 .52495 .60302 .53687 Mtetra
.568 .151 .211 r
.60302 .53687 .61022 .52495 .62541 .52112 .61859 .54154 Mtetra
.465 .116 .289 r
.61859 .54154 .62541 .52112 .64051 .51187 .6341 .53864 Mtetra
.371 .066 .312 r
.6341 .53864 .64051 .51187 .65547 .49827 .6494 .5277 Mtetra
.285 .006 .302 r
.6494 .5277 .65547 .49827 .67033 .48228 .66446 .51023 Mtetra
.195 0 .262 r
.66446 .51023 .67033 .48228 .68515 .46602 .67931 .48906 Mtetra
.085 0 .179 r
.67931 .48906 .68515 .46602 .70003 .45111 .69407 .46734 Mtetra
0 0 .013 r
.69407 .46734 .70003 .45111 .71502 .43843 .70886 .44753 Mtetra
0 0 0 r
.70886 .44753 .71502 .43843 .73016 .4281 .72379 .43095 Mtetra
.668 .958 .737 r
.72379 .43095 .73016 .4281 .74548 .41977 .73892 .41784 Mtetra
.762 .965 .93 r
.73892 .41784 .74548 .41977 .76096 .41289 .75426 .4077 Mtetra
.734 .872 .945 r
.75426 .4077 .76096 .41289 .77657 .40693 .76981 .39974 Mtetra
.701 .807 .93 r
.76981 .39974 .77657 .40693 .79231 .40147 .78553 .39316 Mtetra
.681 .771 .919 r
.78553 .39316 .79231 .40147 .80815 .39627 .8014 .38737 Mtetra
.671 .754 .913 r
.8014 .38737 .80815 .39627 .82409 .39116 .81738 .38197 Mtetra
.667 .746 .91 r
.81738 .38197 .82409 .39116 .84012 .38608 .83347 .37674 Mtetra
.665 .743 .909 r
.83347 .37674 .84012 .38608 .85625 .38099 .84965 .37156 Mtetra
.664 .742 .908 r
.84965 .37156 .85625 .38099 .87246 .37588 .86593 .36638 Mtetra
.664 .741 .908 r
.86593 .36638 .87246 .37588 .88876 .37074 .8823 .36119 Mtetra
.8823 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Mtetra
.36434 .51466 .37272 .5227 .38644 .51836 .37811 .51027 Mtetra
.37811 .51027 .38644 .51836 .40023 .51399 .39194 .50586 Mtetra
.663 .741 .908 r
.39194 .50586 .40023 .51399 .41409 .5096 .40584 .50143 Mtetra
.40584 .50143 .41409 .5096 .42802 .50522 .41982 .49698 Mtetra
.663 .74 .908 r
.41982 .49698 .42802 .50522 .44203 .50086 .43387 .49253 Mtetra
.661 .739 .908 r
.43387 .49253 .44203 .50086 .4561 .49662 .44799 .48813 Mtetra
.656 .735 .907 r
.44799 .48813 .4561 .49662 .47024 .49265 .46218 .48388 Mtetra
.646 .726 .907 r
.46218 .48388 .47024 .49265 .48446 .48927 .47645 .47998 Mtetra
.625 .708 .905 r
.47645 .47998 .48446 .48927 .49875 .48698 .49079 .47685 Mtetra
.586 .674 .901 r
.49079 .47685 .49875 .48698 .51312 .4865 .5052 .47513 Mtetra
.517 .619 .892 r
.5052 .47513 .51312 .4865 .52761 .48865 .51972 .47578 Mtetra
.41 .535 .872 r
.51972 .47578 .52761 .48865 .54226 .4941 .53437 .47992 Mtetra
.253 .421 .836 r
.53437 .47992 .54226 .4941 .5571 .50302 .5492 .4885 Mtetra
.036 .277 .772 r
.5492 .4885 .5571 .50302 .57219 .51459 .5643 .50183 Mtetra
0 .097 .651 r
.5643 .50183 .57219 .51459 .58751 .52685 .5797 .51897 Mtetra
.608 .11 0 r
.5797 .51897 .58751 .52685 .60302 .53687 .59541 .53738 Mtetra
.74 .229 0 r
.59541 .53738 .60302 .53687 .61859 .54154 .61134 .55313 Mtetra
.631 .213 .231 r
.61134 .55313 .61859 .54154 .6341 .53864 .62735 .56189 Mtetra
.496 .157 .322 r
.62735 .56189 .6341 .53864 .6494 .5277 .64321 .56041 Mtetra
.386 .098 .348 r
.64321 .56041 .6494 .5277 .66446 .51023 .65875 .54785 Mtetra
.297 .04 .344 r
.65875 .54785 .66446 .51023 .67931 .48906 .67389 .52612 Mtetra
.215 0 .318 r
.67389 .52612 .67931 .48906 .69407 .46734 .68871 .4991 Mtetra
.126 0 .262 r
.68871 .4991 .69407 .46734 .70886 .44753 .70334 .47112 Mtetra
.005 0 .154 r
.70334 .47112 .70886 .44753 .72379 .43095 .71799 .44562 Mtetra
0 0 0 r
.71799 .44562 .72379 .43095 .73892 .41784 .7328 .42449 Mtetra
.7328 .42449 .73892 .41784 .75426 .4077 .74787 .40811 Mtetra
.754 .995 .856 r
.74787 .40811 .75426 .4077 .76981 .39974 .76322 .39583 Mtetra
.758 .918 .944 r
.76322 .39583 .76981 .39974 .78553 .39316 .77883 .38657 Mtetra
.717 .832 .936 r
.77883 .38657 .78553 .39316 .8014 .38737 .79465 .37927 Mtetra
.689 .783 .923 r
.79465 .37927 .8014 .38737 .81738 .38197 .81063 .37308 Mtetra
.675 .759 .914 r
.81063 .37308 .81738 .38197 .83347 .37674 .82676 .36746 Mtetra
.668 .748 .911 r
.82676 .36746 .83347 .37674 .84965 .37156 .84299 .36209 Mtetra
.665 .744 .909 r
.84299 .36209 .84965 .37156 .86593 .36638 .85933 .35681 Mtetra
.664 .742 .908 r
.85933 .35681 .86593 .36638 .8823 .36119 .87576 .35154 Mtetra
.87576 .35154 .8823 .36119 .89876 .35597 .89229 .34626 Mtetra
.664 .741 .908 r
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .5021 Mtetra
.36969 .5021 .37811 .51027 .39194 .50586 .38357 .49765 Mtetra
.38357 .49765 .39194 .50586 .40584 .50143 .39752 .49317 Mtetra
.663 .741 .908 r
.39752 .49317 .40584 .50143 .41982 .49698 .41154 .48868 Mtetra
.41154 .48868 .41982 .49698 .43387 .49253 .42563 .48416 Mtetra
.662 .74 .908 r
.42563 .48416 .43387 .49253 .44799 .48813 .4398 .47966 Mtetra
.66 .738 .907 r
.4398 .47966 .44799 .48813 .46218 .48388 .45405 .47521 Mtetra
.655 .733 .907 r
.45405 .47521 .46218 .48388 .47645 .47998 .46836 .47093 Mtetra
.643 .721 .905 r
.46836 .47093 .47645 .47998 .49079 .47685 .48275 .46708 Mtetra
.619 .697 .901 r
.48275 .46708 .49079 .47685 .5052 .47513 .49721 .46415 Mtetra
.573 .654 .891 r
.49721 .46415 .5052 .47513 .51972 .47578 .51176 .46292 Mtetra
.496 .582 .871 r
.51176 .46292 .51972 .47578 .53437 .47992 .52642 .46458 Mtetra
.383 .48 .835 r
.52642 .46458 .53437 .47992 .5492 .4885 .54124 .47052 Mtetra
.237 .356 .782 r
.54124 .47052 .5492 .4885 .5643 .50183 .55628 .482 Mtetra
.065 .222 .717 r
.55628 .482 .5643 .50183 .5797 .51897 .57164 .49953 Mtetra
0 .083 .637 r
.57164 .49953 .5797 .51897 .59541 .53738 .58738 .5221 Mtetra
0 0 .509 r
.58738 .5221 .59541 .53738 .61134 .55313 .6035 .54668 Mtetra
.728 .227 0 r
.6035 .54668 .61134 .55313 .62735 .56189 .61991 .56838 Mtetra
.698 .235 .148 r
.61991 .56838 .62735 .56189 .64321 .56041 .63638 .58163 Mtetra
.514 .159 .303 r
.63638 .58163 .64321 .56041 .65875 .54785 .65263 .58203 Mtetra
.376 .091 .348 r
.65263 .58203 .65875 .54785 .67389 .52612 .66842 .56823 Mtetra
.278 .034 .352 r
.66842 .56823 .67389 .52612 .68871 .4991 .68365 .54248 Mtetra
.2 0 .334 r
.68365 .54248 .68871 .4991 .70334 .47112 .6984 .50967 Mtetra
.122 0 .292 r
.6984 .50967 .70334 .47112 .71799 .44562 .71289 .47536 Mtetra
.024 0 .213 r
.71289 .47536 .71799 .44562 .7328 .42449 .72736 .44405 Mtetra
0 0 .052 r
.72736 .44405 .7328 .42449 .74787 .40811 .74203 .41823 Mtetra
0 0 0 r
.74203 .41823 .74787 .40811 .76322 .39583 .75702 .39844 Mtetra
.714 .972 .737 r
.75702 .39844 .76322 .39583 .77883 .38657 .77235 .38391 Mtetra
.777 .957 .929 r
.77235 .38391 .77883 .38657 .79465 .37927 .788 .37328 Mtetra
.733 .858 .94 r
.788 .37328 .79465 .37927 .81063 .37308 .80391 .3652 Mtetra
.697 .796 .926 r
.80391 .3652 .81063 .37308 .82676 .36746 .82002 .35859 Mtetra
.678 .765 .916 r
.82002 .35859 .82676 .36746 .84299 .36209 .83628 .35273 Mtetra
.669 .751 .911 r
.83628 .35273 .84299 .36209 .85933 .35681 .85267 .34721 Mtetra
.666 .745 .909 r
.85267 .34721 .85933 .35681 .87576 .35154 .86916 .34182 Mtetra
.664 .742 .908 r
.86916 .34182 .87576 .35154 .89229 .34626 .88576 .33646 Mtetra
.88576 .33646 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.664 .741 .908 r
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Mtetra
.34734 .49834 .35588 .50654 .36969 .5021 .36119 .49386 Mtetra
.36119 .49386 .36969 .5021 .38357 .49765 .37511 .48936 Mtetra
.37511 .48936 .38357 .49765 .39752 .49317 .38911 .48484 Mtetra
.38911 .48484 .39752 .49317 .41154 .48868 .40318 .4803 Mtetra
.663 .741 .908 r
.40318 .4803 .41154 .48868 .42563 .48416 .41732 .47574 Mtetra
.41732 .47574 .42563 .48416 .4398 .47966 .43154 .47116 Mtetra
.662 .74 .908 r
.43154 .47116 .4398 .47966 .45405 .47521 .44583 .46658 Mtetra
.66 .737 .907 r
.44583 .46658 .45405 .47521 .46836 .47093 .46019 .46207 Mtetra
.654 .731 .906 r
.46019 .46207 .46836 .47093 .48275 .46708 .47463 .45776 Mtetra
.642 .717 .903 r
.47463 .45776 .48275 .46708 .49721 .46415 .48915 .45391 Mtetra
.615 .689 .896 r
.48915 .45391 .49721 .46415 .51176 .46292 .50374 .45108 Mtetra
.566 .636 .88 r
.50374 .45108 .51176 .46292 .52642 .46458 .51843 .45017 Mtetra
.487 .554 .85 r
.51843 .45017 .52642 .46458 .54124 .47052 .53323 .45251 Mtetra
.379 .444 .802 r
.53323 .45251 .54124 .47052 .55628 .482 .54822 .45972 Mtetra
.258 .325 .742 r
.54822 .45972 .55628 .482 .57164 .49953 .56347 .47335 Mtetra
.135 .215 .683 r
.56347 .47335 .57164 .49953 .58738 .5221 .57909 .4941 Mtetra
.013 .121 .632 r
.57909 .4941 .58738 .5221 .6035 .54668 .59517 .52099 Mtetra
0 .038 .592 r
.59517 .52099 .6035 .54668 .61991 .56838 .6117 .55069 Mtetra
0 0 .534 r
.6117 .55069 .61991 .56838 .63638 .58163 .62856 .57757 Mtetra
.681 .143 0 r
.62856 .57757 .63638 .58163 .65263 .58203 .64549 .59498 Mtetra
.515 .093 .177 r
.64549 .59498 .65263 .58203 .66842 .56823 .66212 .59749 Mtetra
.327 .03 .299 r
.66212 .59749 .66842 .56823 .68365 .54248 .67816 .58315 Mtetra
.221 0 .325 r
.67816 .58315 .68365 .54248 .6984 .50967 .69349 .55437 Mtetra
.148 0 .318 r
.69349 .55437 .6984 .50967 .71289 .47536 .70819 .51685 Mtetra
.08 0 .287 r
.70819 .51685 .71289 .47536 .72736 .44405 .72254 .47723 Mtetra
0 0 .223 r
.72254 .47723 .72736 .44405 .74203 .41823 .73686 .44091 Mtetra
0 0 .091 r
.73686 .44091 .74203 .41823 .75702 .39844 .75139 .41097 Mtetra
0 0 0 r
.75139 .41097 .75702 .39844 .77235 .38391 .7663 .38814 Mtetra
.677 .931 .634 r
.7663 .38814 .77235 .38391 .788 .37328 .78162 .37157 Mtetra
.789 .98 .905 r
.78162 .37157 .788 .37328 .80391 .3652 .79732 .35968 Mtetra
.747 .879 .94 r
.79732 .35968 .80391 .3652 .82002 .35859 .81333 .35087 Mtetra
.705 .806 .928 r
.81333 .35087 .82002 .35859 .83628 .35273 .82956 .34385 Mtetra
.682 .77 .917 r
.82956 .34385 .83628 .35273 .85267 .34721 .84597 .33776 Mtetra
.671 .753 .912 r
.84597 .33776 .85267 .34721 .86916 .34182 .86251 .33209 Mtetra
.666 .745 .909 r
.86251 .33209 .86916 .34182 .88576 .33646 .87916 .32659 Mtetra
.664 .743 .908 r
.87916 .32659 .88576 .33646 .90245 .33109 .89592 .32114 Mtetra
.664 .741 .908 r
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Mtetra
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Mtetra
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Mtetra
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Mtetra
.35261 .48554 .36119 .49386 .37511 .48936 .36658 .481 Mtetra
.36658 .481 .37511 .48936 .38911 .48484 .38062 .47643 Mtetra
.38062 .47643 .38911 .48484 .40318 .4803 .39473 .47184 Mtetra
.39473 .47184 .40318 .4803 .41732 .47574 .40892 .46723 Mtetra
.663 .741 .908 r
.40892 .46723 .41732 .47574 .43154 .47116 .42319 .4626 Mtetra
.42319 .4626 .43154 .47116 .44583 .46658 .43753 .45795 Mtetra
.662 .74 .908 r
.43753 .45795 .44583 .46658 .46019 .46207 .45194 .45331 Mtetra
.66 .737 .907 r
.45194 .45331 .46019 .46207 .47463 .45776 .46643 .44873 Mtetra
.654 .73 .905 r
.46643 .44873 .47463 .45776 .48915 .45391 .481 .44434 Mtetra
.641 .715 .901 r
.481 .44434 .48915 .45391 .50374 .45108 .49565 .44044 Mtetra
.614 .683 .891 r
.49565 .44044 .50374 .45108 .51843 .45017 .51037 .43759 Mtetra
.565 .625 .87 r
.51037 .43759 .51843 .45017 .53323 .45251 .5252 .43672 Mtetra
.489 .537 .833 r
.5252 .43672 .53323 .45251 .54822 .45972 .54015 .43926 Mtetra
.394 .428 .778 r
.54015 .43926 .54822 .45972 .56347 .47335 .55531 .44697 Mtetra
.297 .321 .717 r
.55531 .44697 .56347 .47335 .57909 .4941 .57076 .46153 Mtetra
.213 .232 .664 r
.57076 .46153 .57909 .4941 .59517 .52099 .58662 .48385 Mtetra
.146 .17 .628 r
.58662 .48385 .59517 .52099 .6117 .55069 .60298 .51305 Mtetra
.092 .133 .612 r
.60298 .51305 .6117 .55069 .62856 .57757 .61986 .54573 Mtetra
.04 .124 .625 r
.61986 .54573 .62856 .57757 .64549 .59498 .63711 .5759 Mtetra
0 .173 .699 r
.63711 .5759 .64549 .59498 .66212 .59749 .65442 .59629 Mtetra
.237 0 0 r
.65442 .59629 .66212 .59749 .67816 .58315 .67139 .60073 Mtetra
.142 0 .093 r
.67139 .60073 .67816 .58315 .69349 .55437 .68768 .58673 Mtetra
.079 0 .231 r
.68768 .58673 .69349 .55437 .70819 .51685 .70312 .55662 Mtetra
.037 0 .258 r
.70312 .55662 .70819 .51685 .72254 .47723 .71783 .51648 Mtetra
0 0 .244 r
.71783 .51648 .72254 .47723 .73686 .44091 .73211 .47363 Mtetra
0 0 .191 r
.73211 .47363 .73686 .44091 .75139 .41097 .74633 .43409 Mtetra
0 0 .074 r
.74633 .43409 .75139 .41097 .7663 .38814 .76079 .40138 Mtetra
0 0 0 r
.76079 .40138 .7663 .38814 .78162 .37157 .77566 .37643 Mtetra
.678 .916 .592 r
.77566 .37643 .78162 .37157 .79732 .35968 .79101 .35838 Mtetra
.8 .989 .886 r
.79101 .35838 .79732 .35968 .81333 .35087 .80678 .34555 Mtetra
.758 .891 .938 r
.80678 .34555 .81333 .35087 .82956 .34385 .82289 .33617 Mtetra
.711 .814 .929 r
.82289 .33617 .82956 .34385 .84597 .33776 .83925 .32882 Mtetra
.685 .773 .918 r
.83925 .32882 .84597 .33776 .86251 .33209 .85581 .32252 Mtetra
.672 .754 .912 r
.85581 .32252 .86251 .33209 .87916 .32659 .8725 .31672 Mtetra
.667 .746 .91 r
.8725 .31672 .87916 .32659 .89592 .32114 .88932 .31111 Mtetra
.664 .741 .908 r
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Mtetra
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Mtetra
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Mtetra
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Mtetra
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47255 Mtetra
.35796 .47255 .36658 .481 .38062 .47643 .37205 .46794 Mtetra
.37205 .46794 .38062 .47643 .39473 .47184 .38621 .46331 Mtetra
.38621 .46331 .39473 .47184 .40892 .46723 .40044 .45865 Mtetra
.40044 .45865 .40892 .46723 .42319 .4626 .41476 .45397 Mtetra
.663 .741 .908 r
.41476 .45397 .42319 .4626 .43753 .45795 .42914 .44926 Mtetra
.42914 .44926 .43753 .45795 .45194 .45331 .44361 .44454 Mtetra
.662 .74 .907 r
.44361 .44454 .45194 .45331 .46643 .44873 .45815 .43982 Mtetra
.66 .737 .907 r
.45815 .43982 .46643 .44873 .481 .44434 .47277 .43516 Mtetra
.655 .73 .905 r
.47277 .43516 .481 .44434 .49565 .44044 .48747 .43069 Mtetra
.643 .714 .899 r
.48747 .43069 .49565 .44044 .51037 .43759 .50225 .42667 Mtetra
.617 .681 .888 r
.50225 .42667 .51037 .43759 .5252 .43672 .51711 .42364 Mtetra
.571 .622 .864 r
.51711 .42364 .5252 .43672 .54015 .43926 .53207 .42254 Mtetra
.502 .534 .822 r
.53207 .42254 .54015 .43926 .55531 .44697 .54718 .42475 Mtetra
.419 .43 .764 r
.54718 .42475 .55531 .44697 .57076 .46153 .56249 .43203 Mtetra
.341 .333 .704 r
.56249 .43203 .57076 .46153 .58662 .48385 .57811 .44611 Mtetra
.282 .26 .656 r
.57811 .44611 .58662 .48385 .60298 .51305 .59416 .46798 Mtetra
.245 .215 .625 r
.59416 .46798 .60298 .51305 .61986 .54573 .61074 .49694 Mtetra
.229 .197 .614 r
.61074 .49694 .61986 .54573 .63711 .5759 .62786 .52974 Mtetra
.237 .21 .625 r
.62786 .52974 .63711 .5759 .65442 .59629 .64537 .56053 Mtetra
.282 .275 .674 r
.64537 .56053 .65442 .59629 .67139 .60073 .66295 .58199 Mtetra
.43 .485 .815 r
.66295 .58199 .67139 .60073 .68768 .58673 .68017 .58773 Mtetra
.734 .991 .851 r
.68017 .58773 .68768 .58673 .70312 .55662 .69667 .57489 Mtetra
0 0 0 r
.69667 .57489 .70312 .55662 .71783 .51648 .71226 .54549 Mtetra
0 0 .099 r
.71226 .54549 .71783 .51648 .73211 .47363 .72706 .50548 Mtetra
0 0 .137 r
.72706 .50548 .73211 .47363 .74633 .43409 .74139 .46221 Mtetra
0 0 .104 r
.74139 .46221 .74633 .43409 .76079 .40138 .75563 .42194 Mtetra
0 0 0 r
.75563 .42194 .76079 .40138 .77566 .37643 .77012 .38839 Mtetra
.77012 .38839 .77566 .37643 .79101 .35838 .78505 .36266 Mtetra
.724 .94 .622 r
.78505 .36266 .79101 .35838 .80678 .34555 .80047 .34399 Mtetra
.811 .987 .884 r
.80047 .34399 .80678 .34555 .82289 .33617 .81635 .33071 Mtetra
.763 .892 .935 r
.81635 .33071 .82289 .33617 .83925 .32882 .83258 .32101 Mtetra
.714 .815 .928 r
.83258 .32101 .83925 .32882 .85581 .32252 .84909 .31344 Mtetra
.686 .774 .918 r
.84909 .31344 .85581 .32252 .8725 .31672 .8658 .307 Mtetra
.673 .755 .912 r
.8658 .307 .8725 .31672 .88932 .31111 .88266 .30108 Mtetra
.664 .741 .908 r
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Mtetra
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Mtetra
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Mtetra
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46865 Mtetra
.3352 .46865 .34395 .47714 .35796 .47255 .34926 .46402 Mtetra
.34926 .46402 .35796 .47255 .37205 .46794 .36339 .45937 Mtetra
.36339 .45937 .37205 .46794 .38621 .46331 .3776 .45469 Mtetra
.3776 .45469 .38621 .46331 .40044 .45865 .39188 .44998 Mtetra
.39188 .44998 .40044 .45865 .41476 .45397 .40624 .44525 Mtetra
.40624 .44525 .41476 .45397 .42914 .44926 .42068 .4405 Mtetra
.663 .741 .908 r
.42068 .4405 .42914 .44926 .44361 .44454 .43519 .43572 Mtetra
.43519 .43572 .44361 .44454 .45815 .43982 .44978 .43093 Mtetra
.663 .74 .907 r
.44978 .43093 .45815 .43982 .47277 .43516 .46446 .42613 Mtetra
.661 .737 .907 r
.46446 .42613 .47277 .43516 .48747 .43069 .47921 .42138 Mtetra
.656 .731 .904 r
.47921 .42138 .48747 .43069 .50225 .42667 .49404 .41678 Mtetra
.645 .715 .899 r
.49404 .41678 .50225 .42667 .51711 .42364 .50895 .41259 Mtetra
.623 .683 .886 r
.50895 .41259 .51711 .42364 .53207 .42254 .52395 .40928 Mtetra
.582 .626 .861 r
.52395 .40928 .53207 .42254 .54718 .42475 .53905 .40769 Mtetra
.522 .542 .818 r
.53905 .40769 .54718 .42475 .56249 .43203 .5543 .40909 Mtetra
.45 .444 .76 r
.5543 .40909 .56249 .43203 .57811 .44611 .56975 .4151 Mtetra
.386 .355 .702 r
.56975 .4151 .57811 .44611 .59416 .46798 .58552 .42736 Mtetra
.34 .291 .656 r
.58552 .42736 .59416 .46798 .61074 .49694 .6017 .44685 Mtetra
.317 .254 .627 r
.6017 .44685 .61074 .49694 .62786 .52974 .61841 .47305 Mtetra
.315 .243 .614 r
.61841 .47305 .62786 .52974 .64537 .56053 .63564 .50309 Mtetra
.337 .258 .619 r
.63564 .50309 .64537 .56053 .66295 .58199 .65326 .53167 Mtetra
.389 .308 .643 r
.65326 .53167 .66295 .58199 .68017 .58773 .67096 .55203 Mtetra
.499 .419 .697 r
.67096 .55203 .68017 .58773 .69667 .57489 .68832 .5581 Mtetra
.724 .662 .789 r
.68832 .5581 .69667 .57489 .71226 .54549 .70497 .54696 Mtetra
.947 .958 .71 r
.70497 .54696 .71226 .54549 .72706 .50548 .72075 .52014 Mtetra
.693 .778 .296 r
.72075 .52014 .72706 .50548 .74139 .46221 .73574 .48295 Mtetra
0 0 0 r
.73574 .48295 .74139 .46221 .75563 .42194 .75026 .4422 Mtetra
.75026 .4422 .75563 .42194 .77012 .38839 .76468 .40385 Mtetra
.76468 .40385 .77012 .38839 .78505 .36266 .77933 .37156 Mtetra
.636 .816 .393 r
.77933 .37156 .78505 .36266 .80047 .34399 .79442 .34655 Mtetra
.795 .981 .707 r
.79442 .34655 .80047 .34399 .81635 .33071 .80999 .32822 Mtetra
.818 .974 .895 r
.80999 .32822 .81635 .33071 .83258 .32101 .82602 .31505 Mtetra
.761 .881 .932 r
.82602 .31505 .83258 .32101 .84909 .31344 .84241 .30534 Mtetra
.713 .811 .926 r
.84241 .30534 .84909 .31344 .8658 .307 .85909 .29771 Mtetra
.686 .773 .917 r
.85909 .29771 .8658 .307 .88266 .30108 .87596 .29117 Mtetra
.664 .741 .908 r
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Mtetra
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46936 Mtetra
.29838 .46936 .3073 .47784 .32121 .47326 .31234 .46474 Mtetra
.31234 .46474 .32121 .47326 .3352 .46865 .32636 .46009 Mtetra
.32636 .46009 .3352 .46865 .34926 .46402 .34047 .45541 Mtetra
.34047 .45541 .34926 .46402 .36339 .45937 .35465 .45071 Mtetra
.35465 .45071 .36339 .45937 .3776 .45469 .3689 .44598 Mtetra
.3689 .44598 .3776 .45469 .39188 .44998 .38323 .44123 Mtetra
.38323 .44123 .39188 .44998 .40624 .44525 .39764 .43645 Mtetra
.39764 .43645 .40624 .44525 .42068 .4405 .41213 .43165 Mtetra
.41213 .43165 .42068 .4405 .43519 .43572 .42669 .42682 Mtetra
.663 .741 .908 r
.42669 .42682 .43519 .43572 .44978 .43093 .44133 .42197 Mtetra
.44133 .42197 .44978 .43093 .46446 .42613 .45606 .4171 Mtetra
.663 .74 .907 r
.45606 .4171 .46446 .42613 .47921 .42138 .47086 .41222 Mtetra
.661 .738 .907 r
.47086 .41222 .47921 .42138 .49404 .41678 .48574 .40737 Mtetra
.657 .732 .904 r
.48574 .40737 .49404 .41678 .50895 .41259 .50071 .40265 Mtetra
.649 .718 .899 r
.50071 .40265 .50895 .41259 .52395 .40928 .51575 .39825 Mtetra
.63 .69 .887 r
.51575 .39825 .52395 .40928 .53905 .40769 .53089 .39457 Mtetra
.596 .638 .863 r
.53089 .39457 .53905 .40769 .5543 .40909 .54613 .39232 Mtetra
.545 .56 .821 r
.54613 .39232 .5543 .40909 .56975 .4151 .56152 .39258 Mtetra
.484 .469 .766 r
.56152 .39258 .56975 .4151 .58552 .42736 .5771 .39673 Mtetra
.429 .386 .709 r
.5771 .39673 .58552 .42736 .6017 .44685 .59297 .40619 Mtetra
.391 .325 .663 r
.59297 .40619 .6017 .44685 .61841 .47305 .60924 .42189 Mtetra
.373 .291 .633 r
.60924 .42189 .61841 .47305 .63564 .50309 .62598 .44342 Mtetra
.375 .28 .619 r
.62598 .44342 .63564 .50309 .65326 .53167 .64321 .46845 Mtetra
.397 .292 .618 r
.64321 .46845 .65326 .53167 .67096 .55203 .6608 .49252 Mtetra
.442 .329 .63 r
.6608 .49252 .67096 .55203 .68832 .5581 .67847 .50988 Mtetra
.52 .401 .657 r
.67847 .50988 .68832 .5581 .70497 .54696 .69586 .51526 Mtetra
.65 .529 .702 r
.69586 .51526 .70497 .54696 .72075 .52014 .71263 .50594 Mtetra
.843 .733 .743 r
.71263 .50594 .72075 .52014 .73574 .48295 .72861 .48294 Mtetra
.974 .918 .675 r
.72861 .48294 .73574 .48295 .75026 .4422 .74389 .45059 Mtetra
.881 .9 .484 r
.74389 .45059 .75026 .4422 .76468 .40385 .75873 .41467 Mtetra
.763 .838 .381 r
.75873 .41467 .76468 .40385 .77933 .37156 .77347 .38043 Mtetra
.744 .858 .425 r
.77347 .38043 .77933 .37156 .79442 .34655 .78842 .35121 Mtetra
.803 .946 .597 r
.78842 .35121 .79442 .34655 .80999 .32822 .80376 .32824 Mtetra
.849 .998 .803 r
.80376 .32824 .80999 .32822 .82602 .31505 .81957 .31113 Mtetra
.814 .945 .909 r
.81957 .31113 .82602 .31505 .84241 .30534 .8358 .29858 Mtetra
.753 .862 .929 r
.8358 .29858 .84241 .30534 .85909 .29771 .85238 .28915 Mtetra
.709 .802 .923 r
.85238 .28915 .85909 .29771 .87596 .29117 .86923 .2816 Mtetra
.664 .741 .908 r
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Mtetra
.27545 .46545 .2845 .47397 .29838 .46936 .28937 .4608 Mtetra
.28937 .4608 .29838 .46936 .31234 .46474 .30337 .45613 Mtetra
.30337 .45613 .31234 .46474 .32636 .46009 .31744 .45143 Mtetra
.31744 .45143 .32636 .46009 .34047 .45541 .33159 .44671 Mtetra
.33159 .44671 .34047 .45541 .35465 .45071 .34582 .44196 Mtetra
.34582 .44196 .35465 .45071 .3689 .44598 .36012 .43719 Mtetra
.36012 .43719 .3689 .44598 .38323 .44123 .3745 .43239 Mtetra
.3745 .43239 .38323 .44123 .39764 .43645 .38896 .42757 Mtetra
.38896 .42757 .39764 .43645 .41213 .43165 .40349 .42272 Mtetra
.40349 .42272 .41213 .43165 .42669 .42682 .4181 .41784 Mtetra
.4181 .41784 .42669 .42682 .44133 .42197 .4328 .41294 Mtetra
.663 .741 .908 r
.4328 .41294 .44133 .42197 .45606 .4171 .44757 .40801 Mtetra
.44757 .40801 .45606 .4171 .47086 .41222 .46242 .40306 Mtetra
.663 .74 .908 r
.46242 .40306 .47086 .41222 .48574 .40737 .47736 .39809 Mtetra
.662 .739 .907 r
.47736 .39809 .48574 .40737 .50071 .40265 .49238 .39315 Mtetra
.659 .734 .905 r
.49238 .39315 .50071 .40265 .51575 .39825 .50748 .38829 Mtetra
.652 .722 .9 r
.50748 .38829 .51575 .39825 .53089 .39457 .52266 .38367 Mtetra
.638 .698 .889 r
.52266 .38367 .53089 .39457 .54613 .39232 .53794 .3796 Mtetra
.611 .654 .868 r
.53794 .3796 .54613 .39232 .56152 .39258 .55332 .37662 Mtetra
.57 .586 .83 r
.55332 .37662 .56152 .39258 .5771 .39673 .56884 .3756 Mtetra
.518 .503 .778 r
.56884 .3756 .5771 .39673 .59297 .40619 .58454 .37762 Mtetra
.47 .423 .724 r
.58454 .37762 .59297 .40619 .60924 .42189 .6005 .38385 Mtetra
.436 .363 .677 r
.6005 .38385 .60924 .42189 .62598 .44342 .6168 .39503 Mtetra
.419 .328 .645 r
.6168 .39503 .62598 .44342 .64321 .46845 .63352 .41093 Mtetra
.42 .314 .628 r
.63352 .41093 .64321 .46845 .6608 .49252 .65066 .42974 Mtetra
.438 .321 .622 r
.65066 .42974 .6608 .49252 .67847 .50988 .66812 .448 Mtetra
.475 .348 .628 r
.66812 .448 .67847 .50988 .69586 .51526 .68566 .46118 Mtetra
.533 .399 .644 r
.68566 .46118 .69586 .51526 .71263 .50594 .703 .46506 Mtetra
.62 .482 .672 r
.703 .46506 .71263 .50594 .72861 .48294 .71984 .45732 Mtetra
.743 .607 .707 r
.71984 .45732 .72861 .48294 .74389 .45059 .73605 .43855 Mtetra
.883 .768 .731 r
.73605 .43855 .74389 .45059 .75873 .41467 .75167 .41199 Mtetra
.965 .901 .708 r
.75167 .41199 .75873 .41467 .77347 .38043 .76692 .38216 Mtetra
.95 .953 .663 r
.76692 .38216 .77347 .38043 .78842 .35121 .78209 .35333 Mtetra
.913 .972 .678 r
.78209 .35333 .78842 .35121 .80376 .32824 .79743 .32832 Mtetra
.892 .989 .769 r
.79743 .32832 .80376 .32824 .81957 .31113 .81312 .30828 Mtetra
.856 .969 .869 r
.81312 .30828 .81957 .31113 .8358 .29858 .82922 .29298 Mtetra
.796 .904 .917 r
.82922 .29298 .8358 .29858 .85238 .28915 .8457 .28145 Mtetra
.739 .837 .925 r
.8457 .28145 .85238 .28915 .86923 .2816 .86249 .27251 Mtetra
.664 .741 .908 r
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Mtetra
.2663 .45685 .27545 .46545 .28937 .4608 .28027 .45216 Mtetra
.28027 .45216 .28937 .4608 .30337 .45613 .29432 .44744 Mtetra
.29432 .44744 .30337 .45613 .31744 .45143 .30844 .4427 Mtetra
.30844 .4427 .31744 .45143 .33159 .44671 .32263 .43793 Mtetra
.32263 .43793 .33159 .44671 .34582 .44196 .3369 .43313 Mtetra
.3369 .43313 .34582 .44196 .36012 .43719 .35125 .42831 Mtetra
.35125 .42831 .36012 .43719 .3745 .43239 .36568 .42346 Mtetra
.36568 .42346 .3745 .43239 .38896 .42757 .38018 .41859 Mtetra
.38018 .41859 .38896 .42757 .40349 .42272 .39477 .41369 Mtetra
.39477 .41369 .40349 .42272 .4181 .41784 .40943 .40877 Mtetra
.40943 .40877 .4181 .41784 .4328 .41294 .42417 .40381 Mtetra
.42417 .40381 .4328 .41294 .44757 .40801 .439 .39883 Mtetra
.439 .39883 .44757 .40801 .46242 .40306 .4539 .39383 Mtetra
.663 .741 .908 r
.4539 .39383 .46242 .40306 .47736 .39809 .46889 .38879 Mtetra
.46889 .38879 .47736 .39809 .49238 .39315 .48396 .38375 Mtetra
.662 .739 .907 r
.48396 .38375 .49238 .39315 .50748 .38829 .49912 .3787 Mtetra
.66 .736 .905 r
.49912 .3787 .50748 .38829 .52266 .38367 .51436 .37371 Mtetra
.655 .727 .902 r
.51436 .37371 .52266 .38367 .53794 .3796 .52969 .36887 Mtetra
.645 .708 .893 r
.52969 .36887 .53794 .3796 .55332 .37662 .5451 .36442 Mtetra
.626 .672 .875 r
.5451 .36442 .55332 .37662 .56884 .3756 .56062 .36076 Mtetra
.594 .616 .843 r
.56062 .36076 .56884 .3756 .58454 .37762 .57627 .35849 Mtetra
.552 .543 .798 r
.57627 .35849 .58454 .37762 .6005 .38385 .59208 .35845 Mtetra
.51 .468 .746 r
.59208 .35845 .6005 .38385 .6168 .39503 .60812 .36148 Mtetra
.477 .407 .699 r
.60812 .36148 .6168 .39503 .63352 .41093 .62444 .36818 Mtetra
.46 .368 .664 r
.62444 .36818 .63352 .41093 .65066 .42974 .64111 .37841 Mtetra
.458 .35 .643 r
.64111 .37841 .65066 .42974 .66812 .448 .65812 .39088 Mtetra
.472 .351 .634 r
.65812 .39088 .66812 .448 .68566 .46118 .6754 .40309 Mtetra
.5 .369 .634 r
.6754 .40309 .68566 .46118 .703 .46506 .69278 .41173 Mtetra
.544 .407 .644 r
.69278 .41173 .703 .46506 .71984 .45732 .71003 .41366 Mtetra
.607 .466 .664 r
.71003 .41366 .71984 .45732 .73605 .43855 .72692 .40707 Mtetra
.692 .553 .692 r
.72692 .40707 .73605 .43855 .75167 .41199 .74334 .39223 Mtetra
.792 .667 .726 r
.74334 .39223 .75167 .41199 .76692 .38216 .75932 .37136 Mtetra
.882 .79 .755 r
.75932 .37136 .76692 .38216 .78209 .35333 .77503 .34777 Mtetra
.925 .886 .775 r
.77503 .34777 .78209 .35333 .79743 .32832 .79067 .32465 Mtetra
.917 .934 .804 r
.79067 .32465 .79743 .32832 .81312 .30828 .80647 .3042 Mtetra
.88 .941 .852 r
.80647 .3042 .81312 .30828 .82922 .29298 .82256 .28741 Mtetra
.826 .91 .896 r
.82256 .28741 .82922 .29298 .8457 .28145 .83898 .27418 Mtetra
.768 .859 .917 r
.83898 .27418 .8457 .28145 .86249 .27251 .85573 .26383 Mtetra
.664 .741 .908 r
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Mtetra
.25707 .44817 .2663 .45685 .28027 .45216 .27108 .44343 Mtetra
.27108 .44343 .28027 .45216 .29432 .44744 .28517 .43866 Mtetra
.28517 .43866 .29432 .44744 .30844 .4427 .29934 .43387 Mtetra
.29934 .43387 .30844 .4427 .32263 .43793 .31358 .42905 Mtetra
.31358 .42905 .32263 .43793 .3369 .43313 .3279 .42421 Mtetra
.3279 .42421 .3369 .43313 .35125 .42831 .34229 .41934 Mtetra
.34229 .41934 .35125 .42831 .36568 .42346 .35677 .41445 Mtetra
.35677 .41445 .36568 .42346 .38018 .41859 .37132 .40953 Mtetra
.37132 .40953 .38018 .41859 .39477 .41369 .38595 .40458 Mtetra
.38595 .40458 .39477 .41369 .40943 .40877 .40067 .3996 Mtetra
.40067 .3996 .40943 .40877 .42417 .40381 .41546 .3946 Mtetra
.41546 .3946 .42417 .40381 .439 .39883 .43034 .38956 Mtetra
.43034 .38956 .439 .39883 .4539 .39383 .4453 .38451 Mtetra
.4453 .38451 .4539 .39383 .46889 .38879 .46034 .37942 Mtetra
.663 .741 .908 r
.46034 .37942 .46889 .38879 .48396 .38375 .47546 .37431 Mtetra
.47546 .37431 .48396 .38375 .49912 .3787 .49067 .36917 Mtetra
.663 .74 .907 r
.49067 .36917 .49912 .3787 .51436 .37371 .50597 .36403 Mtetra
.661 .737 .906 r
.50597 .36403 .51436 .37371 .52969 .36887 .52135 .35891 Mtetra
.658 .731 .903 r
.52135 .35891 .52969 .36887 .5451 .36442 .53682 .35388 Mtetra
.651 .717 .897 r
.53682 .35388 .5451 .36442 .56062 .36076 .55238 .34911 Mtetra
.638 .691 .883 r
.55238 .34911 .56062 .36076 .57627 .35849 .56804 .34484 Mtetra
.615 .647 .858 r
.56804 .34484 .57627 .35849 .59208 .35845 .58382 .34151 Mtetra
.584 .586 .821 r
.58382 .34151 .59208 .35845 .60812 .36148 .59974 .33967 Mtetra
.548 .518 .774 r
.59974 .33967 .60812 .36148 .62444 .36818 .61585 .33993 Mtetra
.518 .458 .728 r
.61585 .33993 .62444 .36818 .64111 .37841 .6322 .34271 Mtetra
.499 .414 .691 r
.6322 .34271 .64111 .37841 .65812 .39088 .64882 .34794 Mtetra
.494 .391 .666 r
.64882 .34794 .65812 .39088 .6754 .40309 .66572 .35477 Mtetra
.502 .385 .653 r
.66572 .35477 .6754 .40309 .69278 .41173 .68284 .36153 Mtetra
.523 .396 .649 r
.68284 .36153 .69278 .41173 .71003 .41366 .70006 .36594 Mtetra
.557 .424 .656 r
.70006 .36594 .71003 .41366 .72692 .40707 .71722 .36585 Mtetra
.604 .469 .671 r
.71722 .36585 .72692 .40707 .74334 .39223 .73416 .35994 Mtetra
.665 .534 .695 r
.73416 .35994 .74334 .39223 .75932 .37136 .75078 .34828 Mtetra
.736 .619 .727 r
.75078 .34828 .75932 .37136 .77503 .34777 .76711 .3323 Mtetra
.804 .714 .765 r
.76711 .3323 .77503 .34777 .79067 .32465 .78326 .31424 Mtetra
.847 .8 .804 r
.78326 .31424 .79067 .32465 .80647 .3042 .79939 .29629 Mtetra
.853 .853 .842 r
.79939 .29629 .80647 .3042 .82256 .28741 .81564 .28009 Mtetra
.825 .868 .877 r
.81564 .28009 .82256 .28741 .83898 .27418 .83213 .26636 Mtetra
.782 .85 .902 r
.83213 .26636 .83898 .27418 .85573 .26383 .84889 .25513 Mtetra
.664 .741 .908 r
.23376 .44416 .24313 .45288 .25707 .44817 .24775 .4394 Mtetra
.24775 .4394 .25707 .44817 .27108 .44343 .2618 .43461 Mtetra
.2618 .43461 .27108 .44343 .28517 .43866 .27594 .4298 Mtetra
.27594 .4298 .28517 .43866 .29934 .43387 .29015 .42496 Mtetra
.29015 .42496 .29934 .43387 .31358 .42905 .30444 .42009 Mtetra
.30444 .42009 .31358 .42905 .3279 .42421 .3188 .4152 Mtetra
.3188 .4152 .3279 .42421 .34229 .41934 .33325 .41028 Mtetra
.33325 .41028 .34229 .41934 .35677 .41445 .34777 .40534 Mtetra
.34777 .40534 .35677 .41445 .37132 .40953 .36237 .40037 Mtetra
.36237 .40037 .37132 .40953 .38595 .40458 .37705 .39537 Mtetra
.37705 .39537 .38595 .40458 .40067 .3996 .39182 .39034 Mtetra
.39182 .39034 .40067 .3996 .41546 .3946 .40666 .38529 Mtetra
.40666 .38529 .41546 .3946 .43034 .38956 .42159 .3802 Mtetra
.42159 .3802 .43034 .38956 .4453 .38451 .4366 .37509 Mtetra
.4366 .37509 .4453 .38451 .46034 .37942 .4517 .36995 Mtetra
.4517 .36995 .46034 .37942 .47546 .37431 .46688 .36478 Mtetra
.46688 .36478 .47546 .37431 .49067 .36917 .48214 .35959 Mtetra
.663 .741 .908 r
.48214 .35959 .49067 .36917 .50597 .36403 .49749 .35437 Mtetra
.663 .74 .907 r
.49749 .35437 .50597 .36403 .52135 .35891 .51293 .34913 Mtetra
.662 .739 .907 r
.51293 .34913 .52135 .35891 .53682 .35388 .52845 .34389 Mtetra
.66 .734 .905 r
.52845 .34389 .53682 .35388 .55238 .34911 .54407 .3387 Mtetra
.656 .725 .9 r
.54407 .3387 .55238 .34911 .56804 .34484 .55977 .33365 Mtetra
.647 .707 .891 r
.55977 .33365 .56804 .34484 .58382 .34151 .57557 .32891 Mtetra
.633 .675 .873 r
.57557 .32891 .58382 .34151 .59974 .33967 .59149 .32474 Mtetra
.611 .629 .844 r
.59149 .32474 .59974 .33967 .61585 .33993 .60753 .3215 Mtetra
.583 .571 .806 r
.60753 .3215 .61585 .33993 .6322 .34271 .62373 .31958 Mtetra
.557 .515 .764 r
.62373 .31958 .6322 .34271 .64882 .34794 .64012 .31927 Mtetra
.538 .469 .727 r
.64012 .31927 .64882 .34794 .66572 .35477 .65672 .32055 Mtetra
.529 .44 .699 r
.65672 .32055 .66572 .35477 .68284 .36153 .67355 .32288 Mtetra
.532 .428 .681 r
.67355 .32288 .68284 .36153 .70006 .36594 .69056 .32523 Mtetra
.547 .432 .675 r
.69056 .32523 .70006 .36594 .71722 .36585 .70767 .32615 Mtetra
.572 .452 .677 r
.70767 .32615 .71722 .36585 .73416 .35994 .72477 .32424 Mtetra
.608 .487 .689 r
.72477 .32424 .73416 .35994 .75078 .34828 .74176 .31862 Mtetra
.653 .537 .711 r
.74176 .31862 .75078 .34828 .76711 .3323 .75858 .30927 Mtetra
.704 .603 .741 r
.75858 .30927 .76711 .3323 .78326 .31424 .77523 .29704 Mtetra
.751 .676 .778 r
.77523 .29704 .78326 .31424 .79939 .29629 .79179 .28333 Mtetra
.783 .744 .818 r
.79179 .28333 .79939 .29629 .81564 .28009 .80835 .26956 Mtetra
.789 .791 .854 r
.80835 .26956 .81564 .28009 .83213 .26636 .82503 .25683 Mtetra
.772 .809 .883 r
.82503 .25683 .83213 .26636 .84889 .25513 .84191 .24567 Mtetra
.664 .741 .908 r
.2243 .43535 .23376 .44416 .24775 .4394 .23833 .43054 Mtetra
.23833 .43054 .24775 .4394 .2618 .43461 .25243 .4257 Mtetra
.25243 .4257 .2618 .43461 .27594 .4298 .26661 .42084 Mtetra
.26661 .42084 .27594 .4298 .29015 .42496 .28087 .41596 Mtetra
.28087 .41596 .29015 .42496 .30444 .42009 .2952 .41104 Mtetra
.2952 .41104 .30444 .42009 .3188 .4152 .30961 .4061 Mtetra
.30961 .4061 .3188 .4152 .33325 .41028 .32411 .40113 Mtetra
.32411 .40113 .33325 .41028 .34777 .40534 .33868 .39614 Mtetra
.33868 .39614 .34777 .40534 .36237 .40037 .35333 .39112 Mtetra
.35333 .39112 .36237 .40037 .37705 .39537 .36806 .38606 Mtetra
.36806 .38606 .37705 .39537 .39182 .39034 .38288 .38099 Mtetra
.38288 .38099 .39182 .39034 .40666 .38529 .39777 .37588 Mtetra
.39777 .37588 .40666 .38529 .42159 .3802 .41275 .37074 Mtetra
.41275 .37074 .42159 .3802 .4366 .37509 .42782 .36558 Mtetra
.42782 .36558 .4366 .37509 .4517 .36995 .44297 .36039 Mtetra
.44297 .36039 .4517 .36995 .46688 .36478 .4582 .35516 Mtetra
.4582 .35516 .46688 .36478 .48214 .35959 .47352 .34991 Mtetra
.47352 .34991 .48214 .35959 .49749 .35437 .48892 .34463 Mtetra
.663 .741 .908 r
.48892 .34463 .49749 .35437 .51293 .34913 .50442 .33932 Mtetra
.50442 .33932 .51293 .34913 .52845 .34389 .52 .33399 Mtetra
.663 .74 .907 r
.52 .33399 .52845 .34389 .54407 .3387 .53567 .32865 Mtetra
.662 .737 .906 r
.53567 .32865 .54407 .3387 .55977 .33365 .55143 .32332 Mtetra
.659 .731 .903 r
.55143 .32332 .55977 .33365 .57557 .32891 .56728 .31805 Mtetra
.654 .72 .897 r
.56728 .31805 .57557 .32891 .59149 .32474 .58323 .31295 Mtetra
.645 .699 .885 r
.58323 .31295 .59149 .32474 .60753 .3215 .59929 .30817 Mtetra
.631 .666 .865 r
.59929 .30817 .60753 .3215 .62373 .31958 .61546 .30392 Mtetra
.613 .623 .837 r
.61546 .30392 .62373 .31958 .64012 .31927 .63176 .30045 Mtetra
.592 .575 .803 r
.63176 .30045 .64012 .31927 .65672 .32055 .64822 .29791 Mtetra
.575 .531 .769 r
.64822 .29791 .65672 .32055 .67355 .32288 .66486 .29633 Mtetra
.565 .499 .74 r
.66486 .29633 .67355 .32288 .69056 .32523 .68166 .2954 Mtetra
.564 .482 .72 r
.68166 .2954 .69056 .32523 .70767 .32615 .69862 .2945 Mtetra
.572 .479 .71 r
.69862 .2945 .70767 .32615 .72477 .32424 .71569 .29279 Mtetra
.59 .492 .71 r
.71569 .29279 .72477 .32424 .74176 .31862 .73279 .28943 Mtetra
.617 .518 .72 r
.73279 .28943 .74176 .31862 .75858 .30927 .74986 .28384 Mtetra
.649 .558 .738 r
.74986 .28384 .75858 .30927 .77523 .29704 .76686 .276 Mtetra
.685 .609 .765 r
.76686 .276 .77523 .29704 .79179 .28333 .78379 .26636 Mtetra
.717 .666 .798 r
.78379 .26636 .79179 .28333 .80835 .26956 .8007 .25574 Mtetra
.738 .718 .833 r
.8007 .25574 .80835 .26956 .82503 .25683 .81765 .24501 Mtetra
.741 .754 .863 r
.81765 .24501 .82503 .25683 .84191 .24567 .8347 .23485 Mtetra
.664 .741 .908 r
.21474 .42645 .2243 .43535 .23833 .43054 .22882 .42159 Mtetra
.22882 .42159 .23833 .43054 .25243 .4257 .24296 .41671 Mtetra
.24296 .41671 .25243 .4257 .26661 .42084 .25719 .4118 Mtetra
.25719 .4118 .26661 .42084 .28087 .41596 .27149 .40686 Mtetra
.27149 .40686 .28087 .41596 .2952 .41104 .28587 .4019 Mtetra
.28587 .4019 .2952 .41104 .30961 .4061 .30033 .39691 Mtetra
.30033 .39691 .30961 .4061 .32411 .40113 .31487 .39189 Mtetra
.31487 .39189 .32411 .40113 .33868 .39614 .32949 .38684 Mtetra
.32949 .38684 .33868 .39614 .35333 .39112 .34419 .38177 Mtetra
.34419 .38177 .35333 .39112 .36806 .38606 .35898 .37667 Mtetra
.35898 .37667 .36806 .38606 .38288 .38099 .37384 .37154 Mtetra
.37384 .37154 .38288 .38099 .39777 .37588 .38879 .36638 Mtetra
.38879 .36638 .39777 .37588 .41275 .37074 .40382 .36119 Mtetra
.40382 .36119 .41275 .37074 .42782 .36558 .41894 .35597 Mtetra
.41894 .35597 .42782 .36558 .44297 .36039 .43414 .35072 Mtetra
.43414 .35072 .44297 .36039 .4582 .35516 .44943 .34545 Mtetra
.44943 .34545 .4582 .35516 .47352 .34991 .46481 .34014 Mtetra
.46481 .34014 .47352 .34991 .48892 .34463 .48027 .3348 Mtetra
.48027 .3348 .48892 .34463 .50442 .33932 .49582 .32944 Mtetra
.49582 .32944 .50442 .33932 .52 .33399 .51146 .32404 Mtetra
.663 .741 .908 r
.51146 .32404 .52 .33399 .53567 .32865 .52719 .31862 Mtetra
.663 .74 .907 r
.52719 .31862 .53567 .32865 .55143 .32332 .54301 .31317 Mtetra
.663 .739 .907 r
.54301 .31317 .55143 .32332 .56728 .31805 .55892 .30772 Mtetra
.661 .736 .905 r
.55892 .30772 .56728 .31805 .58323 .31295 .57492 .30228 Mtetra
.659 .729 .901 r
.57492 .30228 .58323 .31295 .59929 .30817 .59102 .29692 Mtetra
.654 .716 .894 r
.59102 .29692 .59929 .30817 .61546 .30392 .60722 .29172 Mtetra
.646 .696 .882 r
.60722 .29172 .61546 .30392 .63176 .30045 .62353 .28679 Mtetra
.634 .666 .863 r
.62353 .28679 .63176 .30045 .64822 .29791 .63996 .28227 Mtetra
.621 .631 .839 r
.63996 .28227 .64822 .29791 .66486 .29633 .65652 .27827 Mtetra
.608 .594 .812 r
.65652 .27827 .66486 .29633 .68166 .2954 .67322 .27478 Mtetra
.599 .564 .787 r
.67322 .27478 .68166 .2954 .69862 .2945 .69007 .27166 Mtetra
.595 .544 .767 r
.69007 .27166 .69862 .2945 .71569 .29279 .70704 .26857 Mtetra
.6 .537 .756 r
.70704 .26857 .71569 .29279 .73279 .28943 .72413 .26504 Mtetra
.611 .543 .753 r
.72413 .26504 .73279 .28943 .74986 .28384 .74127 .2606 Mtetra
.629 .562 .76 r
.74127 .2606 .74986 .28384 .76686 .276 .75845 .25492 Mtetra
.652 .592 .775 r
.75845 .25492 .76686 .276 .78379 .26636 .77563 .24795 Mtetra
.675 .631 .797 r
.77563 .24795 .78379 .26636 .8007 .25574 .79281 .23993 Mtetra
.695 .673 .824 r
.79281 .23993 .8007 .25574 .81765 .24501 .81002 .23131 Mtetra
.707 .71 .85 r
.81002 .23131 .81765 .24501 .8347 .23485 .82729 .22257 Mtetra
.664 .741 .908 r
.20509 .41746 .21474 .42645 .22882 .42159 .21921 .41256 Mtetra
.21921 .41256 .22882 .42159 .24296 .41671 .2334 .40762 Mtetra
.2334 .40762 .24296 .41671 .25719 .4118 .24767 .40267 Mtetra
.24767 .40267 .25719 .4118 .27149 .40686 .26202 .39768 Mtetra
.26202 .39768 .27149 .40686 .28587 .4019 .27645 .39266 Mtetra
.27645 .39266 .28587 .4019 .30033 .39691 .29096 .38762 Mtetra
.29096 .38762 .30033 .39691 .31487 .39189 .30555 .38255 Mtetra
.30555 .38255 .31487 .39189 .32949 .38684 .32021 .37745 Mtetra
.32021 .37745 .32949 .38684 .34419 .38177 .33497 .37233 Mtetra
.33497 .37233 .34419 .38177 .35898 .37667 .3498 .36717 Mtetra
.3498 .36717 .35898 .37667 .37384 .37154 .36472 .36199 Mtetra
.36472 .36199 .37384 .37154 .38879 .36638 .37972 .35677 Mtetra
.37972 .35677 .38879 .36638 .40382 .36119 .3948 .35153 Mtetra
.3948 .35153 .40382 .36119 .41894 .35597 .40997 .34626 Mtetra
.40997 .34626 .41894 .35597 .43414 .35072 .42523 .34096 Mtetra
.42523 .34096 .43414 .35072 .44943 .34545 .44057 .33563 Mtetra
.44057 .33563 .44943 .34545 .46481 .34014 .456 .33026 Mtetra
.456 .33026 .46481 .34014 .48027 .3348 .47152 .32487 Mtetra
.47152 .32487 .48027 .3348 .49582 .32944 .48713 .31945 Mtetra
.48713 .31945 .49582 .32944 .51146 .32404 .50282 .31399 Mtetra
.50282 .31399 .51146 .32404 .52719 .31862 .51861 .3085 Mtetra
.663 .741 .908 r
.51861 .3085 .52719 .31862 .54301 .31317 .53449 .30299 Mtetra
.53449 .30299 .54301 .31317 .55892 .30772 .55046 .29744 Mtetra
.663 .74 .907 r
.55046 .29744 .55892 .30772 .57492 .30228 .56653 .29188 Mtetra
.662 .738 .906 r
.56653 .29188 .57492 .30228 .59102 .29692 .58269 .28631 Mtetra
.661 .735 .904 r
.58269 .28631 .59102 .29692 .60722 .29172 .59894 .28076 Mtetra
.659 .728 .9 r
.59894 .28076 .60722 .29172 .62353 .28679 .61529 .27527 Mtetra
.654 .716 .893 r
.61529 .27527 .62353 .28679 .63996 .28227 .63175 .2699 Mtetra
.648 .698 .882 r
.63175 .2699 .63996 .28227 .65652 .27827 .64832 .26473 Mtetra
.641 .675 .867 r
.64832 .26473 .65652 .27827 .67322 .27478 .665 .2598 Mtetra
.633 .65 .849 r
.665 .2598 .67322 .27478 .69007 .27166 .68181 .25513 Mtetra
.626 .626 .83 r
.68181 .25513 .69007 .27166 .70704 .26857 .69874 .25065 Mtetra
.623 .608 .815 r
.69874 .25065 .70704 .26857 .72413 .26504 .71579 .24617 Mtetra
.624 .599 .804 r
.71579 .24617 .72413 .26504 .74127 .2606 .73295 .24147 Mtetra
.631 .6 .801 r
.73295 .24147 .74127 .2606 .75845 .25492 .75019 .23629 Mtetra
.642 .612 .805 r
.75019 .23629 .75845 .25492 .77563 .24795 .76749 .23046 Mtetra
.656 .633 .815 r
.76749 .23046 .77563 .24795 .79281 .23993 .78485 .22393 Mtetra
.67 .66 .831 r
.78485 .22393 .79281 .23993 .81002 .23131 .80225 .21682 Mtetra
.682 .689 .85 r
.80225 .21682 .81002 .23131 .82729 .22257 .81972 .20937 Mtetra
.664 .741 .908 r
.19534 .40839 .20509 .41746 .21921 .41256 .2095 .40343 Mtetra
.2095 .40343 .21921 .41256 .2334 .40762 .22374 .39845 Mtetra
.22374 .39845 .2334 .40762 .24767 .40267 .23806 .39344 Mtetra
.23806 .39344 .24767 .40267 .26202 .39768 .25245 .3884 Mtetra
.25245 .3884 .26202 .39768 .27645 .39266 .26693 .38333 Mtetra
.26693 .38333 .27645 .39266 .29096 .38762 .28149 .37824 Mtetra
.28149 .37824 .29096 .38762 .30555 .38255 .29612 .37312 Mtetra
.29612 .37312 .30555 .38255 .32021 .37745 .31084 .36797 Mtetra
.31084 .36797 .32021 .37745 .33497 .37233 .32564 .36279 Mtetra
.32564 .36279 .33497 .37233 .3498 .36717 .34053 .35758 Mtetra
.34053 .35758 .3498 .36717 .36472 .36199 .35549 .35234 Mtetra
.35549 .35234 .36472 .36199 .37972 .35677 .37055 .34707 Mtetra
.37055 .34707 .37972 .35677 .3948 .35153 .38569 .34178 Mtetra
.38569 .34178 .3948 .35153 .40997 .34626 .40091 .33645 Mtetra
.40091 .33645 .40997 .34626 .42523 .34096 .41622 .33109 Mtetra
.41622 .33109 .42523 .34096 .44057 .33563 .43162 .3257 Mtetra
.43162 .3257 .44057 .33563 .456 .33026 .4471 .32028 Mtetra
.4471 .32028 .456 .33026 .47152 .32487 .46268 .31483 Mtetra
.46268 .31483 .47152 .32487 .48713 .31945 .47834 .30935 Mtetra
.47834 .30935 .48713 .31945 .50282 .31399 .4941 .30384 Mtetra
.4941 .30384 .50282 .31399 .51861 .3085 .50995 .29829 Mtetra
.50995 .29829 .51861 .3085 .53449 .30299 .52589 .29271 Mtetra
.52589 .29271 .53449 .30299 .55046 .29744 .54192 .2871 Mtetra
.663 .741 .908 r
.54192 .2871 .55046 .29744 .56653 .29188 .55804 .28146 Mtetra
.55804 .28146 .56653 .29188 .58269 .28631 .57426 .2758 Mtetra
.663 .74 .907 r
.57426 .2758 .58269 .28631 .59894 .28076 .59058 .27011 Mtetra
.662 .738 .906 r
.59058 .27011 .59894 .28076 .61529 .27527 .60699 .26441 Mtetra
.661 .734 .904 r
.60699 .26441 .61529 .27527 .63175 .2699 .6235 .25872 Mtetra
.659 .728 .9 r
.6235 .25872 .63175 .2699 .64832 .26473 .64012 .25307 Mtetra
.656 .719 .894 r
.64012 .25307 .64832 .26473 .665 .2598 .65684 .2475 Mtetra
.653 .706 .886 r
.65684 .2475 .665 .2598 .68181 .25513 .67367 .24202 Mtetra
.648 .69 .876 r
.67367 .24202 .68181 .25513 .69874 .25065 .69061 .23665 Mtetra
.645 .675 .864 r
.69061 .23665 .69874 .25065 .71579 .24617 .70766 .23136 Mtetra
.643 .662 .854 r
.70766 .23136 .71579 .24617 .73295 .24147 .72483 .22606 Mtetra
.643 .654 .846 r
.72483 .22606 .73295 .24147 .75019 .23629 .7421 .22064 Mtetra
.647 .653 .843 r
.7421 .22064 .75019 .23629 .76749 .23046 .75947 .21498 Mtetra
.653 .66 .844 r
.75947 .21498 .76749 .23046 .78485 .22393 .77693 .20898 Mtetra
.66 .672 .851 r
.77693 .20898 .78485 .22393 .80225 .21682 .79446 .20263 Mtetra
.667 .689 .861 r
.79446 .20263 .80225 .21682 .81972 .20937 .81207 .19597 Mtetra
.664 .741 .908 r
.18549 .39922 .19534 .40839 .2095 .40343 .1997 .39421 Mtetra
.1997 .39421 .2095 .40343 .22374 .39845 .21398 .38918 Mtetra
.21398 .38918 .22374 .39845 .23806 .39344 .22835 .38411 Mtetra
.22835 .38411 .23806 .39344 .25245 .3884 .24279 .37903 Mtetra
.24279 .37903 .25245 .3884 .26693 .38333 .25731 .37391 Mtetra
.25731 .37391 .26693 .38333 .28149 .37824 .27192 .36876 Mtetra
.27192 .36876 .28149 .37824 .29612 .37312 .2866 .36359 Mtetra
.2866 .36359 .29612 .37312 .31084 .36797 .30137 .35838 Mtetra
.30137 .35838 .31084 .36797 .32564 .36279 .31622 .35315 Mtetra
.31622 .35315 .32564 .36279 .34053 .35758 .33116 .34789 Mtetra
.33116 .34789 .34053 .35758 .35549 .35234 .34618 .34259 Mtetra
.34618 .34259 .35549 .35234 .37055 .34707 .36128 .33727 Mtetra
.36128 .33727 .37055 .34707 .38569 .34178 .37647 .33192 Mtetra
.37647 .33192 .38569 .34178 .40091 .33645 .39175 .32653 Mtetra
.39175 .32653 .40091 .33645 .41622 .33109 .40712 .32112 Mtetra
.40712 .32112 .41622 .33109 .43162 .3257 .42257 .31567 Mtetra
.42257 .31567 .43162 .3257 .4471 .32028 .43811 .31019 Mtetra
.43811 .31019 .4471 .32028 .46268 .31483 .45374 .30469 Mtetra
.45374 .30469 .46268 .31483 .47834 .30935 .46947 .29915 Mtetra
.46947 .29915 .47834 .30935 .4941 .30384 .48528 .29357 Mtetra
.48528 .29357 .4941 .30384 .50995 .29829 .50119 .28797 Mtetra
.50119 .28797 .50995 .29829 .52589 .29271 .51719 .28233 Mtetra
.51719 .28233 .52589 .29271 .54192 .2871 .53328 .27666 Mtetra
.53328 .27666 .54192 .2871 .55804 .28146 .54947 .27095 Mtetra
.54947 .27095 .55804 .28146 .57426 .2758 .56575 .26522 Mtetra
.663 .741 .908 r
.56575 .26522 .57426 .2758 .59058 .27011 .58213 .25945 Mtetra
.58213 .25945 .59058 .27011 .60699 .26441 .59861 .25365 Mtetra
.663 .74 .907 r
.59861 .25365 .60699 .26441 .6235 .25872 .61518 .24783 Mtetra
.663 .738 .906 r
.61518 .24783 .6235 .25872 .64012 .25307 .63186 .24199 Mtetra
.662 .735 .904 r
.63186 .24199 .64012 .25307 .65684 .2475 .64863 .23615 Mtetra
.66 .73 .901 r
.64863 .23615 .65684 .2475 .67367 .24202 .66551 .23033 Mtetra
.659 .724 .897 r
.66551 .23033 .67367 .24202 .69061 .23665 .6825 .22452 Mtetra
.657 .716 .892 r
.6825 .22452 .69061 .23665 .70766 .23136 .69959 .21875 Mtetra
.655 .707 .886 r
.69959 .21875 .70766 .23136 .72483 .22606 .7168 .21299 Mtetra
.654 .7 .88 r
.7168 .21299 .72483 .22606 .7421 .22064 .73411 .20721 Mtetra
.654 .694 .875 r
.73411 .20721 .7421 .22064 .75947 .21498 .75153 .20136 Mtetra
.656 .693 .873 r
.75153 .20136 .75947 .21498 .77693 .20898 .76905 .19538 Mtetra
.659 .696 .874 r
.76905 .19538 .77693 .20898 .79446 .20263 .78667 .18923 Mtetra
.662 .703 .877 r
.78667 .18923 .79446 .20263 .81207 .19597 .80439 .1829 Mtetra
.664 .741 .908 r
.17555 .38995 .18549 .39922 .1997 .39421 .1898 .3849 Mtetra
.1898 .3849 .1997 .39421 .21398 .38918 .20413 .37981 Mtetra
.20413 .37981 .21398 .38918 .22835 .38411 .21853 .3747 Mtetra
.21853 .3747 .22835 .38411 .24279 .37903 .23302 .36955 Mtetra
.23302 .36955 .24279 .37903 .25731 .37391 .2476 .36438 Mtetra
.2476 .36438 .25731 .37391 .27192 .36876 .26225 .35918 Mtetra
.26225 .35918 .27192 .36876 .2866 .36359 .27698 .35396 Mtetra
.27698 .35396 .2866 .36359 .30137 .35838 .2918 .3487 Mtetra
.2918 .3487 .30137 .35838 .31622 .35315 .3067 .34341 Mtetra
.3067 .34341 .31622 .35315 .33116 .34789 .32169 .33809 Mtetra
.32169 .33809 .33116 .34789 .34618 .34259 .33676 .33274 Mtetra
.33676 .33274 .34618 .34259 .36128 .33727 .35192 .32736 Mtetra
.35192 .32736 .36128 .33727 .37647 .33192 .36716 .32195 Mtetra
.36716 .32195 .37647 .33192 .39175 .32653 .3825 .31651 Mtetra
.3825 .31651 .39175 .32653 .40712 .32112 .39792 .31104 Mtetra
.39792 .31104 .40712 .32112 .42257 .31567 .41343 .30554 Mtetra
.41343 .30554 .42257 .31567 .43811 .31019 .42902 .3 Mtetra
.42902 .3 .43811 .31019 .45374 .30469 .44471 .29443 Mtetra
.44471 .29443 .45374 .30469 .46947 .29915 .4605 .28883 Mtetra
.4605 .28883 .46947 .29915 .48528 .29357 .47637 .2832 Mtetra
.47637 .2832 .48528 .29357 .50119 .28797 .49233 .27753 Mtetra
.49233 .27753 .50119 .28797 .51719 .28233 .50839 .27183 Mtetra
.50839 .27183 .51719 .28233 .53328 .27666 .52455 .2661 Mtetra
.52455 .2661 .53328 .27666 .54947 .27095 .5408 .26033 Mtetra
.5408 .26033 .54947 .27095 .56575 .26522 .55715 .25453 Mtetra
.55715 .25453 .56575 .26522 .58213 .25945 .57359 .2487 Mtetra
.57359 .2487 .58213 .25945 .59861 .25365 .59013 .24283 Mtetra
.663 .741 .908 r
.59013 .24283 .59861 .25365 .61518 .24783 .60677 .23693 Mtetra
.60677 .23693 .61518 .24783 .63186 .24199 .62351 .23099 Mtetra
.663 .74 .907 r
.62351 .23099 .63186 .24199 .64863 .23615 .64035 .22503 Mtetra
.663 .739 .906 r
.64035 .22503 .64863 .23615 .66551 .23033 .6573 .21905 Mtetra
.662 .737 .905 r
.6573 .21905 .66551 .23033 .6825 .22452 .67435 .21305 Mtetra
.662 .734 .903 r
.67435 .21305 .6825 .22452 .69959 .21875 .6915 .20704 Mtetra
.661 .73 .901 r
.6915 .20704 .69959 .21875 .7168 .21299 .70876 .20101 Mtetra
.66 .726 .898 r
.70876 .20101 .7168 .21299 .73411 .20721 .72613 .19498 Mtetra
.66 .722 .895 r
.72613 .19498 .73411 .20721 .75153 .20136 .74361 .18891 Mtetra
.66 .719 .892 r
.74361 .18891 .75153 .20136 .76905 .19538 .76119 .18279 Mtetra
.66 .718 .891 r
.76119 .18279 .76905 .19538 .78667 .18923 .77888 .1766 Mtetra
.661 .719 .891 r
.77888 .1766 .78667 .18923 .80439 .1829 .79668 .17032 Mtetra
.664 .741 .908 r
.1655 .38059 .17555 .38995 .1898 .3849 .17979 .37549 Mtetra
.17979 .37549 .1898 .3849 .20413 .37981 .19417 .37035 Mtetra
.19417 .37035 .20413 .37981 .21853 .3747 .20862 .36518 Mtetra
.20862 .36518 .21853 .3747 .23302 .36955 .22316 .35999 Mtetra
.22316 .35999 .23302 .36955 .2476 .36438 .23778 .35476 Mtetra
.23778 .35476 .2476 .36438 .26225 .35918 .25248 .34951 Mtetra
.25248 .34951 .26225 .35918 .27698 .35396 .26726 .34422 Mtetra
.26726 .34422 .27698 .35396 .2918 .3487 .28213 .33891 Mtetra
.28213 .33891 .2918 .3487 .3067 .34341 .29708 .33357 Mtetra
.29708 .33357 .3067 .34341 .32169 .33809 .31212 .32819 Mtetra
.31212 .32819 .32169 .33809 .33676 .33274 .32725 .32279 Mtetra
.32725 .32279 .33676 .33274 .35192 .32736 .34246 .31735 Mtetra
.34246 .31735 .35192 .32736 .36716 .32195 .35775 .31188 Mtetra
.35775 .31188 .36716 .32195 .3825 .31651 .37314 .30638 Mtetra
.37314 .30638 .3825 .31651 .39792 .31104 .38862 .30085 Mtetra
.38862 .30085 .39792 .31104 .41343 .30554 .40418 .29529 Mtetra
.40418 .29529 .41343 .30554 .42902 .3 .41984 .2897 Mtetra
.41984 .2897 .42902 .3 .44471 .29443 .43559 .28407 Mtetra
.43559 .28407 .44471 .29443 .4605 .28883 .45143 .27841 Mtetra
.45143 .27841 .4605 .28883 .47637 .2832 .46736 .27271 Mtetra
.46736 .27271 .47637 .2832 .49233 .27753 .48338 .26698 Mtetra
.48338 .26698 .49233 .27753 .50839 .27183 .49951 .26122 Mtetra
.49951 .26122 .50839 .27183 .52455 .2661 .51572 .25543 Mtetra
.51572 .25543 .52455 .2661 .5408 .26033 .53204 .2496 Mtetra
.53204 .2496 .5408 .26033 .55715 .25453 .54845 .24373 Mtetra
.54845 .24373 .55715 .25453 .57359 .2487 .56495 .23783 Mtetra
.56495 .23783 .57359 .2487 .59013 .24283 .58156 .2319 Mtetra
.58156 .2319 .59013 .24283 .60677 .23693 .59827 .22593 Mtetra
.59827 .22593 .60677 .23693 .62351 .23099 .61508 .21992 Mtetra
.663 .741 .908 r
.61508 .21992 .62351 .23099 .64035 .22503 .63199 .21388 Mtetra
.63199 .21388 .64035 .22503 .6573 .21905 .649 .20781 Mtetra
.663 .74 .907 r
.649 .20781 .6573 .21905 .67435 .21305 .66612 .2017 Mtetra
.663 .739 .907 r
.66612 .2017 .67435 .21305 .6915 .20704 .68334 .19556 Mtetra
.663 .738 .906 r
.68334 .19556 .6915 .20704 .70876 .20101 .70066 .1894 Mtetra
.662 .736 .905 r
.70066 .1894 .70876 .20101 .72613 .19498 .7181 .18321 Mtetra
.662 .735 .904 r
.7181 .18321 .72613 .19498 .74361 .18891 .73564 .17699 Mtetra
.662 .733 .902 r
.73564 .17699 .74361 .18891 .76119 .18279 .7533 .17073 Mtetra
.662 .731 .901 r
.7533 .17073 .76119 .18279 .77888 .1766 .77106 .16443 Mtetra
.77106 .16443 .77888 .1766 .79668 .17032 .78893 .15808 Mtetra
.664 .741 .908 r
.15534 .37114 .1655 .38059 .17979 .37549 .16968 .36598 Mtetra
.16968 .36598 .17979 .37549 .19417 .37035 .1841 .36079 Mtetra
.1841 .36079 .19417 .37035 .20862 .36518 .19861 .35557 Mtetra
.19861 .35557 .20862 .36518 .22316 .35999 .21319 .35032 Mtetra
.21319 .35032 .22316 .35999 .23778 .35476 .22786 .34504 Mtetra
.22786 .34504 .23778 .35476 .25248 .34951 .24261 .33973 Mtetra
.24261 .33973 .25248 .34951 .26726 .34422 .25744 .33439 Mtetra
.25744 .33439 .26726 .34422 .28213 .33891 .27236 .32902 Mtetra
.27236 .32902 .28213 .33891 .29708 .33357 .28736 .32362 Mtetra
.28736 .32362 .29708 .33357 .31212 .32819 .30245 .31819 Mtetra
.30245 .31819 .31212 .32819 .32725 .32279 .31763 .31273 Mtetra
.31763 .31273 .32725 .32279 .34246 .31735 .33289 .30723 Mtetra
.33289 .30723 .34246 .31735 .35775 .31188 .34825 .30171 Mtetra
.34825 .30171 .35775 .31188 .37314 .30638 .36369 .29615 Mtetra
.36369 .29615 .37314 .30638 .38862 .30085 .37922 .29056 Mtetra
.37922 .29056 .38862 .30085 .40418 .29529 .39484 .28494 Mtetra
.39484 .28494 .40418 .29529 .41984 .2897 .41055 .27928 Mtetra
.41055 .27928 .41984 .2897 .43559 .28407 .42636 .27359 Mtetra
.42636 .27359 .43559 .28407 .45143 .27841 .44226 .26787 Mtetra
.44226 .26787 .45143 .27841 .46736 .27271 .45825 .26211 Mtetra
.45825 .26211 .46736 .27271 .48338 .26698 .47434 .25632 Mtetra
.47434 .25632 .48338 .26698 .49951 .26122 .49052 .2505 Mtetra
.49052 .2505 .49951 .26122 .51572 .25543 .5068 .24464 Mtetra
.5068 .24464 .51572 .25543 .53204 .2496 .52318 .23874 Mtetra
.52318 .23874 .53204 .2496 .54845 .24373 .53965 .23281 Mtetra
.53965 .23281 .54845 .24373 .56495 .23783 .55622 .22685 Mtetra
.55622 .22685 .56495 .23783 .58156 .2319 .5729 .22085 Mtetra
.5729 .22085 .58156 .2319 .59827 .22593 .58967 .21481 Mtetra
.58967 .21481 .59827 .22593 .61508 .21992 .60655 .20873 Mtetra
.60655 .20873 .61508 .21992 .63199 .21388 .62353 .20262 Mtetra
.62353 .20262 .63199 .21388 .649 .20781 .64061 .19648 Mtetra
.663 .741 .908 r
.64061 .19648 .649 .20781 .66612 .2017 .6578 .19029 Mtetra
.6578 .19029 .66612 .2017 .68334 .19556 .67509 .18407 Mtetra
.663 .741 .907 r
.67509 .18407 .68334 .19556 .70066 .1894 .69249 .17782 Mtetra
.663 .74 .907 r
.69249 .17782 .70066 .1894 .7181 .18321 .70999 .17152 Mtetra
.663 .739 .907 r
.70999 .17152 .7181 .18321 .73564 .17699 .72761 .1652 Mtetra
.663 .739 .906 r
.72761 .1652 .73564 .17699 .7533 .17073 .74534 .15883 Mtetra
.663 .738 .906 r
.74534 .15883 .7533 .17073 .77106 .16443 .76317 .15243 Mtetra
.663 .737 .905 r
.76317 .15243 .77106 .16443 .78893 .15808 .78112 .14599 Mtetra
.664 .741 .908 r
.14508 .36159 .15534 .37114 .16968 .36598 .15947 .35637 Mtetra
.15947 .35637 .16968 .36598 .1841 .36079 .17394 .35113 Mtetra
.17394 .35113 .1841 .36079 .19861 .35557 .18849 .34585 Mtetra
.18849 .34585 .19861 .35557 .21319 .35032 .20312 .34055 Mtetra
.20312 .34055 .21319 .35032 .22786 .34504 .21783 .33521 Mtetra
.21783 .33521 .22786 .34504 .24261 .33973 .23263 .32985 Mtetra
.23263 .32985 .24261 .33973 .25744 .33439 .24752 .32445 Mtetra
.24752 .32445 .25744 .33439 .27236 .32902 .26248 .31903 Mtetra
.26248 .31903 .27236 .32902 .28736 .32362 .27754 .31357 Mtetra
.27754 .31357 .28736 .32362 .30245 .31819 .29268 .30808 Mtetra
.29268 .30808 .30245 .31819 .31763 .31273 .30791 .30256 Mtetra
.30791 .30256 .31763 .31273 .33289 .30723 .32323 .29701 Mtetra
.32323 .29701 .33289 .30723 .34825 .30171 .33863 .29142 Mtetra
.33863 .29142 .34825 .30171 .36369 .29615 .35413 .2858 Mtetra
.35413 .2858 .36369 .29615 .37922 .29056 .36972 .28015 Mtetra
.36972 .28015 .37922 .29056 .39484 .28494 .3854 .27447 Mtetra
.3854 .27447 .39484 .28494 .41055 .27928 .40117 .26875 Mtetra
.40117 .26875 .41055 .27928 .42636 .27359 .41703 .263 Mtetra
.41703 .263 .42636 .27359 .44226 .26787 .43299 .25721 Mtetra
.43299 .25721 .44226 .26787 .45825 .26211 .44904 .25139 Mtetra
.44904 .25139 .45825 .26211 .47434 .25632 .46519 .24554 Mtetra
.46519 .24554 .47434 .25632 .49052 .2505 .48143 .23965 Mtetra
.48143 .23965 .49052 .2505 .5068 .24464 .49778 .23373 Mtetra
.49778 .23373 .5068 .24464 .52318 .23874 .51422 .22777 Mtetra
.51422 .22777 .52318 .23874 .53965 .23281 .53076 .22177 Mtetra
.53076 .22177 .53965 .23281 .55622 .22685 .5474 .21574 Mtetra
.5474 .21574 .55622 .22685 .5729 .22085 .56414 .20967 Mtetra
.56414 .20967 .5729 .22085 .58967 .21481 .58098 .20357 Mtetra
.58098 .20357 .58967 .21481 .60655 .20873 .59792 .19742 Mtetra
.59792 .19742 .60655 .20873 .62353 .20262 .61497 .19124 Mtetra
.61497 .19124 .62353 .20262 .64061 .19648 .63212 .18502 Mtetra
.63212 .18502 .64061 .19648 .6578 .19029 .64938 .17877 Mtetra
.64938 .17877 .6578 .19029 .67509 .18407 .66675 .17247 Mtetra
.66675 .17247 .67509 .18407 .69249 .17782 .68422 .16614 Mtetra
.663 .741 .908 r
.68422 .16614 .69249 .17782 .70999 .17152 .7018 .15977 Mtetra
.7018 .15977 .70999 .17152 .72761 .1652 .71949 .15336 Mtetra
.663 .741 .907 r
.71949 .15336 .72761 .1652 .74534 .15883 .73729 .14691 Mtetra
.663 .74 .907 r
.73729 .14691 .74534 .15883 .76317 .15243 .75521 .14042 Mtetra
.75521 .14042 .76317 .15243 .78112 .14599 .77323 .13389 Mtetra
.664 .741 .908 r
.13472 .35194 .14508 .36159 .15947 .35637 .14915 .34667 Mtetra
.14915 .34667 .15947 .35637 .17394 .35113 .16366 .34137 Mtetra
.16366 .34137 .17394 .35113 .18849 .34585 .17826 .33604 Mtetra
.17826 .33604 .18849 .34585 .20312 .34055 .19294 .33068 Mtetra
.19294 .33068 .20312 .34055 .21783 .33521 .2077 .32529 Mtetra
.2077 .32529 .21783 .33521 .23263 .32985 .22255 .31986 Mtetra
.22255 .31986 .23263 .32985 .24752 .32445 .23748 .31441 Mtetra
.23748 .31441 .24752 .32445 .26248 .31903 .2525 .30893 Mtetra
.2525 .30893 .26248 .31903 .27754 .31357 .26761 .30341 Mtetra
.26761 .30341 .27754 .31357 .29268 .30808 .2828 .29786 Mtetra
.2828 .29786 .29268 .30808 .30791 .30256 .29809 .29228 Mtetra
.29809 .29228 .30791 .30256 .32323 .29701 .31346 .28667 Mtetra
.31346 .28667 .32323 .29701 .33863 .29142 .32892 .28102 Mtetra
.32892 .28102 .33863 .29142 .35413 .2858 .34447 .27534 Mtetra
.34447 .27534 .35413 .2858 .36972 .28015 .36011 .26963 Mtetra
.36011 .26963 .36972 .28015 .3854 .27447 .37585 .26389 Mtetra
.37585 .26389 .3854 .27447 .40117 .26875 .39168 .25811 Mtetra
.39168 .25811 .40117 .26875 .41703 .263 .4076 .25229 Mtetra
.4076 .25229 .41703 .263 .43299 .25721 .42362 .24644 Mtetra
.42362 .24644 .43299 .25721 .44904 .25139 .43973 .24056 Mtetra
.43973 .24056 .44904 .25139 .46519 .24554 .45594 .23464 Mtetra
.45594 .23464 .46519 .24554 .48143 .23965 .47225 .22869 Mtetra
.47225 .22869 .48143 .23965 .49778 .23373 .48865 .2227 Mtetra
.48865 .2227 .49778 .23373 .51422 .22777 .50516 .21667 Mtetra
.50516 .21667 .51422 .22777 .53076 .22177 .52176 .21061 Mtetra
.52176 .21061 .53076 .22177 .5474 .21574 .53847 .20451 Mtetra
.53847 .20451 .5474 .21574 .56414 .20967 .55527 .19837 Mtetra
.55527 .19837 .56414 .20967 .58098 .20357 .57218 .1922 Mtetra
.57218 .1922 .58098 .20357 .59792 .19742 .5892 .18598 Mtetra
.5892 .18598 .59792 .19742 .61497 .19124 .60632 .17973 Mtetra
.60632 .17973 .61497 .19124 .63212 .18502 .62354 .17344 Mtetra
.62354 .17344 .63212 .18502 .64938 .17877 .64087 .16711 Mtetra
.64087 .16711 .64938 .17877 .66675 .17247 .65831 .16075 Mtetra
.65831 .16075 .66675 .17247 .68422 .16614 .67586 .15434 Mtetra
.67586 .15434 .68422 .16614 .7018 .15977 .69351 .14789 Mtetra
.69351 .14789 .7018 .15977 .71949 .15336 .71128 .14141 Mtetra
.71128 .14141 .71949 .15336 .73729 .14691 .72916 .13488 Mtetra
.72916 .13488 .73729 .14691 .75521 .14042 .74715 .12831 Mtetra
.663 .741 .908 r
.74715 .12831 .75521 .14042 .77323 .13389 .76525 .1217 Mtetra
.664 .741 .908 r
.12424 .34218 .13472 .35194 .14915 .34667 .13872 .33686 Mtetra
.13872 .33686 .14915 .34667 .16366 .34137 .15328 .3315 Mtetra
.15328 .3315 .16366 .34137 .17826 .33604 .16793 .32612 Mtetra
.16793 .32612 .17826 .33604 .19294 .33068 .18265 .3207 Mtetra
.18265 .3207 .19294 .33068 .2077 .32529 .19747 .31525 Mtetra
.19747 .31525 .2077 .32529 .22255 .31986 .21236 .30977 Mtetra
.21236 .30977 .22255 .31986 .23748 .31441 .22735 .30426 Mtetra
.22735 .30426 .23748 .31441 .2525 .30893 .24242 .29872 Mtetra
.24242 .29872 .2525 .30893 .26761 .30341 .25758 .29314 Mtetra
.25758 .29314 .26761 .30341 .2828 .29786 .27282 .28753 Mtetra
.27282 .28753 .2828 .29786 .29809 .29228 .28816 .28189 Mtetra
.28816 .28189 .29809 .29228 .31346 .28667 .30358 .27622 Mtetra
.30358 .27622 .31346 .28667 .32892 .28102 .3191 .27051 Mtetra
.3191 .27051 .32892 .28102 .34447 .27534 .33471 .26477 Mtetra
.33471 .26477 .34447 .27534 .36011 .26963 .35041 .259 Mtetra
.35041 .259 .36011 .26963 .37585 .26389 .3662 .25319 Mtetra
.3662 .25319 .37585 .26389 .39168 .25811 .38209 .24735 Mtetra
.38209 .24735 .39168 .25811 .4076 .25229 .39807 .24147 Mtetra
.39807 .24147 .4076 .25229 .42362 .24644 .41415 .23555 Mtetra
.41415 .23555 .42362 .24644 .43973 .24056 .43032 .22961 Mtetra
.43032 .22961 .43973 .24056 .45594 .23464 .44659 .22362 Mtetra
.44659 .22362 .45594 .23464 .47225 .22869 .46296 .2176 Mtetra
.46296 .2176 .47225 .22869 .48865 .2227 .47943 .21154 Mtetra
.47943 .21154 .48865 .2227 .50516 .21667 .496 .20545 Mtetra
.496 .20545 .50516 .21667 .52176 .21061 .51267 .19932 Mtetra
.51267 .19932 .52176 .21061 .53847 .20451 .52944 .19315 Mtetra
.52944 .19315 .53847 .20451 .55527 .19837 .54631 .18694 Mtetra
.54631 .18694 .55527 .19837 .57218 .1922 .56329 .1807 Mtetra
.56329 .1807 .57218 .1922 .5892 .18598 .58037 .17441 Mtetra
.58037 .17441 .5892 .18598 .60632 .17973 .59756 .16809 Mtetra
.59756 .16809 .60632 .17973 .62354 .17344 .61486 .16173 Mtetra
.61486 .16173 .62354 .17344 .64087 .16711 .63226 .15533 Mtetra
.63226 .15533 .64087 .16711 .65831 .16075 .64977 .14889 Mtetra
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Mtetra
.6674 .14241 .67586 .15434 .69351 .14789 .68513 .13588 Mtetra
.68513 .13588 .69351 .14789 .71128 .14141 .70297 .12932 Mtetra
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.11366 .33233 .12424 .34218 .13872 .33686 .12818 .32695 Mtetra
.12818 .32695 .13872 .33686 .15328 .3315 .14279 .32154 Mtetra
.14279 .32154 .15328 .3315 .16793 .32612 .15748 .31609 Mtetra
.15748 .31609 .16793 .32612 .18265 .3207 .17226 .31062 Mtetra
.17226 .31062 .18265 .3207 .19747 .31525 .18712 .30511 Mtetra
.18712 .30511 .19747 .31525 .21236 .30977 .20207 .29957 Mtetra
.20207 .29957 .21236 .30977 .22735 .30426 .2171 .294 Mtetra
.2171 .294 .22735 .30426 .24242 .29872 .23222 .2884 Mtetra
.23222 .2884 .24242 .29872 .25758 .29314 .24743 .28276 Mtetra
.24743 .28276 .25758 .29314 .27282 .28753 .26273 .2771 Mtetra
.26273 .2771 .27282 .28753 .28816 .28189 .27812 .27139 Mtetra
.27812 .27139 .28816 .28189 .30358 .27622 .2936 .26566 Mtetra
.2936 .26566 .30358 .27622 .3191 .27051 .30917 .25989 Mtetra
.30917 .25989 .3191 .27051 .33471 .26477 .32484 .25409 Mtetra
.32484 .25409 .33471 .26477 .35041 .259 .34059 .24825 Mtetra
.34059 .24825 .35041 .259 .3662 .25319 .35644 .24237 Mtetra
.35644 .24237 .3662 .25319 .38209 .24735 .37239 .23647 Mtetra
.37239 .23647 .38209 .24735 .39807 .24147 .38843 .23052 Mtetra
.38843 .23052 .39807 .24147 .41415 .23555 .40457 .22454 Mtetra
.40457 .22454 .41415 .23555 .43032 .22961 .4208 .21853 Mtetra
.4208 .21853 .43032 .22961 .44659 .22362 .43714 .21248 Mtetra
.43714 .21248 .44659 .22362 .46296 .2176 .45357 .20639 Mtetra
.45357 .20639 .46296 .2176 .47943 .21154 .4701 .20026 Mtetra
.4701 .20026 .47943 .21154 .496 .20545 .48673 .1941 Mtetra
.48673 .1941 .496 .20545 .51267 .19932 .50347 .1879 Mtetra
.50347 .1879 .51267 .19932 .52944 .19315 .52031 .18166 Mtetra
.52031 .18166 .52944 .19315 .54631 .18694 .53725 .17538 Mtetra
.53725 .17538 .54631 .18694 .56329 .1807 .5543 .16907 Mtetra
.5543 .16907 .56329 .1807 .58037 .17441 .57145 .16271 Mtetra
.57145 .16271 .58037 .17441 .59756 .16809 .58871 .15632 Mtetra
.58871 .15632 .59756 .16809 .61486 .16173 .60608 .14988 Mtetra
.60608 .14988 .61486 .16173 .63226 .15533 .62355 .14341 Mtetra
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Mtetra
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Mtetra
.65884 .13033 .6674 .14241 .68513 .13588 .67665 .12373 Mtetra
.67665 .12373 .68513 .13588 .70297 .12932 .69457 .11709 Mtetra
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.10296 .32237 .11366 .33233 .12818 .32695 .11753 .31693 Mtetra
.11753 .31693 .12818 .32695 .14279 .32154 .13219 .31146 Mtetra
.13219 .31146 .14279 .32154 .15748 .31609 .14693 .30596 Mtetra
.14693 .30596 .15748 .31609 .17226 .31062 .16175 .30043 Mtetra
.16175 .30043 .17226 .31062 .18712 .30511 .17666 .29486 Mtetra
.17666 .29486 .18712 .30511 .20207 .29957 .19166 .28926 Mtetra
.19166 .28926 .20207 .29957 .2171 .294 .20674 .28363 Mtetra
.20674 .28363 .2171 .294 .23222 .2884 .22192 .27797 Mtetra
.22192 .27797 .23222 .2884 .24743 .28276 .23718 .27227 Mtetra
.23718 .27227 .24743 .28276 .26273 .2771 .25253 .26654 Mtetra
.25253 .26654 .26273 .2771 .27812 .27139 .26797 .26078 Mtetra
.26797 .26078 .27812 .27139 .2936 .26566 .28351 .25498 Mtetra
.28351 .25498 .2936 .26566 .30917 .25989 .29914 .24915 Mtetra
.29914 .24915 .30917 .25989 .32484 .25409 .31485 .24328 Mtetra
.31485 .24328 .32484 .25409 .34059 .24825 .33067 .23738 Mtetra
.33067 .23738 .34059 .24825 .35644 .24237 .34658 .23144 Mtetra
.34658 .23144 .35644 .24237 .37239 .23647 .36258 .22547 Mtetra
.36258 .22547 .37239 .23647 .38843 .23052 .37868 .21946 Mtetra
.37868 .21946 .38843 .23052 .40457 .22454 .39488 .21341 Mtetra
.39488 .21341 .40457 .22454 .4208 .21853 .41118 .20733 Mtetra
.41118 .20733 .4208 .21853 .43714 .21248 .42757 .20121 Mtetra
.42757 .20121 .43714 .21248 .45357 .20639 .44407 .19505 Mtetra
.44407 .19505 .45357 .20639 .4701 .20026 .46067 .18886 Mtetra
.46067 .18886 .4701 .20026 .48673 .1941 .47737 .18262 Mtetra
.47737 .18262 .48673 .1941 .50347 .1879 .49417 .17635 Mtetra
.49417 .17635 .50347 .1879 .52031 .18166 .51107 .17004 Mtetra
.51107 .17004 .52031 .18166 .53725 .17538 .52808 .16369 Mtetra
.52808 .16369 .53725 .17538 .5543 .16907 .5452 .1573 Mtetra
.5452 .1573 .5543 .16907 .57145 .16271 .56242 .15087 Mtetra
.56242 .15087 .57145 .16271 .58871 .15632 .57976 .1444 Mtetra
.57976 .1444 .58871 .15632 .60608 .14988 .5972 .1379 Mtetra
.5972 .1379 .60608 .14988 .62355 .14341 .61475 .13134 Mtetra
.61475 .13134 .62355 .14341 .64114 .13689 .63241 .12475 Mtetra
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Mtetra
.65018 .11812 .65884 .13033 .67665 .12373 .66806 .11144 Mtetra
.66806 .11144 .67665 .12373 .69457 .11709 .68606 .10472 Mtetra
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Mtetra
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.09215 .3123 .10296 .32237 .11753 .31693 .10677 .30681 Mtetra
.10677 .30681 .11753 .31693 .13219 .31146 .12147 .30128 Mtetra
.12147 .30128 .13219 .31146 .14693 .30596 .13626 .29572 Mtetra
.13626 .29572 .14693 .30596 .16175 .30043 .15113 .29013 Mtetra
.15113 .29013 .16175 .30043 .17666 .29486 .16609 .2845 Mtetra
.16609 .2845 .17666 .29486 .19166 .28926 .18114 .27884 Mtetra
.18114 .27884 .19166 .28926 .20674 .28363 .19627 .27315 Mtetra
.19627 .27315 .20674 .28363 .22192 .27797 .2115 .26743 Mtetra
.2115 .26743 .22192 .27797 .23718 .27227 .22681 .26167 Mtetra
.22681 .26167 .23718 .27227 .25253 .26654 .24222 .25587 Mtetra
.24222 .25587 .25253 .26654 .26797 .26078 .25772 .25005 Mtetra
.25772 .25005 .26797 .26078 .28351 .25498 .27331 .24418 Mtetra
.27331 .24418 .28351 .25498 .29914 .24915 .28899 .23829 Mtetra
.28899 .23829 .29914 .24915 .31485 .24328 .30476 .23236 Mtetra
.30476 .23236 .31485 .24328 .33067 .23738 .32064 .22639 Mtetra
.32064 .22639 .33067 .23738 .34658 .23144 .3366 .22038 Mtetra
.3366 .22038 .34658 .23144 .36258 .22547 .35267 .21434 Mtetra
.35267 .21434 .36258 .22547 .37868 .21946 .36883 .20827 Mtetra
.36883 .20827 .37868 .21946 .39488 .21341 .38509 .20215 Mtetra
.38509 .20215 .39488 .21341 .41118 .20733 .40145 .196 Mtetra
.40145 .196 .41118 .20733 .42757 .20121 .4179 .18981 Mtetra
.4179 .18981 .42757 .20121 .44407 .19505 .43446 .18358 Mtetra
.43446 .18358 .44407 .19505 .46067 .18886 .45113 .17732 Mtetra
.45113 .17732 .46067 .18886 .47737 .18262 .46789 .17101 Mtetra
.46789 .17101 .47737 .18262 .49417 .17635 .48476 .16467 Mtetra
.48476 .16467 .49417 .17635 .51107 .17004 .50173 .15829 Mtetra
.50173 .15829 .51107 .17004 .52808 .16369 .51881 .15187 Mtetra
.51881 .15187 .52808 .16369 .5452 .1573 .536 .1454 Mtetra
.536 .1454 .5452 .1573 .56242 .15087 .55329 .1389 Mtetra
.55329 .1389 .56242 .15087 .57976 .1444 .5707 .13236 Mtetra
.5707 .13236 .57976 .1444 .5972 .1379 .58821 .12577 Mtetra
.58821 .12577 .5972 .1379 .61475 .13134 .60583 .11914 Mtetra
.60583 .11914 .61475 .13134 .63241 .12475 .62357 .11247 Mtetra
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Mtetra
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Mtetra
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Mtetra
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Mtetra
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.08123 .30213 .09215 .3123 .10677 .30681 .09589 .29658 Mtetra
.09589 .29658 .10677 .30681 .12147 .30128 .11064 .29099 Mtetra
.11064 .29099 .12147 .30128 .13626 .29572 .12548 .28537 Mtetra
.12548 .28537 .13626 .29572 .15113 .29013 .1404 .27972 Mtetra
.1404 .27972 .15113 .29013 .16609 .2845 .15541 .27403 Mtetra
.15541 .27403 .16609 .2845 .18114 .27884 .1705 .26831 Mtetra
.1705 .26831 .18114 .27884 .19627 .27315 .18569 .26256 Mtetra
.18569 .26256 .19627 .27315 .2115 .26743 .20097 .25677 Mtetra
.20097 .25677 .2115 .26743 .22681 .26167 .21634 .25095 Mtetra
.21634 .25095 .22681 .26167 .24222 .25587 .23179 .24509 Mtetra
.23179 .24509 .24222 .25587 .25772 .25005 .24735 .2392 Mtetra
.24735 .2392 .25772 .25005 .27331 .24418 .26299 .23327 Mtetra
.26299 .23327 .27331 .24418 .28899 .23829 .27873 .22731 Mtetra
.27873 .22731 .28899 .23829 .30476 .23236 .29456 .22131 Mtetra
.29456 .22131 .30476 .23236 .32064 .22639 .31049 .21527 Mtetra
.31049 .21527 .32064 .22639 .3366 .22038 .32652 .2092 Mtetra
.32652 .2092 .3366 .22038 .35267 .21434 .34264 .20309 Mtetra
.34264 .20309 .35267 .21434 .36883 .20827 .35886 .19695 Mtetra
.35886 .19695 .36883 .20827 .38509 .20215 .37518 .19077 Mtetra
.37518 .19077 .38509 .20215 .40145 .196 .3916 .18454 Mtetra
.3916 .18454 .40145 .196 .4179 .18981 .40812 .17828 Mtetra
.40812 .17828 .4179 .18981 .43446 .18358 .42475 .17199 Mtetra
.42475 .17199 .43446 .18358 .45113 .17732 .44148 .16565 Mtetra
.44148 .16565 .45113 .17732 .46789 .17101 .45831 .15927 Mtetra
.45831 .15927 .46789 .17101 .48476 .16467 .47524 .15286 Mtetra
.47524 .15286 .48476 .16467 .50173 .15829 .49228 .1464 Mtetra
.49228 .1464 .50173 .15829 .51881 .15187 .50943 .1399 Mtetra
.50943 .1399 .51881 .15187 .536 .1454 .52669 .13336 Mtetra
.52669 .13336 .536 .1454 .55329 .1389 .54406 .12679 Mtetra
.54406 .12679 .55329 .1389 .5707 .13236 .56153 .12016 Mtetra
.56153 .12016 .5707 .13236 .58821 .12577 .57912 .1135 Mtetra
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Mtetra
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Mtetra
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Mtetra
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Mtetra
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Mtetra
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Mtetra
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Mtetra
.07019 .29185 .08123 .30213 .09589 .29658 .0849 .28624 Mtetra
.0849 .28624 .09589 .29658 .11064 .29099 .09969 .28059 Mtetra
.09969 .28059 .11064 .29099 .12548 .28537 .11458 .27491 Mtetra
.11458 .27491 .12548 .28537 .1404 .27972 .12955 .26919 Mtetra
.12955 .26919 .1404 .27972 .15541 .27403 .14461 .26344 Mtetra
.14461 .26344 .15541 .27403 .1705 .26831 .15975 .25766 Mtetra
.15975 .25766 .1705 .26831 .18569 .26256 .17499 .25184 Mtetra
.17499 .25184 .18569 .26256 .20097 .25677 .19032 .24599 Mtetra
.19032 .24599 .20097 .25677 .21634 .25095 .20574 .24011 Mtetra
.20574 .24011 .21634 .25095 .23179 .24509 .22125 .23418 Mtetra
.22125 .23418 .23179 .24509 .24735 .2392 .23686 .22823 Mtetra
.23686 .22823 .24735 .2392 .26299 .23327 .25256 .22223 Mtetra
.25256 .22223 .26299 .23327 .27873 .22731 .26835 .2162 Mtetra
.26835 .2162 .27873 .22731 .29456 .22131 .28424 .21014 Mtetra
.28424 .21014 .29456 .22131 .31049 .21527 .30023 .20404 Mtetra
.30023 .20404 .31049 .21527 .32652 .2092 .31632 .1979 Mtetra
.31632 .1979 .32652 .2092 .34264 .20309 .3325 .19172 Mtetra
.3325 .19172 .34264 .20309 .35886 .19695 .34878 .1855 Mtetra
.34878 .1855 .35886 .19695 .37518 .19077 .36516 .17925 Mtetra
.36516 .17925 .37518 .19077 .3916 .18454 .38165 .17296 Mtetra
.38165 .17296 .3916 .18454 .40812 .17828 .39823 .16663 Mtetra
.39823 .16663 .40812 .17828 .42475 .17199 .41492 .16026 Mtetra
.41492 .16026 .42475 .17199 .44148 .16565 .43171 .15385 Mtetra
.43171 .15385 .44148 .16565 .45831 .15927 .44861 .1474 Mtetra
.44861 .1474 .45831 .15927 .47524 .15286 .46562 .1409 Mtetra
.46562 .1409 .47524 .15286 .49228 .1464 .48273 .13437 Mtetra
.48273 .13437 .49228 .1464 .50943 .1399 .49994 .1278 Mtetra
.49994 .1278 .50943 .1399 .52669 .13336 .51727 .12119 Mtetra
.51727 .12119 .52669 .13336 .54406 .12679 .53471 .11453 Mtetra
.53471 .11453 .54406 .12679 .56153 .12016 .55226 .10783 Mtetra
.55226 .10783 .56153 .12016 .57912 .1135 .56992 .10109 Mtetra
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Mtetra
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Mtetra
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Mtetra
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Mtetra
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Mtetra
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Mtetra
.05902 .28146 .07019 .29185 .0849 .28624 .07378 .27578 Mtetra
.07378 .27578 .0849 .28624 .09969 .28059 .08863 .27007 Mtetra
.08863 .27007 .09969 .28059 .11458 .27491 .10356 .26433 Mtetra
.10356 .26433 .11458 .27491 .12955 .26919 .11858 .25855 Mtetra
.11858 .25855 .12955 .26919 .14461 .26344 .13369 .25274 Mtetra
.13369 .25274 .14461 .26344 .15975 .25766 .14889 .24689 Mtetra
.14889 .24689 .15975 .25766 .17499 .25184 .16417 .24101 Mtetra
.16417 .24101 .17499 .25184 .19032 .24599 .17956 .2351 Mtetra
.17956 .2351 .19032 .24599 .20574 .24011 .19503 .22915 Mtetra
.19503 .22915 .20574 .24011 .22125 .23418 .2106 .22316 Mtetra
.2106 .22316 .22125 .23418 .23686 .22823 .22626 .21713 Mtetra
.22626 .21713 .23686 .22823 .25256 .22223 .24201 .21107 Mtetra
.24201 .21107 .25256 .22223 .26835 .2162 .25786 .20498 Mtetra
.25786 .20498 .26835 .2162 .28424 .21014 .27381 .19884 Mtetra
.27381 .19884 .28424 .21014 .30023 .20404 .28986 .19267 Mtetra
.28986 .19267 .30023 .20404 .31632 .1979 .306 .18646 Mtetra
.306 .18646 .31632 .1979 .3325 .19172 .32224 .18021 Mtetra
.32224 .18021 .3325 .19172 .34878 .1855 .33859 .17393 Mtetra
.33859 .17393 .34878 .1855 .36516 .17925 .35503 .1676 Mtetra
.35503 .1676 .36516 .17925 .38165 .17296 .37158 .16124 Mtetra
.37158 .16124 .38165 .17296 .39823 .16663 .38823 .15483 Mtetra
.38823 .15483 .39823 .16663 .41492 .16026 .40498 .14839 Mtetra
.40498 .14839 .41492 .16026 .43171 .15385 .42184 .14191 Mtetra
.42184 .14191 .43171 .15385 .44861 .1474 .4388 .13538 Mtetra
.4388 .13538 .44861 .1474 .46562 .1409 .45588 .12881 Mtetra
.45588 .12881 .46562 .1409 .48273 .13437 .47306 .12221 Mtetra
.47306 .12221 .48273 .13437 .49994 .1278 .49034 .11556 Mtetra
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Mtetra
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Mtetra
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Mtetra
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Mtetra
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Mtetra
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Mtetra
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Mtetra
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Mtetra
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Mtetra
.04774 .27095 .05902 .28146 .07378 .27578 .06255 .26522 Mtetra
.06255 .26522 .07378 .27578 .08863 .27007 .07744 .25944 Mtetra
.07744 .25944 .08863 .27007 .10356 .26433 .09242 .25364 Mtetra
.09242 .25364 .10356 .26433 .11858 .25855 .10749 .2478 Mtetra
.10749 .2478 .11858 .25855 .13369 .25274 .12265 .24192 Mtetra
.12265 .24192 .13369 .25274 .14889 .24689 .1379 .23601 Mtetra
.1379 .23601 .14889 .24689 .16417 .24101 .15324 .23006 Mtetra
.15324 .23006 .16417 .24101 .17956 .2351 .16867 .22408 Mtetra
.16867 .22408 .17956 .2351 .19503 .22915 .1842 .21806 Mtetra
.1842 .21806 .19503 .22915 .2106 .22316 .19982 .21201 Mtetra
.19982 .21201 .2106 .22316 .22626 .21713 .21553 .20592 Mtetra
.21553 .20592 .22626 .21713 .24201 .21107 .23135 .19979 Mtetra
.23135 .19979 .24201 .21107 .25786 .20498 .24725 .19362 Mtetra
.24725 .19362 .25786 .20498 .27381 .19884 .26326 .18742 Mtetra
.26326 .18742 .27381 .19884 .28986 .19267 .27936 .18118 Mtetra
.27936 .18118 .28986 .19267 .306 .18646 .29557 .1749 Mtetra
.29557 .1749 .306 .18646 .32224 .18021 .31187 .16858 Mtetra
.31187 .16858 .32224 .18021 .33859 .17393 .32828 .16222 Mtetra
.32828 .16222 .33859 .17393 .35503 .1676 .34478 .15582 Mtetra
.34478 .15582 .35503 .1676 .37158 .16124 .36139 .14938 Mtetra
.36139 .14938 .37158 .16124 .38823 .15483 .37811 .14291 Mtetra
.37811 .14291 .38823 .15483 .40498 .14839 .39493 .13639 Mtetra
.39493 .13639 .40498 .14839 .42184 .14191 .41185 .12983 Mtetra
.41185 .12983 .42184 .14191 .4388 .13538 .42888 .12323 Mtetra
.42888 .12323 .4388 .13538 .45588 .12881 .44602 .11658 Mtetra
.44602 .11658 .45588 .12881 .47306 .12221 .46327 .1099 Mtetra
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Mtetra
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Mtetra
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Mtetra
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Mtetra
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Mtetra
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Mtetra
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Mtetra
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Mtetra
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Mtetra
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.03634 .26033 .04774 .27095 .06255 .26522 .05119 .25453 Mtetra
.05119 .25453 .06255 .26522 .07744 .25944 .06613 .2487 Mtetra
.06613 .2487 .07744 .25944 .09242 .25364 .08116 .24283 Mtetra
.08116 .24283 .09242 .25364 .10749 .2478 .09628 .23692 Mtetra
.09628 .23692 .10749 .2478 .12265 .24192 .11148 .23098 Mtetra
.11148 .23098 .12265 .24192 .1379 .23601 .12679 .225 Mtetra
.12679 .225 .1379 .23601 .15324 .23006 .14218 .21899 Mtetra
.14218 .21899 .15324 .23006 .16867 .22408 .15767 .21294 Mtetra
.15767 .21294 .16867 .22408 .1842 .21806 .17325 .20686 Mtetra
.17325 .20686 .1842 .21806 .19982 .21201 .18892 .20073 Mtetra
.18892 .20073 .19982 .21201 .21553 .20592 .20469 .19457 Mtetra
.20469 .19457 .21553 .20592 .23135 .19979 .22056 .18838 Mtetra
.22056 .18838 .23135 .19979 .24725 .19362 .23652 .18214 Mtetra
.23652 .18214 .24725 .19362 .26326 .18742 .25259 .17587 Mtetra
.25259 .17587 .26326 .18742 .27936 .18118 .26875 .16955 Mtetra
.26875 .16955 .27936 .18118 .29557 .1749 .28501 .1632 Mtetra
.28501 .1632 .29557 .1749 .31187 .16858 .30138 .15681 Mtetra
.30138 .15681 .31187 .16858 .32828 .16222 .31785 .15038 Mtetra
.31785 .15038 .32828 .16222 .34478 .15582 .33442 .14391 Mtetra
.33442 .14391 .34478 .15582 .36139 .14938 .35109 .13739 Mtetra
.35109 .13739 .36139 .14938 .37811 .14291 .36787 .13084 Mtetra
.36787 .13084 .37811 .14291 .39493 .13639 .38475 .12424 Mtetra
.38475 .12424 .39493 .13639 .41185 .12983 .40174 .11761 Mtetra
.40174 .11761 .41185 .12983 .42888 .12323 .41884 .11093 Mtetra
.41884 .11093 .42888 .12323 .44602 .11658 .43605 .10421 Mtetra
.43605 .10421 .44602 .11658 .46327 .1099 .45337 .09744 Mtetra
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Mtetra
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Mtetra
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Mtetra
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Mtetra
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Mtetra
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Mtetra
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Mtetra
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Mtetra
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Mtetra
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Mtetra
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Mtetra
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Mtetra
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Mtetra
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Mtetra
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Mtetra
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Mtetra
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Mtetra
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Mtetra
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Mtetra
.57384 .54314 .58111 .55092 .59512 .54671 .5879 .53889 Mtetra
.5879 .53889 .59512 .54671 .60921 .54249 .60203 .53463 Mtetra
.60203 .53463 .60921 .54249 .62337 .53824 .61624 .53034 Mtetra
.61624 .53034 .62337 .53824 .63759 .53397 .63052 .52603 Mtetra
.63052 .52603 .63759 .53397 .6519 .52968 .64487 .5217 Mtetra
.64487 .5217 .6519 .52968 .66627 .52537 .6593 .51735 Mtetra
.6593 .51735 .66627 .52537 .68072 .52103 .67379 .51297 Mtetra
.67379 .51297 .68072 .52103 .69524 .51668 .68837 .50857 Mtetra
.68837 .50857 .69524 .51668 .70984 .5123 .70302 .50415 Mtetra
.70302 .50415 .70984 .5123 .72452 .5079 .71774 .49971 Mtetra
.71774 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Mtetra
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Mtetra
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Mtetra
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Mtetra
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Mtetra
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Mtetra
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Mtetra
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Mtetra
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Mtetra
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Mtetra
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .53529 Mtetra
.5665 .53529 .57384 .54314 .5879 .53889 .58061 .531 Mtetra
.58061 .531 .5879 .53889 .60203 .53463 .59479 .5267 Mtetra
.59479 .5267 .60203 .53463 .61624 .53034 .60905 .52237 Mtetra
.60905 .52237 .61624 .53034 .63052 .52603 .62338 .51802 Mtetra
.62338 .51802 .63052 .52603 .64487 .5217 .63778 .51365 Mtetra
.63778 .51365 .64487 .5217 .6593 .51735 .65225 .50925 Mtetra
.65225 .50925 .6593 .51735 .67379 .51297 .6668 .50483 Mtetra
.6668 .50483 .67379 .51297 .68837 .50857 .68143 .50039 Mtetra
.68143 .50039 .68837 .50857 .70302 .50415 .69613 .49593 Mtetra
.69613 .49593 .70302 .50415 .71774 .49971 .71091 .49144 Mtetra
.71091 .49144 .71774 .49971 .73255 .49524 .72577 .48693 Mtetra
.72577 .48693 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Mtetra
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Mtetra
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Mtetra
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55702 Mtetra
.46198 .55702 .4697 .56468 .48332 .56054 .47564 .55285 Mtetra
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Mtetra
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Mtetra
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .5402 Mtetra
.51705 .5402 .5246 .54801 .5385 .54379 .531 .53594 Mtetra
.531 .53594 .5385 .54379 .55246 .53955 .54501 .53166 Mtetra
.54501 .53166 .55246 .53955 .5665 .53529 .5591 .52736 Mtetra
.5591 .52736 .5665 .53529 .58061 .531 .57325 .52304 Mtetra
.57325 .52304 .58061 .531 .59479 .5267 .58748 .51869 Mtetra
.58748 .51869 .59479 .5267 .60905 .52237 .60179 .51432 Mtetra
.60179 .51432 .60905 .52237 .62338 .51802 .61616 .50993 Mtetra
.61616 .50993 .62338 .51802 .63778 .51365 .63062 .50552 Mtetra
.63062 .50552 .63778 .51365 .65225 .50925 .64514 .50108 Mtetra
.64514 .50108 .65225 .50925 .6668 .50483 .65974 .49662 Mtetra
.65974 .49662 .6668 .50483 .68143 .50039 .67442 .49214 Mtetra
.67442 .49214 .68143 .50039 .69613 .49593 .68918 .48763 Mtetra
.68918 .48763 .69613 .49593 .71091 .49144 .70401 .4831 Mtetra
.70401 .4831 .71091 .49144 .72577 .48693 .71892 .47854 Mtetra
.71892 .47854 .72577 .48693 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46936 Mtetra
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Mtetra
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56181 Mtetra
.41347 .56181 .42139 .56942 .43486 .56531 .42697 .55767 Mtetra
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .55349 Mtetra
.44054 .55349 .44838 .56118 .46198 .55702 .45418 .5493 Mtetra
.45418 .5493 .46198 .55702 .47564 .55285 .46789 .54509 Mtetra
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Mtetra
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Mtetra
.49552 .5366 .50318 .54444 .51705 .5402 .50944 .53232 Mtetra
.50944 .53232 .51705 .5402 .531 .53594 .52343 .52802 Mtetra
.52343 .52802 .531 .53594 .54501 .53166 .53749 .5237 Mtetra
.53749 .5237 .54501 .53166 .5591 .52736 .55162 .51936 Mtetra
.55162 .51936 .5591 .52736 .57325 .52304 .56582 .51499 Mtetra
.56582 .51499 .57325 .52304 .58748 .51869 .5801 .51061 Mtetra
.5801 .51061 .58748 .51869 .60179 .51432 .59446 .5062 Mtetra
.59446 .5062 .60179 .51432 .61616 .50993 .60888 .50176 Mtetra
.60888 .50176 .61616 .50993 .63062 .50552 .62338 .49731 Mtetra
.62338 .49731 .63062 .50552 .64514 .50108 .63796 .49283 Mtetra
.63796 .49283 .64514 .50108 .65974 .49662 .65262 .48832 Mtetra
.65262 .48832 .65974 .49662 .67442 .49214 .66735 .4838 Mtetra
.66735 .4838 .67442 .49214 .68918 .48763 .68215 .47925 Mtetra
.68215 .47925 .68918 .48763 .70401 .4831 .69704 .47467 Mtetra
.69704 .47467 .70401 .4831 .71892 .47854 .712 .47007 Mtetra
.712 .47007 .71892 .47854 .73391 .47397 .72705 .46545 Mtetra
.72705 .46545 .73391 .47397 .74897 .46936 .74217 .4608 Mtetra
.74217 .4608 .74897 .46936 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Mtetra
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Mtetra
.39199 .55831 .40003 .56594 .41347 .56181 .40547 .55414 Mtetra
.40547 .55414 .41347 .56181 .42697 .55767 .41902 .54995 Mtetra
.41902 .54995 .42697 .55767 .44054 .55349 .43263 .54574 Mtetra
.43263 .54574 .44054 .55349 .45418 .5493 .44632 .54151 Mtetra
.44632 .54151 .45418 .5493 .46789 .54509 .46007 .53726 Mtetra
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .53298 Mtetra
.47389 .53298 .48167 .54086 .49552 .5366 .48778 .52869 Mtetra
.48778 .52869 .49552 .5366 .50944 .53232 .50175 .52437 Mtetra
.50175 .52437 .50944 .53232 .52343 .52802 .51578 .52003 Mtetra
.51578 .52003 .52343 .52802 .53749 .5237 .52989 .51567 Mtetra
.52989 .51567 .53749 .5237 .55162 .51936 .54407 .51128 Mtetra
.54407 .51128 .55162 .51936 .56582 .51499 .55833 .50688 Mtetra
.55833 .50688 .56582 .51499 .5801 .51061 .57265 .50245 Mtetra
.57265 .50245 .5801 .51061 .59446 .5062 .58706 .49799 Mtetra
.58706 .49799 .59446 .5062 .60888 .50176 .60153 .49352 Mtetra
.60153 .49352 .60888 .50176 .62338 .49731 .61609 .48902 Mtetra
.61609 .48902 .62338 .49731 .63796 .49283 .63071 .48449 Mtetra
.63071 .48449 .63796 .49283 .65262 .48832 .64542 .47995 Mtetra
.64542 .47995 .65262 .48832 .66735 .4838 .6602 .47538 Mtetra
.6602 .47538 .66735 .4838 .68215 .47925 .67506 .47078 Mtetra
.67506 .47078 .68215 .47925 .69704 .47467 .69 .46616 Mtetra
.69 .46616 .69704 .47467 .712 .47007 .70502 .46152 Mtetra
.70502 .46152 .712 .47007 .72705 .46545 .72012 .45685 Mtetra
.72012 .45685 .72705 .46545 .74217 .4608 .7353 .45216 Mtetra
.7353 .45216 .74217 .4608 .75737 .45613 .75056 .44744 Mtetra
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Mtetra
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Mtetra
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Mtetra
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Mtetra
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Mtetra
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53791 Mtetra
.42465 .53791 .43263 .54574 .44632 .54151 .43837 .53364 Mtetra
.43837 .53364 .44632 .54151 .46007 .53726 .45217 .52935 Mtetra
.45217 .52935 .46007 .53726 .47389 .53298 .46604 .52504 Mtetra
.46604 .52504 .47389 .53298 .48778 .52869 .47998 .5207 Mtetra
.47998 .5207 .48778 .52869 .50175 .52437 .49399 .51634 Mtetra
.49399 .51634 .50175 .52437 .51578 .52003 .50807 .51196 Mtetra
.50807 .51196 .51578 .52003 .52989 .51567 .52222 .50756 Mtetra
.52222 .50756 .52989 .51567 .54407 .51128 .53645 .50313 Mtetra
.53645 .50313 .54407 .51128 .55833 .50688 .55076 .49868 Mtetra
.55076 .49868 .55833 .50688 .57265 .50245 .56513 .49421 Mtetra
.56513 .49421 .57265 .50245 .58706 .49799 .57958 .48971 Mtetra
.57958 .48971 .58706 .49799 .60153 .49352 .59411 .48519 Mtetra
.59411 .48519 .60153 .49352 .61609 .48902 .60871 .48065 Mtetra
.60871 .48065 .61609 .48902 .63071 .48449 .6234 .47608 Mtetra
.6234 .47608 .63071 .48449 .64542 .47995 .63815 .47149 Mtetra
.63815 .47149 .64542 .47995 .6602 .47538 .65299 .46688 Mtetra
.65299 .46688 .6602 .47538 .67506 .47078 .6679 .46224 Mtetra
.6679 .46224 .67506 .47078 .69 .46616 .6829 .45757 Mtetra
.6829 .45757 .69 .46616 .70502 .46152 .69797 .45288 Mtetra
.69797 .45288 .70502 .46152 .72012 .45685 .71312 .44817 Mtetra
.71312 .44817 .72012 .45685 .7353 .45216 .72836 .44343 Mtetra
.72836 .44343 .7353 .45216 .75056 .44744 .74368 .43866 Mtetra
.74368 .43866 .75056 .44744 .7659 .4427 .75908 .43387 Mtetra
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42905 Mtetra
.77456 .42905 .78132 .43793 .79683 .43313 .79013 .42421 Mtetra
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Mtetra
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .5343 Mtetra
.40288 .5343 .41099 .54216 .42465 .53791 .41658 .53001 Mtetra
.41658 .53001 .42465 .53791 .43837 .53364 .43036 .5257 Mtetra
.43036 .5257 .43837 .53364 .45217 .52935 .4442 .52137 Mtetra
.4442 .52137 .45217 .52935 .46604 .52504 .45811 .51701 Mtetra
.45811 .51701 .46604 .52504 .47998 .5207 .4721 .51263 Mtetra
.4721 .51263 .47998 .5207 .49399 .51634 .48615 .50823 Mtetra
.48615 .50823 .49399 .51634 .50807 .51196 .50028 .50381 Mtetra
.50028 .50381 .50807 .51196 .52222 .50756 .51448 .49937 Mtetra
.51448 .49937 .52222 .50756 .53645 .50313 .52876 .4949 Mtetra
.52876 .4949 .53645 .50313 .55076 .49868 .54311 .4904 Mtetra
.54311 .4904 .55076 .49868 .56513 .49421 .55754 .48589 Mtetra
.55754 .48589 .56513 .49421 .57958 .48971 .57204 .48135 Mtetra
.57204 .48135 .57958 .48971 .59411 .48519 .58662 .47679 Mtetra
.58662 .47679 .59411 .48519 .60871 .48065 .60127 .4722 Mtetra
.60127 .4722 .60871 .48065 .6234 .47608 .616 .46759 Mtetra
.616 .46759 .6234 .47608 .63815 .47149 .63082 .46295 Mtetra
.63082 .46295 .63815 .47149 .65299 .46688 .6457 .45829 Mtetra
.6457 .45829 .65299 .46688 .6679 .46224 .66067 .4536 Mtetra
.66067 .4536 .6679 .46224 .6829 .45757 .67572 .44889 Mtetra
.67572 .44889 .6829 .45757 .69797 .45288 .69085 .44416 Mtetra
.69085 .44416 .69797 .45288 .71312 .44817 .70606 .4394 Mtetra
.70606 .4394 .71312 .44817 .72836 .44343 .72135 .43461 Mtetra
.72135 .43461 .72836 .44343 .74368 .43866 .73673 .4298 Mtetra
.73673 .4298 .74368 .43866 .75908 .43387 .75218 .42496 Mtetra
.75218 .42496 .75908 .43387 .77456 .42905 .76773 .42009 Mtetra
.76773 .42009 .77456 .42905 .79013 .42421 .78335 .4152 Mtetra
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Mtetra
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Mtetra
.38103 .53067 .38925 .53857 .40288 .5343 .3947 .52637 Mtetra
.3947 .52637 .40288 .5343 .41658 .53001 .40845 .52204 Mtetra
.40845 .52204 .41658 .53001 .43036 .5257 .42226 .51768 Mtetra
.42226 .51768 .43036 .5257 .4442 .52137 .43615 .51331 Mtetra
.43615 .51331 .4442 .52137 .45811 .51701 .45011 .50891 Mtetra
.45011 .50891 .45811 .51701 .4721 .51263 .46414 .50449 Mtetra
.46414 .50449 .4721 .51263 .48615 .50823 .47824 .50005 Mtetra
.47824 .50005 .48615 .50823 .50028 .50381 .49242 .49559 Mtetra
.49242 .49559 .50028 .50381 .51448 .49937 .50667 .4911 Mtetra
.50667 .4911 .51448 .49937 .52876 .4949 .52099 .48658 Mtetra
.52099 .48658 .52876 .4949 .54311 .4904 .53539 .48205 Mtetra
.53539 .48205 .54311 .4904 .55754 .48589 .54987 .47749 Mtetra
.54987 .47749 .55754 .48589 .57204 .48135 .56442 .47291 Mtetra
.56442 .47291 .57204 .48135 .58662 .47679 .57905 .4683 Mtetra
.57905 .4683 .58662 .47679 .60127 .4722 .59376 .46367 Mtetra
.59376 .46367 .60127 .4722 .616 .46759 .60854 .45901 Mtetra
.60854 .45901 .616 .46759 .63082 .46295 .62341 .45433 Mtetra
.62341 .45433 .63082 .46295 .6457 .45829 .63835 .44962 Mtetra
.63835 .44962 .6457 .45829 .66067 .4536 .65337 .44489 Mtetra
.65337 .44489 .66067 .4536 .67572 .44889 .66847 .44013 Mtetra
.66847 .44013 .67572 .44889 .69085 .44416 .68366 .43535 Mtetra
.68366 .43535 .69085 .44416 .70606 .4394 .69892 .43054 Mtetra
.69892 .43054 .70606 .4394 .72135 .43461 .71427 .4257 Mtetra
.71427 .4257 .72135 .43461 .73673 .4298 .72971 .42084 Mtetra
.72971 .42084 .73673 .4298 .75218 .42496 .74522 .41596 Mtetra
.74522 .41596 .75218 .42496 .76773 .42009 .76082 .41104 Mtetra
.76082 .41104 .76773 .42009 .78335 .4152 .77651 .4061 Mtetra
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Mtetra
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Mtetra
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Mtetra
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51835 Mtetra
.38644 .51835 .3947 .52637 .40845 .52204 .40023 .51398 Mtetra
.40023 .51398 .40845 .52204 .42226 .51768 .41409 .50959 Mtetra
.41409 .50959 .42226 .51768 .43615 .51331 .42802 .50518 Mtetra
.42802 .50518 .43615 .51331 .45011 .50891 .44203 .50074 Mtetra
.44203 .50074 .45011 .50891 .46414 .50449 .45611 .49627 Mtetra
.45611 .49627 .46414 .50449 .47824 .50005 .47026 .49179 Mtetra
.47026 .49179 .47824 .50005 .49242 .49559 .48448 .48728 Mtetra
.48448 .48728 .49242 .49559 .50667 .4911 .49878 .48275 Mtetra
.49878 .48275 .50667 .4911 .52099 .48658 .51315 .47819 Mtetra
.51315 .47819 .52099 .48658 .53539 .48205 .5276 .47361 Mtetra
.5276 .47361 .53539 .48205 .54987 .47749 .54213 .46901 Mtetra
.54213 .46901 .54987 .47749 .56442 .47291 .55673 .46438 Mtetra
.55673 .46438 .56442 .47291 .57905 .4683 .57141 .45973 Mtetra
.57141 .45973 .57905 .4683 .59376 .46367 .58617 .45505 Mtetra
.58617 .45505 .59376 .46367 .60854 .45901 .60101 .45035 Mtetra
.60101 .45035 .60854 .45901 .62341 .45433 .61592 .44562 Mtetra
.61592 .44562 .62341 .45433 .63835 .44962 .63092 .44086 Mtetra
.63092 .44086 .63835 .44962 .65337 .44489 .646 .43609 Mtetra
.646 .43609 .65337 .44489 .66847 .44013 .66115 .43128 Mtetra
.66115 .43128 .66847 .44013 .68366 .43535 .6764 .42645 Mtetra
.6764 .42645 .68366 .43535 .69892 .43054 .69172 .42159 Mtetra
.69172 .42159 .69892 .43054 .71427 .4257 .70712 .41671 Mtetra
.70712 .41671 .71427 .4257 .72971 .42084 .72262 .4118 Mtetra
.72262 .4118 .72971 .42084 .74522 .41596 .73819 .40686 Mtetra
.73819 .40686 .74522 .41596 .76082 .41104 .75385 .4019 Mtetra
.75385 .4019 .76082 .41104 .77651 .4061 .7696 .39691 Mtetra
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Mtetra
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Mtetra
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Mtetra
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Mtetra
.36434 .51466 .37272 .5227 .38644 .51835 .37811 .51027 Mtetra
.37811 .51027 .38644 .51835 .40023 .51398 .39194 .50586 Mtetra
.39194 .50586 .40023 .51398 .41409 .50959 .40584 .50142 Mtetra
.40584 .50142 .41409 .50959 .42802 .50518 .41982 .49696 Mtetra
.41982 .49696 .42802 .50518 .44203 .50074 .43387 .49248 Mtetra
.43387 .49248 .44203 .50074 .45611 .49627 .44799 .48798 Mtetra
.44799 .48798 .45611 .49627 .47026 .49179 .46219 .48345 Mtetra
.46219 .48345 .47026 .49179 .48448 .48728 .47646 .47889 Mtetra
.47646 .47889 .48448 .48728 .49878 .48275 .49081 .47432 Mtetra
.49081 .47432 .49878 .48275 .51315 .47819 .50523 .46972 Mtetra
.50523 .46972 .51315 .47819 .5276 .47361 .51973 .46509 Mtetra
.51973 .46509 .5276 .47361 .54213 .46901 .53431 .46044 Mtetra
.53431 .46044 .54213 .46901 .55673 .46438 .54896 .45577 Mtetra
.54896 .45577 .55673 .46438 .57141 .45973 .56369 .45107 Mtetra
.56369 .45107 .57141 .45973 .58617 .45505 .57851 .44635 Mtetra
.57851 .44635 .58617 .45505 .60101 .45035 .5934 .4416 Mtetra
.5934 .4416 .60101 .45035 .61592 .44562 .60837 .43682 Mtetra
.60837 .43682 .61592 .44562 .63092 .44086 .62342 .43202 Mtetra
.62342 .43202 .63092 .44086 .646 .43609 .63855 .4272 Mtetra
.63855 .4272 .646 .43609 .66115 .43128 .65376 .42234 Mtetra
.65376 .42234 .66115 .43128 .6764 .42645 .66906 .41746 Mtetra
.66906 .41746 .6764 .42645 .69172 .42159 .68444 .41256 Mtetra
.68444 .41256 .69172 .42159 .70712 .41671 .6999 .40762 Mtetra
.6999 .40762 .70712 .41671 .72262 .4118 .71545 .40267 Mtetra
.71545 .40267 .72262 .4118 .73819 .40686 .73109 .39768 Mtetra
.73109 .39768 .73819 .40686 .75385 .4019 .74681 .39266 Mtetra
.74681 .39266 .75385 .4019 .7696 .39691 .76262 .38762 Mtetra
.76262 .38762 .7696 .39691 .78543 .39189 .77851 .38255 Mtetra
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Mtetra
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .5021 Mtetra
.36969 .5021 .37811 .51027 .39194 .50586 .38357 .49765 Mtetra
.38357 .49765 .39194 .50586 .40584 .50142 .39752 .49317 Mtetra
.39752 .49317 .40584 .50142 .41982 .49696 .41154 .48867 Mtetra
.41154 .48867 .41982 .49696 .43387 .49248 .42564 .48415 Mtetra
.42564 .48415 .43387 .49248 .44799 .48798 .43981 .4796 Mtetra
.43981 .4796 .44799 .48798 .46219 .48345 .45405 .47502 Mtetra
.45405 .47502 .46219 .48345 .47646 .47889 .46837 .47043 Mtetra
.46837 .47043 .47646 .47889 .49081 .47432 .48277 .46581 Mtetra
.48277 .46581 .49081 .47432 .50523 .46972 .49724 .46116 Mtetra
.49724 .46116 .50523 .46972 .51973 .46509 .51179 .45649 Mtetra
.51179 .45649 .51973 .46509 .53431 .46044 .52641 .4518 Mtetra
.52641 .4518 .53431 .46044 .54896 .45577 .54112 .44708 Mtetra
.54112 .44708 .54896 .45577 .56369 .45107 .5559 .44233 Mtetra
.5559 .44233 .56369 .45107 .57851 .44635 .57077 .43756 Mtetra
.57077 .43756 .57851 .44635 .5934 .4416 .58571 .43276 Mtetra
.58571 .43276 .5934 .4416 .60837 .43682 .60073 .42794 Mtetra
.60073 .42794 .60837 .43682 .62342 .43202 .61584 .42309 Mtetra
.61584 .42309 .62342 .43202 .63855 .4272 .63103 .41822 Mtetra
.63103 .41822 .63855 .4272 .65376 .42234 .6463 .41331 Mtetra
.6463 .41331 .65376 .42234 .66906 .41746 .66165 .40839 Mtetra
.66165 .40839 .66906 .41746 .68444 .41256 .67709 .40343 Mtetra
.67709 .40343 .68444 .41256 .6999 .40762 .69261 .39845 Mtetra
.69261 .39845 .6999 .40762 .71545 .40267 .70822 .39344 Mtetra
.70822 .39344 .71545 .40267 .73109 .39768 .72391 .3884 Mtetra
.72391 .3884 .73109 .39768 .74681 .39266 .73969 .38333 Mtetra
.73969 .38333 .74681 .39266 .76262 .38762 .75556 .37824 Mtetra
.75556 .37824 .76262 .38762 .77851 .38255 .77152 .37312 Mtetra
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Mtetra
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Mtetra
.34734 .49834 .35588 .50654 .36969 .5021 .36119 .49386 Mtetra
.36119 .49386 .36969 .5021 .38357 .49765 .37511 .48936 Mtetra
.37511 .48936 .38357 .49765 .39752 .49317 .38911 .48484 Mtetra
.38911 .48484 .39752 .49317 .41154 .48867 .40318 .4803 Mtetra
.40318 .4803 .41154 .48867 .42564 .48415 .41732 .47573 Mtetra
.41732 .47573 .42564 .48415 .43981 .4796 .43154 .47114 Mtetra
.43154 .47114 .43981 .4796 .45405 .47502 .44583 .46652 Mtetra
.44583 .46652 .45405 .47502 .46837 .47043 .4602 .46188 Mtetra
.4602 .46188 .46837 .47043 .48277 .46581 .47464 .45721 Mtetra
.47464 .45721 .48277 .46581 .49724 .46116 .48916 .45252 Mtetra
.48916 .45252 .49724 .46116 .51179 .45649 .50376 .4478 Mtetra
.50376 .4478 .51179 .45649 .52641 .4518 .51844 .44306 Mtetra
.51844 .44306 .52641 .4518 .54112 .44708 .5332 .43829 Mtetra
.5332 .43829 .54112 .44708 .5559 .44233 .54803 .4335 Mtetra
.54803 .4335 .5559 .44233 .57077 .43756 .56295 .42868 Mtetra
.56295 .42868 .57077 .43756 .58571 .43276 .57795 .42384 Mtetra
.57795 .42384 .58571 .43276 .60073 .42794 .59302 .41897 Mtetra
.59302 .41897 .60073 .42794 .61584 .42309 .60818 .41407 Mtetra
.60818 .41407 .61584 .42309 .63103 .41822 .62343 .40915 Mtetra
.62343 .40915 .63103 .41822 .6463 .41331 .63875 .40419 Mtetra
.63875 .40419 .6463 .41331 .66165 .40839 .65416 .39922 Mtetra
.65416 .39922 .66165 .40839 .67709 .40343 .66966 .39421 Mtetra
.66966 .39421 .67709 .40343 .69261 .39845 .68524 .38918 Mtetra
.68524 .38918 .69261 .39845 .70822 .39344 .70091 .38411 Mtetra
.70091 .38411 .70822 .39344 .72391 .3884 .71666 .37903 Mtetra
.71666 .37903 .72391 .3884 .73969 .38333 .7325 .37391 Mtetra
.7325 .37391 .73969 .38333 .75556 .37824 .74843 .36876 Mtetra
.74843 .36876 .75556 .37824 .77152 .37312 .76445 .36359 Mtetra
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Mtetra
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Mtetra
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Mtetra
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Mtetra
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Mtetra
.35261 .48554 .36119 .49386 .37511 .48936 .36658 .481 Mtetra
.36658 .481 .37511 .48936 .38911 .48484 .38062 .47643 Mtetra
.38062 .47643 .38911 .48484 .40318 .4803 .39473 .47184 Mtetra
.39473 .47184 .40318 .4803 .41732 .47573 .40892 .46723 Mtetra
.40892 .46723 .41732 .47573 .43154 .47114 .42319 .46259 Mtetra
.42319 .46259 .43154 .47114 .44583 .46652 .43753 .45793 Mtetra
.43753 .45793 .44583 .46652 .4602 .46188 .45194 .45324 Mtetra
.45194 .45324 .4602 .46188 .47464 .45721 .46644 .44853 Mtetra
.46644 .44853 .47464 .45721 .48916 .45252 .48101 .44379 Mtetra
.48101 .44379 .48916 .45252 .50376 .4478 .49566 .43903 Mtetra
.49566 .43903 .50376 .4478 .51844 .44306 .51039 .43424 Mtetra
.51039 .43424 .51844 .44306 .5332 .43829 .5252 .42943 Mtetra
.5252 .42943 .5332 .43829 .54803 .4335 .54008 .42459 Mtetra
.54008 .42459 .54803 .4335 .56295 .42868 .55505 .41972 Mtetra
.55505 .41972 .56295 .42868 .57795 .42384 .5701 .41482 Mtetra
.5701 .41482 .57795 .42384 .59302 .41897 .58524 .4099 Mtetra
.58524 .4099 .59302 .41897 .60818 .41407 .60045 .40496 Mtetra
.60045 .40496 .60818 .41407 .62343 .40915 .61575 .39998 Mtetra
.61575 .39998 .62343 .40915 .63875 .40419 .63113 .39498 Mtetra
.63113 .39498 .63875 .40419 .65416 .39922 .6466 .38995 Mtetra
.6466 .38995 .65416 .39922 .66966 .39421 .66216 .3849 Mtetra
.66216 .3849 .66966 .39421 .68524 .38918 .6778 .37981 Mtetra
.6778 .37981 .68524 .38918 .70091 .38411 .69352 .3747 Mtetra
.69352 .3747 .70091 .38411 .71666 .37903 .70934 .36955 Mtetra
.70934 .36955 .71666 .37903 .7325 .37391 .72524 .36438 Mtetra
.72524 .36438 .7325 .37391 .74843 .36876 .74123 .35918 Mtetra
.74123 .35918 .74843 .36876 .76445 .36359 .75732 .35396 Mtetra
.75732 .35396 .76445 .36359 .78056 .35838 .77349 .3487 Mtetra
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Mtetra
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Mtetra
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Mtetra
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Mtetra
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47255 Mtetra
.35796 .47255 .36658 .481 .38062 .47643 .37205 .46794 Mtetra
.37205 .46794 .38062 .47643 .39473 .47184 .38621 .46331 Mtetra
.38621 .46331 .39473 .47184 .40892 .46723 .40044 .45865 Mtetra
.40044 .45865 .40892 .46723 .42319 .46259 .41476 .45397 Mtetra
.41476 .45397 .42319 .46259 .43753 .45793 .42914 .44926 Mtetra
.42914 .44926 .43753 .45793 .45194 .45324 .44361 .44452 Mtetra
.44361 .44452 .45194 .45324 .46644 .44853 .45815 .43976 Mtetra
.45815 .43976 .46644 .44853 .48101 .44379 .47277 .43498 Mtetra
.47277 .43498 .48101 .44379 .49566 .43903 .48747 .43017 Mtetra
.48747 .43017 .49566 .43903 .51039 .43424 .50225 .42533 Mtetra
.50225 .42533 .51039 .43424 .5252 .42943 .51712 .42047 Mtetra
.51712 .42047 .5252 .42943 .54008 .42459 .53206 .41558 Mtetra
.53206 .41558 .54008 .42459 .55505 .41972 .54708 .41066 Mtetra
.54708 .41066 .55505 .41972 .5701 .41482 .56218 .40572 Mtetra
.56218 .40572 .5701 .41482 .58524 .4099 .57737 .40075 Mtetra
.57737 .40075 .58524 .4099 .60045 .40496 .59264 .39575 Mtetra
.59264 .39575 .60045 .40496 .61575 .39998 .608 .39073 Mtetra
.608 .39073 .61575 .39998 .63113 .39498 .62344 .38568 Mtetra
.62344 .38568 .63113 .39498 .6466 .38995 .63896 .38059 Mtetra
.63896 .38059 .6466 .38995 .66216 .3849 .65458 .37549 Mtetra
.65458 .37549 .66216 .3849 .6778 .37981 .67028 .37035 Mtetra
.67028 .37035 .6778 .37981 .69352 .3747 .68606 .36518 Mtetra
.68606 .36518 .69352 .3747 .70934 .36955 .70194 .35999 Mtetra
.70194 .35999 .70934 .36955 .72524 .36438 .7179 .35476 Mtetra
.7179 .35476 .72524 .36438 .74123 .35918 .73396 .34951 Mtetra
.73396 .34951 .74123 .35918 .75732 .35396 .75011 .34422 Mtetra
.75011 .34422 .75732 .35396 .77349 .3487 .76634 .33891 Mtetra
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Mtetra
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Mtetra
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Mtetra
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46865 Mtetra
.3352 .46865 .34395 .47714 .35796 .47255 .34926 .46402 Mtetra
.34926 .46402 .35796 .47255 .37205 .46794 .36339 .45937 Mtetra
.36339 .45937 .37205 .46794 .38621 .46331 .3776 .45469 Mtetra
.3776 .45469 .38621 .46331 .40044 .45865 .39188 .44998 Mtetra
.39188 .44998 .40044 .45865 .41476 .45397 .40624 .44525 Mtetra
.40624 .44525 .41476 .45397 .42914 .44926 .42068 .4405 Mtetra
.42068 .4405 .42914 .44926 .44361 .44452 .43519 .43572 Mtetra
.43519 .43572 .44361 .44452 .45815 .43976 .44978 .43091 Mtetra
.44978 .43091 .45815 .43976 .47277 .43498 .46446 .42608 Mtetra
.46446 .42608 .47277 .43498 .48747 .43017 .47921 .42122 Mtetra
.47921 .42122 .48747 .43017 .50225 .42533 .49404 .41633 Mtetra
.49404 .41633 .50225 .42533 .51712 .42047 .50895 .41142 Mtetra
.50895 .41142 .51712 .42047 .53206 .41558 .52395 .40648 Mtetra
.52395 .40648 .53206 .41558 .54708 .41066 .53902 .40152 Mtetra
.53902 .40152 .54708 .41066 .56218 .40572 .55418 .39652 Mtetra
.55418 .39652 .56218 .40572 .57737 .40075 .56943 .3915 Mtetra
.56943 .3915 .57737 .40075 .59264 .39575 .58475 .38645 Mtetra
.58475 .38645 .59264 .39575 .608 .39073 .60016 .38138 Mtetra
.60016 .38138 .608 .39073 .62344 .38568 .61566 .37627 Mtetra
.61566 .37627 .62344 .38568 .63896 .38059 .63125 .37114 Mtetra
.63125 .37114 .63896 .38059 .65458 .37549 .64692 .36598 Mtetra
.64692 .36598 .65458 .37549 .67028 .37035 .66268 .36079 Mtetra
.66268 .36079 .67028 .37035 .68606 .36518 .67853 .35557 Mtetra
.67853 .35557 .68606 .36518 .70194 .35999 .69446 .35032 Mtetra
.69446 .35032 .70194 .35999 .7179 .35476 .71049 .34504 Mtetra
.71049 .34504 .7179 .35476 .73396 .34951 .72661 .33973 Mtetra
.72661 .33973 .73396 .34951 .75011 .34422 .74282 .33439 Mtetra
.74282 .33439 .75011 .34422 .76634 .33891 .75912 .32902 Mtetra
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Mtetra
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46936 Mtetra
.29838 .46936 .3073 .47784 .32121 .47326 .31234 .46474 Mtetra
.31234 .46474 .32121 .47326 .3352 .46865 .32636 .46009 Mtetra
.32636 .46009 .3352 .46865 .34926 .46402 .34047 .45541 Mtetra
.34047 .45541 .34926 .46402 .36339 .45937 .35465 .45071 Mtetra
.35465 .45071 .36339 .45937 .3776 .45469 .3689 .44598 Mtetra
.3689 .44598 .3776 .45469 .39188 .44998 .38323 .44123 Mtetra
.38323 .44123 .39188 .44998 .40624 .44525 .39764 .43645 Mtetra
.39764 .43645 .40624 .44525 .42068 .4405 .41213 .43165 Mtetra
.41213 .43165 .42068 .4405 .43519 .43572 .42669 .42682 Mtetra
.42669 .42682 .43519 .43572 .44978 .43091 .44133 .42197 Mtetra
.44133 .42197 .44978 .43091 .46446 .42608 .45606 .41709 Mtetra
.45606 .41709 .46446 .42608 .47921 .42122 .47086 .41218 Mtetra
.47086 .41218 .47921 .42122 .49404 .41633 .48574 .40724 Mtetra
.48574 .40724 .49404 .41633 .50895 .41142 .50071 .40228 Mtetra
.50071 .40228 .50895 .41142 .52395 .40648 .51576 .39729 Mtetra
.51576 .39729 .52395 .40648 .53902 .40152 .53089 .39228 Mtetra
.53089 .39228 .53902 .40152 .55418 .39652 .5461 .38723 Mtetra
.5461 .38723 .55418 .39652 .56943 .3915 .5614 .38216 Mtetra
.5614 .38216 .56943 .3915 .58475 .38645 .57678 .37706 Mtetra
.57678 .37706 .58475 .38645 .60016 .38138 .59225 .37193 Mtetra
.59225 .37193 .60016 .38138 .61566 .37627 .60781 .36677 Mtetra
.60781 .36677 .61566 .37627 .63125 .37114 .62345 .36159 Mtetra
.62345 .36159 .63125 .37114 .64692 .36598 .63918 .35637 Mtetra
.63918 .35637 .64692 .36598 .66268 .36079 .655 .35113 Mtetra
.655 .35113 .66268 .36079 .67853 .35557 .67091 .34585 Mtetra
.67091 .34585 .67853 .35557 .69446 .35032 .68691 .34055 Mtetra
.68691 .34055 .69446 .35032 .71049 .34504 .703 .33521 Mtetra
.703 .33521 .71049 .34504 .72661 .33973 .71918 .32985 Mtetra
.71918 .32985 .72661 .33973 .74282 .33439 .73545 .32445 Mtetra
.73545 .32445 .74282 .33439 .75912 .32902 .75182 .31903 Mtetra
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.26159 .47008 .27069 .47854 .2845 .47397 .27545 .46545 Mtetra
.27545 .46545 .2845 .47397 .29838 .46936 .28937 .46081 Mtetra
.28937 .46081 .29838 .46936 .31234 .46474 .30337 .45613 Mtetra
.30337 .45613 .31234 .46474 .32636 .46009 .31744 .45144 Mtetra
.31744 .45144 .32636 .46009 .34047 .45541 .33159 .44671 Mtetra
.33159 .44671 .34047 .45541 .35465 .45071 .34582 .44196 Mtetra
.34582 .44196 .35465 .45071 .3689 .44598 .36012 .43719 Mtetra
.36012 .43719 .3689 .44598 .38323 .44123 .3745 .43239 Mtetra
.3745 .43239 .38323 .44123 .39764 .43645 .38896 .42757 Mtetra
.38896 .42757 .39764 .43645 .41213 .43165 .40349 .42272 Mtetra
.40349 .42272 .41213 .43165 .42669 .42682 .4181 .41784 Mtetra
.4181 .41784 .42669 .42682 .44133 .42197 .4328 .41294 Mtetra
.4328 .41294 .44133 .42197 .45606 .41709 .44757 .40801 Mtetra
.44757 .40801 .45606 .41709 .47086 .41218 .46242 .40305 Mtetra
.46242 .40305 .47086 .41218 .48574 .40724 .47736 .39806 Mtetra
.47736 .39806 .48574 .40724 .50071 .40228 .49238 .39305 Mtetra
.49238 .39305 .50071 .40228 .51576 .39729 .50748 .38801 Mtetra
.50748 .38801 .51576 .39729 .53089 .39228 .52267 .38294 Mtetra
.52267 .38294 .53089 .39228 .5461 .38723 .53793 .37785 Mtetra
.53793 .37785 .5461 .38723 .5614 .38216 .55329 .37272 Mtetra
.55329 .37272 .5614 .38216 .57678 .37706 .56873 .36757 Mtetra
.56873 .36757 .57678 .37706 .59225 .37193 .58426 .36239 Mtetra
.58426 .36239 .59225 .37193 .60781 .36677 .59987 .35718 Mtetra
.59987 .35718 .60781 .36677 .62345 .36159 .61557 .35194 Mtetra
.61557 .35194 .62345 .36159 .63918 .35637 .63136 .34667 Mtetra
.63136 .34667 .63918 .35637 .655 .35113 .64724 .34137 Mtetra
.64724 .34137 .655 .35113 .67091 .34585 .66321 .33604 Mtetra
.66321 .33604 .67091 .34585 .68691 .34055 .67927 .33068 Mtetra
.67927 .33068 .68691 .34055 .703 .33521 .69543 .32529 Mtetra
.69543 .32529 .703 .33521 .71918 .32985 .71167 .31986 Mtetra
.71167 .31986 .71918 .32985 .73545 .32445 .72801 .31441 Mtetra
.72801 .31441 .73545 .32445 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.663 .742 .908 r
.25241 .46154 .26159 .47008 .27545 .46545 .2663 .45687 Mtetra
.664 .742 .908 r
.2663 .45687 .27545 .46545 .28937 .46081 .28027 .45218 Mtetra
.28027 .45218 .28937 .46081 .30337 .45613 .29432 .44746 Mtetra
.29432 .44746 .30337 .45613 .31744 .45144 .30843 .44271 Mtetra
.30843 .44271 .31744 .45144 .33159 .44671 .32263 .43794 Mtetra
.32263 .43794 .33159 .44671 .34582 .44196 .3369 .43314 Mtetra
.664 .741 .908 r
.3369 .43314 .34582 .44196 .36012 .43719 .35125 .42832 Mtetra
.35125 .42832 .36012 .43719 .3745 .43239 .36568 .42347 Mtetra
.36568 .42347 .3745 .43239 .38896 .42757 .38018 .41859 Mtetra
.38018 .41859 .38896 .42757 .40349 .42272 .39477 .41369 Mtetra
.39477 .41369 .40349 .42272 .4181 .41784 .40943 .40877 Mtetra
.40943 .40877 .4181 .41784 .4328 .41294 .42417 .40381 Mtetra
.42417 .40381 .4328 .41294 .44757 .40801 .439 .39883 Mtetra
.439 .39883 .44757 .40801 .46242 .40305 .4539 .39382 Mtetra
.4539 .39382 .46242 .40305 .47736 .39806 .46889 .38879 Mtetra
.46889 .38879 .47736 .39806 .49238 .39305 .48397 .38372 Mtetra
.48397 .38372 .49238 .39305 .50748 .38801 .49912 .37863 Mtetra
.49912 .37863 .50748 .38801 .52267 .38294 .51436 .37351 Mtetra
.51436 .37351 .52267 .38294 .53793 .37785 .52969 .36836 Mtetra
.52969 .36836 .53793 .37785 .55329 .37272 .5451 .36319 Mtetra
.5451 .36319 .55329 .37272 .56873 .36757 .56059 .35798 Mtetra
.56059 .35798 .56873 .36757 .58426 .36239 .57618 .35274 Mtetra
.57618 .35274 .58426 .36239 .59987 .35718 .59185 .34748 Mtetra
.59185 .34748 .59987 .35718 .61557 .35194 .60761 .34218 Mtetra
.60761 .34218 .61557 .35194 .63136 .34667 .62346 .33686 Mtetra
.62346 .33686 .63136 .34667 .64724 .34137 .6394 .3315 Mtetra
.6394 .3315 .64724 .34137 .66321 .33604 .65543 .32612 Mtetra
.65543 .32612 .66321 .33604 .67927 .33068 .67156 .3207 Mtetra
.67156 .3207 .67927 .33068 .69543 .32529 .68777 .31525 Mtetra
.68777 .31525 .69543 .32529 .71167 .31986 .70408 .30977 Mtetra
.70408 .30977 .71167 .31986 .72801 .31441 .72049 .30426 Mtetra
.72049 .30426 .72801 .31441 .74444 .30893 .73699 .29872 Mtetra
.73699 .29872 .74444 .30893 .76097 .30341 .75358 .29314 Mtetra
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28753 Mtetra
.77027 .28753 .7776 .29786 .79432 .29228 .78706 .28189 Mtetra
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.663 .743 .909 r
.24312 .45296 .25241 .46154 .2663 .45687 .25706 .44826 Mtetra
.25706 .44826 .2663 .45687 .28027 .45218 .27108 .44352 Mtetra
.664 .743 .909 r
.27108 .44352 .28027 .45218 .29432 .44746 .28517 .43876 Mtetra
.28517 .43876 .29432 .44746 .30843 .44271 .29933 .43395 Mtetra
.29933 .43395 .30843 .44271 .32263 .43794 .31357 .42912 Mtetra
.31357 .42912 .32263 .43794 .3369 .43314 .32789 .42426 Mtetra
.664 .742 .908 r
.32789 .42426 .3369 .43314 .35125 .42832 .34229 .41937 Mtetra
.34229 .41937 .35125 .42832 .36568 .42347 .35677 .41446 Mtetra
.35677 .41446 .36568 .42347 .38018 .41859 .37132 .40953 Mtetra
.664 .741 .908 r
.37132 .40953 .38018 .41859 .39477 .41369 .38595 .40458 Mtetra
.38595 .40458 .39477 .41369 .40943 .40877 .40067 .3996 Mtetra
.40067 .3996 .40943 .40877 .42417 .40381 .41546 .3946 Mtetra
.41546 .3946 .42417 .40381 .439 .39883 .43034 .38956 Mtetra
.43034 .38956 .439 .39883 .4539 .39382 .4453 .38451 Mtetra
.4453 .38451 .4539 .39382 .46889 .38879 .46034 .37942 Mtetra
.46034 .37942 .46889 .38879 .48397 .38372 .47546 .3743 Mtetra
.47546 .3743 .48397 .38372 .49912 .37863 .49067 .36916 Mtetra
.49067 .36916 .49912 .37863 .51436 .37351 .50597 .36399 Mtetra
.50597 .36399 .51436 .37351 .52969 .36836 .52135 .35878 Mtetra
.52135 .35878 .52969 .36836 .5451 .36319 .53682 .35355 Mtetra
.53682 .35355 .5451 .36319 .56059 .35798 .55237 .34829 Mtetra
.55237 .34829 .56059 .35798 .57618 .35274 .56801 .343 Mtetra
.56801 .343 .57618 .35274 .59185 .34748 .58375 .33768 Mtetra
.58375 .33768 .59185 .34748 .60761 .34218 .59957 .33233 Mtetra
.59957 .33233 .60761 .34218 .62346 .33686 .61548 .32695 Mtetra
.61548 .32695 .62346 .33686 .6394 .3315 .63148 .32154 Mtetra
.63148 .32154 .6394 .3315 .65543 .32612 .64757 .31609 Mtetra
.64757 .31609 .65543 .32612 .67156 .3207 .66376 .31062 Mtetra
.66376 .31062 .67156 .3207 .68777 .31525 .68004 .30511 Mtetra
.68004 .30511 .68777 .31525 .70408 .30977 .69642 .29957 Mtetra
.69642 .29957 .70408 .30977 .72049 .30426 .71289 .294 Mtetra
.71289 .294 .72049 .30426 .73699 .29872 .72945 .2884 Mtetra
.72945 .2884 .73699 .29872 .75358 .29314 .74611 .28276 Mtetra
.74611 .28276 .75358 .29314 .77027 .28753 .76287 .2771 Mtetra
.76287 .2771 .77027 .28753 .78706 .28189 .77973 .27139 Mtetra
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.662 .745 .912 r
.23374 .44441 .24312 .45296 .25706 .44826 .24772 .43972 Mtetra
.662 .746 .913 r
.24772 .43972 .25706 .44826 .27108 .44352 .26177 .43499 Mtetra
.663 .748 .913 r
.26177 .43499 .27108 .44352 .28517 .43876 .27591 .4302 Mtetra
.664 .749 .913 r
.27591 .4302 .28517 .43876 .29933 .43395 .29012 .42533 Mtetra
.665 .749 .912 r
.29012 .42533 .29933 .43395 .31357 .42912 .30441 .42041 Mtetra
.666 .748 .911 r
.30441 .42041 .31357 .42912 .32789 .42426 .31879 .41544 Mtetra
.666 .746 .91 r
.31879 .41544 .32789 .42426 .34229 .41937 .33324 .41045 Mtetra
.665 .745 .91 r
.33324 .41045 .34229 .41937 .35677 .41446 .34776 .40544 Mtetra
.665 .744 .909 r
.34776 .40544 .35677 .41446 .37132 .40953 .36237 .40042 Mtetra
.664 .743 .908 r
.36237 .40042 .37132 .40953 .38595 .40458 .37705 .39539 Mtetra
.664 .742 .908 r
.37705 .39539 .38595 .40458 .40067 .3996 .39182 .39035 Mtetra
.39182 .39035 .40067 .3996 .41546 .3946 .40666 .38529 Mtetra
.664 .741 .908 r
.40666 .38529 .41546 .3946 .43034 .38956 .42159 .3802 Mtetra
.42159 .3802 .43034 .38956 .4453 .38451 .4366 .37509 Mtetra
.4366 .37509 .4453 .38451 .46034 .37942 .4517 .36995 Mtetra
.4517 .36995 .46034 .37942 .47546 .3743 .46688 .36478 Mtetra
.46688 .36478 .47546 .3743 .49067 .36916 .48214 .35959 Mtetra
.48214 .35959 .49067 .36916 .50597 .36399 .49749 .35436 Mtetra
.49749 .35436 .50597 .36399 .52135 .35878 .51293 .3491 Mtetra
.51293 .3491 .52135 .35878 .53682 .35355 .52845 .34382 Mtetra
.52845 .34382 .53682 .35355 .55237 .34829 .54406 .3385 Mtetra
.54406 .3385 .55237 .34829 .56801 .343 .55977 .33315 Mtetra
.55977 .33315 .56801 .343 .58375 .33768 .57556 .32778 Mtetra
.57556 .32778 .58375 .33768 .59957 .33233 .59144 .32237 Mtetra
.59144 .32237 .59957 .33233 .61548 .32695 .60741 .31693 Mtetra
.60741 .31693 .61548 .32695 .63148 .32154 .62347 .31146 Mtetra
.62347 .31146 .63148 .32154 .64757 .31609 .63963 .30596 Mtetra
.63963 .30596 .64757 .31609 .66376 .31062 .65588 .30043 Mtetra
.65588 .30043 .66376 .31062 .68004 .30511 .67223 .29486 Mtetra
.67223 .29486 .68004 .30511 .69642 .29957 .68867 .28926 Mtetra
.68867 .28926 .69642 .29957 .71289 .294 .7052 .28363 Mtetra
.7052 .28363 .71289 .294 .72945 .2884 .72183 .27797 Mtetra
.72183 .27797 .72945 .2884 .74611 .28276 .73856 .27227 Mtetra
.73856 .27227 .74611 .28276 .76287 .2771 .75539 .26654 Mtetra
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.656 .749 .919 r
.22424 .43603 .23374 .44441 .24772 .43972 .23824 .4315 Mtetra
.656 .754 .922 r
.23824 .4315 .24772 .43972 .26177 .43499 .25233 .42693 Mtetra
.659 .76 .925 r
.25233 .42693 .26177 .43499 .27591 .4302 .2665 .42223 Mtetra
.663 .765 .926 r
.2665 .42223 .27591 .4302 .29012 .42533 .28076 .41738 Mtetra
.667 .767 .925 r
.28076 .41738 .29012 .42533 .30441 .42041 .29511 .41234 Mtetra
.67 .766 .922 r
.29511 .41234 .30441 .42041 .31879 .41544 .30954 .40717 Mtetra
.671 .763 .919 r
.30954 .40717 .31879 .41544 .33324 .41045 .32406 .40192 Mtetra
.671 .758 .916 r
.32406 .40192 .33324 .41045 .34776 .40544 .33865 .39666 Mtetra
.669 .752 .913 r
.33865 .39666 .34776 .40544 .36237 .40042 .35331 .39142 Mtetra
.667 .748 .911 r
.35331 .39142 .36237 .40042 .37705 .39539 .36805 .38623 Mtetra
.666 .745 .909 r
.36805 .38623 .37705 .39539 .39182 .39035 .38287 .38106 Mtetra
.665 .743 .909 r
.38287 .38106 .39182 .39035 .40666 .38529 .39777 .37591 Mtetra
.664 .742 .908 r
.39777 .37591 .40666 .38529 .42159 .3802 .41275 .37076 Mtetra
.41275 .37076 .42159 .3802 .4366 .37509 .42782 .36558 Mtetra
.664 .741 .908 r
.42782 .36558 .4366 .37509 .4517 .36995 .44297 .36039 Mtetra
.44297 .36039 .4517 .36995 .46688 .36478 .4582 .35516 Mtetra
.4582 .35516 .46688 .36478 .48214 .35959 .47352 .34991 Mtetra
.47352 .34991 .48214 .35959 .49749 .35436 .48892 .34463 Mtetra
.48892 .34463 .49749 .35436 .51293 .3491 .50442 .33932 Mtetra
.50442 .33932 .51293 .3491 .52845 .34382 .52 .33398 Mtetra
.52 .33398 .52845 .34382 .54406 .3385 .53567 .32861 Mtetra
.53567 .32861 .54406 .3385 .55977 .33315 .55143 .3232 Mtetra
.55143 .3232 .55977 .33315 .57556 .32778 .56728 .31777 Mtetra
.56728 .31777 .57556 .32778 .59144 .32237 .58322 .3123 Mtetra
.58322 .3123 .59144 .32237 .60741 .31693 .59926 .30681 Mtetra
.59926 .30681 .60741 .31693 .62347 .31146 .61538 .30128 Mtetra
.61538 .30128 .62347 .31146 .63963 .30596 .6316 .29572 Mtetra
.6316 .29572 .63963 .30596 .65588 .30043 .64792 .29013 Mtetra
.64792 .29013 .65588 .30043 .67223 .29486 .66433 .2845 Mtetra
.66433 .2845 .67223 .29486 .68867 .28926 .68083 .27884 Mtetra
.68083 .27884 .68867 .28926 .7052 .28363 .69743 .27315 Mtetra
.69743 .27315 .7052 .28363 .72183 .27797 .71413 .26743 Mtetra
.71413 .26743 .72183 .27797 .73856 .27227 .73093 .26167 Mtetra
.73093 .26167 .73856 .27227 .75539 .26654 .74783 .25587 Mtetra
.74783 .25587 .75539 .26654 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24418 Mtetra
.78193 .24418 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.639 .755 .932 r
.2146 .42796 .22424 .43603 .23824 .4315 .2286 .42391 Mtetra
.635 .767 .943 r
.2286 .42391 .23824 .4315 .25233 .42693 .24269 .4199 Mtetra
.637 .783 .952 r
.24269 .4199 .25233 .42693 .2665 .42223 .25686 .41574 Mtetra
.645 .801 .958 r
.25686 .41574 .2665 .42223 .28076 .41738 .27115 .41123 Mtetra
.658 .814 .958 r
.27115 .41123 .28076 .41738 .29511 .41234 .28555 .40624 Mtetra
.673 .819 .954 r
.28555 .40624 .29511 .41234 .30954 .40717 .30006 .40078 Mtetra
.683 .815 .946 r
.30006 .40078 .30954 .40717 .32406 .40192 .31467 .39498 Mtetra
.687 .803 .937 r
.31467 .39498 .32406 .40192 .33865 .39666 .32936 .38906 Mtetra
.685 .787 .928 r
.32936 .38906 .33865 .39666 .35331 .39142 .34411 .38319 Mtetra
.68 .771 .92 r
.34411 .38319 .35331 .39142 .36805 .38623 .35894 .37749 Mtetra
.674 .759 .915 r
.35894 .37749 .36805 .38623 .38287 .38106 .37382 .37196 Mtetra
.67 .751 .911 r
.37382 .37196 .38287 .38106 .39777 .37591 .38878 .36657 Mtetra
.667 .746 .909 r
.38878 .36657 .39777 .37591 .41275 .37076 .40382 .36127 Mtetra
.665 .743 .909 r
.40382 .36127 .41275 .37076 .42782 .36558 .41894 .356 Mtetra
.664 .742 .908 r
.41894 .356 .42782 .36558 .44297 .36039 .43414 .35073 Mtetra
.43414 .35073 .44297 .36039 .4582 .35516 .44943 .34545 Mtetra
.664 .741 .908 r
.44943 .34545 .4582 .35516 .47352 .34991 .46481 .34014 Mtetra
.46481 .34014 .47352 .34991 .48892 .34463 .48027 .3348 Mtetra
.48027 .3348 .48892 .34463 .50442 .33932 .49582 .32943 Mtetra
.49582 .32943 .50442 .33932 .52 .33398 .51146 .32404 Mtetra
.51146 .32404 .52 .33398 .53567 .32861 .52719 .31861 Mtetra
.52719 .31861 .53567 .32861 .55143 .3232 .54301 .31315 Mtetra
.54301 .31315 .55143 .3232 .56728 .31777 .55892 .30766 Mtetra
.55892 .30766 .56728 .31777 .58322 .3123 .57492 .30213 Mtetra
.57492 .30213 .58322 .3123 .59926 .30681 .59101 .29658 Mtetra
.59101 .29658 .59926 .30681 .61538 .30128 .6072 .29099 Mtetra
.6072 .29099 .61538 .30128 .6316 .29572 .62349 .28537 Mtetra
.62349 .28537 .6316 .29572 .64792 .29013 .63987 .27972 Mtetra
.63987 .27972 .64792 .29013 .66433 .2845 .65634 .27403 Mtetra
.65634 .27403 .66433 .2845 .68083 .27884 .67291 .26831 Mtetra
.67291 .26831 .68083 .27884 .69743 .27315 .68958 .26256 Mtetra
.68958 .26256 .69743 .27315 .71413 .26743 .70635 .25677 Mtetra
.70635 .25677 .71413 .26743 .73093 .26167 .72322 .25095 Mtetra
.72322 .25095 .73093 .26167 .74783 .25587 .74019 .24509 Mtetra
.74019 .24509 .74783 .25587 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24418 .77443 .23327 Mtetra
.77443 .23327 .78193 .24418 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.602 .754 .951 r
.20482 .42018 .2146 .42796 .2286 .42391 .21878 .41709 Mtetra
.574 .773 .973 r
.21878 .41709 .2286 .42391 .24269 .4199 .23279 .41441 Mtetra
.548 .802 .992 r
.23279 .41441 .24269 .4199 .25686 .41574 .24689 .41177 Mtetra
.536 .84 .999 r
.24689 .41177 .25686 .41574 .27115 .41123 .26113 .40863 Mtetra
.551 .879 .991 r
.26113 .40863 .27115 .41123 .28555 .40624 .27554 .40448 Mtetra
.597 .911 .979 r
.27554 .40448 .28555 .40624 .30006 .40078 .29012 .39905 Mtetra
.655 .928 .973 r
.29012 .39905 .30006 .40078 .31467 .39498 .30487 .39246 Mtetra
.699 .92 .968 r
.30487 .39246 .31467 .39498 .32936 .38906 .31972 .38515 Mtetra
.718 .89 .959 r
.31972 .38515 .32936 .38906 .34411 .38319 .33465 .37769 Mtetra
.715 .849 .946 r
.33465 .37769 .34411 .38319 .35894 .37749 .34962 .37052 Mtetra
.702 .811 .932 r
.34962 .37052 .35894 .37749 .37382 .37196 .36462 .36387 Mtetra
.688 .782 .922 r
.36462 .36387 .37382 .37196 .38878 .36657 .37967 .35772 Mtetra
.677 .762 .915 r
.37967 .35772 .38878 .36657 .40382 .36127 .39478 .35196 Mtetra
.67 .751 .911 r
.39478 .35196 .40382 .36127 .41894 .356 .40997 .34643 Mtetra
.666 .745 .909 r
.40997 .34643 .41894 .356 .43414 .35073 .42523 .34102 Mtetra
.665 .743 .908 r
.42523 .34102 .43414 .35073 .44943 .34545 .44057 .33565 Mtetra
.664 .742 .908 r
.44057 .33565 .44943 .34545 .46481 .34014 .456 .33027 Mtetra
.664 .741 .908 r
.456 .33027 .46481 .34014 .48027 .3348 .47152 .32487 Mtetra
.47152 .32487 .48027 .3348 .49582 .32943 .48713 .31945 Mtetra
.48713 .31945 .49582 .32943 .51146 .32404 .50282 .31399 Mtetra
.50282 .31399 .51146 .32404 .52719 .31861 .51861 .3085 Mtetra
.51861 .3085 .52719 .31861 .54301 .31315 .53449 .30298 Mtetra
.53449 .30298 .54301 .31315 .55892 .30766 .55046 .29743 Mtetra
.55046 .29743 .55892 .30766 .57492 .30213 .56653 .29185 Mtetra
.56653 .29185 .57492 .30213 .59101 .29658 .58268 .28624 Mtetra
.58268 .28624 .59101 .29658 .6072 .29099 .59894 .28059 Mtetra
.59894 .28059 .6072 .29099 .62349 .28537 .61528 .27491 Mtetra
.61528 .27491 .62349 .28537 .63987 .27972 .63173 .26919 Mtetra
.63173 .26919 .63987 .27972 .65634 .27403 .64827 .26344 Mtetra
.64827 .26344 .65634 .27403 .67291 .26831 .66491 .25766 Mtetra
.66491 .25766 .67291 .26831 .68958 .26256 .68164 .25184 Mtetra
.68164 .25184 .68958 .26256 .70635 .25677 .69848 .24599 Mtetra
.69848 .24599 .70635 .25677 .72322 .25095 .71542 .24011 Mtetra
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23418 Mtetra
.73246 .23418 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Mtetra
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .2162 Mtetra
.78419 .2162 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.54 .736 .966 r
.19493 .41238 .20482 .42018 .21878 .41709 .2088 .41067 Mtetra
.436 .734 .99 r
.2088 .41067 .21878 .41709 .23279 .41441 .22264 .41021 Mtetra
.266 .709 .961 r
.22264 .41021 .23279 .41441 .24689 .41177 .23653 .41058 Mtetra
.067 .626 .798 r
.23653 .41058 .24689 .41177 .26113 .40863 .25055 .4108 Mtetra
.031 0 0 r
.25055 .4108 .26113 .40863 .27554 .40448 .26482 .40958 Mtetra
0 0 0 r
.26482 .40958 .27554 .40448 .29012 .39905 .27939 .40579 Mtetra
.27939 .40579 .29012 .39905 .30487 .39246 .29427 .39902 Mtetra
.29427 .39902 .30487 .39246 .31972 .38515 .30938 .3898 Mtetra
.578 .931 .762 r
.30938 .3898 .31972 .38515 .33465 .37769 .32461 .37928 Mtetra
.719 .985 .891 r
.32461 .37928 .33465 .37769 .34962 .37052 .33988 .36875 Mtetra
.758 .946 .941 r
.33988 .36875 .34962 .37052 .36462 .36387 .35513 .35913 Mtetra
.741 .877 .943 r
.35513 .35913 .36462 .36387 .37967 .35772 .37037 .35077 Mtetra
.713 .818 .931 r
.37037 .35077 .37967 .35772 .39478 .35196 .38561 .34358 Mtetra
.69 .78 .92 r
.38561 .34358 .39478 .35196 .40997 .34643 .40088 .33724 Mtetra
.676 .759 .913 r
.40088 .33724 .40997 .34643 .42523 .34102 .41621 .3314 Mtetra
.669 .748 .91 r
.41621 .3314 .42523 .34102 .44057 .33565 .43161 .32581 Mtetra
.665 .744 .909 r
.43161 .32581 .44057 .33565 .456 .33027 .4471 .32032 Mtetra
.664 .742 .908 r
.4471 .32032 .456 .33027 .47152 .32487 .46268 .31484 Mtetra
.46268 .31484 .47152 .32487 .48713 .31945 .47834 .30935 Mtetra
.664 .741 .908 r
.47834 .30935 .48713 .31945 .50282 .31399 .4941 .30384 Mtetra
.4941 .30384 .50282 .31399 .51861 .3085 .50995 .29829 Mtetra
.50995 .29829 .51861 .3085 .53449 .30298 .52589 .29271 Mtetra
.52589 .29271 .53449 .30298 .55046 .29743 .54192 .2871 Mtetra
.54192 .2871 .55046 .29743 .56653 .29185 .55804 .28146 Mtetra
.55804 .28146 .56653 .29185 .58268 .28624 .57426 .27578 Mtetra
.57426 .27578 .58268 .28624 .59894 .28059 .59058 .27007 Mtetra
.59058 .27007 .59894 .28059 .61528 .27491 .60699 .26433 Mtetra
.60699 .26433 .61528 .27491 .63173 .26919 .6235 .25855 Mtetra
.6235 .25855 .63173 .26919 .64827 .26344 .64011 .25274 Mtetra
.64011 .25274 .64827 .26344 .66491 .25766 .65681 .24689 Mtetra
.65681 .24689 .66491 .25766 .68164 .25184 .67362 .24101 Mtetra
.67362 .24101 .68164 .25184 .69848 .24599 .69052 .2351 Mtetra
.69052 .2351 .69848 .24599 .71542 .24011 .70753 .22915 Mtetra
.70753 .22915 .71542 .24011 .73246 .23418 .72464 .22316 Mtetra
.72464 .22316 .73246 .23418 .7496 .22823 .74185 .21713 Mtetra
.74185 .21713 .7496 .22823 .76684 .22223 .75917 .21107 Mtetra
.75917 .21107 .76684 .22223 .78419 .2162 .77659 .20498 Mtetra
.77659 .20498 .78419 .2162 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.478 .699 .966 r
.18499 .404 .19493 .41238 .2088 .41067 .19875 .40361 Mtetra
.253 .628 .96 r
.19875 .40361 .2088 .41067 .22264 .41021 .21238 .40576 Mtetra
0 .402 .74 r
.21238 .40576 .22264 .41021 .23653 .41058 .22592 .41038 Mtetra
.484 0 0 r
.22592 .41038 .23653 .41058 .25055 .4108 .2395 .41634 Mtetra
.533 .021 0 r
.2395 .41634 .25055 .4108 .26482 .40958 .25333 .42144 Mtetra
.464 .015 .098 r
.25333 .42144 .26482 .40958 .27939 .40579 .26762 .42299 Mtetra
.342 0 .116 r
.26762 .42299 .27939 .40579 .29427 .39902 .28246 .41897 Mtetra
.184 0 .067 r
.28246 .41897 .29427 .39902 .30938 .3898 .29781 .40902 Mtetra
0 0 0 r
.29781 .40902 .30938 .3898 .32461 .37928 .3135 .39461 Mtetra
.3135 .39461 .32461 .37928 .33988 .36875 .3293 .37831 Mtetra
.563 .866 .563 r
.3293 .37831 .33988 .36875 .35513 .35913 .34505 .36261 Mtetra
.759 .995 .825 r
.34505 .36261 .35513 .35913 .37037 .35077 .36067 .34909 Mtetra
.787 .951 .926 r
.36067 .34909 .37037 .35077 .38561 .34358 .37618 .33818 Mtetra
.747 .865 .935 r
.37618 .33818 .38561 .34358 .40088 .33724 .39162 .32951 Mtetra
.708 .803 .924 r
.39162 .32951 .40088 .33724 .41621 .3314 .40707 .32239 Mtetra
.684 .769 .916 r
.40707 .32239 .41621 .3314 .43161 .32581 .42255 .31616 Mtetra
.672 .752 .911 r
.42255 .31616 .43161 .32581 .4471 .32032 .43811 .31036 Mtetra
.667 .745 .909 r
.43811 .31036 .4471 .32032 .46268 .31484 .45374 .30474 Mtetra
.664 .743 .908 r
.45374 .30474 .46268 .31484 .47834 .30935 .46947 .29916 Mtetra
.664 .742 .908 r
.46947 .29916 .47834 .30935 .4941 .30384 .48528 .29358 Mtetra
.664 .741 .908 r
.48528 .29358 .4941 .30384 .50995 .29829 .50119 .28797 Mtetra
.50119 .28797 .50995 .29829 .52589 .29271 .51719 .28233 Mtetra
.51719 .28233 .52589 .29271 .54192 .2871 .53328 .27666 Mtetra
.53328 .27666 .54192 .2871 .55804 .28146 .54947 .27095 Mtetra
.54947 .27095 .55804 .28146 .57426 .27578 .56575 .26522 Mtetra
.56575 .26522 .57426 .27578 .59058 .27007 .58213 .25944 Mtetra
.58213 .25944 .59058 .27007 .60699 .26433 .59861 .25364 Mtetra
.59861 .25364 .60699 .26433 .6235 .25855 .61518 .2478 Mtetra
.61518 .2478 .6235 .25855 .64011 .25274 .63185 .24192 Mtetra
.63185 .24192 .64011 .25274 .65681 .24689 .64863 .23601 Mtetra
.64863 .23601 .65681 .24689 .67362 .24101 .6655 .23006 Mtetra
.6655 .23006 .67362 .24101 .69052 .2351 .68248 .22408 Mtetra
.68248 .22408 .69052 .2351 .70753 .22915 .69955 .21806 Mtetra
.69955 .21806 .70753 .22915 .72464 .22316 .71674 .21201 Mtetra
.71674 .21201 .72464 .22316 .74185 .21713 .73402 .20592 Mtetra
.73402 .20592 .74185 .21713 .75917 .21107 .75141 .19979 Mtetra
.75141 .19979 .75917 .21107 .77659 .20498 .76891 .19362 Mtetra
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.46 .668 .953 r
.17504 .39461 .18499 .404 .19875 .40361 .18876 .39482 Mtetra
.172 .535 .924 r
.18876 .39482 .19875 .40361 .21238 .40576 .20222 .39883 Mtetra
0 .179 .611 r
.20222 .39883 .21238 .40576 .22592 .41038 .2154 .40743 Mtetra
.704 .166 0 r
.2154 .40743 .22592 .41038 .2395 .41634 .2284 .42012 Mtetra
.734 .272 .152 r
.2284 .42012 .2395 .41634 .25333 .42144 .2415 .43447 Mtetra
.662 .254 .262 r
.2415 .43447 .25333 .42144 .26762 .42299 .25506 .44623 Mtetra
.546 .179 .295 r
.25506 .44623 .26762 .42299 .28246 .41897 .26943 .45068 Mtetra
.403 .069 .281 r
.26943 .45068 .28246 .41897 .29781 .40902 .28474 .44478 Mtetra
.239 0 .228 r
.28474 .44478 .29781 .40902 .3135 .39461 .30082 .42873 Mtetra
.056 0 .134 r
.30082 .42873 .3135 .39461 .3293 .37831 .31733 .40589 Mtetra
0 0 0 r
.31733 .40589 .3293 .37831 .34505 .36261 .33388 .38102 Mtetra
.33388 .38102 .34505 .36261 .36067 .34909 .35022 .35821 Mtetra
.701 .934 .622 r
.35022 .35821 .36067 .34909 .37618 .33818 .36628 .33965 Mtetra
.817 .993 .865 r
.36628 .33965 .37618 .33818 .39162 .32951 .38208 .32563 Mtetra
.781 .907 .928 r
.38208 .32563 .39162 .32951 .40707 .32239 .39774 .31526 Mtetra
.726 .825 .926 r
.39774 .31526 .40707 .32239 .42255 .31616 .41336 .30729 Mtetra
.692 .778 .917 r
.41336 .30729 .42255 .31616 .43811 .31036 .429 .30065 Mtetra
.675 .755 .912 r
.429 .30065 .43811 .31036 .45374 .30474 .44471 .29465 Mtetra
.667 .746 .909 r
.44471 .29465 .45374 .30474 .46947 .29916 .46049 .2889 Mtetra
.665 .743 .908 r
.46049 .2889 .46947 .29916 .48528 .29358 .47637 .28322 Mtetra
.664 .742 .908 r
.47637 .28322 .48528 .29358 .50119 .28797 .49233 .27754 Mtetra
.664 .741 .908 r
.49233 .27754 .50119 .28797 .51719 .28233 .50839 .27183 Mtetra
.50839 .27183 .51719 .28233 .53328 .27666 .52455 .2661 Mtetra
.52455 .2661 .53328 .27666 .54947 .27095 .5408 .26033 Mtetra
.5408 .26033 .54947 .27095 .56575 .26522 .55715 .25453 Mtetra
.55715 .25453 .56575 .26522 .58213 .25944 .57359 .2487 Mtetra
.57359 .2487 .58213 .25944 .59861 .25364 .59013 .24283 Mtetra
.59013 .24283 .59861 .25364 .61518 .2478 .60677 .23692 Mtetra
.60677 .23692 .61518 .2478 .63185 .24192 .62351 .23098 Mtetra
.62351 .23098 .63185 .24192 .64863 .23601 .64035 .225 Mtetra
.64035 .225 .64863 .23601 .6655 .23006 .6573 .21899 Mtetra
.6573 .21899 .6655 .23006 .68248 .22408 .67434 .21294 Mtetra
.67434 .21294 .68248 .22408 .69955 .21806 .69149 .20686 Mtetra
.69149 .20686 .69955 .21806 .71674 .21201 .70874 .20073 Mtetra
.70874 .20073 .71674 .21201 .73402 .20592 .7261 .19457 Mtetra
.7261 .19457 .73402 .20592 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Mtetra
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.495 .662 .936 r
.16508 .38428 .17504 .39461 .18876 .39482 .17887 .38402 Mtetra
.249 .529 .917 r
.17887 .38402 .18876 .39482 .20222 .39883 .19233 .38809 Mtetra
0 .184 .693 r
.19233 .38809 .20222 .39883 .2154 .40743 .20533 .39832 Mtetra
.728 .227 0 r
.20533 .39832 .2154 .40743 .2284 .42012 .21788 .41562 Mtetra
.849 .395 .113 r
.21788 .41562 .2284 .42012 .2415 .43447 .2302 .43866 Mtetra
.815 .404 .267 r
.2302 .43866 .2415 .43447 .25506 .44623 .24273 .463 Mtetra
.711 .334 .333 r
.24273 .463 .25506 .44623 .26943 .45068 .25608 .48167 Mtetra
.559 .216 .344 r
.25608 .48167 .26943 .45068 .28474 .44478 .27071 .4876 Mtetra
.376 .071 .314 r
.27071 .4876 .28474 .44478 .30082 .42873 .28672 .47709 Mtetra
.184 0 .251 r
.28672 .47709 .30082 .42873 .31733 .40589 .30377 .45188 Mtetra
0 0 .158 r
.30377 .45188 .31733 .40589 .33388 .38102 .32126 .41811 Mtetra
0 0 .022 r
.32126 .41811 .33388 .38102 .35022 .35821 .33863 .3832 Mtetra
0 0 0 r
.33863 .3832 .35022 .35821 .36628 .33965 .35558 .35273 Mtetra
.692 .886 .508 r
.35558 .35273 .36628 .33965 .38208 .32563 .37204 .32915 Mtetra
.837 .999 .805 r
.37204 .32915 .38208 .32563 .39774 .31526 .38812 .31226 Mtetra
.807 .929 .914 r
.38812 .31226 .39774 .31526 .41336 .30729 .40398 .30042 Mtetra
.74 .837 .924 r
.40398 .30042 .41336 .30729 .429 .30065 .41977 .29177 Mtetra
.697 .782 .917 r
.41977 .29177 .429 .30065 .44471 .29465 .43556 .28482 Mtetra
.676 .757 .912 r
.43556 .28482 .44471 .29465 .46049 .2889 .45142 .27865 Mtetra
.668 .747 .909 r
.45142 .27865 .46049 .2889 .47637 .28322 .46736 .27278 Mtetra
.665 .743 .908 r
.46736 .27278 .47637 .28322 .49233 .27754 .48338 .267 Mtetra
.664 .742 .908 r
.48338 .267 .49233 .27754 .50839 .27183 .49951 .26123 Mtetra
.664 .741 .908 r
.49951 .26123 .50839 .27183 .52455 .2661 .51572 .25543 Mtetra
.51572 .25543 .52455 .2661 .5408 .26033 .53204 .2496 Mtetra
.53204 .2496 .5408 .26033 .55715 .25453 .54845 .24373 Mtetra
.54845 .24373 .55715 .25453 .57359 .2487 .56495 .23783 Mtetra
.56495 .23783 .57359 .2487 .59013 .24283 .58156 .2319 Mtetra
.58156 .2319 .59013 .24283 .60677 .23692 .59827 .22593 Mtetra
.59827 .22593 .60677 .23692 .62351 .23098 .61508 .21992 Mtetra
.61508 .21992 .62351 .23098 .64035 .225 .63199 .21388 Mtetra
.63199 .21388 .64035 .225 .6573 .21899 .649 .2078 Mtetra
.649 .2078 .6573 .21899 .67434 .21294 .66611 .20168 Mtetra
.66611 .20168 .67434 .21294 .69149 .20686 .68334 .19552 Mtetra
.68334 .19552 .69149 .20686 .70874 .20073 .70066 .18933 Mtetra
.70066 .18933 .70874 .20073 .7261 .19457 .71809 .1831 Mtetra
.71809 .1831 .7261 .19457 .74357 .18838 .73563 .17683 Mtetra
.73563 .17683 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.552 .677 .921 r
.15507 .37352 .16508 .38428 .17887 .38402 .16902 .37194 Mtetra
.39 .577 .914 r
.16902 .37194 .17887 .38402 .19233 .38809 .18266 .37424 Mtetra
.038 .332 .814 r
.18266 .37424 .19233 .38809 .20533 .39832 .19581 .38282 Mtetra
0 0 .501 r
.19581 .38282 .20533 .39832 .21788 .41562 .20831 .39996 Mtetra
.787 .371 0 r
.20831 .39996 .21788 .41562 .2302 .43866 .22023 .42636 Mtetra
.898 .487 .096 r
.22023 .42636 .2302 .43866 .24273 .463 .23192 .45944 Mtetra
.887 .479 .233 r
.23192 .45944 .24273 .463 .25608 .48167 .24406 .49238 Mtetra
.767 .371 .304 r
.24406 .49238 .25608 .48167 .27071 .4876 .25742 .51543 Mtetra
.537 .179 .308 r
.25742 .51543 .27071 .4876 .28672 .47709 .27256 .51976 Mtetra
.258 0 .255 r
.27256 .51976 .28672 .47709 .30377 .45188 .28943 .50203 Mtetra
.006 0 .171 r
.28943 .50203 .30377 .45188 .32126 .41811 .30747 .46642 Mtetra
0 0 .07 r
.30747 .46642 .32126 .41811 .33863 .3832 .32585 .42213 Mtetra
0 0 0 r
.32585 .42213 .33863 .3832 .35558 .35273 .34389 .37874 Mtetra
.34389 .37874 .35558 .35273 .37204 .32915 .36129 .34256 Mtetra
.768 .912 .528 r
.36129 .34256 .37204 .32915 .38812 .31226 .37804 .31571 Mtetra
.866 .996 .794 r
.37804 .31571 .38812 .31226 .40398 .30042 .39433 .29719 Mtetra
.818 .926 .906 r
.39433 .29719 .40398 .30042 .41977 .29177 .41036 .28464 Mtetra
.744 .835 .921 r
.41036 .28464 .41977 .29177 .43556 .28482 .42629 .2757 Mtetra
.698 .781 .915 r
.42629 .2757 .43556 .28482 .45142 .27865 .44224 .26861 Mtetra
.676 .756 .911 r
.44224 .26861 .45142 .27865 .46736 .27278 .45824 .26235 Mtetra
.668 .746 .909 r
.45824 .26235 .46736 .27278 .48338 .267 .47434 .25639 Mtetra
.665 .743 .908 r
.47434 .25639 .48338 .267 .49951 .26123 .49052 .25051 Mtetra
.664 .742 .908 r
.49052 .25051 .49951 .26123 .51572 .25543 .5068 .24464 Mtetra
.664 .741 .908 r
.5068 .24464 .51572 .25543 .53204 .2496 .52318 .23874 Mtetra
.52318 .23874 .53204 .2496 .54845 .24373 .53965 .23281 Mtetra
.53965 .23281 .54845 .24373 .56495 .23783 .55622 .22685 Mtetra
.55622 .22685 .56495 .23783 .58156 .2319 .5729 .22085 Mtetra
.5729 .22085 .58156 .2319 .59827 .22593 .58967 .21481 Mtetra
.58967 .21481 .59827 .22593 .61508 .21992 .60655 .20873 Mtetra
.60655 .20873 .61508 .21992 .63199 .21388 .62353 .20262 Mtetra
.62353 .20262 .63199 .21388 .649 .2078 .64061 .19647 Mtetra
.64061 .19647 .649 .2078 .66611 .20168 .6578 .19029 Mtetra
.6578 .19029 .66611 .20168 .68334 .19552 .67509 .18406 Mtetra
.67509 .18406 .68334 .19552 .70066 .18933 .69249 .1778 Mtetra
.69249 .1778 .70066 .18933 .71809 .1831 .70999 .1715 Mtetra
.70999 .1715 .71809 .1831 .73563 .17683 .72761 .16516 Mtetra
.72761 .16516 .73563 .17683 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.602 .699 .912 r
.14493 .36283 .15507 .37352 .16902 .37194 .15908 .35977 Mtetra
.511 .633 .907 r
.15908 .35977 .16902 .37194 .18266 .37424 .17302 .35943 Mtetra
.316 .484 .867 r
.17302 .35943 .18266 .37424 .19581 .38282 .18655 .36408 Mtetra
0 .211 .727 r
.18655 .36408 .19581 .38282 .20831 .39996 .19946 .37652 Mtetra
0 0 .494 r
.19946 .37652 .20831 .39996 .22023 .42636 .21162 .39908 Mtetra
0 0 .289 r
.21162 .39908 .22023 .42636 .23192 .45944 .22317 .43186 Mtetra
.724 .417 0 r
.22317 .43186 .23192 .45944 .24406 .49238 .23461 .47083 Mtetra
.805 .441 0 r
.23461 .47083 .24406 .49238 .25742 .51543 .24677 .5072 Mtetra
.804 .32 0 r
.24677 .5072 .25742 .51543 .27256 .51976 .2605 .52958 Mtetra
.332 0 0 r
.2605 .52958 .27256 .51976 .28943 .50203 .2763 .52891 Mtetra
0 0 0 r
.2763 .52891 .28943 .50203 .30747 .46642 .29396 .50352 Mtetra
.29396 .50352 .30747 .46642 .32585 .42213 .31268 .4601 Mtetra
.31268 .4601 .32585 .42213 .34389 .37874 .33155 .40985 Mtetra
.672 .758 .269 r
.33155 .40985 .34389 .37874 .36129 .34256 .34989 .36298 Mtetra
.78 .862 .422 r
.34989 .36298 .36129 .34256 .37804 .31571 .36746 .32538 Mtetra
.876 .965 .637 r
.36746 .32538 .37804 .31571 .39433 .29719 .38432 .29831 Mtetra
.886 .978 .826 r
.38432 .29831 .39433 .29719 .41036 .28464 .40072 .28005 Mtetra
.811 .899 .904 r
.40072 .28005 .41036 .28464 .42629 .2757 .41686 .26781 Mtetra
.736 .82 .916 r
.41686 .26781 .42629 .2757 .44224 .26861 .43293 .25906 Mtetra
.694 .774 .913 r
.43293 .25906 .44224 .26861 .45824 .26235 .44903 .25203 Mtetra
.675 .753 .91 r
.44903 .25203 .45824 .26235 .47434 .25639 .46519 .24574 Mtetra
.667 .745 .909 r
.46519 .24574 .47434 .25639 .49052 .25051 .48143 .23971 Mtetra
.665 .742 .908 r
.48143 .23971 .49052 .25051 .5068 .24464 .49778 .23374 Mtetra
.664 .742 .908 r
.49778 .23374 .5068 .24464 .52318 .23874 .51422 .22777 Mtetra
.664 .741 .908 r
.51422 .22777 .52318 .23874 .53965 .23281 .53076 .22177 Mtetra
.53076 .22177 .53965 .23281 .55622 .22685 .5474 .21574 Mtetra
.5474 .21574 .55622 .22685 .5729 .22085 .56414 .20967 Mtetra
.56414 .20967 .5729 .22085 .58967 .21481 .58098 .20357 Mtetra
.58098 .20357 .58967 .21481 .60655 .20873 .59792 .19742 Mtetra
.59792 .19742 .60655 .20873 .62353 .20262 .61497 .19124 Mtetra
.61497 .19124 .62353 .20262 .64061 .19647 .63212 .18502 Mtetra
.63212 .18502 .64061 .19647 .6578 .19029 .64938 .17877 Mtetra
.64938 .17877 .6578 .19029 .67509 .18406 .66675 .17247 Mtetra
.66675 .17247 .67509 .18406 .69249 .1778 .68422 .16614 Mtetra
.68422 .16614 .69249 .1778 .70999 .1715 .7018 .15976 Mtetra
.7018 .15976 .70999 .1715 .72761 .16516 .71949 .15335 Mtetra
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Mtetra
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.635 .718 .908 r
.13465 .35247 .14493 .36283 .15908 .35977 .14896 .34824 Mtetra
.589 .681 .904 r
.14896 .34824 .15908 .35977 .17302 .35943 .16319 .34554 Mtetra
.491 .594 .885 r
.16319 .34554 .17302 .35943 .18655 .36408 .17717 .34596 Mtetra
.313 .43 .82 r
.17717 .34596 .18655 .36408 .19946 .37652 .19071 .35188 Mtetra
.085 .205 .693 r
.19071 .35188 .19946 .37652 .21162 .39908 .2036 .36603 Mtetra
0 .013 .556 r
.2036 .36603 .21162 .39908 .22317 .43186 .21577 .39031 Mtetra
0 0 .472 r
.21577 .39031 .22317 .43186 .23461 .47083 .22745 .42393 Mtetra
0 0 .459 r
.22745 .42393 .23461 .47083 .24677 .5072 .23921 .46181 Mtetra
0 0 .52 r
.23921 .46181 .24677 .5072 .2605 .52958 .25189 .49445 Mtetra
.22 .234 .662 r
.25189 .49445 .2605 .52958 .2763 .52891 .26628 .51089 Mtetra
.664 .634 .81 r
.26628 .51089 .2763 .52891 .29396 .50352 .28269 .5038 Mtetra
.948 .892 .741 r
.28269 .5038 .29396 .50352 .31268 .4601 .30074 .4737 Mtetra
.971 .92 .596 r
.30074 .4737 .31268 .4601 .33155 .40985 .3196 .42863 Mtetra
.943 .908 .525 r
.3196 .42863 .33155 .40985 .34989 .36298 .3384 .37967 Mtetra
.932 .917 .537 r
.3384 .37967 .34989 .36298 .36746 .32538 .35659 .33584 Mtetra
.938 .949 .622 r
.35659 .33584 .36746 .32538 .38432 .29831 .37403 .30168 Mtetra
.93 .968 .754 r
.37403 .30168 .38432 .29831 .40072 .28005 .39084 .27751 Mtetra
.87 .931 .862 r
.39084 .27751 .40072 .28005 .41686 .26781 .40726 .26125 Mtetra
.784 .858 .905 r
.40726 .26125 .41686 .26781 .43293 .25906 .4235 .25016 Mtetra
.72 .798 .912 r
.4235 .25016 .43293 .25906 .44903 .25203 .43969 .24194 Mtetra
.686 .764 .911 r
.43969 .24194 .44903 .25203 .46519 .24574 .45593 .2351 Mtetra
.672 .75 .909 r
.45593 .2351 .46519 .24574 .48143 .23971 .47225 .22883 Mtetra
.666 .744 .908 r
.47225 .22883 .48143 .23971 .49778 .23374 .48865 .22273 Mtetra
.664 .742 .908 r
.48865 .22273 .49778 .23374 .51422 .22777 .50516 .21668 Mtetra
.664 .741 .908 r
.50516 .21668 .51422 .22777 .53076 .22177 .52176 .21061 Mtetra
.52176 .21061 .53076 .22177 .5474 .21574 .53847 .20451 Mtetra
.53847 .20451 .5474 .21574 .56414 .20967 .55527 .19837 Mtetra
.55527 .19837 .56414 .20967 .58098 .20357 .57218 .1922 Mtetra
.57218 .1922 .58098 .20357 .59792 .19742 .5892 .18598 Mtetra
.5892 .18598 .59792 .19742 .61497 .19124 .60632 .17973 Mtetra
.60632 .17973 .61497 .19124 .63212 .18502 .62354 .17344 Mtetra
.62354 .17344 .63212 .18502 .64938 .17877 .64087 .16711 Mtetra
.64087 .16711 .64938 .17877 .66675 .17247 .65831 .16075 Mtetra
.65831 .16075 .66675 .17247 .68422 .16614 .67586 .15434 Mtetra
.67586 .15434 .68422 .16614 .7018 .15976 .69351 .14789 Mtetra
.69351 .14789 .7018 .15976 .71949 .15335 .71128 .14141 Mtetra
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Mtetra
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Mtetra
.652 .731 .907 r
.12422 .34237 .13465 .35247 .14896 .34824 .13865 .33745 Mtetra
.633 .712 .904 r
.13865 .33745 .14896 .34824 .16319 .34554 .15308 .33321 Mtetra
.588 .668 .894 r
.15308 .33321 .16319 .34554 .17717 .34596 .16743 .33052 Mtetra
.5 .575 .863 r
.16743 .33052 .17717 .34596 .19071 .35188 .18154 .33088 Mtetra
.364 .425 .791 r
.18154 .33088 .19071 .35188 .2036 .36603 .19526 .33643 Mtetra
.226 .259 .688 r
.19526 .33643 .2036 .36603 .21577 .39031 .20841 .34937 Mtetra
.143 .144 .599 r
.20841 .34937 .21577 .39031 .22745 .42393 .22101 .37082 Mtetra
.135 .103 .554 r
.22101 .37082 .22745 .42393 .23921 .46181 .23332 .39926 Mtetra
.193 .128 .55 r
.23332 .39926 .23921 .46181 .25189 .49445 .24589 .42939 Mtetra
.305 .208 .577 r
.24589 .42939 .25189 .49445 .26628 .51089 .25943 .45277 Mtetra
.46 .333 .62 r
.25943 .45277 .26628 .51089 .28269 .5038 .27452 .46073 Mtetra
.639 .488 .662 r
.27452 .46073 .28269 .5038 .30074 .4737 .29126 .44875 Mtetra
.803 .644 .685 r
.29126 .44875 .30074 .4737 .3196 .42863 .30922 .41896 Mtetra
.914 .766 .683 r
.30922 .41896 .3196 .42863 .3384 .37967 .32767 .37893 Mtetra
.963 .843 .676 r
.32767 .37893 .3384 .37967 .35659 .33584 .34595 .33768 Mtetra
.97 .889 .693 r
.34595 .33768 .35659 .33584 .37403 .30168 .36369 .3019 Mtetra
.948 .914 .748 r
.36369 .3019 .37403 .30168 .39084 .27751 .38083 .27446 Mtetra
.897 .908 .824 r
.38083 .27446 .39084 .27751 .40726 .26125 .39751 .25503 Mtetra
.82 .867 .881 r
.39751 .25503 .40726 .26125 .4235 .25016 .41392 .24165 Mtetra
.748 .814 .904 r
.41392 .24165 .4235 .25016 .43969 .24194 .43024 .23207 Mtetra
.702 .776 .909 r
.43024 .23207 .43969 .24194 .45593 .2351 .44657 .22451 Mtetra
.678 .755 .909 r
.44657 .22451 .45593 .2351 .47225 .22883 .46295 .21789 Mtetra
.669 .746 .908 r
.46295 .21789 .47225 .22883 .48865 .22273 .47943 .21163 Mtetra
.665 .743 .908 r
.47943 .21163 .48865 .22273 .50516 .21668 .496 .20547 Mtetra
.664 .742 .908 r
.496 .20547 .50516 .21668 .52176 .21061 .51267 .19932 Mtetra
.664 .741 .908 r
.51267 .19932 .52176 .21061 .53847 .20451 .52944 .19315 Mtetra
.52944 .19315 .53847 .20451 .55527 .19837 .54631 .18694 Mtetra
.54631 .18694 .55527 .19837 .57218 .1922 .56329 .1807 Mtetra
.56329 .1807 .57218 .1922 .5892 .18598 .58037 .17441 Mtetra
.58037 .17441 .5892 .18598 .60632 .17973 .59756 .16809 Mtetra
.59756 .16809 .60632 .17973 .62354 .17344 .61486 .16173 Mtetra
.61486 .16173 .62354 .17344 .64087 .16711 .63226 .15533 Mtetra
.63226 .15533 .64087 .16711 .65831 .16075 .64977 .14889 Mtetra
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Mtetra
.6674 .14241 .67586 .15434 .69351 .14789 .68513 .13588 Mtetra
.68513 .13588 .69351 .14789 .71128 .14141 .70297 .12932 Mtetra
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.66 .738 .907 r
.11365 .33238 .12422 .34237 .13865 .33745 .12816 .32713 Mtetra
.653 .73 .906 r
.12816 .32713 .13865 .33745 .15308 .33321 .14272 .3221 Mtetra
.635 .71 .901 r
.14272 .3221 .15308 .33321 .16743 .33052 .1573 .31768 Mtetra
.597 .665 .886 r
.1573 .31768 .16743 .33052 .18154 .33088 .17181 .3146 Mtetra
.528 .579 .85 r
.17181 .3146 .18154 .33088 .19526 .33643 .18615 .31409 Mtetra
.434 .454 .781 r
.18615 .31409 .19526 .33643 .20841 .34937 .20019 .31774 Mtetra
.347 .329 .697 r
.20019 .31774 .20841 .34937 .22101 .37082 .21384 .32701 Mtetra
.305 .248 .628 r
.21384 .32701 .22101 .37082 .23332 .39926 .22715 .34229 Mtetra
.311 .222 .591 r
.22715 .34229 .23332 .39926 .24589 .42939 .24037 .36176 Mtetra
.358 .241 .581 r
.24037 .36176 .24589 .42939 .25943 .45277 .25395 .38093 Mtetra
.432 .292 .589 r
.25395 .38093 .25943 .45277 .27452 .46073 .26838 .39353 Mtetra
.525 .366 .608 r
.26838 .39353 .27452 .46073 .29126 .44875 .28399 .39401 Mtetra
.628 .457 .632 r
.28399 .39401 .29126 .44875 .30922 .41896 .30074 .3803 Mtetra
.729 .556 .657 r
.30074 .3803 .30922 .41896 .32767 .37893 .31827 .35502 Mtetra
.815 .653 .682 r
.31827 .35502 .32767 .37893 .34595 .33768 .33605 .32398 Mtetra
.873 .737 .71 r
.33605 .32398 .34595 .33768 .36369 .3019 .35364 .29333 Mtetra
.893 .8 .75 r
.35364 .29333 .36369 .3019 .38083 .27446 .37085 .26726 Mtetra
.875 .834 .803 r
.37085 .26726 .38083 .27446 .39751 .25503 .38768 .24724 Mtetra
.825 .834 .855 r
.38768 .24724 .39751 .25503 .41392 .24165 .40425 .2327 Mtetra
.763 .809 .889 r
.40425 .2327 .41392 .24165 .43024 .23207 .42068 .2221 Mtetra
.714 .779 .903 r
.42068 .2221 .43024 .23207 .44657 .22451 .43709 .21388 Mtetra
.686 .759 .907 r
.43709 .21388 .44657 .22451 .46295 .21789 .45356 .20688 Mtetra
.672 .748 .908 r
.45356 .20688 .46295 .21789 .47943 .21163 .4701 .20042 Mtetra
.666 .744 .908 r
.4701 .20042 .47943 .21163 .496 .20547 .48673 .19414 Mtetra
.664 .742 .908 r
.48673 .19414 .496 .20547 .51267 .19932 .50347 .18791 Mtetra
.664 .741 .908 r
.50347 .18791 .51267 .19932 .52944 .19315 .52031 .18166 Mtetra
.52031 .18166 .52944 .19315 .54631 .18694 .53725 .17538 Mtetra
.53725 .17538 .54631 .18694 .56329 .1807 .5543 .16907 Mtetra
.5543 .16907 .56329 .1807 .58037 .17441 .57145 .16271 Mtetra
.57145 .16271 .58037 .17441 .59756 .16809 .58871 .15632 Mtetra
.58871 .15632 .59756 .16809 .61486 .16173 .60608 .14988 Mtetra
.60608 .14988 .61486 .16173 .63226 .15533 .62355 .14341 Mtetra
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Mtetra
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Mtetra
.65884 .13033 .6674 .14241 .68513 .13588 .67665 .12373 Mtetra
.67665 .12373 .68513 .13588 .70297 .12932 .69457 .11709 Mtetra
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.663 .74 .908 r
.10296 .32238 .11365 .33238 .12816 .32713 .11753 .31698 Mtetra
.661 .738 .907 r
.11753 .31698 .12816 .32713 .14272 .3221 .13217 .31162 Mtetra
.655 .73 .905 r
.13217 .31162 .14272 .3221 .1573 .31768 .14687 .30643 Mtetra
.641 .712 .899 r
.14687 .30643 .1573 .31768 .17181 .3146 .1616 .3017 Mtetra
.613 .673 .883 r
.1616 .3017 .17181 .3146 .18615 .31409 .17631 .29797 Mtetra
.564 .601 .848 r
.17631 .29797 .18615 .31409 .20019 .31774 .19093 .29607 Mtetra
.5 .501 .789 r
.19093 .29607 .20019 .31774 .21384 .32701 .20537 .29702 Mtetra
.443 .402 .718 r
.20537 .29702 .21384 .32701 .22715 .34229 .21961 .3016 Mtetra
.414 .335 .659 r
.21961 .3016 .22715 .34229 .24037 .36176 .2337 .30972 Mtetra
.417 .308 .622 r
.2337 .30972 .24037 .36176 .25395 .38093 .24783 .31981 Mtetra
.448 .315 .607 r
.24783 .31981 .25395 .38093 .26838 .39353 .26232 .32869 Mtetra
.497 .347 .607 r
.26232 .32869 .26838 .39353 .28399 .39401 .27743 .33251 Mtetra
.557 .396 .618 r
.27743 .33251 .28399 .39401 .30074 .3803 .29332 .32831 Mtetra
.625 .458 .637 r
.29332 .32831 .30074 .3803 .31827 .35502 .3099 .31556 Mtetra
.693 .53 .662 r
.3099 .31556 .31827 .35502 .33605 .32398 .32692 .29645 Mtetra
.754 .607 .694 r
.32692 .29645 .33605 .32398 .35364 .29333 .34405 .27469 Mtetra
.797 .68 .735 r
.34405 .27469 .35364 .29333 .37085 .26726 .36107 .25387 Mtetra
.812 .74 .784 r
.36107 .25387 .37085 .26726 .38768 .24724 .37788 .2362 Mtetra
.795 .774 .834 r
.37788 .2362 .38768 .24724 .40425 .2327 .3945 .22227 Mtetra
.757 .781 .872 r
.3945 .22227 .40425 .2327 .42068 .2221 .41102 .21154 Mtetra
.718 .771 .894 r
.41102 .21154 .42068 .2221 .43709 .21388 .42752 .203 Mtetra
.69 .758 .904 r
.42752 .203 .43709 .21388 .45356 .20688 .44405 .19574 Mtetra
.674 .749 .907 r
.44405 .19574 .45356 .20688 .4701 .20042 .46066 .18909 Mtetra
.668 .744 .908 r
.46066 .18909 .4701 .20042 .48673 .19414 .47736 .18269 Mtetra
.665 .742 .908 r
.47736 .18269 .48673 .19414 .50347 .18791 .49417 .17637 Mtetra
.664 .742 .908 r
.49417 .17637 .50347 .18791 .52031 .18166 .51107 .17005 Mtetra
.664 .741 .908 r
.51107 .17005 .52031 .18166 .53725 .17538 .52808 .16369 Mtetra
.52808 .16369 .53725 .17538 .5543 .16907 .5452 .1573 Mtetra
.5452 .1573 .5543 .16907 .57145 .16271 .56242 .15087 Mtetra
.56242 .15087 .57145 .16271 .58871 .15632 .57976 .1444 Mtetra
.57976 .1444 .58871 .15632 .60608 .14988 .5972 .1379 Mtetra
.5972 .1379 .60608 .14988 .62355 .14341 .61475 .13134 Mtetra
.61475 .13134 .62355 .14341 .64114 .13689 .63241 .12475 Mtetra
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Mtetra
.65018 .11812 .65884 .13033 .67665 .12373 .66806 .11144 Mtetra
.66806 .11144 .67665 .12373 .69457 .11709 .68606 .10472 Mtetra
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Mtetra
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.663 .741 .908 r
.09215 .31231 .10296 .32238 .11753 .31698 .10677 .30682 Mtetra
.663 .74 .908 r
.10677 .30682 .11753 .31698 .13217 .31162 .12147 .30131 Mtetra
.661 .738 .907 r
.12147 .30131 .13217 .31162 .14687 .30643 .13624 .29583 Mtetra
.657 .732 .905 r
.13624 .29583 .14687 .30643 .1616 .3017 .15109 .29046 Mtetra
.648 .718 .899 r
.15109 .29046 .1616 .3017 .17631 .29797 .16599 .28538 Mtetra
.63 .688 .885 r
.16599 .28538 .17631 .29797 .19093 .29607 .18091 .28092 Mtetra
.599 .634 .857 r
.18091 .28092 .19093 .29607 .20537 .29702 .1958 .27758 Mtetra
.558 .558 .81 r
.1958 .27758 .20537 .29702 .21961 .3016 .21064 .2759 Mtetra
.518 .479 .753 r
.21064 .2759 .21961 .3016 .2337 .30972 .22541 .2762 Mtetra
.495 .419 .7 r
.22541 .2762 .2337 .30972 .24783 .31981 .24016 .27825 Mtetra
.493 .388 .663 r
.24016 .27825 .24783 .31981 .26232 .32869 .25503 .28094 Mtetra
.51 .384 .644 r
.25503 .28094 .26232 .32869 .27743 .33251 .27017 .28243 Mtetra
.542 .402 .64 r
.27017 .28243 .27743 .33251 .29332 .32831 .28572 .28069 Mtetra
.583 .436 .647 r
.28572 .28069 .29332 .32831 .3099 .31556 .30173 .27446 Mtetra
.63 .484 .665 r
.30173 .27446 .3099 .31556 .32692 .29645 .31813 .26382 Mtetra
.677 .541 .692 r
.31813 .26382 .32692 .29645 .34405 .27469 .33476 .2502 Mtetra
.718 .604 .729 r
.33476 .2502 .34405 .27469 .36107 .25387 .35146 .23564 Mtetra
.744 .666 .774 r
.35146 .23564 .36107 .25387 .37788 .2362 .36812 .2219 Mtetra
.749 .715 .82 r
.36812 .2219 .37788 .2362 .3945 .22227 .38472 .20999 Mtetra
.734 .744 .86 r
.38472 .20999 .3945 .22227 .41102 .21154 .40128 .20004 Mtetra
.71 .753 .886 r
.40128 .20004 .41102 .21154 .42752 .203 .41784 .19168 Mtetra
.689 .751 .899 r
.41784 .19168 .42752 .203 .44405 .19574 .43444 .18436 Mtetra
.675 .747 .905 r
.43444 .18436 .44405 .19574 .46066 .18909 .45112 .17761 Mtetra
.668 .744 .907 r
.45112 .17761 .46066 .18909 .47736 .18269 .46789 .17111 Mtetra
.665 .742 .908 r
.46789 .17111 .47736 .18269 .49417 .17637 .48476 .1647 Mtetra
.664 .742 .908 r
.48476 .1647 .49417 .17637 .51107 .17005 .50173 .1583 Mtetra
.664 .741 .908 r
.50173 .1583 .51107 .17005 .52808 .16369 .51881 .15187 Mtetra
.51881 .15187 .52808 .16369 .5452 .1573 .536 .1454 Mtetra
.536 .1454 .5452 .1573 .56242 .15087 .55329 .1389 Mtetra
.55329 .1389 .56242 .15087 .57976 .1444 .5707 .13236 Mtetra
.5707 .13236 .57976 .1444 .5972 .1379 .58821 .12577 Mtetra
.58821 .12577 .5972 .1379 .61475 .13134 .60583 .11914 Mtetra
.60583 .11914 .61475 .13134 .63241 .12475 .62357 .11247 Mtetra
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Mtetra
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Mtetra
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Mtetra
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Mtetra
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.08123 .30213 .09215 .31231 .10677 .30682 .09589 .29658 Mtetra
.663 .741 .908 r
.09589 .29658 .10677 .30682 .12147 .30131 .11064 .291 Mtetra
.11064 .291 .12147 .30131 .13624 .29583 .12547 .28539 Mtetra
.662 .739 .907 r
.12547 .28539 .13624 .29583 .15109 .29046 .14039 .27979 Mtetra
.66 .735 .905 r
.14039 .27979 .15109 .29046 .16599 .28538 .15538 .27423 Mtetra
.655 .725 .901 r
.15538 .27423 .16599 .28538 .18091 .28092 .17044 .26883 Mtetra
.644 .705 .891 r
.17044 .26883 .18091 .28092 .1958 .27758 .18556 .26375 Mtetra
.627 .669 .871 r
.18556 .26375 .1958 .27758 .21064 .2759 .20071 .25925 Mtetra
.603 .618 .839 r
.20071 .25925 .21064 .2759 .22541 .2762 .21587 .25556 Mtetra
.578 .559 .797 r
.21587 .25556 .22541 .2762 .24016 .27825 .23106 .25278 Mtetra
.56 .508 .754 r
.23106 .25278 .24016 .27825 .25503 .28094 .2463 .2507 Mtetra
.555 .475 .72 r
.2463 .2507 .25503 .28094 .27017 .28243 .26167 .2487 Mtetra
.563 .464 .7 r
.26167 .2487 .27017 .28243 .28572 .28069 .27723 .24587 Mtetra
.583 .473 .694 r
.27723 .24587 .28572 .28069 .30173 .27446 .29305 .24132 Mtetra
.61 .497 .7 r
.29305 .24132 .30173 .27446 .31813 .26382 .30913 .2346 Mtetra
.641 .535 .718 r
.30913 .2346 .31813 .26382 .33476 .2502 .32542 .22594 Mtetra
.672 .583 .747 r
.32542 .22594 .33476 .2502 .35146 .23564 .34186 .21608 Mtetra
.696 .634 .783 r
.34186 .21608 .35146 .23564 .36812 .2219 .35836 .20598 Mtetra
.708 .681 .822 r
.35836 .20598 .36812 .2219 .38472 .20999 .3749 .19641 Mtetra
.706 .716 .857 r
.3749 .19641 .38472 .20999 .40128 .20004 .39146 .1877 Mtetra
.695 .735 .881 r
.39146 .1877 .40128 .20004 .41784 .19168 .40806 .17987 Mtetra
.683 .742 .896 r
.40806 .17987 .41784 .19168 .43444 .18436 .42472 .1727 Mtetra
.673 .743 .903 r
.42472 .1727 .43444 .18436 .45112 .17761 .44147 .16594 Mtetra
.668 .743 .906 r
.44147 .16594 .45112 .17761 .46789 .17111 .4583 .15938 Mtetra
.665 .742 .907 r
.4583 .15938 .46789 .17111 .48476 .1647 .47524 .15289 Mtetra
.664 .742 .908 r
.47524 .15289 .48476 .1647 .50173 .1583 .49228 .14641 Mtetra
.664 .741 .908 r
.49228 .14641 .50173 .1583 .51881 .15187 .50943 .13991 Mtetra
.50943 .13991 .51881 .15187 .536 .1454 .52669 .13337 Mtetra
.52669 .13337 .536 .1454 .55329 .1389 .54406 .12679 Mtetra
.54406 .12679 .55329 .1389 .5707 .13236 .56153 .12016 Mtetra
.56153 .12016 .5707 .13236 .58821 .12577 .57912 .1135 Mtetra
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Mtetra
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Mtetra
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Mtetra
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Mtetra
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Mtetra
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Mtetra
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Mtetra
.07019 .29185 .08123 .30213 .09589 .29658 .0849 .28624 Mtetra
.0849 .28624 .09589 .29658 .11064 .291 .09969 .28059 Mtetra
.663 .741 .908 r
.09969 .28059 .11064 .291 .12547 .28539 .11458 .27491 Mtetra
.11458 .27491 .12547 .28539 .14039 .27979 .12954 .2692 Mtetra
.663 .74 .907 r
.12954 .2692 .14039 .27979 .15538 .27423 .1446 .26348 Mtetra
.662 .737 .906 r
.1446 .26348 .15538 .27423 .17044 .26883 .15974 .25777 Mtetra
.659 .732 .903 r
.15974 .25777 .17044 .26883 .18556 .26375 .17496 .25211 Mtetra
.654 .72 .897 r
.17496 .25211 .18556 .26375 .20071 .25925 .19026 .24658 Mtetra
.645 .7 .886 r
.19026 .24658 .20071 .25925 .21587 .25556 .20562 .2413 Mtetra
.634 .669 .866 r
.20562 .2413 .21587 .25556 .23106 .25278 .22104 .23634 Mtetra
.621 .632 .841 r
.22104 .23634 .23106 .25278 .2463 .2507 .23653 .23173 Mtetra
.611 .597 .812 r
.23653 .23173 .2463 .2507 .26167 .2487 .2521 .22732 Mtetra
.606 .57 .787 r
.2521 .22732 .26167 .2487 .27723 .24587 .26779 .22284 Mtetra
.61 .558 .771 r
.26779 .22284 .27723 .24587 .29305 .24132 .28363 .2179 Mtetra
.621 .561 .766 r
.28363 .2179 .29305 .24132 .30913 .2346 .29963 .21218 Mtetra
.637 .579 .773 r
.29963 .21218 .30913 .2346 .32542 .22594 .31579 .20555 Mtetra
.655 .607 .789 r
.31579 .20555 .32542 .22594 .34186 .21608 .33209 .19817 Mtetra
.671 .642 .813 r
.33209 .19817 .34186 .21608 .35836 .20598 .3485 .19038 Mtetra
.681 .677 .839 r
.3485 .19038 .35836 .20598 .3749 .19641 .36499 .18255 Mtetra
.684 .706 .864 r
.36499 .18255 .3749 .19641 .39146 .1877 .38155 .17496 Mtetra
.681 .725 .884 r
.38155 .17496 .39146 .1877 .40806 .17987 .39819 .16772 Mtetra
.675 .736 .896 r
.39819 .16772 .40806 .17987 .42472 .1727 .4149 .16079 Mtetra
.67 .74 .903 r
.4149 .16079 .42472 .1727 .44147 .16594 .43171 .15408 Mtetra
.667 .741 .906 r
.43171 .15408 .44147 .16594 .4583 .15938 .44861 .14749 Mtetra
.665 .742 .907 r
.44861 .14749 .4583 .15938 .47524 .15289 .46561 .14094 Mtetra
.664 .741 .908 r
.46561 .14094 .47524 .15289 .49228 .14641 .48273 .13438 Mtetra
.48273 .13438 .49228 .14641 .50943 .13991 .49994 .1278 Mtetra
.49994 .1278 .50943 .13991 .52669 .13337 .51727 .12119 Mtetra
.51727 .12119 .52669 .13337 .54406 .12679 .53471 .11453 Mtetra
.53471 .11453 .54406 .12679 .56153 .12016 .55226 .10783 Mtetra
.55226 .10783 .56153 .12016 .57912 .1135 .56992 .10109 Mtetra
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Mtetra
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Mtetra
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Mtetra
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Mtetra
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Mtetra
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Mtetra
.05902 .28146 .07019 .29185 .0849 .28624 .07378 .27578 Mtetra
.07378 .27578 .0849 .28624 .09969 .28059 .08863 .27007 Mtetra
.08863 .27007 .09969 .28059 .11458 .27491 .10356 .26433 Mtetra
.10356 .26433 .11458 .27491 .12954 .2692 .11858 .25855 Mtetra
.663 .741 .908 r
.11858 .25855 .12954 .2692 .1446 .26348 .13369 .25275 Mtetra
.13369 .25275 .1446 .26348 .15974 .25777 .14888 .24691 Mtetra
.663 .739 .907 r
.14888 .24691 .15974 .25777 .17496 .25211 .16417 .24106 Mtetra
.661 .736 .905 r
.16417 .24106 .17496 .25211 .19026 .24658 .17954 .23521 Mtetra
.659 .731 .902 r
.17954 .23521 .19026 .24658 .20562 .2413 .195 .2294 Mtetra
.656 .721 .896 r
.195 .2294 .20562 .2413 .22104 .23634 .21054 .22365 Mtetra
.651 .706 .887 r
.21054 .22365 .22104 .23634 .23653 .23173 .22617 .218 Mtetra
.646 .687 .874 r
.22617 .218 .23653 .23173 .2521 .22732 .24188 .21244 Mtetra
.642 .668 .86 r
.24188 .21244 .2521 .22732 .26779 .22284 .25769 .20691 Mtetra
.64 .653 .847 r
.25769 .20691 .26779 .22284 .28363 .2179 .27361 .2013 Mtetra
.642 .645 .838 r
.27361 .2013 .28363 .2179 .29963 .21218 .28964 .19547 Mtetra
.647 .647 .836 r
.28964 .19547 .29963 .21218 .31579 .20555 .30579 .18931 Mtetra
.655 .658 .841 r
.30579 .18931 .31579 .20555 .33209 .19817 .32207 .18282 Mtetra
.663 .675 .851 r
.32207 .18282 .33209 .19817 .3485 .19038 .33845 .17607 Mtetra
.668 .694 .865 r
.33845 .17607 .3485 .19038 .36499 .18255 .35494 .16918 Mtetra
.671 .712 .879 r
.35494 .16918 .36499 .18255 .38155 .17496 .37152 .16228 Mtetra
.671 .725 .89 r
.37152 .16228 .38155 .17496 .39819 .16772 .3882 .15545 Mtetra
.669 .734 .898 r
.3882 .15545 .39819 .16772 .4149 .16079 .40497 .14872 Mtetra
.667 .738 .903 r
.40497 .14872 .4149 .16079 .43171 .15408 .42183 .14206 Mtetra
.665 .74 .906 r
.42183 .14206 .43171 .15408 .44861 .14749 .4388 .13545 Mtetra
.664 .741 .907 r
.4388 .13545 .44861 .14749 .46561 .14094 .45588 .12884 Mtetra
.664 .741 .908 r
.45588 .12884 .46561 .14094 .48273 .13438 .47306 .12221 Mtetra
.47306 .12221 .48273 .13438 .49994 .1278 .49034 .11556 Mtetra
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Mtetra
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Mtetra
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Mtetra
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Mtetra
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Mtetra
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Mtetra
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Mtetra
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Mtetra
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Mtetra
.04774 .27095 .05902 .28146 .07378 .27578 .06255 .26522 Mtetra
.06255 .26522 .07378 .27578 .08863 .27007 .07744 .25944 Mtetra
.07744 .25944 .08863 .27007 .10356 .26433 .09242 .25364 Mtetra
.09242 .25364 .10356 .26433 .11858 .25855 .10749 .2478 Mtetra
.10749 .2478 .11858 .25855 .13369 .25275 .12265 .24192 Mtetra
.663 .741 .908 r
.12265 .24192 .13369 .25275 .14888 .24691 .1379 .23601 Mtetra
.1379 .23601 .14888 .24691 .16417 .24106 .15324 .23007 Mtetra
.663 .74 .907 r
.15324 .23007 .16417 .24106 .17954 .23521 .16867 .2241 Mtetra
.663 .739 .907 r
.16867 .2241 .17954 .23521 .195 .2294 .18419 .21811 Mtetra
.662 .737 .905 r
.18419 .21811 .195 .2294 .21054 .22365 .19981 .2121 Mtetra
.661 .733 .903 r
.19981 .2121 .21054 .22365 .22617 .218 .21552 .20609 Mtetra
.659 .727 .899 r
.21552 .20609 .22617 .218 .24188 .21244 .23132 .20009 Mtetra
.658 .719 .894 r
.23132 .20009 .24188 .21244 .25769 .20691 .24721 .19408 Mtetra
.656 .711 .888 r
.24721 .19408 .25769 .20691 .27361 .2013 .2632 .18805 Mtetra
.656 .705 .883 r
.2632 .18805 .27361 .2013 .28964 .19547 .2793 .18196 Mtetra
.657 .702 .88 r
.2793 .18196 .28964 .19547 .30579 .18931 .2955 .17576 Mtetra
.659 .703 .879 r
.2955 .17576 .30579 .18931 .32207 .18282 .31181 .16944 Mtetra
.662 .708 .882 r
.31181 .16944 .32207 .18282 .33845 .17607 .32823 .16299 Mtetra
.664 .716 .887 r
.32823 .16299 .33845 .17607 .35494 .16918 .34475 .15643 Mtetra
.666 .724 .893 r
.34475 .15643 .35494 .16918 .37152 .16228 .36137 .14982 Mtetra
.666 .731 .898 r
.36137 .14982 .37152 .16228 .3882 .15545 .37809 .14319 Mtetra
.666 .736 .902 r
.37809 .14319 .3882 .15545 .40497 .14872 .39492 .13655 Mtetra
.665 .739 .905 r
.39492 .13655 .40497 .14872 .42183 .14206 .41185 .12991 Mtetra
.664 .74 .906 r
.41185 .12991 .42183 .14206 .4388 .13545 .42888 .12326 Mtetra
.664 .741 .907 r
.42888 .12326 .4388 .13545 .45588 .12884 .44602 .1166 Mtetra
.664 .741 .908 r
.44602 .1166 .45588 .12884 .47306 .12221 .46327 .1099 Mtetra
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Mtetra
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Mtetra
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Mtetra
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Mtetra
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Mtetra
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Mtetra
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Mtetra
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Mtetra
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Mtetra
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.03634 .26033 .04774 .27095 .06255 .26522 .05119 .25453 Mtetra
.05119 .25453 .06255 .26522 .07744 .25944 .06613 .2487 Mtetra
.06613 .2487 .07744 .25944 .09242 .25364 .08116 .24283 Mtetra
.08116 .24283 .09242 .25364 .10749 .2478 .09628 .23692 Mtetra
.09628 .23692 .10749 .2478 .12265 .24192 .11148 .23098 Mtetra
.11148 .23098 .12265 .24192 .1379 .23601 .12679 .225 Mtetra
.12679 .225 .1379 .23601 .15324 .23007 .14218 .21899 Mtetra
.663 .741 .908 r
.14218 .21899 .15324 .23007 .16867 .2241 .15766 .21295 Mtetra
.15766 .21295 .16867 .2241 .18419 .21811 .17324 .20686 Mtetra
.663 .74 .907 r
.17324 .20686 .18419 .21811 .19981 .2121 .18892 .20075 Mtetra
.18892 .20075 .19981 .2121 .21552 .20609 .20469 .1946 Mtetra
.663 .738 .906 r
.20469 .1946 .21552 .20609 .23132 .20009 .22055 .18843 Mtetra
.662 .736 .905 r
.22055 .18843 .23132 .20009 .24721 .19408 .23652 .18223 Mtetra
.662 .734 .903 r
.23652 .18223 .24721 .19408 .2632 .18805 .25258 .176 Mtetra
.662 .731 .901 r
.25258 .176 .2632 .18805 .2793 .18196 .26874 .16973 Mtetra
.662 .729 .9 r
.26874 .16973 .2793 .18196 .2955 .17576 .285 .16342 Mtetra
.662 .728 .899 r
.285 .16342 .2955 .17576 .31181 .16944 .30136 .15704 Mtetra
.662 .729 .899 r
.30136 .15704 .31181 .16944 .32823 .16299 .31783 .1506 Mtetra
.663 .731 .9 r
.31783 .1506 .32823 .16299 .34475 .15643 .3344 .1441 Mtetra
.664 .733 .902 r
.3344 .1441 .34475 .15643 .36137 .14982 .35108 .13754 Mtetra
.664 .736 .903 r
.35108 .13754 .36137 .14982 .37809 .14319 .36786 .13094 Mtetra
.664 .738 .905 r
.36786 .13094 .37809 .14319 .39492 .13655 .38475 .12431 Mtetra
.664 .74 .906 r
.38475 .12431 .39492 .13655 .41185 .12991 .40174 .11764 Mtetra
.664 .741 .907 r
.40174 .11764 .41185 .12991 .42888 .12326 .41884 .11095 Mtetra
.664 .741 .908 r
.41884 .11095 .42888 .12326 .44602 .1166 .43605 .10421 Mtetra
.43605 .10421 .44602 .1166 .46327 .1099 .45337 .09744 Mtetra
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Mtetra
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Mtetra
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Mtetra
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Mtetra
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Mtetra
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Mtetra
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Mtetra
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Mtetra
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Mtetra
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`006_oooonD000003?oooooU?l0000Kooooo`006_oo
ool00`00003oooooooooo`2@ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0T?oo
ool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2@ooooo`0300000?oooooo
oooo037ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Iooooo`006_ooool00`00
003oooooooooo`2@ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0T?ooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000ooo
ool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooo
ooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003oooo
o`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`00
6_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@00
0003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0a
ooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00
003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`00
00?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wo
oooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`03o`00
0?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0ao`0000P00000E?l0
0003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo02[o000000<00000o`000000000010000008
01TI6@<00000DOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo
08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo02Ko00001000000C01TI
6@0300000?l0003o000004go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0So`0000<0
0000600I6AT00`00003o0000o`00001<o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
8_l000000`0000006ATI01TI6@0501TI6@go0000200I6AT00`00003o0000o`00001;o`0000?ooooo
00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oo
oooooooo037ooooo00?o0000ooooooooool07ol000000`00003o00000000000501TI6@?o00003@0c
<c<3o`0000H06ATICOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooo
oooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01ko000000<00000
01TI6@0I6AT0100I6AT2o`0000H0<c<c2?l0000503<c<`03o`00000I6AT06ATI00@06ATI00<00000
o`000?l00000BOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo
08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01co00000P00000401TI
6@?o00000P0c<c<6o`0000P0C4a<00?o000003<c<`0c<c<00`0c<c<00ol000006ATI01TI6@0301TI
6@0300000?l0003o000004Wo00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Jo`000080
00000`0I6AT3o`0000<0<c<c0_l0000304a<C0Wo00000`1<C4`2o`0000@0<c<c00?o000001TI6@0I
6AT00`0I6AT00`00003o0000o`000018o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
6?l000000`00003o000001TI6@0301TI6@04o`00000c<c<0<c<c03<c<`?o000000<0C4a<o`000?l0
00000_l0000906IVIP05o`00001<C4`0C4a<04a<C?l00000100c<c<00ol000006ATI01TI6@0301TI
6@0300000?l0003o000004So00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Go`000003
0000000I6AT06ATI00806ATI0_l000001@0c<c?o0000o`000?l00000C4a<00?o000000<0IVIVo`00
0?l000002Ol0000206IVIP05o`00001<C4`0C4a<04a<C?l000000`0c<c<00ol000006ATI01TI6@03
01TI6@0300000?l0003o000004So00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00
003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Fo`00
00030000000I6AT06ATI00806ATI00Co000003<c<`0c<c?o00000P1<C4`2o`000080IVIV0_l00003
07moO`Co0000101oOgl2o`00000506IVI_l00000C4a<04a<C?l00000100c<c<00ol000006ATI01TI
6@0201TI6@0300000?l0003o000004So00000oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0D
o`00000300000?l000006ATI00806ATI0_l00000100c<c?o0000o`00001<C4`2o`00000306IVI_l0
003o000000Ko00000`000000102IVIWo0000o`000?l0000207moO`04o`00001VIVH0IVIVo`000080
C4a<00Go000003<c<`0c<c<0<c<co`00000401TI6@0300000?l0003o000004So00000oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`0Co`0000030000000I6AT06ATI00806ATI00Co000003<c<`0c
<c?o00000P1<C4`7o`00000309VIV@0000000000008000000`2c/k<20000000509VIVOl00000Ogmo
07moOol000000P1VIVH01?l00000C4a<04a<C?l0000303<c<`03o`00000I6AT06ATI00806ATI00<0
0000o`000?l00000B?l00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooo
oooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01;o000000<00000
01TI6@0I6AT00P0I6AT01Ol00000<c<c03<c<ol00000C4a<00?o000000@0Ogmoo`000?l00000VIVI
0`000006o`0000<0/k>c00D0000009VIVOl00000Ogmoo`00000206IVIP04o`00001<C4`0C4a<o`00
00<0<c<c00Go000001TI6@0I6AT06ATI0000001;o`0000?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000oooo
ooooool04Ol000000`0000006ATI01TI6@0201TI6@08o`00000c<c<0<c<co`00001<C4co000006IV
I_l0000207moO`04o`00002IVIT000000;>c/`;o00001P3<c<`01_l00000/k>c0;>c/`000000VIVI
o`000080Ogmo00?o000006IVI_l000000P1<C4`01?l00000<c<c03<c<ol0000401TI6@0300000?l0
003o000004Wo00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=
000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0?o`00008000000`0I6AT2
o`00000303<c<ol0003o000000Co000000D0Ogmoo`000000003o000000000002o`000080c<c<1Ol0
00020<c<c00:o`00002c/k<0/k>c0000002IVIWo000007moOol00000IVIVo`000080C4a<00Co0000
03<c<`0c<c?o0000100I6AT00`00003o0000o`000019o`0000?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000
ooooooooool03_l000000`0000006ATI01TI6@0201TI6@09o`00000c<c<0<c<co`00001<C4co0000
06IVI_l00000Ogmo00;o000000<00000o`000?l000001Ol000050>KViP03o`00003<c<co00000080
/k>c00L0000009VIVOl00000Ogmoo`00001VIVKo00000080C4a<00Co000003<c<`0c<c?o0000100I
6AT00`00003o0000o`000019o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000
ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool03_l00000
1@0000006ATI01TI6@0I6AWo00000080<c<c00_o000004a<C?l00000IVIVo`00001oOgoo000009VI
V@00003o00000<c<c002o`0000030>KVi_l0003o000000Co00000P3Vi^H02Ol00000c<c<0<c<c?l0
0000/k>c00000?l00000Ogmoo`00000206IVIP03o`00001<C4co00000080<c<c00?o000001TI6@0I
6AT00P0I6AT00`00003o0000o`00001:o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
3Ol000001@0000006ATI01TI6@0I6AWo00000080<c<c00Co000004a<C?l00000IVIV0ol000001P00
003o0000o`00003<c<co00000>KViP;o00001P3oool03ol00000i^KV0>KVi_l00000c<c<o`00002c
/k<00000o`00001oOgoo000006IVI_l00000C4a<o`00000203<c<`03o`00000I6AT06ATI00806ATI
00<00000o`000?l00000Bol00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oo
oooooooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo00co000000D0
000001TI6@0I6AT06ATIo`00000203<c<`05o`00001<C4`0C4a<o`00001VIVH00_l000001@000000
/k>c0;>c/ol00000c<c<00;o0000203oool00ol00000i^KVo`0000020<c<c00:o`00002c/k<00000
o`00001oOgoo000006IVI_l00000C4a<o`000080<c<c00Go000001TI6@0I6AT06ATI0000001>o`00
00?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool02ol000001@0000006ATI01TI6@0I6AWo0000
0080<c<c00Go000004a<C01<C4co000006IVIP02o`0000080000002c/k<0/k>co`00003<c<co0000
0>KVi_l000070?ooo`09o`00003Vi^H0i^KVo`00003<c<co00000;>c/`00003o00000080Ogmo0_l0
00000`1<C4co000003<c<`0203<c<`04o`00000I6AT06ATI000004oo00000oooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Ooo
ool00ol0003oooooooooo`0;o`0000040000000I6AT06ATIo`0000<0<c<c00ko000004a<C?l00000
IVIVo`00001oOgoo00000000002c/k?o00000<c<c?l00000i^KVo`0000P0oooo00?o00000>KVi_l0
00000P3<c<`02_l00000000009VIVOl00000Ogmoo`00001VIVKo000004a<C?l0000203<c<`05o`00
000I6AT06ATI01TI6@000000Col00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`030000
0?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo00[o0000
00D0000001TI6@0I6AT06ATIo`00000203<c<`0<o`00001<C4co000006IVI_l00000Ogmoo`00002I
VIT00000o`00003<c<co00000P3Vi^H00ol00000oooo0?ooo`040?ooo`;o000000<0i^KVo`000?l0
00000_l000001000003o0000o`00001oOgl3o`00000504a<C?l00000<c<c03<c<ol000000`0I6AT0
0`00003o0000o`00001>o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooo
ooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool02_l000001@00
00006ATI01TI6@0I6AWo00000080<c<c00co000004a<C?l00000IVIVo`00001oOgoo000009VIV@00
003o00000<c<c?l000020>KViP03o`00003oool0oooo00<0oooo00Wo00000>KVi_l0003o00000<c<
c?l00000/k>c00000?l000000P1oOgl2o`000080C4a<00Co000003<c<`0c<c?o00000`0I6AT00`00
003o0000o`00001?o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooooooo
ool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool02Ol000001@000000
6ATI01TI6@0I6AWo00000080<c<c00[o000004a<C?l00000IVIVo`00001oOgoo000009VIV@00003o
00000P3<c<`01_l00000i^KV0>KViP3Vi^Ko00000?ooo`?o000000D0i^KVo`00003<c<`0c<c<o`00
000200000003o`00001oOgoo000000;o000000@0C4a<o`000?l00000<c<c0_l0000301TI6E?o0000
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`08o`0000050000000I6AT06ATI01TI6Ol00000
0P0c<c<02_l00000C4a<o`00001VIVKo000007moOol00000VIVI0000002c/k<2o`0000030<c<c?l0
0000i^KV0080i^KV0_l000030>KViPGo000000P0VIVIo`00001oOgoo000006IVI_l00000C4a<o`00
0080<c<c00?o000001TI6@0I6AT00P0I6AT00`00003o0000o`00001Ao`0000?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool02?l0000401TI6@0<o`00000c<c<0<c<co`00001<C4co000006IVI_l0
0000Ogmoo`00002IVIT000000`2c/k<00ol00000c<c<o`000002o`000080i^KV1?l00000202c/k<0
00000000002IVIWo000007moOol00000IVIV0ol0000303<c<`05o`00000I6AT06ATI01TI6@000000
E?l00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000ooo
ool00`00003oooooooooo`0aooooo`03o`000?oooooooooo00Oo000000<0000001TI6@0I6AT00P0I
6AT00ol00000<c<co`00000204a<C003o`00001VIVKo00000080Ogmo00?o000009VIV@0000000`2c
/k<01?l00000c<c<0<c<c03<c<`2o`0000030<c<c?l0003o0000008000000P2IVIT5o`00000404a<
C?l00000<c<c03<c<`;o00000`0I6AT00`00003o0000o`00001Co`0000?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool01_l000000`0000006ATI01TI6@0201TI6@04o`00000c<c<0<c<co`000080
C4a<00?o000006IVI_l000000P1oOgl00ol00000VIVI000000040;>c/`?o000000<0c<c<o`000?l0
00000P00000209VIV@?o000000D0IVIVo`00001<C4`0C4a<o`00000203<c<`03o`00000I6AT06ATI
00806ATIEol00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d0
00000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo00Ko000000<0000001TI6@0I
6AT00P0I6AT01?l00000<c<c03<c<ol0000204a<C003o`00001VIVKo00000080Ogmo0_l00000102I
VIT000000000000000030;>c/`0400000?l000000000000000So000000<0C4a<o`000?l000000P0c
<c<00ol000006ATI01TI6@0201TI6@0300000?l0003o000005Go00000oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`06o`0000030000000I6AT06ATI00806ATI00Co000003<c<`0c<c?o00000P1<
C4`01?l00000IVIV06IVI_l0000307moO`04o`00002IVIT0VIVI09VIV@<000000P2IVIT2o`000080
Ogmo1?l000000`1<C4co0000o`00000203<c<`;o0000100I6AT00`00003o0000o`00001Fo`0000?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`030000
0?oooooooooo037ooooo00?o0000ooooooooool01_l000000`0000006ATI01TI6@0201TI6@04o`00
000c<c<0<c<co`0000<0C4a<00Co000006IVIP1VIVKo00000`1oOgl8o`00000307moOol0003o0000
00?o00000P1<C4`00ol00000<c<c03<c<`02o`0000@06ATI0P00001Io`0000?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool01_l000000`0000006ATI01TI6@0201TI6@04o`00000c<c<0<c<co`00
00<0C4a<00Co000006IVIP1VIVH0IVIV0_l0000707moO`?o00000P1VIVH01Ol00000C4a<04a<C01<
C4co00000080<c<c00?o000001TI6@0I6AT00`0I6AT00`00003o0000o`00001Io`0000?ooooo00?o
0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooo
oooo037ooooo00?o0000ooooooooool01_l000000`0000006ATI01TI6@0201TI6@04o`00000c<c<0
<c<c03<c<`;o00000P1<C4`3o`000080IVIV3?l0000204a<C0;o000000<0<c<co`000?l000000`0I
6AT2000005go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=
000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`06o`0000030000000I6AT0
6ATI00806ATI00?o000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00204a<C0Wo00000`1<C4`4
o`00000303<c<ol0003o000000<06ATI0P00001Oo`0000?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000oooo
ooooool01_l000000`0000006ATI01TI6@0301TI6@03o`00000c<c<0<c<c00<0<c<c0ol0000:04a<
C0?o00000`0c<c<2o`0000@06ATIH_l00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
00000?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo00Ko
000000<0000001TI6@0I6AT0100I6AT00ol00000<c<c03<c<`0503<c<`[o00000`0c<c<3o`0000@0
6ATI0P00001Ro`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0
S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool01_l000000`0000006ATI
01TI6@0501TI6@?o00003P0c<c<3o`0000D06ATI0P00001To`0000?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o
0000ooooooooool01ol000000`0000006ATI01TI6@0701TI6@Co00001P0c<c<4o`0000H06ATI0P00
001Vo`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool02?l000000`0000006ATI01TI6@0:
01TI6@Ko0000200I6AT2000006So00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00
003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`09o`00
00800000500I6AT4000006[o00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0;o`0000<0
00003@0I6AT4000006ko00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooo
ooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0>o`0000<00000
0`0I6AT7000007;o00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Ao`0000<00000NOl0
0003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0
003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooooooo
ool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00`00003oooooooooo`1f000000h06ATI2@000003ooooo`0300000?oooooooooo037ooooo00?o
0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooo
oooo07800000500I6AT7000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=
o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0K`00000H01TI
6@H000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`1/000001`06ATI1@000003ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wo
oooo000Jooooo`0300000?oooooooooo06X00000300I6AT7000000/06ATI1@000003ooooo`030000
0?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0300000?oooooooooo06L00000200I6AT7000000L0<c<c0P00000:01TI6@@000000ooo
ool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00`00003oooooooooo`1T000000L06ATI00@00000o`000?l000000000400c
<c<00`0000006ATI01TI6@0701TI6@@000000oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`1R
00000003o`00000I6AT06ATI00<06ATI0`00000D03<c<`030000000I6AT06ATI00L06ATI10000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`0300000?oooooooooo064000001@0I6AT2000000L0<c<c2P00000703<c
<`030000000I6AT06ATI00H06ATI10000003ooooo`0300000?oooooooooo037ooooo00?o0000oooo
ooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo05l0
00001@0I6AT2000000D0<c<c1000000:04a<C08000001@0c<c<00`0000006ATI01TI6@0501TI6@D0
00000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`1J00000003o`0000000000000000@06ATI
0`00000303<c<`0400000?l0003o0000000000@0C4a<1P00000604a<C0030000000c<c<0<c<c00<0
<c<c00<0000001TI6@0I6AT0100I6AT5000000?ooooo00<00000ooooooooool0<Oooool00ol0003o
ooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0
FP00000501TI6@8000000`0c<c<3000000@0C4a<1000000606IVIP030000001<C4`0C4a<00<0C4a<
00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0401TI6@D000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00`00003oooooooooo`1I000000@06ATI0P00000403<c<`040000001<C4`0C4a<04a<C0@00000
2`1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT0
100I6AT5000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo
00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0F000000401TI6@030000000c
<c<0<c<c0080<c<c0P00000204a<C003o`0000000000IVIV00<0IVIV2?l0000406IVIP03o`00001<
C4`0C4a<0080C4a<00D0000003<c<`0c<c<0<c<c0000000601TI6@H000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00`00003oooooooooo`1F000000<06ATI00@00000o`0000000000<c<c1`0000000ol00000IVIV
06IVIP04o`0000P0Ogmo0_l0000306IVIP050000001<C4`0C4a<04a<C00000000`0c<c<00`000000
6ATI01TI6@0401TI6@03o`0000000000000000<000000oooool00`00003oooooooooo`0aooooo`03
o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooo
ooooo`1D000000@06ATI00<0000003<c<`0c<c<00P00000204a<C08000000`1VIVH<o`0000@0Ogmo
00Go000006IVIP1VIVH0IVIV0000000304a<C0050000000c<c<0<c<c03<c<`0000001@0I6AT70000
00?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool0DP00000401TI6@8000000P0c<c<00`000000
C4a<04a<C00200000080IVIV1_l0000909VIV@;o00000`1oOgl01?l00000IVIV06IVIP00000204a<
C0050000000c<c<0<c<c03<c<`0000001P0I6AT7000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooo
ooooool0C`0000000ol00000000001TI6@0201TI6@8000000P0c<c<00`00003o000004a<C0020000
0080IVIV1Ol0000309VIV@Oo0000102IVIT01?l00000Ogmo07moOol0000206IVIP040000001<C4`0
C4a<000000<0<c<c00?o000001TI6@0I6AT00`0I6AT8000000?ooooo00<00000ooooooooool0<Ooo
ool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000
ooooooooool0C`00000401TI6@030000000c<c<0<c<c0080000000<0C4a<0000000000000P1VIVH4
o`0000<0VIVI0ol000060;>c/`03o`00002IVIT0VIVI0080VIVI00Co000007moO`1oOgoo00000P1V
IVH010000000C4a<04a<C000000303<c<`030000000I6AT06ATI00<06ATI20000003ooooo`030000
0?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0300000?oooooooooo04h00000100I6AT010000000<c<c03<c<`00000204a<C0030000
001VIVH0IVIV00Co00000P2IVIT9o`0000@0/k>c00Go000009VIV@2IVIT0VIVIo`00000207moO`03
o`00001VIVH000000080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0201TI6@T0
00000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`1=000000@06ATI00@0000003<c<`0c<c<0
00000P1<C4`01P000000IVIVo`000?l00000Ogmoo`000080VIVI1Ol000060<c<c005o`00002c/k<0
/k>c0;>c/ol000000P2IVIT01?l00000Ogmo07moOol0000206IVIP040000001<C4`0C4a<000000<0
<c<c00<0000001TI6@0I6AT00P0I6AT:000000?ooooo00<00000ooooooooool0<Oooool00ol0003o
ooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0
B`00000401TI6@80000000L0<c<c000000000000C4a<00000?l00000IVIV00Wo00000`3<c<`2o`00
00D0c<c<00Oo00000;>c/`2c/k<0/k>co`00002IVIWo00000080Ogmo00?o000006IVIP0000000P1<
C4`01@000000<c<c03<c<`0c<c<0000000@06ATI2`000003ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oo
oooooooo04T000001@0I6AT010000000<c<c03<c<`00000204a<C0030000001VIVKo000000Go0000
00@0/k>co`000?l00000c<c<1?l000020>KViP03o`00003<c<`0c<c<0080c<c<00Wo00000;>c/`2c
/k<0/k>co`00002IVIWo000007moOol000000P1VIVH00`000000C4a<0000000303<c<`030000000I
6AT06ATI00806ATI30000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl0
0003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo04L000001P0I6AT0
1@000000<c<c000000000000C4a<008000001Ol000020;>c/`Go00001`3Vi^H01Ol00000c<c<0<c<
c03<c<co00000080/k>c00Go000009VIVOl00000Ogmoo`00000206IVIP030000001<C4co000000<0
<c<c00?o000001TI6@0I6AT00P0I6AT=000000?ooooo00<00000ooooooooool0<Oooool00ol0003o
ooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0
AP00000401TI6@0500000?l00000000003<c<`0000000P1<C4`020000000IVIVo`00001oOgoo0000
09VIVOl00000/k>c1?l000030>KViPCo0000103Vi^H02_l00000c<c<0<c<c?l00000/k>co`00002I
VIWo000007moOol0000206IVIP030000001<C4`0000000<0<c<c00<0000001TI6@0I6AT00P0I6AT0
0ol0000000000000000;000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=
o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0A@0000001Ol0
00006ATI01TI6@0I6AT0000000<0<c<c00T0000004a<C000003o000006IVI_l00000Ogmoo`00002I
VIT00ol00000103<c<co00000>KViP3Vi^H3o`0000<0oooo00?o00000>KViP3Vi^H00P3Vi^H03?l0
0000c<c<0<c<c?l00000/k>co`00002IVIWo000007moOol00000IVIV00000080C4a<00@0000003<c
<`0c<c<00000100I6AT?000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=
o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0A000000401TI
6@070000000c<c<0<c<c03<c<`000000C4a<0000000206IVIPOo000000<0c<c<o`00003Vi^H00_l0
00060?ooo`05o`00003Vi^H0i^KV0>KVi_l000000P3<c<`00ol00000/k>co`000002o`00000407mo
Ool00000IVIV00000080C4a<00@0000003<c<`0c<c<00000100I6AT@000000?ooooo00<00000oooo
ooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[o
oooo00<00000ooooooooool0@`00000401TI6@080000000c<c<0<c<c03<c<`000000C4a<0000001V
IVH3o`00000409VIVOl00000/k>co`000080c<c<00?o00000>KVi_l000002@3oool02?l00000i^KV
0>KVi_l00000c<c<o`00002c/k?o00000P2IVIT2o`00000506IVIP000000C4a<04a<C?l000000P0c
<c<00ol000006ATI01TI6@0201TI6A4000000oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`12
000000@06ATI00<0000003<c<`0c<c<00P0000002`1<C4`0000006IVI_l00000Ogmoo`00002IVIWo
00000;>c/ol00000c<c<00;o000000<0i^KVo`00003oool02@3oool02?l00000i^KVo`00003<c<co
00000;>c/ol00000VIVI0ol000001@1VIVH0000004a<C01<C4`000000080<c<c00<0000001TI6@0I
6AT00P0I6ATB000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0@@00000501TI6@030000
000c<c<000000080C4a<00<0000006IVI_l000000P1oOgl01_l00000VIVIo`000?l00000c<c<o`00
0080i^KV00?o00000?ooo`3oool0203oool02Ol00000i^KVo`00003<c<co00000;>c/ol00000VIVI
o`00000207moO`05o`00001VIVH0000004a<C00000000P0c<c<00`0000006ATI01TI6@0301TI6A80
00000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`10000000D06ATI00P0000003<c<`0c<c<0
000004a<C0000000IVIVo`000080Ogmo00Co000009VIVOl00000/k>c0_l000020>KViP03o`00003o
ool0oooo00P0oooo00[o00000>KVi_l00000c<c<o`00002c/k?o000009VIVOl00000Ogmo0_l00000
101VIVH0000004a<C000000203<c<`030000000I6AT06ATI00<06ATI4`000003ooooo`0300000?oo
oooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`0300000?oooooooooo03l000001@0I6AT01P000000<c<c03<c<`000000C4a<00000080IVIV
00Ko000007moOol00000VIVIo`00002c/k<2o`000080i^KV00?o00000?ooo`3oool0203oool02ol0
0000i^KVo`00003<c<co00000;>c/ol00000VIVIo`00001oOgoo00000080IVIV00<0000004a<C?l0
00000P0c<c<00`0000006ATI01TI6@0301TI6A@000000oooool00`00003oooooooooo`0aooooo`03
o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooo
ooooo`0n000000@06ATI0P00000203<c<`040000001<C4`0000006IVIPCo000000P0VIVIo`00002c
/k?o00000<c<c?l00000i^KVo`0000L0oooo1_l000000`3<c<co0000o`000003o`00000307moOol0
0000IVIV0080000000<0C4a<0000000c<c<00P00000401TI6@0300000?l00000000001<000000ooo
ool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00`00003oooooooooo`0m000000@06ATI00T0000003<c<`0c<c<00000o`00
001<C4`0000006IVI_l000000P1oOgl01ol00000VIVIo`00002c/k?o00000<c<c?l000000P3Vi^H0
0ol00000oooo0?ooo`030?ooo`;o00000P3Vi^H2o`000080c<c<0_l000000`2IVIWo000007moO`02
o`00000706IVIP000000C4a<04a<C0000000<c<c0000000501TI6AL000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00`00003oooooooooo`0l000000@06ATI00@0000003<c<`0c<c<000000P1<C4`00`000000IVIV
o`00000207moO`07o`00002IVIWo00000;>c/ol00000c<c<o`0000040>KViP03o`00003oool0oooo
00;o00000`3Vi^H00ol00000c<c<0<c<c005o`00000607moOol00000IVIV06IVIP000000C4a<0P00
00000`0c<c<0000001TI6@0401TI6AP000000oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0k
000000@06ATI00@0000003<c<`0c<c<000000P1<C4`00`000000IVIVo`00000207moO`07o`00002I
VIWo00000;>c/ol00000c<c<o`0000060>KViP;o00000`3Vi^H2o`0000030<c<c?l0003o000000?o
00000P1oOgl01_l00000000000000?l00000C4a<00000080<c<c00?o000001TI6@0I6AT00P0I6AT0
0`00003o00000000000G000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=
o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0>`00000301TI
6@050000000c<c<0<c<c03<c<`0000000P1<C4`01@000000IVIVo`00001oOgoo00000080VIVI00?o
00000;>c/ol000000P3<c<`00ol00000i^KV0>KViP050>KViP?o000000D0c<c<o`000?l0003o0000
09VIV@02o`00000407moOol0003o0000000000<0C4a<00@0000003<c<`0000000000100I6ATK0000
00?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool0>P00000301TI6@050000000c<c<0<c<c03<c
<`0000000P1<C4`01@000000IVIVo`00001oOgoo00000080VIVI00Co00000;>c/`2c/k?o00000`3<
c<`00ol00000i^KV0>KViP04o`000080c<c<1?l000001`2IVIWo000007moO`1oOgoo000006IVIP00
00000P1<C4`20000000303<c<`0000006ATI00@06ATI70000003ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`030000
0?oooooooooo03T00000100I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00D0000006IVI_l0
0000Ogmoo`00000209VIV@04o`00002c/k<0/k>co`0000@0c<c<0_l000040<c<c0;o000000H0/k>c
o`00002IVIT0VIVIo`00001oOgl2o`00000506IVIP000000C4a<04a<C00000000P0c<c<00`000000
6ATI01TI6@0201TI6Ah000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go
00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0h000000@06ATI
00D0000003<c<`0c<c<0<c<c0000000204a<C0030000001VIVKo00000080Ogmo00?o000009VIVOl0
00000`2c/k<2o`0000D0c<c<1ol000000`2IVIWo0000o`000002o`000080000000Go000000000000
003o000003<c<`02000000@06ATI00?o000000000000000070000003ooooo`0300000?oooooooooo
037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
00000?oooooooooo03H0000000?o000001TI6@0I6AT00`0I6AT01@000000<c<c03<c<`0c<c<00000
0080C4a<00<0000006IVI_l000000P1oOgl00ol00000VIVIo`0000050;>c/`Go00000`2c/k<00ol0
0000VIVI09VIV@04o`00000506IVIP000000C4a<04a<C00000000P0c<c<2000000@06ATI8@000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`0300000?oooooooooo03L00000100I6AT01@000000<c<c03<c<`0c<c<0
00000080C4a<00@0000006IVIP1VIVKo00000P1oOgl01?l00000VIVI09VIVOl000090;>c/`?o0000
00<0VIVIo`000?l000000_l0000206IVIP040000001<C4`0C4a<00000080<c<c00<0000001TI6@0I
6AT00`0I6ATR000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0=P00000501TI6@050000
000c<c<0<c<c03<c<`0000000P1<C4`00`000000IVIVo`00000307moO`04o`00002IVIT0VIVI09VI
V@Wo00000P2IVIT2o`00000407moOol00000IVIV06IVIP8000000P1<C4`01@000000<c<c03<c<`0c
<c<0000000@06ATI8`000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl0
0003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo03D000001@0I6AT0
1@000000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVKo00000`1oOgl2o`0000P0VIVI
1Ol000000`1oOgoo0000o`00000;000000<06ATI9@000003ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oo
oooooooo03D000001@0I6AT010000000<c<c03<c<ol0000304a<C0050000001VIVH0IVIV06IVI_l0
0000101oOgl2o`000080VIVI1?l0000307moO`?o000000<0000004a<C01<C4`00P00000303<c<`03
0000000I6AT06ATI00<06ATI9`000003ooooo`0300000?oooooooooo037ooooo00?o0000oooooooo
ool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo03@00000
1@0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00<0000006IVIP1VIVH00P1VIVH00ol00000
Ogmo07moO`0307moO`;o0000101oOgl3o`00000306IVIP00000000000080C4a<00?o000003<c<`0c
<c<00P0c<c<00`0000006ATI01TI6@0301TI6@03o`0000000000000002D000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`00
6_ooool00`00003oooooooooo`0b00000003o`00000I6AT06ATI00@06ATI00D0000003<c<`0c<c<0
<c<c0000000304a<C0800000101VIVH00ol00000Ogmo07moO`0407moO`Co00000P1VIVH200000080
C4a<0P00000203<c<`80000000?o000001TI6@0I6AT00P0I6ATZ000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0<`00000601TI6@050000000c<c<0<c<c03<c<`0000001@1<C4`00`000000
IVIV06IVIP0206IVIPKo0000101VIVH20000000504a<C000000000000000000c<c<00`00000501TI
6B`000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0c000000H06ATI00D0000003<c<`0c
<c<0<c<c0000000604a<C0030000001VIVH0IVIV00L0IVIV1`00000303<c<`030000000I6AT06ATI
00@06ATI;P000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003oooo
o`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo038000001P0I6AT00`000000
<c<c03<c<`0203<c<`030000001<C4`0C4a<00D0C4a<2@00000304a<C0030000000c<c<0<c<c00<0
<c<c00?o000001TI6@0I6AT0100I6AT00ol0000000000000000/000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0<P00000601TI6@030000000c<c<0<c<c00<0<c<c0`00000=04a<C0<00000
100c<c<2000000D06ATI<@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo038000001P0I
6AT00`000000<c<c03<c<`0603<c<`<000000`1<C4`7000000@0<c<c0`00000401TI6C@000000ooo
ool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00`00003oooooooooo`0a000000P06ATI00<0000003<c<`0c<c<0200c<c<3
000000L0<c<c1000000601TI6CD000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooo
oooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0a0000
00T06ATI0P00000>03<c<`@000001`0I6AT200000003o`0000000000000003<000000oooool00`00
003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Ioooo
o`006_ooool00`00003oooooooooo`0a000000/06ATI00<0000003<c<`0c<c<0200c<c<3000000P0
6ATI>`000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo038000002`0I6AT:000000X06ATI
?0000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`00
0?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo038000007@0I6ATn000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00<00000ooooooooool0<`00000G01TI6@<0000000?o0000000000000000?@000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`0300000?oooooooooo03<0000000?o00000000000I6AT04@0I6AU60000
00?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool0=P00000=01TI6DX000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`00
6_ooool00`00003oooooooooo`0i000000H06ATICP000003ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oo
oooooooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000
ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000oooo
ooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d0
00000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0
<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<0
0000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl0
0003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0
003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooooooo
ool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0aoooo
o`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`030000
0?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=
000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000
ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo
037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
00000?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go
00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2@ooooo`030000
0?oooooooooo037ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Iooooo`006_oo
oonD000003?oooooU?l0000Kooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00QOooool2o`000<Gooooo0_l00012ooooo`00P_ooool3o`000003ooooool0003o
oooo0<7ooooo0ol000000ooooooo0000ooooo`11ooooo`00P?ooool2o`0000;ooooo0_nY_NP2o`00
0;oooooo0_l00002ooooo`;oZKgX0_l00011ooooo`00OOooool3o`000003oooooonY_NSoZKgX00?o
ZKgX00?o0000ooooool00000^oooool3o`000003oooooonY_NSoZKgX00?oZKgX00?o0000ooooool0
0000@?ooool007[ooooo0ol00003ooooo`KoZKgX00?o0000ooooool00000^?ooool3o`0000?ooooo
1_nY_NP00ol0003oooooo`000010ooooo`00N?ooool2o`0000Cooooo2?nY_NP01?l0003oZKgXoooo
ool0002eooooo`;o00000oooool9ojVmj004o`000?nY_NSoooooo`0003oooooo001eooooo`?o0000
0_ooool<ojVmj005o`000?nY_NSoZKgXooooool00000/Oooool3o`0000;ooooo3?nY_NP01Ol0003o
ZKgXojVmj?oooooo000003kooooo001cooooo`;o00000_ooool?ojVmj005o`000?nY_NSoZKgXoooo
ool00000[oooool2o`0000;ooooo3onY_NP01Ol0003oZKgXojVmj?oooooo000003kooooo001`oooo
o`?o00000oooool@ojVmj006o`000?nY_NSoZKgXojVmj?oooooo0000Zoooool3o`0000?ooooo4?nY
_NP01_l0003oZKgXojVmj?nY_NSoooooo`0003gooooo001^ooooo`;o00001?oooolBojVmj006o`00
0?nY_NSoZKgXojVmj?oooooo0000ZOooool2o`0000Cooooo4_nY_NP01_l0003oZKgXojVmj?nY_NSo
ooooo`0003gooooo001[ooooo`?o00000_oooolFojVmj003o`000?nY_NSoZKgX00;oZKgX00?ooooo
o`000?ooool0Y?ooool3o`0000;ooooo5_nY_NP00ol0003oZKgXojVmj002ojVmj003ooooool0003o
oooo03_ooooo001Xooooo`?o00000_oooolIojVmj003o`000?nY_NSoZKgX00?oZKgX00?oooooo`00
0?ooool0X?ooool3o`0000;ooooo6OnY_NP00ol0003oZKgXojVmj003ojVmj003ooooool0003ooooo
03[ooooo001Vooooo`;o00001?oooolKojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000oooooooo
ool0WOooool2o`0000Cooooo6onY_NP00ol0003oZKgXojVmj002ojVmj003ooooool0003ooooo03[o
oooo001Sooooo`?o00001?oooolMojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ooooooooool0
VOooool3o`0000Cooooo7OnY_NP00ol0003oZKgXojVmj003ojVmj003ooooool0003ooooo03Wooooo
001Qooooo`;o00001?oooolPojVmj003o`000?nY_NSoZKgX00CoZKgX00?oooooo`000?ooool0Uooo
ool2o`0000Cooooo8?nY_NP00ol0003oZKgXojVmj004ojVmj003ooooool0003ooooo03Sooooo001N
ooooo`?o00000_oooolTojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ooooooooool0Toooool3
o`0000;ooooo9?nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?oooooooooo03Oooooo001Loooo
o`;o00000_oooolWojVmj003o`000?nY_NSoZKgX00GoZKgX00?oooooo`000?ooool0TOooool2o`00
00;ooooo9onY_NP00ol0003oZKgXojVmj005ojVmj003ooooool0003ooooo03Oooooo001Iooooo`?o
00000ooooolXojVmj003o`000?nY_NSoZKgX00KoZKgX00?oooooo`000?ooool0SOooool3o`0000?o
oooo:?nY_NP00ol0003oZKgXojVmj006ojVmj003ooooool0003ooooo03Kooooo001Gooooo`;o0000
1?oooolZojVmj003o`000?nY_NSoZKgX00OoZKgX00?o0000ooooooooool0R_ooool2o`0000Cooooo
:_nY_NP00ol0003oZKgXojVmj006ojVmj003ooooool0003ooooo03Kooooo001Dooooo`?o00000ooo
ool]ojVmj003o`000?nY_NSoZKgX00OoZKgX00?oooooo`000?ooool0Qoooool3o`0000?ooooo;OnY
_NP00ol0003oZKgXojVmj007ojVmj003ooooool0003ooooo03Gooooo001Aooooo`?o00000oooool`
ojVmj003o`000?nY_NSoZKgX00SoZKgX00?oooooo`000?ooool0Poooool3o`0000?ooooo<?nY_NP0
0ol0003oZKgXojVmj008ojVmj003ooooool0003ooooo03Cooooo001?ooooo`;o00000ooooolcojVm
j003o`000?nY_NSoZKgX00SoZKgX00?oooooo`000?ooool0POooool2o`0000?ooooo<onY_NP00ol0
003oZKgXojVmj008ojVmj003ooooool0003ooooo03Cooooo001<ooooo`?o00000_oooolfojVmj003
o`000?nY_NSoZKgX00WoZKgX00?oooooo`000?ooool0OOooool3o`0000;ooooo00?oZKgWojVmj?nY
_NP0<onY_NP00ol0003oZKgXojVmj009ojVmj003ooooool0003ooooo03?ooooo001:ooooo`;o0000
1?oooolgojVmj003o`000?nY_NSoZKgX00[oZKgX00?o0000ooooooooool0N_ooool2o`0000Cooooo
0onY_NL3ojVmj003ojVmionY_NSoZKgX02koZKgX00?o0000ojVmj?nY_NP02_nY_NP00ol0003ooooo
ooooo`0booooo`00Aoooool3o`0000Cooooo>OnY_NP00ol0003oZKgXojVmj00;ojVmj003o`000?oo
oooooooo07Kooooo0ol00004ooooo`03ojVlionY_NOoZKgW00;oZKgW00?oZKgXojVmionY_NL00_nY
_NL_ojVmj003o`000?nY_NSoZKgX00_oZKgX00?o0000ooooooooool0<Oooool004Gooooo0_l00004
oooooccoZKgX00?o0000ojVmj?nY_NP02onY_NP00ooooooo0000ooooo`1dooooo`;o00001?ooool5
ojVli`;oZKgW0_nZ_NL4ojVmibooZKgX00?o0000ojVmj?nY_NP02onY_NP00ooooooo0000ooooo`0a
ooooo`00@_ooool3o`0000?ooooo?onY_NP00ol0003oZKgXojVmj00<ojVmj003o`000?oooooooooo
073ooooo0ol00002ooooo`;oZK_V1_nY_>L2ojZliPCoZ[gW0_nY_NL2ojZmibkoZKgX00?o0000ojVm
j?nY_NP03?nY_NP00ol0003oooooooooo`0`ooooo`00?oooool3o`0000?ooooo@_nY_NP00ol0003o
ZKgXojVmj00<ojVmj003ooooool0003ooooo06gooooo0ol00002ooooo`KoZK_V0_nY_>L2ojZki@Co
Z[cV0_nZ_NL2ojZli`CoZ[gW0_nY_NP2ojZmj2WoZKgX00?o0000ojVmj?nY_NP03?nY_NP00ooooooo
0000ooooo`0`ooooo`00?Oooool2o`0000?oooooAOnY_NP00ol0003oZKgXojVmj00;ojVmj0;oZKcW
00?oooooo`000?ooool0J_ooool2o`0000?ooooo1onY^nH2ojZii0CoZ[_U0_nZ_>H2oj^ki@CoZ[cW
1?nZ_NL4ojZmj2SoZKgX00?o0000ojVmj?nY_NP03OnY_NP00ooooooo0000ooooo`0_ooooo`00>_oo
ool3o`0000;oooooB?nY_NP00ol0003oZKgXojVmj008ojVmj0KoZKcW00?o0000ooooooooool0I_oo
ool3o`0000Cooooo0_nY^^H3ojVkiP03ojVghonZ^NCoZ[WT00?oZ[WT0_nZ^nD2oj^ih`CoZk_U0_nZ
_>L2oj^mi`CoZ[gW1?nZ_NPWojVmj003o`000?nY_NSoZKgX00koZKgX00?o0000ooooooooool0;_oo
ool003Sooooo0_l00004ooooodWoZKgX00?o0000ojVmj?nY_NP01OnY_NP00onY_NOoZKcWojVli`05
ojVli`03ojVki_oooooo000006Gooooo0_l00005ooooo`GoZK[V00CoZK_VojVghonY]n?oZKOS0onZ
^N@00on[]^7oZkWSoj^ih`03oj^ih`;oZk_U0_n/_>D4oj^mi`;oZ[gW0_n[_^L4ojZmj2KoZKgX00?o
0000ojVmj?nY_NP03_nY_NP00ooooooo0000ooooo`0^ooooo`00=Oooool3o`0000CoooooBonY_NP0
0ol0003oZKgXojVmj003ojVmj0CoZKgW0_nY_>L6ojVkiP03ooooool0003ooooo063ooooo0ol00004
ooooo`OoZK[V0_nY]N44ojVgh`04ojZii?n[]^7oZkKQoj^fh@?oZkWS00?o[[WRojbliOn/_>D00on/
_>D2oj^mi`;o[;kW1?n[_^L3ojZmj2KoZKgX00?o0000ojVmj?nY_NP03onY_NP00ooooooo0000oooo
o`0]ooooo`00<oooool2o`0000CoooooC_nY_NP00ol0003oZKgXojVmj004ojVmj0;oZKgW2?nY^nH2
ojVhi003o`000?oooooooooo05gooooo0_l00004ooooo`;oZK_V1OnY^^H2ojRch@CoZKGQ0_nY]n<2
oj^ag@CoZkKQ00CoZkWSojjih_n^^N;o[[WR0on/_>D2ojjmi@Co[;kW0_n[_^L00on[_^SoZ[gXojZm
j002ojZmj2GoZKgX00?o0000ojVmj?nY_NP03onY_NP00ooooooo0000ooooo`0]ooooo`00<?ooool3
o`0000?oooooDOnY_NP00ol0003oZKgXojVmj003ojVmj0;oZKcW1_nY^nH00onX]nCoZKSTojVhi003
ojVhi003o`000?oooooooooo05Wooooo0ol00003ooooo`;oZK_W1?nY^nH00onY^^KoZ;?QojRch@04
ojRch@;oZKGQ00?oZJcIoj^agOn[/Md00on[/Md2oj^fh@;o[kCM1?n^^N800on/_>Go[[gUojjmi@02
ojjmi@;o[;kW00?o[;oWoj^nj?n[_^P00_n[_^P4ojZmj2CoZKgX00?o0000ojVmj?nY_NP04?nY_NP0
0ooooooo0000ooooo`0/ooooo`00;Oooool3o`0000?oooooE?nY_NP00ol0003oZKgXojVmj006ojVl
i`;oZK_V00?oZ;STojRgi?nX]n@00_nX]n@2ojVhi0;oZK?P00?o0000ooooooooool0E_ooool3o`00
00?ooooo0_nY_>L4ojVki`;oZK_V00?oYkCRojRchOnX/n401?nX/n400onWZ=OoZJcIojV/f@02ojV/
f@?oZk7M00?o[ZgFojndgOn_]=d00on_]=d2ojjihP;o/KcQ0on^_ND00on``>Ko[;oWojboi`02ojbo
i`CoZkkX1?nZ_NPSojVmj003o`000?nY_NSoZKgX017oZKgX00?o0000ooooooooool0:oooool002_o
oooo0_l00003oooooeOoZKgX00?oZKcWo`000?nY_>L01?nY_>L2ojRhi@CoZ;ST0_nX]n@00onX/]oo
ZK?PojVch003ojVch003o`000?oooooooooo05?ooooo0_l00003ooooo`KoZKcW0_nY^nL00onW]^?o
YkCRojNdhP02ojNdhP;oZ;?Q00?oYJGFojNXeonWZ=L00_nWZ=L4ojV/f@04oj^agOn^[MKo[ZgFojj]
eP?o[kCM0_nd]m/4ok6lh@04ojjmiOn``>Ko/<3Vok30iP;o[;oW0_n/_nP4oj^nj0;oZ[gX9OnY_NP0
0ol0003oZKgXojVmj00AojVmj003o`000?oooooooooo02[ooooo000Xooooo`?o00000_oooomHojVm
j0?oZKcW00Co0000ojVlionY_>OoZ;WU1OnX^>D2ojRhi003ojNagonX/]ooZ;;O00;oZ;;O1?nY/n00
0ooooooo0000ooooo`1@ooooo`?o00000_ooool2ojVmj0KoZKcW00?oZ;STojNfhonW]^<00_nW]^<2
ojNdhP03ojBUe_nUYMKoYJGF00;oYJGF1?nWZ=L2ojV/f@;oZjC@1?n^[MH00on_]=go];OKokBgf`02
okBgf`;o/KcQ00?o]L3Rok30i_n``>H00_n``>H00on/_nOo[;oXojboj002ojboj0;oZkkX0_nZ_^PV
ojVmj003o`000?nY_NSoZKgX017oZKgX00?oooooo`000?ooool0:_ooool002Kooooo0_l00002oooo
oecoZKgX0_nY_>L00ol0003oZ;WUojRii@02ojRii@CoZ;SU00CoZ;STojNagonW/MooYk7O1?nX/]l2
ojVch003ojZ`g?oooooo000004oooooo0_l00002ooooo`KoZKgX0_nY_>L00onX^^KoZ;STojRhi002
ojRhi0?oYkKS00CoYkCRojBUe_nTYMKoY:GF1?nUYMH2ojNXe`03ojNKbOn[Y=3oZjC@00?oZjC@0_n^
[MH2okF^dP?o];OK00?o^kkLokG0h_ne`>800_ne`>82ok30iP;o/<;W1On/_nP4ojZnj2GoZKgX00?o
0000ojVmj?nY_NP04_nY_NP00ol0003oooooooooo`0Yooooo`008oooool3o`0000?oooooGOnY_NP0
1?nY_>OoZK[Vo`000?nY^^H4ojRii@;oZ;SU1_nW/Ml2ojRbg`03ojR/fOnZ/=coZ[3L00;oZ[3L00?o
ooooo`000?ooool0B_ooool3o`0000?ooooo1_nY_NP00onY^nOoZ;[VojRjiP02ojRjiPCoZ;ST00?o
YkKSoj>Wf?nTYMH01?nTYMH2ojFUeP03oj>DaOnWVlWoYi_900;oYi_90on[Y=000onbX/So]JkBokF^
dP03okF^dP04okBgfonk_]co^kkLok^ng0;o]L3R0_ngaN@4ok32i`Go[;oX0onZ_^PUojVmj003o`00
0?nY_NSoZKgX01;oZKgX00?oooooo`000?ooool0:Oooool0027ooooo0_l00004oooooekoZKgX0_nY
^nL01?nY^^Ko0000ojVji_nY^^H2ojRii@03ojNchOnW/MooYk7O00CoYk7O0_nWZ=P4ojR/f@;oZ[3L
0_n^/=T00ooooooo0000ooooo`17ooooo`;o00001?ooool5ojVmj003ojVlionY^nOoZK_W00;oZK_W
1?nX^^H2ojRhi004ojB[g?nSYmSoXjOHoj>Wf0?oY:GF00?oWXo4oj>DaOnSU<D00_nSU<D4ojNKb@04
oj^Td?nbX/So/Z;8ok:Rb0?o]JkB00Co_kOAok^ng?nk_]co^kkL0_o1aml4okO5i0;o/<;W0_n_`^P3
ojboj003oj^nj?nZ_^SoZ[kX00;oZ[kX9?nY_NP00ol0003oZKgXojVmj00CojVmj003ooooool0003o
oooo02Sooooo000Nooooo`?o00001?oooomMojVmj0;oZKcW1?nY^nL00ol0003oZK[VojNdhP04ojNc
h@;oYk7O00?oYJOGojNXf?nWZ=P00onWZ=P2ojR/f@03oj^Xe?n^/=Wo[[3I00?o[[3I00?o0000oooo
ooooool0@oooool3o`0000Cooooo1_nY_NP3ojVli`CoZK_W0_nX^^H2ojF_g`?oY:_L0onSYmP01?nT
YMKoWXo4oij?a?nNSl@3oj>Da@?oYi_900?o[9Fook:Rb?nbX/P00onbX/P01One[];o_kOAokngdOno
]m7o^kkL00Co`LOO0_ngaN@2okK7i`Co[l;X00Co[;oXoj^nj?n[_^SoZkkX0_nZ_^PUojVmj003o`00
0?nY_NSoZKgX01CoZKgX00?o0000ooooooooool09oooool001cooooo0_l00004oooooegoZKgX00?o
ZKgWojVlionY_>L00onY_>L2ojVki`03ojRgi?l0003oYkCR00;oYkCR0_nW/n400onTYmSoYJOGojFW
e`02ojFWe`CoYjSH00CoZ:cIoj^Xe?n[Z=CoZjSD0on^/=T00ond]MWoooooo`000012ooooo`;o0000
1?ooool9ojVmj0CoZKcW0_nY^nL2ojJdh`CoYJoO00?oY:_Loi^AbOnLS/D00_nLS/D4oij?a0CoXiC5
00CoYi_9ojbE_on/UKoo[9Fo1?nbX/P4okngd@04ol_6eOo1amoo`LOOol77g`;o`loS1?nfanL2ojo2
j004ojg1j?n[_^SoZkkXoj^nj0;oZ[kX9_nY_NP00ol0003oZKgXojVmj00EojVmj003o`000?oooooo
oooo02Kooooo000Iooooo`?o00000ooooomNojVmj0CoZKgW0_nY_>L2ojRii@?oZ;OT00Co0000ojNd
h_nW]>;oY:WJ1?nTYmP4ojFWe`;oYjSH00?oYj;@oj^Xe?n[Z=@00on[Z=@01_n^/=Wo];GIokBefOnd
]MWoooooo`0003kooooo0ol00003ooooo`goZKgX0_nY_>L2ojNhi@CoY[CS0_nU[ml01?nLV<ooVi79
oi^AbOnKTLT3oib>a@?oWXo40onSU<D00onTR;Oo[9FoojbE_`02ojbE_`?o/Z;80_nnZ/H2okngd@?o
blKE00?o`LOOol??hoo3cn<00_o3cn<2okK7i`03ok?6j?n]`NSo[L7X00;o[L7X00?oZkkXojZnj?nZ
_^P00_nZ_^PUojVmj003o`000?nY_NSoZKgX01GoZKgX00?oooooo`000?ooool09_ooool001Kooooo
0ol00003ooooof;oZKgX0_nY_NL2ojRjiPCoZ;WU0_nX]n@00ol0003oY:WJojBYfP02ojBYfPCoY:OH
0_nUYmL00onTW<koYj;@ojNRd002ojNRd0?oZjSD00?o/JcBokBefOnd]MT00_nd]MT00ooooooo0000
ooooo`0jooooo`?o00000oooool?ojVmj0;oZ;_V1?nW^>D2ojJdh`04oijQeonLV<ooW9S?oibHc`?o
Vi790onLS/D4oij?a004oj>DaOnTR;OoY8RgojB8]`Co[9Fo00Go/Z;8okjZa_nnZ/Ko_Z[6okngd@04
ol_6e@04om?Ef_o3cn?o`loSol??h`;o_m3W0onca^P2ojg1j0?o[;oX0_nZ_^P2ojZmj2CoZKgX00?o
0000ojVmj?nY_NP05_nY_NP00ol0003oooooooooo`0Uooooo`005?ooool2o`0000CoooooHonY_NP2
ojVli`CoZ;[V0_nX^ND01OnU/>3oYJcMojF/gOl0003oYJcM00CoY:WJ0_nTYmP00onQVLgoY9c>ojBL
cP02ojBLcP?oYj;@00?oZjSDok6/d_na[=800_na[=82okBef@04okg1g?ooooooooooo`0003Sooooo
0_l00003ooooo`ooZKgX0_nY_>L4ojRkiP;oYkSU00?oXZ_MoijQeonNXML00_nNXML3oibHc`;oVi79
1?nLS/D2oij?a003oiao/onTR;OoY8Rg00;oY8Rg0on/UKl00ongV[[o_Z[6okjZaP02okjZaP04olnm
b?o;a]GoblKEol_6e@?odmGJ00?o`loSoko@ionod>L00_nod>L00onca^So[l?Yojo3j@03ojboj0;o
Z[kX1?nZ_NPSojVmj003o`000?nY_NSoZKgX01KoZKgX00?oooooo`000?ooool09Oooool0017ooooo
0ol00003ooooof?oZKgX1_nY_>L2ojRjiP03ojNdh_nU/>3oYK3P00;oYK3P0_l00002ojF/g@;oY:WJ
00?oWiW=oj6IcOnQVLd00_nQVLd3ojBLcP;oYj;@0_n/XL`3ok6/dP03okbgeOnm`Mco_L7L00;o_L7L
0_ooool00ol0003oooooooooo`0booooo`?o00000ooooolAojVmj0?oZKcW0_nX^nH2ojFchP?oXZ_M
1?nNXML2oibHc`?oVi790_nLS/D00onENK7oW7ncoiao/`02oiao/`CoY8Rg00Co[9FookNJ^_ngV[[o
]iZj0_nnZ/H3olnmb004ol_6eOoCeM[odmGJom?EfP?odMgQ0_nod>L00onhc>Wo[l?Yojo3j@02ojo3
j@03ojboj?nZ_^SoZ[kX00;oZ[kX0_nZ_NPSojVmj0;o00006OnY_NP00ooooooo0000ooooo`0Toooo
o`004?ooool2o`0000;oooooIOnY_NP6ojVli`03ojNhi?nW]>;oYkCR00;oYkCR0ol000001?nOVm3o
0000oinKd?nOVm04oinIc@?oXIW=0_nTW<h00onVUlKo[:7<ojbQc003ojbQc004ok6/d_nl]mGo_;OE
okbge@;o_L7L0oo5cn800ol0003oooooooooo`0aooooo`;o00000_oooolEojVmj003ojVlionW^>Go
YkSU00CoYK?R0onRZmd2oijQe`03ohn2`On>NKSoSWVh00?oT7Jc1?nENK43oiao/`CoY8Rg1?ngV[X0
0onnZ/Kockg8olnmb002olnmb0;ogmG=00GodmGJom7MhOoAgN7odMgQolSKi`04okS<j@;o[l?Y0on/
`>P3ojZnj2;oZKgX0ol000000onY_NSo0000ojVmj00IojVmj003o`000?oooooooooo02?ooooo000@
ooooo`03o`000?nY_NSoZKgX06OoZKgX0_nY_>L00onX^^KoYkSTojNhi002ojNhi0?o00001?nPX=@0
1?nOVm3o0000oinKd?nOVm03oinIc@;oXIW=00?oXHo2ojJGa_nVUlH00_nVUlH3ojbQc003okNZc?nl
]mGo_;OE00;o_;OE00Oo_L7LolG?h_o5cn;oaLoRolSIi_oooooo000003;ooooo00?o0000ojVmj?nY
_NP05OnY_NP2ojRki`?oYkSU0_nU/n801?nJW]KoTho<oi>?c?nCSl`3ohn2`@?oSWVh0on@M[<3oiEi
/@?oW7nc0onTR;L00on]R[7o]iZjokNJ^P02okNJ^P04olb^_?o?_LSockg8olnmb0?ogmG=0_oUj=80
1?oAgN7ob=_WolSKioo8fnL2okS<j@;o/LKY0on/`>P00on[_^SoZ[kXojZnj002ojZnj1koZKgX0ol0
0005ojVmj003o`000?nY_NSoZKgX01SoZKgX00?o0000ooooooooool08_ooool0013ooooo00?o0000
ojVmj?nY_NP0I_nY_NP00onY^nOoZ;[VojRjiP02ojRjiP?o00001?nRY]T3oj2Pe0;oWi_@00Go0000
oinKd?nOVLgoWiW=oib;`004oj6?`PCoYYO600Co[:7<okNZc?ngZ/co]j[<0_nl]mD3olW:fP05olG?
h_o8fNKob=WVolSIi_l00000<_ooool00ol0003oZKgXojVmj00BojVmj0;oZKcW1?nX^nL00onW^>Go
X:_NoiZNeP03oiZNeP;oTho<0on?P/43ohii^0?oT7Jc0onENK44oiao/`04ojB8]on]R[7o[HZaojf:
/@?o]iZj0_o<[[`00oo?_LSogmG=omoEc@02omoEc@;oiNSB0oo8fnL2okcAjPCo/LKY00Co[<3Xoj^n
j?n[_^SoZkkX0_nZ_^PLojVmj0?o00002OnY_NP00ol0003oZKgXojVmj00GojVmj003o`000?oooooo
oooo02;ooooo000@ooooo`03o`000?ooooooZKgX06?oZKgX00?oZKcWojVkionY^nL00_nY^nL3o`00
0004ojFbhOnT[=goY:cMojB/g@CoXZKI0onPX=@2oinKd003o`000?nLRl3oW8_000;oW8_00onQSl83
ojJGaP03ojnK`ongZ/co]j[<00;o]j[<00?o_;OEolW:f_o9b]X00_o9b]X3olSIiP;oa=_Z00?o0000
ooooooooool0;oooool00ol0003oooooojVmj00AojVmj0CoZKcW0_nX^nL01?nT]>CoX:_Noj2[g_nP
Zmh3oiZNeP?oTho<0on?P/42ohii^0?oT7Jc1?nENK42oiao/`03oj5kZ_n]R[7o[HZa00;o[HZa0_ng
V[X3olb^_004onC<_ooOeLgogmG=omoEc@;oiNSB0_oNk]`00oo8fnOo_=7ZokcAjP02okcAjP;o/LKY
0on]`NT00on[_^SoZ[kXojZnj00JojVmj0?o00003OnY_NP00ol0003oZKgXojVmj00GojVmj003o`00
0?oooooooooo027ooooo000?ooooo`04o`000?ooooooooooooooof7oZKgX1?nY_>L3o`000003ojNg
i?nU/^7oYK;Q00;oYK;Q0onT[=d2oj:Vf@04oiV@bOnHRlCoV8_4oiR;a0;oVHW100?o0000oiV9`OnL
Rl000_nLRl04oj6?`P04ojJGa_n_Vl?o[i_3ojnK``;o]j[<0_o8_]43olW:fP;odmkP00Kob=WVolCK
j_o4fn[o_MK/ooooool0000_ooooo`04o`000?oooooooooooooooa;oZKgX0_nY_>L2ojNiiP?oY;CT
0onPZmh3oiZNeP;oTho<0on?P/43ohii^0?oT7Jc0onENK400onLOk?oXG^Zoj5kZP04ojf:/@03okNJ
^_o<[[coc:jl00;oc:jl0_oTc;l00ooOeLgoiNSBonGXdP02omk^g0?ocnKW0_nldNX2ok;7jP?o[L7Y
00?oZkoXojZnj?nZ_^P00_nZ_^PFojVmj0?o00004?nY_NP00ol0003oZKgXojVmj00GojVmj003oooo
ool0003ooooo027ooooo000?ooooo`03o`000?oooooooooo00;oooooHOnY_NP3o`000003ojRji_nW
]nCoYkOT00;oYkOT0_nU/^401?nNXMKoViS?oi^HconKV<l3oiV@b@CoV8_40_nIRL400ol0003oW8_0
oib;`002oib;`0;oXHo200?oYXjlojnK`on_Vl<00_n_Vl<00ongZ/cob;kAolRnd@02olRnd@03olW:
f_oCg^3odmkP00;odnSU00Goa=_ZokgFk?nme^co_MK/o`00000_ooooo`03o`000?oooooooooo00;o
oooo4?nY_NP2ojRli`CoYkWV00?oY;CToiVRfon>S/l00_n>S/l3ohAj`0;oOV^c0omnHjT3ohii^0?o
T7Jc0_nENK401?nEKjGoXG^Zoj5kZ_nQNjX4ojf:/@Coc:jl0ooTc;l2oo;Y_`03onkg`OoNk]cocnKW
00;ocnKW0_nneN/4ok;7jP04ojg1jOn[_nSoZkoXoj^oj0;oZ[kX5?nY_NP3o`0001CoZKgX00?o0000
ojVmj?nY_NP05onY_NP00ol0003oooooooooo`0Pooooo`003oooool00ol0003oooooooooo`03oooo
oegoZKgX0ol000000onY_>OoZ;[VojRjiP02ojRjiP;oYkOT00CoXZ[LoijQe_nNXMKoWZ7F0onKV<l4
oiV@b@?oV8_40onIRL401?l0003oW8_0oib;`?nMQ;P3ojJ>_0Co[i_31Oo8_]401?oJf]OodmkPom?X
iOoCj>D2ol_WjP;o_MK/0_necN`00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00?ooooo
3_nY_NP4ojRli`;oYkWV00CoXK3RoiVRfonIX]_oVJ;K0on>S/l2ohAj`0;oOV^c0omnHjT3oh9RY0?o
RVJS0onEKjD4oj5kZP?o[HZa00?o`I^aolb^_?o<[[`01?oTc;l2oo;Y_`04onkg`OoRn]?oh_[ColoV
i`Co_]G[0_nbanX2ojg1j@;oZkoX0_nZ_^PBojVmj0?o00006?nY_NP00ol0003oZKgXojVmj00FojVm
j003ooooool0003ooooo023ooooo000?ooooo`03o`000?oooooooooo00CoooooFOnY_NP3o`0000Go
ZKcW0_nX^^H00onU/^7oXZ[Loj:Zg002oj:Zg0?oWZ7F0onKV<l3oiV@b@CoV8_40_nIRL401?nGOKGo
0000oif4^?nMQ;P4ojJ>_0;o[i_30_o0[LL3olRnd@;of][G00GohO3Jom?XiOo;in[obnOZol3Lk@05
okG=k003o`000?oooooooooo02_ooooo00?o0000ooooooooool01?ooool>ojVmj0;oZ;cW0_nU]nH3
oj6`hP;oVJ;K0on>S/l2ohAj`0?oOV^c0_mnHjT3oh9RY0?oRVJS0onEKjD4oj5kZP;o[HZa0oo1Vk40
1?o<[[coi<boonC<_ooTc;l2oo;Y_`;ok_O100Coh_[Com7]iooAkNOodNgW0_nneN/2ok;8jP;o[L7Y
1_nZ_^P>ojVmj0?o00007?nY_NP00ol0003oZKgXojVmj00FojVmj003ooooool0003ooooo01oooooo
000?ooooo`03o`000?oooooooooo00GoooooE_nY_NP2o`000003ojVmj?nY_>OoZKcW00CoZKcW00?o
YkOTojFbhOnU/^400_nU/^43oj:Zg0?oWZ7F0onKV<l2oiV@b@03oi1k^?nBN[GoTWZe00;oTWZe0onG
OKD01?l0003oWHBhoif4^?nMQ;P3ojJ>_003ojnK`oo0[LOo`:g700;o`:g700?ob;kAom[JeooJf]L0
0_oQl=X00ooKn=kobnOZol3Lk@02ol3Lk@;o]Lg/0_n_aNX00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00Gooooo3?nY_NP2ojRki`CoYKOV0onQ/>82oiVRf`;oSXk?0on4N/02ogi[/`;oOV>Y
0on2HZ@3ohYVX`CoUFnU0onQNjX00on]R[7o`I^aol6K/@02ol6K/@03omnl]OoTc;ooi<bo00;ol^Vo
0_o^ml401?oRn]?odNgWom7]iooAkNL3okgFk003ok;8j_n/`NWo[<7Y00KoZ[kX3OnY_NP2o`0001oo
ZKgX00?o0000ojVmj?nY_NP05onY_NP00ol0003oooooooooo`0Nooooo`003oooool00ol0003ooooo
ooooo`06oooooe;oZKgX0ol00004ojVmj0;oZKcW00?oZ;[VojNgi?nW]n@00_nW]n@2ojFbh@04oibO
e_nGTlgoUi?=oiNCc@?oThO40on@Okd4oi1k^0?oTWZe0onGOKD01?nMQ;So0000oif4^?nMQ;P2ojJ>
_003okBJ_Oo0[LOo`:g700?o`:g700Gof<c=om[JeooQl=[ohO3Jom_hgP02om3aj0;o`=c]0_nfcnd4
ojo5jP03o`000?oooooooooo02[ooooo00?o0000ooooooooool01_ooool9ojVmj0;oZKcX0onX^nL2
ojFgiP04oib/h_n@VMWoT9WIoi2If@;oOh390omaI[L2ohAj`0;oOV^c0_mnHjT3oh9RY0?oRVJS1?nE
KjD3oj5kZPGo`I^a0_oO_;D01OoTc;ool^Vooo;Y_oo`lYooh?NS00;ogOk;00Goc^gYokgFk?nme^co
_MK/ok77jP04ojc1j@;oZ[kX0_nY_^P;ojVmj0?o00008_nY_NP00ol0003oZKgXojVmj00GojVmj003
o`000?oooooooooo01gooooo000>ooooo`03o`000?oooooooooo00SoooooC_nY_NP3o`0000KoZKgX
0_nY_>L3ojRjiP;oYkOT00?oXJ[MoibOe_nLWmH00_nLWmH3oiNCc@?oThO40on@Okd3oi1k^0?oTWZe
1?nGOKD01?nMQ;So0000oif4^?nVS[`3okBJ_@?o`:g70_oHc<d00ooZklgohO3Jom_hgP02om3aj0;o
`^7^1?nfcnd2ojo5jP;o[<7Y00?o0000ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`So
ZKgX0onY_>P00onX^nOoY;KVojBfiP03oib/hP;oT9WI0omoP<T2og5V]`;oJEFX0_mnJk<3ogiSZ@?o
PV:T0on:IZ<3oiE_Y@;oXG^Z0_naQjT3ol6K/@?ogkbe0_ohhk42oo3bW`;ogOk;0oo>kNT01?nme^co
/LOZok77j_naanX2ojc1j@;oZ[kX1?nY_^P7ojVmj0?o00009_nY_NP00ol0003oZKgXojVmj00GojVm
j003o`000?oooooooooo01cooooo000>ooooo`03o`000?oooooooooo00WoooooB_nY_NP3o`0000So
ZKgX1?nY_>L00onX^^KoYK;RojFbhP03oj6Zg@?oW9oF0onGTld3oi>7a0?oT7nm0on@NkP4oi9j]@?o
Ugfe0_nMQ;P00ol0003o]9ZmokBJ_@03okBJ_@08ol2]aooHc<gof<c=omS<cOoZklgoi?g4omWocOo@
lNP4ol;QkP;o]/o]0_n_a^/2ojc1j@03ojZnj?l0003ooooo02Wooooo00?o0000ooooooooool02Ooo
ool6ojVmj0;oZKcX0_nW^^L4ojBfiP?oW:cR0_n@VMT2ogn0b@;oLFJg0_mYEJP2ofY>W`03ogi[/omn
HjWoOV>Y00?oPV:T0on:IZ<3oiE_Y@04oj5kZ_naQjWo/HNYok67Z@?o`I^a0ooO_;D2ooSS/@03oo3b
WooMo/_ogOk;00?oc^gY0_nidnd2ok77jP;o[<3Y1?nZ_^P2ojVnj0GoZKgX0ol0000ZojVmj003o`00
0?nY_NSoZKgX01KoZKgX00?o0000ooooooooool07?ooool000kooooo00?o0000ooooooooool02ooo
oom5ojVmj0?o00003?nY_NP2ojVli`03ojNhiOnU/^;oYK;R00;oYK;R0onQZ]d3oibOeP?oUi?=0_nC
Ql@3oi1o_@CoT7^h0onBN[D3oiMm]@04oif4^?nWRKKo0000ojN9]PCo]9Zm0ooHc<d01?oZklgoi?g4
omWocOoIold2om7ii@;o`^7^0_nfd>d2ojo6j`03ojc1jOnZ_^SoZ[kX00;oZ[kX00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0;ooooo`?oZKgX1?nY_>P2ojNji`;oY;KV00CoV:[RohNDfOn7
U=WoQiCI0_m_M<L2ogn0b@;oLFJg0_mYEJP3ofY>W`;oOV>Y0on2HZ@3ohYVX`;oUFnU00?oWgFSok67
ZOnaQjT00_naQjT2ol6K/@?ogkbe0_ohhk401?o`lYooa>V7olCYQooFolh3olOXk@03okWCkOn_a>[o
[lCZ00Co[<3Y0_nZ_^P5ojVmj0?o0000;OnY_NP00ol0003oZKgXojVmj00GojVmj003o`000?oooooo
oooo01_ooooo000>ooooo`03o`000?oooooooooo00cooooo@OnY_NP3o`0000koZKgX00?oZ;_WojNh
iOnW^>D00_nW^>D2ojFbhP04oibQf?nET/koUI;>oiFBcP?oSX?30on9N;X3ohM`/P?oT7nm0on@NkP3
oi9j]@;oUgfe00GoVgb`ojN9]_nWRKKoYhVfo`000003okBJ_@;ocKK300?of<c=on[_cOoToL@00_oI
old2om7ii@05ol?Tkonfd>go]]3]okK@kOn_aN/01?n/`NT2ojZnj003ojVnj?oooooo000002Sooooo
00?o0000ooooooooool03?ooool3ojVmj0;oZKcX0_nW^^L2oj:eiP?oV:[R0_n7U=T2ofmda`?oF5Bb
0_maI[L01_mYEJSoJTjOofY>WomZCYooLU2KogiSZ@?oPV:T0on:IZ<00onEKjGoWgFSoimeX`05ok67
Z@04ol6K/OoO_;Gogkbeomnl]@;on>>a00?oama/olCYQooFolh00oo7j>d00onecNco[lCZojo4jP02
ojo4jP;o[<3Y00?oZ[kXojVmj?nY_NP00_nY_NP3o`00037oZKgX00?o0000ojVmj?nY_NP05_nY_NP0
0ooooooo0000ooooo`0Kooooo`003_ooool00ol0003oooooooooo`0=ooooocgoZKgX0ol0000>ojVm
j0;oZKcW0onX^nL2ojNhi@04oj:/gonLXMSoW:7HoibQf0?oUI;>0on>Pl<3ohUh^P?oQg2b0on8KJh3
oha^[0?oTW>]1?nKO;03ojN9]P03o`000?ndV[gocKK300;ocKK300Kok>;6onWh[Oo=lYSocO:Hol_k
]?oAnND3ol?Tk`04okK@kOn_aN_o[lG[ojo5j`;o[<7Y00?oZ[kXojVnj?nY_^P00_nY_^P00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00gooooo00?oZKgXojRlj?nX_>P01?nW^^L2oj:eiP?o
V:[R0_n7U=T2ofmda`;oF5Bb0_maI[L01?mYEJSoJTjOofY>WomZCYl2og9@V`?oPV:T0_n:IZ<00on>
IIkoWgFSoimeX`02oimeX`Co/HNY00?od:N^omnl]OoO_;D00_ohhk400oo7g6coa>V7ok7RPP02om7n
g@04olOXkOnecNco]Lg/okG=k0;o[lCZ0_n[_nP3ojZnj0?o0000=OnY_NP00ol0003oZKgXojVmj00F
ojVmj003o`000?oooooooooo01[ooooo000>ooooo`03o`000?oooooooooo00kooooo>OnY_NP3o`00
017oZKgX00?oZKcWojNii_nW^NH00onU]>@3oj:/g`?oW:7H0onET/h3ohj3``;oRGRj0on7L;83ohQ]
[P?oS6j/1?nBLjd3oi]l/0?oYhVf00?o0000olff`oo=]/<00_o=]/<01?o/h/KojOR]olgbV?o=lYP2
ololhP;o`nC_0_nfd>d2ojo5j`03oj_0jOnZ_^SoZ[kX00;oZ[kX0_nY_^P00onY_NSoooooo`00000W
ooooo`03o`000?oooooooooo00gooooo1?nX_>P2ojNji`03oj:fionFZnCoUZ_T00?oOi?L0_mMK<X2
ofmda`;oF5Bb00?oCSnPog5V]omYEJP00omZCYl2og9@V`?oOeRK0on>IIh4oimeX`Co/HNY0_o@Yjh0
1OoO_;Gon>>aooSS/Oo4jHOo/N:200;odOkM0onogNl00onecNco[L;Yojg2j@03oj^oj0?o0000>?nY
_NP00ol0003oZKgXojVmj00FojVmj003ooooool0003ooooo01[ooooo000=ooooo`03o`000?oooooo
oooo013ooooo=OnY_NP3o`0001?oZKgX00?oZ;_WojNii_nW^NH00_nW^NH3ojFdi0?oXZcO0_nLXMP3
oiFBcP?oSX?30on9N;X3ohM`/P?oR6f^0on<KZ`3oi9c[@?oVgb`0onWRKH01_nlW[[o0000olff`oo=
]/?ok>;6onWh[@;ocO:H0_o?o>82ol;Tl0;o]]3]00?o[/GZoj_0jOn[`>T00_n[`>T2ojZnj0GoZKgX
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0?ooooo`;oZ;cX0_nV^nP3oj:fi`;oUZ_T
0omoTm`00omMK<[o>D:`ocU2/002oeQD/P;oCSnP0_mYEJP2ofY>W`;oLU2K0omoF9/3ohiUWPCoWgFS
0onaQjT3om2W[P;om]N]00?oama/o`000?o9lnd00_o9lnd2okoMk`04ok37jon]`^Wo[L;Yojg2j@?o
000000?oZ[kXojVmj?nY_NP0>OnY_NP00ol0003oZKgXojVmj00FojVmj003o`000?oooooooooo01Wo
oooo000=ooooo`03o`000?oooooooooo013ooooo<onY_NP2o`0001CoZKgX1?nX^nL2ojNiiP04oj>`
h_nMYM_oWJGKoifUf`?oUIKB0_n<Q<H3ohAe^P?oOfV`0on9N;X3ohM`/P?oR6f^0on<KZ`3oi9c[@Co
Vgb`00GoYhVfokbN^_nlW[[o_9jjo`000002oncRaP04onWh[Oo=lYSo^O2OololhP;o`^C`00?o]<k]
ojk5j_n^aNX00_n^aNX2oj_0j@03ojZnj?nY_NSoZKgX00KoZKgX00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0@ooooo`CoY[_X0onR]^L2oiJ[i0;oOi?L0_mMK<X2ocU2/003oeQD/_m>?j3o
CSnP00;oJEFX0_mZCYl2og9@V`?oOeRK0on>IIh5oimeX`03ok67ZOo@Yjkod:N^00;od:N^0_ofejd0
1Ol0003obO?]olWckOo9lngo]]7^00Co/<O[0_l00005ojZnj3_oZKgX00?o0000ojVmj?nY_NP05_nY
_NP00ol0003oooooooooo`0Hooooo`003Oooool00ol0003oooooooooo`0AooooobooZKgX0ol0000G
ojVmj0;oZ;_W00?oY[OUoj>`h_nS/>800_nS/>83oifUf`?oUIKB0_n<Q<H2ohAe^P?oOfV`0omnI:X3
ohM`/P?oR6f^0on<KZ`4oi9c[@;oVgb`00?oZXRaokbN^_nlW[X00_nlW[X01OoQb/7o0000oncRa_oY
n:goX]1T00;oc?gR00Co`^C`okC>kOndc^go]<k]0_n^aNX2oj_0j@?oZ[kX2?nY_NP00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo017ooooo0_nV^nP2oj:gj0;oUZkW0_mmV>83oe1^d@03oee/
b_li@[3o>D:`00;oF5Bb00?oCSnPodlhUomYEJP00omZCYl2og9@V`;oOeRK0on>IIh5oimeX`04ok67
ZOo@Yjkod:N^om2W[P;om]N]00Coama/ol;ndoo2o]?obO?]0onfdNh3o`000003oj_0jOnZ_^SoZ[kX
00?oZ[kX?OnY_NP00ol0003oZKgXojVmj00FojVmj003o`000?oooooooooo01Oooooo000=ooooo`03
o`000?oooooooooo01;ooooo:onY_NP3o`0001WoZKgX0_nX^nL3ojJgi@?oXk3R0onMYM/3oiFFdP;o
S8C60on4MKX2ogmY/0?oOVBZ0_n0HZL2ohM`/P?oR6f^0on<KZ`3oi9c[@03oi]l/?nZR;7oZXRa00Co
_9jj00CohL[1o`000?ocljWo_]]/0_o<oN82okoQl0;o]<k]0_n]`nX4oj_0j@03ojZnj?nY_NSoZKgX
00OoZKgX00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Booooo`CoX[OX0_nF[^L2ogfH
hP;oD6kA00So5CBaocU2/?li@[3o92BIoeQD/_m>?j3oCcRGofUEZ0?oJTjO0_mbD9/2ogmHV`CoSVFN
1?nOMJ<4om2W[P;om]N]0_o2o]<2okgPl@?o00000_n]`nX3oj_0j@;oZ[kX?onY_NP00ol0003oZKgX
ojVmj00FojVmj003o`000?oooooooooo01Oooooo000=ooooo`03o`000?oooooooooo01?ooooo9onY
_NP3o`0001WoZKgX0_nY_>L4ojRki`03ojJgiOnP[=ooV9gG00;oV9gG0on=Rl`3oh9g_P;oNVRb0on4
MKX3ogmY/0;oOVBZ1?n0HZL3ohQ][P?oS6j/0_nBLjd00onJN:_oZXRaojZ8/@02ojZ8/@;o_9jj0ooQ
b/400ol0003obO[WolWji`02okoQl0;o//_]1?n]`nX2oj_0j@;oZ[kX2_nY_NP00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo01?ooooo0_nR]nP2oiZbj@05oh:Rj?m@NmgoD7_Moe1kgOm@K]40
0_lE=;401?li@[3o92BIoeQD/_m>?j02odlhU`?oJTjO0_mbD9/3ogmHV`?oSVFN1?nOMJ<3om2W[P;o
m]N]00?ok^Z9ol;bl?l000000_l00002ok38k0;o[L?Z1OnZ_^Q1ojVmj003o`000?nY_NSoZKgX01Ko
ZKgX00?o0000ooooooooool05_ooool000gooooo00?o0000ooooooooool05OoooolRojVmj0?o0000
6onY_NP4ojVli`;oZ;_W00CoYKGToj2/gonP[=ooX:cO0onHWML3ohf;c0;oPWNn0omjJ;82ohAe^P?o
OfV`0omnI:X3oh1RY`?oQFFV0on>K:L4oiYhZ`?oZXRa00Wo_9jjon7:`OoQb/7ohL[1oo?cZOo9n^Oo
0000olWjionkfo001?nbbnd2ojg3jP;oZkoY0_nZ_^P<ojVmj003o`000?oooooooooo023ooooo00?o
0000ooooooooool05?ooool4oiZbj@07oh:Rj?m@NmgoD7_Mo`0f^_m@K]7o5CBaocU2/002ob@TV@04
odhoX?m?>9OoCcRGoe/mU0;oJTjO0_mbD9/3ogmHV`?oSVFN0onOMJ<2okZ>Z0;od:N^00Com]N]o`00
0?l0003o00000onccnh00on`b>coZl3Yoj_0j@05ojZnj4?oZKgX00?o0000ojVmj?nY_NP05_nY_NP0
0ol0003oooooooooo`0Eooooo`003?ooool00ol0003oooooooooo`0GoooooakoZKgX0ol0000OojVm
j0;oZKcW00?oYk[VojFei?nU]N@00_nU]N@3oj2/g`?oV9gG0_n=Rl`3oh9g_P;oNVRb0_meGZT00on4
MK[oOfV`ogmY/003ogiTZP?oP6:W0on5IJH3ohi/Y`CoVWR[0onZR;402?o:Z[WohL[1on7:`OocljWo
0000ojg^X_o9n^Oo00000_nkfo02ok;;k@;o[<;Y0_n[_nT00onZ_^SoZKgXojVmj00<ojVmj003o`00
0?oooooooooo01oooooo00?o0000ooooooooool05_ooool2oiZbj@03ohf]jomSTnWoHi?Y00;oD7_M
00Go03JjoaDd/Ol00hko>D:`ob@TV@02odhoX004odlhUomK?ICoFcfDofY>W`;oLU2K0omoF9/3ohiU
WP;oWgFS0onjSZP3o`000003onkZROngfO;o]mWb00;o/lo^00?o[<;Zoj_0jOn[`>T00_n[`>T2ojZn
j4KoZKgX00?o0000ojVmj?nY_NP05OnY_NP00ol0003oooooooooo`0Eooooo`003?ooool00ol0003o
ooooooooo`0Hoooooa[oZKgX0ol0000QojVmj0;oZ;cW0onW^^H2ojFei004oibWg_nAU]CoTIKDoi6F
e0?oQ8370_mhK;T3oh9g_P;oNVRb0omeGZT2ogmY/0?oOVBZ0on0HZL4ohEUYP?oSVbW0onJN:/3ojZ8
/@;obZZi00?ohL[1oo?cZOn]kZ800_o6m>d01?l0003o^m_`ok38k?n`b>`2ojc2j@GoZ[kX3_nY_NP0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo0on=[N/2of>Cj@09o`UDd?l0=[[o
5CBao`03S_li@[3o92BIob8JSOm>?j3oCcRG00?oFcfD0ombD9/2ogmHV`?oSVFN00?oWgFSokZ>Z?l0
00000_l000001Oo@Yjkom]N]ooKG[On/`TCo]mWb00;o[/G[0on/`^X2oj_0j@;oZ[kXAonY_NP00ol0
003oZKgXojVmj00FojVmj003o`000?oooooooooo01Cooooo000<ooooo`03o`000?oooooooooo01Wo
oooo5_nY_NP3o`0002CoZKgX0onX_>L00onW^^KoXk;Soj>bh`03oibWgP;oTIKD0on4P<L3ogQ/^@;o
PWNn0omjJ;82ogENZ@;oMEVT00?oOfV`ogiTZ_mnI:X00on0HZL4ohEUYP?oSVbW1?nJN:/01_nZR;7o
bZZiolZZ^Oo:Z[WomnJeojg^XP;oa_C]0_nge>l00ol0003o/<S/oj_1j@06ojZnj13oZKgX00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Hooooo`;oSJg[0omSTnT02?l0083o03JjoaDd/Oli
@[3o92BIob8JSOm>?j3oCcRG0omK?I@2ofi:UP03og9@VomoF9_oOeRK00;oSVFN0ol00003okZ>Z0;o
jLB^00?olNR6ojo9kOn^aN/00on^aN/00on/`^[oZ[kXojZnj004ojZnj4OoZKgX00?o0000ojVmj?nY
_NP05_nY_NP00ol0003oooooooooo`0Cooooo`003?ooool00ol0003oooooooooo`0Joooooa?oZKgX
0_l0000VojVmj003ojRkionV^>KoY[SV00;oY[SV0onS/^<3oibWgP;oTIKD0_n4P<L3ogQ/^@;oKeb]
00?oPWNnogYX/_mjJ;800_meGZT3ogEIY0;oOVBZ1?n0HZL3ohEUYP?oSVbW1?nJN:/01OnZR;7obZZi
olZZ^Oo:Z[WomnJe00;o`^_a0_nge>l00on^aN_oZl7Yo`000002oj_1j@;oZ[kX4onY_NP00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01[ooooo00_oOZW_ocn7j_loQn[o?hOZo`00P?lE=;7o
00>>ob@TVOlR6XgoCSnPodlhU`03oe/mU0?oKTZF0_moF9/2o`000003oj1dXOnjSZSo^XjX00?o^XjX
0_oYa:h00ooaj8Ko[lW]ojo9k@02ojk5j`03ojZojOnZ_^SoZ[kX00CoZ[kXBOnY_NP00ol0003oZKgX
ojVmj00EojVmj003o`000?oooooooooo01?ooooo000<ooooo`03o`000?oooooooooo01cooooo3_nY
_NP3o`0002OoZKgX0onX^nL2ojJhiP04oj6`honHXmcoV:?LoiRSg0?oRhoB0_mkN<@3ohB0a`;oN6bi
0om_G:d2ogYX/P?oMEjY0_meFJ@2ogQIXP04ogiTZ_n0HZOoP6:Woh1RY`?oQFFV0on>K:L4oiYhZ`?o
bZZi00ComnJeol;[lOo2jo7o/lk^1?n^aN/00on[`NWo0000ojZnj00FojVmj003o`000?oooooooooo
01cooooo00?o0000ooooooooool06_ooool2ogF[l`?o?hOZ00?o0020o`03S_lT99T00_lR6Xd01?m?
>9OoFcfDoe/mU?mK?I@2ofi:UP?o00001?nPM:43okZ>Z0;ojLB^00?olNR6ojo9kOn_bNd00_n[`>T3
ojZoj@;oZ[kXCOnY_NP00ol0003oZKgXojVmj00EojVmj003o`000?oooooooooo01;ooooo000<oooo
o`03o`000?oooooooooo01cooooo2onY_NP3o`0002_oZKgX00?oZ;_WojJgi_nV]nH00onQ/><3oiRS
g0;oRhoB0_mkN<@2ofeR]@03ohB0aomhK;WoN6bi00?oKeb]0_m[DjD00omjJ;;oMEjYogENZ@02ogEI
Y0?oN5VR0on0HZL3ohEUYPCoSVbW0_nJN:/01_naSK7obZZiolZZ^Oo:Z[WomnJeok_Ol@?o/lk^0_n^
aN/2oj^oj@03o`000?nZ_^SoZ[kX01GoZKgX00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Kooooo`?oMJ_c00Ko;8S/o`00P?l00hko001hob@TVOlR6Xd2odlhU`05oe/mU?l0003o0000o`00
0?m^BYH00_n6GI/4oj1dX@?o^XjX0_oYa:h00ooaj8KoZl;Zoj_2jP03oj_0j@04ojZojOnY_^SoZKkX
ojVnj4goZKgX00?o0000ojVmj?nY_NP05OnY_NP00ol0003oooooooooo`0Booooo`003?ooool00ol0
003oooooooooo`0Mooooo`OoZKgX0ol0000]ojVmj003ojRkionV]nKoY[OV00;oY[OV0onQ/><2oiRS
g0?oRhoB0_mkN<@2ofeR]@?oN6bi0_m_G:d3of]CY@;oMEjY0omeFJ@2ogQIXP;oOejR00?oP6:WohEU
Y_n5IJH00_n5IJH3ohi/Y`06oiYhZonaSK7o/Hfaok6=/Oo:Z[WomnJe0onkgo401Oncc^ko[<;Zojc2
j_n/`^[oZkoY00;oZ[kX00?o0000ojVmj?nY_NP05OnY_NP00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01cooooo1?mj/_L01?l0083o001hob@TVOlR6Xd3o`000004oe/mU?m^BYKoKTZFofi:
UP?oQUfK0onPM:42okZ>Z0?ojLB^00?olNR6oj_2j_nZ_^P01?nZ_^P2ojVnj4ooZKgX00?o0000ojVm
j?nY_NP05OnY_NP00ol0003oooooooooo`0Aooooo`002oooool00ol0003oooooooooo`0Oooooo`?o
ZKgX0ol0000]ojVmj0;oZKcX0onX^nL2ojJgiP04oin^h_nDX=coU:3LoiBPg0;oQH[A0omcLL82og]h
a0;oKF:e0_mTDjT00omhK;WoKeb]ofmL[@03of]CY@;oMEjY0omeFJ@2ogQIXP?oOejR1?n5IJH2ohi/
Y`03oi]gZOnaSK7o/Hfa00;o/Hfa00CobZZiooOV]Onkgo7o^moa0_n`b>`2ojc2jPGoZ[kX00?o0000
ojVmj?nY_NP05OnY_NP00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01kooooo0_mj/_L2
ohZlm`?o000000Co<B2<odlhUomK?ICoFcfD0om^BYH3ohIMV`CoX7BQ00Co^XjXonW4[_oYa:kolNR6
1_nZ_^QCojVmj003o`000?nY_NSoZKgX01GoZKgX00?o0000ooooooooool04?ooool000_ooooo00?o
0000ooooooooool07oooool3o`00033oZKgX00?oZKcXojNkionW^nL00onU]nH3oin^hP?oU:3L0_n5
R]42og=a`P;oHUZc0_m]H[D3ofACZ@;oKeb]0om[DjD00om[D:3oMEjYogEIY002ogEIY0;oN5VR0omo
GZ84oh]XY0?oVgNY1?naSK400ooRa;_ohNIkokKDl002ok38k003oj_0jOnZ_^SoZ[kX00CoZ[kX0_nY
_NP00ol0003oZKgXojVmj00DojVmj003o`000?oooooooooo01Wooooo00?o0000ooooooooool07ooo
ool3o`000005o`03S_l007So8QZ=oc4PS?m?>9L00omK?I@2ofi:UP?oQUfK1?nPM:401?njSZSojLB^
onW4[_oaj8H4ojZnj5KoZKgX00?o0000ojVmj?nY_NP05?nY_NP00ol0003oooooooooo`0@ooooo`00
2oooool00ol0003oooooooooo`0Looooo`?o00000oooool_ojVmj003ojVlj?nW^nOoYk_W00;oYk_W
0onU]nH2oin^hP?oU:3L0_n5R]43og=a`P;oHUZc0_m]H[D2ofACZ@?oKeb]0_m[DjD2of]@X003ogEN
ZOmeFJCoMEVT00?oN5VR0_moGZ84oh]XY0CoVgNY0onaSK400ooRa;_o]]C`ojg4j`04oj_0j@;oZ[kX
1OnY_NP00ol0003oZKgXojVmj00EojVmj003o`000?oooooooooo01Sooooo00?o0000ooooooooool0
7?ooool3o`0000;ooooo0_nJ`O<01?l007So8QZ=oc4PS?la88`3oe/mU0;oKTZF0on6GI/4oj1dX@03
olfT[ooYa:kojLB^00;oZ[kXFOnY_NP00ol0003oZKgXojVmj00EojVmj003o`000?oooooooooo00oo
oooo000;ooooo`03o`000?oooooooooo01Wooooo0ol00007ooooobgoZKgX0onY_>P2ojNki`04ojBf
i_nM[^?oWJkSoif^h`;oTYoM0on0R=83of]^``;oLg720_mRF[<2ofeR]@;oI5>Y00?oGdZRofmL[Om_
G:d00_m[DjD3of]@X0;oMEVT0omhFJ83ogmNXP?oRfRT1?nKMjT2ok6=/@;oh/Bk0on]a>/2oj_0j@;o
Z[kX1onY_NP00ol0003oZKgXojVmj00EojVmj003o`000?oooooooooo01Oooooo00?o0000oooooooo
ool06Oooool3o`0000Kooooo00?oV/7co`00N?lR6Xd00_la88`3oe/mU0?oKTZF0_n6GI/4oj1dX@;o
cJB_00?olNR6ojVnj?nY_^P0F_nY_NP00ol0003oZKgXojVmj00DojVmj0;o00004?ooool000_ooooo
00?o0000ooooooooool05_ooool3o`0000_ooooo;OnY_NP00onY_>SoYk[WojNji`03ojBfiP?oWJkS
0_nBWmd3oh28dP;oJfk300KoEeFdog=a`_mRF[?oHUZcoeM:Yom]H[D3ofACZ@04oem:X_m_G:goJe>U
of]CY@?oJe2P00?oL5:OogEIY?meFJ@00_mhFJ83ogmNXP?oRfRT1?nKMjT01?naSK7oh/Bkon;4^ooQ
iW/2ojg4j`;oZkoY0_nZ_^P9ojVmj003o`000?nY_NSoZKgX01CoZKgX00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Fooooo`?o00002_ooool01?l007So8QZ=ob8JSOla88`3oe/mU0?oKTZF
0on6GI/2oj1dX@?ocJB_00?on>^HojVnj?nY_NP0FonY_NP00ol0003oZKgXojVmj00DojVmj003o`00
0?oooooooooo00kooooo000;ooooo`03o`000?oooooooooo01Cooooo0_l0000?ooooob_oZKgX0_nX
_>P3ojNji`03ojBfi_nM[^CoT9oN00;oT9oN0ommRMD2oh28dP;oJfk30_mGEK@01OmcLL;oHUZcof9J
/omGBZOoKF:e00;oI5>Y0_mOBZ83of]CY@;oJe2P0_m`DYl00omeFJCoN5VRogQIXP03ogmNXPCoRfRT
0onKMjT3on;4^`?o[<7Y00?oZkoYojVnj?nY_^P02onY_NP00ol0003oZKgXojVmj00CojVmj003o`00
0?oooooooooo01Oooooo00?o0000ooooooooool05?ooool2o`0000gooooo00Go001ho`00MOlR6Xgo
<B2<odheT`02oe/mU0?oKTZF0on6GI/00onPM:7ocJB_olfT[`02olfT[eooZKgX00?o0000ojVmj?nY
_NP04_nY_NP00ooooooo0000ooooo`0?ooooo`002_ooool00ol0003oooooooooo`0Booooo`?o0000
4_oooolYojVmj0;oZ;cX0_nW^^L2ojBgiP?oWJkT0on@Wmh2ogf9e@?oI6g700CoJfk3oeME]?mGEKCo
EeFd0_mRF[<2oeM:Y`;oI5>Y0_mOBZ83of]CY@;oJe2P0om`DYl2ogQIXP?oOejR1?n;J:@3oi]gZ@03
okjK]?oRa;_oh/Bk00;o[<7Y00?oZ[kXojVnj?nY_^P00_nY_^P:ojVmj003o`000?nY_NSoZKgX00go
ZKgX1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01;ooooo0ol0000@ooooo`03
o`00MOlR6Xgo<B2<00;oCSFC00CoFcfDofi:U_m^BYKoKTZF0on6GI/01OnPM:7ocJB_olfT[oo=Y:oo
n>^H05ooZKgX00?o0000ojVmj?nY_NP03OnY_NP6ooooo`03o`000?oooooooooo00kooooo000:oooo
o`03o`000?oooooooooo00oooooo0ol0000FooooobOoZKgX0_nX_>P4ojNji`;oY;OV0onM[^@3oi2O
gP;oOHWE0_mTKLL2of]^``;oEeFd0_mRF[<2oeM:Y`;oI5>Y0_mOBZ800omOAikoJe>Uof]CY@03of]@
X0;oL5:O00?oNEVPogQIX_mhFJ800_moGZ84oh]XY0;oVgNY0onnVk@00ooQiW_oZ[kXojZnj002ojZn
j0;oZKkX3?nY_NP00ol0003oZKgXojVmj009ojVmj0[ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0?ooooo`?o00004oooool01?l007So8QZ=oc4PS?la88`2odheT`?oKTZF0_n6GI/0
0onSO:WocJB_olfT[`02olfT[`03ooS[V?nY_NSoZKgX05koZKgX00?o0000ojVmj?nY_NP02OnY_NP:
ooooo`03o`000?oooooooooo00gooooo000:ooooo`03o`000?oooooooooo00cooooo0ol0000Joooo
obGoZKgX1?nX_>P2ojNji`04ojBgionM/>GoWK3Uoif`i@;oT:;Q0omlSMT2of5ac@;oI6g700KoC5:g
of]^`omGEKCoEeFdodQ2YomRF[<2oeM:Y`04oe51X?mTDjWoGdZRoem:XP;oGdNN00CoJe>Uof]@X?m[
D:3oJe2P0_m`DYl2ogUIX004ogQIX_moGZ;oOejRogmNXP?oRfRT00?oVgNYokjK]?nnVk@00_nnVk@2
oj^oj@;oZ[kX4?nY_NP00ol0003oZKgXojVmj005ojVmj0gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0<ooooo`?o00005_ooool01?l007So001eoc4PS?la88`2odheT`?oMEFN00?o
QUfKoj=lZOnSO:T00oo=Y:l00oohjiSoZKgXojVmj01PojVmj003o`000?nY_NSoZKgX00GoZKgX3Ooo
ool00ol0003oooooooooo`0=ooooo`002_ooool00ol0003oooooooooo`09ooooo`?o00007_oooolU
ojVmj0;oZ;cX00?oYk_WojBgionT]nL00_nT]nL3oif`i@;oT:;Q0omlSMT01OmQLLgo@U>mofA]aomT
KLOoC5:g00;oEeFd0_m8@ZL01OmRF[?oEdZWoeM:YomA@J3oI5>Y00;oGdZR00?oGdNNof]CYOm[D:00
0_m[D:02og1BW`?oNEVP0omoGZ82oh]XY003oiik[?nnVkCo_Y^d00?o_Y^d0onZ_^PAojVmj003o`00
0?nY_NSoZKgX00;oZKgX4?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo
0ol0000Jooooo`03o`00MOla88co<B2<00;oCSFC0omeEIh4oj=lZ@;ocJB_00?on>^HojVmj?nY_NP0
H?nY_NP00ol0003oZKgXojVmj002ojVmj13ooooo00?o0000ooooooooool03Oooool000[ooooo00?o
0000ooooooooool01_ooool3o`0002;ooooo8_nY_NP4ojRlj0;oYk_W0_nT]nL01?nN/^KoTZOToi:W
i?nBYn@2ogjDgP?oHW[E0_mQLLd00om2DkgoI6g7odaB]`03oeME]0;oB4:W0_mGBZL01?mA@J3oI5>Y
oem:X_mOBZ82oem7WP?oJe2P0om`DYl2ogUIX0?oR6JT1?nNNj`3okjK]0?oZ[kX4onY_NP00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool3o`0001go
oooo00?o001eoc4PS?la88`00_m>=I<3ogEEWPCoXgbY00?ocJB_ooS[V?obi;d0HonY_NP00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00gooooo000:ooooo`03o`000?oooooooooo00?ooooo
0ol0000Vooooob;oZKgX0_nX_>P00onW^nSoY;SWojBhi`02ojBhi`;oW[;V0onBYn@2ogjDgP;oHW[E
0_llFlP2od9C_@;oC5:g0_mGEK@2odQ2Y`;oEdZW0_mA@J02oem:XP;oGdNN00?oIDZNof]@X?m[D:00
0om`DYl2ogUIX0?oR6JT1?nNNj`2okjK]003ooW[[?nZ_^SoZKgX013oZKgX1Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool3o`00023ooooo
00?o001eo`00QOla88`00_m>=I<3ogEEWPCoXgbY00?ocJB_oo;T_OnY_NP0GonY_NP5ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03Oooool000Wooooo00Co0000oooooooooooooooo
0ol0000Zooooob3oZKgX0_nX_>P3ojNkj0;oY;SW00CoWkGWoiJ/i_nF[>KoUZcV0on4W^@2ofR8g`;o
HW[E0_llFlP01Om2Dkgo8SN^odaB]olf>jWoEeFd00;oB4:W00Co?SNOoeM:YomA@J3oDD6P0_mOBZ82
oem7WP;oIDZN0_m[D:02og1BW`?oNEVP0on8IZ@4oiik[003okjK]?oijjcoZKgX00koZKgX2Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooooooo0ol0
000Tooooo`04o`00MOla88coCSFCodheT`?oMEFN1?nSO:T2oo;T_EgoZKgX2Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00gooooo0009ooooo`Co0000;ooooolNojVmj0?oZ;cX00?o
Yk_XojFij?nU^NP00onO]NL3oiJ/iP?oQ9kT00?oJ8SOod1[e_m0JmH00_llFlP00om2Dkgo8SN^ob8g
[P02ocHkZ@;oB4:W0_ln=il2oe51X004oe0nWOmOBZ;oGdNNoem7WP?oIDZN00?oJe2Pog1BWom`DYl0
0omiFJ03ohQVY0CoWW^/00?oek^nojVmj?nY_NP02onY_NP<ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool05?ooool4o`0002Oooooo00?o001eo`00QOla88`00_m>=I<3ogEEWP?oXgbY
00?ol^BmojVmj?nY_NP0FOnY_NP<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3Oooool000Wooooo0_l0000aoooooaooZKgX0onW_>P3ojFij003oineionJ/NSoV[7X00;oS:SX0omd
VNL2oe23i005od1[e_l9A/Go?5_8oa0h]om2Dkd00_lR=jh00olf>jWoB4:WodQ2Y`02ochgW`05oeM:
YomA@J3oDD6Poe0nWOmOBZ800_mOAih3ofE:WP;oL5:O0omiFJ03ohQVY0CoWW^/00?oek^nojVmj?nY
_NP02OnY_NP?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool2o`0002[o
oooo00Co0025oc4PS?m>=I?oCSFC0omeEIh2oj=lZ@;ol^BmFOnY_NP?ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03?ooool000_ooooo00?o0000ooooooooool0;ooooolOojVmj003
ojNlj?nV^^SoY[[X00?oX[OX0onJ/NP2ohbXj0?oM9WW0_m@Pn@01?lHI=Wo2DK5ocaKb?l@>;L2ob8g
[P;o=S^Y0_m8@ZL2ochgW`;oDD6P00CoD3jMoem:X_mOAikoGdNN0omUBYh00omaE:7oL5:Oog1BW`02
ogUIX0?oR6JT0onNNj`00ooG^kko/LM;ojVmj007ojVmj1?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Oooooo0_l008D2odheT`?oMEFN00?oXgbY
oo;T_Oobi;d0EonY_NPCooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool0
00cooooo00?o0000ooooooooool0<?oooolLojVmj0;oZ;cX0onV^^P00onR]nSoW[KYoijfj@02oiB`
jP?oPjO/0_mXVnh3oe23i003oaQTfOl9A/Go43Rg00;o8SN^00Co0ajQocHkZOlU:j3oB4:W0_ln=il2
oe51X0;oD3jM0_mOAih3ofE:WP;oLEBQ00?oL5:OogUIX?miFJ001?n8IZ@01?nNNjcoek^nomNk__na
ad/2ojVmj1[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02Kooooo00Co001eo`00QOm>=I?oCSFC0omeEIh00onSO:Wol^Bmoo;T_@1AojVmj1[ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooooooo
o`0_oooooacoZKgX00?oZ;cXojNkj?nT^NP00onT^NP3oijfj@;oU;3Z0on3Yn`2ofRKkP;o?H[/00Go
06cGo`0f]_l0=[Ko43Rgob8g[P02o`<NX@06obD[X?m8@ZOo?SNOochgWolj<YgoDD6P0_m@?Yd2oem7
WP?oIDZN0omaE:43ogUIX0?oR6JT00CoWW^/omNk__naad_oZKgX7?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09_ooool00ol008Go>3^YodheT`02
ogEEWP?oZJ;?00?oooooojVmj?nY_NP0COnY_NPLooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool000kooooo0_l0000`oooooa[oZKgX00CoZ;cXojNkj?nW^nSoYk_X0_nT^NP0
1?nR^NWoVkK[oi^fjonK]^/4oi2bk@;oP:ga0omVZ?H02OlmXOGo06cGo`0f]_l0=[Ko01FSob8g[_l3
7Z7o=S^YobD[X002ochgW`06ocXbWOmA@J3oD3jMoe0nWOmF@YkoGdNN0omUBYh3og5DX@?oQFJX0_n8
IZ@01?nVQk?oek^nomNk__naad/Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
6?ooool2o`0002Kooooo00Co0025ocPkZOlh>jWoMEFN1?nYX/l2oooood_oZKgX8?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo000@ooooo`03o`000?oooooooooo02oooooo
5onY_NP3ojRlj003ojNkj?nV^nSoY[_X00?oX[WY0onK]^/2oi2bk@03oi:glOn5^?KoQKSf00;oQKSf
0_md^o`2oeg0o0;oQ]?o00Co8SN^o`<NXOl37Z7o9B^P0_ln=il2ocXbW@05oe51X?m@?YgoD3jMoeI2
W_mOAih00_mUBYh3og5DX@?oQFJX1?nVQk<00ooG^kkol_Feooooo`0Nooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Tooooo`03o`00QOlh>jWoZJ;?
00?oZJ;?1Ooooom6ojVmj2Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`004Oooool00ol0003oooooooooo`0_oooooaOoZKgX0onX_>P3ojJkj004oj:ijOnQ^^_oXK[[oj6j
j`;oV[S]0onB]o42ohFhmP;oTL;g00CoRlWloig=n?nMcOSoWLgh0_nOdoX2o`<NX@06obD[X?lG8Yco
?SNOochgWolj<YgoDD6P0_m@?Yd00omF@YkoGdNNofE:WP02ofE:WP?oLEBQ0on5IZP3ojJ7/`03oo;e
]Ooooooooooo01oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo02?ooooo00?o0025ocPkZOlh>jT00_nYX/l7oooood3oZKgX:_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00cooooo000Booooo`03o`000?oooooooooo02oooooo5onY
_NP00onX_>SoYkcXojNlj003ojFkj@;oXK[[00?oXK_/oiflk_nM_>h00_nM_>h2oiNmlP;oTL;g0_nM
a_D2oig=n0;oY/Wb00GoZ<_bo`<NXOl37Z7o00VGobD[X002ochgW`;o>S:M0_m@?Yd2oeI2WP?oIDZN
0omaE:43ohEVZ0?oYXNc00?ol_Feooooooooool07oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool08oooool3ocPkZ@03ojVRcooooooooooo00Kooooo
?OnY_NP/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool001?ooooo0_l0
000`oooooaGoZKgX0_nX_NP3ojNlj004ojFkjOnT_>[oY;cZojBljP;oXK_/0_nM_>h2oj6okP?oW/;a
00KoWLKeojG6l?nUa_3oYLK`ojK9l_nYa>d2oj[4k@;o0ajQ00?o9B^PoaLRW?ln=il00_lj<Yd2oe0n
W@;oET:N0omUBYh3og5DX@?oQFJX0_nVQk<00oobmKGoooooooooo`0Qooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool07?ooool2o`00033ooooo>OnY_NP`ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool001Gooooo00?o0000ooooooooool0;ooooolCojVmj0?o
Z;gX0onW_>T2ojBljP03ojFmj_nS_NcoXkg/00;oXkg/00?oXKo^ojG0kOnT`nl00onT`nl2ojG6l0;o
Z<?]0_nYa>d2oj[4k@04o`<NXOl02IOo5b:LochgW`;o>S:M00Go?3FOoe0nWOmF@YkoET:Nof=>Y002
ofE:WP?oLEBQ1?n5IZP00onVQk?ol_Feooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0_oooooc;oZKgX=_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00_ooooo000Fooooo`03o`000?oooooooooo02kooooo5?nY_NP3ojRm
j004ojNljOnW_NWoYkgYojNmj@;oYKgZ0_nS_N`2ojFnj`;oYL3]0_nT`nl2ojS1k0;oZ<?]00?oZL3Z
oj[0j_nZ`>X00onZ`>X00ol02IOo9B^PoaLRW002ocXbW@;o?3FO00GoD3jMoeI2W_mF@YkoHdjTofE:
WP03og5DX@CoQFJX00?oYXNcoo;e]Oooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0;_ooool_ojVmj3[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0;ooooo`005oooool00ol0003oooooooooo`0^oooooaCoZKgX0onX_NP3
ojNmj@?oY[kZ0_nU_^/00onW_n_oYl3[ojO0j`02ojO0j`03ojS1k?nY`>[oZL3Z00?oZL3Z0_nZ`>X2
ooooo`;o00VG00?o5b:LocXbWOlj<Yd00_ll=Il00om@?YgoET:NoeI2WP02of=>Y0CoLEBQ0_n5IZP2
okVYbBKooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02kooooo;?nY_NPlooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool0
01Sooooo0_l0000`oooooa?oZKgX00?oZ;gXojRmjOnX_NT00onW_NT01?nV_^[oZ;kZojRnj_nX_^X2
ojNoj`;oYl3[0_nY_nX4ojW0jPKooooo00?o00VGoaLRW?lG8Y`00_lj<Yd2oc`eW`;oET:N0_mSCZ@3
ogm[/P03og5DXOn5IZSo^JW900;o^JW99oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo027ooooo0_l0000`ooooobOoZKgX@?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00_ooooo000Jooooo`03o`000?oooooooooo02gooooo5?nY_NP3ojRmj@03ojNmjOnX_NWoZ;gY
00;oZ;kZ1OnX_^T00onY_n[oooooooooo`0:ooooo`04o`09UolG8Yco2QnOocXbW@;o?3FO0_mF@Yh3
of=>Y0?oOf^b0oniZLTYooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0]ooooob;oZKgXA_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00[ooooo000Kooooo`03o`000?oooooooooo02gooooo4onY_NP4ojRmj003ojRmjOnY_^WoZKkY
00GoZ;kY3oooool00ol008So2QnOocXbW@02oc`eW`03odQ6[?mF@YkoHdjT00;oHdjT1?moJk800oni
ZLWoooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0]oooooaooZKgXBOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo000Looooo`03o`000?oooooooooo02kooooo4_nY_NP2ojRmj0;oZKgX0onY_^T00onX_^Wo
ooooooooo`0Aooooo`04oaLRW?l:7ioo?3FOoc`eW`;oB4J/00?oET:Nof=>Y?mSCZ@01?moJk800oni
ZLWoooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0^oooooaSoZKgXC_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo000Mooooo`03o`000?oooooooooo02kooooo5?nY_NPIooooo`04o`XOWoll=Ioo?3FOoc`e
W`;oB4J/0omSCZ@2ogm[/Rkooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo02kooooo5?nY_NQBooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool001kooooo0_l0000_oooooa7oZKgX7?ooool00ol:7ioo?3FOoc`eW`02odQ6[0?o
KWc@00?oOf^bok_mfOooool0;_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Ko
oooo0_l0000^oooooa;oZKgXEOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[o
oooo000Pooooo`03o`000?oooooooooo02gooooo2onY_NPRooooo`03o`0//_ll=IooB4J/00;oB4J/
0om^O=0`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0/ooooo`coZKgXF_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo
000Qooooo`03o`000?oooooooooo02gooooo2?nY_NPUooooo`04o`0//_m8AZcoB4J/odQ6[0?oKWc@
<Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
;Oooool7ojVmj5kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`008_oo
ool00ol0003oooooooooo`0]ooooo`CoZKgX;?ooool00om8AZcoKWc@ooooo`0booooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0]ooooo`CoZKgXHOoo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo000Sooooo`;o0000;Oooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool2
o`0002gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Hoooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool002Ko
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Tooooo`05o`000?oooooooooooooo
ool00000;oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`009oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
06Gooooo00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo06Gooooo00Co0000oooooooooooo00002oooool002Sooooo0_l0000Xooooo`03o`000?oooooo
oooo06Kooooo00?o0000ooooool00000<Oooool2o`0002Sooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooo`00000;ooooo`00:_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06Kooooo00?o0000ooooool00000<oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06Kooooo00?o0000ooooool000002oooool002_ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1Wooooo`03o`000?oooooo000003?ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1Wooooo`03o`000?oooooo000000[ooooo000/ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0J?ooool2o`0003Cooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1Xooooo`;o00002_ooool002gooooo0_l0000Sooooo`03o`000?oooooooooo06Oooooo0ol0
000eooooo`;o00008oooool00ol0003oooooooooo`1Wooooo`?o00002_ooool002oooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`1Sooooo`Co0000>_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo06?ooooo1?l0000=ooooo`00<?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo063ooooo0ol0000oooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0H?ooool3o`00017ooooo000aooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0G?ooool4o`0004?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Looooo`Co
00005?ooool003;ooooo0_l0000Nooooo`03o`000?oooooooooo05Sooooo1?l00018ooooo`;o0000
7_ooool00ol0003oooooooooo`1Hooooo`Co00006?ooool003Cooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1Dooooo`Co0000C_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo05Cooooo1?l0000Looooo`00=Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo057ooooo0ol0001Cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool3
o`00023ooooo000fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0COooool4o`00
05Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1=ooooo`Co00008oooool003Oo
oooo0_l0000Iooooo`03o`000?oooooooooo04Wooooo1?l0001Looooo`;o00006Oooool00ol0003o
ooooooooo`19ooooo`Co00009oooool003Wooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`15ooooo`Co0000H_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Gooooo
1?l0000[ooooo`00>_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04?ooooo0ol0
001Wooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@oooool3o`0002oooooo000k
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?oooool4o`0006_ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0oooooo`Co0000<_ooool003cooooo0_l0000Coooo
o`03o`000?oooooooooo03_ooooo1?l0001`ooooo`;o00004oooool00ol0003oooooooooo`0koooo
o`Co0000=_ooool003kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0gooooo`Co
0000M_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Oooooo1?l0000jooooo`00
?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo1?l0001kooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0<oooool4o`0003kooooo0010ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0<?ooool3o`00083ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0`ooooo`?o0000@_ooool0047ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0/ooooo`Co0000Q?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo02cooooo1?l00015ooooo`00@_ooool2o`0000gooooo00?o0000ooooooooool0:?ooool4o`00
08Wooooo0_l0000=ooooo`03o`000?oooooooooo02Sooooo1?l00019ooooo`00A?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo1?l0002?ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool09?ooool4o`0004gooooo0015ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool08Oooool3o`0009Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Qooooo`?o0000DOooool004Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Mooooo`Co0000V?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0
001Dooooo`00Aoooool2o`0000Sooooo00?o0000ooooooooool06Oooool4o`0009gooooo0_l00008
ooooo`03o`000?oooooooooo01Wooooo1?l0001Hooooo`00BOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Gooooo1?l0002Sooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05Oooool4o`0005cooooo001:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04_ooool3o`000:Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`?o
0000H?ooool004_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000
[?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0001Sooooo`00C?oo
ool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000;7ooooo0_l00003ooooo`03o`000?oo
oooooooo00[ooooo1?l0001Wooooo`00C_ooool01?l0003oooooooooool00008ooooo`Co0000]ooo
ool01?l0003oooooooooool00008ooooo`Co0000Joooool004oooooo00?o0000ooooool000001Ooo
ool3o`000;cooooo00?o0000ooooool000001Oooool3o`0006oooooo001@ooooo`;o000000?ooooo
o`000?l000000_l00030ooooo`;o000000?oooooo`000?l000000_l0001booooo`00DOooool2o`00
0<Gooooo0_l0001fooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-1.41844, \
-1.14991, 0.01418, 0.01418}, {{208.5, 389.375}, {315.688, 169}} -> {-4.23892, \
-1.14991, 0.01418, 0.01418}, {{9.625, 190.438}, {154.375, 7.6875}} -> \
{-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, 389.375}, {154.375, \
7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoClassificationRegions[pdf1, pdf2, pr, x, y, classColors, gd, 
        Axes \[Rule] False, Frame \[Rule] True, FS];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.00495 .70044 m
.04485 .68095 L
.08837 .65904 L
.12924 .63782 L
.16854 .61683 L
.21038 .59382 L
.25065 .57101 L
.29345 .54603 L
.33469 .52122 L
.37436 .49665 L
.41657 .46973 L
.45721 .44301 L
.49628 .41656 L
.53789 .38754 L
.57793 .35876 L
.62051 .32718 L
.66152 .29579 L
.70096 .26465 L
.74294 .23044 L
.78335 .19641 L
.8263 .15902 L
.86768 .12172 L
.90749 .08459 L
.94984 .04369 L
.98854 .00495 L
s
.00495 .99505 m
.04485 .99505 L
.08837 .99505 L
.12924 .99505 L
.16854 .99505 L
.21038 .99505 L
.25065 .99505 L
.29345 .99505 L
.33469 .99505 L
.37436 .99505 L
.41657 .99505 L
.45721 .99505 L
.49628 .99505 L
.53789 .99505 L
.57793 .99505 L
.62051 .99505 L
.66152 .99505 L
.70096 .99505 L
.74294 .99505 L
.78335 .99505 L
.8263 .99505 L
.86768 .99505 L
.90749 .99505 L
.94984 .99505 L
.98854 .99505 L
s
1 1 .5 r
.00495 .70044 m
.04485 .68095 L
.08837 .65904 L
.12924 .63782 L
.16854 .61683 L
.21038 .59382 L
.25065 .57101 L
.29345 .54603 L
.33469 .52122 L
.37436 .49665 L
.41657 .46973 L
.45721 .44301 L
.49628 .41656 L
.53789 .38754 L
.57793 .35876 L
.62051 .32718 L
.66152 .29579 L
.70096 .26465 L
.74294 .23044 L
.78335 .19641 L
.8263 .15902 L
.86768 .12172 L
.90749 .08459 L
.94984 .04369 L
.98854 .00495 L
.98854 .99505 L
.94984 .99505 L
.90749 .99505 L
.86768 .99505 L
.8263 .99505 L
.78335 .99505 L
.74294 .99505 L
.70096 .99505 L
.66152 .99505 L
.62051 .99505 L
.57793 .99505 L
.53789 .99505 L
.49628 .99505 L
.45721 .99505 L
.41657 .99505 L
.37436 .99505 L
.33469 .99505 L
.29345 .99505 L
.25065 .99505 L
.21038 .99505 L
.16854 .99505 L
.12924 .99505 L
.08837 .99505 L
.04485 .99505 L
.00495 .99505 L
F
0 g
.00495 .70044 m
.04485 .68095 L
.08837 .65904 L
.12924 .63782 L
.16854 .61683 L
.21038 .59382 L
.25065 .57101 L
.29345 .54603 L
.33469 .52122 L
.37436 .49665 L
.41657 .46973 L
.45721 .44301 L
.49628 .41656 L
.53789 .38754 L
.57793 .35876 L
.62051 .32718 L
.66152 .29579 L
.70096 .26465 L
.74294 .23044 L
.78335 .19641 L
.8263 .15902 L
.86768 .12172 L
.90749 .08459 L
.94984 .04369 L
.98854 .00495 L
s
.00495 .99505 m
.04485 .99505 L
.08837 .99505 L
.12924 .99505 L
.16854 .99505 L
.21038 .99505 L
.25065 .99505 L
.29345 .99505 L
.33469 .99505 L
.37436 .99505 L
.41657 .99505 L
.45721 .99505 L
.49628 .99505 L
.53789 .99505 L
.57793 .99505 L
.62051 .99505 L
.66152 .99505 L
.70096 .99505 L
.74294 .99505 L
.78335 .99505 L
.8263 .99505 L
.86768 .99505 L
.90749 .99505 L
.94984 .99505 L
.98854 .99505 L
s
.98854 .00495 m
.98881 .00495 L
.98909 .00495 L
.98936 .00495 L
.98962 .00495 L
.9899 .00495 L
.99017 .00495 L
.99045 .00495 L
.99072 .00495 L
.99099 .00495 L
.99126 .00495 L
.99153 .00495 L
.99179 .00495 L
.99207 .00495 L
.99233 .00495 L
.99261 .00495 L
.99289 .00495 L
.99315 .00495 L
.99342 .00495 L
.99369 .00495 L
.99398 .00495 L
.99425 .00495 L
.99451 .00495 L
.99479 .00495 L
.99505 .00495 L
s
.98854 .99505 m
.98881 .99505 L
.98909 .99505 L
.98936 .99505 L
.98962 .99505 L
.9899 .99505 L
.99017 .99505 L
.99045 .99505 L
.99072 .99505 L
.99099 .99505 L
.99126 .99505 L
.99153 .99505 L
.99179 .99505 L
.99207 .99505 L
.99233 .99505 L
.99261 .99505 L
.99289 .99505 L
.99315 .99505 L
.99342 .99505 L
.99369 .99505 L
.99398 .99505 L
.99425 .99505 L
.99451 .99505 L
.99479 .99505 L
.99505 .99505 L
s
1 1 .5 r
.98854 .00495 m
.98881 .00495 L
.98909 .00495 L
.98936 .00495 L
.98962 .00495 L
.9899 .00495 L
.99017 .00495 L
.99045 .00495 L
.99072 .00495 L
.99099 .00495 L
.99126 .00495 L
.99153 .00495 L
.99179 .00495 L
.99207 .00495 L
.99233 .00495 L
.99261 .00495 L
.99289 .00495 L
.99315 .00495 L
.99342 .00495 L
.99369 .00495 L
.99398 .00495 L
.99425 .00495 L
.99451 .00495 L
.99479 .00495 L
.99505 .00495 L
.99505 .99505 L
.99479 .99505 L
.99451 .99505 L
.99425 .99505 L
.99398 .99505 L
.99369 .99505 L
.99342 .99505 L
.99315 .99505 L
.99289 .99505 L
.99261 .99505 L
.99233 .99505 L
.99207 .99505 L
.99179 .99505 L
.99153 .99505 L
.99126 .99505 L
.99099 .99505 L
.99072 .99505 L
.99045 .99505 L
.99017 .99505 L
.9899 .99505 L
.98962 .99505 L
.98936 .99505 L
.98909 .99505 L
.98881 .99505 L
.98854 .99505 L
F
0 g
.98854 .00495 m
.98881 .00495 L
.98909 .00495 L
.98936 .00495 L
.98962 .00495 L
.9899 .00495 L
.99017 .00495 L
.99045 .00495 L
.99072 .00495 L
.99099 .00495 L
.99126 .00495 L
.99153 .00495 L
.99179 .00495 L
.99207 .00495 L
.99233 .00495 L
.99261 .00495 L
.99289 .00495 L
.99315 .00495 L
.99342 .00495 L
.99369 .00495 L
.99398 .00495 L
.99425 .00495 L
.99451 .00495 L
.99479 .00495 L
.99505 .00495 L
s
.98854 .99505 m
.98881 .99505 L
.98909 .99505 L
.98936 .99505 L
.98962 .99505 L
.9899 .99505 L
.99017 .99505 L
.99045 .99505 L
.99072 .99505 L
.99099 .99505 L
.99126 .99505 L
.99153 .99505 L
.99179 .99505 L
.99207 .99505 L
.99233 .99505 L
.99261 .99505 L
.99289 .99505 L
.99315 .99505 L
.99342 .99505 L
.99369 .99505 L
.99398 .99505 L
.99425 .99505 L
.99451 .99505 L
.99479 .99505 L
.99505 .99505 L
s
.00495 .00495 m
.04485 .00495 L
.08837 .00495 L
.12924 .00495 L
.16854 .00495 L
.21038 .00495 L
.25065 .00495 L
.29345 .00495 L
.33469 .00495 L
.37436 .00495 L
.41657 .00495 L
.45721 .00495 L
.49628 .00495 L
.53789 .00495 L
.57793 .00495 L
.62051 .00495 L
.66152 .00495 L
.70096 .00495 L
.74294 .00495 L
.78335 .00495 L
.8263 .00495 L
.86768 .00495 L
.90749 .00495 L
.94984 .00495 L
.98854 .00495 L
s
.00495 .70044 m
.04485 .68095 L
.08837 .65904 L
.12924 .63782 L
.16854 .61683 L
.21038 .59382 L
.25065 .57101 L
.29345 .54603 L
.33469 .52122 L
.37436 .49665 L
.41657 .46973 L
.45721 .44301 L
.49628 .41656 L
.53789 .38754 L
.57793 .35876 L
.62051 .32718 L
.66152 .29579 L
.70096 .26465 L
.74294 .23044 L
.78335 .19641 L
.8263 .15902 L
.86768 .12172 L
.90749 .08459 L
.94984 .04369 L
.98854 .00495 L
s
.5 1 1 r
.00495 .00495 m
.04485 .00495 L
.08837 .00495 L
.12924 .00495 L
.16854 .00495 L
.21038 .00495 L
.25065 .00495 L
.29345 .00495 L
.33469 .00495 L
.37436 .00495 L
.41657 .00495 L
.45721 .00495 L
.49628 .00495 L
.53789 .00495 L
.57793 .00495 L
.62051 .00495 L
.66152 .00495 L
.70096 .00495 L
.74294 .00495 L
.78335 .00495 L
.8263 .00495 L
.86768 .00495 L
.90749 .00495 L
.94984 .00495 L
.98854 .00495 L
.98854 .00495 L
.94984 .04369 L
.90749 .08459 L
.86768 .12172 L
.8263 .15902 L
.78335 .19641 L
.74294 .23044 L
.70096 .26465 L
.66152 .29579 L
.62051 .32718 L
.57793 .35876 L
.53789 .38754 L
.49628 .41656 L
.45721 .44301 L
.41657 .46973 L
.37436 .49665 L
.33469 .52122 L
.29345 .54603 L
.25065 .57101 L
.21038 .59382 L
.16854 .61683 L
.12924 .63782 L
.08837 .65904 L
.04485 .68095 L
.00495 .70044 L
F
0 g
.00495 .00495 m
.04485 .00495 L
.08837 .00495 L
.12924 .00495 L
.16854 .00495 L
.21038 .00495 L
.25065 .00495 L
.29345 .00495 L
.33469 .00495 L
.37436 .00495 L
.41657 .00495 L
.45721 .00495 L
.49628 .00495 L
.53789 .00495 L
.57793 .00495 L
.62051 .00495 L
.66152 .00495 L
.70096 .00495 L
.74294 .00495 L
.78335 .00495 L
.8263 .00495 L
.86768 .00495 L
.90749 .00495 L
.94984 .00495 L
.98854 .00495 L
s
.00495 .70044 m
.04485 .68095 L
.08837 .65904 L
.12924 .63782 L
.16854 .61683 L
.21038 .59382 L
.25065 .57101 L
.29345 .54603 L
.33469 .52122 L
.37436 .49665 L
.41657 .46973 L
.45721 .44301 L
.49628 .41656 L
.53789 .38754 L
.57793 .35876 L
.62051 .32718 L
.66152 .29579 L
.70096 .26465 L
.74294 .23044 L
.78335 .19641 L
.8263 .15902 L
.86768 .12172 L
.90749 .08459 L
.94984 .04369 L
.98854 .00495 L
s
1 0 0 r
.02 w
.55676 .77478 Mdot
.69324 .76004 Mdot
.80651 .59963 Mdot
.67742 .72344 Mdot
.68349 .68561 Mdot
.6236 .74701 Mdot
.65643 .67193 Mdot
.58307 .5608 Mdot
.5293 .6864 Mdot
.65901 .66775 Mdot
.56166 .67502 Mdot
.59273 .67935 Mdot
.67422 .72241 Mdot
.64316 .69539 Mdot
.66342 .65434 Mdot
.81891 .58245 Mdot
.85002 .5272 Mdot
.64933 .64285 Mdot
.63797 .56244 Mdot
.72284 .6246 Mdot
.68774 .67438 Mdot
.67935 .60815 Mdot
.62783 .64837 Mdot
.63848 .66001 Mdot
.53592 .74599 Mdot
.84379 .61737 Mdot
.66455 .70688 Mdot
.73316 .62295 Mdot
.63211 .75769 Mdot
.62184 .70497 Mdot
.59747 .67047 Mdot
.6502 .66762 Mdot
.52138 .81673 Mdot
.38316 .87114 Mdot
.59115 .5631 Mdot
.94571 .5486 Mdot
.60136 .73023 Mdot
.71728 .6042 Mdot
.94133 .58313 Mdot
.8838 .43988 Mdot
.69075 .58066 Mdot
.47923 .67369 Mdot
.62459 .70122 Mdot
.53018 .78476 Mdot
.76887 .57231 Mdot
.84614 .51692 Mdot
.65087 .73158 Mdot
.83044 .49027 Mdot
.72797 .59202 Mdot
.82319 .52875 Mdot
.70748 .58152 Mdot
.84587 .58067 Mdot
.98376 .52223 Mdot
.1587 .97177 Mdot
.63853 .53974 Mdot
.74522 .6337 Mdot
.67767 .56762 Mdot
.75715 .66654 Mdot
.39887 .74406 Mdot
.65031 .77292 Mdot
.49344 .66956 Mdot
.61838 .70507 Mdot
.64349 .58219 Mdot
.64158 .728 Mdot
.60883 .59889 Mdot
.70148 .55064 Mdot
.83988 .52999 Mdot
.62934 .62075 Mdot
.69287 .67215 Mdot
.49681 .69294 Mdot
.56408 .63866 Mdot
.56887 .78254 Mdot
.85922 .57118 Mdot
.80285 .57533 Mdot
.61461 .72099 Mdot
.64863 .63891 Mdot
.42682 .68759 Mdot
.79747 .54691 Mdot
.58937 .64708 Mdot
.66063 .70405 Mdot
.35935 .83956 Mdot
.53494 .59905 Mdot
.70629 .54521 Mdot
.60852 .69324 Mdot
.67342 .52372 Mdot
.54288 .77401 Mdot
.50785 .73208 Mdot
.50463 .66882 Mdot
.77359 .52647 Mdot
.61837 .64151 Mdot
.64836 .71348 Mdot
.46526 .79031 Mdot
.69289 .55757 Mdot
.64567 .50819 Mdot
.95133 .48829 Mdot
.46931 .81207 Mdot
.66136 .67984 Mdot
.72914 .6186 Mdot
.65209 .54406 Mdot
.48686 .76072 Mdot
0 0 1 r
.28869 .21599 Mdot
.27905 .18211 Mdot
.13672 .25346 Mdot
.13693 .37485 Mdot
.28868 .19825 Mdot
.10183 .25907 Mdot
.2985 .18952 Mdot
.25843 .27046 Mdot
.20228 .25681 Mdot
.33473 .31044 Mdot
.32388 .17207 Mdot
.25046 .20996 Mdot
.34554 .20108 Mdot
.42917 .1414 Mdot
.16469 .34957 Mdot
.23118 .256 Mdot
.16485 .28625 Mdot
.30886 .22002 Mdot
.16762 .15652 Mdot
.25214 .23443 Mdot
.39891 .22744 Mdot
.19809 .26867 Mdot
.26021 .2906 Mdot
.32762 .12785 Mdot
.24954 .3728 Mdot
.26565 .23738 Mdot
.3206 .19101 Mdot
.23139 .41358 Mdot
.07459 .45413 Mdot
.21125 .3652 Mdot
.04275 .20578 Mdot
.08664 .31604 Mdot
.18984 .27116 Mdot
.38693 .17474 Mdot
.15452 .39662 Mdot
.34313 .27904 Mdot
.4767 .19632 Mdot
.1963 .35775 Mdot
.31123 .2871 Mdot
.41261 .19535 Mdot
.31788 .15578 Mdot
.26556 .13498 Mdot
.3206 .2818 Mdot
.26196 .27529 Mdot
.16993 .25939 Mdot
.25435 .3129 Mdot
.22563 .32623 Mdot
.39645 .22435 Mdot
.28407 .30012 Mdot
.25617 .24143 Mdot
.48719 .15723 Mdot
.24627 .21723 Mdot
.2758 .28045 Mdot
.34203 .2014 Mdot
.39132 .19762 Mdot
.25447 .21901 Mdot
.19451 .29681 Mdot
.10771 .32152 Mdot
.34631 .26056 Mdot
.06927 .39426 Mdot
.28716 .22649 Mdot
.12267 .24024 Mdot
.29382 .21614 Mdot
.3637 .15727 Mdot
.18597 .19798 Mdot
.32256 .19923 Mdot
.2176 .24266 Mdot
.27206 .2602 Mdot
.27894 .40062 Mdot
.19782 .23581 Mdot
.32564 .24225 Mdot
.25912 .30985 Mdot
.28871 .2688 Mdot
.137 .26679 Mdot
.24367 .28345 Mdot
.24374 .24308 Mdot
.17967 .26772 Mdot
.28146 .15447 Mdot
.29522 .22011 Mdot
.13476 .26358 Mdot
.23364 .2392 Mdot
.32651 .20264 Mdot
.10665 .28038 Mdot
.20781 .19675 Mdot
.15057 .33353 Mdot
.2856 .24843 Mdot
.31395 .25839 Mdot
.22864 .27283 Mdot
.21712 .26377 Mdot
.19637 .25262 Mdot
.08248 .24607 Mdot
.38278 .19393 Mdot
.4309 .13012 Mdot
.33049 .23157 Mdot
.22998 .27816 Mdot
.16775 .34381 Mdot
.36978 .17072 Mdot
.24491 .31364 Mdot
.2724 .21271 Mdot
.32053 .17654 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00ool0000Po`000040oooo003oo`00023o00000@3oool00003o`00001oool0Oooo0?l0Oooo
601oool01Ol00000oomo0?ooO`3ooooo00000040oooo00000ol00000Oooo07ooo`3o07oooaL0Oooo
00Ko00000?ooO`3oogl0oomo0?ooool000010?ooo`0000?o000007ooo`1oool0o`1ooolF07ooo`03
o`00003oogl0oomo0080oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`3o07oooaD0Oooo
00?o00000?ooO`3oogl00`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0?l0Oooo501o
ool00ol00000oomo0?ooO`040?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0o`1ooolC
07ooo`03o`00003oogl0oomo00D0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`3o07oo
oa80Oooo00?o00000?ooO`3oogl01P3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0?l0
Oooo4@1oool00ol00000oomo0?ooO`070?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0
o`1oool@07ooo`03o`00003oogl0oomo00P0oomo0@3oool1o`000040oooo00000ol00000Oooo07oo
o`3o07ooo`l0Oooo00?o00000?ooO`3oogl02@3oogl10?ooo`7o00000@3oool00003o`00001oool0
Oooo0?l0Oooo3P1oool00ol00000oomo0?ooO`0:0?ooO`40oooo0Ol000010?ooo`0000?o000007oo
o`1oool0o`1oool=07ooo`03o`00003oogl0oomo00/0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`3o07ooo``0Oooo00?o00000?ooO`3oogl0303oogl10?ooo`7o00000@3oool00003o`00
001oool0Oooo0?l0Oooo2`1oool00ol00000oomo0?ooO`0=0?ooO`40oooo0Ol000010?ooo`0000?o
000007ooo`1oool0o`1oool:07ooo`03o`00003oogl0oomo00h0oomo0@3oool1o`000040oooo0000
0ol00000Oooo07ooo`3o07ooo`T0Oooo00?o00000?ooO`3oogl03`3oogl10?ooo`7o00000@3oool0
0003o`00001oool0Oooo0?l0Oooo201oool00ol00000oomo0?ooO`0@0?ooO`40oooo0Ol000010?oo
o`0000?o000007ooo`1oool0o`1oool707ooo`03o`00003oogl0oomo0140oomo0@3oool1o`000040
oooo00000ol00000Oooo07ooo`3o07ooo`H0Oooo00?o00000?ooO`3oogl04P3oogl10?ooo`7o0000
0@3oool00003o`00001oool0Oooo0?l0Oooo1@1oool00ol00000oomo0?ooO`0C0?ooO`40oooo0Ol0
00010?ooo`0000?o000007ooo`1oool0o`1oool407ooo`03o`00003oogl0oomo01@0oomo0@3oool1
o`000040oooo00000ol00000Oooo07ooo`3o07ooo`<0Oooo00?o00000?ooO`3oogl05@3oogl10?oo
o`7o00000@3oool00003o`00001oool0Oooo0?l0Oooo0@1oool2o`0001P0oomo0@3oool1o`000040
oooo00000ol00000Oooo07ooo`3o07ooo`03o`00003oogl0oomo01P0oomo0@3oool1o`000040oooo
00000ol00000Oooo07ooo`3n07ooo`03o`00003oogl0oomo01T0oomo0@3oool1o`000040oooo0000
0ol00000Oooo07ooo`3m07ooo`03o`00003oogl0oomo01X0oomo0@3oool1o`000040oooo00000ol0
0000Oooo07ooo`3l07ooo`03o`00003oogl0oomo01/0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`3k07ooo`03o`00003oogl0oomo01`0oomo0@3oool1o`000040oooo00000ol00000Oooo
07ooo`3j07ooo`03o`00003oogl0oomo01d0oomo0@3oool1o`000040oooo00000ol00000Oooo07oo
o`3i07ooo`03o`00003oogl0oomo01h0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`3h
07ooo`03o`00003oogl0oomo01l0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`3g07oo
o`03o`00003oogl0oomo0200oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`3f07ooo`03
o`00003oogl0oomo0240oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1I07ooo`?o003o
6`1oool3o`00ogX0Oooo0_l0000T0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0F01o
ool5o`00oaT0Oooo1Ol00?mh07ooo`03o`00003oogl0oomo02@0oomo0@3oool1o`000040oooo0000
0ol00000Oooo07ooo`1707ooo`?o003o3P1oool5o`00oaT0Oooo1Ol00?mg07ooo`03o`00003oogl0
oomo02D0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1607ooo`Go003o3@1oool5o`00
oaT0Oooo1Ol00?mf07ooo`03o`00003oogl0oomo02H0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`1607ooo`Go003o3P1oool3o`00oaT0Oooo1Ol00?mf07ooo`03o`00003oogl0oomo02L0
oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1607ooo`Go003o:P1oool5o`00ogD0Oooo
00?o00000?ooO`3oogl0:03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo04L0Oooo0ol0
0?l[07ooo`Go003oM01oool00ol00000oomo0?ooO`0Y0?ooO`40oooo0Ol000010?ooo`0000?o0000
07ooo`1oool0C01oool3o`00obL0Oooo0ol00?md07ooo`03o`00003oogl0oomo02X0oomo0@3oool1
o`000040oooo00000ol00000Oooo07ooo`0[07ooo`?o003o7@1oool5o`00o`H0Oooo0ol00?l;07oo
o`?o003o801oool3o`00of80Oooo00?o00000?ooO`3oogl0:`3oogl10?ooo`7o00000@3oool00003
o`00001oool0Oooo02X0Oooo1Ol00?lL07ooo`Go003o1@1oool5o`00o`T0Oooo1Ol00?lN07ooo`Go
003oH01oool00ol00000oomo0?ooO`0/0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0
:P1oool5o`00oa`0Oooo1Ol00?l507ooo`Go003o2@1oool5o`00oah0Oooo1Ol00?mN07ooo`;o0000
;`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo02X0Oooo1Ol00?lM07ooo`?o003o1P1o
ool5o`00o`T0Oooo1Ol00?lN07ooo`Go003oG@1oool00ol00000oomo0?ooO`0_0?ooO`40oooo0Ol0
00010?ooo`0000?o000007ooo`1oool0:`1oool3o`00obP0Oooo1Ol00?l907ooo`Co003o7`1oool3
o`00oed0Oooo00?o00000?ooO`3oogl0<03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo
05L0Oooo1Ol00?l807ooo`Go003o00@0Ooooo`00ool00?oo003oN@1oool00ol00000oomo0?ooO`0a
0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0E`1oool5o`00o`P0Oooo2_l00?mg07oo
o`03o`00003oogl0oomo0380oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1;07ooo`?o
003o201oool6o`00o`P0Oooo2_l00?me07ooo`;o0000=@3oogl10?ooo`7o00000@3oool00003o`00
001oool0Oooo04X0Oooo1Ol00?l707ooo`Go003o2P1oool3o`00o`0307ooool00?oo003o00?o003o
M01oool00ol00000oomo0?ooO`0e0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0BP1o
ool5o`00o`80Oooo0ol00?l207ooo`Go003o3`1oool3o`00og@0Oooo00?o00000?ooO`3oogl0=P3o
ogl10?ooo`7o00000@3oool00003o`00001oool0Oooo04X0Oooo1Ol00?l00`1ooooo003oo`00o`03
o`00o`80Oooo0ol00?n607ooo`03o`00003oogl0oomo03L0oomo0@3oool1o`000040oooo00000ol0
0000Oooo07ooo`0g07ooo`?o003o4@1oool3o`00o`80Oooo1Ol00?l00`1ooooo003oo`00o`03o`00
o`h0Oooo0ol00?l607ooo`?o003o3`1oool3o`00oeP0Oooo00?o00000?ooO`3oogl0>03oogl10?oo
o`7o00000@3oool00003o`00001oool0Oooo0340Oooo0ol00?l207ooo`Go003o4`1oool7o`00o`03
07ooool00?oo003o00?o003o3@1oool7o`00o`80Oooo1Ol00?l=07ooo`Go003oEP1oool00ol00000
oomo0?ooO`0i0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0<01oool5o`00o`0307oo
ool00?oo003o00?o003o4P1oool7o`00o`80Oooo1_l00?l00`1ooooo003oo`00o`02o`00o`L0Oooo
2?l00?l00`1ooooo003oo`00o`03o`00o`d0Oooo1Ol00?mD07ooo`;o0000?03oogl10?ooo`7o0000
0@3oool00003o`00001oool0Oooo00P0Oooo0ol00?lU07ooo`Go003o00<0Ooooo`00ool00?l00ol0
0?lB07ooo`Go003o1@1oool;o`00o`H0Oooo2?l00?l00`1ooooo003oo`00o`03o`00o`d0Oooo1Ol0
0?mC07ooo`03o`00003oogl0oomo03`0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`07
07ooo`Go003o901oool5o`00o`80Oooo0ol00?l907ooo`?o003o1`1oool5o`00o`D0Oooo2ol00?l7
07ooo`Oo003o0P1oool3o`00o`l0Oooo0ol00?mC07ooo`03o`00003oogl0oomo03d0oomo0@3oool1
o`000040oooo00000ol00000Oooo07ooo`0707ooo`Go003o9@1oool3o`00o`h0Oooo1Ol00?l207oo
o`?o003o0P1oool3o`00o`L0Oooo2_l00?l:07ooo`?o003oJP1oool00ol00000oomo0?ooO`0n0?oo
O`40oooo0Ol000010?ooo`0000?o000007ooo`1oool01`1oool5o`00ocH0Oooo1Ol00?l00`1ooooo
003oo`00o`03o`00o`0307ooool00?oo003o00?o003o1P1oool3o`00o`0307ooool00?oo003o00;o
003oM`1oool00ol00000oomo0?ooO`0o0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0
201oool3o`00ocH0Oooo1_l00?l00`1ooooo003oo`00o`0=o`00oh00Oooo00?o00000?ooO`3oogl0
@03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0440Oooo5ol00?lE07ooo`?o003oIP1o
ool00ol00000oomo0?ooO`110?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0@@1oool7
o`00o`0507ooool00?oo003oo`00o`1oool02ol00?lD07ooo`Go003oI01oool00ol00000oomo0?oo
O`120?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0@P1oool6o`00o`D0Oooo2ol00?l2
07ooo`?o003o3`1oool6o`00of80Oooo00?o00000?ooO`3oogl0@`3oogl10?ooo`7o00000@3oool0
0003o`00001oool0Oooo04@0Oooo0ol00?l607ooo`Ko003o00@0Ooooo`00ool00?oo003o0P1oool5
o`00o`h0Oooo1_l00?mQ07ooo`03o`00003oogl0oomo04@0oomo0@3oool1o`000040oooo00000ol0
0000Oooo07ooo`0d07ooo`?o003o301oool7o`00o`<0Oooo1Ol00?l707ooo`Go003o3`1oool5o`00
oel0Oooo0_l000170?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool07P1oool3o`00oa80
Oooo1Ol00?l607ooo`?o003o0P1oool8o`00o`<0Oooo0ol00?l807ooo`Go003o401oool3o`00oel0
Oooo00?o00000?ooO`3oogl0A`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo01<0Oooo
0ol00?l707ooo`Go003o4@1oool5o`00o`80Oooo4Ol00?l=07ooo`Go003oLP1oool00ol00000oomo
0?ooO`180?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool04P1oool5o`00o`H0Oooo1Ol0
0?lA07ooo`Go003o00<0Ooooo`00ool00?l04?l00?l207ooo`?o003o201oool5o`00og40Oooo00?o
00000?ooO`3oogl0B@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0180Oooo1Ol00?l6
07ooo`Go003o4P1oool3o`00o`80Oooo4Ol00?l207ooo`Go003o1`1oool5o`00og00Oooo00?o0000
0?ooO`3oogl0BP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0180Oooo1Ol00?l707oo
o`?o003o0P1oool3o`00o`d0Oooo1Ol00?l00`1ooooo003oo`00o`0=o`00o`@0Oooo1Ol00?l807oo
o`?o003oK`1oool2o`0004d0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0C07ooo`?o
003o0`1oool3o`00o`H0Oooo1Ol00?l507ooo`?o003o101oool5o`00o`80Oooo2_l00?l807ooo`Go
003o101oool3o`00og80Oooo00?o00000?ooO`3oogl0C@3oogl10?ooo`7o00000@3oool00003o`00
001oool0Oooo01P0Oooo1Ol00?l507ooo`Go003o101oool5o`00o`<0Oooo1_l00?l407ooo`Go003o
1`1oool3o`00o`0407ooool00?oo003oo`00o`@0Oooo1Ol00?l607ooo`?o003oI`1oool00ol00000
oomo0?ooO`1>0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0601oool5o`00o`D0Oooo
1Ol00?l407ooo`Go003o101oool5o`00o`0307ooool00?oo003o00Ko003o1P1oool5o`00o`L0Oooo
1Ol00?l507ooo`Go003oI@1oool00ol00000oomo0?ooO`1?0?ooO`40oooo0Ol000010?ooo`0000?o
000007ooo`1oool0601oool5o`00o`@0Oooo1_l00?l407ooo`Oo003o0P1oool=o`00o`@0Oooo2?l0
0?l0101ooooo003oo`00ool00?l307ooo`Go003o1@1oool5o`00of@0Oooo00?o00000?ooO`3oogl0
D03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo01T0Oooo0ol00?l507ooo`Ko003o1@1o
ool<o`00o`0307ooool00?oo003o00Go003o101oool>o`00o`<0Oooo0ol00?l607ooo`Go003oHP1o
ool2o`0005<0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0Q07ooo`Ko003o1`1oool:
o`00o`0307ooool00?oo003o00Ko003o0`1oool8o`00o`0307ooool00?oo003o00?o003o3@1oool3
o`00of80Oooo00?o00000?ooO`3oogl0D`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo
01X0Oooo0ol00?l507ooo`Co003o201oool:o`00o`80Oooo1ol00?l307ooo`ko003o301oool3o`00
of40Oooo0_l0001F0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool06@1oool5o`00oa40
Oooo2?l00?l507ooo`So003o00<0Ooooo`00ool00?l02_l00?l607ooo`?o003o0`1oool5o`00oel0
Oooo00?o00000?ooO`3oogl0EP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo01T0Oooo
1Ol00?l=07ooo`?o003o101oool3o`00o`L0Oooo4_l00?l707ooo`Ko003o0P1oool5o`00oed0Oooo
0_l0001I0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool06@1oool5o`00o``0Oooo1Ol0
0?l=07ooo`Wo003o00<0Ooooo`00ool00?l01_l00?l607ooo`Oo003o0P1oool5o`00oe`0Oooo00?o
00000?ooO`3oogl0F@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo01X0Oooo0ol00?l=
07ooo`Go003o3P1oool@o`00o`L0Oooo1ol00?l307ooo`?o003oF`1oool2o`0005`0oomo0@3oool1
o`000040oooo00000ol00000Oooo07ooo`0Z07ooo`Go003o101oool3o`00o`/0Oooo0ol00?l00`1o
oooo003oo`00o`03o`00o`X0Oooo1_l00?mQ07ooo`03o`00003oogl0oomo05`0oomo0@3oool1o`00
0040oooo00000ol00000Oooo07ooo`0[07ooo`?o003o101oool5o`00o`h0Oooo1Ol00?l307ooo`?o
003o1@1oool3o`00of40Oooo0_l0001O0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0
<P1oool5o`00o`l0Oooo0ol00?l307ooo`Go003oI`1oool00ol00000oomo0?ooO`1O0?ooO`40oooo
0Ol000010?ooo`0000?o000007ooo`1oool0<P1oool5o`00oaD0Oooo1Ol00?mV07ooo`03o`00003o
ogl0oomo0600oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0c07ooo`?o003o401oool3
o`00o`<0Oooo1Ol00?l:07ooo`?o003oF01oool00ol00000oomo0?ooO`1Q0?ooO`40oooo0Ol00001
0?ooo`0000?o000007ooo`1oool0@P1oool8o`00o`<0Oooo0ol00?l:07ooo`Go003oE@1oool2o`00
06@0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0D07ooo`?o003o:P1oool9o`00oa00
Oooo1Ol00?mD07ooo`03o`00003oogl0oomo06@0oomo0@3oool1o`000040oooo00000ol00000Oooo
07ooo`0C07ooo`Go003o0P1oool3o`00ob@0Oooo2Ol00?l@07ooo`Go003oD`1oool00ol00000oomo
0?ooO`1U0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool04`1oool5o`00o`0307ooool0
0?oo003o00?o003o7P1oool3o`00o`80Oooo2?l00?lB07ooo`?o003oD`1oool00ol00000oomo0?oo
O`1V0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool04`1oool5o`00o`0307ooool00?oo
003o00?o003o7@1oool5o`00o`80Oooo1Ol00?mY07ooo`03o`00003oogl0oomo06L0oomo0@3oool1
o`000040oooo00000ol00000Oooo07ooo`0D07ooo`?o003o0P1oool5o`00oad0Oooo1Ol00?m^07oo
o`;o0000JP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo01X0Oooo0ol00?l907ooo`?o
003o4P1oool5o`00ofd0Oooo00?o00000?ooO`3oogl0JP3oogl10?ooo`7o00000@3oool00003o`00
001oool0Oooo02D0Oooo1Ol00?lB07ooo`?o003oK01oool2o`0006d0oomo0@3oool1o`000040oooo
00000ol00000Oooo07ooo`0U07ooo`Go003oP01oool00ol00000oomo0?ooO`1]0?ooO`40oooo0Ol0
00010?ooo`0000?o000007ooo`1oool09@1oool5o`00o`0407ooool00?oo003oo`00ogX0Oooo0_l0
001`0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool09P1oool3o`00o`0307ooool00?oo
003o00?o003oN01oool00ol00000oomo0?ooO`1`0?ooO`40oooo0Ol000010?ooo`0000?o000007oo
o`1oool0:P1oool5o`00ogL0Oooo00?o00000?ooO`3oogl0L@3oogl10?ooo`7o00000@3oool00003
o`00001oool0Oooo02X0Oooo1Ol00?me07ooo`;o0000M03oogl10?ooo`7o00000@3oool00003o`00
001oool0Oooo02X0Oooo1Ol00?l507ooo`?o003oK01oool00ol00000oomo0?ooO`1d0?ooO`40oooo
0Ol000010?ooo`0000?o000007ooo`1oool0:`1oool3o`00o`D0Oooo1Ol00?mY07ooo`;o0000M`3o
ogl10?ooo`7o00000@3oool00003o`00001oool0Oooo03<0Oooo2?l00?mU07ooo`03o`00003oogl0
oomo07L0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0c07ooo`Wo003oH`1oool00ol0
0000oomo0?ooO`1h0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool08`1oool3o`00o`h0
Oooo2?l00?l707ooo`?o003oF01oool00ol00000oomo0?ooO`1i0?ooO`40oooo0Ol000010?ooo`00
00?o000007ooo`1oool08P1oool5o`00oa00Oooo1Ol00?l607ooo`Go003oE@1oool2o`0007`0oomo
0@3oool1o`000040oooo00000ol00000Oooo07ooo`0R07ooo`Go003o4@1oool3o`00o`L0Oooo1Ol0
0?mD07ooo`03o`00003oogl0oomo07`0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0R
07ooo`Go003o6`1oool5o`00oe<0Oooo00?o00000?ooO`3oogl0O@3oogl10?ooo`7o00000@3oool0
0003o`00001oool0Oooo02<0Oooo0ol00?lM07ooo`?o003oD`1oool00ol00000oomo0?ooO`1n0?oo
O`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0V01oool00ol00000oomo0?ooO`1o0?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool03`1oool3o`00oh@0Oooo0_l000220?ooO`40oooo
0Ol000010?ooo`0000?o000007ooo`1oool03P1oool5o`00oaD0Oooo0ol00?mZ07ooo`03o`00003o
ogl0oomo0880oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0>07ooo`Go003o501oool5
o`00oal0Oooo0ol00?m507ooo`;o0000Q@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo
00h0Oooo1Ol00?lD07ooo`Go003o7P1oool5o`00od<0Oooo00?o00000?ooO`3oogl0Q@3oogl10?oo
o`7o00000@3oool00003o`00001oool0Oooo00l0Oooo0ol00?lE07ooo`Go003o7P1oool5o`00od40
Oooo0_l000280?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0:01oool3o`00oal0Oooo
1Ol00?m007ooo`03o`00003oogl0oomo08P0oomo0@3oool1o`000040oooo00000ol00000Oooo07oo
o`0n07ooo`?o003o2P1oool3o`00ocl0Oooo0_l0002;0?ooO`40oooo0Ol000010?ooo`0000?o0000
07ooo`1oool0?@1oool5o`00odX0Oooo00?o00000?ooO`3oogl0R`3oogl10?ooo`7o00000@3oool0
0003o`00001oool0Oooo03d0Oooo1Ol00?m807ooo`;o0000SP3oogl10?ooo`7o00000@3oool00003
o`00001oool0Oooo03d0Oooo1Ol00?m707ooo`03o`00003oogl0oomo08h0oomo0@3oool1o`000040
oooo00000ol00000Oooo07ooo`0n07ooo`?o003oA`1oool00ol00000oomo0?ooO`2?0?ooO`40oooo
0Ol000010?ooo`0000?o000007ooo`1oool0QP1oool2o`000980oomo0@3oool1o`000040oooo0000
0ol00000Oooo07ooo`2507ooo`03o`00003oogl0oomo0980oomo0@3oool1o`000040oooo00000ol0
0000Oooo07ooo`2307ooo`;o0000M03oogl3ool001h0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`2207ooo`03o`00003oogl0oomo07<0oomo1Ooo000M0?ooO`40oooo0Ol000010?ooo`00
00?o000007ooo`1oool0P@1oool00ol00000oomo0?ooO`1d0?ooO`Goo`007@3oogl10?ooo`7o0000
0@3oool00003o`00001oool0Oooo07l0Oooo0_l0001g0?ooO`Goo`007@3oogl10?ooo`7o00000@3o
ool00003o`00001oool0Oooo0140Oooo0ol00?mY07ooo`;o0000NP3oogl3ool001h0oomo0@3oool1
o`000040oooo00000ol00000Oooo07ooo`0@07ooo`Go003oI`1oool00ol00000oomo0?ooO`2K0?oo
O`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0401oool5o`00ofD0Oooo0_l0002N0?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool0401oool5o`00of<0Oooo0_l0002P0?ooO`40oooo
0Ol000010?ooo`0000?o000007ooo`1oool04@1oool3o`00of<0Oooo00?o00000?ooO`3oogl0X03o
ogl10?ooo`7o00000@3oool00003o`00001oool0Oooo07D0Oooo0_l0002S0?ooO`40oooo0Ol00001
0?ooo`0000?o000007ooo`1oool0L`1oool2o`000:D0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`1b07ooo`03o`00003oogl0oomo0:D0oomo0@3oool1o`000040oooo00000ol00000Oooo
07ooo`1`07ooo`;o0000Z03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo06l0Oooo00?o
00000?ooO`3oogl0Z03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo06d0Oooo0_l0002M
0?ooO`?oo`002`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo06`0Oooo00?o00000?oo
O`3oogl0NP3oogl3ool001l0oomo1Ooo000:0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1o
ool0JP1oool2o`0007`0oomo1Ooo000N0?ooO`Goo`002P3oogl10?ooo`7o00000@3oool00003o`00
001oool0Oooo06T0Oooo00?o00000?ooO`3oogl0O03oogl5ool001h0oomo1Ooo000:0?ooO`40oooo
0Ol000010?ooo`0000?o000007ooo`1oool0I`1oool2o`0007l0oomo1Ooo000O0?ooO`?oo`002`3o
ogl10?ooo`7o00000@3oool00003o`00001oool0Oooo06H0Oooo00?o00000?ooO`3oogl0P03oogl3
ool002h0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1T07ooo`;o0000CP3oogl3ool0
06<0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1R07ooo`;o0000C`3oogl5ool00680
oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1Q07ooo`03o`00003oogl0oomo04l0oomo
1Ooo000f0?ooO`?oo`00:@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo05l0Oooo0_l0
001B0?ooO`Goo`00=@3oogl5ool002P0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1N
07ooo`03o`00003oogl0oomo05<0oomo0ooo00050?ooO`?oo`00;P3oogl5ool002<0oomo0ooo0002
0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0G01oool2o`0005d0oomo1Ooo000I0?oo
O`?oo`004@3oogl5ool00280oomo1Ooo00000`3oogl0ooooo`0000010?ooo`0000?o000007ooo`1o
ool0FP1oool2o`0005l0oomo1Ooo000H0?ooO`Goo`002P3oogl3ool00080oomo1ooo000Q0?ooO`Go
o`0000<0oomo0?ooool000000@3oool00003o`00001oool0Oooo05T0Oooo00?o00000?ooO`3oogl0
G`3oogl5ool001P0oomo1Ooo00090?ooO`goo`008@3oogl5ool000030?ooO`3ooooo00000040oooo
00000ol00000Oooo07ooo`1G07ooo`;o0000H`3oogl3ool001T0oomo1Ooo00090?ooO`goo`008P3o
ogl3ool00080oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1E07ooo`;o0000F`3oogl3
ool002@0oomo0ooo000:0?ooO`coo`00:03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo
05@0Oooo00?o00000?ooO`3oogl0FP3oogl8ool000d0oomo0ooo000N0?ooO`?oo`000P3oogl3ool0
02/0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1B07ooo`;o0000G@3oogl9ool000/0
oomo1Ooo000F0?ooO`?oo`009`3oogl3ool000d0oomo0@3oool1o`000040oooo00000ol00000Oooo
07ooo`1@07ooo`;o0000G`3oogl9ool000X0oomo1_oo000E0?ooO`Goo`009@3oogl5ool000`0oomo
0@3oool1o`000040oooo00000ol00000Oooo07ooo`1>07ooo`;o0000HP3oogl8ool000T0oomo1ooo
000E0?ooO`Goo`009@3oogl5ool000`0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1=
07ooo`03o`00003oogl0oomo06H0oomo0ooo00090?ooO`Ooo`005P3oogl5ool002D0oomo1Ooo000<
0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0B`1oool2o`0005H0oomo1Ooo000:0?oo
O`?oo`00303oogl7ool001P0oomo0ooo000W0?ooO`?oo`003@3oogl10?ooo`7o00000@3oool00003
o`00001oool0Oooo04T0Oooo0_l0001G0?ooO`Ooo`00203oogl5ool000/0oomo1_oo001C0?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool0B01oool00ol00000oomo0?ooO`1G0?ooO`Ooo`00
203oogl5ool000P0oomo2?oo001D0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0AP1o
ool2o`0005X0oomo1ooo00080?ooO`Goo`001`3oogl8ool001<0oomo0ooo000G0?ooO`?oo`009@3o
ogl10?ooo`7o00000@3oool00003o`00001oool0Oooo04@0Oooo0_l0001M0?ooO`Goo`002P3oogl3
ool000P0oomo1Ooo000E0?ooO`Goo`001P3oogl3ool000`0oomo1Ooo000T0?ooO`40oooo0Ol00001
0?ooo`0000?o000007ooo`1oool0@P1oool2o`0007T0oomo1ooo000C0?ooO`Goo`001@3oogl5ool0
00P0oomo2?oo000T0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0@@1oool00ol00000
oomo0?ooO`1`0?ooO`?oo`001`3oogl7ool000040?ooOooo003oo`00ool000h0oomo1Ooo00050?oo
O`Soo`00103oogl9ool001<0oomo0ooo000>0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1o
ool0?`1oool2o`000780oomo1Ooo00080?ooO`[oo`003P3oogl3ool000H0oomo2Ooo00030?ooO`So
o`004`3oogl5ool000d0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0m07ooo`;o0000
M03oogl5ool000P0oomo2_oo000H0?ooO`Soo`000`3oogl5ool001H0oomo1Ooo000=0?ooO`40oooo
0Ol000010?ooo`0000?o000007ooo`1oool0?01oool00ol00000oomo0?ooO`1d0?ooO`Goo`002@3o
ogl3ool000030?ooOooo003oo`0000?oo`000P3oogl3ool001H0oomo1Ooo00040?ooO`?oo`005`3o
ogl5ool000d0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0j07ooo`;o0000N03oogl3
ool000l0oomo0ooo00020?ooO`Goo`005P3oogl3ool00200oomo0ooo000>0?ooO`40oooo0Ol00001
0?ooo`0000?o000007ooo`1oool0>01oool2o`0005/0oomo0ooo000B0?ooO`?oo`007P3oogl5ool0
01<0oomo0ooo000d0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0=P1oool2o`0005`0
oomo1Ooo000@0?ooO`Goo`006`3oogl7ool00180oomo1Ooo000c0?ooO`40oooo0Ol000010?ooo`00
00?o000007ooo`1oool0=01oool2o`0005h0oomo1Ooo000@0?ooO`Goo`00403oogl3ool000L0oomo
1ooo000C0?ooO`Goo`00<`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0380Oooo0_l0
001P0?ooO`Goo`00403oogl5ool000l0oomo1Ooo00060?ooO`Goo`005@3oogl5ool003<0oomo0@3o
ool1o`000040oooo00000ol00000Oooo07ooo`0`07ooo`;o0000H`3oogl3ool00180oomo0ooo000@
0?ooO`Goo`001P3oogl5ool001H0oomo0ooo000d0?ooO`40oooo0Ol000010?ooo`0000?o000007oo
o`1oool0;P1oool2o`0008d0oomo1Ooo00070?ooO`Koo`007P3oogl3ool002X0oomo0@3oool1o`00
0040oooo00000ol00000Oooo07ooo`0/07ooo`;o0000PP3oogl3ool000/0oomo0ooo000:0?ooO`Go
o`00703oogl5ool002T0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0[07ooo`03o`00
003oogl0oomo0840oomo1Ooo000G0?ooO`Koo`006`3oogl5ool002T0oomo0@3oool1o`000040oooo
00000ol00000Oooo07ooo`0Y07ooo`;o0000Q03oogl5ool001H0oomo2?oo000J0?ooO`Goo`00:@3o
ogl10?ooo`7o00000@3oool00003o`00001oool0Oooo02L0Oooo0_l000260?ooO`Goo`005P3oogl8
ool001/0oomo0ooo000Z0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool09P1oool00ol0
0000oomo0?ooO`270?ooO`?oo`005`3oogl:ool004H0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`0T07ooo`;o0000M`3oogl3ool001D0oomo0ooo000C0?ooO`[oo`00A@3oogl10?ooo`7o
00000@3oool00003o`00001oool0Oooo02<0Oooo00?o00000?ooO`3oogl0MP3oogl5ool000`0oomo
0ooo00040?ooO`Goo`005`3oogl5ool004D0oomo0@3oool1o`000040oooo00000ol00000Oooo07oo
o`0Q07ooo`;o0000N@3oogl5ool000<0oomo0ooo00050?ooO`Goo`000`3oogl6ool001H0oomo1Ooo
00150?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool07`1oool2o`0007/0oomo1Ooo0002
0?ooO`Goo`00103oogl6ool00080oomo1_oo000G0?ooO`?oo`00AP3oogl10?ooo`7o00000@3oool0
0003o`00001oool0Oooo01d0Oooo0_l0001n0?ooO`?oo`000`3oogl5ool000@0oomo1ooo00020?oo
O`Goo`00H03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo01/0Oooo0_l000260?ooO`Go
o`001@3oogl6ool000<0oomo0ooo0000103oogooo`00ool00?oo001M0?ooO`40oooo0Ol000010?oo
o`0000?o000007ooo`1oool06@1oool2o`0008T0oomo0ooo00070?ooO`Ooo`00103oogl5ool005`0
oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0G07ooo`;o0000UP3oogl7ool000<0oomo
1Ooo001L0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool05@1oool2o`0009X0oomo3Ooo
000F0?ooO`?oo`00@`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo01<0Oooo0_l0001d
0?ooO`Koo`00603oogl3ool000L0oomo3?oo000F0?ooO`Goo`00@P3oogl10?ooo`7o00000@3oool0
0003o`00001oool0Oooo0140Oooo0_l0001b0?ooO`_oo`00303oogl3ool000L0oomo1Ooo00070?oo
O`[oo`001@3oogl4ool000h0oomo1Ooo00120?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1o
ool03P1oool3o`0007<0oomo3?oo000;0?ooO`Goo`001P3oogl5ool000X0oomo1ooo00040?ooO`Ko
o`003@3oogl5ool00480oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0<07ooo`;o0000
MP3oogl<ool000/0oomo1Ooo00050?ooO`Koo`002`3oogl6ool000@0oomo1_oo000>0?ooO`?oo`00
@`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo00X0Oooo0_l0001h0?ooO`_oo`00303o
ogl5ool000@0oomo1_oo000=0?ooO`Koo`000`3oogl6ool005@0oomo0@3oool1o`000040oooo0000
0ol00000Oooo07ooo`0807ooo`;o0000K03oogl3ool000`0oomo0ooo000;0?ooO`?oo`001P3oogl3
ool000D0oomo1Ooo000?0?ooO`Goo`000P3oogl6ool005D0oomo0@3oool1o`000040oooo00000ol0
0000Oooo07ooo`0607ooo`;o0000K@3oogl5ool001P0oomo1Ooo000=0?ooO`Goo`003`3oogl5ool0
00030?ooOooo003oo`0000?oo`00E`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo00<0
Oooo0ol0001_0?ooO`Goo`00403oogl3ool000D0oomo1Ooo000>0?ooO`?oo`000P3oogl3ool000L0
oomo0ooo00020?ooO`?oo`000P3oogl5ool005L0oomo0@3oool1o`000040oooo00001?l00000Oooo
07ooo`1oool2o`000780oomo1Ooo000?0?ooO`Goo`00103oogl5ool00180oomo1Ooo00050?ooO`Go
o`001P3oogl5ool005L0oomo0@3oool1o`000040oooo00001?l00000Ooooo`000?l0001e0?ooO`?o
o`00403oogl5ool000D0oomo0ooo000C0?ooO`Soo`000P3oogl5ool000L0oomo0ooo001H0?ooO`40
oooo0Ol000010?ooo`000_l0002:0?ooO`Goo`006`3oogl9ool000030?ooOooo003oo`0000?oo`00
00@0oomoool00?oo003oo`00GP3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo08X0oomo
0ooo000M0?ooO`Soo`000P3oogl3ool000030?ooOooo003oo`0000?oo`00G@3oogl10?ooo`7o0000
0@3oool00003o`00003oogl0oomo0:`0oomo1_oo00060?ooO`Koo`00G03oogl10?ooo`7o00000@3o
ool00003o`00003oogl0oomo0:`0oomo1_oo00030?ooO`Woo`00G03oogl10?ooo`7o00000@3oool0
0003o`00003oogl0oomo0:d0oomo1?oo00030?ooO`[oo`00G03oogl10?ooo`7o00000@3oool00003
o`00003oogl0oomo0:`0oomo0ooo00050?ooO`Goo`0000<0oomoool00?oo00001Ooo001I0?ooO`40
oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0Z`3oogl5ool000@0oomo1Ooo00030?ooO`Koo`00
F03oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo0:P0oomo2?oo00030?ooO`Goo`00103o
ogl6ool005P0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`2=0?ooO`?oo`005`3oogl9
ool00080oomo1ooo00030?ooO`Koo`00F03oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo
08`0oomo1Ooo000F0?ooO`Soo`000`3oogl8ool000<0oomo1?oo001I0?ooO`40oooo0Ol000010?oo
o`0000?o00000?ooO`3oogl0S03oogl5ool001H0oomo1Ooo00060?ooO`Soo`00H03oogl10?ooo`7o
00000@3oool00003o`00003oogl0oomo06h0oomo0ooo000K0?ooO`Goo`005`3oogl3ool000P0oomo
1ooo001P0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0K@3oogl5ool001/0oomo0ooo
00050?ooO`?oo`005P3oogl3ool000D0oomo0ooo001Q0?ooO`40oooo0Ol000010?ooo`0000?o0000
0?ooO`3oogl0K@3oogl5ool00280oomo1Ooo000D0?ooO`Goo`00J03oogl10?ooo`7o00000@3oool0
0003o`00003oogl0oomo06d0oomo1Ooo000R0?ooO`Goo`00503oogl5ool006P0oomo0@3oool1o`00
0040oooo00000ol00000oomo0?ooO`1^0?ooO`?oo`008`3oogl5ool001@0oomo1ooo001V0?ooO`40
oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0Q`3oogl3ool000/0oomo0ooo000F0?ooO`Ooo`00
3@3oogl3ool005D0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`260?ooO`Goo`009@3o
ogl5ool000`0oomo1Ooo001D0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0QP3oogl5
ool002D0oomo1Ooo000<0?ooO`Goo`00E03oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo
08H0oomo1Ooo000V0?ooO`?oo`003@3oogl5ool005@0oomo0@3oool1o`000040oooo00000ol00000
oomo0?ooO`270?ooO`?oo`003@3oogl3ool000040?ooOooo003oo`00ool001P0oomo0ooo00090?oo
O`?oo`00E@3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo09H0oomo2Ooo000F0?ooO`Go
o`00H03oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo09H0oomo2ooo000D0?ooO`Goo`00
H03oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo09<0oomo3ooo000C0?ooO`Goo`00H03o
ogl10?ooo`7o00000@3oool00003o`00003oogl0oomo0980oomo2?oo00000`3oogooo`00ool00005
ool001@0oomo0ooo001Q0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0P@3oogl3ool0
00h0oomo1Ooo00060?ooO`Goo`00N03oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo0800
oomo1Ooo000=0?ooO`Goo`001`3oogl3ool007T0oomo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`200?ooO`Goo`003P3oogl3ool008@0oomo0@3oool1o`000040oooo00000ol00000oomo0?oo
O`200?ooO`Goo`00U@3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo0840oomo0ooo002F
0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?oo
o`0000?o00000?ooO`3oogl0PP3oogl3ool009D0oomo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`210?ooO`Goo`002`3oogl3ool008H0oomo0@3oool1o`000040oooo00000ol00000oomo0?oo
O`210?ooO`Goo`002P3oogl5ool008D0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`21
0?ooO`Goo`002P3oogl5ool008D0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`220?oo
O`?oo`002`3oogl5ool008D0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`2A0?ooO`?o
o`00QP3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo0?l0oomo6`3oogl10?ooo`7o0000
0@3oool00003o`00003oogl0oomo0?l0oomo6`3oogl10?ooo`7o00000@3oool00003o`00003oogl0
oomo0680oomo0ooo002e0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0H@3oogl5ool0
0;@0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`1Q0?ooO`Goo`00]03oogl10?ooo`7o
00000@3oool00003o`00003oogl0oomo0640oomo1Ooo002d0?ooO`40oooo0Ol000010?ooo`0000?o
00000?ooO`3oogl0HP3oogl3ool00;D0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`3o
0?ooOa/0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`3o0?ooOa/0oomo0@3oool1o`00
0040oooo00000ol00000oomo0?ooO`3o0?ooOa/0oomo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`3o0?ooOa/0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`1Y0?ooO`?oo`00[P3o
ogl10?ooo`7o00000@3oool00003o`00003oogl0oomo06P0oomo1Ooo002]0?ooO`40oooo0Ol00001
0?ooo`0000?o00000?ooO`3oogl0J03oogl5ool00:d0oomo0@3oool1o`000040oooo00000ol00000
oomo0?ooO`1X0?ooO`Goo`00[@3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo06T0oomo
0ooo002^0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol0
00010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?oo
O`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40
oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o
00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK
0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?oo
o`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0
o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol0
00010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?oo
O`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40
oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o
00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK
0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?oo
o`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0
o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol0
00010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?oo
O`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40
oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0:@3oogl3ool00>h0oomo0@3oool1o`000040oooo
00000ol00000oomo0?ooO`0X0?ooO`Goo`00k@3oogl10?ooo`7o00000@3oool00003o`00003oogl0
oomo02P0oomo1Ooo003]0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0:03oogl5ool0
0>d0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`0Y0?ooO`?oo`00kP3oogl10?ooo`7o
00000@3oool00003o`00003oogl0oomo0?l0oomo6`3oogl10?ooo`7o00000@3oool00003o`00003o
ogl0oomo0?l0oomo6`3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo0?l0oomo6`3oogl1
0?ooo`7o00000@3oool00?oo00008?l000010?ooo`00ool0000Po`000040oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-6, -5.00005*^-6, \
0.00348436, 0.00348436}, {{0, 287}, {287, 0}} -> {-1.01089, -1.01089, \
0.00704453, 0.00704453}, {{0, 287}, {287, 0}} -> {-1.01089, -1.01089, \
0.00704453, 0.00704453}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example D: different Gaussian distributions", "Section"],

Cell[CellGroupData[{

Cell["Generate data from two Gaussian classes", "Subsection"],

Cell[CellGroupData[{

Cell["Definition of Gaussians", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Mu]1\  = \ { .3,  .3};\)\), "\n", 
    \(\(\[CapitalSigma]1\  = \  .07 {{1. , \(- .5\)}, {\(- .5\),  \
.5}};\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(\[Mu]2\  = \ {\(- .5\), \(- .5\)};\)\), "\n", 
    \(\(\[CapitalSigma]2\  = \  .06 {{1. ,  .5}, { .5,  .5}};\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 100;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = \ 
        Table[rgBounded[{\[Mu]1, \ \[CapitalSigma]1}, pr], {n1}];\)\), "\n", 
    \(\(data2\  = \ 
        Table[rgBounded[{\[Mu]2, \ \[CapitalSigma]2}, 
            pr], {n2}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, gd2, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.65005 .67979 Mdot
.65668 .68481 Mdot
.59171 .65175 Mdot
.68367 .7168 Mdot
.5952 .62518 Mdot
.71124 .65959 Mdot
.60847 .7135 Mdot
.69326 .52667 Mdot
.50542 .79038 Mdot
.55928 .68614 Mdot
.5095 .68259 Mdot
.53672 .60827 Mdot
.58606 .73753 Mdot
.4895 .76409 Mdot
.62638 .61225 Mdot
.74825 .81755 Mdot
.93934 .54181 Mdot
.83996 .59467 Mdot
.61716 .56623 Mdot
.64383 .66297 Mdot
.413 .93191 Mdot
.657 .52576 Mdot
.67051 .56303 Mdot
.68115 .64248 Mdot
.59556 .68462 Mdot
.56929 .62799 Mdot
.61831 .53748 Mdot
.51308 .74161 Mdot
.53978 .56649 Mdot
.49507 .79977 Mdot
.7424 .59105 Mdot
.81972 .62257 Mdot
.57556 .65221 Mdot
.4916 .8486 Mdot
.77097 .49496 Mdot
.64574 .78233 Mdot
.49111 .78536 Mdot
.53569 .66691 Mdot
.52763 .6027 Mdot
.84176 .68743 Mdot
.93055 .48793 Mdot
.6626 .59538 Mdot
.84272 .55947 Mdot
.57997 .6131 Mdot
.5388 .74502 Mdot
.55823 .76882 Mdot
.46589 .70795 Mdot
.82912 .61117 Mdot
.87626 .70158 Mdot
.53714 .70769 Mdot
.56971 .69113 Mdot
.58497 .73133 Mdot
.54687 .69647 Mdot
.58764 .6659 Mdot
.47336 .73841 Mdot
.78593 .52091 Mdot
.71271 .63947 Mdot
.62159 .6575 Mdot
.50007 .70082 Mdot
.53988 .71435 Mdot
.52718 .75876 Mdot
.74763 .56479 Mdot
.52518 .63743 Mdot
.60522 .68696 Mdot
.79329 .61222 Mdot
.77146 .54188 Mdot
.76264 .72656 Mdot
.68448 .5752 Mdot
.46482 .63585 Mdot
.64189 .77375 Mdot
.7346 .68207 Mdot
.7226 .56857 Mdot
.71153 .69934 Mdot
.98087 .43904 Mdot
.3534 .74427 Mdot
.39863 .71988 Mdot
.51531 .72348 Mdot
.58228 .62538 Mdot
.60727 .74229 Mdot
.68046 .61449 Mdot
.55276 .62253 Mdot
.57378 .65458 Mdot
.6418 .65208 Mdot
.64402 .49992 Mdot
.60874 .73215 Mdot
.72805 .44625 Mdot
.64336 .57809 Mdot
.65717 .67016 Mdot
.64459 .67234 Mdot
.46239 .7058 Mdot
.81452 .54997 Mdot
.5847 .595 Mdot
.51679 .87463 Mdot
.75966 .62446 Mdot
.79928 .41831 Mdot
.57611 .74639 Mdot
.48189 .71917 Mdot
.50346 .69933 Mdot
.65963 .61345 Mdot
.5893 .73849 Mdot
0 0 1 r
.21576 .23234 Mdot
.26975 .16427 Mdot
.11913 .16651 Mdot
.30344 .29015 Mdot
.26816 .3324 Mdot
.44663 .3428 Mdot
.12413 .22867 Mdot
.19752 .18487 Mdot
.5082 .26994 Mdot
.41855 .4026 Mdot
.44765 .42777 Mdot
.27869 .20796 Mdot
.05963 .09343 Mdot
.42768 .35195 Mdot
.3609 .32313 Mdot
.39867 .30202 Mdot
.34392 .19089 Mdot
.47317 .33556 Mdot
.16826 .23958 Mdot
.19858 .29752 Mdot
.14636 .19379 Mdot
.31764 .3829 Mdot
.14206 .23241 Mdot
.14997 .2323 Mdot
.32126 .21147 Mdot
.09944 .23781 Mdot
.26482 .2127 Mdot
.18113 .23056 Mdot
.37267 .29599 Mdot
.14025 .20346 Mdot
.19719 .21514 Mdot
.35377 .39947 Mdot
.46072 .38115 Mdot
.2848 .26599 Mdot
.17426 .17323 Mdot
.08962 .13828 Mdot
.32459 .19569 Mdot
.38428 .43663 Mdot
.38869 .33703 Mdot
.22474 .14049 Mdot
.2948 .28537 Mdot
.25422 .31305 Mdot
.39567 .36039 Mdot
.17688 .21705 Mdot
.37578 .35926 Mdot
.40113 .24029 Mdot
.30186 .28588 Mdot
.01724 .25916 Mdot
.4162 .34275 Mdot
.19592 .1887 Mdot
.38861 .29146 Mdot
.06219 .23088 Mdot
.12206 .22931 Mdot
.21064 .27561 Mdot
.35626 .27534 Mdot
.28917 .36697 Mdot
.39682 .35107 Mdot
.15573 .1008 Mdot
.38772 .32089 Mdot
.1662 .31889 Mdot
.4925 .36156 Mdot
.17004 .13977 Mdot
.35686 .32156 Mdot
.22553 .33815 Mdot
.11958 .1047 Mdot
.38219 .29668 Mdot
.2313 .18202 Mdot
.22873 .14192 Mdot
.13533 .09302 Mdot
.50496 .4203 Mdot
.19178 .17123 Mdot
.25002 .22972 Mdot
.18912 .15469 Mdot
.37225 .34249 Mdot
.19943 .19805 Mdot
.3148 .19297 Mdot
.37583 .30953 Mdot
.30685 .24309 Mdot
.25071 .26039 Mdot
.35709 .3544 Mdot
.19295 .20118 Mdot
.4004 .36134 Mdot
.44861 .30828 Mdot
.18071 .28262 Mdot
.24863 .29856 Mdot
.25092 .27624 Mdot
.21645 .21592 Mdot
.14201 .21429 Mdot
.13492 .12334 Mdot
.2032 .2098 Mdot
.12607 .25385 Mdot
.0869 .18025 Mdot
.27367 .19217 Mdot
.23478 .24927 Mdot
.35376 .22148 Mdot
.3736 .34655 Mdot
.13787 .16273 Mdot
.30839 .22589 Mdot
.36216 .29126 Mdot
.22991 .25276 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`00000P00000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`00
00<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703o
ool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?oo
o`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040
oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3o
oolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`00
0000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`40
00000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?oo
o`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool0
00030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0
oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003o
ool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@000001
0?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0
oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool1
00000040oooo00000`000000oooo0?ooo`0<0?ooo`?o003o4`3oool3o`00ooH0oooo0@0000010?oo
o`0000<000000?ooo`3oool02`3oool5o`00oa40oooo1Ol00?oe0?ooo`4000000@3oool000030000
003oool0oooo00/0oooo1Ol00?lA0?ooo`Go003o0P3oool3o`00oo00oooo0@0000010?ooo`0000<0
00000?ooo`3oool02`3oool5o`00o`h0oooo2?l00?l00`3ooooo003oo`00o`03o`00onl0oooo0@00
00010?ooo`0000<000000?ooo`3oool0303oool3o`00o`h0oooo2?l00?l20?ooo`Go003ok`3oool1
00000040oooo00000`000000oooo0?ooo`0M0?ooo`Go003o1@3oool5o`00onl0oooo0@0000010?oo
o`0000<000000?ooo`3oool07@3oool5o`00o`H0oooo0ol00?o`0?ooo`4000000@3oool000030000
003oool0oooo01h0oooo0ol00?oj0?ooo`4000000@3oool000030000003oool0oooo0280oooo0ol0
0?of0?ooo`4000000@3oool000030000003oool0oooo0240oooo1Ol00?oe0?ooo`4000000@3oool0
00030000003oool0oooo0240oooo1Ol00?oe0?ooo`4000000@3oool000030000003oool0oooo0240
oooo1Ol00?oe0?ooo`4000000@3oool000030000003oool0oooo0280oooo0ol00?of0?ooo`400000
0@3oool000030000003oool0oooo01D0oooo0ol00?lD0?ooo`?o003o3@3oool3o`00om`0oooo0@00
00010?ooo`0000<000000?ooo`3oool0503oool5o`00oa80oooo1Ol00?l;0?ooo`Go003of`3oool1
00000040oooo00000`000000oooo0?ooo`0D0?ooo`Go003o4P3oool5o`00o`/0oooo1_l00?oJ0?oo
o`4000000@3oool000030000003oool0oooo01@0oooo1Ol00?lB0?ooo`Go003o2`3oool6o`00omX0
oooo0@0000010?ooo`0000<000000?ooo`3oool05@3oool3o`00oa@0oooo0ol00?l30?ooo`?o003o
1`3oool5o`00omX0oooo0@0000010?ooo`0000<000000?ooo`3oool0<@3oool5o`00o`L0oooo0ol0
0?oK0?ooo`4000000@3oool000030000003oool0oooo0340oooo1Ol00?oU0?ooo`4000000@3oool0
00030000003oool0oooo02<0oooo0ol00?l;0?ooo`Go003o4`3oool3o`00oll0oooo0@0000010?oo
o`0000<000000?ooo`3oool07@3oool3o`00o`80oooo1Ol00?l;0?ooo`?o003o4`3oool5o`00olh0
oooo0@0000010?ooo`0000<000000?ooo`3oool0703oool5o`00o`030?ooool00?oo003o00?o003o
2`3oool3o`00oa<0oooo1Ol00?o>0?ooo`4000000@3oool000030000003oool0oooo01`0oooo1Ol0
0?l00`3ooooo003oo`00o`03o`00o`H0oooo0ol00?l00`3ooooo003oo`00o`03o`00oa80oooo1Ol0
0?o>0?ooo`4000000@3oool000030000003oool0oooo01`0oooo1Ol00?l20?ooo`?o003o1P3oool:
o`00oa<0oooo0ol00?o?0?ooo`4000000@3oool000030000003oool0oooo01@0oooo0ol00?l60?oo
o`?o003o303oool:o`00o`P0oooo0ol00?oJ0?ooo`4000000@3oool000030000003oool0oooo01<0
oooo1Ol00?lD0?ooo`Go003o00<0ooooo`00ool00?l00ol00?l60?ooo`Go003of@3oool100000040
oooo00000`000000oooo0?ooo`0C0?ooo`Go003o5@3oool3o`00o`<0oooo1Ol00?l50?ooo`Go003o
f@3oool100000040oooo00000`000000oooo0?ooo`0C0?ooo`Go003o6P3oool6o`00o`D0oooo1Ol0
0?l80?ooo`?o003o2@3oool3o`00o`D0oooo0ol00?nj0?ooo`4000000@3oool000030000003oool0
oooo01@0oooo0ol00?l>0?ooo`?o003o2P3oool6o`00o`H0oooo0ol00?l80?ooo`Go003o1`3oool6
o`00o`80oooo1Ol00?ni0?ooo`4000000@3oool000030000003oool0oooo02@0oooo1Ol00?l90?oo
o`Ko003o4@3oool5o`00o`L0oooo1ol00?l00`3ooooo003oo`00o`03o`00okT0oooo0@0000010?oo
o`0000<000000?ooo`3oool0903oool5o`00o`X0oooo1_l00?l@0?ooo`Go003o1`3oool7o`00o`03
0?ooool00?oo003o00?o003o^@3oool100000040oooo00000`000000oooo0?ooo`0S0?ooo`Ko003o
2@3oool7o`00oa40oooo0ol00?l90?ooo`Ko003o0P3oool3o`00okX0oooo0@0000010?ooo`0000<0
00000?ooo`3oool08`3oool5o`00o`X0oooo1ol00?lB0?ooo`?o003o2P3oool3o`00ol00oooo0@00
00010?ooo`0000<000000?ooo`3oool08`3oool5o`00o`X0oooo2?l00?l=0?ooo`So003o203oool3
o`00ol40oooo0@0000010?ooo`0000<000000?ooo`3oool08`3oool5o`00o`H0oooo0ol00?l20?oo
o`Wo003o2P3oool9o`00o`L0oooo1Ol00?o00?ooo`4000000@3oool000030000003oool0oooo02<0
oooo1Ol00?l50?ooo`Go003o00<0ooooo`00ool00?l02?l00?l90?ooo`Wo003o1`3oool5o`00o`H0
oooo0ol00?ng0?ooo`4000000@3oool000030000003oool0oooo02<0oooo1Ol00?l50?ooo`Go003o
00<0ooooo`00ool00?l02?l00?l90?ooo`So003o203oool5o`00o`D0oooo1Ol00?nf0?ooo`400000
0@3oool000030000003oool0oooo02@0oooo0ol00?l60?ooo`Go003o00<0ooooo`00ool00?l02?l0
0?l:0?ooo`?o003o2P3oool6o`00o`H0oooo1Ol00?nf0?ooo`4000000@3oool000030000003oool0
oooo00d0oooo0ol00?l>0?ooo`Co003o303oool4o`00o`80oooo0ol00?l20?ooo`?o003o1`3oool3
o`00o`d0oooo1Ol00?l80?ooo`Go003o]P3oool100000040oooo00000`000000oooo0?ooo`0<0?oo
o`Go003o303oool6o`00o`030?ooool00?oo003o00?o003o1@3oool5o`00o`H0oooo0ol00?l60?oo
o`Go003o303oool5o`00o`T0oooo0ol00?ng0?ooo`4000000@3oool000030000003oool0oooo00`0
oooo1Ol00?l70?ooo`?o003o0P3oool=o`00o`@0oooo1Ol00?l50?ooo`Go003o1@3oool5o`00o``0
oooo1Ol00?o30?ooo`4000000@3oool000030000003oool0oooo00`0oooo1Ol00?l60?ooo`Go003o
00<0ooooo`00ool00?l02ol00?l20?ooo`Oo003o1@3oool5o`00o`D0oooo1Ol00?l=0?ooo`?o003o
5`3oool3o`00ojX0oooo0@0000010?ooo`0000<000000?ooo`3oool03@3oool3o`00o`L0oooo1Ol0
0?l20?ooo`Co003o00<0ooooo`00ool00?l01Ol00?l00`3ooooo003oo`00o`05o`00o`H0oooo1Ol0
0?l60?ooo`?o003o3@3oool3o`00oaL0oooo1Ol00?nY0?ooo`4000000@3oool000030000003oool0
oooo01L0oooo1Ol00?l80?ooo`Go003o0P3oool5o`00o`T0oooo0ol00?l30?ooo`?o003o403oool5
o`00oaH0oooo1Ol00?nY0?ooo`4000000@3oool000030000003oool0oooo01P0oooo0ol00?l@0?oo
o`Go003o3@3oool6o`00o`l0oooo1Ol00?lF0?ooo`Go003oZ@3oool100000040oooo00000`000000
oooo0?ooo`0O0?ooo`?o003o2P3oool3o`00o`d0oooo1ol00?l?0?ooo`Go003o5`3oool3o`00ojX0
oooo0@0000010?ooo`0000<000000?ooo`3oool00ol00?lK0?ooo`Go003o6@3oool7o`00oa00oooo
0ol00?o50?ooo`4000000@3oool000030000003ooooo003o00Co003o6P3oool5o`00oaT0oooo1_l0
0?l0103ooooo003oo`00ool00?oE0?ooo`4000000@3oool000030000003ooooo003o00Co003o6P3o
ool5o`00oaX0oooo0ol00?l20?ooo`Go003o1P3oool3o`00ol/0oooo0@0000010?ooo`0000<00000
0?ooool00?l01?l00?lK0?ooo`?o003o803oool5o`00o`D0oooo1Ol00?ll0?ooo`?o003oR`3oool1
00000040oooo00000`000000oooo0?ooo`03o`00ocl0oooo1Ol00?l50?ooo`Go003o>`3oool5o`00
ohX0oooo0@0000010?ooo`0000<000000?ooo`3oool0>03oool3o`00o`P0oooo0ol00?l60?ooo`Go
003o403oool3o`00obP0oooo1Ol00?n:0?ooo`4000000@3oool000030000003oool0oooo03L0oooo
1Ol00?l60?ooo`Go003o1P3oool3o`00oa00oooo1Ol00?lW0?ooo`Go003oRP3oool100000040oooo
00000`000000oooo0?ooo`0_0?ooo`?o003o1@3oool5o`00o`H0oooo1Ol00?lI0?ooo`Go003o:03o
ool3o`00oh/0oooo0@0000010?ooo`0000<000000?ooo`3oool0;P3oool5o`00o`@0oooo1Ol00?l6
0?ooo`Go003o2@3oool5o`00o`/0oooo1Ol00?nf0?ooo`4000000@3oool000030000003oool0oooo
02h0oooo1Ol00?l50?ooo`?o003o203oool3o`00o`T0oooo1ol00?l;0?ooo`Go003o]@3oool10000
0040oooo00000`000000oooo0?ooo`0^0?ooo`Go003o703oool7o`00o``0oooo1Ol00?l40?ooo`?o
003o[@3oool100000040oooo00000`000000oooo0?ooo`0_0?ooo`?o003o0P3oool3o`00oaP0oooo
1ol00?l<0?ooo`go003o[03oool100000040oooo00000`000000oooo0?ooo`0c0?ooo`Go003o2`3o
ool3o`00o`X0oooo1_l00?l<0?ooo`go003o[03oool100000040oooo00000`000000oooo0?ooo`0c
0?ooo`Go003o2P3oool5o`00o`/0oooo0ol00?l>0?ooo`ko003oZP3oool100000040oooo00000`00
0000oooo0?ooo`0c0?ooo`Go003o2P3oool5o`00oah0oooo3Ol00?l:0?ooo`?o003oW03oool10000
0040oooo00000`000000oooo0?ooo`0d0?ooo`?o003o2`3oool5o`00oal0oooo1_l00?l00`3ooooo
003oo`00o`03o`00o`T0oooo1Ol00?nK0?ooo`4000000@3oool000030000003oool0oooo04<0oooo
1?l00?lO0?ooo`Go003o0P3oool5o`00o`T0oooo1Ol00?nK0?ooo`4000000@3oool000030000003o
ool0oooo02/0oooo0ol00?lE0?ooo`Go003o7P3oool5o`00o`<0oooo0ol00?l:0?ooo`Go003oV`3o
ool100000040oooo00000`000000oooo0?ooo`0Z0?ooo`Go003o503oool5o`00oaX0oooo0ol00?l0
0`3ooooo003oo`00o`05o`00o`l0oooo0ol00?nL0?ooo`4000000@3oool000030000003oool0oooo
02X0oooo1Ol00?lD0?ooo`Go003o6@3oool5o`00o`030?ooool00?oo003o00Go003o[@3oool10000
0040oooo00000`000000oooo0?ooo`0Z0?ooo`Go003o5@3oool3o`00oaX0oooo1_l00?l20?ooo`Go
003o[@3oool100000040oooo00000`000000oooo0?ooo`0[0?ooo`?o003o6P3oool3o`00oaH0oooo
1_l00?l20?ooo`Go003o[@3oool100000040oooo00000`000000oooo0?ooo`170?ooo`Go003o5P3o
ool5o`00o`<0oooo0ol00?lF0?ooo`?o003oU@3oool100000040oooo00000`000000oooo0?ooo`0l
0?ooo`?o003o203oool5o`00oaL0oooo0ol00?l50?ooo`?o003o503oool5o`00oi@0oooo0@000001
0?ooo`0000<000000?ooo`3oool0>`3oool5o`00o`L0oooo1Ol00?lJ0?ooo`?o003o00<0ooooo`00
ool00?l00ol00?l40?ooo`?o003o1@3oool3o`00o`@0oooo1Ol00?nD0?ooo`4000000@3oool00003
0000003oool0oooo03/0oooo1Ol00?l80?ooo`?o003o6P3oool:o`00o`<0oooo1Ol00?l30?ooo`Go
003o0`3oool5o`00oi@0oooo0@0000010?ooo`0000<000000?ooo`3oool0>`3oool5o`00obD0oooo
2_l00?l30?ooo`Go003o0`3oool5o`00o`@0oooo0ol00?nE0?ooo`4000000@3oool000030000003o
ool0oooo03`0oooo0ol00?lV0?ooo`Go003o00<0ooooo`00ool00?l00ol00?l20?ooo`Oo003o00<0
ooooo`00ool00?l00ol00?nL0?ooo`4000000@3oool000030000003oool0oooo0680oooo2?l00?l2
0?ooo`Go003o0P3oool7o`00o`040?ooool00?oo003oo`00oid0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0H@3oool9o`00o`80oooo1Ol00?l40?ooo`Go003oX@3oool100000040oooo00000`00
0000oooo0?ooo`1Q0?ooo`[o003o00<0ooooo`00ool00?l00ol00?l40?ooo`Go003o3`3oool3o`00
ohl0oooo0@0000010?ooo`0000<000000?ooo`3oool0CP3oool3o`00oa00oooo2_l00?l00`3ooooo
003oo`00o`04o`00o`@0oooo0ol00?l?0?ooo`Go003oSP3oool100000040oooo00000`000000oooo
0?ooo`1=0?ooo`Go003o403oool3o`00o`030?ooool00?oo003o00?o003o00<0ooooo`00ool00?l0
1?l00?lF0?ooo`Go003oSP3oool100000040oooo00000`000000oooo0?ooo`1=0?ooo`Go003o5@3o
ool3o`00o`<0oooo1Ol00?lF0?ooo`Go003oSP3oool100000040oooo00000`000000oooo0?ooo`1=
0?ooo`Go003o703oool3o`00oaP0oooo0ol00?n?0?ooo`4000000@3oool000030000003oool0oooo
04h0oooo0ol00?l^0?ooo`?o003oV@3oool100000040oooo00000`000000oooo0?ooo`1F0?ooo`?o
003o9@3oool5o`00oiP0oooo0@0000010?ooo`0000<000000?ooo`3oool0E@3oool5o`00ob@0oooo
1Ol00?nH0?ooo`4000000@3oool000030000003oool0oooo05D0oooo1Ol00?lT0?ooo`Go003oV03o
ool100000040oooo00000`000000oooo0?ooo`1E0?ooo`Go003o9@3oool3o`00oiT0oooo0@000001
0?ooo`0000<000000?ooo`3oool0EP3oool3o`00o`P0oooo0ol00?ng0?ooo`4000000@3oool00003
0000003oool0oooo0600oooo1Ol00?l>0?ooo`?o003oY@3oool100000040oooo00000`000000oooo
0?ooo`1P0?ooo`Go003o3@3oool5o`00oj@0oooo0@0000010?ooo`0000<000000?ooo`3oool0H03o
ool5o`00o`d0oooo1Ol00?nT0?ooo`4000000@3oool000030000003oool0oooo0640oooo0ol00?l>
0?ooo`Go003oY03oool100000040oooo00000`000000oooo0?ooo`1c0?ooo`?o003oY@3oool10000
0040oooo00000`000000oooo0?ooo`2<0?ooo`?o003oDP3oool3ool003L0oooo0@0000010?ooo`00
00<000000?ooo`3oool0R`3oool5o`00oe00oooo1Ooo000f0?ooo`4000000@3oool000030000003o
ool0oooo08/0oooo1Ol00?m@0?ooo`Goo`00=P3oool100000040oooo00000`000000oooo0?ooo`1l
0?ooo`?o003o303oool5o`00oe00oooo1Ooo000f0?ooo`4000000@3oool000030000003oool0oooo
07/0oooo1Ol00?l<0?ooo`?o003oDP3oool3ool003L0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0JP3oool3o`00o`h0oooo1Ol00?nK0?ooo`4000000@3oool000030000003oool0oooo06T0oooo
1Ol00?l=0?ooo`Go003oU@3oool3ool000<0oooo0@0000010?ooo`0000<000000?ooo`3oool0J@3o
ool5o`00o`h0oooo0ol00?nE0?ooo`Goo`000P3oool100000040oooo00000`000000oooo0?ooo`1Y
0?ooo`Go003oGP3oool3ool004D0oooo1Ooo00020?ooo`4000000@3oool000030000003oool0oooo
06X0oooo0ol00?mN0?ooo`Goo`00A03oool5ool00080oooo0@0000010?ooo`0000<000000?ooo`3o
ool0b`3oool5ool004D0oooo0ooo00030?ooo`4000000@3oool000030000003oool0oooo0</0oooo
1Ooo001;0?ooo`4000000@3oool000030000003oool0oooo0<`0oooo0ooo001<0?ooo`4000000@3o
ool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oo
oa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000
003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@00
00010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo
0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?ooo`L0oooo0ooo000B0?ooo`40
00000@3oool000030000003oool0oooo0?l0oooo1P3oool5ool00140oooo0@0000010?ooo`0000<0
00000?ooo`3oool0f03oool3ool002X0oooo1Ooo000A0?ooo`4000000@3oool000030000003oool0
oooo0;@0oooo0ooo000P0?ooo`Goo`00:@3oool5ool00140oooo0@0000010?ooo`0000<000000?oo
o`3oool0/`3oool5ool001l0oooo1Ooo000Z0?ooo`?oo`004P3oool100000040oooo00000`000000
oooo0?ooo`2c0?ooo`Goo`007`3oool5ool003l0oooo0@0000010?ooo`0000<000000?ooo`3oool0
/`3oool5ool00200oooo0ooo00100?ooo`4000000@3oool000030000003oool0oooo0;@0oooo0ooo
001T0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`00
0000oooo0?ooo`3M0?ooo`?oo`00>`3oool100000040oooo00000`000000oooo0?ooo`3L0?ooo`Go
o`00>P3oool100000040oooo00000`000000oooo0?ooo`2h0?ooo`?oo`001`3oool3ool001L0oooo
1Ooo000j0?ooo`4000000@3oool000030000003oool0oooo0;L0oooo1Ooo00050?ooo`Goo`005P3o
ool5ool003X0oooo0@0000010?ooo`0000<000000?ooo`3oool0]`3oool5ool000D0oooo1Ooo000G
0?ooo`?oo`00>`3oool100000040oooo00000`000000oooo0?ooo`2]0?ooo`?oo`001`3oool5ool0
00D0oooo1Ooo001E0?ooo`4000000@3oool000030000003oool0oooo0:`0oooo1Ooo00070?ooo`?o
o`001`3oool3ool001@0oooo0ooo000]0?ooo`?oo`003`3oool100000040oooo00000`000000oooo
0?ooo`2/0?ooo`Goo`009`3oool5ool002/0oooo1Ooo000>0?ooo`4000000@3oool000030000003o
ool0oooo0:`0oooo1Ooo000W0?ooo`Goo`00:`3oool5ool000h0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0[@3oool3ool002P0oooo1Ooo00080?ooo`?oo`00803oool5ool000h0oooo0@000001
0?ooo`0000<000000?ooo`3oool0f@3oool3ool000P0oooo1Ooo000P0?ooo`?oo`003`3oool10000
0040oooo00000`000000oooo0?ooo`3T0?ooo`Goo`00103oool3ool002/0oooo0@0000010?ooo`00
00<000000?ooo`3oool0_03oool3ool002D0oooo1Ooo00030?ooo`Goo`00:P3oool100000040oooo
00000`000000oooo0?ooo`2F0?ooo`?oo`004`3oool3ool000`0oooo1Ooo000B0?ooo`?oo`00403o
ool3ool000@0oooo1Ooo000Z0?ooo`4000000@3oool000030000003oool0oooo09D0oooo1Ooo000A
0?ooo`Goo`002`3oool5ool000/0oooo0ooo00030?ooo`Goo`005P3oool5ool002X0oooo0@000001
0?ooo`0000<000000?ooo`3oool0U@3oool5ool00140oooo1Ooo000;0?ooo`Goo`002P3oool5ool0
0080oooo1Ooo000G0?ooo`?oo`00:`3oool100000040oooo00000`000000oooo0?ooo`2E0?ooo`Go
o`004@3oool5ool000`0oooo0ooo0000103oooooo`00ool00?oo00070?ooo`Goo`000P3oool5ool0
04D0oooo0@0000010?ooo`0000<000000?ooo`3oool0UP3oool3ool001<0oooo0ooo00050?ooo`?o
o`00203oool5ool000H0oooo1Ooo00030?ooo`?oo`00AP3oool100000040oooo00000`000000oooo
0?ooo`2c0?ooo`Goo`001`3oool5ool000L0oooo0ooo001=0?ooo`4000000@3oool000030000003o
ool0oooo0;<0oooo1Ooo00070?ooo`Goo`00E`3oool100000040oooo00000`000000oooo0?ooo`2c
0?ooo`Goo`00203oool3ool000d0oooo0ooo00180?ooo`4000000@3oool000030000003oool0oooo
0;@0oooo0ooo000H0?ooo`Goo`00603oool3ool002`0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0X`3oool3ool001<0oooo0ooo000C0?ooo`Goo`005`3oool5ool002/0oooo0@0000010?ooo`00
00<000000?ooo`3oool0XP3oool5ool00140oooo1Ooo000B0?ooo`Goo`005`3oool5ool002/0oooo
0@0000010?ooo`0000<000000?ooo`3oool0T`3oool3ool000`0oooo1Ooo000A0?ooo`Goo`004`3o
ool3ool001P0oooo1Ooo000[0?ooo`4000000@3oool000030000003oool0oooo0980oooo1_oo000:
0?ooo`Goo`004@3oool5ool002l0oooo0ooo000/0?ooo`4000000@3oool000030000003oool0oooo
0980oooo1ooo000:0?ooo`?oo`002@3oool3ool000L0oooo0ooo000S0?ooo`?oo`001`3oool3ool0
02l0oooo0@0000010?ooo`0000<000000?ooo`3oool0TP3oool7ool000T0oooo0ooo00090?ooo`Go
o`001@3oool3ool000<0oooo0ooo000M0?ooo`Goo`001@3oool5ool002h0oooo0@0000010?ooo`00
00<000000?ooo`3oool0T`3oool6ool000P0oooo1Ooo00080?ooo`Goo`00103oool5ool000030?oo
oooo003oo`0000?oo`00703oool5ool000D0oooo1Ooo000^0?ooo`4000000@3oool000030000003o
ool0oooo09D0oooo0ooo00020?ooo`?oo`00103oool5ool000P0oooo1Ooo00040?ooo`Goo`0000<0
ooooool00?oo00000ooo000L0?ooo`Goo`000`3oool7ool002h0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0V@3oool5ool000<0oooo2?oo00060?ooo`?oo`001@3oool5ool000030?oooooo003o
o`0000?oo`004`3oool3ool000L0oooo0ooo00030?ooo`Ooo`00;`3oool100000040oooo00000`00
0000oooo0?ooo`2I0?ooo`Goo`0000<0ooooool00?oo00002Ooo000>0?ooo`?oo`000`3oool3ool0
01<0oooo1Ooo000<0?ooo`Goo`00<@3oool100000040oooo00000`000000oooo0?ooo`2I0?oooa7o
o`00:P3oool5ool000`0oooo1Ooo000a0?ooo`4000000@3oool000030000003oool0oooo0840oooo
0ooo000F0?ooo`?oo`0000<0ooooool00?oo00002_oo000Z0?ooo`Goo`003@3oool3ool00380oooo
0@0000010?ooo`0000<000000?ooo`3oool0P03oool5ool000d0oooo0ooo00090?ooo`Ooo`0000@0
ooooool00?oo003oo`007`3oool3ool000X0oooo0ooo00130?ooo`4000000@3oool000030000003o
ool0oooo0800oooo1Ooo000<0?ooo`Goo`002@3oool3ool001d0oooo0ooo00050?ooo`Goo`00C`3o
ool100000040oooo00000`000000oooo0?ooo`200?ooo`Goo`00303oool5ool002P0oooo1Ooo0004
0?ooo`Goo`00C`3oool100000040oooo00000`000000oooo0?ooo`210?ooo`?oo`003@3oool5ool0
02P0oooo1Ooo00040?ooo`Goo`00C`3oool100000040oooo00000`000000oooo0?ooo`2B0?ooo`?o
o`002`3oool3ool00080oooo0ooo000;0?ooo`?oo`00203oool5ool000D0oooo0ooo001@0?ooo`40
00000@3oool000030000003oool0oooo09l0oooo2_oo00050?ooo`?oo`0000<0ooooool00?oo0000
0ooo00080?ooo`?oo`00F@3oool100000040oooo00000`000000oooo0?ooo`2O0?ooo`[oo`00103o
ool:ool00100oooo0ooo001A0?ooo`4000000@3oool000030000003oool0oooo09l0oooo2_oo0004
0?ooo`[oo`003`3oool5ool00500oooo0@0000010?ooo`0000<000000?ooo`3oool0U@3oool3ool0
00L0oooo2Ooo00050?ooo`Goo`0000<0ooooool00?oo00000ooo000>0?ooo`Goo`00D03oool10000
0040oooo00000`000000oooo0?ooo`2D0?ooo`Goo`001`3oool8ool000H0oooo0ooo00020?ooo`So
o`002`3oool5ool00500oooo0@0000010?ooo`0000<000000?ooo`3oool0U03oool5ool000X0oooo
1Ooo000;0?ooo`Woo`002`3oool3ool00540oooo0@0000010?ooo`0000<000000?ooo`3oool0U03o
ool5ool000X0oooo1Ooo000;0?ooo`Woo`00G`3oool100000040oooo00000`000000oooo0?ooo`2E
0?ooo`?oo`00303oool3ool000`0oooo2Ooo001O0?ooo`4000000@3oool000030000003oool0oooo
08d0oooo0ooo000F0?ooo`?oo`002P3oool8ool001<0oooo0ooo001:0?ooo`4000000@3oool00003
0000003oool0oooo08`0oooo1Ooo000;0?ooo`?oo`001P3oool7ool000P0oooo2?oo000A0?ooo`Go
o`006`3oool3ool002/0oooo0@0000010?ooo`0000<000000?ooo`3oool0S03oool5ool000X0oooo
1ooo00030?ooo`Soo`00203oool7ool00140oooo1Ooo000J0?ooo`Goo`00:P3oool100000040oooo
00000`000000oooo0?ooo`2<0?ooo`Goo`002P3oool8ool00080oooo2?oo00090?ooo`Koo`004@3o
ool5ool001X0oooo1Ooo000Z0?ooo`4000000@3oool000030000003oool0oooo08`0oooo1?oo0008
0?ooo`_oo`000`3oool7ool000/0oooo0ooo000<0?ooo`?oo`00103oool3ool001/0oooo1Ooo000Z
0?ooo`4000000@3oool000030000003oool0oooo08/0oooo1Ooo00070?ooo`coo`001P3oool3ool0
01X0oooo1Ooo000R0?ooo`?oo`001`3oool3ool00240oooo0@0000010?ooo`0000<000000?ooo`3o
ool0P03oool3ool000L0oooo1_oo00070?ooo`Goo`000`3oool3ool002@0oooo1Ooo000[0?ooo`Go
o`00803oool100000040oooo00000`000000oooo0?ooo`1o0?ooo`Goo`001P3oool6ool000D0oooo
1ooo000Z0?ooo`Goo`00:`3oool5ool00200oooo0@0000010?ooo`0000<000000?ooo`3oool0O`3o
ool6ool000D0oooo1Ooo00050?ooo`Ooo`00;03oool3ool002`0oooo1Ooo000P0?ooo`4000000@3o
ool000030000003oool0oooo07l0oooo1_oo00060?ooo`?oo`001P3oool5ool00140oooo0ooo000B
0?ooo`?oo`00=@3oool3ool00240oooo0@0000010?ooo`0000<000000?ooo`3oool0KP3oool3ool0
00l0oooo2?oo000<0?ooo`Koo`003`3oool5ool00100oooo1Ooo001H0?ooo`4000000@3oool00003
0000003oool0oooo06d0oooo1Ooo000?0?ooo`Soo`001P3oool3ool000<0oooo1Ooo000?0?ooo`Go
o`00403oool5ool005P0oooo0@0000010?ooo`0000<000000?ooo`3oool0K@3oool5ool00180oooo
1Ooo00050?ooo`Goo`000P3oool5ool000l0oooo1Ooo000@0?ooo`Goo`004`3oool3ool00480oooo
0@0000010?ooo`0000<000000?ooo`3oool0K@3oool5ool00180oooo1Ooo00050?ooo`Goo`000`3o
ool3ool00140oooo0ooo000B0?ooo`?oo`004`3oool5ool00440oooo0@0000010?ooo`0000<00000
0?ooo`3oool0KP3oool3ool001@0oooo0ooo00060?ooo`Goo`00403oool3ool000@0oooo0ooo000X
0?ooo`Goo`00@@3oool100000040oooo00000`000000oooo0?ooo`2?0?ooo`?oo`00403oool5ool0
0080oooo1Ooo000W0?ooo`Goo`00@@3oool100000040oooo00000`000000oooo0?ooo`230?ooo`?o
o`00703oool5ool00080oooo1Ooo000X0?ooo`?oo`00@P3oool100000040oooo00000`000000oooo
0?ooo`1Q0?ooo`?oo`007P3oool5ool000L0oooo0ooo000A0?ooo`Koo`0000<0ooooool00?oo0000
0ooo001]0?ooo`4000000@3oool000030000003oool0oooo0600oooo1Ooo000M0?ooo`Goo`001P3o
ool5ool000@0oooo0ooo00080?ooo`coo`00KP3oool100000040oooo00000`000000oooo0?ooo`1P
0?ooo`Goo`007@3oool5ool000H0oooo1Ooo00030?ooo`Goo`001P3oool=ool006h0oooo0@000001
0?ooo`0000<000000?ooo`3oool0H03oool5ool001h0oooo0ooo00070?ooo`Goo`000`3oool5ool0
00H0oooo1ooo00000`3oooooo`00ool00003ool006h0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0H@3oool3ool002X0oooo0ooo00040?ooo`Goo`001P3oool5ool000@0oooo0ooo001_0?ooo`40
00000@3oool000030000003oool0oooo0980oooo0ooo0000103oooooo`00ool00?oo00080?ooo`?o
o`00M`3oool100000040oooo00000`000000oooo0?ooo`280?ooo`?oo`001P3oool5ool008D0oooo
0@0000010?ooo`0000<000000?ooo`3oool0Q`3oool5ool000D0oooo1Ooo00050?ooo`?oo`00O@3o
ool100000040oooo00000`000000oooo0?ooo`270?ooo`Goo`001@3oool5ool000@0oooo1Ooo001l
0?ooo`4000000@3oool000030000003oool0oooo08L0oooo1Ooo00060?ooo`?oo`001@3oool5ool0
01@0oooo0ooo001U0?ooo`4000000@3oool000030000003oool0oooo08P0oooo0ooo000?0?ooo`Go
o`004`3oool5ool006@0oooo0@0000010?ooo`0000<000000?ooo`3oool0V`3oool3ool001@0oooo
1Ooo001T0?ooo`4000000@3oool000030000003oool0oooo08P0oooo0ooo000W0?ooo`Koo`00H`3o
ool100000040oooo00000`000000oooo0?ooo`270?ooo`Goo`009`3oool5ool006<0oooo0@000001
0?ooo`0000<000000?ooo`3oool0Q`3oool8ool002@0oooo1Ooo001S0?ooo`4000000@3oool00003
0000003oool0oooo08L0oooo2Ooo000T0?ooo`?oo`00I03oool100000040oooo00000`000000oooo
0?ooo`280?ooo`Soo`00R`3oool100000040oooo00000`000000oooo0?ooo`280?ooo`Soo`00R`3o
ool100000040oooo00000`000000oooo0?ooo`280?ooo`Ooo`00S03oool100000040oooo00000`00
0000oooo0?ooo`280?ooo`Goo`00SP3oool100000040oooo00000`000000oooo0?ooo`290?ooo`?o
o`00S`3oool100000040oooo00000`000000oooo0?ooo`3B0?ooo`?oo`00AP3oool100000040oooo
00000`000000oooo0?ooo`3A0?ooo`Goo`00A@3oool100000040oooo00000`000000oooo0?ooo`3A
0?ooo`Goo`00A@3oool100000040oooo00000`000000oooo0?ooo`3A0?ooo`Goo`00A@3oool10000
0040oooo00000`000000oooo0?ooo`3B0?ooo`?oo`00AP3oool100000040oooo00000`000000oooo
0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3o
ool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oo
oa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0R03oool3ool00900oooo0@0000010?ooo`00
00<000000?ooo`3oool0Q`3oool5ool008l0oooo0@0000010?ooo`0000<000000?ooo`3oool0Q`3o
ool5ool008l0oooo0@0000010?ooo`0000<000000?ooo`3oool0Q`3oool5ool008l0oooo0@000001
0?ooo`0000<000000?ooo`3oool0R03oool3ool00900oooo0@0000010?ooo`0000<000000?ooo`3o
ool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo
00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0T03oool3
ool008P0oooo0@0000010?ooo`0000<000000?ooo`3oool0S`3oool5ool008L0oooo0@0000010?oo
o`0000<000000?ooo`3oool0S`3oool5ool008L0oooo0@0000010?ooo`0000<000000?ooo`3oool0
S`3oool5ool008L0oooo0@0000010?ooo`0000<000000?ooo`3oool0T03oool3ool008P0oooo0@00
00010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo
0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`00
00<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703o
ool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?oo
o`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040
oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3o
oolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`00
0000oooo0?ooo`1b0?ooo`?oo`00YP3oool100000040oooo00000`000000oooo0?ooo`1a0?ooo`Go
o`00Y@3oool100000040oooo00000`000000oooo0?ooo`1a0?ooo`Goo`00Y@3oool100000040oooo
00000`000000oooo0?ooo`1a0?ooo`Goo`00Y@3oool100000040oooo00000`000000oooo0?ooo`1b
0?ooo`?oo`00YP3oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?oo
o`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo
703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool10000
0040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0
o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo0000
0`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?oo
o`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo
0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3o
ool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oo
oa`0oooo0@0000010?ooo`00o`00000P00000040oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Gaussian probability density functions", "Subsection"],

Cell[CellGroupData[{

Cell["Compute Gaussian pdfs", "Subsubsection"],

Cell[BoxData[{
    \(\(pdf1\  = \ gaussian[data1, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(pdf2\  = \ gaussian[data2, {x, y}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Gaussian pdfs", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[pdf1, pdf2, pr, x, y, yS, imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.68491 .46298 m
.70957 .45692 L
.73422 .45122 L
.75888 .44706 L
.78353 .44503 L
.80819 .44556 L
.83284 .44933 L
.8575 .45771 L
.86731 .46302 L
.88215 .47489 L
.89167 .48767 L
.9009 .51233 L
.90212 .53698 L
.89769 .56164 L
.889 .58629 L
.88215 .60204 L
.87695 .61095 L
.86127 .6356 L
.8575 .64134 L
.84242 .66026 L
.83284 .67188 L
.82069 .68491 L
.80819 .69771 L
.79573 .70957 L
.78353 .72028 L
.7673 .73422 L
.75888 .74049 L
.73521 .75888 L
.73422 .75946 L
.70957 .77559 L
.69777 .78353 L
.68491 .79017 L
.66026 .80466 L
.65403 .80819 L
.6356 .81598 L
.61095 .82772 L
.59945 .83284 L
.58629 .83678 L
.56164 .84496 L
.53698 .85234 L
.51494 .8575 L
.51233 .85784 L
.48767 .86079 L
.46302 .86215 L
.43836 .8611 L
.41538 .8575 L
.41371 .85669 L
.38905 .84664 L
.37076 .83284 L
.3644 .8262 L
.35503 .80819 L
.35001 .78353 L
.35161 .75888 L
.35803 .73422 L
.3644 .71644 L
.36813 .70957 L
.38225 .68491 L
.38905 .67384 L
.39921 .66026 L
.41371 .64171 L
.41912 .6356 L
.43836 .61484 L
.44229 .61095 L
.46302 .59154 L
.4689 .58629 L
.48767 .57099 L
.49923 .56164 L
.51233 .55257 L
.53359 .53698 L
.53698 .53514 L
.56164 .51987 L
.57362 .51233 L
.58629 .50642 L
.61095 .49317 L
.62155 .48767 L
.6356 .48258 L
.66026 .47237 L
.68475 .46302 L
F
0 g
.68491 .46298 m
.70957 .45692 L
.73422 .45122 L
.75888 .44706 L
.78353 .44503 L
.80819 .44556 L
.83284 .44933 L
.8575 .45771 L
.86731 .46302 L
.88215 .47489 L
.89167 .48767 L
.9009 .51233 L
.90212 .53698 L
.89769 .56164 L
.889 .58629 L
.88215 .60204 L
.87695 .61095 L
.86127 .6356 L
.8575 .64134 L
.84242 .66026 L
.83284 .67188 L
.82069 .68491 L
.80819 .69771 L
.79573 .70957 L
.78353 .72028 L
.7673 .73422 L
.75888 .74049 L
.73521 .75888 L
.73422 .75946 L
.70957 .77559 L
.69777 .78353 L
.68491 .79017 L
.66026 .80466 L
.65403 .80819 L
.6356 .81598 L
.61095 .82772 L
.59945 .83284 L
.58629 .83678 L
.56164 .84496 L
.53698 .85234 L
.51494 .8575 L
.51233 .85784 L
.48767 .86079 L
.46302 .86215 L
.43836 .8611 L
.41538 .8575 L
.41371 .85669 L
.38905 .84664 L
.37076 .83284 L
.3644 .8262 L
Mistroke
.35503 .80819 L
.35001 .78353 L
.35161 .75888 L
.35803 .73422 L
.3644 .71644 L
.36813 .70957 L
.38225 .68491 L
.38905 .67384 L
.39921 .66026 L
.41371 .64171 L
.41912 .6356 L
.43836 .61484 L
.44229 .61095 L
.46302 .59154 L
.4689 .58629 L
.48767 .57099 L
.49923 .56164 L
.51233 .55257 L
.53359 .53698 L
.53698 .53514 L
.56164 .51987 L
.57362 .51233 L
.58629 .50642 L
.61095 .49317 L
.62155 .48767 L
.6356 .48258 L
.66026 .47237 L
.68475 .46302 L
.68491 .46298 L
Mfstroke
.2 g
.70957 .48737 m
.73422 .48352 L
.75888 .48176 L
.78353 .483 L
.80661 .48767 L
.80819 .48866 L
.83284 .50242 L
.84175 .51233 L
.85238 .53698 L
.85305 .56164 L
.84728 .58629 L
.83677 .61095 L
.83284 .61874 L
.822 .6356 L
.80819 .65475 L
.8036 .66026 L
.78353 .68271 L
.78136 .68491 L
.75888 .7062 L
.75505 .70957 L
.73422 .72648 L
.72422 .73422 L
.70957 .7443 L
.68802 .75888 L
.68491 .7606 L
.66026 .7746 L
.6439 .78353 L
.6356 .78713 L
.61095 .79797 L
.58629 .80774 L
.58507 .80819 L
.56164 .81478 L
.53698 .82058 L
.51233 .82437 L
.48767 .82556 L
.46302 .82339 L
.43836 .8163 L
.42385 .80819 L
.41371 .80004 L
.4039 .78353 L
.3986 .75888 L
.40116 .73422 L
.40919 .70957 L
.41371 .69865 L
.42171 .68491 L
.43803 .66026 L
.43836 .65979 L
.45847 .6356 L
.46302 .63055 L
.48256 .61095 L
.48767 .60624 L
.51069 .58629 L
.51233 .58504 L
.53698 .56656 L
.54385 .56164 L
.56164 .55043 L
.58329 .53698 L
.58629 .53549 L
.61095 .52289 L
.6327 .51233 L
.6356 .51126 L
.66026 .50206 L
.68491 .49377 L
.70785 .48767 L
F
0 g
.70957 .48737 m
.73422 .48352 L
.75888 .48176 L
.78353 .483 L
.80661 .48767 L
.80819 .48866 L
.83284 .50242 L
.84175 .51233 L
.85238 .53698 L
.85305 .56164 L
.84728 .58629 L
.83677 .61095 L
.83284 .61874 L
.822 .6356 L
.80819 .65475 L
.8036 .66026 L
.78353 .68271 L
.78136 .68491 L
.75888 .7062 L
.75505 .70957 L
.73422 .72648 L
.72422 .73422 L
.70957 .7443 L
.68802 .75888 L
.68491 .7606 L
.66026 .7746 L
.6439 .78353 L
.6356 .78713 L
.61095 .79797 L
.58629 .80774 L
.58507 .80819 L
.56164 .81478 L
.53698 .82058 L
.51233 .82437 L
.48767 .82556 L
.46302 .82339 L
.43836 .8163 L
.42385 .80819 L
.41371 .80004 L
.4039 .78353 L
.3986 .75888 L
.40116 .73422 L
.40919 .70957 L
.41371 .69865 L
.42171 .68491 L
.43803 .66026 L
.43836 .65979 L
.45847 .6356 L
.46302 .63055 L
.48256 .61095 L
Mistroke
.48767 .60624 L
.51069 .58629 L
.51233 .58504 L
.53698 .56656 L
.54385 .56164 L
.56164 .55043 L
.58329 .53698 L
.58629 .53549 L
.61095 .52289 L
.6327 .51233 L
.6356 .51126 L
.66026 .50206 L
.68491 .49377 L
.70785 .48767 L
.70957 .48737 L
Mfstroke
.3 g
.70957 .50787 m
.73422 .50514 L
.75888 .50561 L
.78353 .51093 L
.7874 .51233 L
.80819 .52507 L
.81622 .53698 L
.82285 .56164 L
.82011 .58629 L
.81121 .61095 L
.80819 .61777 L
.79723 .6356 L
.78353 .65478 L
.77891 .66026 L
.75888 .68225 L
.75617 .68491 L
.73422 .70493 L
.72869 .70957 L
.70957 .72425 L
.69568 .73422 L
.68491 .74107 L
.66026 .75603 L
.65522 .75888 L
.6356 .7685 L
.61095 .77963 L
.60137 .78353 L
.58629 .78844 L
.56164 .7954 L
.53698 .80026 L
.51233 .80239 L
.48767 .80097 L
.46302 .79416 L
.44643 .78353 L
.43836 .77407 L
.43138 .75888 L
.42969 .73422 L
.43547 .70957 L
.43836 .70005 L
.44684 .68491 L
.46275 .66026 L
.46302 .65989 L
.48326 .6356 L
.48767 .63082 L
.50811 .61095 L
.51233 .60721 L
.53698 .58698 L
.53788 .58629 L
.56164 .56972 L
.57403 .56164 L
.58629 .55464 L
.61095 .54123 L
.61942 .53698 L
.6356 .53015 L
.66026 .52062 L
.68491 .51295 L
.68628 .51233 L
F
0 g
.70957 .50787 m
.73422 .50514 L
.75888 .50561 L
.78353 .51093 L
.7874 .51233 L
.80819 .52507 L
.81622 .53698 L
.82285 .56164 L
.82011 .58629 L
.81121 .61095 L
.80819 .61777 L
.79723 .6356 L
.78353 .65478 L
.77891 .66026 L
.75888 .68225 L
.75617 .68491 L
.73422 .70493 L
.72869 .70957 L
.70957 .72425 L
.69568 .73422 L
.68491 .74107 L
.66026 .75603 L
.65522 .75888 L
.6356 .7685 L
.61095 .77963 L
.60137 .78353 L
.58629 .78844 L
.56164 .7954 L
.53698 .80026 L
.51233 .80239 L
.48767 .80097 L
.46302 .79416 L
.44643 .78353 L
.43836 .77407 L
.43138 .75888 L
.42969 .73422 L
.43547 .70957 L
.43836 .70005 L
.44684 .68491 L
.46275 .66026 L
.46302 .65989 L
.48326 .6356 L
.48767 .63082 L
.50811 .61095 L
.51233 .60721 L
.53698 .58698 L
.53788 .58629 L
.56164 .56972 L
.57403 .56164 L
.58629 .55464 L
Mistroke
.61095 .54123 L
.61942 .53698 L
.6356 .53015 L
.66026 .52062 L
.68491 .51295 L
.68628 .51233 L
.70957 .50787 L
Mfstroke
.4 g
.66026 .53541 m
.68491 .52863 L
.70957 .52427 L
.73422 .52314 L
.75888 .52665 L
.78064 .53698 L
.78353 .53967 L
.79701 .56164 L
.79797 .58629 L
.79079 .61095 L
.78353 .62824 L
.77771 .6356 L
.7595 .66026 L
.75888 .66101 L
.73622 .68491 L
.73422 .68681 L
.70957 .70796 L
.70751 .70957 L
.68491 .72574 L
.67189 .73422 L
.66026 .74095 L
.6356 .75407 L
.62557 .75888 L
.61095 .7648 L
.58629 .77351 L
.56164 .77996 L
.538 .78353 L
.53698 .78362 L
.51233 .78377 L
.50983 .78353 L
.48767 .77894 L
.46302 .76207 L
.46111 .75888 L
.45348 .73422 L
.45669 .70957 L
.46302 .69247 L
.46672 .68491 L
.48229 .66026 L
.48767 .65297 L
.50285 .6356 L
.51233 .62581 L
.52851 .61095 L
.53698 .60387 L
.5601 .58629 L
.56164 .58525 L
.58629 .56949 L
.59987 .56164 L
.61095 .55604 L
.6356 .54466 L
.65522 .53698 L
F
0 g
.66026 .53541 m
.68491 .52863 L
.70957 .52427 L
.73422 .52314 L
.75888 .52665 L
.78064 .53698 L
.78353 .53967 L
.79701 .56164 L
.79797 .58629 L
.79079 .61095 L
.78353 .62824 L
.77771 .6356 L
.7595 .66026 L
.75888 .66101 L
.73622 .68491 L
.73422 .68681 L
.70957 .70796 L
.70751 .70957 L
.68491 .72574 L
.67189 .73422 L
.66026 .74095 L
.6356 .75407 L
.62557 .75888 L
.61095 .7648 L
.58629 .77351 L
.56164 .77996 L
.538 .78353 L
.53698 .78362 L
.51233 .78377 L
.50983 .78353 L
.48767 .77894 L
.46302 .76207 L
.46111 .75888 L
.45348 .73422 L
.45669 .70957 L
.46302 .69247 L
.46672 .68491 L
.48229 .66026 L
.48767 .65297 L
.50285 .6356 L
.51233 .62581 L
.52851 .61095 L
.53698 .60387 L
.5601 .58629 L
.56164 .58525 L
.58629 .56949 L
.59987 .56164 L
.61095 .55604 L
.6356 .54466 L
.65522 .53698 L
Mistroke
.66026 .53541 L
Mfstroke
.5 g
.6356 .55739 m
.66026 .54848 L
.68491 .54215 L
.70957 .53902 L
.73422 .54009 L
.75888 .54779 L
.77153 .56164 L
.77782 .58629 L
.77284 .61095 L
.76068 .6356 L
.75888 .63873 L
.74257 .66026 L
.73422 .66981 L
.71876 .68491 L
.70957 .69306 L
.68853 .70957 L
.68491 .71212 L
.66026 .72806 L
.64954 .73422 L
.6356 .74126 L
.61095 .75213 L
.59224 .75888 L
.58629 .76047 L
.56164 .76603 L
.53698 .76835 L
.51233 .76594 L
.49311 .75888 L
.48767 .75358 L
.47584 .73422 L
.47562 .70957 L
.48416 .68491 L
.48767 .67678 L
.49915 .66026 L
.51233 .6434 L
.51984 .6356 L
.53698 .61897 L
.54646 .61095 L
.56164 .59916 L
.58029 .58629 L
.58629 .58259 L
.61095 .56872 L
.62538 .56164 L
F
0 g
.6356 .55739 m
.66026 .54848 L
.68491 .54215 L
.70957 .53902 L
.73422 .54009 L
.75888 .54779 L
.77153 .56164 L
.77782 .58629 L
.77284 .61095 L
.76068 .6356 L
.75888 .63873 L
.74257 .66026 L
.73422 .66981 L
.71876 .68491 L
.70957 .69306 L
.68853 .70957 L
.68491 .71212 L
.66026 .72806 L
.64954 .73422 L
.6356 .74126 L
.61095 .75213 L
.59224 .75888 L
.58629 .76047 L
.56164 .76603 L
.53698 .76835 L
.51233 .76594 L
.49311 .75888 L
.48767 .75358 L
.47584 .73422 L
.47562 .70957 L
.48416 .68491 L
.48767 .67678 L
.49915 .66026 L
.51233 .6434 L
.51984 .6356 L
.53698 .61897 L
.54646 .61095 L
.56164 .59916 L
.58029 .58629 L
.58629 .58259 L
.61095 .56872 L
.62538 .56164 L
.6356 .55739 L
s
.6 g
.66026 .56053 m
.68491 .55507 L
.70957 .55348 L
.73422 .55837 L
.74128 .56164 L
.75781 .58629 L
.75592 .61095 L
.74491 .6356 L
.73422 .65301 L
.72703 .66026 L
.70957 .67882 L
.70255 .68491 L
.68491 .69932 L
.67034 .70957 L
.66026 .71595 L
.6356 .72961 L
.62618 .73422 L
.61095 .74031 L
.58629 .74828 L
.56164 .75301 L
.53698 .7536 L
.51233 .74795 L
.49923 .73422 L
.49379 .70957 L
.5004 .68491 L
.51233 .66369 L
.5147 .66026 L
.5356 .6356 L
.53698 .63418 L
.56164 .61227 L
.56339 .61095 L
.58629 .59473 L
.6002 .58629 L
.61095 .58054 L
.6356 .56907 L
.656 .56164 L
F
0 g
.66026 .56053 m
.68491 .55507 L
.70957 .55348 L
.73422 .55837 L
.74128 .56164 L
.75781 .58629 L
.75592 .61095 L
.74491 .6356 L
.73422 .65301 L
.72703 .66026 L
.70957 .67882 L
.70255 .68491 L
.68491 .69932 L
.67034 .70957 L
.66026 .71595 L
.6356 .72961 L
.62618 .73422 L
.61095 .74031 L
.58629 .74828 L
.56164 .75301 L
.53698 .7536 L
.51233 .74795 L
.49923 .73422 L
.49379 .70957 L
.5004 .68491 L
.51233 .66369 L
.5147 .66026 L
.5356 .6356 L
.53698 .63418 L
.56164 .61227 L
.56339 .61095 L
.58629 .59473 L
.6002 .58629 L
.61095 .58054 L
.6356 .56907 L
.656 .56164 L
.66026 .56053 L
s
.7 g
.6356 .58049 m
.66026 .57219 L
.68491 .56764 L
.70957 .56757 L
.73422 .58387 L
.73582 .58629 L
.73895 .61095 L
.73422 .62595 L
.7296 .6356 L
.71191 .66026 L
.70957 .66307 L
.68652 .68491 L
.68491 .68625 L
.66026 .70432 L
.65165 .70957 L
.6356 .71821 L
.61095 .72903 L
.59829 .73422 L
.58629 .73621 L
.56164 .73962 L
.53698 .73673 L
.52869 .73422 L
.51275 .70957 L
.51636 .68491 L
.5298 .66026 L
.53698 .64964 L
.55092 .6356 L
.56164 .62541 L
.58034 .61095 L
.58629 .60679 L
.61095 .59182 L
.62167 .58629 L
F
0 g
.6356 .58049 m
.66026 .57219 L
.68491 .56764 L
.70957 .56757 L
.73422 .58387 L
.73582 .58629 L
.73895 .61095 L
.73422 .62595 L
.7296 .6356 L
.71191 .66026 L
.70957 .66307 L
.68652 .68491 L
.68491 .68625 L
.66026 .70432 L
.65165 .70957 L
.6356 .71821 L
.61095 .72903 L
.59829 .73422 L
.58629 .73621 L
.56164 .73962 L
.53698 .73673 L
.52869 .73422 L
.51275 .70957 L
.51636 .68491 L
.5298 .66026 L
.53698 .64964 L
.55092 .6356 L
.56164 .62541 L
.58034 .61095 L
.58629 .60679 L
.61095 .59182 L
.62167 .58629 L
.6356 .58049 L
s
.8 g
.66026 .58463 m
.68491 .58186 L
.70445 .58629 L
.70957 .5892 L
.72099 .61095 L
.71383 .6356 L
.70957 .6429 L
.69665 .66026 L
.68491 .67346 L
.66997 .68491 L
.66026 .69209 L
.6356 .7069 L
.63128 .70957 L
.61095 .71737 L
.58629 .7244 L
.56164 .72728 L
.53698 .71274 L
.53466 .70957 L
.5331 .68491 L
.53698 .67476 L
.54505 .66026 L
.56164 .63702 L
.56656 .6356 L
.58629 .61853 L
.59827 .61095 L
.61095 .60349 L
.6356 .59165 L
.65364 .58629 L
F
0 g
.66026 .58463 m
.68491 .58186 L
.70445 .58629 L
.70957 .5892 L
.72099 .61095 L
.71383 .6356 L
.70957 .6429 L
.69665 .66026 L
.68491 .67346 L
.66997 .68491 L
.66026 .69209 L
.6356 .7069 L
.63128 .70957 L
.61095 .71737 L
.58629 .7244 L
.56164 .72728 L
.53698 .71274 L
.53466 .70957 L
.5331 .68491 L
.53698 .67476 L
.54505 .66026 L
.56164 .63702 L
.56656 .6356 L
.58629 .61853 L
.59827 .61095 L
.61095 .60349 L
.6356 .59165 L
.65364 .58629 L
.66026 .58463 L
s
.9 g
.6356 .6043 m
.66026 .59583 L
.68491 .60023 L
.70178 .61095 L
.69696 .6356 L
.68491 .65409 L
.68032 .66026 L
.66026 .68276 L
.65195 .68491 L
.6356 .69475 L
.61095 .70693 L
.58629 .70925 L
.56164 .70427 L
.55158 .68491 L
.56164 .66083 L
.56192 .66026 L
.58405 .6356 L
.58629 .63351 L
.61095 .61392 L
.61683 .61095 L
F
0 g
.6356 .6043 m
.66026 .59583 L
.68491 .60023 L
.70178 .61095 L
.69696 .6356 L
.68491 .65409 L
.68032 .66026 L
.66026 .68276 L
.65195 .68491 L
.6356 .69475 L
.61095 .70693 L
.58629 .70925 L
.56164 .70427 L
.55158 .68491 L
.56164 .66083 L
.56192 .66026 L
.58405 .6356 L
.58629 .63351 L
.61095 .61392 L
.61683 .61095 L
.6356 .6043 L
s
1 g
.61095 .63117 m
.6356 .6207 L
.66026 .6177 L
.67392 .6356 L
.66026 .65891 L
.65899 .66026 L
.6356 .67798 L
.62128 .68491 L
.61095 .6899 L
.58629 .688 L
.58161 .68491 L
.5821 .66026 L
.58629 .65508 L
.60527 .6356 L
F
0 g
.61095 .63117 m
.6356 .6207 L
.66026 .6177 L
.67392 .6356 L
.66026 .65891 L
.65899 .66026 L
.6356 .67798 L
.62128 .68491 L
.61095 .6899 L
.58629 .688 L
.58161 .68491 L
.5821 .66026 L
.58629 .65508 L
.60527 .6356 L
.61095 .63117 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .15173 m
.02324 .16716 L
.03453 .19181 L
.04389 .20657 L
.05152 .21647 L
.06854 .23836 L
.07109 .24112 L
.0932 .26458 L
.09444 .26578 L
.11785 .2872 L
.12152 .29043 L
.1425 .30699 L
.15234 .31509 L
.16716 .32451 L
.18663 .33974 L
.19181 .34365 L
.21647 .35829 L
.22529 .3644 L
.24112 .37377 L
.26578 .38656 L
.26994 .38905 L
.29043 .39909 L
.31509 .4092 L
.32425 .41371 L
.33974 .41972 L
.3644 .42623 L
.38905 .43473 L
.40148 .43836 L
.41371 .43977 L
.43836 .44303 L
.46302 .44449 L
.48767 .44246 L
.50398 .43836 L
.51233 .43429 L
.53072 .41371 L
.53483 .38905 L
.52925 .3644 L
.51764 .33974 L
.51233 .32949 L
.50166 .31509 L
.48767 .29649 L
.48217 .29043 L
.46302 .26974 L
.45894 .26578 L
.43836 .24677 L
.432 .24112 L
.41371 .2267 L
.40139 .21647 L
.38905 .20879 L
.36754 .19181 L
.3644 .18937 L
.33974 .17482 L
.32881 .16716 L
.31509 .15889 L
.29043 .14614 L
.28443 .1425 L
.26578 .13325 L
.24112 .12311 L
.2306 .11785 L
.21647 .11228 L
.19181 .10565 L
.16716 .09689 L
.15491 .0932 L
.1425 .09168 L
.11785 .08813 L
.0932 .08626 L
.06854 .08769 L
.04701 .0932 L
.04389 .09484 L
.02164 .11785 L
.01923 .12533 L
F
0 g
.01923 .15173 m
.02324 .16716 L
.03453 .19181 L
.04389 .20657 L
.05152 .21647 L
.06854 .23836 L
.07109 .24112 L
.0932 .26458 L
.09444 .26578 L
.11785 .2872 L
.12152 .29043 L
.1425 .30699 L
.15234 .31509 L
.16716 .32451 L
.18663 .33974 L
.19181 .34365 L
.21647 .35829 L
.22529 .3644 L
.24112 .37377 L
.26578 .38656 L
.26994 .38905 L
.29043 .39909 L
.31509 .4092 L
.32425 .41371 L
.33974 .41972 L
.3644 .42623 L
.38905 .43473 L
.40148 .43836 L
.41371 .43977 L
.43836 .44303 L
.46302 .44449 L
.48767 .44246 L
.50398 .43836 L
.51233 .43429 L
.53072 .41371 L
.53483 .38905 L
.52925 .3644 L
.51764 .33974 L
.51233 .32949 L
.50166 .31509 L
.48767 .29649 L
.48217 .29043 L
.46302 .26974 L
.45894 .26578 L
.43836 .24677 L
.432 .24112 L
.41371 .2267 L
.40139 .21647 L
.38905 .20879 L
.36754 .19181 L
Mistroke
.3644 .18937 L
.33974 .17482 L
.32881 .16716 L
.31509 .15889 L
.29043 .14614 L
.28443 .1425 L
.26578 .13325 L
.24112 .12311 L
.2306 .11785 L
.21647 .11228 L
.19181 .10565 L
.16716 .09689 L
.15491 .0932 L
.1425 .09168 L
.11785 .08813 L
.0932 .08626 L
.06854 .08769 L
.04701 .0932 L
.04389 .09484 L
.02164 .11785 L
.01923 .12533 L
Mfstroke
.2 g
.11785 .11736 m
.14105 .11785 L
.1425 .11799 L
.16716 .12196 L
.19181 .12854 L
.21647 .13679 L
.23539 .1425 L
.24112 .14509 L
.26578 .15717 L
.28892 .16716 L
.29043 .16803 L
.31509 .18308 L
.33175 .19181 L
.33974 .19727 L
.3644 .21423 L
.36817 .21647 L
.38905 .23306 L
.39947 .24112 L
.41371 .25366 L
.42662 .26578 L
.43836 .27753 L
.44955 .29043 L
.46302 .30679 L
.46824 .31509 L
.48197 .33974 L
.48767 .35675 L
.489 .3644 L
.48767 .38234 L
.48519 .38905 L
.46302 .40854 L
.43836 .41316 L
.41371 .413 L
.38905 .40941 L
.3644 .40315 L
.33974 .39512 L
.31952 .38905 L
.31509 .38709 L
.29043 .37521 L
.26578 .3645 L
.26546 .3644 L
.24112 .34967 L
.22231 .33974 L
.21647 .3358 L
.19181 .31869 L
.18583 .31509 L
.16716 .30039 L
.15425 .29043 L
.1425 .28022 L
.12691 .26578 L
.11785 .25686 L
.10385 .24112 L
.0932 .22865 L
.08512 .21647 L
.07106 .19181 L
.06854 .18558 L
.06391 .16716 L
.06716 .1425 L
.06854 .13995 L
.0932 .12119 L
.11136 .11785 L
F
0 g
.11785 .11736 m
.14105 .11785 L
.1425 .11799 L
.16716 .12196 L
.19181 .12854 L
.21647 .13679 L
.23539 .1425 L
.24112 .14509 L
.26578 .15717 L
.28892 .16716 L
.29043 .16803 L
.31509 .18308 L
.33175 .19181 L
.33974 .19727 L
.3644 .21423 L
.36817 .21647 L
.38905 .23306 L
.39947 .24112 L
.41371 .25366 L
.42662 .26578 L
.43836 .27753 L
.44955 .29043 L
.46302 .30679 L
.46824 .31509 L
.48197 .33974 L
.48767 .35675 L
.489 .3644 L
.48767 .38234 L
.48519 .38905 L
.46302 .40854 L
.43836 .41316 L
.41371 .413 L
.38905 .40941 L
.3644 .40315 L
.33974 .39512 L
.31952 .38905 L
.31509 .38709 L
.29043 .37521 L
.26578 .3645 L
.26546 .3644 L
.24112 .34967 L
.22231 .33974 L
.21647 .3358 L
.19181 .31869 L
.18583 .31509 L
.16716 .30039 L
.15425 .29043 L
.1425 .28022 L
.12691 .26578 L
.11785 .25686 L
Mistroke
.10385 .24112 L
.0932 .22865 L
.08512 .21647 L
.07106 .19181 L
.06854 .18558 L
.06391 .16716 L
.06716 .1425 L
.06854 .13995 L
.0932 .12119 L
.11136 .11785 L
.11785 .11736 L
Mfstroke
.3 g
.11785 .14099 m
.1425 .1373 L
.16716 .13891 L
.18852 .1425 L
.19181 .14329 L
.21647 .1507 L
.24112 .16004 L
.26002 .16716 L
.26578 .16999 L
.29043 .18301 L
.3079 .19181 L
.31509 .19627 L
.33974 .21227 L
.34656 .21647 L
.3644 .22981 L
.37913 .24112 L
.38905 .24953 L
.40662 .26578 L
.41371 .27265 L
.42919 .29043 L
.43836 .30074 L
.44663 .31509 L
.45797 .33974 L
.45985 .3644 L
.43836 .38836 L
.43659 .38905 L
.41371 .3933 L
.38905 .39226 L
.36815 .38905 L
.3644 .38822 L
.33974 .38113 L
.31509 .37203 L
.29464 .3644 L
.29043 .36236 L
.26578 .34954 L
.2463 .33974 L
.24112 .33657 L
.21647 .32065 L
.20742 .31509 L
.19181 .30354 L
.17461 .29043 L
.16716 .28421 L
.14692 .26578 L
.1425 .26159 L
.12419 .24112 L
.11785 .23458 L
.10662 .21647 L
.09499 .19181 L
.0932 .1842 L
.09275 .16716 L
.0932 .16528 L
.11327 .1425 L
F
0 g
.11785 .14099 m
.1425 .1373 L
.16716 .13891 L
.18852 .1425 L
.19181 .14329 L
.21647 .1507 L
.24112 .16004 L
.26002 .16716 L
.26578 .16999 L
.29043 .18301 L
.3079 .19181 L
.31509 .19627 L
.33974 .21227 L
.34656 .21647 L
.3644 .22981 L
.37913 .24112 L
.38905 .24953 L
.40662 .26578 L
.41371 .27265 L
.42919 .29043 L
.43836 .30074 L
.44663 .31509 L
.45797 .33974 L
.45985 .3644 L
.43836 .38836 L
.43659 .38905 L
.41371 .3933 L
.38905 .39226 L
.36815 .38905 L
.3644 .38822 L
.33974 .38113 L
.31509 .37203 L
.29464 .3644 L
.29043 .36236 L
.26578 .34954 L
.2463 .33974 L
.24112 .33657 L
.21647 .32065 L
.20742 .31509 L
.19181 .30354 L
.17461 .29043 L
.16716 .28421 L
.14692 .26578 L
.1425 .26159 L
.12419 .24112 L
.11785 .23458 L
.10662 .21647 L
.09499 .19181 L
.0932 .1842 L
.09275 .16716 L
Mistroke
.0932 .16528 L
.11327 .1425 L
.11785 .14099 L
Mfstroke
.4 g
.1425 .15377 m
.16716 .15285 L
.19181 .15623 L
.21647 .16245 L
.2327 .16716 L
.24112 .17062 L
.26578 .18147 L
.28781 .19181 L
.29043 .19327 L
.31509 .20789 L
.32922 .21647 L
.33974 .22377 L
.36305 .24112 L
.3644 .24218 L
.38905 .26405 L
.39079 .26578 L
.41309 .29043 L
.41371 .29123 L
.42925 .31509 L
.4377 .33974 L
.43215 .3644 L
.41371 .37615 L
.38905 .37799 L
.3644 .37513 L
.33974 .36927 L
.32236 .3644 L
.31509 .36142 L
.29043 .35084 L
.26658 .33974 L
.26578 .33931 L
.24112 .32493 L
.2248 .31509 L
.21647 .30939 L
.19181 .29123 L
.19078 .29043 L
.16716 .26993 L
.16289 .26578 L
.1425 .24395 L
.14039 .24112 L
.12391 .21647 L
.11785 .20234 L
.11518 .19181 L
.11785 .17187 L
.12019 .16716 L
F
0 g
.1425 .15377 m
.16716 .15285 L
.19181 .15623 L
.21647 .16245 L
.2327 .16716 L
.24112 .17062 L
.26578 .18147 L
.28781 .19181 L
.29043 .19327 L
.31509 .20789 L
.32922 .21647 L
.33974 .22377 L
.36305 .24112 L
.3644 .24218 L
.38905 .26405 L
.39079 .26578 L
.41309 .29043 L
.41371 .29123 L
.42925 .31509 L
.4377 .33974 L
.43215 .3644 L
.41371 .37615 L
.38905 .37799 L
.3644 .37513 L
.33974 .36927 L
.32236 .3644 L
.31509 .36142 L
.29043 .35084 L
.26658 .33974 L
.26578 .33931 L
.24112 .32493 L
.2248 .31509 L
.21647 .30939 L
.19181 .29123 L
.19078 .29043 L
.16716 .26993 L
.16289 .26578 L
.1425 .24395 L
.14039 .24112 L
.12391 .21647 L
.11785 .20234 L
.11518 .19181 L
.11785 .17187 L
.12019 .16716 L
.1425 .15377 L
s
.5 g
.16716 .16688 m
.1878 .16716 L
.19181 .16755 L
.21647 .17251 L
.24112 .18063 L
.26578 .19068 L
.26848 .19181 L
.29043 .20311 L
.3137 .21647 L
.31509 .21734 L
.33974 .23434 L
.34877 .24112 L
.3644 .25384 L
.37693 .26578 L
.38905 .27712 L
.39877 .29043 L
.41363 .31509 L
.41371 .31528 L
.4182 .33974 L
.41371 .35057 L
.38905 .36338 L
.3644 .36364 L
.33974 .3591 L
.31509 .35135 L
.29043 .34154 L
.28608 .33974 L
.26578 .32948 L
.24112 .31549 L
.24043 .31509 L
.21647 .29889 L
.20505 .29043 L
.19181 .27989 L
.17666 .26578 L
.16716 .25748 L
.15461 .24112 L
.1425 .22255 L
.1395 .21647 L
.13437 .19181 L
.1425 .17622 L
.16484 .16716 L
F
0 g
.16716 .16688 m
.1878 .16716 L
.19181 .16755 L
.21647 .17251 L
.24112 .18063 L
.26578 .19068 L
.26848 .19181 L
.29043 .20311 L
.3137 .21647 L
.31509 .21734 L
.33974 .23434 L
.34877 .24112 L
.3644 .25384 L
.37693 .26578 L
.38905 .27712 L
.39877 .29043 L
.41363 .31509 L
.41371 .31528 L
.4182 .33974 L
.41371 .35057 L
.38905 .36338 L
.3644 .36364 L
.33974 .3591 L
.31509 .35135 L
.29043 .34154 L
.28608 .33974 L
.26578 .32948 L
.24112 .31549 L
.24043 .31509 L
.21647 .29889 L
.20505 .29043 L
.19181 .27989 L
.17666 .26578 L
.16716 .25748 L
.15461 .24112 L
.1425 .22255 L
.1395 .21647 L
.13437 .19181 L
.1425 .17622 L
.16484 .16716 L
.16716 .16688 L
s
.6 g
.16716 .18278 m
.19181 .17803 L
.21647 .18236 L
.24112 .18967 L
.24776 .19181 L
.26578 .19939 L
.29043 .21193 L
.29872 .21647 L
.31509 .22648 L
.33567 .24112 L
.33974 .24382 L
.36426 .26578 L
.3644 .26592 L
.38563 .29043 L
.38905 .29572 L
.39858 .31509 L
.39723 .33974 L
.38905 .3462 L
.3644 .35287 L
.33974 .34911 L
.31509 .34221 L
.30706 .33974 L
.29043 .33287 L
.26578 .32065 L
.25546 .31509 L
.24112 .30648 L
.21822 .29043 L
.21647 .28933 L
.19181 .26826 L
.18937 .26578 L
.16775 .24112 L
.16716 .24026 L
.15439 .21647 L
.15447 .19181 L
F
0 g
.16716 .18278 m
.19181 .17803 L
.21647 .18236 L
.24112 .18967 L
.24776 .19181 L
.26578 .19939 L
.29043 .21193 L
.29872 .21647 L
.31509 .22648 L
.33567 .24112 L
.33974 .24382 L
.36426 .26578 L
.3644 .26592 L
.38563 .29043 L
.38905 .29572 L
.39858 .31509 L
.39723 .33974 L
.38905 .3462 L
.3644 .35287 L
.33974 .34911 L
.31509 .34221 L
.30706 .33974 L
.29043 .33287 L
.26578 .32065 L
.25546 .31509 L
.24112 .30648 L
.21822 .29043 L
.21647 .28933 L
.19181 .26826 L
.18937 .26578 L
.16775 .24112 L
.16716 .24026 L
.15439 .21647 L
.15447 .19181 L
.16716 .18278 L
s
.7 g
.19181 .1919 m
.21647 .19261 L
.24112 .1978 L
.26578 .20796 L
.28366 .21647 L
.29043 .21992 L
.31509 .23561 L
.32274 .24112 L
.33974 .25334 L
.35199 .26578 L
.3644 .2795 L
.37267 .29043 L
.38338 .31509 L
.3644 .33811 L
.33974 .33859 L
.31509 .33406 L
.29043 .32429 L
.27069 .31509 L
.26578 .31261 L
.24112 .29748 L
.23114 .29043 L
.21647 .28043 L
.2016 .26578 L
.19181 .25529 L
.1806 .24112 L
.16967 .21647 L
F
0 g
.19181 .1919 m
.21647 .19261 L
.24112 .1978 L
.26578 .20796 L
.28366 .21647 L
.29043 .21992 L
.31509 .23561 L
.32274 .24112 L
.33974 .25334 L
.35199 .26578 L
.3644 .2795 L
.37267 .29043 L
.38338 .31509 L
.3644 .33811 L
.33974 .33859 L
.31509 .33406 L
.29043 .32429 L
.27069 .31509 L
.26578 .31261 L
.24112 .29748 L
.23114 .29043 L
.21647 .28043 L
.2016 .26578 L
.19181 .25529 L
.1806 .24112 L
.16967 .21647 L
.19181 .1919 L
s
.8 g
.19181 .21092 m
.21647 .20383 L
.24112 .20696 L
.26471 .21647 L
.26578 .21693 L
.29043 .2281 L
.30977 .24112 L
.31509 .24535 L
.33938 .26578 L
.33974 .2662 L
.35962 .29043 L
.364 .31509 L
.33974 .32692 L
.31509 .3248 L
.29043 .31525 L
.29 .31509 L
.26578 .30469 L
.24429 .29043 L
.24112 .28786 L
.21647 .26832 L
.21424 .26578 L
.19382 .24112 L
.19181 .23633 L
.18792 .21647 L
F
0 g
.19181 .21092 m
.21647 .20383 L
.24112 .20696 L
.26471 .21647 L
.26578 .21693 L
.29043 .2281 L
.30977 .24112 L
.31509 .24535 L
.33938 .26578 L
.33974 .2662 L
.35962 .29043 L
.364 .31509 L
.33974 .32692 L
.31509 .3248 L
.29043 .31525 L
.29 .31509 L
.26578 .30469 L
.24429 .29043 L
.24112 .28786 L
.21647 .26832 L
.21424 .26578 L
.19382 .24112 L
.19181 .23633 L
.18792 .21647 L
.19181 .21092 L
s
.9 g
.21647 .21884 m
.24112 .21874 L
.26578 .2266 L
.29043 .23858 L
.29435 .24112 L
.31509 .25635 L
.32654 .26578 L
.33974 .28322 L
.34413 .29043 L
.33974 .31001 L
.31509 .31259 L
.29043 .3055 L
.26578 .29439 L
.25944 .29043 L
.24112 .27714 L
.22681 .26578 L
.21647 .25254 L
.2085 .24112 L
F
0 g
.21647 .21884 m
.24112 .21874 L
.26578 .2266 L
.29043 .23858 L
.29435 .24112 L
.31509 .25635 L
.32654 .26578 L
.33974 .28322 L
.34413 .29043 L
.33974 .31001 L
.31509 .31259 L
.29043 .3055 L
.26578 .29439 L
.25944 .29043 L
.24112 .27714 L
.22681 .26578 L
.21647 .25254 L
.2085 .24112 L
.21647 .21884 L
s
1 g
.24112 .2341 m
.26578 .23841 L
.27237 .24112 L
.29043 .25127 L
.30891 .26578 L
.31509 .27316 L
.32151 .29043 L
.31509 .29592 L
.29043 .29351 L
.28235 .29043 L
.26578 .28164 L
.24468 .26578 L
.24112 .2619 L
.23106 .24112 L
F
0 g
.24112 .2341 m
.26578 .23841 L
.27237 .24112 L
.29043 .25127 L
.30891 .26578 L
.31509 .27316 L
.32151 .29043 L
.31509 .29592 L
.29043 .29351 L
.28235 .29043 L
.26578 .28164 L
.24468 .26578 L
.24112 .2619 L
.23106 .24112 L
.24112 .2341 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.663 .741 .908 r
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58845 Mtetra
.42372 .58845 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58784 .4504 .5804 Mtetra
.4504 .5804 .45807 .58784 .47147 .58383 .46385 .57636 Mtetra
.46385 .57636 .47147 .58383 .48494 .5798 .47736 .57231 Mtetra
.662 .742 .909 r
.47736 .57231 .48494 .5798 .49847 .57576 .49093 .56825 Mtetra
.49093 .56825 .49847 .57576 .51207 .57171 .50458 .56419 Mtetra
.661 .742 .91 r
.50458 .56419 .51207 .57171 .52574 .56765 .51829 .56013 Mtetra
.661 .743 .911 r
.51829 .56013 .52574 .56765 .53948 .56357 .53207 .55607 Mtetra
.66 .745 .913 r
.53207 .55607 .53948 .56357 .55329 .55947 .54593 .55201 Mtetra
.66 .747 .914 r
.54593 .55201 .55329 .55947 .56716 .55535 .55985 .54792 Mtetra
.66 .749 .915 r
.55985 .54792 .56716 .55535 .58111 .55119 .57385 .5438 Mtetra
.661 .751 .916 r
.57385 .5438 .58111 .55119 .59513 .547 .58791 .53962 Mtetra
.662 .753 .917 r
.58791 .53962 .59513 .547 .60921 .54277 .60205 .53538 Mtetra
.664 .754 .917 r
.60205 .53538 .60921 .54277 .62337 .5385 .61626 .53106 Mtetra
.665 .754 .917 r
.61626 .53106 .62337 .5385 .6376 .53419 .63054 .52669 Mtetra
.666 .753 .916 r
.63054 .52669 .6376 .53419 .6519 .52986 .64489 .52226 Mtetra
.666 .752 .914 r
.64489 .52226 .6519 .52986 .66628 .5255 .65931 .51779 Mtetra
.666 .75 .913 r
.65931 .51779 .66628 .5255 .68073 .52113 .67381 .5133 Mtetra
.666 .748 .912 r
.67381 .5133 .68073 .52113 .69525 .51674 .68838 .5088 Mtetra
.665 .746 .91 r
.68838 .5088 .69525 .51674 .70984 .51234 .70303 .5043 Mtetra
.665 .745 .91 r
.70303 .5043 .70984 .51234 .72452 .50792 .71775 .4998 Mtetra
.664 .743 .909 r
.71775 .4998 .72452 .50792 .73927 .50348 .73255 .49529 Mtetra
.664 .743 .908 r
.73255 .49529 .73927 .50348 .75409 .49903 .74743 .49078 Mtetra
.664 .742 .908 r
.74743 .49078 .75409 .49903 .76899 .49456 .76238 .48625 Mtetra
.76238 .48625 .76899 .49456 .78397 .49006 .77742 .48171 Mtetra
.664 .741 .908 r
.77742 .48171 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.663 .741 .908 r
.40261 .58505 .41047 .59244 .42372 .58845 .41589 .58102 Mtetra
.41589 .58102 .42372 .58845 .43703 .58443 .42925 .57697 Mtetra
.42925 .57697 .43703 .58443 .4504 .5804 .44266 .5729 Mtetra
.44266 .5729 .4504 .5804 .46385 .57636 .45615 .56883 Mtetra
.662 .741 .909 r
.45615 .56883 .46385 .57636 .47736 .57231 .4697 .56475 Mtetra
.4697 .56475 .47736 .57231 .49093 .56825 .48332 .56068 Mtetra
.661 .742 .91 r
.48332 .56068 .49093 .56825 .50458 .56419 .49701 .55663 Mtetra
.659 .743 .912 r
.49701 .55663 .50458 .56419 .51829 .56013 .51077 .55261 Mtetra
.658 .744 .914 r
.51077 .55261 .51829 .56013 .53207 .55607 .5246 .54861 Mtetra
.656 .746 .916 r
.5246 .54861 .53207 .55607 .54593 .55201 .5385 .54464 Mtetra
.655 .75 .919 r
.5385 .54464 .54593 .55201 .55985 .54792 .55247 .54067 Mtetra
.655 .754 .923 r
.55247 .54067 .55985 .54792 .57385 .5438 .56652 .53668 Mtetra
.656 .759 .926 r
.56652 .53668 .57385 .5438 .58791 .53962 .58064 .53262 Mtetra
.658 .764 .928 r
.58064 .53262 .58791 .53962 .60205 .53538 .59483 .52846 Mtetra
.661 .768 .929 r
.59483 .52846 .60205 .53538 .61626 .53106 .60909 .52416 Mtetra
.664 .77 .929 r
.60909 .52416 .61626 .53106 .63054 .52669 .62343 .51973 Mtetra
.667 .771 .928 r
.62343 .51973 .63054 .52669 .64489 .52226 .63783 .51517 Mtetra
.669 .769 .925 r
.63783 .51517 .64489 .52226 .65931 .51779 .6523 .51053 Mtetra
.67 .766 .922 r
.6523 .51053 .65931 .51779 .67381 .5133 .66685 .50583 Mtetra
.67 .761 .919 r
.66685 .50583 .67381 .5133 .68838 .5088 .68146 .50113 Mtetra
.669 .756 .916 r
.68146 .50113 .68838 .5088 .70303 .5043 .69616 .49643 Mtetra
.668 .752 .913 r
.69616 .49643 .70303 .5043 .71775 .4998 .71093 .49177 Mtetra
.667 .748 .911 r
.71093 .49177 .71775 .4998 .73255 .49529 .72578 .48713 Mtetra
.666 .746 .91 r
.72578 .48713 .73255 .49529 .74743 .49078 .74071 .48251 Mtetra
.665 .744 .909 r
.74071 .48251 .74743 .49078 .76238 .48625 .75571 .4779 Mtetra
.664 .743 .909 r
.75571 .4779 .76238 .48625 .77742 .48171 .7708 .47329 Mtetra
.664 .742 .908 r
.7708 .47329 .77742 .48171 .79253 .47714 .78597 .46867 Mtetra
.78597 .46867 .79253 .47714 .80773 .47255 .80122 .46403 Mtetra
.664 .741 .908 r
.80122 .46403 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.38141 .58164 .38939 .58906 .40261 .58505 .39467 .57759 Mtetra
.663 .741 .908 r
.39467 .57759 .40261 .58505 .41589 .58102 .408 .57352 Mtetra
.408 .57352 .41589 .58102 .42925 .57697 .42139 .56943 Mtetra
.42139 .56943 .42925 .57697 .44266 .5729 .43485 .56533 Mtetra
.43485 .56533 .44266 .5729 .45615 .56883 .44838 .56123 Mtetra
.662 .741 .909 r
.44838 .56123 .45615 .56883 .4697 .56475 .46198 .55713 Mtetra
.661 .741 .91 r
.46198 .55713 .4697 .56475 .48332 .56068 .47564 .55305 Mtetra
.659 .742 .911 r
.47564 .55305 .48332 .56068 .49701 .55663 .48937 .54902 Mtetra
.656 .742 .913 r
.48937 .54902 .49701 .55663 .51077 .55261 .50318 .54506 Mtetra
.653 .744 .916 r
.50318 .54506 .51077 .55261 .5246 .54861 .51705 .54118 Mtetra
.65 .747 .921 r
.51705 .54118 .5246 .54861 .5385 .54464 .531 .5374 Mtetra
.646 .752 .927 r
.531 .5374 .5385 .54464 .55247 .54067 .54502 .53369 Mtetra
.643 .76 .933 r
.54502 .53369 .55247 .54067 .56652 .53668 .55912 .53 Mtetra
.643 .769 .94 r
.55912 .53 .56652 .53668 .58064 .53262 .5733 .52626 Mtetra
.644 .781 .946 r
.5733 .52626 .58064 .53262 .59483 .52846 .58755 .52238 Mtetra
.649 .792 .951 r
.58755 .52238 .59483 .52846 .60909 .52416 .60188 .51828 Mtetra
.655 .801 .952 r
.60188 .51828 .60909 .52416 .62343 .51973 .61627 .5139 Mtetra
.663 .806 .951 r
.61627 .5139 .62343 .51973 .63783 .51517 .63073 .50925 Mtetra
.67 .806 .948 r
.63073 .50925 .63783 .51517 .6523 .51053 .64526 .50436 Mtetra
.675 .801 .942 r
.64526 .50436 .6523 .51053 .66685 .50583 .65985 .49933 Mtetra
.677 .793 .936 r
.65985 .49933 .66685 .50583 .68146 .50113 .67452 .49423 Mtetra
.677 .782 .929 r
.67452 .49423 .68146 .50113 .69616 .49643 .68925 .48914 Mtetra
.675 .772 .923 r
.68925 .48914 .69616 .49643 .71093 .49177 .70406 .48412 Mtetra
.673 .763 .918 r
.70406 .48412 .71093 .49177 .72578 .48713 .71896 .47919 Mtetra
.67 .755 .915 r
.71896 .47919 .72578 .48713 .74071 .48251 .73393 .47435 Mtetra
.668 .75 .912 r
.73393 .47435 .74071 .48251 .75571 .4779 .74899 .46958 Mtetra
.666 .746 .91 r
.74899 .46958 .75571 .4779 .7708 .47329 .76413 .46485 Mtetra
.665 .744 .909 r
.76413 .46485 .7708 .47329 .78597 .46867 .77935 .46014 Mtetra
.664 .743 .908 r
.77935 .46014 .78597 .46867 .80122 .46403 .79466 .45543 Mtetra
.664 .742 .908 r
.79466 .45543 .80122 .46403 .81656 .45937 .81005 .45072 Mtetra
.81005 .45072 .81656 .45937 .83197 .45469 .82552 .44599 Mtetra
.664 .741 .908 r
.82552 .44599 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.37336 .57414 .38141 .58164 .39467 .57759 .38666 .57005 Mtetra
.663 .741 .908 r
.38666 .57005 .39467 .57759 .408 .57352 .40003 .56595 Mtetra
.40003 .56595 .408 .57352 .42139 .56943 .41347 .56182 Mtetra
.41347 .56182 .42139 .56943 .43485 .56533 .42697 .55769 Mtetra
.42697 .55769 .43485 .56533 .44838 .56123 .44054 .55355 Mtetra
.662 .741 .909 r
.44054 .55355 .44838 .56123 .46198 .55713 .45418 .54943 Mtetra
.66 .741 .91 r
.45418 .54943 .46198 .55713 .47564 .55305 .46789 .54534 Mtetra
.657 .741 .911 r
.46789 .54534 .47564 .55305 .48937 .54902 .48166 .54133 Mtetra
.653 .741 .914 r
.48166 .54133 .48937 .54902 .50318 .54506 .49551 .53745 Mtetra
.647 .743 .919 r
.49551 .53745 .50318 .54506 .51705 .54118 .50943 .53374 Mtetra
.64 .746 .926 r
.50943 .53374 .51705 .54118 .531 .5374 .52342 .53024 Mtetra
.631 .752 .935 r
.52342 .53024 .531 .5374 .54502 .53369 .5375 .52695 Mtetra
.621 .762 .946 r
.5375 .52695 .54502 .53369 .55912 .53 .55165 .52382 Mtetra
.613 .777 .959 r
.55165 .52382 .55912 .53 .5733 .52626 .5659 .52073 Mtetra
.609 .798 .972 r
.5659 .52073 .5733 .52626 .58755 .52238 .58022 .51752 Mtetra
.609 .821 .981 r
.58022 .51752 .58755 .52238 .60188 .51828 .59462 .51399 Mtetra
.617 .843 .986 r
.59462 .51399 .60188 .51828 .61627 .5139 .60909 .51 Mtetra
.631 .861 .986 r
.60909 .51 .61627 .5139 .63073 .50925 .62363 .50546 Mtetra
.65 .871 .982 r
.62363 .50546 .63073 .50925 .64526 .50436 .63822 .50038 Mtetra
.669 .871 .975 r
.63822 .50038 .64526 .50436 .65985 .49933 .65287 .49488 Mtetra
.683 .861 .967 r
.65287 .49488 .65985 .49933 .67452 .49423 .66758 .48913 Mtetra
.689 .843 .957 r
.66758 .48913 .67452 .49423 .68925 .48914 .68235 .48331 Mtetra
.69 .821 .946 r
.68235 .48331 .68925 .48914 .70406 .48412 .69719 .47757 Mtetra
.686 .8 .935 r
.69719 .47757 .70406 .48412 .71896 .47919 .71211 .47201 Mtetra
.681 .781 .926 r
.71211 .47201 .71896 .47919 .73393 .47435 .72712 .46666 Mtetra
.676 .767 .919 r
.72712 .46666 .73393 .47435 .74899 .46958 .74222 .46151 Mtetra
.671 .757 .915 r
.74222 .46151 .74899 .46958 .76413 .46485 .7574 .45652 Mtetra
.668 .75 .912 r
.7574 .45652 .76413 .46485 .77935 .46014 .77267 .45163 Mtetra
.666 .746 .91 r
.77267 .45163 .77935 .46014 .79466 .45543 .78803 .44681 Mtetra
.665 .744 .909 r
.78803 .44681 .79466 .45543 .81005 .45072 .80348 .44201 Mtetra
.664 .742 .908 r
.80348 .44201 .81005 .45072 .82552 .44599 .819 .43721 Mtetra
.819 .43721 .82552 .44599 .84107 .44123 .83462 .4324 Mtetra
.664 .741 .908 r
.83462 .4324 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.663 .741 .908 r
.37858 .56245 .38666 .57005 .40003 .56595 .39199 .55831 Mtetra
.39199 .55831 .40003 .56595 .41347 .56182 .40547 .55415 Mtetra
.40547 .55415 .41347 .56182 .42697 .55769 .41902 .54997 Mtetra
.41902 .54997 .42697 .55769 .44054 .55355 .43263 .5458 Mtetra
.662 .741 .909 r
.43263 .5458 .44054 .55355 .45418 .54943 .44631 .54164 Mtetra
.66 .74 .91 r
.44631 .54164 .45418 .54943 .46789 .54534 .46006 .53753 Mtetra
.656 .74 .912 r
.46006 .53753 .46789 .54534 .48166 .54133 .47388 .53353 Mtetra
.65 .739 .915 r
.47388 .53353 .48166 .54133 .49551 .53745 .48777 .52972 Mtetra
.641 .74 .92 r
.48777 .52972 .49551 .53745 .50943 .53374 .50174 .52619 Mtetra
.628 .741 .929 r
.50174 .52619 .50943 .53374 .52342 .53024 .51578 .52303 Mtetra
.61 .746 .942 r
.51578 .52303 .52342 .53024 .5375 .52695 .5299 .5203 Mtetra
.587 .756 .958 r
.5299 .5203 .5375 .52695 .55165 .52382 .54411 .51799 Mtetra
.56 .773 .978 r
.54411 .51799 .55165 .52382 .5659 .52073 .55842 .51597 Mtetra
.529 .797 .995 r
.55842 .51597 .5659 .52073 .58022 .51752 .57282 .51399 Mtetra
.498 .825 1 r
.57282 .51399 .58022 .51752 .59462 .51399 .58731 .51171 Mtetra
.474 .852 .985 r
.58731 .51171 .59462 .51399 .60909 .51 .60189 .50879 Mtetra
.47 .874 .956 r
.60189 .50879 .60909 .51 .62363 .50546 .61652 .50493 Mtetra
.495 .897 .933 r
.61652 .50493 .62363 .50546 .63822 .50038 .63121 .50002 Mtetra
.547 .922 .93 r
.63121 .50002 .63822 .50038 .65287 .49488 .64594 .49414 Mtetra
.611 .942 .946 r
.64594 .49414 .65287 .49488 .66758 .48913 .6607 .48752 Mtetra
.666 .942 .963 r
.6607 .48752 .66758 .48913 .68235 .48331 .67551 .48051 Mtetra
.698 .92 .968 r
.67551 .48051 .68235 .48331 .69719 .47757 .69037 .47346 Mtetra
.708 .883 .962 r
.69037 .47346 .69719 .47757 .71211 .47201 .7053 .46665 Mtetra
.704 .844 .95 r
.7053 .46665 .71211 .47201 .72712 .46666 .72032 .46023 Mtetra
.695 .811 .937 r
.72032 .46023 .72712 .46666 .74222 .46151 .73543 .45424 Mtetra
.685 .785 .926 r
.73543 .45424 .74222 .46151 .7574 .45652 .75064 .44864 Mtetra
.677 .767 .919 r
.75064 .44864 .7574 .45652 .77267 .45163 .76595 .44335 Mtetra
.671 .756 .914 r
.76595 .44335 .77267 .45163 .78803 .44681 .78135 .43826 Mtetra
.668 .749 .911 r
.78135 .43826 .78803 .44681 .80348 .44201 .79684 .43329 Mtetra
.666 .745 .909 r
.79684 .43329 .80348 .44201 .819 .43721 .81243 .42838 Mtetra
.665 .743 .909 r
.81243 .42838 .819 .43721 .83462 .4324 .8281 .42349 Mtetra
.664 .742 .908 r
.8281 .42349 .83462 .4324 .85032 .42757 .84386 .4186 Mtetra
.84386 .4186 .85032 .42757 .8661 .42272 .85971 .4137 Mtetra
.664 .741 .908 r
.85971 .4137 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.663 .741 .908 r
.38388 .5506 .39199 .55831 .40547 .55415 .3974 .5464 Mtetra
.3974 .5464 .40547 .55415 .41902 .54997 .41099 .54218 Mtetra
.41099 .54218 .41902 .54997 .43263 .5458 .42464 .53796 Mtetra
.662 .741 .909 r
.42464 .53796 .43263 .5458 .44631 .54164 .43837 .53376 Mtetra
.659 .74 .909 r
.43837 .53376 .44631 .54164 .46006 .53753 .45216 .52962 Mtetra
.655 .739 .911 r
.45216 .52962 .46006 .53753 .47388 .53353 .46603 .52561 Mtetra
.648 .737 .914 r
.46603 .52561 .47388 .53353 .48777 .52972 .47996 .52183 Mtetra
.636 .736 .92 r
.47996 .52183 .48777 .52972 .50174 .52619 .49397 .51843 Mtetra
.617 .734 .93 r
.49397 .51843 .50174 .52619 .51578 .52303 .50805 .51559 Mtetra
.588 .734 .944 r
.50805 .51559 .51578 .52303 .5299 .5203 .52222 .51347 Mtetra
.546 .737 .964 r
.52222 .51347 .5299 .5203 .54411 .51799 .53648 .51214 Mtetra
.484 .744 .986 r
.53648 .51214 .54411 .51799 .55842 .51597 .55086 .51154 Mtetra
.393 .749 .993 r
.55086 .51154 .55842 .51597 .57282 .51399 .56534 .5114 Mtetra
.265 .733 .945 r
.56534 .5114 .57282 .51399 .58731 .51171 .57994 .51124 Mtetra
.126 .674 .804 r
.57994 .51124 .58731 .51171 .60189 .50879 .59464 .51044 Mtetra
0 0 0 r
.59464 .51044 .60189 .50879 .61652 .50493 .60942 .50837 Mtetra
.60942 .50837 .61652 .50493 .63121 .50002 .62425 .50458 Mtetra
.62425 .50458 .63121 .50002 .64594 .49414 .6391 .4989 Mtetra
.6391 .4989 .64594 .49414 .6607 .48752 .65395 .49157 Mtetra
.65395 .49157 .6607 .48752 .67551 .48051 .66881 .48306 Mtetra
.509 .9 .751 r
.66881 .48306 .67551 .48051 .69037 .47346 .68369 .47401 Mtetra
.649 .968 .884 r
.68369 .47401 .69037 .47346 .7053 .46665 .69861 .46504 Mtetra
.715 .957 .947 r
.69861 .46504 .7053 .46665 .72032 .46023 .71361 .45659 Mtetra
.726 .906 .958 r
.71361 .45659 .72032 .46023 .73543 .45424 .7287 .44889 Mtetra
.714 .852 .948 r
.7287 .44889 .73543 .45424 .75064 .44864 .7439 .44199 Mtetra
.698 .81 .934 r
.7439 .44199 .75064 .44864 .76595 .44335 .75921 .43576 Mtetra
.685 .781 .924 r
.75921 .43576 .76595 .44335 .78135 .43826 .77464 .43007 Mtetra
.676 .763 .917 r
.77464 .43007 .78135 .43826 .79684 .43329 .79017 .42472 Mtetra
.67 .752 .912 r
.79017 .42472 .79684 .43329 .81243 .42838 .8058 .41958 Mtetra
.667 .747 .91 r
.8058 .41958 .81243 .42838 .8281 .42349 .82152 .41455 Mtetra
.665 .744 .909 r
.82152 .41455 .8281 .42349 .84386 .4186 .83734 .40957 Mtetra
.664 .742 .908 r
.83734 .40957 .84386 .4186 .85971 .4137 .85324 .40459 Mtetra
.85324 .40459 .85971 .4137 .87564 .40877 .86924 .39961 Mtetra
.664 .741 .908 r
.86924 .39961 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38957 Mtetra
.9015 .38957 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.663 .741 .908 r
.37569 .54281 .38388 .5506 .3974 .5464 .38925 .53857 Mtetra
.38925 .53857 .3974 .5464 .41099 .54218 .40288 .53431 Mtetra
.40288 .53431 .41099 .54218 .42464 .53796 .41658 .53005 Mtetra
.662 .741 .908 r
.41658 .53005 .42464 .53796 .43837 .53376 .43035 .5258 Mtetra
.66 .74 .909 r
.43035 .5258 .43837 .53376 .45216 .52962 .44419 .5216 Mtetra
.656 .738 .911 r
.44419 .5216 .45216 .52962 .46603 .52561 .4581 .51754 Mtetra
.648 .736 .913 r
.4581 .51754 .46603 .52561 .47996 .52183 .47208 .51373 Mtetra
.634 .732 .919 r
.47208 .51373 .47996 .52183 .49397 .51843 .48613 .51038 Mtetra
.611 .726 .927 r
.48613 .51038 .49397 .51843 .50805 .51559 .50025 .50773 Mtetra
.573 .719 .941 r
.50025 .50773 .50805 .51559 .52222 .51347 .51446 .50608 Mtetra
.511 .709 .96 r
.51446 .50608 .52222 .51347 .53648 .51214 .52877 .50568 Mtetra
.41 .692 .978 r
.52877 .50568 .53648 .51214 .55086 .51154 .5432 .50662 Mtetra
.241 .652 .961 r
.5432 .50662 .55086 .51154 .56534 .5114 .55776 .50873 Mtetra
0 .54 .819 r
.55776 .50873 .56534 .5114 .57994 .51124 .57247 .51149 Mtetra
.248 0 0 r
.57247 .51149 .57994 .51124 .59464 .51044 .58731 .51404 Mtetra
.351 0 0 r
.58731 .51404 .59464 .51044 .60942 .50837 .60227 .51531 Mtetra
.60227 .51531 .60942 .50837 .62425 .50458 .6173 .51428 Mtetra
.303 0 .016 r
.6173 .51428 .62425 .50458 .6391 .4989 .63234 .51028 Mtetra
.227 0 .03 r
.63234 .51028 .6391 .4989 .65395 .49157 .64736 .50317 Mtetra
.124 0 0 r
.64736 .50317 .65395 .49157 .66881 .48306 .66232 .49344 Mtetra
0 0 0 r
.66232 .49344 .66881 .48306 .68369 .47401 .67725 .48199 Mtetra
.67725 .48199 .68369 .47401 .69861 .46504 .69216 .46991 Mtetra
.455 .826 .575 r
.69216 .46991 .69861 .46504 .71361 .45659 .7071 .45816 Mtetra
.66 .97 .822 r
.7071 .45816 .71361 .45659 .7287 .44889 .72212 .44742 Mtetra
.738 .967 .934 r
.72212 .44742 .7287 .44889 .7439 .44199 .73726 .43799 Mtetra
.737 .902 .952 r
.73726 .43799 .7439 .44199 .75921 .43576 .75253 .42987 Mtetra
.715 .841 .942 r
.75253 .42987 .75921 .43576 .77464 .43007 .76793 .42285 Mtetra
.695 .798 .929 r
.76793 .42285 .77464 .43007 .79017 .42472 .78347 .41665 Mtetra
.681 .772 .919 r
.78347 .41665 .79017 .42472 .8058 .41958 .79912 .411 Mtetra
.673 .757 .914 r
.79912 .411 .8058 .41958 .82152 .41455 .81489 .40567 Mtetra
.668 .749 .911 r
.81489 .40567 .82152 .41455 .83734 .40957 .83076 .40051 Mtetra
.666 .745 .909 r
.83076 .40051 .83734 .40957 .85324 .40459 .84672 .39543 Mtetra
.664 .743 .908 r
.84672 .39543 .85324 .40459 .86924 .39961 .86278 .39036 Mtetra
.664 .742 .908 r
.86278 .39036 .86924 .39961 .88532 .3946 .87892 .38529 Mtetra
.664 .741 .908 r
.87892 .38529 .88532 .3946 .9015 .38957 .89516 .3802 Mtetra
.89516 .3802 .9015 .38957 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.663 .741 .908 r
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53068 Mtetra
.38103 .53068 .38925 .53857 .40288 .53431 .3947 .52637 Mtetra
.3947 .52637 .40288 .53431 .41658 .53005 .40845 .52206 Mtetra
.662 .741 .908 r
.40845 .52206 .41658 .53005 .43035 .5258 .42226 .51776 Mtetra
.661 .74 .909 r
.42226 .51776 .43035 .5258 .44419 .5216 .43614 .5135 Mtetra
.657 .738 .91 r
.43614 .5135 .44419 .5216 .4581 .51754 .4501 .50935 Mtetra
.649 .735 .912 r
.4501 .50935 .4581 .51754 .47208 .51373 .46412 .50545 Mtetra
.636 .729 .916 r
.46412 .50545 .47208 .51373 .48613 .51038 .47821 .50201 Mtetra
.611 .72 .923 r
.47821 .50201 .48613 .51038 .50025 .50773 .49238 .49936 Mtetra
.569 .705 .934 r
.49238 .49936 .50025 .50773 .51446 .50608 .50663 .49791 Mtetra
.497 .682 .949 r
.50663 .49791 .51446 .50608 .52877 .50568 .52098 .49809 Mtetra
.373 .641 .959 r
.52098 .49809 .52877 .50568 .5432 .50662 .53545 .50027 Mtetra
.157 .557 .929 r
.53545 .50027 .5432 .50662 .55776 .50873 .55008 .50454 Mtetra
0 .38 .752 r
.55008 .50454 .55776 .50873 .57247 .51149 .56487 .51053 Mtetra
.458 0 0 r
.56487 .51053 .57247 .51149 .58731 .51404 .57986 .51732 Mtetra
.555 .019 0 r
.57986 .51732 .58731 .51404 .60227 .51531 .59501 .52348 Mtetra
.537 .075 .103 r
.59501 .52348 .60227 .51531 .6173 .51428 .61028 .52732 Mtetra
.478 .073 .192 r
.61028 .52732 .6173 .51428 .63234 .51028 .6256 .52731 Mtetra
.405 .039 .227 r
.6256 .52731 .63234 .51028 .64736 .50317 .64088 .52255 Mtetra
.323 0 .227 r
.64088 .52255 .64736 .50317 .66232 .49344 .65605 .51304 Mtetra
.23 0 .194 r
.65605 .51304 .66232 .49344 .67725 .48199 .6711 .49972 Mtetra
.118 0 .123 r
.6711 .49972 .67725 .48199 .69216 .46991 .68603 .48411 Mtetra
0 0 0 r
.68603 .48411 .69216 .46991 .7071 .45816 .70092 .4679 Mtetra
.70092 .4679 .7071 .45816 .72212 .44742 .71584 .45252 Mtetra
.526 .856 .574 r
.71584 .45252 .72212 .44742 .73726 .43799 .73085 .43888 Mtetra
.72 .989 .847 r
.73085 .43888 .73726 .43799 .75253 .42987 .746 .42733 Mtetra
.758 .95 .94 r
.746 .42733 .75253 .42987 .76793 .42285 .76131 .41776 Mtetra
.734 .874 .945 r
.76131 .41776 .76793 .42285 .78347 .41665 .7768 .40982 Mtetra
.707 .816 .933 r
.7768 .40982 .78347 .41665 .79912 .411 .79244 .40306 Mtetra
.687 .781 .922 r
.79244 .40306 .79912 .411 .81489 .40567 .80822 .39708 Mtetra
.676 .761 .915 r
.80822 .39708 .81489 .40567 .83076 .40051 .82413 .39154 Mtetra
.669 .751 .911 r
.82413 .39154 .83076 .40051 .84672 .39543 .84014 .38625 Mtetra
.666 .745 .909 r
.84014 .38625 .84672 .39543 .86278 .39036 .85625 .38106 Mtetra
.665 .743 .909 r
.85625 .38106 .86278 .39036 .87892 .38529 .87246 .37591 Mtetra
.664 .742 .908 r
.87246 .37591 .87892 .38529 .89516 .3802 .88876 .37075 Mtetra
.88876 .37075 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.664 .741 .908 r
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.35908 .52703 .36742 .53496 .38103 .53068 .37272 .52271 Mtetra
.663 .741 .908 r
.37272 .52271 .38103 .53068 .3947 .52637 .38644 .51836 Mtetra
.38644 .51836 .3947 .52637 .40845 .52206 .40023 .514 Mtetra
.40023 .514 .40845 .52206 .42226 .51776 .41409 .50964 Mtetra
.661 .74 .908 r
.41409 .50964 .42226 .51776 .43614 .5135 .42802 .5053 Mtetra
.658 .739 .909 r
.42802 .5053 .43614 .5135 .4501 .50935 .44202 .50106 Mtetra
.652 .735 .91 r
.44202 .50106 .4501 .50935 .46412 .50545 .45609 .49701 Mtetra
.64 .729 .913 r
.45609 .49701 .46412 .50545 .47821 .50201 .47023 .49339 Mtetra
.617 .718 .918 r
.47023 .49339 .47821 .50201 .49238 .49936 .48444 .49052 Mtetra
.577 .698 .925 r
.48444 .49052 .49238 .49936 .50663 .49791 .49873 .4889 Mtetra
.506 .666 .934 r
.49873 .4889 .50663 .49791 .52098 .49809 .51311 .48914 Mtetra
.384 .609 .938 r
.51311 .48914 .52098 .49809 .53545 .50027 .52762 .49187 Mtetra
.175 .506 .911 r
.52762 .49187 .53545 .50027 .55008 .50454 .54228 .49755 Mtetra
0 .32 .777 r
.54228 .49755 .55008 .50454 .56487 .51053 .55714 .50622 Mtetra
.503 0 0 r
.55714 .50622 .56487 .51053 .57986 .51732 .57223 .51719 Mtetra
.668 .123 0 r
.57223 .51719 .57986 .51732 .59501 .52348 .58755 .529 Mtetra
.668 .192 .112 r
.58755 .529 .59501 .52348 .61028 .52732 .60308 .53944 Mtetra
.602 .189 .233 r
.60308 .53944 .61028 .52732 .6256 .52731 .61872 .54604 Mtetra
.517 .154 .291 r
.61872 .54604 .6256 .52731 .64088 .52255 .63436 .54669 Mtetra
.428 .103 .311 r
.63436 .54669 .64088 .52255 .65605 .51304 .64987 .54031 Mtetra
.34 .042 .305 r
.64987 .54031 .65605 .51304 .6711 .49972 .66517 .52724 Mtetra
.25 0 .277 r
.66517 .52724 .6711 .49972 .68603 .48411 .68025 .50906 Mtetra
.15 0 .222 r
.68025 .50906 .68603 .48411 .70092 .4679 .69514 .48815 Mtetra
.025 0 .123 r
.69514 .48815 .70092 .4679 .71584 .45252 .70995 .46692 Mtetra
0 0 0 r
.70995 .46692 .71584 .45252 .73085 .43888 .72479 .4473 Mtetra
.72479 .4473 .73085 .43888 .746 .42733 .73974 .43039 Mtetra
.677 .957 .719 r
.73974 .43039 .746 .42733 .76131 .41776 .75489 .41651 Mtetra
.772 .981 .909 r
.75489 .41651 .76131 .41776 .7768 .40982 .77024 .40542 Mtetra
.753 .902 .944 r
.77024 .40542 .7768 .40982 .79244 .40306 .78581 .39653 Mtetra
.718 .832 .935 r
.78581 .39653 .79244 .40306 .80822 .39708 .80156 .38922 Mtetra
.693 .789 .924 r
.80156 .38922 .80822 .39708 .82413 .39154 .81746 .38291 Mtetra
.679 .765 .916 r
.81746 .38291 .82413 .39154 .84014 .38625 .83351 .37718 Mtetra
.671 .752 .912 r
.83351 .37718 .84014 .38625 .85625 .38106 .84967 .37175 Mtetra
.667 .746 .91 r
.84967 .37175 .85625 .38106 .87246 .37591 .86593 .36646 Mtetra
.665 .743 .909 r
.86593 .36646 .87246 .37591 .88876 .37075 .8823 .36122 Mtetra
.664 .742 .908 r
.8823 .36122 .88876 .37075 .90516 .36558 .89876 .35598 Mtetra
.89876 .35598 .90516 .36558 .92164 .36039 .91531 .35073 Mtetra
.664 .741 .908 r
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.35065 .51903 .35908 .52703 .37272 .52271 .36434 .51466 Mtetra
.663 .741 .908 r
.36434 .51466 .37272 .52271 .38644 .51836 .37811 .51027 Mtetra
.37811 .51027 .38644 .51836 .40023 .514 .39194 .50587 Mtetra
.39194 .50587 .40023 .514 .41409 .50964 .40584 .50145 Mtetra
.662 .74 .908 r
.40584 .50145 .41409 .50964 .42802 .5053 .41982 .49704 Mtetra
.66 .739 .908 r
.41982 .49704 .42802 .5053 .44202 .50106 .43387 .49269 Mtetra
.656 .736 .909 r
.43387 .49269 .44202 .50106 .45609 .49701 .44798 .48849 Mtetra
.646 .731 .91 r
.44798 .48849 .45609 .49701 .47023 .49339 .46217 .48461 Mtetra
.627 .719 .913 r
.46217 .48461 .47023 .49339 .48444 .49052 .47643 .48137 Mtetra
.593 .699 .917 r
.47643 .48137 .48444 .49052 .49873 .4889 .49076 .47927 Mtetra
.532 .664 .921 r
.49076 .47927 .49873 .4889 .51311 .48914 .50518 .479 Mtetra
.429 .603 .919 r
.50518 .479 .51311 .48914 .52762 .49187 .51971 .48139 Mtetra
.257 .502 .898 r
.51971 .48139 .52762 .49187 .54228 .49755 .53439 .48728 Mtetra
0 .339 .82 r
.53439 .48728 .54228 .49755 .55714 .50622 .54927 .4972 Mtetra
0 .111 .631 r
.54927 .4972 .55714 .50622 .57223 .51719 .56441 .51104 Mtetra
.64 .116 0 r
.56441 .51104 .57223 .51719 .58755 .529 .57984 .52772 Mtetra
.757 .245 0 r
.57984 .52772 .58755 .529 .60308 .53944 .59557 .54503 Mtetra
.727 .268 .161 r
.59557 .54503 .60308 .53944 .61872 .54604 .61152 .55986 Mtetra
.632 .233 .27 r
.61152 .55986 .61872 .54604 .63436 .54669 .62756 .56887 Mtetra
.521 .175 .321 r
.62756 .56887 .63436 .54669 .64987 .54031 .64352 .5694 Mtetra
.414 .109 .336 r
.64352 .5694 .64987 .54031 .66517 .52724 .65924 .56036 Mtetra
.315 .041 .328 r
.65924 .56036 .66517 .52724 .68025 .50906 .67463 .54259 Mtetra
.222 0 .302 r
.67463 .54259 .68025 .50906 .69514 .48815 .68967 .51861 Mtetra
.125 0 .252 r
.68967 .51861 .69514 .48815 .70995 .46692 .70446 .49173 Mtetra
.011 0 .168 r
.70446 .49173 .70995 .46692 .72479 .4473 .71914 .46514 Mtetra
0 0 .018 r
.71914 .46514 .72479 .4473 .73974 .43039 .73387 .44117 Mtetra
0 0 0 r
.73387 .44117 .73974 .43039 .75489 .41651 .74877 .42106 Mtetra
.655 .92 .622 r
.74877 .42106 .75489 .41651 .77024 .40542 .7639 .405 Mtetra
.784 .994 .876 r
.7639 .405 .77024 .40542 .78581 .39653 .7793 .39253 Mtetra
.768 .919 .938 r
.7793 .39253 .78581 .39653 .80156 .38922 .79495 .38282 Mtetra
.728 .842 .935 r
.79495 .38282 .80156 .38922 .81746 .38291 .81081 .37503 Mtetra
.698 .794 .924 r
.81081 .37503 .81746 .38291 .83351 .37718 .82685 .36845 Mtetra
.681 .767 .916 r
.82685 .36845 .83351 .37718 .84967 .37175 .84304 .36255 Mtetra
.671 .753 .912 r
.84304 .36255 .84967 .37175 .86593 .36646 .85935 .35701 Mtetra
.667 .746 .91 r
.85935 .35701 .86593 .36646 .8823 .36122 .87577 .35162 Mtetra
.665 .743 .909 r
.87577 .35162 .8823 .36122 .89876 .35598 .89229 .34629 Mtetra
.664 .742 .908 r
.89229 .34629 .89876 .35598 .91531 .35073 .90891 .34097 Mtetra
.664 .741 .908 r
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .50211 Mtetra
.663 .741 .908 r
.36969 .50211 .37811 .51027 .39194 .50587 .38357 .49765 Mtetra
.38357 .49765 .39194 .50587 .40584 .50145 .39752 .49319 Mtetra
.39752 .49319 .40584 .50145 .41982 .49704 .41154 .48872 Mtetra
.661 .74 .908 r
.41154 .48872 .41982 .49704 .43387 .49269 .42563 .48427 Mtetra
.658 .738 .908 r
.42563 .48427 .43387 .49269 .44798 .48849 .4398 .47991 Mtetra
.652 .733 .909 r
.4398 .47991 .44798 .48849 .46217 .48461 .45403 .47578 Mtetra
.638 .724 .91 r
.45403 .47578 .46217 .48461 .47643 .48137 .46834 .47212 Mtetra
.612 .706 .911 r
.46834 .47212 .47643 .48137 .49076 .47927 .48272 .46937 Mtetra
.565 .673 .911 r
.48272 .46937 .49076 .47927 .50518 .479 .49718 .46818 Mtetra
.485 .617 .907 r
.49718 .46818 .50518 .479 .51971 .48139 .51174 .46946 Mtetra
.356 .526 .887 r
.51174 .46946 .51971 .48139 .53439 .48728 .52642 .47427 Mtetra
.166 .392 .837 r
.52642 .47427 .53439 .48728 .54927 .4972 .5413 .4836 Mtetra
0 .216 .739 r
.5413 .4836 .54927 .4972 .56441 .51104 .55643 .49802 Mtetra
0 .02 .585 r
.55643 .49802 .56441 .51104 .57984 .52772 .57189 .51718 Mtetra
.611 .158 0 r
.57189 .51718 .57984 .52772 .59557 .54503 .5877 .53948 Mtetra
.771 .273 0 r
.5877 .53948 .59557 .54503 .61152 .55986 .60386 .56191 Mtetra
.771 .29 .09 r
.60386 .56191 .61152 .55986 .62756 .56887 .62025 .58042 Mtetra
.65 .23 .233 r
.62025 .58042 .62756 .56887 .64352 .5694 .63668 .59085 Mtetra
.498 .145 .299 r
.63668 .59085 .64352 .5694 .65924 .56036 .65293 .59015 Mtetra
.361 .063 .318 r
.65293 .59015 .65924 .56036 .67463 .54259 .66881 .57745 Mtetra
.246 0 .31 r
.66881 .57745 .67463 .54259 .68967 .51861 .68421 .55435 Mtetra
.147 0 .284 r
.68421 .55435 .68967 .51861 .70446 .49173 .69917 .52436 Mtetra
.051 0 .236 r
.69917 .52436 .70446 .49173 .71914 .46514 .71382 .49174 Mtetra
0 0 .155 r
.71382 .49174 .71914 .46514 .73387 .44117 .72837 .4603 Mtetra
0 0 .013 r
.72837 .4603 .73387 .44117 .74877 .42106 .743 .43264 Mtetra
0 0 0 r
.743 .43264 .74877 .42106 .7639 .405 .75785 .40996 Mtetra
.68 .919 .597 r
.75785 .40996 .7639 .405 .7793 .39253 .773 .39226 Mtetra
.801 .997 .859 r
.773 .39226 .7793 .39253 .79495 .38282 .78846 .3788 Mtetra
.779 .924 .932 r
.78846 .3788 .79495 .38282 .81081 .37503 .8042 .36853 Mtetra
.733 .845 .933 r
.8042 .36853 .81081 .37503 .82685 .36845 .82019 .36043 Mtetra
.7 .795 .923 r
.82019 .36043 .82685 .36845 .84304 .36255 .83638 .35367 Mtetra
.681 .767 .916 r
.83638 .35367 .84304 .36255 .85935 .35701 .85272 .34765 Mtetra
.672 .753 .912 r
.85272 .34765 .85935 .35701 .87577 .35162 .86918 .34201 Mtetra
.667 .746 .909 r
.86918 .34201 .87577 .35162 .89229 .34629 .88577 .33654 Mtetra
.665 .743 .909 r
.88577 .33654 .89229 .34629 .90891 .34097 .90245 .33112 Mtetra
.664 .741 .908 r
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Mtetra
.34734 .49834 .35588 .50654 .36969 .50211 .36119 .49386 Mtetra
.36119 .49386 .36969 .50211 .38357 .49765 .37511 .48937 Mtetra
.663 .741 .908 r
.37511 .48937 .38357 .49765 .39752 .49319 .38911 .48485 Mtetra
.38911 .48485 .39752 .49319 .41154 .48872 .40318 .48032 Mtetra
.662 .74 .908 r
.40318 .48032 .41154 .48872 .42563 .48427 .41732 .47579 Mtetra
.661 .739 .908 r
.41732 .47579 .42563 .48427 .4398 .47991 .43153 .47131 Mtetra
.657 .736 .908 r
.43153 .47131 .4398 .47991 .45403 .47578 .44582 .46695 Mtetra
.648 .729 .908 r
.44582 .46695 .45403 .47578 .46834 .47212 .46018 .46291 Mtetra
.63 .715 .908 r
.46018 .46291 .46834 .47212 .48272 .46937 .47461 .45949 Mtetra
.597 .689 .906 r
.47461 .45949 .48272 .46937 .49718 .46818 .48911 .45725 Mtetra
.539 .642 .9 r
.48911 .45725 .49718 .46818 .51174 .46946 .5037 .45701 Mtetra
.446 .566 .882 r
.5037 .45701 .51174 .46946 .52642 .47427 .51841 .45984 Mtetra
.312 .456 .844 r
.51841 .45984 .52642 .47427 .5413 .4836 .53327 .46699 Mtetra
.145 .318 .78 r
.53327 .46699 .5413 .4836 .55643 .49802 .54836 .47954 Mtetra
0 .173 .697 r
.54836 .47954 .55643 .49802 .57189 .51718 .56376 .49798 Mtetra
0 .04 .607 r
.56376 .49798 .57189 .51718 .5877 .53948 .57954 .52167 Mtetra
0 0 .516 r
.57954 .52167 .5877 .53948 .60386 .56191 .59575 .54845 Mtetra
0 0 .408 r
.59575 .54845 .60386 .56191 .62025 .58042 .61231 .57454 Mtetra
.709 .196 0 r
.61231 .57454 .62025 .58042 .63668 .59085 .6291 .59509 Mtetra
.64 .128 .012 r
.6291 .59509 .63668 .59085 .65293 .59015 .64585 .60539 Mtetra
.409 .011 .17 r
.64585 .60539 .65293 .59015 .66881 .57745 .66231 .60231 Mtetra
.222 0 .225 r
.66231 .60231 .66881 .57745 .68421 .55435 .67827 .58545 Mtetra
.096 0 .231 r
.67827 .58545 .68421 .55435 .69917 .52436 .69363 .55728 Mtetra
0 0 .211 r
.69363 .55728 .69917 .52436 .71382 .49174 .70849 .52221 Mtetra
0 0 .165 r
.70849 .52221 .71382 .49174 .72837 .4603 .72302 .48521 Mtetra
0 0 .083 r
.72302 .48521 .72837 .4603 .743 .43264 .73747 .45042 Mtetra
0 0 0 r
.73747 .45042 .743 .43264 .75785 .40996 .75206 .42046 Mtetra
.75206 .42046 .75785 .40996 .773 .39226 .76692 .39637 Mtetra
.748 .953 .644 r
.76692 .39637 .773 .39226 .78846 .3788 .78213 .37788 Mtetra
.821 .992 .867 r
.78213 .37788 .78846 .3788 .8042 .36853 .7977 .36403 Mtetra
.783 .914 .928 r
.7977 .36403 .8042 .36853 .82019 .36043 .81357 .35358 Mtetra
.733 .839 .93 r
.81357 .35358 .82019 .36043 .83638 .35367 .82971 .34538 Mtetra
.7 .791 .921 r
.82971 .34538 .83638 .35367 .85272 .34765 .84605 .33855 Mtetra
.681 .765 .915 r
.84605 .33855 .85272 .34765 .86918 .34201 .86255 .33247 Mtetra
.671 .752 .911 r
.86255 .33247 .86918 .34201 .88577 .33654 .87918 .32675 Mtetra
.667 .746 .909 r
.87918 .32675 .88577 .33654 .90245 .33112 .89592 .3212 Mtetra
.664 .741 .908 r
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Mtetra
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Mtetra
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Mtetra
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Mtetra
.35261 .48554 .36119 .49386 .37511 .48937 .36658 .481 Mtetra
.663 .741 .908 r
.36658 .481 .37511 .48937 .38911 .48485 .38062 .47644 Mtetra
.38062 .47644 .38911 .48485 .40318 .48032 .39473 .47185 Mtetra
.39473 .47185 .40318 .48032 .41732 .47579 .40892 .46726 Mtetra
.662 .74 .908 r
.40892 .46726 .41732 .47579 .43153 .47131 .42318 .46268 Mtetra
.66 .738 .908 r
.42318 .46268 .43153 .47131 .44582 .46695 .43752 .45815 Mtetra
.655 .734 .908 r
.43752 .45815 .44582 .46695 .46018 .46291 .45193 .4538 Mtetra
.644 .724 .907 r
.45193 .4538 .46018 .46291 .47461 .45949 .46641 .44983 Mtetra
.623 .705 .905 r
.46641 .44983 .47461 .45949 .48911 .45725 .48097 .44664 Mtetra
.584 .67 .899 r
.48097 .44664 .48911 .45725 .5037 .45701 .49561 .44485 Mtetra
.52 .611 .884 r
.49561 .44485 .5037 .45701 .51841 .45984 .51034 .44542 Mtetra
.425 .522 .853 r
.51034 .44542 .51841 .45984 .53327 .46699 .5252 .44953 Mtetra
.306 .409 .803 r
.5252 .44953 .53327 .46699 .54836 .47954 .54024 .4585 Mtetra
.182 .29 .74 r
.54024 .4585 .54836 .47954 .56376 .49798 .55555 .47341 Mtetra
.073 .186 .678 r
.55555 .47341 .56376 .49798 .57954 .52167 .57122 .49458 Mtetra
0 .113 .632 r
.57122 .49458 .57954 .52167 .59575 .54845 .58731 .52105 Mtetra
0 .073 .609 r
.58731 .52105 .59575 .54845 .61231 .57454 .60385 .55012 Mtetra
0 .074 .62 r
.60385 .55012 .61231 .57454 .6291 .59509 .62076 .57745 Mtetra
0 .144 .685 r
.62076 .57745 .6291 .59509 .64585 .60539 .63783 .59775 Mtetra
0 .396 .837 r
.63783 .59775 .64585 .60539 .66231 .60231 .6548 .60619 Mtetra
0 0 0 r
.6548 .60619 .66231 .60231 .67827 .58545 .67136 .59996 Mtetra
.67136 .59996 .67827 .58545 .69363 .55728 .68732 .57929 Mtetra
.68732 .57929 .69363 .55728 .70849 .52221 .70263 .54742 Mtetra
0 0 .03 r
.70263 .54742 .70849 .52221 .72302 .48521 .71742 .50935 Mtetra
0 0 .006 r
.71742 .50935 .72302 .48521 .73747 .45042 .7319 .47031 Mtetra
0 0 0 r
.7319 .47031 .73747 .45042 .75206 .42046 .74635 .43442 Mtetra
.74635 .43442 .75206 .42046 .76692 .39637 .76099 .40409 Mtetra
.699 .868 .465 r
.76099 .40409 .76692 .39637 .78213 .37788 .77595 .38004 Mtetra
.825 .99 .733 r
.77595 .38004 .78213 .37788 .7977 .36403 .79129 .3618 Mtetra
.832 .973 .886 r
.79129 .3618 .7977 .36403 .81357 .35358 .80701 .34821 Mtetra
.778 .893 .926 r
.80701 .34821 .81357 .35358 .82971 .34538 .82306 .33796 Mtetra
.728 .826 .926 r
.82306 .33796 .82971 .34538 .84605 .33855 .83936 .32989 Mtetra
.696 .784 .919 r
.83936 .32989 .84605 .33855 .86255 .33247 .85587 .3231 Mtetra
.679 .762 .914 r
.85587 .3231 .86255 .33247 .87918 .32675 .87253 .317 Mtetra
.67 .75 .91 r
.87253 .317 .87918 .32675 .89592 .3212 .88933 .31123 Mtetra
.664 .741 .908 r
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Mtetra
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Mtetra
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Mtetra
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Mtetra
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47255 Mtetra
.35796 .47255 .36658 .481 .38062 .47644 .37205 .46794 Mtetra
.663 .741 .908 r
.37205 .46794 .38062 .47644 .39473 .47185 .38621 .46331 Mtetra
.38621 .46331 .39473 .47185 .40892 .46726 .40044 .45866 Mtetra
.40044 .45866 .40892 .46726 .42318 .46268 .41475 .454 Mtetra
.662 .74 .908 r
.41475 .454 .42318 .46268 .43752 .45815 .42914 .44936 Mtetra
.659 .737 .907 r
.42914 .44936 .43752 .45815 .45193 .4538 .4436 .44479 Mtetra
.653 .731 .907 r
.4436 .44479 .45193 .4538 .46641 .44983 .45814 .44043 Mtetra
.641 .719 .905 r
.45814 .44043 .46641 .44983 .48097 .44664 .47275 .43651 Mtetra
.618 .696 .9 r
.47275 .43651 .48097 .44664 .49561 .44485 .48744 .43346 Mtetra
.576 .654 .889 r
.48744 .43346 .49561 .44485 .51034 .44542 .50221 .43197 Mtetra
.512 .586 .866 r
.50221 .43197 .51034 .44542 .5252 .44953 .51709 .43303 Mtetra
.426 .494 .826 r
.51709 .43303 .5252 .44953 .54024 .4585 .53211 .43786 Mtetra
.33 .389 .772 r
.53211 .43786 .54024 .4585 .55555 .47341 .54733 .44775 Mtetra
.246 .294 .715 r
.54733 .44775 .55555 .47341 .57122 .49458 .56285 .46364 Mtetra
.188 .224 .668 r
.56285 .46364 .57122 .49458 .58731 .52105 .57875 .48561 Mtetra
.161 .187 .64 r
.57875 .48561 .58731 .52105 .60385 .55012 .5951 .51238 Mtetra
.166 .184 .634 r
.5951 .51238 .60385 .55012 .62076 .57745 .61188 .54092 Mtetra
.207 .218 .652 r
.61188 .54092 .62076 .57745 .63783 .59775 .629 .56667 Mtetra
.296 .304 .699 r
.629 .56667 .63783 .59775 .6548 .60619 .64622 .58438 Mtetra
.465 .474 .783 r
.64622 .58438 .6548 .60619 .67136 .59996 .66326 .58959 Mtetra
.739 .759 .869 r
.66326 .58959 .67136 .59996 .68732 .57929 .67983 .58014 Mtetra
.929 .969 .756 r
.67983 .58014 .68732 .57929 .70263 .54742 .69576 .55693 Mtetra
.848 .901 .486 r
.69576 .55693 .70263 .54742 .71742 .50935 .71104 .52362 Mtetra
.739 .803 .324 r
.71104 .52362 .71742 .50935 .7319 .47031 .72584 .48535 Mtetra
.694 .768 .279 r
.72584 .48535 .7319 .47031 .74635 .43442 .74039 .4471 Mtetra
.708 .797 .325 r
.74039 .4471 .74635 .43442 .76099 .40409 .75497 .41261 Mtetra
.771 .877 .454 r
.75497 .41261 .76099 .40409 .77595 .38004 .76978 .38386 Mtetra
.847 .968 .645 r
.76978 .38386 .77595 .38004 .79129 .3618 .78494 .36129 Mtetra
.869 .992 .818 r
.78494 .36129 .79129 .3618 .80701 .34821 .80049 .34424 Mtetra
.824 .937 .903 r
.80049 .34424 .80701 .34821 .82306 .33796 .81642 .3315 Mtetra
.764 .864 .923 r
.81642 .3315 .82306 .33796 .83936 .32989 .83266 .32178 Mtetra
.718 .809 .921 r
.83266 .32178 .83936 .32989 .85587 .3231 .84915 .314 Mtetra
.691 .775 .916 r
.84915 .314 .85587 .3231 .87253 .317 .86584 .30733 Mtetra
.676 .757 .912 r
.86584 .30733 .87253 .317 .88933 .31123 .88268 .30125 Mtetra
.664 .741 .908 r
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Mtetra
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Mtetra
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Mtetra
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46865 Mtetra
.3352 .46865 .34395 .47714 .35796 .47255 .34926 .46402 Mtetra
.34926 .46402 .35796 .47255 .37205 .46794 .36339 .45937 Mtetra
.36339 .45937 .37205 .46794 .38621 .46331 .3776 .45469 Mtetra
.663 .741 .908 r
.3776 .45469 .38621 .46331 .40044 .45866 .39188 .44999 Mtetra
.39188 .44999 .40044 .45866 .41475 .454 .40624 .44527 Mtetra
.40624 .44527 .41475 .454 .42914 .44936 .42068 .44054 Mtetra
.662 .739 .908 r
.42068 .44054 .42914 .44936 .4436 .44479 .43519 .43583 Mtetra
.659 .736 .907 r
.43519 .43583 .4436 .44479 .45814 .44043 .44978 .43121 Mtetra
.652 .729 .906 r
.44978 .43121 .45814 .44043 .47275 .43651 .46444 .42681 Mtetra
.64 .715 .902 r
.46444 .42681 .47275 .43651 .48744 .43346 .47919 .42287 Mtetra
.616 .689 .895 r
.47919 .42287 .48744 .43346 .50221 .43197 .49401 .41985 Mtetra
.575 .642 .88 r
.49401 .41985 .50221 .43197 .51709 .43303 .50892 .41842 Mtetra
.516 .572 .851 r
.50892 .41842 .51709 .43303 .53211 .43786 .52394 .41955 Mtetra
.442 .483 .806 r
.52394 .41955 .53211 .43786 .54733 .44775 .53912 .42438 Mtetra
.369 .391 .752 r
.53912 .42438 .54733 .44775 .56285 .46364 .55452 .43404 Mtetra
.314 .315 .701 r
.55452 .43404 .56285 .46364 .57875 .48561 .57023 .44927 Mtetra
.284 .267 .663 r
.57023 .44927 .57875 .48561 .5951 .51238 .58631 .46989 Mtetra
.281 .247 .641 r
.58631 .46989 .5951 .51238 .61188 .54092 .60282 .49438 Mtetra
.305 .255 .636 r
.60282 .49438 .61188 .54092 .629 .56667 .61973 .51965 Mtetra
.356 .29 .645 r
.61973 .51965 .629 .56667 .64622 .58438 .63691 .54132 Mtetra
.435 .354 .666 r
.63691 .54132 .64622 .58438 .66326 .58959 .65414 .5547 Mtetra
.549 .454 .699 r
.65414 .5547 .66326 .58959 .67983 .58014 .67113 .5561 Mtetra
.697 .591 .733 r
.67113 .5561 .67983 .58014 .69576 .55693 .68764 .54415 Mtetra
.856 .749 .743 r
.68764 .54415 .69576 .55693 .71104 .52362 .70354 .52024 Mtetra
.962 .871 .701 r
.70354 .52024 .71104 .52362 .72584 .48535 .71887 .48808 Mtetra
.977 .92 .624 r
.71887 .48808 .72584 .48535 .74039 .4471 .73379 .45237 Mtetra
.947 .928 .574 r
.73379 .45237 .74039 .4471 .75497 .41261 .74855 .41748 Mtetra
.924 .941 .588 r
.74855 .41748 .75497 .41261 .76978 .38386 .76339 .38649 Mtetra
.918 .968 .668 r
.76339 .38649 .76978 .38386 .78494 .36129 .77849 .36091 Mtetra
.906 .981 .781 r
.77849 .36091 .78494 .36129 .80049 .34424 .79394 .34089 Mtetra
.862 .951 .869 r
.79394 .34089 .80049 .34424 .81642 .3315 .80976 .32569 Mtetra
.8 .89 .909 r
.80976 .32569 .81642 .3315 .83266 .32178 .82594 .31417 Mtetra
.744 .832 .918 r
.82594 .31417 .83266 .32178 .84915 .314 .8424 .30519 Mtetra
.707 .791 .917 r
.8424 .30519 .84915 .314 .86584 .30733 .8591 .29779 Mtetra
.685 .766 .913 r
.8591 .29779 .86584 .30733 .88268 .30125 .87597 .29128 Mtetra
.664 .741 .908 r
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Mtetra
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46936 Mtetra
.29838 .46936 .3073 .47784 .32121 .47326 .31234 .46474 Mtetra
.31234 .46474 .32121 .47326 .3352 .46865 .32636 .46009 Mtetra
.32636 .46009 .3352 .46865 .34926 .46402 .34047 .45541 Mtetra
.34047 .45541 .34926 .46402 .36339 .45937 .35465 .45071 Mtetra
.35465 .45071 .36339 .45937 .3776 .45469 .3689 .44598 Mtetra
.3689 .44598 .3776 .45469 .39188 .44999 .38323 .44123 Mtetra
.663 .741 .908 r
.38323 .44123 .39188 .44999 .40624 .44527 .39764 .43646 Mtetra
.39764 .43646 .40624 .44527 .42068 .44054 .41213 .43167 Mtetra
.663 .74 .908 r
.41213 .43167 .42068 .44054 .43519 .43583 .42669 .42687 Mtetra
.662 .739 .907 r
.42669 .42687 .43519 .43583 .44978 .43121 .44133 .42209 Mtetra
.659 .736 .907 r
.44133 .42209 .44978 .43121 .46444 .42681 .45605 .4174 Mtetra
.652 .728 .905 r
.45605 .4174 .46444 .42681 .47919 .42287 .47085 .41292 Mtetra
.64 .713 .9 r
.47085 .41292 .47919 .42287 .49401 .41985 .48572 .40891 Mtetra
.617 .685 .891 r
.48572 .40891 .49401 .41985 .50892 .41842 .50068 .40577 Mtetra
.58 .637 .872 r
.50068 .40577 .50892 .41842 .52394 .41955 .51574 .40413 Mtetra
.528 .569 .84 r
.51574 .40413 .52394 .41955 .53912 .42438 .53091 .40486 Mtetra
.468 .486 .794 r
.53091 .40486 .53912 .42438 .55452 .43404 .54624 .40893 Mtetra
.413 .407 .743 r
.54624 .40893 .55452 .43404 .57023 .44927 .5618 .41727 Mtetra
.375 .345 .697 r
.5618 .41727 .57023 .44927 .58631 .46989 .57765 .43033 Mtetra
.359 .307 .663 r
.57765 .43033 .58631 .46989 .60282 .49438 .59385 .44774 Mtetra
.365 .294 .644 r
.59385 .44774 .60282 .49438 .61973 .51965 .61044 .46789 Mtetra
.391 .304 .636 r
.61044 .46789 .61973 .51965 .63691 .54132 .62736 .48791 Mtetra
.436 .332 .639 r
.62736 .48791 .63691 .54132 .65414 .5547 .64449 .504 Mtetra
.498 .38 .65 r
.64449 .504 .65414 .5547 .67113 .5561 .66161 .51233 Mtetra
.578 .448 .667 r
.66161 .51233 .67113 .5561 .68764 .54415 .67848 .5102 Mtetra
.674 .534 .687 r
.67848 .5102 .68764 .54415 .70354 .52024 .69492 .49696 Mtetra
.779 .637 .704 r
.69492 .49696 .70354 .52024 .71887 .48808 .71084 .47423 Mtetra
.875 .741 .711 r
.71084 .47423 .71887 .48808 .73379 .45237 .7263 .44535 Mtetra
.939 .829 .709 r
.7263 .44535 .73379 .45237 .74855 .41748 .74146 .41427 Mtetra
.962 .889 .71 r
.74146 .41427 .74855 .41748 .76339 .38649 .75655 .38446 Mtetra
.955 .925 .733 r
.75655 .38446 .76339 .38649 .77849 .36091 .77175 .35826 Mtetra
.929 .94 .785 r
.77175 .35826 .77849 .36091 .79394 .34089 .78722 .33671 Mtetra
.884 .929 .846 r
.78722 .33671 .79394 .34089 .80976 .32569 .80301 .31976 Mtetra
.825 .891 .89 r
.80301 .31976 .80976 .32569 .82594 .31417 .81915 .3067 Mtetra
.768 .844 .909 r
.81915 .3067 .82594 .31417 .8424 .30519 .8356 .29654 Mtetra
.724 .803 .914 r
.8356 .29654 .8424 .30519 .8591 .29779 .8523 .28834 Mtetra
.695 .775 .913 r
.8523 .28834 .8591 .29779 .87597 .29128 .8692 .28133 Mtetra
.664 .741 .908 r
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Mtetra
.27545 .46545 .2845 .47397 .29838 .46936 .28937 .4608 Mtetra
.28937 .4608 .29838 .46936 .31234 .46474 .30337 .45613 Mtetra
.30337 .45613 .31234 .46474 .32636 .46009 .31744 .45143 Mtetra
.31744 .45143 .32636 .46009 .34047 .45541 .33159 .44671 Mtetra
.33159 .44671 .34047 .45541 .35465 .45071 .34582 .44196 Mtetra
.34582 .44196 .35465 .45071 .3689 .44598 .36012 .43719 Mtetra
.36012 .43719 .3689 .44598 .38323 .44123 .3745 .43239 Mtetra
.3745 .43239 .38323 .44123 .39764 .43646 .38895 .42757 Mtetra
.663 .741 .908 r
.38895 .42757 .39764 .43646 .41213 .43167 .40349 .42272 Mtetra
.40349 .42272 .41213 .43167 .42669 .42687 .4181 .41785 Mtetra
.663 .74 .908 r
.4181 .41785 .42669 .42687 .44133 .42209 .4328 .41298 Mtetra
.662 .739 .907 r
.4328 .41298 .44133 .42209 .45605 .4174 .44757 .40812 Mtetra
.659 .735 .906 r
.44757 .40812 .45605 .4174 .47085 .41292 .46242 .40335 Mtetra
.653 .728 .904 r
.46242 .40335 .47085 .41292 .48572 .40891 .47735 .39876 Mtetra
.642 .713 .899 r
.47735 .39876 .48572 .40891 .50068 .40577 .49236 .3946 Mtetra
.622 .685 .888 r
.49236 .3946 .50068 .40577 .51574 .40413 .50746 .3912 Mtetra
.59 .64 .868 r
.50746 .3912 .51574 .40413 .53091 .40486 .52266 .38912 Mtetra
.547 .576 .835 r
.52266 .38912 .53091 .40486 .54624 .40893 .53798 .38906 Mtetra
.499 .502 .791 r
.53798 .38906 .54624 .40893 .5618 .41727 .55346 .39179 Mtetra
.456 .432 .743 r
.55346 .39179 .5618 .41727 .57765 .43033 .56915 .39796 Mtetra
.428 .378 .701 r
.56915 .39796 .57765 .43033 .59385 .44774 .5851 .40782 Mtetra
.418 .346 .669 r
.5851 .40782 .59385 .44774 .61044 .46789 .60137 .42085 Mtetra
.426 .335 .65 r
.60137 .42085 .61044 .46789 .62736 .48791 .61796 .43556 Mtetra
.449 .342 .641 r
.61796 .43556 .62736 .48791 .64449 .504 .63482 .4495 Mtetra
.486 .364 .64 r
.63482 .4495 .64449 .504 .66161 .51233 .65182 .45967 Mtetra
.534 .401 .646 r
.65182 .45967 .66161 .51233 .67848 .5102 .66878 .46325 Mtetra
.593 .451 .657 r
.66878 .46325 .67848 .5102 .69492 .49696 .68553 .45848 Mtetra
.662 .514 .672 r
.68553 .45848 .69492 .49696 .71084 .47423 .70192 .44522 Mtetra
.736 .587 .689 r
.70192 .44522 .71084 .47423 .7263 .44535 .71792 .42505 Mtetra
.808 .668 .708 r
.71792 .42505 .7263 .44535 .74146 .41427 .7336 .40071 Mtetra
.865 .746 .729 r
.7336 .40071 .74146 .41427 .75655 .38446 .74909 .3752 Mtetra
.897 .81 .755 r
.74909 .3752 .75655 .38446 .77175 .35826 .76457 .35111 Mtetra
.899 .854 .789 r
.76457 .35111 .77175 .35826 .78722 .33671 .7802 .33004 Mtetra
.874 .872 .831 r
.7802 .33004 .78722 .33671 .80301 .31976 .79608 .31263 Mtetra
.83 .863 .87 r
.79608 .31263 .80301 .31976 .81915 .3067 .81225 .29874 Mtetra
.78 .837 .895 r
.81225 .29874 .81915 .3067 .8356 .29654 .82871 .28773 Mtetra
.736 .806 .907 r
.82871 .28773 .8356 .29654 .8523 .28834 .84543 .27884 Mtetra
.705 .78 .91 r
.84543 .27884 .8523 .28834 .8692 .28133 .86237 .27134 Mtetra
.664 .741 .908 r
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Mtetra
.2663 .45685 .27545 .46545 .28937 .4608 .28027 .45216 Mtetra
.28027 .45216 .28937 .4608 .30337 .45613 .29432 .44744 Mtetra
.29432 .44744 .30337 .45613 .31744 .45143 .30844 .4427 Mtetra
.30844 .4427 .31744 .45143 .33159 .44671 .32263 .43793 Mtetra
.32263 .43793 .33159 .44671 .34582 .44196 .3369 .43313 Mtetra
.3369 .43313 .34582 .44196 .36012 .43719 .35125 .42831 Mtetra
.35125 .42831 .36012 .43719 .3745 .43239 .36568 .42346 Mtetra
.36568 .42346 .3745 .43239 .38895 .42757 .38018 .41859 Mtetra
.38018 .41859 .38895 .42757 .40349 .42272 .39477 .41369 Mtetra
.663 .741 .908 r
.39477 .41369 .40349 .42272 .4181 .41785 .40943 .40877 Mtetra
.40943 .40877 .4181 .41785 .4328 .41298 .42417 .40383 Mtetra
.663 .74 .908 r
.42417 .40383 .4328 .41298 .44757 .40812 .439 .39887 Mtetra
.662 .739 .907 r
.439 .39887 .44757 .40812 .46242 .40335 .4539 .39393 Mtetra
.659 .736 .906 r
.4539 .39393 .46242 .40335 .47735 .39876 .46889 .38905 Mtetra
.655 .729 .904 r
.46889 .38905 .47735 .39876 .49236 .3946 .48396 .38434 Mtetra
.645 .715 .898 r
.48396 .38434 .49236 .3946 .50746 .3912 .49911 .37996 Mtetra
.629 .689 .888 r
.49911 .37996 .50746 .3912 .52266 .38912 .51435 .37622 Mtetra
.603 .649 .868 r
.51435 .37622 .52266 .38912 .53798 .38906 .52969 .37354 Mtetra
.569 .593 .837 r
.52969 .37354 .53798 .38906 .55346 .39179 .54515 .37244 Mtetra
.531 .527 .797 r
.54515 .37244 .55346 .39179 .56915 .39796 .56077 .37348 Mtetra
.497 .465 .752 r
.56077 .37348 .56915 .39796 .5851 .40782 .57657 .37709 Mtetra
.474 .417 .712 r
.57657 .37709 .5851 .40782 .60137 .42085 .59261 .38334 Mtetra
.467 .386 .682 r
.59261 .38334 .60137 .42085 .61796 .43556 .6089 .39167 Mtetra
.473 .374 .662 r
.6089 .39167 .61796 .43556 .63482 .4495 .62546 .40084 Mtetra
.492 .377 .651 r
.62546 .40084 .63482 .4495 .65182 .45967 .64221 .40896 Mtetra
.521 .394 .648 r
.64221 .40896 .65182 .45967 .66878 .46325 .65907 .41385 Mtetra
.559 .422 .651 r
.65907 .41385 .66878 .46325 .68553 .45848 .67589 .41362 Mtetra
.605 .462 .66 r
.67589 .41362 .68553 .45848 .70192 .44522 .69255 .40726 Mtetra
.657 .511 .674 r
.69255 .40726 .70192 .44522 .71792 .42505 .70896 .39494 Mtetra
.711 .569 .692 r
.70896 .39494 .71792 .42505 .7336 .40071 .7251 .37799 Mtetra
.764 .633 .715 r
.7251 .37799 .7336 .40071 .74909 .3752 .74105 .35845 Mtetra
.807 .698 .744 r
.74105 .35845 .74909 .3752 .76457 .35111 .75691 .33846 Mtetra
.832 .754 .778 r
.75691 .33846 .76457 .35111 .7802 .33004 .77282 .31974 Mtetra
.833 .795 .815 r
.77282 .31974 .7802 .33004 .79608 .31263 .78888 .30335 Mtetra
.812 .813 .851 r
.78888 .30335 .79608 .31263 .81225 .29874 .80516 .28962 Mtetra
.777 .811 .879 r
.80516 .28962 .81225 .29874 .82871 .28773 .82169 .27836 Mtetra
.741 .796 .897 r
.82169 .27836 .82871 .28773 .84543 .27884 .83846 .26908 Mtetra
.711 .779 .905 r
.83846 .26908 .84543 .27884 .86237 .27134 .85545 .26121 Mtetra
.664 .741 .908 r
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Mtetra
.25707 .44817 .2663 .45685 .28027 .45216 .27108 .44343 Mtetra
.27108 .44343 .28027 .45216 .29432 .44744 .28517 .43866 Mtetra
.28517 .43866 .29432 .44744 .30844 .4427 .29934 .43387 Mtetra
.29934 .43387 .30844 .4427 .32263 .43793 .31358 .42905 Mtetra
.31358 .42905 .32263 .43793 .3369 .43313 .3279 .42421 Mtetra
.3279 .42421 .3369 .43313 .35125 .42831 .34229 .41934 Mtetra
.34229 .41934 .35125 .42831 .36568 .42346 .35677 .41445 Mtetra
.35677 .41445 .36568 .42346 .38018 .41859 .37132 .40953 Mtetra
.37132 .40953 .38018 .41859 .39477 .41369 .38595 .40458 Mtetra
.38595 .40458 .39477 .41369 .40943 .40877 .40067 .3996 Mtetra
.663 .741 .908 r
.40067 .3996 .40943 .40877 .42417 .40383 .41546 .3946 Mtetra
.41546 .3946 .42417 .40383 .439 .39887 .43034 .38958 Mtetra
.663 .74 .908 r
.43034 .38958 .439 .39887 .4539 .39393 .4453 .38454 Mtetra
.662 .739 .907 r
.4453 .38454 .4539 .39393 .46889 .38905 .46034 .37951 Mtetra
.66 .736 .906 r
.46034 .37951 .46889 .38905 .48396 .38434 .47546 .37452 Mtetra
.656 .73 .904 r
.47546 .37452 .48396 .38434 .49911 .37996 .49067 .36965 Mtetra
.649 .718 .899 r
.49067 .36965 .49911 .37996 .51435 .37622 .50596 .36505 Mtetra
.637 .697 .889 r
.50596 .36505 .51435 .37622 .52969 .37354 .52135 .36091 Mtetra
.617 .663 .872 r
.52135 .36091 .52969 .37354 .54515 .37244 .53683 .35756 Mtetra
.591 .615 .845 r
.53683 .35756 .54515 .37244 .56077 .37348 .55243 .35535 Mtetra
.562 .559 .809 r
.55243 .35535 .56077 .37348 .57657 .37709 .56817 .35467 Mtetra
.535 .504 .769 r
.56817 .35467 .57657 .37709 .59261 .38334 .58408 .35574 Mtetra
.516 .46 .732 r
.58408 .35574 .59261 .38334 .6089 .39167 .60019 .35853 Mtetra
.509 .43 .702 r
.60019 .35853 .6089 .39167 .62546 .40084 .6165 .36256 Mtetra
.513 .415 .681 r
.6165 .36256 .62546 .40084 .64221 .40896 .63302 .36687 Mtetra
.527 .415 .669 r
.63302 .36687 .64221 .40896 .65907 .41385 .64969 .37013 Mtetra
.55 .427 .665 r
.64969 .37013 .65907 .41385 .67589 .41362 .66643 .3709 Mtetra
.58 .449 .667 r
.66643 .3709 .67589 .41362 .69255 .40726 .68316 .36802 Mtetra
.616 .481 .675 r
.68316 .36802 .69255 .40726 .70896 .39494 .69979 .36099 Mtetra
.655 .521 .688 r
.69979 .36099 .70896 .39494 .7251 .37799 .71627 .35009 Mtetra
.697 .57 .708 r
.71627 .35009 .7251 .37799 .74105 .35845 .7326 .33632 Mtetra
.735 .623 .734 r
.7326 .33632 .74105 .35845 .75691 .33846 .74885 .3211 Mtetra
.765 .677 .765 r
.74885 .3211 .75691 .33846 .77282 .31974 .76508 .30582 Mtetra
.78 .724 .8 r
.76508 .30582 .77282 .31974 .78888 .30335 .78139 .29155 Mtetra
.778 .758 .835 r
.78139 .29155 .78888 .30335 .80516 .28962 .79786 .27892 Mtetra
.76 .775 .865 r
.79786 .27892 .80516 .28962 .82169 .27836 .81451 .26806 Mtetra
.736 .776 .886 r
.81451 .26806 .82169 .27836 .83846 .26908 .83138 .25881 Mtetra
.711 .77 .898 r
.83138 .25881 .83846 .26908 .85545 .26121 .84844 .2508 Mtetra
.664 .741 .908 r
.23376 .44416 .24313 .45288 .25707 .44817 .24775 .4394 Mtetra
.24775 .4394 .25707 .44817 .27108 .44343 .2618 .43461 Mtetra
.2618 .43461 .27108 .44343 .28517 .43866 .27594 .4298 Mtetra
.27594 .4298 .28517 .43866 .29934 .43387 .29015 .42496 Mtetra
.29015 .42496 .29934 .43387 .31358 .42905 .30444 .42009 Mtetra
.30444 .42009 .31358 .42905 .3279 .42421 .3188 .4152 Mtetra
.3188 .4152 .3279 .42421 .34229 .41934 .33325 .41028 Mtetra
.33325 .41028 .34229 .41934 .35677 .41445 .34777 .40534 Mtetra
.34777 .40534 .35677 .41445 .37132 .40953 .36237 .40037 Mtetra
.36237 .40037 .37132 .40953 .38595 .40458 .37705 .39537 Mtetra
.37705 .39537 .38595 .40458 .40067 .3996 .39182 .39034 Mtetra
.39182 .39034 .40067 .3996 .41546 .3946 .40666 .38529 Mtetra
.663 .741 .908 r
.40666 .38529 .41546 .3946 .43034 .38958 .42159 .38021 Mtetra
.42159 .38021 .43034 .38958 .4453 .38454 .4366 .3751 Mtetra
.4366 .3751 .4453 .38454 .46034 .37951 .4517 .36998 Mtetra
.662 .74 .907 r
.4517 .36998 .46034 .37951 .47546 .37452 .46688 .36485 Mtetra
.661 .737 .906 r
.46688 .36485 .47546 .37452 .49067 .36965 .48214 .35975 Mtetra
.658 .732 .904 r
.48214 .35975 .49067 .36965 .50596 .36505 .49749 .35473 Mtetra
.653 .723 .9 r
.49749 .35473 .50596 .36505 .52135 .36091 .51293 .34988 Mtetra
.644 .706 .892 r
.51293 .34988 .52135 .36091 .53683 .35756 .52845 .34537 Mtetra
.63 .679 .877 r
.52845 .34537 .53683 .35756 .55243 .35535 .54408 .34137 Mtetra
.612 .641 .855 r
.54408 .34137 .55243 .35535 .56817 .35467 .55982 .33815 Mtetra
.59 .596 .826 r
.55982 .33815 .56817 .35467 .58408 .35574 .57569 .33591 Mtetra
.57 .549 .792 r
.57569 .33591 .58408 .35574 .60019 .35853 .5917 .33477 Mtetra
.554 .508 .758 r
.5917 .33477 .60019 .35853 .6165 .36256 .60788 .33466 Mtetra
.547 .478 .73 r
.60788 .33466 .6165 .36256 .63302 .36687 .62422 .3352 Mtetra
.549 .462 .709 r
.62422 .3352 .63302 .36687 .64969 .37013 .64072 .33573 Mtetra
.559 .458 .696 r
.64072 .33573 .64969 .37013 .66643 .3709 .65735 .33538 Mtetra
.576 .466 .691 r
.65735 .33538 .66643 .3709 .68316 .36802 .67404 .33327 Mtetra
.599 .483 .693 r
.67404 .33327 .68316 .36802 .69979 .36099 .69075 .32878 Mtetra
.627 .51 .701 r
.69075 .32878 .69979 .36099 .71627 .35009 .70741 .32167 Mtetra
.657 .545 .715 r
.70741 .32167 .71627 .35009 .7326 .33632 .72401 .31224 Mtetra
.688 .586 .736 r
.72401 .31224 .7326 .33632 .74885 .3211 .74056 .30117 Mtetra
.715 .631 .762 r
.74056 .30117 .74885 .3211 .76508 .30582 .7571 .28936 Mtetra
.734 .675 .793 r
.7571 .28936 .76508 .30582 .78139 .29155 .77368 .27766 Mtetra
.741 .713 .825 r
.77368 .27766 .78139 .29155 .79786 .27892 .79036 .26668 Mtetra
.736 .739 .854 r
.79036 .26668 .79786 .27892 .81451 .26806 .80718 .25674 Mtetra
.722 .753 .876 r
.80718 .25674 .81451 .26806 .83138 .25881 .82416 .2479 Mtetra
.706 .756 .892 r
.82416 .2479 .83138 .25881 .84844 .2508 .84132 .24001 Mtetra
.664 .741 .908 r
.2243 .43535 .23376 .44416 .24775 .4394 .23833 .43054 Mtetra
.23833 .43054 .24775 .4394 .2618 .43461 .25243 .4257 Mtetra
.25243 .4257 .2618 .43461 .27594 .4298 .26661 .42084 Mtetra
.26661 .42084 .27594 .4298 .29015 .42496 .28087 .41596 Mtetra
.28087 .41596 .29015 .42496 .30444 .42009 .2952 .41104 Mtetra
.2952 .41104 .30444 .42009 .3188 .4152 .30961 .4061 Mtetra
.30961 .4061 .3188 .4152 .33325 .41028 .32411 .40113 Mtetra
.32411 .40113 .33325 .41028 .34777 .40534 .33868 .39614 Mtetra
.33868 .39614 .34777 .40534 .36237 .40037 .35333 .39112 Mtetra
.35333 .39112 .36237 .40037 .37705 .39537 .36806 .38606 Mtetra
.36806 .38606 .37705 .39537 .39182 .39034 .38288 .38099 Mtetra
.38288 .38099 .39182 .39034 .40666 .38529 .39777 .37588 Mtetra
.39777 .37588 .40666 .38529 .42159 .38021 .41275 .37074 Mtetra
.41275 .37074 .42159 .38021 .4366 .3751 .42782 .36558 Mtetra
.663 .741 .908 r
.42782 .36558 .4366 .3751 .4517 .36998 .44297 .36039 Mtetra
.44297 .36039 .4517 .36998 .46688 .36485 .4582 .35518 Mtetra
.663 .74 .907 r
.4582 .35518 .46688 .36485 .48214 .35975 .47352 .34996 Mtetra
.662 .738 .907 r
.47352 .34996 .48214 .35975 .49749 .35473 .48892 .34475 Mtetra
.66 .734 .905 r
.48892 .34475 .49749 .35473 .51293 .34988 .50442 .33958 Mtetra
.656 .727 .902 r
.50442 .33958 .51293 .34988 .52845 .34537 .52 .33451 Mtetra
.65 .715 .895 r
.52 .33451 .52845 .34537 .54408 .34137 .53567 .32965 Mtetra
.642 .695 .885 r
.53567 .32965 .54408 .34137 .55982 .33815 .55145 .32511 Mtetra
.629 .668 .868 r
.55145 .32511 .55982 .33815 .57569 .33591 .56732 .32104 Mtetra
.615 .633 .845 r
.56732 .32104 .57569 .33591 .5917 .33477 .58332 .31755 Mtetra
.6 .595 .818 r
.58332 .31755 .5917 .33477 .60788 .33466 .59944 .3147 Mtetra
.588 .56 .79 r
.59944 .3147 .60788 .33466 .62422 .3352 .6157 .31239 Mtetra
.582 .533 .765 r
.6157 .31239 .62422 .3352 .64072 .33573 .6321 .31038 Mtetra
.582 .516 .746 r
.6321 .31038 .64072 .33573 .65735 .33538 .64863 .30824 Mtetra
.589 .51 .733 r
.64863 .30824 .65735 .33538 .67404 .33327 .66527 .30546 Mtetra
.601 .514 .728 r
.66527 .30546 .67404 .33327 .69075 .32878 .68197 .30155 Mtetra
.619 .528 .73 r
.68197 .30155 .69075 .32878 .70741 .32167 .69872 .29617 Mtetra
.639 .55 .738 r
.69872 .29617 .70741 .32167 .72401 .31224 .71547 .28928 Mtetra
.662 .58 .753 r
.71547 .28928 .72401 .31224 .74056 .30117 .73223 .28109 Mtetra
.683 .615 .773 r
.73223 .28109 .74056 .30117 .7571 .28936 .749 .27204 Mtetra
.7 .651 .798 r
.749 .27204 .7571 .28936 .77368 .27766 .76581 .26264 Mtetra
.71 .686 .825 r
.76581 .26264 .77368 .27766 .79036 .26668 .7827 .25338 Mtetra
.712 .714 .85 r
.7827 .25338 .79036 .26668 .80718 .25674 .7997 .24458 Mtetra
.706 .733 .872 r
.7997 .24458 .80718 .25674 .82416 .2479 .81682 .23638 Mtetra
.697 .743 .887 r
.81682 .23638 .82416 .2479 .84132 .24001 .83409 .2288 Mtetra
.664 .741 .908 r
.21474 .42645 .2243 .43535 .23833 .43054 .22882 .42159 Mtetra
.22882 .42159 .23833 .43054 .25243 .4257 .24296 .41671 Mtetra
.24296 .41671 .25243 .4257 .26661 .42084 .25719 .4118 Mtetra
.25719 .4118 .26661 .42084 .28087 .41596 .27149 .40686 Mtetra
.27149 .40686 .28087 .41596 .2952 .41104 .28587 .4019 Mtetra
.28587 .4019 .2952 .41104 .30961 .4061 .30033 .39691 Mtetra
.30033 .39691 .30961 .4061 .32411 .40113 .31487 .39189 Mtetra
.31487 .39189 .32411 .40113 .33868 .39614 .32949 .38684 Mtetra
.32949 .38684 .33868 .39614 .35333 .39112 .34419 .38177 Mtetra
.34419 .38177 .35333 .39112 .36806 .38606 .35898 .37667 Mtetra
.35898 .37667 .36806 .38606 .38288 .38099 .37384 .37154 Mtetra
.37384 .37154 .38288 .38099 .39777 .37588 .38879 .36638 Mtetra
.38879 .36638 .39777 .37588 .41275 .37074 .40382 .36119 Mtetra
.40382 .36119 .41275 .37074 .42782 .36558 .41894 .35597 Mtetra
.41894 .35597 .42782 .36558 .44297 .36039 .43414 .35072 Mtetra
.663 .741 .908 r
.43414 .35072 .44297 .36039 .4582 .35518 .44943 .34545 Mtetra
.44943 .34545 .4582 .35518 .47352 .34996 .46481 .34015 Mtetra
.663 .74 .907 r
.46481 .34015 .47352 .34996 .48892 .34475 .48027 .33483 Mtetra
.662 .739 .907 r
.48027 .33483 .48892 .34475 .50442 .33958 .49582 .32951 Mtetra
.661 .737 .906 r
.49582 .32951 .50442 .33958 .52 .33451 .51146 .3242 Mtetra
.659 .732 .903 r
.51146 .3242 .52 .33451 .53567 .32965 .52719 .31895 Mtetra
.655 .723 .899 r
.52719 .31895 .53567 .32965 .55145 .32511 .54301 .3138 Mtetra
.65 .71 .891 r
.54301 .3138 .55145 .32511 .56732 .32104 .55893 .30883 Mtetra
.643 .691 .88 r
.55893 .30883 .56732 .32104 .58332 .31755 .57495 .30412 Mtetra
.634 .667 .864 r
.57495 .30412 .58332 .31755 .59944 .3147 .59108 .29971 Mtetra
.624 .639 .845 r
.59108 .29971 .59944 .3147 .6157 .31239 .60733 .29564 Mtetra
.617 .612 .824 r
.60733 .29564 .6157 .31239 .6321 .31038 .62369 .29182 Mtetra
.612 .59 .804 r
.62369 .29182 .6321 .31038 .64863 .30824 .64018 .28811 Mtetra
.611 .574 .788 r
.64018 .28811 .64863 .30824 .66527 .30546 .65677 .28425 Mtetra
.616 .568 .777 r
.65677 .28425 .66527 .30546 .68197 .30155 .67347 .27996 Mtetra
.624 .57 .773 r
.67347 .27996 .68197 .30155 .69872 .29617 .69025 .275 Mtetra
.637 .581 .775 r
.69025 .275 .69872 .29617 .71547 .28928 .70708 .26921 Mtetra
.651 .599 .783 r
.70708 .26921 .71547 .28928 .73223 .28109 .72397 .2626 Mtetra
.666 .623 .796 r
.72397 .2626 .73223 .28109 .749 .27204 .7409 .2553 Mtetra
.679 .65 .814 r
.7409 .2553 .749 .27204 .76581 .26264 .75789 .24758 Mtetra
.688 .677 .834 r
.75789 .24758 .76581 .26264 .7827 .25338 .77495 .23972 Mtetra
.692 .702 .854 r
.77495 .23972 .7827 .25338 .7997 .24458 .79211 .23195 Mtetra
.691 .72 .872 r
.79211 .23195 .7997 .24458 .81682 .23638 .80937 .22444 Mtetra
.686 .733 .886 r
.80937 .22444 .81682 .23638 .83409 .2288 .82676 .21725 Mtetra
.664 .741 .908 r
.20509 .41746 .21474 .42645 .22882 .42159 .21921 .41256 Mtetra
.21921 .41256 .22882 .42159 .24296 .41671 .2334 .40762 Mtetra
.2334 .40762 .24296 .41671 .25719 .4118 .24767 .40267 Mtetra
.24767 .40267 .25719 .4118 .27149 .40686 .26202 .39768 Mtetra
.26202 .39768 .27149 .40686 .28587 .4019 .27645 .39266 Mtetra
.27645 .39266 .28587 .4019 .30033 .39691 .29096 .38762 Mtetra
.29096 .38762 .30033 .39691 .31487 .39189 .30555 .38255 Mtetra
.30555 .38255 .31487 .39189 .32949 .38684 .32021 .37745 Mtetra
.32021 .37745 .32949 .38684 .34419 .38177 .33497 .37233 Mtetra
.33497 .37233 .34419 .38177 .35898 .37667 .3498 .36717 Mtetra
.3498 .36717 .35898 .37667 .37384 .37154 .36472 .36199 Mtetra
.36472 .36199 .37384 .37154 .38879 .36638 .37972 .35677 Mtetra
.37972 .35677 .38879 .36638 .40382 .36119 .3948 .35153 Mtetra
.3948 .35153 .40382 .36119 .41894 .35597 .40997 .34626 Mtetra
.40997 .34626 .41894 .35597 .43414 .35072 .42523 .34096 Mtetra
.42523 .34096 .43414 .35072 .44943 .34545 .44057 .33563 Mtetra
.663 .741 .908 r
.44057 .33563 .44943 .34545 .46481 .34015 .456 .33027 Mtetra
.456 .33027 .46481 .34015 .48027 .33483 .47152 .32488 Mtetra
.47152 .32488 .48027 .33483 .49582 .32951 .48713 .31946 Mtetra
.663 .74 .907 r
.48713 .31946 .49582 .32951 .51146 .3242 .50282 .31403 Mtetra
.662 .738 .906 r
.50282 .31403 .51146 .3242 .52719 .31895 .51861 .3086 Mtetra
.661 .735 .905 r
.51861 .3086 .52719 .31895 .54301 .3138 .53449 .30318 Mtetra
.659 .73 .902 r
.53449 .30318 .54301 .3138 .55893 .30883 .55047 .29781 Mtetra
.656 .722 .897 r
.55047 .29781 .55893 .30883 .57495 .30412 .56654 .29252 Mtetra
.652 .71 .89 r
.56654 .29252 .57495 .30412 .59108 .29971 .5827 .28735 Mtetra
.647 .694 .88 r
.5827 .28735 .59108 .29971 .60733 .29564 .59898 .28232 Mtetra
.642 .676 .868 r
.59898 .28232 .60733 .29564 .62369 .29182 .61536 .27744 Mtetra
.637 .658 .854 r
.61536 .27744 .62369 .29182 .64018 .28811 .63185 .27266 Mtetra
.635 .642 .84 r
.63185 .27266 .64018 .28811 .65677 .28425 .64844 .26789 Mtetra
.635 .631 .829 r
.64844 .26789 .65677 .28425 .67347 .27996 .66515 .263 Mtetra
.637 .625 .821 r
.66515 .263 .67347 .27996 .69025 .275 .68195 .25785 Mtetra
.643 .626 .818 r
.68195 .25785 .69025 .275 .70708 .26921 .69884 .25232 Mtetra
.651 .634 .82 r
.69884 .25232 .70708 .26921 .72397 .2626 .7158 .24634 Mtetra
.659 .647 .827 r
.7158 .24634 .72397 .2626 .7409 .2553 .73285 .23994 Mtetra
.668 .665 .838 r
.73285 .23994 .7409 .2553 .75789 .24758 .74996 .2332 Mtetra
.674 .683 .851 r
.74996 .2332 .75789 .24758 .77495 .23972 .76716 .22627 Mtetra
.678 .701 .864 r
.76716 .22627 .77495 .23972 .79211 .23195 .78445 .21926 Mtetra
.679 .717 .877 r
.78445 .21926 .79211 .23195 .80937 .22444 .80184 .21231 Mtetra
.678 .728 .888 r
.80184 .21231 .80937 .22444 .82676 .21725 .81934 .20548 Mtetra
.664 .741 .908 r
.19534 .40839 .20509 .41746 .21921 .41256 .2095 .40343 Mtetra
.2095 .40343 .21921 .41256 .2334 .40762 .22374 .39845 Mtetra
.22374 .39845 .2334 .40762 .24767 .40267 .23806 .39344 Mtetra
.23806 .39344 .24767 .40267 .26202 .39768 .25245 .3884 Mtetra
.25245 .3884 .26202 .39768 .27645 .39266 .26693 .38333 Mtetra
.26693 .38333 .27645 .39266 .29096 .38762 .28149 .37824 Mtetra
.28149 .37824 .29096 .38762 .30555 .38255 .29612 .37312 Mtetra
.29612 .37312 .30555 .38255 .32021 .37745 .31084 .36797 Mtetra
.31084 .36797 .32021 .37745 .33497 .37233 .32564 .36279 Mtetra
.32564 .36279 .33497 .37233 .3498 .36717 .34053 .35758 Mtetra
.34053 .35758 .3498 .36717 .36472 .36199 .35549 .35234 Mtetra
.35549 .35234 .36472 .36199 .37972 .35677 .37055 .34707 Mtetra
.37055 .34707 .37972 .35677 .3948 .35153 .38569 .34178 Mtetra
.38569 .34178 .3948 .35153 .40997 .34626 .40091 .33645 Mtetra
.40091 .33645 .40997 .34626 .42523 .34096 .41622 .33109 Mtetra
.41622 .33109 .42523 .34096 .44057 .33563 .43162 .3257 Mtetra
.43162 .3257 .44057 .33563 .456 .33027 .4471 .32028 Mtetra
.4471 .32028 .456 .33027 .47152 .32488 .46268 .31483 Mtetra
.663 .741 .908 r
.46268 .31483 .47152 .32488 .48713 .31946 .47834 .30935 Mtetra
.47834 .30935 .48713 .31946 .50282 .31403 .4941 .30385 Mtetra
.663 .74 .907 r
.4941 .30385 .50282 .31403 .51861 .3086 .50995 .29832 Mtetra
.663 .739 .907 r
.50995 .29832 .51861 .3086 .53449 .30318 .52589 .29277 Mtetra
.662 .738 .906 r
.52589 .29277 .53449 .30318 .55047 .29781 .54192 .28721 Mtetra
.661 .735 .904 r
.54192 .28721 .55047 .29781 .56654 .29252 .55805 .28166 Mtetra
.66 .73 .902 r
.55805 .28166 .56654 .29252 .5827 .28735 .57427 .27613 Mtetra
.657 .723 .897 r
.57427 .27613 .5827 .28735 .59898 .28232 .59059 .27065 Mtetra
.655 .714 .892 r
.59059 .27065 .59898 .28232 .61536 .27744 .60701 .26522 Mtetra
.653 .704 .884 r
.60701 .26522 .61536 .27744 .63185 .27266 .62354 .25983 Mtetra
.65 .693 .876 r
.62354 .25983 .63185 .27266 .64844 .26789 .64017 .25447 Mtetra
.649 .683 .869 r
.64017 .25447 .64844 .26789 .66515 .263 .65691 .24908 Mtetra
.65 .676 .862 r
.65691 .24908 .66515 .263 .68195 .25785 .67374 .2436 Mtetra
.651 .673 .857 r
.67374 .2436 .68195 .25785 .69884 .25232 .69068 .23797 Mtetra
.655 .674 .856 r
.69068 .23797 .69884 .25232 .7158 .24634 .70771 .23212 Mtetra
.659 .679 .858 r
.70771 .23212 .7158 .24634 .73285 .23994 .72483 .22605 Mtetra
.663 .687 .862 r
.72483 .22605 .73285 .23994 .74996 .2332 .74204 .21977 Mtetra
.667 .698 .869 r
.74204 .21977 .74996 .2332 .76716 .22627 .75934 .21332 Mtetra
.67 .709 .877 r
.75934 .21332 .76716 .22627 .78445 .21926 .77674 .20677 Mtetra
.671 .719 .885 r
.77674 .20677 .78445 .21926 .80184 .21231 .79424 .20019 Mtetra
.671 .728 .892 r
.79424 .20019 .80184 .21231 .81934 .20548 .81185 .19361 Mtetra
.664 .741 .908 r
.18549 .39922 .19534 .40839 .2095 .40343 .1997 .39421 Mtetra
.1997 .39421 .2095 .40343 .22374 .39845 .21398 .38918 Mtetra
.21398 .38918 .22374 .39845 .23806 .39344 .22835 .38411 Mtetra
.22835 .38411 .23806 .39344 .25245 .3884 .24279 .37903 Mtetra
.24279 .37903 .25245 .3884 .26693 .38333 .25731 .37391 Mtetra
.25731 .37391 .26693 .38333 .28149 .37824 .27192 .36876 Mtetra
.27192 .36876 .28149 .37824 .29612 .37312 .2866 .36359 Mtetra
.2866 .36359 .29612 .37312 .31084 .36797 .30137 .35838 Mtetra
.30137 .35838 .31084 .36797 .32564 .36279 .31622 .35315 Mtetra
.31622 .35315 .32564 .36279 .34053 .35758 .33116 .34789 Mtetra
.33116 .34789 .34053 .35758 .35549 .35234 .34618 .34259 Mtetra
.34618 .34259 .35549 .35234 .37055 .34707 .36128 .33727 Mtetra
.36128 .33727 .37055 .34707 .38569 .34178 .37647 .33192 Mtetra
.37647 .33192 .38569 .34178 .40091 .33645 .39175 .32653 Mtetra
.39175 .32653 .40091 .33645 .41622 .33109 .40712 .32112 Mtetra
.40712 .32112 .41622 .33109 .43162 .3257 .42257 .31567 Mtetra
.42257 .31567 .43162 .3257 .4471 .32028 .43811 .31019 Mtetra
.43811 .31019 .4471 .32028 .46268 .31483 .45374 .30469 Mtetra
.45374 .30469 .46268 .31483 .47834 .30935 .46947 .29915 Mtetra
.46947 .29915 .47834 .30935 .4941 .30385 .48528 .29357 Mtetra
.663 .741 .908 r
.48528 .29357 .4941 .30385 .50995 .29832 .50119 .28797 Mtetra
.50119 .28797 .50995 .29832 .52589 .29277 .51719 .28234 Mtetra
.663 .74 .907 r
.51719 .28234 .52589 .29277 .54192 .28721 .53328 .27669 Mtetra
.663 .739 .907 r
.53328 .27669 .54192 .28721 .55805 .28166 .54947 .27101 Mtetra
.662 .738 .906 r
.54947 .27101 .55805 .28166 .57427 .27613 .56575 .26531 Mtetra
.662 .735 .904 r
.56575 .26531 .57427 .27613 .59059 .27065 .58213 .25962 Mtetra
.661 .732 .902 r
.58213 .25962 .59059 .27065 .60701 .26522 .59861 .25392 Mtetra
.66 .727 .899 r
.59861 .25392 .60701 .26522 .62354 .25983 .61519 .24822 Mtetra
.658 .722 .895 r
.61519 .24822 .62354 .25983 .64017 .25447 .63188 .24252 Mtetra
.658 .716 .891 r
.63188 .24252 .64017 .25447 .65691 .24908 .64866 .23681 Mtetra
.657 .711 .887 r
.64866 .23681 .65691 .24908 .67374 .2436 .66555 .23106 Mtetra
.658 .707 .884 r
.66555 .23106 .67374 .2436 .69068 .23797 .68254 .22524 Mtetra
.659 .706 .882 r
.68254 .22524 .69068 .23797 .70771 .23212 .69963 .21933 Mtetra
.66 .706 .881 r
.69963 .21933 .70771 .23212 .72483 .22605 .71682 .21331 Mtetra
.662 .709 .883 r
.71682 .21331 .72483 .22605 .74204 .21977 .73411 .20716 Mtetra
.664 .714 .885 r
.73411 .20716 .74204 .21977 .75934 .21332 .7515 .20091 Mtetra
.666 .72 .889 r
.7515 .20091 .75934 .21332 .77674 .20677 .76899 .19456 Mtetra
.667 .725 .893 r
.76899 .19456 .77674 .20677 .79424 .20019 .78658 .18816 Mtetra
.667 .73 .897 r
.78658 .18816 .79424 .20019 .81185 .19361 .80428 .18172 Mtetra
.664 .741 .908 r
.17555 .38995 .18549 .39922 .1997 .39421 .1898 .3849 Mtetra
.1898 .3849 .1997 .39421 .21398 .38918 .20413 .37981 Mtetra
.20413 .37981 .21398 .38918 .22835 .38411 .21853 .3747 Mtetra
.21853 .3747 .22835 .38411 .24279 .37903 .23302 .36955 Mtetra
.23302 .36955 .24279 .37903 .25731 .37391 .2476 .36438 Mtetra
.2476 .36438 .25731 .37391 .27192 .36876 .26225 .35918 Mtetra
.26225 .35918 .27192 .36876 .2866 .36359 .27698 .35396 Mtetra
.27698 .35396 .2866 .36359 .30137 .35838 .2918 .3487 Mtetra
.2918 .3487 .30137 .35838 .31622 .35315 .3067 .34341 Mtetra
.3067 .34341 .31622 .35315 .33116 .34789 .32169 .33809 Mtetra
.32169 .33809 .33116 .34789 .34618 .34259 .33676 .33274 Mtetra
.33676 .33274 .34618 .34259 .36128 .33727 .35192 .32736 Mtetra
.35192 .32736 .36128 .33727 .37647 .33192 .36716 .32195 Mtetra
.36716 .32195 .37647 .33192 .39175 .32653 .3825 .31651 Mtetra
.3825 .31651 .39175 .32653 .40712 .32112 .39792 .31104 Mtetra
.39792 .31104 .40712 .32112 .42257 .31567 .41343 .30554 Mtetra
.41343 .30554 .42257 .31567 .43811 .31019 .42902 .3 Mtetra
.42902 .3 .43811 .31019 .45374 .30469 .44471 .29443 Mtetra
.44471 .29443 .45374 .30469 .46947 .29915 .4605 .28883 Mtetra
.4605 .28883 .46947 .29915 .48528 .29357 .47637 .2832 Mtetra
.47637 .2832 .48528 .29357 .50119 .28797 .49233 .27753 Mtetra
.49233 .27753 .50119 .28797 .51719 .28234 .50839 .27184 Mtetra
.663 .741 .908 r
.50839 .27184 .51719 .28234 .53328 .27669 .52455 .26611 Mtetra
.52455 .26611 .53328 .27669 .54947 .27101 .5408 .26035 Mtetra
.663 .74 .907 r
.5408 .26035 .54947 .27101 .56575 .26531 .55715 .25456 Mtetra
.55715 .25456 .56575 .26531 .58213 .25962 .57359 .24874 Mtetra
.663 .738 .906 r
.57359 .24874 .58213 .25962 .59861 .25392 .59013 .2429 Mtetra
.662 .737 .905 r
.59013 .2429 .59861 .25392 .61519 .24822 .60678 .23705 Mtetra
.662 .734 .904 r
.60678 .23705 .61519 .24822 .63188 .24252 .62352 .23117 Mtetra
.661 .732 .902 r
.62352 .23117 .63188 .24252 .64866 .23681 .64036 .22526 Mtetra
.661 .729 .9 r
.64036 .22526 .64866 .23681 .66555 .23106 .65731 .21933 Mtetra
.661 .727 .898 r
.65731 .21933 .66555 .23106 .68254 .22524 .67436 .21336 Mtetra
.661 .725 .897 r
.67436 .21336 .68254 .22524 .69963 .21933 .69152 .20734 Mtetra
.662 .725 .896 r
.69152 .20734 .69963 .21933 .71682 .21331 .70878 .20125 Mtetra
.70878 .20125 .71682 .21331 .73411 .20716 .72614 .1951 Mtetra
.663 .727 .896 r
.72614 .1951 .73411 .20716 .7515 .20091 .7436 .18887 Mtetra
.664 .729 .898 r
.7436 .18887 .7515 .20091 .76899 .19456 .76117 .18258 Mtetra
.665 .731 .899 r
.76117 .18258 .76899 .19456 .78658 .18816 .77885 .17623 Mtetra
.665 .734 .901 r
.77885 .17623 .78658 .18816 .80428 .18172 .79664 .16984 Mtetra
.664 .741 .908 r
.1655 .38059 .17555 .38995 .1898 .3849 .17979 .37549 Mtetra
.17979 .37549 .1898 .3849 .20413 .37981 .19417 .37035 Mtetra
.19417 .37035 .20413 .37981 .21853 .3747 .20862 .36518 Mtetra
.20862 .36518 .21853 .3747 .23302 .36955 .22316 .35999 Mtetra
.22316 .35999 .23302 .36955 .2476 .36438 .23778 .35476 Mtetra
.23778 .35476 .2476 .36438 .26225 .35918 .25248 .34951 Mtetra
.25248 .34951 .26225 .35918 .27698 .35396 .26726 .34422 Mtetra
.26726 .34422 .27698 .35396 .2918 .3487 .28213 .33891 Mtetra
.28213 .33891 .2918 .3487 .3067 .34341 .29708 .33357 Mtetra
.29708 .33357 .3067 .34341 .32169 .33809 .31212 .32819 Mtetra
.31212 .32819 .32169 .33809 .33676 .33274 .32725 .32279 Mtetra
.32725 .32279 .33676 .33274 .35192 .32736 .34246 .31735 Mtetra
.34246 .31735 .35192 .32736 .36716 .32195 .35775 .31188 Mtetra
.35775 .31188 .36716 .32195 .3825 .31651 .37314 .30638 Mtetra
.37314 .30638 .3825 .31651 .39792 .31104 .38862 .30085 Mtetra
.38862 .30085 .39792 .31104 .41343 .30554 .40418 .29529 Mtetra
.40418 .29529 .41343 .30554 .42902 .3 .41984 .2897 Mtetra
.41984 .2897 .42902 .3 .44471 .29443 .43559 .28407 Mtetra
.43559 .28407 .44471 .29443 .4605 .28883 .45143 .27841 Mtetra
.45143 .27841 .4605 .28883 .47637 .2832 .46736 .27271 Mtetra
.46736 .27271 .47637 .2832 .49233 .27753 .48338 .26698 Mtetra
.48338 .26698 .49233 .27753 .50839 .27184 .49951 .26122 Mtetra
.49951 .26122 .50839 .27184 .52455 .26611 .51572 .25543 Mtetra
.51572 .25543 .52455 .26611 .5408 .26035 .53204 .2496 Mtetra
.663 .741 .908 r
.53204 .2496 .5408 .26035 .55715 .25456 .54845 .24374 Mtetra
.54845 .24374 .55715 .25456 .57359 .24874 .56495 .23784 Mtetra
.663 .74 .907 r
.56495 .23784 .57359 .24874 .59013 .2429 .58156 .23192 Mtetra
.58156 .23192 .59013 .2429 .60678 .23705 .59827 .22596 Mtetra
.663 .739 .907 r
.59827 .22596 .60678 .23705 .62352 .23117 .61508 .21997 Mtetra
.663 .738 .906 r
.61508 .21997 .62352 .23117 .64036 .22526 .63199 .21395 Mtetra
.663 .737 .905 r
.63199 .21395 .64036 .22526 .65731 .21933 .649 .2079 Mtetra
.663 .736 .904 r
.649 .2079 .65731 .21933 .67436 .21336 .66612 .20181 Mtetra
.663 .735 .904 r
.66612 .20181 .67436 .21336 .69152 .20734 .68334 .19569 Mtetra
.663 .734 .903 r
.68334 .19569 .69152 .20734 .70878 .20125 .70067 .18952 Mtetra
.70067 .18952 .70878 .20125 .72614 .1951 .71811 .1833 Mtetra
.71811 .1833 .72614 .1951 .7436 .18887 .73565 .17703 Mtetra
.664 .735 .903 r
.73565 .17703 .7436 .18887 .76117 .18258 .75329 .17071 Mtetra
.664 .736 .904 r
.75329 .17071 .76117 .18258 .77885 .17623 .77105 .16434 Mtetra
.664 .737 .904 r
.77105 .16434 .77885 .17623 .79664 .16984 .78892 .15793 Mtetra
.664 .741 .908 r
.15534 .37114 .1655 .38059 .17979 .37549 .16968 .36598 Mtetra
.16968 .36598 .17979 .37549 .19417 .37035 .1841 .36079 Mtetra
.1841 .36079 .19417 .37035 .20862 .36518 .19861 .35557 Mtetra
.19861 .35557 .20862 .36518 .22316 .35999 .21319 .35032 Mtetra
.21319 .35032 .22316 .35999 .23778 .35476 .22786 .34504 Mtetra
.22786 .34504 .23778 .35476 .25248 .34951 .24261 .33973 Mtetra
.24261 .33973 .25248 .34951 .26726 .34422 .25744 .33439 Mtetra
.25744 .33439 .26726 .34422 .28213 .33891 .27236 .32902 Mtetra
.27236 .32902 .28213 .33891 .29708 .33357 .28736 .32362 Mtetra
.28736 .32362 .29708 .33357 .31212 .32819 .30245 .31819 Mtetra
.30245 .31819 .31212 .32819 .32725 .32279 .31763 .31273 Mtetra
.31763 .31273 .32725 .32279 .34246 .31735 .33289 .30723 Mtetra
.33289 .30723 .34246 .31735 .35775 .31188 .34825 .30171 Mtetra
.34825 .30171 .35775 .31188 .37314 .30638 .36369 .29615 Mtetra
.36369 .29615 .37314 .30638 .38862 .30085 .37922 .29056 Mtetra
.37922 .29056 .38862 .30085 .40418 .29529 .39484 .28494 Mtetra
.39484 .28494 .40418 .29529 .41984 .2897 .41055 .27928 Mtetra
.41055 .27928 .41984 .2897 .43559 .28407 .42636 .27359 Mtetra
.42636 .27359 .43559 .28407 .45143 .27841 .44226 .26787 Mtetra
.44226 .26787 .45143 .27841 .46736 .27271 .45825 .26211 Mtetra
.45825 .26211 .46736 .27271 .48338 .26698 .47434 .25632 Mtetra
.47434 .25632 .48338 .26698 .49951 .26122 .49052 .2505 Mtetra
.49052 .2505 .49951 .26122 .51572 .25543 .5068 .24464 Mtetra
.5068 .24464 .51572 .25543 .53204 .2496 .52318 .23874 Mtetra
.52318 .23874 .53204 .2496 .54845 .24374 .53965 .23281 Mtetra
.53965 .23281 .54845 .24374 .56495 .23784 .55622 .22685 Mtetra
.663 .741 .908 r
.55622 .22685 .56495 .23784 .58156 .23192 .5729 .22085 Mtetra
.5729 .22085 .58156 .23192 .59827 .22596 .58967 .21482 Mtetra
.58967 .21482 .59827 .22596 .61508 .21997 .60655 .20875 Mtetra
.663 .74 .907 r
.60655 .20875 .61508 .21997 .63199 .21395 .62353 .20264 Mtetra
.62353 .20264 .63199 .21395 .649 .2079 .64061 .1965 Mtetra
.64061 .1965 .649 .2079 .66612 .20181 .6578 .19033 Mtetra
.663 .739 .906 r
.6578 .19033 .66612 .20181 .68334 .19569 .67509 .18411 Mtetra
.67509 .18411 .68334 .19569 .70067 .18952 .69249 .17786 Mtetra
.69249 .17786 .70067 .18952 .71811 .1833 .71 .17157 Mtetra
.71 .17157 .71811 .1833 .73565 .17703 .72761 .16523 Mtetra
.72761 .16523 .73565 .17703 .75329 .17071 .74534 .15885 Mtetra
.664 .739 .906 r
.74534 .15885 .75329 .17071 .77105 .16434 .76317 .15242 Mtetra
.76317 .15242 .77105 .16434 .78892 .15793 .78112 .14595 Mtetra
.664 .741 .908 r
.14508 .36159 .15534 .37114 .16968 .36598 .15947 .35637 Mtetra
.15947 .35637 .16968 .36598 .1841 .36079 .17394 .35113 Mtetra
.17394 .35113 .1841 .36079 .19861 .35557 .18849 .34585 Mtetra
.18849 .34585 .19861 .35557 .21319 .35032 .20312 .34055 Mtetra
.20312 .34055 .21319 .35032 .22786 .34504 .21783 .33521 Mtetra
.21783 .33521 .22786 .34504 .24261 .33973 .23263 .32985 Mtetra
.23263 .32985 .24261 .33973 .25744 .33439 .24752 .32445 Mtetra
.24752 .32445 .25744 .33439 .27236 .32902 .26248 .31903 Mtetra
.26248 .31903 .27236 .32902 .28736 .32362 .27754 .31357 Mtetra
.27754 .31357 .28736 .32362 .30245 .31819 .29268 .30808 Mtetra
.29268 .30808 .30245 .31819 .31763 .31273 .30791 .30256 Mtetra
.30791 .30256 .31763 .31273 .33289 .30723 .32323 .29701 Mtetra
.32323 .29701 .33289 .30723 .34825 .30171 .33863 .29142 Mtetra
.33863 .29142 .34825 .30171 .36369 .29615 .35413 .2858 Mtetra
.35413 .2858 .36369 .29615 .37922 .29056 .36972 .28015 Mtetra
.36972 .28015 .37922 .29056 .39484 .28494 .3854 .27447 Mtetra
.3854 .27447 .39484 .28494 .41055 .27928 .40117 .26875 Mtetra
.40117 .26875 .41055 .27928 .42636 .27359 .41703 .263 Mtetra
.41703 .263 .42636 .27359 .44226 .26787 .43299 .25721 Mtetra
.43299 .25721 .44226 .26787 .45825 .26211 .44904 .25139 Mtetra
.44904 .25139 .45825 .26211 .47434 .25632 .46519 .24554 Mtetra
.46519 .24554 .47434 .25632 .49052 .2505 .48143 .23965 Mtetra
.48143 .23965 .49052 .2505 .5068 .24464 .49778 .23373 Mtetra
.49778 .23373 .5068 .24464 .52318 .23874 .51422 .22777 Mtetra
.51422 .22777 .52318 .23874 .53965 .23281 .53076 .22177 Mtetra
.53076 .22177 .53965 .23281 .55622 .22685 .5474 .21574 Mtetra
.5474 .21574 .55622 .22685 .5729 .22085 .56414 .20967 Mtetra
.56414 .20967 .5729 .22085 .58967 .21482 .58098 .20357 Mtetra
.58098 .20357 .58967 .21482 .60655 .20875 .59792 .19743 Mtetra
.663 .741 .908 r
.59792 .19743 .60655 .20875 .62353 .20264 .61497 .19125 Mtetra
.61497 .19125 .62353 .20264 .64061 .1965 .63212 .18503 Mtetra
.63212 .18503 .64061 .1965 .6578 .19033 .64938 .17878 Mtetra
.663 .741 .907 r
.64938 .17878 .6578 .19033 .67509 .18411 .66675 .17249 Mtetra
.66675 .17249 .67509 .18411 .69249 .17786 .68422 .16615 Mtetra
.663 .74 .907 r
.68422 .16615 .69249 .17786 .71 .17157 .7018 .15978 Mtetra
.7018 .15978 .71 .17157 .72761 .16523 .71949 .15337 Mtetra
.71949 .15337 .72761 .16523 .74534 .15885 .73729 .14692 Mtetra
.664 .74 .907 r
.73729 .14692 .74534 .15885 .76317 .15242 .75521 .14043 Mtetra
.75521 .14043 .76317 .15242 .78112 .14595 .77323 .13389 Mtetra
.664 .741 .908 r
.13472 .35194 .14508 .36159 .15947 .35637 .14915 .34667 Mtetra
.14915 .34667 .15947 .35637 .17394 .35113 .16366 .34137 Mtetra
.16366 .34137 .17394 .35113 .18849 .34585 .17826 .33604 Mtetra
.17826 .33604 .18849 .34585 .20312 .34055 .19294 .33068 Mtetra
.19294 .33068 .20312 .34055 .21783 .33521 .2077 .32529 Mtetra
.2077 .32529 .21783 .33521 .23263 .32985 .22255 .31986 Mtetra
.22255 .31986 .23263 .32985 .24752 .32445 .23748 .31441 Mtetra
.23748 .31441 .24752 .32445 .26248 .31903 .2525 .30893 Mtetra
.2525 .30893 .26248 .31903 .27754 .31357 .26761 .30341 Mtetra
.26761 .30341 .27754 .31357 .29268 .30808 .2828 .29786 Mtetra
.2828 .29786 .29268 .30808 .30791 .30256 .29809 .29228 Mtetra
.29809 .29228 .30791 .30256 .32323 .29701 .31346 .28667 Mtetra
.31346 .28667 .32323 .29701 .33863 .29142 .32892 .28102 Mtetra
.32892 .28102 .33863 .29142 .35413 .2858 .34447 .27534 Mtetra
.34447 .27534 .35413 .2858 .36972 .28015 .36011 .26963 Mtetra
.36011 .26963 .36972 .28015 .3854 .27447 .37585 .26389 Mtetra
.37585 .26389 .3854 .27447 .40117 .26875 .39168 .25811 Mtetra
.39168 .25811 .40117 .26875 .41703 .263 .4076 .25229 Mtetra
.4076 .25229 .41703 .263 .43299 .25721 .42362 .24644 Mtetra
.42362 .24644 .43299 .25721 .44904 .25139 .43973 .24056 Mtetra
.43973 .24056 .44904 .25139 .46519 .24554 .45594 .23464 Mtetra
.45594 .23464 .46519 .24554 .48143 .23965 .47225 .22869 Mtetra
.47225 .22869 .48143 .23965 .49778 .23373 .48865 .2227 Mtetra
.48865 .2227 .49778 .23373 .51422 .22777 .50516 .21667 Mtetra
.50516 .21667 .51422 .22777 .53076 .22177 .52176 .21061 Mtetra
.52176 .21061 .53076 .22177 .5474 .21574 .53847 .20451 Mtetra
.53847 .20451 .5474 .21574 .56414 .20967 .55527 .19837 Mtetra
.55527 .19837 .56414 .20967 .58098 .20357 .57218 .1922 Mtetra
.57218 .1922 .58098 .20357 .59792 .19743 .5892 .18598 Mtetra
.5892 .18598 .59792 .19743 .61497 .19125 .60632 .17973 Mtetra
.60632 .17973 .61497 .19125 .63212 .18503 .62354 .17344 Mtetra
.62354 .17344 .63212 .18503 .64938 .17878 .64087 .16712 Mtetra
.64087 .16712 .64938 .17878 .66675 .17249 .65831 .16075 Mtetra
.65831 .16075 .66675 .17249 .68422 .16615 .67586 .15434 Mtetra
.67586 .15434 .68422 .16615 .7018 .15978 .69351 .1479 Mtetra
.69351 .1479 .7018 .15978 .71949 .15337 .71128 .14141 Mtetra
.71128 .14141 .71949 .15337 .73729 .14692 .72916 .13488 Mtetra
.72916 .13488 .73729 .14692 .75521 .14043 .74715 .12831 Mtetra
.74715 .12831 .75521 .14043 .77323 .13389 .76526 .1217 Mtetra
.12424 .34218 .13472 .35194 .14915 .34667 .13872 .33686 Mtetra
.13872 .33686 .14915 .34667 .16366 .34137 .15328 .3315 Mtetra
.15328 .3315 .16366 .34137 .17826 .33604 .16793 .32612 Mtetra
.16793 .32612 .17826 .33604 .19294 .33068 .18265 .3207 Mtetra
.18265 .3207 .19294 .33068 .2077 .32529 .19747 .31525 Mtetra
.19747 .31525 .2077 .32529 .22255 .31986 .21236 .30977 Mtetra
.21236 .30977 .22255 .31986 .23748 .31441 .22735 .30426 Mtetra
.22735 .30426 .23748 .31441 .2525 .30893 .24242 .29872 Mtetra
.24242 .29872 .2525 .30893 .26761 .30341 .25758 .29314 Mtetra
.25758 .29314 .26761 .30341 .2828 .29786 .27282 .28753 Mtetra
.27282 .28753 .2828 .29786 .29809 .29228 .28816 .28189 Mtetra
.28816 .28189 .29809 .29228 .31346 .28667 .30358 .27622 Mtetra
.30358 .27622 .31346 .28667 .32892 .28102 .3191 .27051 Mtetra
.3191 .27051 .32892 .28102 .34447 .27534 .33471 .26477 Mtetra
.33471 .26477 .34447 .27534 .36011 .26963 .35041 .259 Mtetra
.35041 .259 .36011 .26963 .37585 .26389 .3662 .25319 Mtetra
.3662 .25319 .37585 .26389 .39168 .25811 .38209 .24735 Mtetra
.38209 .24735 .39168 .25811 .4076 .25229 .39807 .24147 Mtetra
.39807 .24147 .4076 .25229 .42362 .24644 .41415 .23555 Mtetra
.41415 .23555 .42362 .24644 .43973 .24056 .43032 .22961 Mtetra
.43032 .22961 .43973 .24056 .45594 .23464 .44659 .22362 Mtetra
.44659 .22362 .45594 .23464 .47225 .22869 .46296 .2176 Mtetra
.46296 .2176 .47225 .22869 .48865 .2227 .47943 .21154 Mtetra
.47943 .21154 .48865 .2227 .50516 .21667 .496 .20545 Mtetra
.496 .20545 .50516 .21667 .52176 .21061 .51267 .19932 Mtetra
.51267 .19932 .52176 .21061 .53847 .20451 .52944 .19315 Mtetra
.52944 .19315 .53847 .20451 .55527 .19837 .54631 .18694 Mtetra
.54631 .18694 .55527 .19837 .57218 .1922 .56329 .1807 Mtetra
.56329 .1807 .57218 .1922 .5892 .18598 .58037 .17441 Mtetra
.58037 .17441 .5892 .18598 .60632 .17973 .59756 .16809 Mtetra
.59756 .16809 .60632 .17973 .62354 .17344 .61486 .16173 Mtetra
.61486 .16173 .62354 .17344 .64087 .16712 .63226 .15533 Mtetra
.63226 .15533 .64087 .16712 .65831 .16075 .64977 .14889 Mtetra
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Mtetra
.6674 .14241 .67586 .15434 .69351 .1479 .68513 .13589 Mtetra
.68513 .13589 .69351 .1479 .71128 .14141 .70297 .12932 Mtetra
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76526 .1217 .75719 .10938 Mtetra
.11366 .33233 .12424 .34218 .13872 .33686 .12818 .32695 Mtetra
.12818 .32695 .13872 .33686 .15328 .3315 .14279 .32154 Mtetra
.14279 .32154 .15328 .3315 .16793 .32612 .15748 .31609 Mtetra
.15748 .31609 .16793 .32612 .18265 .3207 .17226 .31062 Mtetra
.17226 .31062 .18265 .3207 .19747 .31525 .18712 .30511 Mtetra
.18712 .30511 .19747 .31525 .21236 .30977 .20207 .29957 Mtetra
.20207 .29957 .21236 .30977 .22735 .30426 .2171 .294 Mtetra
.2171 .294 .22735 .30426 .24242 .29872 .23222 .2884 Mtetra
.23222 .2884 .24242 .29872 .25758 .29314 .24743 .28276 Mtetra
.24743 .28276 .25758 .29314 .27282 .28753 .26273 .2771 Mtetra
.26273 .2771 .27282 .28753 .28816 .28189 .27812 .27139 Mtetra
.27812 .27139 .28816 .28189 .30358 .27622 .2936 .26566 Mtetra
.2936 .26566 .30358 .27622 .3191 .27051 .30917 .25989 Mtetra
.30917 .25989 .3191 .27051 .33471 .26477 .32484 .25409 Mtetra
.32484 .25409 .33471 .26477 .35041 .259 .34059 .24825 Mtetra
.34059 .24825 .35041 .259 .3662 .25319 .35644 .24237 Mtetra
.35644 .24237 .3662 .25319 .38209 .24735 .37239 .23647 Mtetra
.37239 .23647 .38209 .24735 .39807 .24147 .38843 .23052 Mtetra
.38843 .23052 .39807 .24147 .41415 .23555 .40457 .22454 Mtetra
.40457 .22454 .41415 .23555 .43032 .22961 .4208 .21853 Mtetra
.4208 .21853 .43032 .22961 .44659 .22362 .43714 .21248 Mtetra
.43714 .21248 .44659 .22362 .46296 .2176 .45357 .20639 Mtetra
.45357 .20639 .46296 .2176 .47943 .21154 .4701 .20026 Mtetra
.4701 .20026 .47943 .21154 .496 .20545 .48673 .1941 Mtetra
.48673 .1941 .496 .20545 .51267 .19932 .50347 .1879 Mtetra
.50347 .1879 .51267 .19932 .52944 .19315 .52031 .18166 Mtetra
.52031 .18166 .52944 .19315 .54631 .18694 .53725 .17538 Mtetra
.53725 .17538 .54631 .18694 .56329 .1807 .5543 .16907 Mtetra
.5543 .16907 .56329 .1807 .58037 .17441 .57145 .16271 Mtetra
.57145 .16271 .58037 .17441 .59756 .16809 .58871 .15632 Mtetra
.58871 .15632 .59756 .16809 .61486 .16173 .60608 .14988 Mtetra
.60608 .14988 .61486 .16173 .63226 .15533 .62355 .14341 Mtetra
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Mtetra
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Mtetra
.65884 .13033 .6674 .14241 .68513 .13589 .67665 .12374 Mtetra
.67665 .12374 .68513 .13589 .70297 .12932 .69457 .11709 Mtetra
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.10296 .32237 .11366 .33233 .12818 .32695 .11753 .31693 Mtetra
.11753 .31693 .12818 .32695 .14279 .32154 .13219 .31146 Mtetra
.13219 .31146 .14279 .32154 .15748 .31609 .14693 .30596 Mtetra
.14693 .30596 .15748 .31609 .17226 .31062 .16175 .30043 Mtetra
.16175 .30043 .17226 .31062 .18712 .30511 .17666 .29486 Mtetra
.17666 .29486 .18712 .30511 .20207 .29957 .19166 .28926 Mtetra
.19166 .28926 .20207 .29957 .2171 .294 .20674 .28363 Mtetra
.20674 .28363 .2171 .294 .23222 .2884 .22192 .27797 Mtetra
.22192 .27797 .23222 .2884 .24743 .28276 .23718 .27227 Mtetra
.23718 .27227 .24743 .28276 .26273 .2771 .25253 .26654 Mtetra
.25253 .26654 .26273 .2771 .27812 .27139 .26797 .26078 Mtetra
.26797 .26078 .27812 .27139 .2936 .26566 .28351 .25498 Mtetra
.28351 .25498 .2936 .26566 .30917 .25989 .29914 .24915 Mtetra
.29914 .24915 .30917 .25989 .32484 .25409 .31485 .24328 Mtetra
.31485 .24328 .32484 .25409 .34059 .24825 .33067 .23738 Mtetra
.33067 .23738 .34059 .24825 .35644 .24237 .34658 .23144 Mtetra
.34658 .23144 .35644 .24237 .37239 .23647 .36258 .22547 Mtetra
.36258 .22547 .37239 .23647 .38843 .23052 .37868 .21946 Mtetra
.37868 .21946 .38843 .23052 .40457 .22454 .39488 .21341 Mtetra
.39488 .21341 .40457 .22454 .4208 .21853 .41118 .20733 Mtetra
.41118 .20733 .4208 .21853 .43714 .21248 .42757 .20121 Mtetra
.42757 .20121 .43714 .21248 .45357 .20639 .44407 .19505 Mtetra
.44407 .19505 .45357 .20639 .4701 .20026 .46067 .18886 Mtetra
.46067 .18886 .4701 .20026 .48673 .1941 .47737 .18262 Mtetra
.47737 .18262 .48673 .1941 .50347 .1879 .49417 .17635 Mtetra
.49417 .17635 .50347 .1879 .52031 .18166 .51107 .17004 Mtetra
.51107 .17004 .52031 .18166 .53725 .17538 .52808 .16369 Mtetra
.52808 .16369 .53725 .17538 .5543 .16907 .5452 .1573 Mtetra
.5452 .1573 .5543 .16907 .57145 .16271 .56242 .15087 Mtetra
.56242 .15087 .57145 .16271 .58871 .15632 .57976 .1444 Mtetra
.57976 .1444 .58871 .15632 .60608 .14988 .5972 .1379 Mtetra
.5972 .1379 .60608 .14988 .62355 .14341 .61475 .13134 Mtetra
.61475 .13134 .62355 .14341 .64114 .13689 .63241 .12475 Mtetra
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Mtetra
.65018 .11812 .65884 .13033 .67665 .12374 .66806 .11144 Mtetra
.66806 .11144 .67665 .12374 .69457 .11709 .68606 .10472 Mtetra
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Mtetra
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.09215 .3123 .10296 .32237 .11753 .31693 .10677 .30681 Mtetra
.10677 .30681 .11753 .31693 .13219 .31146 .12147 .30128 Mtetra
.12147 .30128 .13219 .31146 .14693 .30596 .13626 .29572 Mtetra
.13626 .29572 .14693 .30596 .16175 .30043 .15113 .29013 Mtetra
.15113 .29013 .16175 .30043 .17666 .29486 .16609 .2845 Mtetra
.16609 .2845 .17666 .29486 .19166 .28926 .18114 .27884 Mtetra
.18114 .27884 .19166 .28926 .20674 .28363 .19627 .27315 Mtetra
.19627 .27315 .20674 .28363 .22192 .27797 .2115 .26743 Mtetra
.2115 .26743 .22192 .27797 .23718 .27227 .22681 .26167 Mtetra
.22681 .26167 .23718 .27227 .25253 .26654 .24222 .25587 Mtetra
.24222 .25587 .25253 .26654 .26797 .26078 .25772 .25005 Mtetra
.25772 .25005 .26797 .26078 .28351 .25498 .27331 .24418 Mtetra
.27331 .24418 .28351 .25498 .29914 .24915 .28899 .23829 Mtetra
.28899 .23829 .29914 .24915 .31485 .24328 .30476 .23236 Mtetra
.30476 .23236 .31485 .24328 .33067 .23738 .32064 .22639 Mtetra
.32064 .22639 .33067 .23738 .34658 .23144 .3366 .22038 Mtetra
.3366 .22038 .34658 .23144 .36258 .22547 .35267 .21434 Mtetra
.35267 .21434 .36258 .22547 .37868 .21946 .36883 .20827 Mtetra
.36883 .20827 .37868 .21946 .39488 .21341 .38509 .20215 Mtetra
.38509 .20215 .39488 .21341 .41118 .20733 .40145 .196 Mtetra
.40145 .196 .41118 .20733 .42757 .20121 .4179 .18981 Mtetra
.4179 .18981 .42757 .20121 .44407 .19505 .43446 .18358 Mtetra
.43446 .18358 .44407 .19505 .46067 .18886 .45113 .17732 Mtetra
.45113 .17732 .46067 .18886 .47737 .18262 .46789 .17101 Mtetra
.46789 .17101 .47737 .18262 .49417 .17635 .48476 .16467 Mtetra
.48476 .16467 .49417 .17635 .51107 .17004 .50173 .15829 Mtetra
.50173 .15829 .51107 .17004 .52808 .16369 .51881 .15187 Mtetra
.51881 .15187 .52808 .16369 .5452 .1573 .536 .1454 Mtetra
.536 .1454 .5452 .1573 .56242 .15087 .55329 .1389 Mtetra
.55329 .1389 .56242 .15087 .57976 .1444 .5707 .13236 Mtetra
.5707 .13236 .57976 .1444 .5972 .1379 .58821 .12577 Mtetra
.58821 .12577 .5972 .1379 .61475 .13134 .60583 .11914 Mtetra
.60583 .11914 .61475 .13134 .63241 .12475 .62357 .11247 Mtetra
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Mtetra
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Mtetra
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Mtetra
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Mtetra
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.08123 .30213 .09215 .3123 .10677 .30681 .09589 .29658 Mtetra
.09589 .29658 .10677 .30681 .12147 .30128 .11064 .29099 Mtetra
.11064 .29099 .12147 .30128 .13626 .29572 .12548 .28537 Mtetra
.12548 .28537 .13626 .29572 .15113 .29013 .1404 .27972 Mtetra
.1404 .27972 .15113 .29013 .16609 .2845 .15541 .27403 Mtetra
.15541 .27403 .16609 .2845 .18114 .27884 .1705 .26831 Mtetra
.1705 .26831 .18114 .27884 .19627 .27315 .18569 .26256 Mtetra
.18569 .26256 .19627 .27315 .2115 .26743 .20097 .25677 Mtetra
.20097 .25677 .2115 .26743 .22681 .26167 .21634 .25095 Mtetra
.21634 .25095 .22681 .26167 .24222 .25587 .23179 .24509 Mtetra
.23179 .24509 .24222 .25587 .25772 .25005 .24735 .2392 Mtetra
.24735 .2392 .25772 .25005 .27331 .24418 .26299 .23327 Mtetra
.26299 .23327 .27331 .24418 .28899 .23829 .27873 .22731 Mtetra
.27873 .22731 .28899 .23829 .30476 .23236 .29456 .22131 Mtetra
.29456 .22131 .30476 .23236 .32064 .22639 .31049 .21527 Mtetra
.31049 .21527 .32064 .22639 .3366 .22038 .32652 .2092 Mtetra
.32652 .2092 .3366 .22038 .35267 .21434 .34264 .20309 Mtetra
.34264 .20309 .35267 .21434 .36883 .20827 .35886 .19695 Mtetra
.35886 .19695 .36883 .20827 .38509 .20215 .37518 .19077 Mtetra
.37518 .19077 .38509 .20215 .40145 .196 .3916 .18454 Mtetra
.3916 .18454 .40145 .196 .4179 .18981 .40812 .17828 Mtetra
.40812 .17828 .4179 .18981 .43446 .18358 .42475 .17199 Mtetra
.42475 .17199 .43446 .18358 .45113 .17732 .44148 .16565 Mtetra
.44148 .16565 .45113 .17732 .46789 .17101 .45831 .15927 Mtetra
.45831 .15927 .46789 .17101 .48476 .16467 .47524 .15286 Mtetra
.47524 .15286 .48476 .16467 .50173 .15829 .49228 .1464 Mtetra
.49228 .1464 .50173 .15829 .51881 .15187 .50943 .1399 Mtetra
.50943 .1399 .51881 .15187 .536 .1454 .52669 .13336 Mtetra
.52669 .13336 .536 .1454 .55329 .1389 .54406 .12679 Mtetra
.54406 .12679 .55329 .1389 .5707 .13236 .56153 .12016 Mtetra
.56153 .12016 .5707 .13236 .58821 .12577 .57912 .1135 Mtetra
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Mtetra
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Mtetra
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Mtetra
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Mtetra
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Mtetra
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Mtetra
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Mtetra
.07019 .29185 .08123 .30213 .09589 .29658 .0849 .28624 Mtetra
.0849 .28624 .09589 .29658 .11064 .29099 .09969 .28059 Mtetra
.09969 .28059 .11064 .29099 .12548 .28537 .11458 .27491 Mtetra
.11458 .27491 .12548 .28537 .1404 .27972 .12955 .26919 Mtetra
.12955 .26919 .1404 .27972 .15541 .27403 .14461 .26344 Mtetra
.14461 .26344 .15541 .27403 .1705 .26831 .15975 .25766 Mtetra
.15975 .25766 .1705 .26831 .18569 .26256 .17499 .25184 Mtetra
.17499 .25184 .18569 .26256 .20097 .25677 .19032 .24599 Mtetra
.19032 .24599 .20097 .25677 .21634 .25095 .20574 .24011 Mtetra
.20574 .24011 .21634 .25095 .23179 .24509 .22125 .23418 Mtetra
.22125 .23418 .23179 .24509 .24735 .2392 .23686 .22823 Mtetra
.23686 .22823 .24735 .2392 .26299 .23327 .25256 .22223 Mtetra
.25256 .22223 .26299 .23327 .27873 .22731 .26835 .2162 Mtetra
.26835 .2162 .27873 .22731 .29456 .22131 .28424 .21014 Mtetra
.28424 .21014 .29456 .22131 .31049 .21527 .30023 .20404 Mtetra
.30023 .20404 .31049 .21527 .32652 .2092 .31632 .1979 Mtetra
.31632 .1979 .32652 .2092 .34264 .20309 .3325 .19172 Mtetra
.3325 .19172 .34264 .20309 .35886 .19695 .34878 .1855 Mtetra
.34878 .1855 .35886 .19695 .37518 .19077 .36516 .17925 Mtetra
.36516 .17925 .37518 .19077 .3916 .18454 .38165 .17296 Mtetra
.38165 .17296 .3916 .18454 .40812 .17828 .39823 .16663 Mtetra
.39823 .16663 .40812 .17828 .42475 .17199 .41492 .16026 Mtetra
.41492 .16026 .42475 .17199 .44148 .16565 .43171 .15385 Mtetra
.43171 .15385 .44148 .16565 .45831 .15927 .44861 .1474 Mtetra
.44861 .1474 .45831 .15927 .47524 .15286 .46562 .1409 Mtetra
.46562 .1409 .47524 .15286 .49228 .1464 .48273 .13437 Mtetra
.48273 .13437 .49228 .1464 .50943 .1399 .49994 .1278 Mtetra
.49994 .1278 .50943 .1399 .52669 .13336 .51727 .12119 Mtetra
.51727 .12119 .52669 .13336 .54406 .12679 .53471 .11453 Mtetra
.53471 .11453 .54406 .12679 .56153 .12016 .55226 .10783 Mtetra
.55226 .10783 .56153 .12016 .57912 .1135 .56992 .10109 Mtetra
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Mtetra
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Mtetra
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Mtetra
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Mtetra
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Mtetra
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Mtetra
.05902 .28146 .07019 .29185 .0849 .28624 .07378 .27578 Mtetra
.07378 .27578 .0849 .28624 .09969 .28059 .08863 .27007 Mtetra
.08863 .27007 .09969 .28059 .11458 .27491 .10356 .26433 Mtetra
.10356 .26433 .11458 .27491 .12955 .26919 .11858 .25855 Mtetra
.11858 .25855 .12955 .26919 .14461 .26344 .13369 .25274 Mtetra
.13369 .25274 .14461 .26344 .15975 .25766 .14889 .24689 Mtetra
.14889 .24689 .15975 .25766 .17499 .25184 .16417 .24101 Mtetra
.16417 .24101 .17499 .25184 .19032 .24599 .17956 .2351 Mtetra
.17956 .2351 .19032 .24599 .20574 .24011 .19503 .22915 Mtetra
.19503 .22915 .20574 .24011 .22125 .23418 .2106 .22316 Mtetra
.2106 .22316 .22125 .23418 .23686 .22823 .22626 .21713 Mtetra
.22626 .21713 .23686 .22823 .25256 .22223 .24201 .21107 Mtetra
.24201 .21107 .25256 .22223 .26835 .2162 .25786 .20498 Mtetra
.25786 .20498 .26835 .2162 .28424 .21014 .27381 .19884 Mtetra
.27381 .19884 .28424 .21014 .30023 .20404 .28986 .19267 Mtetra
.28986 .19267 .30023 .20404 .31632 .1979 .306 .18646 Mtetra
.306 .18646 .31632 .1979 .3325 .19172 .32224 .18021 Mtetra
.32224 .18021 .3325 .19172 .34878 .1855 .33859 .17393 Mtetra
.33859 .17393 .34878 .1855 .36516 .17925 .35503 .1676 Mtetra
.35503 .1676 .36516 .17925 .38165 .17296 .37158 .16124 Mtetra
.37158 .16124 .38165 .17296 .39823 .16663 .38823 .15483 Mtetra
.38823 .15483 .39823 .16663 .41492 .16026 .40498 .14839 Mtetra
.40498 .14839 .41492 .16026 .43171 .15385 .42184 .14191 Mtetra
.42184 .14191 .43171 .15385 .44861 .1474 .4388 .13538 Mtetra
.4388 .13538 .44861 .1474 .46562 .1409 .45588 .12881 Mtetra
.45588 .12881 .46562 .1409 .48273 .13437 .47306 .12221 Mtetra
.47306 .12221 .48273 .13437 .49994 .1278 .49034 .11556 Mtetra
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Mtetra
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Mtetra
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Mtetra
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Mtetra
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Mtetra
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Mtetra
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Mtetra
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Mtetra
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Mtetra
.04774 .27095 .05902 .28146 .07378 .27578 .06255 .26522 Mtetra
.06255 .26522 .07378 .27578 .08863 .27007 .07744 .25944 Mtetra
.07744 .25944 .08863 .27007 .10356 .26433 .09242 .25364 Mtetra
.09242 .25364 .10356 .26433 .11858 .25855 .10749 .2478 Mtetra
.10749 .2478 .11858 .25855 .13369 .25274 .12265 .24192 Mtetra
.12265 .24192 .13369 .25274 .14889 .24689 .1379 .23601 Mtetra
.1379 .23601 .14889 .24689 .16417 .24101 .15324 .23006 Mtetra
.15324 .23006 .16417 .24101 .17956 .2351 .16867 .22408 Mtetra
.16867 .22408 .17956 .2351 .19503 .22915 .1842 .21806 Mtetra
.1842 .21806 .19503 .22915 .2106 .22316 .19982 .21201 Mtetra
.19982 .21201 .2106 .22316 .22626 .21713 .21553 .20592 Mtetra
.21553 .20592 .22626 .21713 .24201 .21107 .23135 .19979 Mtetra
.23135 .19979 .24201 .21107 .25786 .20498 .24725 .19362 Mtetra
.24725 .19362 .25786 .20498 .27381 .19884 .26326 .18742 Mtetra
.26326 .18742 .27381 .19884 .28986 .19267 .27936 .18118 Mtetra
.27936 .18118 .28986 .19267 .306 .18646 .29557 .1749 Mtetra
.29557 .1749 .306 .18646 .32224 .18021 .31187 .16858 Mtetra
.31187 .16858 .32224 .18021 .33859 .17393 .32828 .16222 Mtetra
.32828 .16222 .33859 .17393 .35503 .1676 .34478 .15582 Mtetra
.34478 .15582 .35503 .1676 .37158 .16124 .36139 .14938 Mtetra
.36139 .14938 .37158 .16124 .38823 .15483 .37811 .14291 Mtetra
.37811 .14291 .38823 .15483 .40498 .14839 .39493 .13639 Mtetra
.39493 .13639 .40498 .14839 .42184 .14191 .41185 .12983 Mtetra
.41185 .12983 .42184 .14191 .4388 .13538 .42888 .12323 Mtetra
.42888 .12323 .4388 .13538 .45588 .12881 .44602 .11658 Mtetra
.44602 .11658 .45588 .12881 .47306 .12221 .46327 .1099 Mtetra
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Mtetra
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Mtetra
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Mtetra
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Mtetra
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Mtetra
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Mtetra
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Mtetra
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Mtetra
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Mtetra
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.03634 .26033 .04774 .27095 .06255 .26522 .05119 .25453 Mtetra
.05119 .25453 .06255 .26522 .07744 .25944 .06613 .2487 Mtetra
.06613 .2487 .07744 .25944 .09242 .25364 .08116 .24283 Mtetra
.08116 .24283 .09242 .25364 .10749 .2478 .09628 .23692 Mtetra
.09628 .23692 .10749 .2478 .12265 .24192 .11148 .23098 Mtetra
.11148 .23098 .12265 .24192 .1379 .23601 .12679 .225 Mtetra
.12679 .225 .1379 .23601 .15324 .23006 .14218 .21899 Mtetra
.14218 .21899 .15324 .23006 .16867 .22408 .15767 .21294 Mtetra
.15767 .21294 .16867 .22408 .1842 .21806 .17325 .20686 Mtetra
.17325 .20686 .1842 .21806 .19982 .21201 .18892 .20073 Mtetra
.18892 .20073 .19982 .21201 .21553 .20592 .20469 .19457 Mtetra
.20469 .19457 .21553 .20592 .23135 .19979 .22056 .18838 Mtetra
.22056 .18838 .23135 .19979 .24725 .19362 .23652 .18214 Mtetra
.23652 .18214 .24725 .19362 .26326 .18742 .25259 .17587 Mtetra
.25259 .17587 .26326 .18742 .27936 .18118 .26875 .16955 Mtetra
.26875 .16955 .27936 .18118 .29557 .1749 .28501 .1632 Mtetra
.28501 .1632 .29557 .1749 .31187 .16858 .30138 .15681 Mtetra
.30138 .15681 .31187 .16858 .32828 .16222 .31785 .15038 Mtetra
.31785 .15038 .32828 .16222 .34478 .15582 .33442 .14391 Mtetra
.33442 .14391 .34478 .15582 .36139 .14938 .35109 .13739 Mtetra
.35109 .13739 .36139 .14938 .37811 .14291 .36787 .13084 Mtetra
.36787 .13084 .37811 .14291 .39493 .13639 .38475 .12424 Mtetra
.38475 .12424 .39493 .13639 .41185 .12983 .40174 .11761 Mtetra
.40174 .11761 .41185 .12983 .42888 .12323 .41884 .11093 Mtetra
.41884 .11093 .42888 .12323 .44602 .11658 .43605 .10421 Mtetra
.43605 .10421 .44602 .11658 .46327 .1099 .45337 .09744 Mtetra
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Mtetra
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Mtetra
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Mtetra
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Mtetra
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Mtetra
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Mtetra
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Mtetra
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Mtetra
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Mtetra
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Mtetra
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Mtetra
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Mtetra
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Mtetra
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Mtetra
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Mtetra
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Mtetra
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Mtetra
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Mtetra
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Mtetra
.57384 .54314 .58111 .55092 .59512 .54671 .5879 .53889 Mtetra
.5879 .53889 .59512 .54671 .60921 .54249 .60203 .53463 Mtetra
.60203 .53463 .60921 .54249 .62337 .53824 .61624 .53034 Mtetra
.61624 .53034 .62337 .53824 .63759 .53397 .63052 .52603 Mtetra
.63052 .52603 .63759 .53397 .6519 .52968 .64487 .5217 Mtetra
.64487 .5217 .6519 .52968 .66627 .52537 .6593 .51735 Mtetra
.6593 .51735 .66627 .52537 .68072 .52103 .67379 .51297 Mtetra
.67379 .51297 .68072 .52103 .69524 .51668 .68837 .50857 Mtetra
.68837 .50857 .69524 .51668 .70984 .5123 .70302 .50415 Mtetra
.70302 .50415 .70984 .5123 .72452 .5079 .71774 .49971 Mtetra
.71774 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Mtetra
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Mtetra
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Mtetra
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Mtetra
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Mtetra
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Mtetra
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Mtetra
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Mtetra
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Mtetra
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Mtetra
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .53529 Mtetra
.5665 .53529 .57384 .54314 .5879 .53889 .58061 .531 Mtetra
.58061 .531 .5879 .53889 .60203 .53463 .59479 .5267 Mtetra
.59479 .5267 .60203 .53463 .61624 .53034 .60905 .52237 Mtetra
.60905 .52237 .61624 .53034 .63052 .52603 .62338 .51802 Mtetra
.62338 .51802 .63052 .52603 .64487 .5217 .63778 .51365 Mtetra
.63778 .51365 .64487 .5217 .6593 .51735 .65225 .50925 Mtetra
.65225 .50925 .6593 .51735 .67379 .51297 .6668 .50483 Mtetra
.6668 .50483 .67379 .51297 .68837 .50857 .68143 .50039 Mtetra
.68143 .50039 .68837 .50857 .70302 .50415 .69613 .49593 Mtetra
.69613 .49593 .70302 .50415 .71774 .49971 .71091 .49144 Mtetra
.71091 .49144 .71774 .49971 .73255 .49524 .72577 .48693 Mtetra
.72577 .48693 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Mtetra
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Mtetra
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Mtetra
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55702 Mtetra
.46198 .55702 .4697 .56468 .48332 .56054 .47564 .55285 Mtetra
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Mtetra
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Mtetra
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .5402 Mtetra
.51705 .5402 .5246 .54801 .5385 .54379 .531 .53594 Mtetra
.531 .53594 .5385 .54379 .55246 .53955 .54501 .53166 Mtetra
.54501 .53166 .55246 .53955 .5665 .53529 .5591 .52736 Mtetra
.5591 .52736 .5665 .53529 .58061 .531 .57325 .52304 Mtetra
.57325 .52304 .58061 .531 .59479 .5267 .58748 .51869 Mtetra
.58748 .51869 .59479 .5267 .60905 .52237 .60179 .51432 Mtetra
.60179 .51432 .60905 .52237 .62338 .51802 .61616 .50993 Mtetra
.61616 .50993 .62338 .51802 .63778 .51365 .63062 .50552 Mtetra
.63062 .50552 .63778 .51365 .65225 .50925 .64514 .50108 Mtetra
.64514 .50108 .65225 .50925 .6668 .50483 .65974 .49662 Mtetra
.65974 .49662 .6668 .50483 .68143 .50039 .67442 .49214 Mtetra
.67442 .49214 .68143 .50039 .69613 .49593 .68918 .48763 Mtetra
.68918 .48763 .69613 .49593 .71091 .49144 .70401 .4831 Mtetra
.70401 .4831 .71091 .49144 .72577 .48693 .71892 .47854 Mtetra
.71892 .47854 .72577 .48693 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46936 Mtetra
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Mtetra
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56181 Mtetra
.41347 .56181 .42139 .56942 .43486 .56531 .42697 .55767 Mtetra
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .55349 Mtetra
.44054 .55349 .44838 .56118 .46198 .55702 .45418 .5493 Mtetra
.45418 .5493 .46198 .55702 .47564 .55285 .46789 .54509 Mtetra
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Mtetra
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Mtetra
.49552 .5366 .50318 .54444 .51705 .5402 .50944 .53232 Mtetra
.50944 .53232 .51705 .5402 .531 .53594 .52343 .52802 Mtetra
.52343 .52802 .531 .53594 .54501 .53166 .53749 .5237 Mtetra
.53749 .5237 .54501 .53166 .5591 .52736 .55162 .51936 Mtetra
.55162 .51936 .5591 .52736 .57325 .52304 .56582 .51499 Mtetra
.56582 .51499 .57325 .52304 .58748 .51869 .5801 .51061 Mtetra
.5801 .51061 .58748 .51869 .60179 .51432 .59446 .5062 Mtetra
.59446 .5062 .60179 .51432 .61616 .50993 .60888 .50176 Mtetra
.60888 .50176 .61616 .50993 .63062 .50552 .62338 .49731 Mtetra
.62338 .49731 .63062 .50552 .64514 .50108 .63796 .49283 Mtetra
.63796 .49283 .64514 .50108 .65974 .49662 .65262 .48832 Mtetra
.65262 .48832 .65974 .49662 .67442 .49214 .66735 .4838 Mtetra
.66735 .4838 .67442 .49214 .68918 .48763 .68215 .47925 Mtetra
.68215 .47925 .68918 .48763 .70401 .4831 .69704 .47467 Mtetra
.69704 .47467 .70401 .4831 .71892 .47854 .712 .47007 Mtetra
.712 .47007 .71892 .47854 .73391 .47397 .72705 .46545 Mtetra
.72705 .46545 .73391 .47397 .74897 .46936 .74217 .4608 Mtetra
.74217 .4608 .74897 .46936 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Mtetra
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Mtetra
.39199 .55831 .40003 .56594 .41347 .56181 .40547 .55414 Mtetra
.40547 .55414 .41347 .56181 .42697 .55767 .41902 .54995 Mtetra
.41902 .54995 .42697 .55767 .44054 .55349 .43263 .54574 Mtetra
.43263 .54574 .44054 .55349 .45418 .5493 .44632 .54151 Mtetra
.44632 .54151 .45418 .5493 .46789 .54509 .46007 .53726 Mtetra
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .53298 Mtetra
.47389 .53298 .48167 .54086 .49552 .5366 .48778 .52869 Mtetra
.48778 .52869 .49552 .5366 .50944 .53232 .50175 .52437 Mtetra
.50175 .52437 .50944 .53232 .52343 .52802 .51578 .52003 Mtetra
.51578 .52003 .52343 .52802 .53749 .5237 .52989 .51567 Mtetra
.52989 .51567 .53749 .5237 .55162 .51936 .54407 .51128 Mtetra
.54407 .51128 .55162 .51936 .56582 .51499 .55833 .50688 Mtetra
.55833 .50688 .56582 .51499 .5801 .51061 .57265 .50245 Mtetra
.57265 .50245 .5801 .51061 .59446 .5062 .58706 .49799 Mtetra
.58706 .49799 .59446 .5062 .60888 .50176 .60153 .49352 Mtetra
.60153 .49352 .60888 .50176 .62338 .49731 .61609 .48902 Mtetra
.61609 .48902 .62338 .49731 .63796 .49283 .63071 .48449 Mtetra
.63071 .48449 .63796 .49283 .65262 .48832 .64542 .47995 Mtetra
.64542 .47995 .65262 .48832 .66735 .4838 .6602 .47538 Mtetra
.6602 .47538 .66735 .4838 .68215 .47925 .67506 .47078 Mtetra
.67506 .47078 .68215 .47925 .69704 .47467 .69 .46616 Mtetra
.69 .46616 .69704 .47467 .712 .47007 .70502 .46152 Mtetra
.70502 .46152 .712 .47007 .72705 .46545 .72012 .45685 Mtetra
.72012 .45685 .72705 .46545 .74217 .4608 .7353 .45216 Mtetra
.7353 .45216 .74217 .4608 .75737 .45613 .75056 .44744 Mtetra
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Mtetra
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Mtetra
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Mtetra
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Mtetra
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Mtetra
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53791 Mtetra
.42465 .53791 .43263 .54574 .44632 .54151 .43837 .53364 Mtetra
.43837 .53364 .44632 .54151 .46007 .53726 .45217 .52935 Mtetra
.45217 .52935 .46007 .53726 .47389 .53298 .46604 .52504 Mtetra
.46604 .52504 .47389 .53298 .48778 .52869 .47998 .5207 Mtetra
.47998 .5207 .48778 .52869 .50175 .52437 .49399 .51634 Mtetra
.49399 .51634 .50175 .52437 .51578 .52003 .50807 .51196 Mtetra
.50807 .51196 .51578 .52003 .52989 .51567 .52222 .50756 Mtetra
.52222 .50756 .52989 .51567 .54407 .51128 .53645 .50313 Mtetra
.53645 .50313 .54407 .51128 .55833 .50688 .55076 .49868 Mtetra
.55076 .49868 .55833 .50688 .57265 .50245 .56513 .49421 Mtetra
.56513 .49421 .57265 .50245 .58706 .49799 .57958 .48971 Mtetra
.57958 .48971 .58706 .49799 .60153 .49352 .59411 .48519 Mtetra
.59411 .48519 .60153 .49352 .61609 .48902 .60871 .48065 Mtetra
.60871 .48065 .61609 .48902 .63071 .48449 .6234 .47608 Mtetra
.6234 .47608 .63071 .48449 .64542 .47995 .63815 .47149 Mtetra
.63815 .47149 .64542 .47995 .6602 .47538 .65299 .46688 Mtetra
.65299 .46688 .6602 .47538 .67506 .47078 .6679 .46224 Mtetra
.6679 .46224 .67506 .47078 .69 .46616 .6829 .45757 Mtetra
.6829 .45757 .69 .46616 .70502 .46152 .69797 .45288 Mtetra
.69797 .45288 .70502 .46152 .72012 .45685 .71312 .44817 Mtetra
.71312 .44817 .72012 .45685 .7353 .45216 .72836 .44343 Mtetra
.72836 .44343 .7353 .45216 .75056 .44744 .74368 .43866 Mtetra
.74368 .43866 .75056 .44744 .7659 .4427 .75908 .43387 Mtetra
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42905 Mtetra
.77456 .42905 .78132 .43793 .79683 .43313 .79013 .42421 Mtetra
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Mtetra
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .5343 Mtetra
.40288 .5343 .41099 .54216 .42465 .53791 .41658 .53001 Mtetra
.41658 .53001 .42465 .53791 .43837 .53364 .43036 .5257 Mtetra
.43036 .5257 .43837 .53364 .45217 .52935 .4442 .52137 Mtetra
.4442 .52137 .45217 .52935 .46604 .52504 .45811 .51701 Mtetra
.45811 .51701 .46604 .52504 .47998 .5207 .4721 .51263 Mtetra
.4721 .51263 .47998 .5207 .49399 .51634 .48615 .50823 Mtetra
.48615 .50823 .49399 .51634 .50807 .51196 .50028 .50381 Mtetra
.50028 .50381 .50807 .51196 .52222 .50756 .51448 .49937 Mtetra
.51448 .49937 .52222 .50756 .53645 .50313 .52876 .4949 Mtetra
.52876 .4949 .53645 .50313 .55076 .49868 .54311 .4904 Mtetra
.54311 .4904 .55076 .49868 .56513 .49421 .55754 .48589 Mtetra
.55754 .48589 .56513 .49421 .57958 .48971 .57204 .48135 Mtetra
.57204 .48135 .57958 .48971 .59411 .48519 .58662 .47679 Mtetra
.58662 .47679 .59411 .48519 .60871 .48065 .60127 .4722 Mtetra
.60127 .4722 .60871 .48065 .6234 .47608 .616 .46759 Mtetra
.616 .46759 .6234 .47608 .63815 .47149 .63082 .46295 Mtetra
.63082 .46295 .63815 .47149 .65299 .46688 .6457 .45829 Mtetra
.6457 .45829 .65299 .46688 .6679 .46224 .66067 .4536 Mtetra
.66067 .4536 .6679 .46224 .6829 .45757 .67572 .44889 Mtetra
.67572 .44889 .6829 .45757 .69797 .45288 .69085 .44416 Mtetra
.69085 .44416 .69797 .45288 .71312 .44817 .70606 .4394 Mtetra
.70606 .4394 .71312 .44817 .72836 .44343 .72135 .43461 Mtetra
.72135 .43461 .72836 .44343 .74368 .43866 .73673 .4298 Mtetra
.73673 .4298 .74368 .43866 .75908 .43387 .75218 .42496 Mtetra
.75218 .42496 .75908 .43387 .77456 .42905 .76773 .42009 Mtetra
.76773 .42009 .77456 .42905 .79013 .42421 .78335 .4152 Mtetra
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Mtetra
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Mtetra
.38103 .53067 .38925 .53857 .40288 .5343 .3947 .52637 Mtetra
.3947 .52637 .40288 .5343 .41658 .53001 .40845 .52204 Mtetra
.40845 .52204 .41658 .53001 .43036 .5257 .42226 .51768 Mtetra
.42226 .51768 .43036 .5257 .4442 .52137 .43615 .51331 Mtetra
.43615 .51331 .4442 .52137 .45811 .51701 .45011 .50891 Mtetra
.45011 .50891 .45811 .51701 .4721 .51263 .46414 .50449 Mtetra
.46414 .50449 .4721 .51263 .48615 .50823 .47824 .50005 Mtetra
.47824 .50005 .48615 .50823 .50028 .50381 .49242 .49559 Mtetra
.49242 .49559 .50028 .50381 .51448 .49937 .50667 .4911 Mtetra
.50667 .4911 .51448 .49937 .52876 .4949 .52099 .48658 Mtetra
.52099 .48658 .52876 .4949 .54311 .4904 .53539 .48205 Mtetra
.53539 .48205 .54311 .4904 .55754 .48589 .54987 .47749 Mtetra
.54987 .47749 .55754 .48589 .57204 .48135 .56442 .47291 Mtetra
.56442 .47291 .57204 .48135 .58662 .47679 .57905 .4683 Mtetra
.57905 .4683 .58662 .47679 .60127 .4722 .59376 .46367 Mtetra
.59376 .46367 .60127 .4722 .616 .46759 .60854 .45901 Mtetra
.60854 .45901 .616 .46759 .63082 .46295 .62341 .45433 Mtetra
.62341 .45433 .63082 .46295 .6457 .45829 .63835 .44962 Mtetra
.63835 .44962 .6457 .45829 .66067 .4536 .65337 .44489 Mtetra
.65337 .44489 .66067 .4536 .67572 .44889 .66847 .44013 Mtetra
.66847 .44013 .67572 .44889 .69085 .44416 .68366 .43535 Mtetra
.68366 .43535 .69085 .44416 .70606 .4394 .69892 .43054 Mtetra
.69892 .43054 .70606 .4394 .72135 .43461 .71427 .4257 Mtetra
.71427 .4257 .72135 .43461 .73673 .4298 .72971 .42084 Mtetra
.72971 .42084 .73673 .4298 .75218 .42496 .74522 .41596 Mtetra
.74522 .41596 .75218 .42496 .76773 .42009 .76082 .41104 Mtetra
.76082 .41104 .76773 .42009 .78335 .4152 .77651 .4061 Mtetra
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Mtetra
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Mtetra
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Mtetra
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51835 Mtetra
.38644 .51835 .3947 .52637 .40845 .52204 .40023 .51398 Mtetra
.40023 .51398 .40845 .52204 .42226 .51768 .41409 .50959 Mtetra
.41409 .50959 .42226 .51768 .43615 .51331 .42802 .50518 Mtetra
.42802 .50518 .43615 .51331 .45011 .50891 .44203 .50074 Mtetra
.44203 .50074 .45011 .50891 .46414 .50449 .45611 .49627 Mtetra
.45611 .49627 .46414 .50449 .47824 .50005 .47026 .49179 Mtetra
.47026 .49179 .47824 .50005 .49242 .49559 .48448 .48728 Mtetra
.48448 .48728 .49242 .49559 .50667 .4911 .49878 .48275 Mtetra
.49878 .48275 .50667 .4911 .52099 .48658 .51315 .47819 Mtetra
.51315 .47819 .52099 .48658 .53539 .48205 .5276 .47361 Mtetra
.5276 .47361 .53539 .48205 .54987 .47749 .54213 .46901 Mtetra
.54213 .46901 .54987 .47749 .56442 .47291 .55673 .46438 Mtetra
.55673 .46438 .56442 .47291 .57905 .4683 .57141 .45973 Mtetra
.57141 .45973 .57905 .4683 .59376 .46367 .58617 .45505 Mtetra
.58617 .45505 .59376 .46367 .60854 .45901 .60101 .45035 Mtetra
.60101 .45035 .60854 .45901 .62341 .45433 .61592 .44562 Mtetra
.61592 .44562 .62341 .45433 .63835 .44962 .63092 .44086 Mtetra
.63092 .44086 .63835 .44962 .65337 .44489 .646 .43609 Mtetra
.646 .43609 .65337 .44489 .66847 .44013 .66115 .43128 Mtetra
.66115 .43128 .66847 .44013 .68366 .43535 .6764 .42645 Mtetra
.6764 .42645 .68366 .43535 .69892 .43054 .69172 .42159 Mtetra
.69172 .42159 .69892 .43054 .71427 .4257 .70712 .41671 Mtetra
.70712 .41671 .71427 .4257 .72971 .42084 .72262 .4118 Mtetra
.72262 .4118 .72971 .42084 .74522 .41596 .73819 .40686 Mtetra
.73819 .40686 .74522 .41596 .76082 .41104 .75385 .4019 Mtetra
.75385 .4019 .76082 .41104 .77651 .4061 .7696 .39691 Mtetra
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Mtetra
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Mtetra
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Mtetra
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Mtetra
.36434 .51466 .37272 .5227 .38644 .51835 .37811 .51027 Mtetra
.37811 .51027 .38644 .51835 .40023 .51398 .39194 .50586 Mtetra
.39194 .50586 .40023 .51398 .41409 .50959 .40584 .50142 Mtetra
.40584 .50142 .41409 .50959 .42802 .50518 .41982 .49696 Mtetra
.41982 .49696 .42802 .50518 .44203 .50074 .43387 .49248 Mtetra
.43387 .49248 .44203 .50074 .45611 .49627 .44799 .48798 Mtetra
.44799 .48798 .45611 .49627 .47026 .49179 .46219 .48345 Mtetra
.46219 .48345 .47026 .49179 .48448 .48728 .47646 .47889 Mtetra
.47646 .47889 .48448 .48728 .49878 .48275 .49081 .47432 Mtetra
.49081 .47432 .49878 .48275 .51315 .47819 .50523 .46972 Mtetra
.50523 .46972 .51315 .47819 .5276 .47361 .51973 .46509 Mtetra
.51973 .46509 .5276 .47361 .54213 .46901 .53431 .46044 Mtetra
.53431 .46044 .54213 .46901 .55673 .46438 .54896 .45577 Mtetra
.54896 .45577 .55673 .46438 .57141 .45973 .56369 .45107 Mtetra
.56369 .45107 .57141 .45973 .58617 .45505 .57851 .44635 Mtetra
.57851 .44635 .58617 .45505 .60101 .45035 .5934 .4416 Mtetra
.5934 .4416 .60101 .45035 .61592 .44562 .60837 .43682 Mtetra
.60837 .43682 .61592 .44562 .63092 .44086 .62342 .43202 Mtetra
.62342 .43202 .63092 .44086 .646 .43609 .63855 .4272 Mtetra
.63855 .4272 .646 .43609 .66115 .43128 .65376 .42234 Mtetra
.65376 .42234 .66115 .43128 .6764 .42645 .66906 .41746 Mtetra
.66906 .41746 .6764 .42645 .69172 .42159 .68444 .41256 Mtetra
.68444 .41256 .69172 .42159 .70712 .41671 .6999 .40762 Mtetra
.6999 .40762 .70712 .41671 .72262 .4118 .71545 .40267 Mtetra
.71545 .40267 .72262 .4118 .73819 .40686 .73109 .39768 Mtetra
.73109 .39768 .73819 .40686 .75385 .4019 .74681 .39266 Mtetra
.74681 .39266 .75385 .4019 .7696 .39691 .76262 .38762 Mtetra
.76262 .38762 .7696 .39691 .78543 .39189 .77851 .38255 Mtetra
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Mtetra
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .5021 Mtetra
.36969 .5021 .37811 .51027 .39194 .50586 .38357 .49765 Mtetra
.38357 .49765 .39194 .50586 .40584 .50142 .39752 .49317 Mtetra
.39752 .49317 .40584 .50142 .41982 .49696 .41154 .48867 Mtetra
.41154 .48867 .41982 .49696 .43387 .49248 .42564 .48415 Mtetra
.42564 .48415 .43387 .49248 .44799 .48798 .43981 .4796 Mtetra
.43981 .4796 .44799 .48798 .46219 .48345 .45405 .47502 Mtetra
.45405 .47502 .46219 .48345 .47646 .47889 .46837 .47043 Mtetra
.46837 .47043 .47646 .47889 .49081 .47432 .48277 .46581 Mtetra
.48277 .46581 .49081 .47432 .50523 .46972 .49724 .46116 Mtetra
.49724 .46116 .50523 .46972 .51973 .46509 .51179 .45649 Mtetra
.51179 .45649 .51973 .46509 .53431 .46044 .52641 .4518 Mtetra
.52641 .4518 .53431 .46044 .54896 .45577 .54112 .44708 Mtetra
.54112 .44708 .54896 .45577 .56369 .45107 .5559 .44233 Mtetra
.5559 .44233 .56369 .45107 .57851 .44635 .57077 .43756 Mtetra
.57077 .43756 .57851 .44635 .5934 .4416 .58571 .43276 Mtetra
.58571 .43276 .5934 .4416 .60837 .43682 .60073 .42794 Mtetra
.60073 .42794 .60837 .43682 .62342 .43202 .61584 .42309 Mtetra
.61584 .42309 .62342 .43202 .63855 .4272 .63103 .41822 Mtetra
.63103 .41822 .63855 .4272 .65376 .42234 .6463 .41331 Mtetra
.6463 .41331 .65376 .42234 .66906 .41746 .66165 .40839 Mtetra
.66165 .40839 .66906 .41746 .68444 .41256 .67709 .40343 Mtetra
.67709 .40343 .68444 .41256 .6999 .40762 .69261 .39845 Mtetra
.69261 .39845 .6999 .40762 .71545 .40267 .70822 .39344 Mtetra
.70822 .39344 .71545 .40267 .73109 .39768 .72391 .3884 Mtetra
.72391 .3884 .73109 .39768 .74681 .39266 .73969 .38333 Mtetra
.73969 .38333 .74681 .39266 .76262 .38762 .75556 .37824 Mtetra
.75556 .37824 .76262 .38762 .77851 .38255 .77152 .37312 Mtetra
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Mtetra
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Mtetra
.34734 .49834 .35588 .50654 .36969 .5021 .36119 .49386 Mtetra
.36119 .49386 .36969 .5021 .38357 .49765 .37511 .48936 Mtetra
.37511 .48936 .38357 .49765 .39752 .49317 .38911 .48484 Mtetra
.38911 .48484 .39752 .49317 .41154 .48867 .40318 .4803 Mtetra
.40318 .4803 .41154 .48867 .42564 .48415 .41732 .47573 Mtetra
.41732 .47573 .42564 .48415 .43981 .4796 .43154 .47114 Mtetra
.43154 .47114 .43981 .4796 .45405 .47502 .44583 .46652 Mtetra
.44583 .46652 .45405 .47502 .46837 .47043 .4602 .46188 Mtetra
.4602 .46188 .46837 .47043 .48277 .46581 .47464 .45721 Mtetra
.47464 .45721 .48277 .46581 .49724 .46116 .48916 .45252 Mtetra
.48916 .45252 .49724 .46116 .51179 .45649 .50376 .4478 Mtetra
.50376 .4478 .51179 .45649 .52641 .4518 .51844 .44306 Mtetra
.51844 .44306 .52641 .4518 .54112 .44708 .5332 .43829 Mtetra
.5332 .43829 .54112 .44708 .5559 .44233 .54803 .4335 Mtetra
.54803 .4335 .5559 .44233 .57077 .43756 .56295 .42868 Mtetra
.56295 .42868 .57077 .43756 .58571 .43276 .57795 .42384 Mtetra
.57795 .42384 .58571 .43276 .60073 .42794 .59302 .41897 Mtetra
.59302 .41897 .60073 .42794 .61584 .42309 .60818 .41407 Mtetra
.60818 .41407 .61584 .42309 .63103 .41822 .62343 .40915 Mtetra
.62343 .40915 .63103 .41822 .6463 .41331 .63875 .40419 Mtetra
.63875 .40419 .6463 .41331 .66165 .40839 .65416 .39922 Mtetra
.65416 .39922 .66165 .40839 .67709 .40343 .66966 .39421 Mtetra
.66966 .39421 .67709 .40343 .69261 .39845 .68524 .38918 Mtetra
.68524 .38918 .69261 .39845 .70822 .39344 .70091 .38411 Mtetra
.70091 .38411 .70822 .39344 .72391 .3884 .71666 .37903 Mtetra
.71666 .37903 .72391 .3884 .73969 .38333 .7325 .37391 Mtetra
.7325 .37391 .73969 .38333 .75556 .37824 .74843 .36876 Mtetra
.74843 .36876 .75556 .37824 .77152 .37312 .76445 .36359 Mtetra
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Mtetra
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Mtetra
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Mtetra
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Mtetra
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Mtetra
.35261 .48554 .36119 .49386 .37511 .48936 .36658 .481 Mtetra
.36658 .481 .37511 .48936 .38911 .48484 .38062 .47643 Mtetra
.38062 .47643 .38911 .48484 .40318 .4803 .39473 .47184 Mtetra
.39473 .47184 .40318 .4803 .41732 .47573 .40892 .46723 Mtetra
.40892 .46723 .41732 .47573 .43154 .47114 .42319 .46259 Mtetra
.42319 .46259 .43154 .47114 .44583 .46652 .43753 .45793 Mtetra
.43753 .45793 .44583 .46652 .4602 .46188 .45194 .45324 Mtetra
.45194 .45324 .4602 .46188 .47464 .45721 .46644 .44853 Mtetra
.46644 .44853 .47464 .45721 .48916 .45252 .48101 .44379 Mtetra
.48101 .44379 .48916 .45252 .50376 .4478 .49566 .43903 Mtetra
.49566 .43903 .50376 .4478 .51844 .44306 .51039 .43424 Mtetra
.51039 .43424 .51844 .44306 .5332 .43829 .5252 .42943 Mtetra
.5252 .42943 .5332 .43829 .54803 .4335 .54008 .42459 Mtetra
.54008 .42459 .54803 .4335 .56295 .42868 .55505 .41972 Mtetra
.55505 .41972 .56295 .42868 .57795 .42384 .5701 .41483 Mtetra
.5701 .41483 .57795 .42384 .59302 .41897 .58524 .4099 Mtetra
.58524 .4099 .59302 .41897 .60818 .41407 .60045 .40496 Mtetra
.60045 .40496 .60818 .41407 .62343 .40915 .61575 .39998 Mtetra
.61575 .39998 .62343 .40915 .63875 .40419 .63113 .39498 Mtetra
.63113 .39498 .63875 .40419 .65416 .39922 .6466 .38995 Mtetra
.6466 .38995 .65416 .39922 .66966 .39421 .66216 .3849 Mtetra
.66216 .3849 .66966 .39421 .68524 .38918 .6778 .37981 Mtetra
.6778 .37981 .68524 .38918 .70091 .38411 .69352 .3747 Mtetra
.69352 .3747 .70091 .38411 .71666 .37903 .70934 .36956 Mtetra
.70934 .36956 .71666 .37903 .7325 .37391 .72524 .36438 Mtetra
.72524 .36438 .7325 .37391 .74843 .36876 .74123 .35918 Mtetra
.74123 .35918 .74843 .36876 .76445 .36359 .75732 .35396 Mtetra
.75732 .35396 .76445 .36359 .78056 .35838 .77349 .3487 Mtetra
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Mtetra
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Mtetra
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Mtetra
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Mtetra
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47255 Mtetra
.35796 .47255 .36658 .481 .38062 .47643 .37205 .46794 Mtetra
.37205 .46794 .38062 .47643 .39473 .47184 .38621 .46331 Mtetra
.38621 .46331 .39473 .47184 .40892 .46723 .40044 .45865 Mtetra
.40044 .45865 .40892 .46723 .42319 .46259 .41476 .45397 Mtetra
.41476 .45397 .42319 .46259 .43753 .45793 .42914 .44926 Mtetra
.42914 .44926 .43753 .45793 .45194 .45324 .44361 .44452 Mtetra
.44361 .44452 .45194 .45324 .46644 .44853 .45815 .43976 Mtetra
.45815 .43976 .46644 .44853 .48101 .44379 .47277 .43498 Mtetra
.47277 .43498 .48101 .44379 .49566 .43903 .48747 .43017 Mtetra
.48747 .43017 .49566 .43903 .51039 .43424 .50225 .42533 Mtetra
.50225 .42533 .51039 .43424 .5252 .42943 .51712 .42047 Mtetra
.51712 .42047 .5252 .42943 .54008 .42459 .53206 .41558 Mtetra
.53206 .41558 .54008 .42459 .55505 .41972 .54708 .41066 Mtetra
.54708 .41066 .55505 .41972 .5701 .41483 .56218 .40572 Mtetra
.56218 .40572 .5701 .41483 .58524 .4099 .57737 .40075 Mtetra
.57737 .40075 .58524 .4099 .60045 .40496 .59264 .39575 Mtetra
.59264 .39575 .60045 .40496 .61575 .39998 .608 .39073 Mtetra
.608 .39073 .61575 .39998 .63113 .39498 .62344 .38568 Mtetra
.62344 .38568 .63113 .39498 .6466 .38995 .63896 .3806 Mtetra
.63896 .3806 .6466 .38995 .66216 .3849 .65458 .37549 Mtetra
.65458 .37549 .66216 .3849 .6778 .37981 .67028 .37035 Mtetra
.67028 .37035 .6778 .37981 .69352 .3747 .68606 .36518 Mtetra
.68606 .36518 .69352 .3747 .70934 .36956 .70194 .35999 Mtetra
.70194 .35999 .70934 .36956 .72524 .36438 .7179 .35476 Mtetra
.7179 .35476 .72524 .36438 .74123 .35918 .73396 .34951 Mtetra
.73396 .34951 .74123 .35918 .75732 .35396 .75011 .34422 Mtetra
.75011 .34422 .75732 .35396 .77349 .3487 .76634 .33891 Mtetra
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Mtetra
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Mtetra
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Mtetra
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46865 Mtetra
.3352 .46865 .34395 .47714 .35796 .47255 .34926 .46402 Mtetra
.34926 .46402 .35796 .47255 .37205 .46794 .36339 .45937 Mtetra
.36339 .45937 .37205 .46794 .38621 .46331 .3776 .45469 Mtetra
.3776 .45469 .38621 .46331 .40044 .45865 .39188 .44998 Mtetra
.39188 .44998 .40044 .45865 .41476 .45397 .40624 .44525 Mtetra
.40624 .44525 .41476 .45397 .42914 .44926 .42068 .4405 Mtetra
.42068 .4405 .42914 .44926 .44361 .44452 .43519 .43572 Mtetra
.43519 .43572 .44361 .44452 .45815 .43976 .44978 .43091 Mtetra
.44978 .43091 .45815 .43976 .47277 .43498 .46446 .42608 Mtetra
.46446 .42608 .47277 .43498 .48747 .43017 .47921 .42122 Mtetra
.47921 .42122 .48747 .43017 .50225 .42533 .49404 .41633 Mtetra
.49404 .41633 .50225 .42533 .51712 .42047 .50895 .41142 Mtetra
.50895 .41142 .51712 .42047 .53206 .41558 .52395 .40648 Mtetra
.52395 .40648 .53206 .41558 .54708 .41066 .53902 .40152 Mtetra
.53902 .40152 .54708 .41066 .56218 .40572 .55418 .39653 Mtetra
.55418 .39653 .56218 .40572 .57737 .40075 .56943 .39151 Mtetra
.663 .741 .908 r
.56943 .39151 .57737 .40075 .59264 .39575 .58475 .38646 Mtetra
.58475 .38646 .59264 .39575 .608 .39073 .60017 .38139 Mtetra
.664 .741 .908 r
.60017 .38139 .608 .39073 .62344 .38568 .61566 .37628 Mtetra
.61566 .37628 .62344 .38568 .63896 .3806 .63125 .37115 Mtetra
.63125 .37115 .63896 .3806 .65458 .37549 .64692 .36599 Mtetra
.64692 .36599 .65458 .37549 .67028 .37035 .66268 .3608 Mtetra
.66268 .3608 .67028 .37035 .68606 .36518 .67853 .35558 Mtetra
.67853 .35558 .68606 .36518 .70194 .35999 .69446 .35032 Mtetra
.69446 .35032 .70194 .35999 .7179 .35476 .71049 .34504 Mtetra
.71049 .34504 .7179 .35476 .73396 .34951 .72661 .33973 Mtetra
.72661 .33973 .73396 .34951 .75011 .34422 .74282 .33439 Mtetra
.74282 .33439 .75011 .34422 .76634 .33891 .75912 .32902 Mtetra
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Mtetra
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46936 Mtetra
.29838 .46936 .3073 .47784 .32121 .47326 .31234 .46474 Mtetra
.31234 .46474 .32121 .47326 .3352 .46865 .32636 .46009 Mtetra
.32636 .46009 .3352 .46865 .34926 .46402 .34047 .45541 Mtetra
.34047 .45541 .34926 .46402 .36339 .45937 .35465 .45071 Mtetra
.35465 .45071 .36339 .45937 .3776 .45469 .3689 .44598 Mtetra
.3689 .44598 .3776 .45469 .39188 .44998 .38323 .44123 Mtetra
.38323 .44123 .39188 .44998 .40624 .44525 .39764 .43645 Mtetra
.39764 .43645 .40624 .44525 .42068 .4405 .41213 .43165 Mtetra
.41213 .43165 .42068 .4405 .43519 .43572 .42669 .42682 Mtetra
.42669 .42682 .43519 .43572 .44978 .43091 .44133 .42197 Mtetra
.44133 .42197 .44978 .43091 .46446 .42608 .45606 .41709 Mtetra
.45606 .41709 .46446 .42608 .47921 .42122 .47086 .41218 Mtetra
.47086 .41218 .47921 .42122 .49404 .41633 .48574 .40725 Mtetra
.48574 .40725 .49404 .41633 .50895 .41142 .50071 .40228 Mtetra
.663 .741 .908 r
.50071 .40228 .50895 .41142 .52395 .40648 .51576 .3973 Mtetra
.51576 .3973 .52395 .40648 .53902 .40152 .53089 .39229 Mtetra
.53089 .39229 .53902 .40152 .55418 .39653 .5461 .38725 Mtetra
.663 .742 .908 r
.5461 .38725 .55418 .39653 .56943 .39151 .5614 .38218 Mtetra
.5614 .38218 .56943 .39151 .58475 .38646 .57678 .37709 Mtetra
.57678 .37709 .58475 .38646 .60017 .38139 .59225 .37197 Mtetra
.59225 .37197 .60017 .38139 .61566 .37628 .60781 .36682 Mtetra
.664 .742 .908 r
.60781 .36682 .61566 .37628 .63125 .37115 .62345 .36163 Mtetra
.62345 .36163 .63125 .37115 .64692 .36599 .63918 .35641 Mtetra
.63918 .35641 .64692 .36599 .66268 .3608 .655 .35116 Mtetra
.655 .35116 .66268 .3608 .67853 .35558 .67091 .34588 Mtetra
.67091 .34588 .67853 .35558 .69446 .35032 .68691 .34057 Mtetra
.68691 .34057 .69446 .35032 .71049 .34504 .703 .33522 Mtetra
.664 .741 .908 r
.703 .33522 .71049 .34504 .72661 .33973 .71918 .32986 Mtetra
.71918 .32986 .72661 .33973 .74282 .33439 .73545 .32446 Mtetra
.73545 .32446 .74282 .33439 .75912 .32902 .75182 .31903 Mtetra
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Mtetra
.27545 .46545 .2845 .47397 .29838 .46936 .28937 .4608 Mtetra
.28937 .4608 .29838 .46936 .31234 .46474 .30337 .45613 Mtetra
.30337 .45613 .31234 .46474 .32636 .46009 .31744 .45143 Mtetra
.31744 .45143 .32636 .46009 .34047 .45541 .33159 .44671 Mtetra
.33159 .44671 .34047 .45541 .35465 .45071 .34582 .44196 Mtetra
.34582 .44196 .35465 .45071 .3689 .44598 .36012 .43719 Mtetra
.36012 .43719 .3689 .44598 .38323 .44123 .3745 .43239 Mtetra
.3745 .43239 .38323 .44123 .39764 .43645 .38896 .42757 Mtetra
.38896 .42757 .39764 .43645 .41213 .43165 .40349 .42272 Mtetra
.40349 .42272 .41213 .43165 .42669 .42682 .4181 .41784 Mtetra
.4181 .41784 .42669 .42682 .44133 .42197 .4328 .41294 Mtetra
.4328 .41294 .44133 .42197 .45606 .41709 .44757 .40801 Mtetra
.663 .741 .908 r
.44757 .40801 .45606 .41709 .47086 .41218 .46242 .40305 Mtetra
.46242 .40305 .47086 .41218 .48574 .40725 .47736 .39807 Mtetra
.47736 .39807 .48574 .40725 .50071 .40228 .49238 .39307 Mtetra
.663 .742 .908 r
.49238 .39307 .50071 .40228 .51576 .3973 .50748 .38804 Mtetra
.663 .742 .909 r
.50748 .38804 .51576 .3973 .53089 .39229 .52267 .383 Mtetra
.52267 .383 .53089 .39229 .5461 .38725 .53794 .37793 Mtetra
.663 .743 .909 r
.53794 .37793 .5461 .38725 .5614 .38218 .55329 .37283 Mtetra
.663 .743 .91 r
.55329 .37283 .5614 .38218 .57678 .37709 .56873 .3677 Mtetra
.663 .744 .91 r
.56873 .3677 .57678 .37709 .59225 .37197 .58426 .36254 Mtetra
.664 .744 .91 r
.58426 .36254 .59225 .37197 .60781 .36682 .59987 .35733 Mtetra
.59987 .35733 .60781 .36682 .62345 .36163 .61558 .35208 Mtetra
.664 .744 .909 r
.61558 .35208 .62345 .36163 .63918 .35641 .63137 .34678 Mtetra
.664 .743 .909 r
.63137 .34678 .63918 .35641 .655 .35116 .64725 .34146 Mtetra
.64725 .34146 .655 .35116 .67091 .34588 .66321 .3361 Mtetra
.664 .742 .908 r
.66321 .3361 .67091 .34588 .68691 .34057 .67928 .33071 Mtetra
.67928 .33071 .68691 .34057 .703 .33522 .69543 .32531 Mtetra
.69543 .32531 .703 .33522 .71918 .32986 .71167 .31987 Mtetra
.664 .741 .908 r
.71167 .31987 .71918 .32986 .73545 .32446 .72801 .31442 Mtetra
.72801 .31442 .73545 .32446 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Mtetra
.2663 .45685 .27545 .46545 .28937 .4608 .28027 .45216 Mtetra
.28027 .45216 .28937 .4608 .30337 .45613 .29432 .44744 Mtetra
.29432 .44744 .30337 .45613 .31744 .45143 .30844 .4427 Mtetra
.30844 .4427 .31744 .45143 .33159 .44671 .32263 .43793 Mtetra
.32263 .43793 .33159 .44671 .34582 .44196 .3369 .43313 Mtetra
.3369 .43313 .34582 .44196 .36012 .43719 .35125 .42831 Mtetra
.35125 .42831 .36012 .43719 .3745 .43239 .36568 .42346 Mtetra
.36568 .42346 .3745 .43239 .38896 .42757 .38018 .41859 Mtetra
.38018 .41859 .38896 .42757 .40349 .42272 .39477 .41369 Mtetra
.39477 .41369 .40349 .42272 .4181 .41784 .40943 .40877 Mtetra
.663 .741 .908 r
.40943 .40877 .4181 .41784 .4328 .41294 .42417 .40382 Mtetra
.42417 .40382 .4328 .41294 .44757 .40801 .439 .39884 Mtetra
.439 .39884 .44757 .40801 .46242 .40305 .4539 .39385 Mtetra
.663 .742 .909 r
.4539 .39385 .46242 .40305 .47736 .39807 .46889 .38884 Mtetra
.662 .742 .909 r
.46889 .38884 .47736 .39807 .49238 .39307 .48396 .38383 Mtetra
.662 .743 .91 r
.48396 .38383 .49238 .39307 .50748 .38804 .49912 .3788 Mtetra
.661 .744 .911 r
.49912 .3788 .50748 .38804 .52267 .383 .51436 .37376 Mtetra
.661 .745 .912 r
.51436 .37376 .52267 .383 .53794 .37793 .52969 .3687 Mtetra
.662 .747 .913 r
.52969 .3687 .53794 .37793 .55329 .37283 .5451 .36361 Mtetra
.662 .748 .914 r
.5451 .36361 .55329 .37283 .56873 .3677 .5606 .35845 Mtetra
.663 .749 .914 r
.5606 .35845 .56873 .3677 .58426 .36254 .57619 .35322 Mtetra
.665 .749 .913 r
.57619 .35322 .58426 .36254 .59987 .35733 .59186 .34792 Mtetra
.665 .749 .912 r
.59186 .34792 .59987 .35733 .61558 .35208 .60762 .34255 Mtetra
.666 .747 .911 r
.60762 .34255 .61558 .35208 .63137 .34678 .62347 .33714 Mtetra
.666 .746 .91 r
.62347 .33714 .63137 .34678 .64725 .34146 .63941 .33169 Mtetra
.665 .744 .909 r
.63941 .33169 .64725 .34146 .66321 .3361 .65544 .32624 Mtetra
.665 .743 .908 r
.65544 .32624 .66321 .3361 .67928 .33071 .67156 .32077 Mtetra
.664 .742 .908 r
.67156 .32077 .67928 .33071 .69543 .32531 .68778 .31529 Mtetra
.68778 .31529 .69543 .32531 .71167 .31987 .70409 .30979 Mtetra
.664 .741 .908 r
.70409 .30979 .71167 .31987 .72801 .31442 .72049 .30427 Mtetra
.72049 .30427 .72801 .31442 .74444 .30893 .73699 .29872 Mtetra
.73699 .29872 .74444 .30893 .76097 .30341 .75358 .29314 Mtetra
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28753 Mtetra
.77027 .28753 .7776 .29786 .79432 .29228 .78706 .28189 Mtetra
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Mtetra
.25707 .44817 .2663 .45685 .28027 .45216 .27108 .44343 Mtetra
.27108 .44343 .28027 .45216 .29432 .44744 .28517 .43866 Mtetra
.28517 .43866 .29432 .44744 .30844 .4427 .29934 .43387 Mtetra
.29934 .43387 .30844 .4427 .32263 .43793 .31358 .42905 Mtetra
.31358 .42905 .32263 .43793 .3369 .43313 .3279 .42421 Mtetra
.3279 .42421 .3369 .43313 .35125 .42831 .34229 .41934 Mtetra
.34229 .41934 .35125 .42831 .36568 .42346 .35677 .41445 Mtetra
.35677 .41445 .36568 .42346 .38018 .41859 .37132 .40953 Mtetra
.663 .741 .908 r
.37132 .40953 .38018 .41859 .39477 .41369 .38595 .40458 Mtetra
.38595 .40458 .39477 .41369 .40943 .40877 .40067 .39961 Mtetra
.40067 .39961 .40943 .40877 .42417 .40382 .41546 .39463 Mtetra
.662 .742 .909 r
.41546 .39463 .42417 .40382 .439 .39884 .43034 .38964 Mtetra
.662 .742 .91 r
.43034 .38964 .439 .39884 .4539 .39385 .44529 .38467 Mtetra
.66 .743 .912 r
.44529 .38467 .4539 .39385 .46889 .38884 .46033 .37971 Mtetra
.659 .745 .914 r
.46033 .37971 .46889 .38884 .48396 .38383 .47546 .37478 Mtetra
.657 .748 .917 r
.47546 .37478 .48396 .38383 .49912 .3788 .49067 .36988 Mtetra
.657 .752 .92 r
.49067 .36988 .49912 .3788 .51436 .37376 .50596 .36496 Mtetra
.657 .756 .923 r
.50596 .36496 .51436 .37376 .52969 .3687 .52135 .35999 Mtetra
.66 .76 .924 r
.52135 .35999 .52969 .3687 .5451 .36361 .53682 .3549 Mtetra
.663 .763 .924 r
.53682 .3549 .5451 .36361 .5606 .35845 .55238 .34966 Mtetra
.666 .763 .923 r
.55238 .34966 .5606 .35845 .57619 .35322 .56803 .34426 Mtetra
.669 .761 .92 r
.56803 .34426 .57619 .35322 .59186 .34792 .58377 .33873 Mtetra
.67 .758 .916 r
.58377 .33873 .59186 .34792 .60762 .34255 .59959 .33312 Mtetra
.67 .753 .913 r
.59959 .33312 .60762 .34255 .62347 .33714 .61549 .32749 Mtetra
.669 .749 .911 r
.61549 .32749 .62347 .33714 .63941 .33169 .63149 .32188 Mtetra
.667 .746 .909 r
.63149 .32188 .63941 .33169 .65544 .32624 .64758 .31628 Mtetra
.666 .744 .908 r
.64758 .31628 .65544 .32624 .67156 .32077 .66377 .31072 Mtetra
.665 .742 .908 r
.66377 .31072 .67156 .32077 .68778 .31529 .68004 .30516 Mtetra
.664 .742 .908 r
.68004 .30516 .68778 .31529 .70409 .30979 .69642 .29959 Mtetra
.664 .741 .908 r
.69642 .29959 .70409 .30979 .72049 .30427 .71289 .29401 Mtetra
.71289 .29401 .72049 .30427 .73699 .29872 .72945 .2884 Mtetra
.72945 .2884 .73699 .29872 .75358 .29314 .74611 .28276 Mtetra
.74611 .28276 .75358 .29314 .77027 .28753 .76287 .2771 Mtetra
.76287 .2771 .77027 .28753 .78706 .28189 .77973 .27139 Mtetra
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.23376 .44416 .24313 .45288 .25707 .44817 .24775 .4394 Mtetra
.24775 .4394 .25707 .44817 .27108 .44343 .2618 .43461 Mtetra
.2618 .43461 .27108 .44343 .28517 .43866 .27594 .4298 Mtetra
.27594 .4298 .28517 .43866 .29934 .43387 .29015 .42496 Mtetra
.29015 .42496 .29934 .43387 .31358 .42905 .30444 .42009 Mtetra
.30444 .42009 .31358 .42905 .3279 .42421 .3188 .4152 Mtetra
.3188 .4152 .3279 .42421 .34229 .41934 .33325 .41029 Mtetra
.663 .741 .908 r
.33325 .41029 .34229 .41934 .35677 .41445 .34777 .40534 Mtetra
.34777 .40534 .35677 .41445 .37132 .40953 .36237 .40038 Mtetra
.36237 .40038 .37132 .40953 .38595 .40458 .37705 .39541 Mtetra
.662 .742 .909 r
.37705 .39541 .38595 .40458 .40067 .39961 .39181 .39044 Mtetra
.661 .742 .91 r
.39181 .39044 .40067 .39961 .41546 .39463 .40666 .3855 Mtetra
.658 .744 .913 r
.40666 .3855 .41546 .39463 .43034 .38964 .42158 .38062 Mtetra
.655 .746 .917 r
.42158 .38062 .43034 .38964 .44529 .38467 .43658 .37585 Mtetra
.65 .751 .924 r
.43658 .37585 .44529 .38467 .46033 .37971 .45167 .37121 Mtetra
.646 .759 .931 r
.45167 .37121 .46033 .37971 .47546 .37478 .46684 .36666 Mtetra
.643 .769 .939 r
.46684 .36666 .47546 .37478 .49067 .36988 .48211 .36213 Mtetra
.644 .78 .946 r
.48211 .36213 .49067 .36988 .50596 .36496 .49746 .35749 Mtetra
.65 .79 .949 r
.49746 .35749 .50596 .36496 .52135 .35999 .51291 .35259 Mtetra
.659 .796 .948 r
.51291 .35259 .52135 .35999 .53682 .3549 .52846 .34735 Mtetra
.669 .797 .943 r
.52846 .34735 .53682 .3549 .55238 .34966 .54408 .34175 Mtetra
.677 .791 .935 r
.54408 .34175 .55238 .34966 .56803 .34426 .5598 .33586 Mtetra
.68 .781 .926 r
.5598 .33586 .56803 .34426 .58377 .33873 .57559 .32982 Mtetra
.68 .77 .919 r
.57559 .32982 .58377 .33873 .59959 .33312 .59147 .32377 Mtetra
.677 .76 .914 r
.59147 .32377 .59959 .33312 .61549 .32749 .60743 .3178 Mtetra
.673 .752 .91 r
.60743 .3178 .61549 .32749 .63149 .32188 .62349 .31195 Mtetra
.669 .747 .908 r
.62349 .31195 .63149 .32188 .64758 .31628 .63964 .30621 Mtetra
.667 .744 .908 r
.63964 .30621 .64758 .31628 .66377 .31072 .65589 .30054 Mtetra
.665 .742 .908 r
.65589 .30054 .66377 .31072 .68004 .30516 .67223 .29491 Mtetra
.664 .742 .908 r
.67223 .29491 .68004 .30516 .69642 .29959 .68867 .28928 Mtetra
.664 .741 .908 r
.68867 .28928 .69642 .29959 .71289 .29401 .7052 .28364 Mtetra
.7052 .28364 .71289 .29401 .72945 .2884 .72183 .27797 Mtetra
.72183 .27797 .72945 .2884 .74611 .28276 .73856 .27227 Mtetra
.73856 .27227 .74611 .28276 .76287 .2771 .75539 .26654 Mtetra
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.2243 .43535 .23376 .44416 .24775 .4394 .23833 .43054 Mtetra
.23833 .43054 .24775 .4394 .2618 .43461 .25243 .4257 Mtetra
.25243 .4257 .2618 .43461 .27594 .4298 .26661 .42084 Mtetra
.26661 .42084 .27594 .4298 .29015 .42496 .28087 .41596 Mtetra
.28087 .41596 .29015 .42496 .30444 .42009 .2952 .41104 Mtetra
.663 .741 .908 r
.2952 .41104 .30444 .42009 .3188 .4152 .30961 .40611 Mtetra
.30961 .40611 .3188 .4152 .33325 .41029 .3241 .40115 Mtetra
.3241 .40115 .33325 .41029 .34777 .40534 .33867 .39617 Mtetra
.662 .742 .909 r
.33867 .39617 .34777 .40534 .36237 .40038 .35332 .39121 Mtetra
.66 .742 .911 r
.35332 .39121 .36237 .40038 .37705 .39541 .36805 .38629 Mtetra
.656 .744 .914 r
.36805 .38629 .37705 .39541 .39181 .39044 .38285 .38149 Mtetra
.65 .747 .92 r
.38285 .38149 .39181 .39044 .40666 .3855 .39773 .37688 Mtetra
.64 .753 .93 r
.39773 .37688 .40666 .3855 .42158 .38062 .41269 .37255 Mtetra
.627 .764 .944 r
.41269 .37255 .42158 .38062 .43658 .37585 .42773 .36855 Mtetra
.612 .78 .962 r
.42773 .36855 .43658 .37585 .45167 .37121 .44285 .36482 Mtetra
.597 .802 .978 r
.44285 .36482 .45167 .37121 .46684 .36666 .45807 .36117 Mtetra
.592 .826 .989 r
.45807 .36117 .46684 .36666 .48211 .36213 .4734 .35728 Mtetra
.603 .849 .991 r
.4734 .35728 .48211 .36213 .49746 .35749 .48883 .35284 Mtetra
.631 .865 .986 r
.48883 .35284 .49746 .35749 .51291 .35259 .50436 .34761 Mtetra
.665 .866 .976 r
.50436 .34761 .51291 .35259 .52846 .34735 .51999 .34158 Mtetra
.691 .852 .96 r
.51999 .34158 .52846 .34735 .54408 .34175 .53569 .33493 Mtetra
.702 .828 .943 r
.53569 .33493 .54408 .34175 .5598 .33586 .55147 .32797 Mtetra
.701 .802 .927 r
.55147 .32797 .5598 .33586 .57559 .32982 .56732 .32104 Mtetra
.694 .779 .917 r
.56732 .32104 .57559 .32982 .59147 .32377 .58326 .31433 Mtetra
.685 .763 .91 r
.58326 .31433 .59147 .32377 .60743 .3178 .59928 .30795 Mtetra
.677 .752 .908 r
.59928 .30795 .60743 .3178 .62349 .31195 .6154 .30186 Mtetra
.671 .746 .907 r
.6154 .30186 .62349 .31195 .63964 .30621 .63161 .29599 Mtetra
.667 .743 .907 r
.63161 .29599 .63964 .30621 .65589 .30054 .64792 .29024 Mtetra
.665 .742 .907 r
.64792 .29024 .65589 .30054 .67223 .29491 .66433 .28455 Mtetra
.664 .741 .908 r
.66433 .28455 .67223 .29491 .68867 .28928 .68083 .27886 Mtetra
.68083 .27886 .68867 .28928 .7052 .28364 .69743 .27316 Mtetra
.69743 .27316 .7052 .28364 .72183 .27797 .71413 .26743 Mtetra
.71413 .26743 .72183 .27797 .73856 .27227 .73093 .26167 Mtetra
.73093 .26167 .73856 .27227 .75539 .26654 .74783 .25587 Mtetra
.74783 .25587 .75539 .26654 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24418 Mtetra
.78193 .24418 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.21474 .42645 .2243 .43535 .23833 .43054 .22882 .42159 Mtetra
.22882 .42159 .23833 .43054 .25243 .4257 .24296 .41671 Mtetra
.24296 .41671 .25243 .4257 .26661 .42084 .25719 .4118 Mtetra
.25719 .4118 .26661 .42084 .28087 .41596 .27149 .40687 Mtetra
.663 .741 .908 r
.27149 .40687 .28087 .41596 .2952 .41104 .28587 .40191 Mtetra
.28587 .40191 .2952 .41104 .30961 .40611 .30033 .39693 Mtetra
.662 .741 .909 r
.30033 .39693 .30961 .40611 .3241 .40115 .31487 .39197 Mtetra
.66 .742 .91 r
.31487 .39197 .3241 .40115 .33867 .39617 .32948 .38705 Mtetra
.656 .743 .914 r
.32948 .38705 .33867 .39617 .35332 .39121 .34417 .38226 Mtetra
.648 .746 .921 r
.34417 .38226 .35332 .39121 .36805 .38629 .35892 .37774 Mtetra
.632 .752 .934 r
.35892 .37774 .36805 .38629 .38285 .38149 .37374 .37368 Mtetra
.606 .764 .955 r
.37374 .37368 .38285 .38149 .39773 .37688 .38863 .37025 Mtetra
.561 .782 .982 r
.38863 .37025 .39773 .37688 .41269 .37255 .40358 .36755 Mtetra
.489 .801 1 r
.40358 .36755 .41269 .37255 .42773 .36855 .41862 .36545 Mtetra
.392 .804 .978 r
.41862 .36545 .42773 .36855 .44285 .36482 .43378 .36354 Mtetra
.314 .793 .912 r
.43378 .36354 .44285 .36482 .45807 .36117 .44906 .36117 Mtetra
.319 .806 .864 r
.44906 .36117 .45807 .36117 .4734 .35728 .46447 .35762 Mtetra
.423 .868 .881 r
.46447 .35762 .4734 .35728 .48883 .35284 .48002 .35244 Mtetra
.576 .934 .933 r
.48002 .35244 .48883 .35284 .50436 .34761 .49567 .34557 Mtetra
.692 .945 .96 r
.49567 .34557 .50436 .34761 .51999 .34158 .5114 .33742 Mtetra
.739 .905 .951 r
.5114 .33742 .51999 .34158 .53569 .33493 .52719 .32868 Mtetra
.742 .853 .931 r
.52719 .32868 .53569 .33493 .55147 .32797 .54305 .32003 Mtetra
.727 .809 .915 r
.54305 .32003 .55147 .32797 .56732 .32104 .55896 .31192 Mtetra
.708 .778 .907 r
.55896 .31192 .56732 .32104 .58326 .31433 .57496 .30453 Mtetra
.691 .759 .903 r
.57496 .30453 .58326 .31433 .59928 .30795 .59104 .2978 Mtetra
.679 .749 .904 r
.59104 .2978 .59928 .30795 .6154 .30186 .60722 .29156 Mtetra
.671 .744 .905 r
.60722 .29156 .6154 .30186 .63161 .29599 .62349 .28561 Mtetra
.667 .742 .906 r
.62349 .28561 .63161 .29599 .64792 .29024 .63987 .27981 Mtetra
.665 .741 .907 r
.63987 .27981 .64792 .29024 .66433 .28455 .65634 .27406 Mtetra
.664 .741 .908 r
.65634 .27406 .66433 .28455 .68083 .27886 .67291 .26832 Mtetra
.67291 .26832 .68083 .27886 .69743 .27316 .68958 .26256 Mtetra
.68958 .26256 .69743 .27316 .71413 .26743 .70635 .25677 Mtetra
.70635 .25677 .71413 .26743 .73093 .26167 .72322 .25095 Mtetra
.72322 .25095 .73093 .26167 .74783 .25587 .74019 .24509 Mtetra
.74019 .24509 .74783 .25587 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24418 .77443 .23327 Mtetra
.77443 .23327 .78193 .24418 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.20509 .41746 .21474 .42645 .22882 .42159 .21921 .41256 Mtetra
.21921 .41256 .22882 .42159 .24296 .41671 .2334 .40763 Mtetra
.663 .741 .908 r
.2334 .40763 .24296 .41671 .25719 .4118 .24767 .40267 Mtetra
.24767 .40267 .25719 .4118 .27149 .40687 .26202 .39769 Mtetra
.663 .741 .909 r
.26202 .39769 .27149 .40687 .28587 .40191 .27645 .39271 Mtetra
.661 .742 .91 r
.27645 .39271 .28587 .40191 .30033 .39693 .29095 .38777 Mtetra
.657 .742 .913 r
.29095 .38777 .30033 .39693 .31487 .39197 .30552 .38295 Mtetra
.648 .744 .92 r
.30552 .38295 .31487 .39197 .32948 .38705 .32015 .37841 Mtetra
.63 .749 .933 r
.32015 .37841 .32948 .38705 .34417 .38226 .33484 .37442 Mtetra
.593 .759 .958 r
.33484 .37442 .34417 .38226 .35892 .37774 .34957 .37134 Mtetra
.512 .77 .99 r
.34957 .37134 .35892 .37774 .37374 .37368 .36434 .36952 Mtetra
.33 .747 .978 r
.36434 .36952 .37374 .37368 .38863 .37025 .37915 .36912 Mtetra
.01 .582 .763 r
.37915 .36912 .38863 .37025 .40358 .36755 .39405 .36991 Mtetra
.243 0 0 r
.39405 .36991 .40358 .36755 .41862 .36545 .40907 .37108 Mtetra
.314 0 0 r
.40907 .37108 .41862 .36545 .43378 .36354 .42427 .37136 Mtetra
.262 0 0 r
.42427 .37136 .43378 .36354 .44906 .36117 .43967 .3694 Mtetra
.101 0 0 r
.43967 .3694 .44906 .36117 .46447 .35762 .45526 .36427 Mtetra
0 0 0 r
.45526 .36427 .46447 .35762 .48002 .35244 .47099 .35591 Mtetra
.583 .936 .774 r
.47099 .35591 .48002 .35244 .49567 .34557 .48682 .34513 Mtetra
.78 .982 .905 r
.48682 .34513 .49567 .34557 .5114 .33742 .50269 .33327 Mtetra
.804 .91 .912 r
.50269 .33327 .5114 .33742 .52719 .32868 .51859 .32163 Mtetra
.777 .839 .899 r
.51859 .32163 .52719 .32868 .54305 .32003 .53452 .3111 Mtetra
.743 .792 .892 r
.53452 .3111 .54305 .32003 .55896 .31192 .5505 .30199 Mtetra
.713 .764 .892 r
.5505 .30199 .55896 .31192 .57496 .30453 .56656 .29417 Mtetra
.692 .749 .896 r
.56656 .29417 .57496 .30453 .59104 .2978 .5827 .28731 Mtetra
.678 .743 .9 r
.5827 .28731 .59104 .2978 .60722 .29156 .59895 .28104 Mtetra
.67 .741 .904 r
.59895 .28104 .60722 .29156 .62349 .28561 .61529 .27508 Mtetra
.666 .741 .906 r
.61529 .27508 .62349 .28561 .63987 .27981 .63173 .26925 Mtetra
.664 .741 .907 r
.63173 .26925 .63987 .27981 .65634 .27406 .64827 .26346 Mtetra
.664 .741 .908 r
.64827 .26346 .65634 .27406 .67291 .26832 .66491 .25767 Mtetra
.66491 .25767 .67291 .26832 .68958 .26256 .68164 .25185 Mtetra
.68164 .25185 .68958 .26256 .70635 .25677 .69848 .24599 Mtetra
.69848 .24599 .70635 .25677 .72322 .25095 .71542 .24011 Mtetra
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23418 Mtetra
.73246 .23418 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Mtetra
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .2162 Mtetra
.78419 .2162 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.19534 .40839 .20509 .41746 .21921 .41256 .2095 .40343 Mtetra
.663 .741 .908 r
.2095 .40343 .21921 .41256 .2334 .40763 .22374 .39846 Mtetra
.22374 .39846 .2334 .40763 .24767 .40267 .23806 .39346 Mtetra
.662 .741 .909 r
.23806 .39346 .24767 .40267 .26202 .39769 .25245 .38849 Mtetra
.659 .742 .911 r
.25245 .38849 .26202 .39769 .27645 .39271 .26691 .3836 Mtetra
.652 .743 .916 r
.26691 .3836 .27645 .39271 .29095 .38777 .28143 .37894 Mtetra
.635 .746 .928 r
.28143 .37894 .29095 .38777 .30552 .38295 .296 .3748 Mtetra
.597 .753 .952 r
.296 .3748 .30552 .38295 .32015 .37841 .31059 .37166 Mtetra
.504 .757 .987 r
.31059 .37166 .32015 .37841 .33484 .37442 .32518 .37012 Mtetra
.241 .693 .954 r
.32518 .37012 .33484 .37442 .34957 .37134 .33976 .37081 Mtetra
.254 0 0 r
.33976 .37081 .34957 .37134 .36434 .36952 .35434 .37403 Mtetra
.519 0 0 r
.35434 .37403 .36434 .36952 .37915 .36912 .36898 .37934 Mtetra
.567 .112 .132 r
.36898 .37934 .37915 .36912 .39405 .36991 .38377 .38534 Mtetra
.542 .13 .209 r
.38377 .38534 .39405 .36991 .40907 .37108 .39882 .38979 Mtetra
.474 .081 .214 r
.39882 .38979 .40907 .37108 .42427 .37136 .41418 .39029 Mtetra
.345 0 .149 r
.41418 .39029 .42427 .37136 .43967 .3694 .42986 .3852 Mtetra
.09 0 0 r
.42986 .3852 .43967 .3694 .45526 .36427 .44576 .37445 Mtetra
0 0 0 r
.44576 .37445 .45526 .36427 .47099 .35591 .46179 .35952 Mtetra
.813 .998 .784 r
.46179 .35952 .47099 .35591 .48682 .34513 .47785 .34278 Mtetra
.874 .935 .857 r
.47785 .34278 .48682 .34513 .50269 .33327 .49388 .32653 Mtetra
.832 .847 .858 r
.49388 .32653 .50269 .33327 .51859 .32163 .50988 .31228 Mtetra
.782 .79 .86 r
.50988 .31228 .51859 .32163 .53452 .3111 .52589 .30054 Mtetra
.74 .759 .868 r
.52589 .30054 .53452 .3111 .5505 .30199 .54194 .29108 Mtetra
.708 .744 .88 r
.54194 .29108 .5505 .30199 .56656 .29417 .55806 .28329 Mtetra
.687 .739 .891 r
.55806 .28329 .56656 .29417 .5827 .28731 .57428 .27655 Mtetra
.674 .739 .899 r
.57428 .27655 .5827 .28731 .59895 .28104 .59058 .27037 Mtetra
.668 .74 .904 r
.59058 .27037 .59895 .28104 .61529 .27508 .60699 .26443 Mtetra
.665 .74 .906 r
.60699 .26443 .61529 .27508 .63173 .26925 .6235 .25858 Mtetra
.664 .741 .907 r
.6235 .25858 .63173 .26925 .64827 .26346 .64011 .25275 Mtetra
.664 .741 .908 r
.64011 .25275 .64827 .26346 .66491 .25767 .65681 .2469 Mtetra
.65681 .2469 .66491 .25767 .68164 .25185 .67362 .24101 Mtetra
.67362 .24101 .68164 .25185 .69848 .24599 .69052 .2351 Mtetra
.69052 .2351 .69848 .24599 .71542 .24011 .70753 .22915 Mtetra
.70753 .22915 .71542 .24011 .73246 .23418 .72464 .22316 Mtetra
.72464 .22316 .73246 .23418 .7496 .22823 .74185 .21713 Mtetra
.74185 .21713 .7496 .22823 .76684 .22223 .75917 .21107 Mtetra
.75917 .21107 .76684 .22223 .78419 .2162 .77659 .20498 Mtetra
.77659 .20498 .78419 .2162 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.663 .741 .908 r
.18549 .39922 .19534 .40839 .2095 .40343 .1997 .39422 Mtetra
.1997 .39422 .2095 .40343 .22374 .39846 .21398 .38922 Mtetra
.661 .741 .91 r
.21398 .38922 .22374 .39846 .23806 .39346 .22833 .38426 Mtetra
.656 .742 .913 r
.22833 .38426 .23806 .39346 .25245 .38849 .24275 .37945 Mtetra
.644 .744 .921 r
.24275 .37945 .25245 .38849 .26691 .3836 .25722 .37503 Mtetra
.615 .748 .94 r
.25722 .37503 .26691 .3836 .28143 .37894 .2717 .37145 Mtetra
.539 .751 .974 r
.2717 .37145 .28143 .37894 .296 .3748 .28616 .36947 Mtetra
.303 .703 .977 r
.28616 .36947 .296 .3748 .31059 .37166 .30055 .37007 Mtetra
.278 0 0 r
.30055 .37007 .31059 .37166 .32518 .37012 .31484 .37422 Mtetra
.608 .093 0 r
.31484 .37422 .32518 .37012 .33976 .37081 .32905 .3824 Mtetra
.661 .238 .231 r
.32905 .3824 .33976 .37081 .35434 .37403 .34328 .39394 Mtetra
.648 .273 .32 r
.34328 .39394 .35434 .37403 .36898 .37934 .35769 .40662 Mtetra
.607 .257 .35 r
.35769 .40662 .36898 .37934 .38377 .38534 .37248 .41684 Mtetra
.539 .2 .342 r
.37248 .41684 .38377 .38534 .39882 .38979 .38777 .4207 Mtetra
.42 .085 .289 r
.38777 .4207 .39882 .38979 .41418 .39029 .40358 .4156 Mtetra
.178 0 .136 r
.40358 .4156 .41418 .39029 .42986 .3852 .41977 .40145 Mtetra
0 0 0 r
.41977 .40145 .42986 .3852 .44576 .37445 .43616 .3807 Mtetra
.883 .982 .699 r
.43616 .3807 .44576 .37445 .46179 .35952 .45255 .35723 Mtetra
.923 .904 .787 r
.45255 .35723 .46179 .35952 .47785 .34278 .46884 .33468 Mtetra
.865 .814 .797 r
.46884 .33468 .47785 .34278 .49388 .32653 .485 .3154 Mtetra
.808 .762 .81 r
.485 .3154 .49388 .32653 .50988 .31228 .5011 .30015 Mtetra
.761 .737 .831 r
.5011 .30015 .50988 .31228 .52589 .30054 .51717 .2885 Mtetra
.724 .729 .855 r
.51717 .2885 .52589 .30054 .54194 .29108 .53329 .2795 Mtetra
.696 .73 .876 r
.53329 .2795 .54194 .29108 .55806 .28329 .54948 .27214 Mtetra
.679 .733 .891 r
.54948 .27214 .55806 .28329 .57428 .27655 .56576 .26567 Mtetra
.67 .737 .9 r
.56576 .26567 .57428 .27655 .59058 .27037 .58213 .2596 Mtetra
.666 .739 .905 r
.58213 .2596 .59058 .27037 .60699 .26443 .59861 .25369 Mtetra
.664 .74 .907 r
.59861 .25369 .60699 .26443 .6235 .25858 .61518 .24781 Mtetra
.664 .741 .908 r
.61518 .24781 .6235 .25858 .64011 .25275 .63185 .24192 Mtetra
.63185 .24192 .64011 .25275 .65681 .2469 .64863 .23601 Mtetra
.64863 .23601 .65681 .2469 .67362 .24101 .6655 .23006 Mtetra
.6655 .23006 .67362 .24101 .69052 .2351 .68248 .22408 Mtetra
.68248 .22408 .69052 .2351 .70753 .22915 .69955 .21806 Mtetra
.69955 .21806 .70753 .22915 .72464 .22316 .71674 .21201 Mtetra
.71674 .21201 .72464 .22316 .74185 .21713 .73402 .20592 Mtetra
.73402 .20592 .74185 .21713 .75917 .21107 .75141 .19979 Mtetra
.75141 .19979 .75917 .21107 .77659 .20498 .76891 .19362 Mtetra
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.662 .741 .909 r
.17554 .38997 .18549 .39922 .1997 .39422 .18979 .38496 Mtetra
.66 .742 .91 r
.18979 .38496 .1997 .39422 .21398 .38922 .2041 .38002 Mtetra
.653 .742 .915 r
.2041 .38002 .21398 .38922 .22833 .38426 .21848 .37531 Mtetra
.635 .744 .927 r
.21848 .37531 .22833 .38426 .24275 .37945 .23288 .37117 Mtetra
.587 .747 .953 r
.23288 .37117 .24275 .37945 .25722 .37503 .24726 .36827 Mtetra
.444 .734 .989 r
.24726 .36827 .25722 .37503 .2717 .37145 .26155 .36768 Mtetra
0 .508 .806 r
.26155 .36768 .2717 .37145 .28616 .36947 .27567 .3708 Mtetra
.595 .046 0 r
.27567 .3708 .28616 .36947 .30055 .37007 .28957 .37905 Mtetra
.704 .274 .224 r
.28957 .37905 .30055 .37007 .31484 .37422 .30328 .39314 Mtetra
.705 .336 .346 r
.30328 .39314 .31484 .37422 .32905 .3824 .31693 .41212 Mtetra
.68 .341 .394 r
.31693 .41212 .32905 .3824 .34328 .39394 .3308 .43279 Mtetra
.637 .314 .407 r
.3308 .43279 .34328 .39394 .35769 .40662 .34519 .44991 Mtetra
.569 .253 .394 r
.34519 .44991 .35769 .40662 .37248 .41684 .36035 .45776 Mtetra
.445 .132 .34 r
.36035 .45776 .37248 .41684 .38777 .4207 .37633 .45253 Mtetra
.159 0 .172 r
.37633 .45253 .38777 .4207 .40358 .4156 .39293 .43414 Mtetra
0 0 0 r
.39293 .43414 .40358 .4156 .41977 .40145 .40983 .40634 Mtetra
.963 .939 .69 r
.40983 .40634 .41977 .40145 .43616 .3807 .42673 .3748 Mtetra
.924 .822 .727 r
.42673 .3748 .43616 .3807 .45255 .35723 .44342 .34481 Mtetra
.861 .747 .736 r
.44342 .34481 .45255 .35723 .46884 .33468 .45986 .31967 Mtetra
.811 .711 .755 r
.45986 .31967 .46884 .33468 .485 .3154 .4761 .30035 Mtetra
.769 .699 .786 r
.4761 .30035 .485 .3154 .5011 .30015 .49224 .28621 Mtetra
.733 .703 .822 r
.49224 .28621 .5011 .30015 .51717 .2885 .50837 .27582 Mtetra
.704 .714 .856 r
.50837 .27582 .51717 .2885 .53329 .2795 .52455 .26776 Mtetra
.684 .725 .881 r
.52455 .26776 .53329 .2795 .54948 .27214 .5408 .26096 Mtetra
.672 .733 .896 r
.5408 .26096 .54948 .27214 .56576 .26567 .55715 .25475 Mtetra
.667 .738 .903 r
.55715 .25475 .56576 .26567 .58213 .2596 .57359 .24876 Mtetra
.665 .74 .906 r
.57359 .24876 .58213 .2596 .59861 .25369 .59013 .24285 Mtetra
.664 .741 .907 r
.59013 .24285 .59861 .25369 .61518 .24781 .60677 .23693 Mtetra
.664 .741 .908 r
.60677 .23693 .61518 .24781 .63185 .24192 .62351 .23098 Mtetra
.62351 .23098 .63185 .24192 .64863 .23601 .64035 .225 Mtetra
.64035 .225 .64863 .23601 .6655 .23006 .6573 .21899 Mtetra
.6573 .21899 .6655 .23006 .68248 .22408 .67434 .21294 Mtetra
.67434 .21294 .68248 .22408 .69955 .21806 .69149 .20686 Mtetra
.69149 .20686 .69955 .21806 .71674 .21201 .70874 .20073 Mtetra
.70874 .20073 .71674 .21201 .73402 .20592 .7261 .19457 Mtetra
.7261 .19457 .73402 .20592 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Mtetra
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.659 .742 .911 r
.16549 .38068 .17554 .38997 .18979 .38496 .17976 .37576 Mtetra
.649 .742 .917 r
.17976 .37576 .18979 .38496 .2041 .38002 .19408 .37115 Mtetra
.624 .744 .933 r
.19408 .37115 .2041 .38002 .21848 .37531 .20841 .3673 Mtetra
.555 .745 .965 r
.20841 .3673 .21848 .37531 .23288 .37117 .22268 .36507 Mtetra
.315 .692 .979 r
.22268 .36507 .23288 .37117 .24726 .36827 .23678 .36585 Mtetra
.367 0 0 r
.23678 .36585 .24726 .36827 .26155 .36768 .25059 .37148 Mtetra
.7 .218 .101 r
.25059 .37148 .26155 .36768 .27567 .3708 .26404 .3838 Mtetra
.739 .35 .315 r
.26404 .3838 .27567 .3708 .28957 .37905 .27715 .40375 Mtetra
.728 .382 .394 r
.27715 .40375 .28957 .37905 .30328 .39314 .29011 .43014 Mtetra
.7 .377 .426 r
.29011 .43014 .30328 .39314 .31693 .41212 .3033 .45878 Mtetra
.658 .345 .432 r
.3033 .45878 .31693 .41212 .3308 .43279 .31719 .48278 Mtetra
.588 .28 .414 r
.31719 .48278 .3308 .43279 .34519 .44991 .33216 .49454 Mtetra
.445 .137 .347 r
.33216 .49454 .34519 .44991 .36035 .45776 .34831 .48902 Mtetra
.018 0 .092 r
.34831 .48902 .36035 .45776 .37633 .45253 .36539 .46622 Mtetra
.894 .936 .564 r
.36539 .46622 .37633 .45253 .39293 .43414 .38293 .43122 Mtetra
.954 .828 .681 r
.38293 .43122 .39293 .43414 .40983 .40634 .40045 .39162 Mtetra
.883 .724 .68 r
.40045 .39162 .40983 .40634 .42673 .3748 .41766 .35432 Mtetra
.832 .674 .687 r
.41766 .35432 .42673 .3748 .44342 .34481 .43445 .32348 Mtetra
.793 .654 .708 r
.43445 .32348 .44342 .34481 .45986 .31967 .45091 .30027 Mtetra
.761 .654 .744 r
.45091 .30027 .45986 .31967 .4761 .30035 .46715 .28374 Mtetra
.733 .67 .788 r
.46715 .28374 .4761 .30035 .49224 .28621 .48332 .27204 Mtetra
.707 .692 .834 r
.48332 .27204 .49224 .28621 .50837 .27582 .49949 .26333 Mtetra
.687 .713 .869 r
.49949 .26333 .50837 .27582 .52455 .26776 .51572 .25622 Mtetra
.674 .727 .89 r
.51572 .25622 .52455 .26776 .5408 .26096 .53204 .24987 Mtetra
.667 .735 .901 r
.53204 .24987 .5408 .26096 .55715 .25475 .54845 .24382 Mtetra
.665 .739 .905 r
.54845 .24382 .55715 .25475 .57359 .24876 .56495 .23786 Mtetra
.664 .741 .907 r
.56495 .23786 .57359 .24876 .59013 .24285 .58156 .2319 Mtetra
.664 .741 .908 r
.58156 .2319 .59013 .24285 .60677 .23693 .59827 .22593 Mtetra
.59827 .22593 .60677 .23693 .62351 .23098 .61508 .21992 Mtetra
.61508 .21992 .62351 .23098 .64035 .225 .63199 .21388 Mtetra
.63199 .21388 .64035 .225 .6573 .21899 .649 .2078 Mtetra
.649 .2078 .6573 .21899 .67434 .21294 .66611 .20168 Mtetra
.66611 .20168 .67434 .21294 .69149 .20686 .68334 .19552 Mtetra
.68334 .19552 .69149 .20686 .70874 .20073 .70066 .18933 Mtetra
.70066 .18933 .70874 .20073 .7261 .19457 .71809 .1831 Mtetra
.71809 .1831 .7261 .19457 .74357 .18838 .73563 .17683 Mtetra
.73563 .17683 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.646 .742 .919 r
.1553 .37147 .16549 .38068 .17976 .37576 .16958 .36693 Mtetra
.616 .744 .937 r
.16958 .36693 .17976 .37576 .19408 .37115 .18383 .3633 Mtetra
.526 .74 .973 r
.18383 .3633 .19408 .37115 .20841 .3673 .19799 .36159 Mtetra
.195 .636 .946 r
.19799 .36159 .20841 .3673 .22268 .36507 .2119 .36342 Mtetra
.523 0 0 r
.2119 .36342 .22268 .36507 .23678 .36585 .22543 .37096 Mtetra
.739 .29 .186 r
.22543 .37096 .23678 .36585 .25059 .37148 .23844 .38639 Mtetra
.758 .386 .35 r
.23844 .38639 .25059 .37148 .26404 .3838 .25097 .41081 Mtetra
.744 .408 .413 r
.25097 .41081 .26404 .3838 .27715 .40375 .26324 .44282 Mtetra
.719 .399 .437 r
.26324 .44282 .27715 .40375 .29011 .43014 .27574 .47751 Mtetra
.678 .366 .438 r
.27574 .47751 .29011 .43014 .3033 .45878 .2891 .50668 Mtetra
.606 .292 .412 r
.2891 .50668 .3033 .45878 .31719 .48278 .30384 .52128 Mtetra
.42 .096 .309 r
.30384 .52128 .31719 .48278 .33216 .49454 .32013 .51532 Mtetra
0 0 0 r
.32013 .51532 .33216 .49454 .34831 .48902 .33766 .48893 Mtetra
.964 .849 .68 r
.33766 .48893 .34831 .48902 .36539 .46622 .35582 .44833 Mtetra
.882 .703 .655 r
.35582 .44833 .36539 .46622 .38293 .43122 .37398 .4026 Mtetra
.829 .639 .647 r
.37398 .4026 .38293 .43122 .40045 .39162 .39171 .35984 Mtetra
.793 .61 .654 r
.39171 .35984 .40045 .39162 .41766 .35432 .40887 .32482 Mtetra
.767 .602 .675 r
.40887 .32482 .41766 .35432 .43445 .32348 .42556 .29878 Mtetra
.745 .612 .711 r
.42556 .29878 .43445 .32348 .45091 .30027 .44192 .28054 Mtetra
.725 .636 .76 r
.44192 .28054 .45091 .30027 .46715 .28374 .45812 .26791 Mtetra
.705 .67 .813 r
.45812 .26791 .46715 .28374 .48332 .27204 .4743 .25873 Mtetra
.687 .7 .857 r
.4743 .25873 .48332 .27204 .49949 .26333 .49051 .2514 Mtetra
.675 .721 .884 r
.49051 .2514 .49949 .26333 .51572 .25622 .5068 .24495 Mtetra
.668 .733 .898 r
.5068 .24495 .51572 .25622 .53204 .24987 .52318 .23884 Mtetra
.665 .738 .905 r
.52318 .23884 .53204 .24987 .54845 .24382 .53965 .23284 Mtetra
.664 .74 .907 r
.53965 .23284 .54845 .24382 .56495 .23786 .55622 .22685 Mtetra
.664 .741 .908 r
.55622 .22685 .56495 .23786 .58156 .2319 .5729 .22085 Mtetra
.5729 .22085 .58156 .2319 .59827 .22593 .58967 .21481 Mtetra
.58967 .21481 .59827 .22593 .61508 .21992 .60655 .20873 Mtetra
.60655 .20873 .61508 .21992 .63199 .21388 .62353 .20262 Mtetra
.62353 .20262 .63199 .21388 .649 .2078 .64061 .19647 Mtetra
.64061 .19647 .649 .2078 .66611 .20168 .6578 .19029 Mtetra
.6578 .19029 .66611 .20168 .68334 .19552 .67509 .18406 Mtetra
.67509 .18406 .68334 .19552 .70066 .18933 .69249 .1778 Mtetra
.69249 .1778 .70066 .18933 .71809 .1831 .70999 .1715 Mtetra
.70999 .1715 .71809 .1831 .73563 .17683 .72761 .16516 Mtetra
.72761 .16516 .73563 .17683 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.612 .743 .939 r
.14496 .36261 .1553 .37147 .16958 .36693 .15916 .35907 Mtetra
.513 .736 .975 r
.15916 .35907 .16958 .36693 .18383 .3633 .17322 .35757 Mtetra
.145 .606 .927 r
.17322 .35757 .18383 .3633 .19799 .36159 .187 .35985 Mtetra
.565 0 0 r
.187 .35985 .19799 .36159 .2119 .36342 .2003 .36821 Mtetra
.755 .312 .2 r
.2003 .36821 .2119 .36342 .22543 .37096 .213 .38493 Mtetra
.772 .401 .353 r
.213 .38493 .22543 .37096 .23844 .38639 .22509 .41117 Mtetra
.761 .422 .411 r
.22509 .41117 .23844 .38639 .25097 .41081 .23685 .44543 Mtetra
.739 .414 .432 r
.23685 .44543 .25097 .41081 .26324 .44282 .24884 .48244 Mtetra
.703 .38 .428 r
.24884 .48244 .26324 .44282 .27574 .47751 .26177 .51347 Mtetra
.628 .293 .384 r
.26177 .51347 .27574 .47751 .2891 .50668 .2763 .52891 Mtetra
.309 0 .132 r
.2763 .52891 .2891 .50668 .30384 .52128 .29264 .52248 Mtetra
.945 .914 .754 r
.29264 .52248 .30384 .52128 .32013 .51532 .31047 .49443 Mtetra
.86 .683 .661 r
.31047 .49443 .32013 .51532 .33766 .48893 .32906 .4515 Mtetra
.809 .608 .631 r
.32906 .4515 .33766 .48893 .35582 .44833 .34767 .40336 Mtetra
.778 .575 .625 r
.34767 .40336 .35582 .44833 .37398 .4026 .3658 .35855 Mtetra
.756 .561 .633 r
.3658 .35855 .37398 .4026 .39171 .35984 .38325 .32203 Mtetra
.739 .562 .654 r
.38325 .32203 .39171 .35984 .40887 .32482 .40012 .295 Mtetra
.725 .578 .689 r
.40012 .295 .40887 .32482 .42556 .29878 .41657 .27618 Mtetra
.713 .609 .74 r
.41657 .27618 .42556 .29878 .44192 .28054 .43281 .26323 Mtetra
.699 .65 .798 r
.43281 .26323 .44192 .28054 .45812 .26791 .44898 .25389 Mtetra
.685 .689 .848 r
.44898 .25389 .45812 .26791 .4743 .25873 .46517 .24648 Mtetra
.674 .716 .88 r
.46517 .24648 .4743 .25873 .49051 .2514 .48143 .23997 Mtetra
.668 .731 .897 r
.48143 .23997 .49051 .2514 .5068 .24495 .49778 .23383 Mtetra
.665 .737 .904 r
.49778 .23383 .5068 .24495 .52318 .23884 .51422 .2278 Mtetra
.664 .74 .907 r
.51422 .2278 .52318 .23884 .53965 .23284 .53076 .22178 Mtetra
.664 .741 .908 r
.53076 .22178 .53965 .23284 .55622 .22685 .5474 .21574 Mtetra
.5474 .21574 .55622 .22685 .5729 .22085 .56414 .20967 Mtetra
.56414 .20967 .5729 .22085 .58967 .21481 .58098 .20357 Mtetra
.58098 .20357 .58967 .21481 .60655 .20873 .59792 .19742 Mtetra
.59792 .19742 .60655 .20873 .62353 .20262 .61497 .19124 Mtetra
.61497 .19124 .62353 .20262 .64061 .19647 .63212 .18502 Mtetra
.63212 .18502 .64061 .19647 .6578 .19029 .64938 .17877 Mtetra
.64938 .17877 .6578 .19029 .67509 .18406 .66675 .17247 Mtetra
.66675 .17247 .67509 .18406 .69249 .1778 .68422 .16614 Mtetra
.68422 .16614 .69249 .1778 .70999 .1715 .7018 .15976 Mtetra
.7018 .15976 .70999 .1715 .72761 .16516 .71949 .15335 Mtetra
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Mtetra
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.521 .736 .972 r
.1344 .35455 .14496 .36261 .15916 .35907 .14841 .35291 Mtetra
.191 .625 .945 r
.14841 .35291 .15916 .35907 .17322 .35757 .16212 .3549 Mtetra
.519 0 0 r
.16212 .3549 .17322 .35757 .187 .35985 .17533 .36272 Mtetra
.755 .294 .155 r
.17533 .36272 .187 .35985 .2003 .36821 .1879 .37854 Mtetra
.783 .398 .326 r
.1879 .37854 .2003 .36821 .213 .38493 .19983 .4034 Mtetra
.778 .426 .389 r
.19983 .4034 .213 .38493 .22509 .41117 .2114 .4358 Mtetra
.763 .422 .408 r
.2114 .4358 .22509 .41117 .23685 .44543 .22317 .47063 Mtetra
.736 .388 .392 r
.22317 .47063 .23685 .44543 .24884 .48244 .23592 .49958 Mtetra
.662 .266 .284 r
.23592 .49958 .24884 .48244 .26177 .51347 .25031 .51356 Mtetra
.55 .924 .93 r
.25031 .51356 .26177 .51347 .2763 .52891 .2666 .50674 Mtetra
.804 .657 .7 r
.2666 .50674 .2763 .52891 .29264 .52248 .28445 .4795 Mtetra
.773 .577 .634 r
.28445 .4795 .29264 .52248 .31047 .49443 .30315 .43827 Mtetra
.753 .545 .615 r
.30315 .43827 .31047 .49443 .32906 .4515 .3219 .39222 Mtetra
.738 .53 .612 r
.3219 .39222 .32906 .4515 .34767 .40336 .34016 .34941 Mtetra
.725 .526 .621 r
.34016 .34941 .34767 .40336 .3658 .35855 .35772 .3145 Mtetra
.715 .533 .642 r
.35772 .3145 .3658 .35855 .38325 .32203 .37466 .28862 Mtetra
.707 .554 .678 r
.37466 .28862 .38325 .32203 .40012 .295 .39114 .27051 Mtetra
.7 .591 .73 r
.39114 .27051 .40012 .295 .41657 .27618 .40739 .25794 Mtetra
.692 .638 .791 r
.40739 .25794 .41657 .27618 .43281 .26323 .42354 .24878 Mtetra
.682 .682 .844 r
.42354 .24878 .43281 .26323 .44898 .25389 .43971 .24144 Mtetra
.673 .713 .879 r
.43971 .24144 .44898 .25389 .46517 .24648 .45594 .23494 Mtetra
.667 .73 .896 r
.45594 .23494 .46517 .24648 .48143 .23997 .47225 .22878 Mtetra
.665 .737 .904 r
.47225 .22878 .48143 .23997 .49778 .23383 .48865 .22272 Mtetra
.664 .74 .907 r
.48865 .22272 .49778 .23383 .51422 .2278 .50516 .21668 Mtetra
.664 .741 .908 r
.50516 .21668 .51422 .2278 .53076 .22178 .52176 .21061 Mtetra
.52176 .21061 .53076 .22178 .5474 .21574 .53847 .20451 Mtetra
.53847 .20451 .5474 .21574 .56414 .20967 .55527 .19837 Mtetra
.55527 .19837 .56414 .20967 .58098 .20357 .57218 .1922 Mtetra
.57218 .1922 .58098 .20357 .59792 .19742 .5892 .18598 Mtetra
.5892 .18598 .59792 .19742 .61497 .19124 .60632 .17973 Mtetra
.60632 .17973 .61497 .19124 .63212 .18502 .62354 .17344 Mtetra
.62354 .17344 .63212 .18502 .64938 .17877 .64087 .16711 Mtetra
.64087 .16711 .64938 .17877 .66675 .17247 .65831 .16075 Mtetra
.65831 .16075 .66675 .17247 .68422 .16614 .67586 .15434 Mtetra
.67586 .15434 .68422 .16614 .7018 .15976 .69351 .14789 Mtetra
.69351 .14789 .7018 .15976 .71949 .15335 .71128 .14141 Mtetra
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Mtetra
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Mtetra
.306 .673 .975 r
.12355 .34765 .1344 .35455 .14841 .35291 .13727 .34869 Mtetra
.342 0 0 r
.13727 .34869 .14841 .35291 .16212 .3549 .15054 .35478 Mtetra
.721 .212 .016 r
.15054 .35478 .16212 .3549 .17533 .36272 .16321 .36775 Mtetra
.787 .366 .249 r
.16321 .36775 .17533 .36272 .1879 .37854 .17528 .38844 Mtetra
.795 .413 .331 r
.17528 .38844 .1879 .37854 .19983 .4034 .18701 .41545 Mtetra
.792 .417 .346 r
.18701 .41545 .19983 .4034 .2114 .4358 .19894 .44432 Mtetra
.781 .377 .286 r
.19894 .44432 .2114 .4358 .22317 .47063 .21177 .46791 Mtetra
.604 .033 0 r
.21177 .46791 .22317 .47063 .23592 .49958 .22614 .47861 Mtetra
.652 .597 .78 r
.22614 .47861 .23592 .49958 .25031 .51356 .24226 .47161 Mtetra
.713 .54 .653 r
.24226 .47161 .25031 .51356 .2666 .50674 .25987 .44734 Mtetra
.717 .517 .617 r
.25987 .44734 .2666 .50674 .28445 .4795 .27829 .41126 Mtetra
.713 .505 .606 r
.27829 .41126 .28445 .4795 .30315 .43827 .29681 .3711 Mtetra
.706 .5 .607 r
.29681 .3711 .30315 .43827 .3219 .39222 .31489 .3337 Mtetra
.7 .503 .618 r
.31489 .3337 .3219 .39222 .34016 .34941 .33235 .30303 Mtetra
.695 .515 .641 r
.33235 .30303 .34016 .34941 .35772 .3145 .34921 .28007 Mtetra
.692 .541 .678 r
.34921 .28007 .35772 .3145 .37466 .28862 .36566 .26374 Mtetra
.689 .583 .731 r
.36566 .26374 .37466 .28862 .39114 .27051 .38186 .25215 Mtetra
.685 .634 .793 r
.38186 .25215 .39114 .27051 .40739 .25794 .39799 .24345 Mtetra
.678 .681 .846 r
.39799 .24345 .40739 .25794 .42354 .24878 .41412 .2363 Mtetra
.671 .713 .88 r
.41412 .2363 .42354 .24878 .43971 .24144 .43031 .22986 Mtetra
.667 .73 .897 r
.43031 .22986 .43971 .24144 .45594 .23494 .44659 .2237 Mtetra
.665 .737 .904 r
.44659 .2237 .45594 .23494 .47225 .22878 .46296 .21762 Mtetra
.664 .74 .907 r
.46296 .21762 .47225 .22878 .48865 .22272 .47943 .21155 Mtetra
.664 .741 .908 r
.47943 .21155 .48865 .22272 .50516 .21668 .496 .20545 Mtetra
.496 .20545 .50516 .21668 .52176 .21061 .51267 .19932 Mtetra
.51267 .19932 .52176 .21061 .53847 .20451 .52944 .19315 Mtetra
.52944 .19315 .53847 .20451 .55527 .19837 .54631 .18694 Mtetra
.54631 .18694 .55527 .19837 .57218 .1922 .56329 .1807 Mtetra
.56329 .1807 .57218 .1922 .5892 .18598 .58037 .17441 Mtetra
.58037 .17441 .5892 .18598 .60632 .17973 .59756 .16809 Mtetra
.59756 .16809 .60632 .17973 .62354 .17344 .61486 .16173 Mtetra
.61486 .16173 .62354 .17344 .64087 .16711 .63226 .15533 Mtetra
.63226 .15533 .64087 .16711 .65831 .16075 .64977 .14889 Mtetra
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Mtetra
.6674 .14241 .67586 .15434 .69351 .14789 .68513 .13588 Mtetra
.68513 .13588 .69351 .14789 .71128 .14141 .70297 .12932 Mtetra
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
0 .507 .859 r
.11244 .34169 .12355 .34765 .13727 .34869 .12587 .34531 Mtetra
.566 0 0 r
.12587 .34531 .13727 .34869 .15054 .35478 .13881 .35428 Mtetra
.753 .259 .055 r
.13881 .35428 .15054 .35478 .16321 .36775 .15127 .36918 Mtetra
.797 .35 .181 r
.15127 .36918 .16321 .36775 .17528 .38844 .16346 .38883 Mtetra
.81 .36 .171 r
.16346 .38883 .17528 .38844 .18701 .41545 .17583 .40969 Mtetra
.75 .232 0 r
.17583 .40969 .18701 .41545 .19894 .44432 .18896 .42628 Mtetra
.272 .422 .83 r
.18896 .42628 .19894 .44432 .21177 .46791 .20339 .43287 Mtetra
.613 .493 .692 r
.20339 .43287 .21177 .46791 .22614 .47861 .21928 .42592 Mtetra
.667 .488 .634 r
.21928 .42592 .22614 .47861 .24226 .47161 .23644 .40583 Mtetra
.681 .483 .612 r
.23644 .40583 .24226 .47161 .25987 .44734 .2543 .37674 Mtetra
.684 .481 .606 r
.2543 .37674 .25987 .44734 .27829 .41126 .27229 .34452 Mtetra
.683 .482 .609 r
.27229 .34452 .27829 .41126 .29681 .3711 .28995 .31438 Mtetra
.681 .491 .622 r
.28995 .31438 .29681 .3711 .31489 .3337 .30711 .28939 Mtetra
.68 .509 .648 r
.30711 .28939 .31489 .3337 .33235 .30303 .32378 .27032 Mtetra
.68 .54 .688 r
.32378 .27032 .33235 .30303 .34921 .28007 .3401 .25637 Mtetra
.681 .587 .743 r
.3401 .25637 .34921 .28007 .36566 .26374 .35624 .24607 Mtetra
.679 .64 .804 r
.35624 .24607 .36566 .26374 .38186 .25215 .37231 .23799 Mtetra
.674 .686 .853 r
.37231 .23799 .38186 .25215 .39799 .24345 .3884 .23109 Mtetra
.669 .716 .883 r
.3884 .23109 .39799 .24345 .41412 .2363 .40456 .22474 Mtetra
.666 .731 .898 r
.40456 .22474 .41412 .2363 .43031 .22986 .4208 .21859 Mtetra
.664 .738 .905 r
.4208 .21859 .43031 .22986 .44659 .2237 .43714 .21249 Mtetra
.664 .74 .907 r
.43714 .21249 .44659 .2237 .46296 .21762 .45357 .20639 Mtetra
.664 .741 .908 r
.45357 .20639 .46296 .21762 .47943 .21155 .4701 .20026 Mtetra
.4701 .20026 .47943 .21155 .496 .20545 .48673 .1941 Mtetra
.48673 .1941 .496 .20545 .51267 .19932 .50347 .1879 Mtetra
.50347 .1879 .51267 .19932 .52944 .19315 .52031 .18166 Mtetra
.52031 .18166 .52944 .19315 .54631 .18694 .53725 .17538 Mtetra
.53725 .17538 .54631 .18694 .56329 .1807 .5543 .16907 Mtetra
.5543 .16907 .56329 .1807 .58037 .17441 .57145 .16271 Mtetra
.57145 .16271 .58037 .17441 .59756 .16809 .58871 .15632 Mtetra
.58871 .15632 .59756 .16809 .61486 .16173 .60608 .14988 Mtetra
.60608 .14988 .61486 .16173 .63226 .15533 .62355 .14341 Mtetra
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Mtetra
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Mtetra
.65884 .13033 .6674 .14241 .68513 .13588 .67665 .12373 Mtetra
.67665 .12373 .68513 .13588 .70297 .12932 .69457 .11709 Mtetra
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
0 .423 .797 r
.1012 .33548 .11244 .34169 .12587 .34531 .11451 .34023 Mtetra
.51 0 0 r
.11451 .34023 .12587 .34531 .13881 .35428 .12747 .3491 Mtetra
.655 .1 0 r
.12747 .3491 .13881 .35428 .15127 .36918 .14026 .36118 Mtetra
.601 .06 0 r
.14026 .36118 .15127 .36918 .16346 .38883 .1532 .37395 Mtetra
0 .284 .785 r
.1532 .37395 .16346 .38883 .17583 .40969 .16675 .38359 Mtetra
.472 .45 .753 r
.16675 .38359 .17583 .40969 .18896 .42628 .18128 .38622 Mtetra
.601 .467 .671 r
.18128 .38622 .18896 .42628 .20339 .43287 .19693 .37948 Mtetra
.642 .468 .633 r
.19693 .37948 .20339 .43287 .21928 .42592 .21354 .3637 Mtetra
.658 .468 .617 r
.21354 .3637 .21928 .42592 .23644 .40583 .23072 .34171 Mtetra
.664 .471 .613 r
.23072 .34171 .23644 .40583 .2543 .37674 .24804 .31754 Mtetra
.666 .477 .62 r
.24804 .31754 .2543 .37674 .27229 .34452 .26514 .29477 Mtetra
.667 .49 .636 r
.26514 .29477 .27229 .34452 .28995 .31438 .28189 .27556 Mtetra
.669 .514 .666 r
.28189 .27556 .28995 .31438 .30711 .28939 .2983 .26047 Mtetra
.673 .552 .71 r
.2983 .26047 .30711 .28939 .32378 .27032 .31447 .24894 Mtetra
.675 .602 .766 r
.31447 .24894 .32378 .27032 .3401 .25637 .33051 .23995 Mtetra
.675 .654 .822 r
.33051 .23995 .3401 .25637 .35624 .24607 .34652 .2325 Mtetra
.671 .695 .864 r
.34652 .2325 .35624 .24607 .37231 .23799 .36256 .22586 Mtetra
.667 .721 .889 r
.36256 .22586 .37231 .23799 .3884 .23109 .37868 .21959 Mtetra
.665 .733 .9 r
.37868 .21959 .3884 .23109 .40456 .22474 .39488 .21345 Mtetra
.664 .738 .905 r
.39488 .21345 .40456 .22474 .4208 .21859 .41118 .20734 Mtetra
.664 .74 .907 r
.41118 .20734 .4208 .21859 .43714 .21249 .42757 .20121 Mtetra
.664 .741 .908 r
.42757 .20121 .43714 .21249 .45357 .20639 .44407 .19505 Mtetra
.44407 .19505 .45357 .20639 .4701 .20026 .46067 .18886 Mtetra
.46067 .18886 .4701 .20026 .48673 .1941 .47737 .18262 Mtetra
.47737 .18262 .48673 .1941 .50347 .1879 .49417 .17635 Mtetra
.49417 .17635 .50347 .1879 .52031 .18166 .51107 .17004 Mtetra
.51107 .17004 .52031 .18166 .53725 .17538 .52808 .16369 Mtetra
.52808 .16369 .53725 .17538 .5543 .16907 .5452 .1573 Mtetra
.5452 .1573 .5543 .16907 .57145 .16271 .56242 .15087 Mtetra
.56242 .15087 .57145 .16271 .58871 .15632 .57976 .1444 Mtetra
.57976 .1444 .58871 .15632 .60608 .14988 .5972 .1379 Mtetra
.5972 .1379 .60608 .14988 .62355 .14341 .61475 .13134 Mtetra
.61475 .13134 .62355 .14341 .64114 .13689 .63241 .12475 Mtetra
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Mtetra
.65018 .11812 .65884 .13033 .67665 .12373 .66806 .11144 Mtetra
.66806 .11144 .67665 .12373 .69457 .11709 .68606 .10472 Mtetra
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Mtetra
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.11 .533 .914 r
.09008 .32731 .1012 .33548 .11451 .34023 .10354 .33097 Mtetra
0 .425 .855 r
.10354 .33097 .11451 .34023 .12747 .3491 .11691 .33659 Mtetra
.121 .434 .874 r
.11691 .33659 .12747 .3491 .14026 .36118 .13042 .34255 Mtetra
.383 .474 .83 r
.13042 .34255 .14026 .36118 .1532 .37395 .14437 .34644 Mtetra
.536 .478 .738 r
.14437 .34644 .1532 .37395 .16675 .38359 .15901 .34586 Mtetra
.601 .473 .678 r
.15901 .34586 .16675 .38359 .18128 .38622 .17443 .3394 Mtetra
.631 .47 .647 r
.17443 .3394 .18128 .38622 .19693 .37948 .19053 .32728 Mtetra
.645 .471 .633 r
.19053 .32728 .19693 .37948 .21354 .3637 .20705 .31127 Mtetra
.652 .475 .632 r
.20705 .31127 .21354 .3637 .23072 .34171 .2237 .29387 Mtetra
.656 .486 .641 r
.2237 .29387 .23072 .34171 .24804 .31754 .24025 .27735 Mtetra
.66 .505 .662 r
.24025 .27735 .24804 .31754 .26514 .29477 .25659 .26305 Mtetra
.665 .535 .696 r
.25659 .26305 .26514 .29477 .28189 .27556 .27272 .25133 Mtetra
.669 .577 .743 r
.27272 .25133 .28189 .27556 .2983 .26047 .28871 .24185 Mtetra
.672 .627 .796 r
.28871 .24185 .2983 .26047 .31447 .24894 .30465 .23397 Mtetra
.671 .674 .844 r
.30465 .23397 .31447 .24894 .33051 .23995 .32059 .22705 Mtetra
.669 .707 .876 r
.32059 .22705 .33051 .23995 .34652 .2325 .33659 .22063 Mtetra
.666 .726 .894 r
.33659 .22063 .34652 .2325 .36256 .22586 .35266 .21443 Mtetra
.664 .735 .903 r
.35266 .21443 .36256 .22586 .37868 .21959 .36883 .20829 Mtetra
.664 .739 .906 r
.36883 .20829 .37868 .21959 .39488 .21345 .38509 .20216 Mtetra
.664 .741 .907 r
.38509 .20216 .39488 .21345 .41118 .20734 .40145 .196 Mtetra
.664 .741 .908 r
.40145 .196 .41118 .20734 .42757 .20121 .4179 .18981 Mtetra
.4179 .18981 .42757 .20121 .44407 .19505 .43446 .18358 Mtetra
.43446 .18358 .44407 .19505 .46067 .18886 .45113 .17732 Mtetra
.45113 .17732 .46067 .18886 .47737 .18262 .46789 .17101 Mtetra
.46789 .17101 .47737 .18262 .49417 .17635 .48476 .16467 Mtetra
.48476 .16467 .49417 .17635 .51107 .17004 .50173 .15829 Mtetra
.50173 .15829 .51107 .17004 .52808 .16369 .51881 .15187 Mtetra
.51881 .15187 .52808 .16369 .5452 .1573 .536 .1454 Mtetra
.536 .1454 .5452 .1573 .56242 .15087 .55329 .1389 Mtetra
.55329 .1389 .56242 .15087 .57976 .1444 .5707 .13236 Mtetra
.5707 .13236 .57976 .1444 .5972 .1379 .58821 .12577 Mtetra
.58821 .12577 .5972 .1379 .61475 .13134 .60583 .11914 Mtetra
.60583 .11914 .61475 .13134 .63241 .12475 .62357 .11247 Mtetra
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Mtetra
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Mtetra
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Mtetra
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Mtetra
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.416 .629 .942 r
.07923 .31618 .09008 .32731 .10354 .33097 .09308 .31704 Mtetra
.448 .586 .898 r
.09308 .31704 .10354 .33097 .11691 .33659 .10704 .31804 Mtetra
.518 .549 .826 r
.10704 .31804 .11691 .33659 .13042 .34255 .12131 .31779 Mtetra
.576 .52 .755 r
.12131 .31779 .13042 .34255 .14437 .34644 .13603 .31496 Mtetra
.61 .502 .705 r
.13603 .31496 .14437 .34644 .15901 .34586 .15126 .30875 Mtetra
.63 .493 .677 r
.15126 .30875 .15901 .34586 .17443 .3394 .16695 .29931 Mtetra
.641 .492 .665 r
.16695 .29931 .17443 .3394 .19053 .32728 .18293 .28766 Mtetra
.648 .498 .666 r
.18293 .28766 .19053 .32728 .20705 .31127 .19903 .2752 Mtetra
.654 .512 .678 r
.19903 .2752 .20705 .31127 .2237 .29387 .2151 .26323 Mtetra
.659 .536 .703 r
.2151 .26323 .2237 .29387 .24025 .27735 .23108 .25252 Mtetra
.664 .571 .74 r
.23108 .25252 .24025 .27735 .25659 .26305 .24698 .24328 Mtetra
.668 .614 .785 r
.24698 .24328 .25659 .26305 .27272 .25133 .26282 .23531 Mtetra
.67 .658 .83 r
.26282 .23531 .27272 .25133 .28871 .24185 .27865 .22823 Mtetra
.669 .694 .865 r
.27865 .22823 .28871 .24185 .30465 .23397 .29453 .22169 Mtetra
.666 .718 .887 r
.29453 .22169 .30465 .23397 .32059 .22705 .31048 .21541 Mtetra
.665 .731 .899 r
.31048 .21541 .32059 .22705 .33659 .22063 .32651 .20925 Mtetra
.664 .737 .905 r
.32651 .20925 .33659 .22063 .35266 .21443 .34264 .20311 Mtetra
.664 .74 .907 r
.34264 .20311 .35266 .21443 .36883 .20829 .35886 .19695 Mtetra
.664 .741 .908 r
.35886 .19695 .36883 .20829 .38509 .20216 .37518 .19077 Mtetra
.37518 .19077 .38509 .20216 .40145 .196 .3916 .18454 Mtetra
.3916 .18454 .40145 .196 .4179 .18981 .40812 .17828 Mtetra
.40812 .17828 .4179 .18981 .43446 .18358 .42475 .17199 Mtetra
.42475 .17199 .43446 .18358 .45113 .17732 .44148 .16565 Mtetra
.44148 .16565 .45113 .17732 .46789 .17101 .45831 .15927 Mtetra
.45831 .15927 .46789 .17101 .48476 .16467 .47524 .15286 Mtetra
.47524 .15286 .48476 .16467 .50173 .15829 .49228 .1464 Mtetra
.49228 .1464 .50173 .15829 .51881 .15187 .50943 .1399 Mtetra
.50943 .1399 .51881 .15187 .536 .1454 .52669 .13336 Mtetra
.52669 .13336 .536 .1454 .55329 .1389 .54406 .12679 Mtetra
.54406 .12679 .55329 .1389 .5707 .13236 .56153 .12016 Mtetra
.56153 .12016 .5707 .13236 .58821 .12577 .57912 .1135 Mtetra
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Mtetra
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Mtetra
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Mtetra
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Mtetra
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Mtetra
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Mtetra
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Mtetra
.565 .646 .889 r
.06862 .3026 .07923 .31618 .09308 .31704 .08289 .3004 Mtetra
.585 .607 .841 r
.08289 .3004 .09308 .31704 .10704 .31804 .09737 .29753 Mtetra
.608 .573 .79 r
.09737 .29753 .10704 .31804 .12131 .31779 .11214 .29328 Mtetra
.625 .549 .749 r
.11214 .29328 .12131 .31779 .13603 .31496 .12724 .28726 Mtetra
.637 .536 .724 r
.12724 .28726 .13603 .31496 .15126 .30875 .14262 .27955 Mtetra
.645 .534 .713 r
.14262 .27955 .15126 .30875 .16695 .29931 .15821 .27069 Mtetra
.651 .541 .716 r
.15821 .27069 .16695 .29931 .18293 .28766 .1739 .26141 Mtetra
.657 .557 .731 r
.1739 .26141 .18293 .28766 .19903 .2752 .18963 .25236 Mtetra
.662 .583 .757 r
.18963 .25236 .19903 .2752 .2151 .26323 .20534 .24395 Mtetra
.666 .618 .791 r
.20534 .24395 .2151 .26323 .23108 .25252 .22104 .2363 Mtetra
.668 .655 .828 r
.22104 .2363 .23108 .25252 .24698 .24328 .23676 .22928 Mtetra
.668 .688 .86 r
.23676 .22928 .24698 .24328 .26282 .23531 .25252 .22271 Mtetra
.667 .713 .883 r
.25252 .22271 .26282 .23531 .27865 .22823 .26834 .2164 Mtetra
.665 .728 .896 r
.26834 .2164 .27865 .22823 .29453 .22169 .28424 .21021 Mtetra
.664 .735 .903 r
.28424 .21021 .29453 .22169 .31048 .21541 .30023 .20406 Mtetra
.664 .739 .906 r
.30023 .20406 .31048 .21541 .32651 .20925 .31632 .1979 Mtetra
.664 .741 .907 r
.31632 .1979 .32651 .20925 .34264 .20311 .3325 .19172 Mtetra
.664 .741 .908 r
.3325 .19172 .34264 .20311 .35886 .19695 .34878 .1855 Mtetra
.34878 .1855 .35886 .19695 .37518 .19077 .36516 .17925 Mtetra
.36516 .17925 .37518 .19077 .3916 .18454 .38165 .17296 Mtetra
.38165 .17296 .3916 .18454 .40812 .17828 .39823 .16663 Mtetra
.39823 .16663 .40812 .17828 .42475 .17199 .41492 .16026 Mtetra
.41492 .16026 .42475 .17199 .44148 .16565 .43171 .15385 Mtetra
.43171 .15385 .44148 .16565 .45831 .15927 .44861 .1474 Mtetra
.44861 .1474 .45831 .15927 .47524 .15286 .46562 .1409 Mtetra
.46562 .1409 .47524 .15286 .49228 .1464 .48273 .13437 Mtetra
.48273 .13437 .49228 .1464 .50943 .1399 .49994 .1278 Mtetra
.49994 .1278 .50943 .1399 .52669 .13336 .51727 .12119 Mtetra
.51727 .12119 .52669 .13336 .54406 .12679 .53471 .11453 Mtetra
.53471 .11453 .54406 .12679 .56153 .12016 .55226 .10783 Mtetra
.55226 .10783 .56153 .12016 .57912 .1135 .56992 .10109 Mtetra
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Mtetra
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Mtetra
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Mtetra
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Mtetra
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Mtetra
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Mtetra
.624 .657 .862 r
.05802 .28818 .06862 .3026 .08289 .3004 .07261 .28381 Mtetra
.632 .63 .83 r
.07261 .28381 .08289 .3004 .09737 .29753 .0874 .27876 Mtetra
.641 .608 .801 r
.0874 .27876 .09737 .29753 .11214 .29328 .10239 .27285 Mtetra
.648 .595 .782 r
.10239 .27285 .11214 .29328 .12724 .28726 .11758 .26614 Mtetra
.653 .592 .774 r
.11758 .26614 .12724 .28726 .14262 .27955 .13291 .25887 Mtetra
.658 .599 .777 r
.13291 .25887 .14262 .27955 .15821 .27069 .14833 .25139 Mtetra
.662 .615 .791 r
.14833 .25139 .15821 .27069 .1739 .26141 .16382 .244 Mtetra
.665 .638 .813 r
.16382 .244 .1739 .26141 .18963 .25236 .17935 .2369 Mtetra
.667 .665 .839 r
.17935 .2369 .18963 .25236 .20534 .24395 .19492 .23013 Mtetra
.667 .691 .863 r
.19492 .23013 .20534 .24395 .22104 .2363 .21055 .22365 Mtetra
.666 .711 .882 r
.21055 .22365 .22104 .2363 .23676 .22928 .22623 .21736 Mtetra
.665 .726 .894 r
.22623 .21736 .23676 .22928 .25252 .22271 .242 .21117 Mtetra
.664 .734 .902 r
.242 .21117 .25252 .22271 .26834 .2164 .25786 .20501 Mtetra
.664 .738 .905 r
.25786 .20501 .26834 .2164 .28424 .21021 .27381 .19885 Mtetra
.664 .74 .907 r
.27381 .19885 .28424 .21021 .30023 .20406 .28986 .19268 Mtetra
.664 .741 .908 r
.28986 .19268 .30023 .20406 .31632 .1979 .306 .18646 Mtetra
.306 .18646 .31632 .1979 .3325 .19172 .32224 .18021 Mtetra
.32224 .18021 .3325 .19172 .34878 .1855 .33859 .17393 Mtetra
.33859 .17393 .34878 .1855 .36516 .17925 .35503 .1676 Mtetra
.35503 .1676 .36516 .17925 .38165 .17296 .37158 .16124 Mtetra
.37158 .16124 .38165 .17296 .39823 .16663 .38823 .15483 Mtetra
.38823 .15483 .39823 .16663 .41492 .16026 .40498 .14839 Mtetra
.40498 .14839 .41492 .16026 .43171 .15385 .42184 .14191 Mtetra
.42184 .14191 .43171 .15385 .44861 .1474 .4388 .13538 Mtetra
.4388 .13538 .44861 .1474 .46562 .1409 .45588 .12881 Mtetra
.45588 .12881 .46562 .1409 .48273 .13437 .47306 .12221 Mtetra
.47306 .12221 .48273 .13437 .49994 .1278 .49034 .11556 Mtetra
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Mtetra
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Mtetra
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Mtetra
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Mtetra
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Mtetra
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Mtetra
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Mtetra
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Mtetra
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Mtetra
.649 .678 .864 r
.04721 .2744 .05802 .28818 .07261 .28381 .06199 .26894 Mtetra
.653 .663 .847 r
.06199 .26894 .07261 .28381 .0874 .27876 .07691 .26309 Mtetra
.657 .654 .836 r
.07691 .26309 .0874 .27876 .10239 .27285 .09196 .25688 Mtetra
.66 .652 .831 r
.09196 .25688 .10239 .27285 .11758 .26614 .10713 .25041 Mtetra
.663 .658 .835 r
.10713 .25041 .11758 .26614 .13291 .25887 .1224 .24383 Mtetra
.665 .669 .844 r
.1224 .24383 .13291 .25887 .14833 .25139 .13774 .23728 Mtetra
.666 .684 .858 r
.13774 .23728 .14833 .25139 .16382 .244 .15314 .23083 Mtetra
.666 .701 .873 r
.15314 .23083 .16382 .244 .17935 .2369 .16862 .2245 Mtetra
.665 .716 .886 r
.16862 .2245 .17935 .2369 .19492 .23013 .18417 .21827 Mtetra
.665 .727 .895 r
.18417 .21827 .19492 .23013 .21055 .22365 .19981 .2121 Mtetra
.664 .734 .902 r
.19981 .2121 .21055 .22365 .22623 .21736 .21553 .20596 Mtetra
.664 .738 .905 r
.21553 .20596 .22623 .21736 .242 .21117 .23134 .1998 Mtetra
.664 .74 .907 r
.23134 .1998 .242 .21117 .25786 .20501 .24725 .19363 Mtetra
.664 .741 .907 r
.24725 .19363 .25786 .20501 .27381 .19885 .26326 .18742 Mtetra
.664 .741 .908 r
.26326 .18742 .27381 .19885 .28986 .19268 .27936 .18118 Mtetra
.27936 .18118 .28986 .19268 .306 .18646 .29557 .1749 Mtetra
.29557 .1749 .306 .18646 .32224 .18021 .31187 .16858 Mtetra
.31187 .16858 .32224 .18021 .33859 .17393 .32828 .16222 Mtetra
.32828 .16222 .33859 .17393 .35503 .1676 .34478 .15582 Mtetra
.34478 .15582 .35503 .1676 .37158 .16124 .36139 .14938 Mtetra
.36139 .14938 .37158 .16124 .38823 .15483 .37811 .14291 Mtetra
.37811 .14291 .38823 .15483 .40498 .14839 .39493 .13639 Mtetra
.39493 .13639 .40498 .14839 .42184 .14191 .41185 .12983 Mtetra
.41185 .12983 .42184 .14191 .4388 .13538 .42888 .12323 Mtetra
.42888 .12323 .4388 .13538 .45588 .12881 .44602 .11658 Mtetra
.44602 .11658 .45588 .12881 .47306 .12221 .46327 .1099 Mtetra
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Mtetra
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Mtetra
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Mtetra
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Mtetra
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Mtetra
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Mtetra
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Mtetra
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Mtetra
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Mtetra
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.659 .703 .879 r
.03611 .26178 .04721 .2744 .06199 .26894 .05097 .25594 Mtetra
.661 .698 .873 r
.05097 .25594 .06199 .26894 .07691 .26309 .06594 .24995 Mtetra
.663 .697 .872 r
.06594 .24995 .07691 .26309 .09196 .25688 .08101 .24384 Mtetra
.664 .7 .873 r
.08101 .24384 .09196 .25688 .10713 .25041 .09617 .23766 Mtetra
.665 .707 .879 r
.09617 .23766 .10713 .25041 .1224 .24383 .11142 .23147 Mtetra
.665 .715 .885 r
.11142 .23147 .1224 .24383 .13774 .23728 .12675 .2253 Mtetra
.665 .723 .892 r
.12675 .2253 .13774 .23728 .15314 .23083 .14216 .21915 Mtetra
.664 .73 .898 r
.14216 .21915 .15314 .23083 .16862 .2245 .15766 .21302 Mtetra
.664 .735 .903 r
.15766 .21302 .16862 .2245 .18417 .21827 .17324 .20689 Mtetra
.664 .738 .905 r
.17324 .20689 .18417 .21827 .19981 .2121 .18892 .20075 Mtetra
.664 .74 .907 r
.18892 .20075 .19981 .2121 .21553 .20596 .20469 .19458 Mtetra
.664 .741 .907 r
.20469 .19458 .21553 .20596 .23134 .1998 .22056 .18838 Mtetra
.664 .741 .908 r
.22056 .18838 .23134 .1998 .24725 .19363 .23652 .18214 Mtetra
.23652 .18214 .24725 .19363 .26326 .18742 .25259 .17587 Mtetra
.25259 .17587 .26326 .18742 .27936 .18118 .26875 .16955 Mtetra
.26875 .16955 .27936 .18118 .29557 .1749 .28501 .1632 Mtetra
.28501 .1632 .29557 .1749 .31187 .16858 .30138 .15681 Mtetra
.30138 .15681 .31187 .16858 .32828 .16222 .31785 .15038 Mtetra
.31785 .15038 .32828 .16222 .34478 .15582 .33442 .14391 Mtetra
.33442 .14391 .34478 .15582 .36139 .14938 .35109 .13739 Mtetra
.35109 .13739 .36139 .14938 .37811 .14291 .36787 .13084 Mtetra
.36787 .13084 .37811 .14291 .39493 .13639 .38475 .12424 Mtetra
.38475 .12424 .39493 .13639 .41185 .12983 .40174 .11761 Mtetra
.40174 .11761 .41185 .12983 .42888 .12323 .41884 .11093 Mtetra
.41884 .11093 .42888 .12323 .44602 .11658 .43605 .10421 Mtetra
.43605 .10421 .44602 .11658 .46327 .1099 .45337 .09744 Mtetra
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Mtetra
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Mtetra
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Mtetra
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Mtetra
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Mtetra
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Mtetra
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Mtetra
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Mtetra
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Mtetra
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`006_oooonD000003?oooooU?l0000Kooooo`006_oo
ool00`00003oooooooooo`2@ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0T?oo
ool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2@ooooo`0300000?oooooo
oooo037ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Iooooo`006_ooool00`00
003oooooooooo`2@ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0T?ooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000ooo
ool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooo
ooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003oooo
o`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`00
6_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@00
0003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0a
ooooo`03o`000?oooooooooo00Wo00001@00001oo`0000?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000oooo
ooooool01Ol00004000000D06ATI2000001go`0000?ooooo00?o0000ooooooooool06Oooool001[o
oooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000oooooooo
ool00ol00002000001406ATI0`00001do`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
0_l000000`0000006ATI01TI6@0D01TI6@<00000LOl00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`05o`000?oo
ooooooooo`00000000006P0I6AT3000006ko00000oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool01?l0003ooooooooo
ool0000;01TI6@0300000?l0003o000000H000002P0I6AT00`00003o0000o`00001[o`0000?ooooo
00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oo
oooooooo037ooooo00Co0000oooooooooooo00002@0I6AT2000000T0<c<c1000000701TI6@03o`00
00000000000006[o00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0801TI6@8000003`0c
<c<3000000L06ATI0`00001Wo`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000
ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool01`0I6AT0
0`000000<c<c03<c<`0403<c<`03o`0000000000000000P000000`0c<c<4000000H06ATI00<00000
o`000?l00000I?l00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo
08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo00L06ATI00?o000003<c
<`0c<c<0100c<c<00ol00000C4a<04a<C00804a<C0<00000100c<c<2000000D06ATI00<00000o`00
00000000Hol00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d0
00000oooool00`00003oooooooooo`0aooooo`04o`000?oooooooooo000000H06ATI00<0000003<c
<`0c<c<00`0c<c<010000000C4a<04a<C01<C4`8o`0000<0C4a<1000000203<c<`8000001P0I6AT0
0`00003o0000o`00001Po`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooo
ooooool0S@000003ooooo`0300000?oooooooooo037ooooo00Co0000ooooooooool000001@0I6AT0
0`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C?l00000201VIVH3o`0000@0C4a<0`00
0000100c<c<0000000000000000401TI6@800000H?l00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`05o`000?oo
ooooooooo`0000000000100I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C?l0
0000101VIVH00`00003o0000o`000005000000Co00000`1<C4`01_l00000<c<c03<c<`0c<c?o0000
000000@06ATI0P00001No`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooo
ooooool0S@000003ooooo`0300000?oooooooooo037ooooo00Go0000oooooooooooo000000000004
01TI6@030000000c<c<0<c<c0080<c<c00@0000004a<C01<C4co0000101VIVH00`000000Ogmo07mo
O`0607moO`@000000ol000000`1<C4`000000000000303<c<`030000000I6AT06ATI00<06ATI0P00
001Lo`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003
ooooo`0300000?oooooooooo037ooooo00Go0000oooooooooooo00000000000501TI6@050000000c
<c<0<c<c03<c<`0000000P1<C4`01Ol00000IVIV06IVIP1VIVH0000000D0Ogmo1?l0000407moO`80
000000@0IVIVo`000?l0003o00000P00000203<c<`030000000I6AT06ATI00@06ATI00<00000o`00
0?l00000FOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d0
00000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo00;o000000<0000001TI6@0I
6AT00P0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00Go000006IVIP1VIVH0IVIV00000002
07moO`?o0000102IVIT4o`000080Ogmo0P00000206IVIP05o`00001<C4`000000000000c<c<00`00
000401TI6@0300000?l0003o000005So00000oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`02
o`0000030000000I6AT06ATI00<06ATI00Co000003<c<`0c<c?o00000P1<C4`01?l00000IVIV06IV
IP00000207moO`03o`00002IVIT0VIVI0080VIVI2ol000020000000306IVI_l0003o000000;o0000
0`0c<c<00ol000006ATI01TI6@0201TI6@800000F?l00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo00?o000000<0000001TI6@0I6AT00P0I6AT010000000<c<c03<c<`00000204a<C004o`00
001VIVH0IVIV00000080Ogmo00?o000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`040;>c/`?o
000000<0VIVIo`000?l000000P00000206IVIP03o`000000000000000080<c<c0P00000401TI6@03
00000?l0003o000005Go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooo
ooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`04o`0000030000
000I6AT06ATI00806ATI00H0000003<c<`0c<c<0000004a<C?l0000206IVIP040000001oOgl0Ogmo
o`0000<0VIVI00?o00000;>c/`2c/k<01ol000000`2c/k?o0000o`000003o`000080000000<0IVIV
o`00001<C4`00P00000203<c<`8000000`0I6AT00`00003o0000o`00001Do`0000?ooooo00?o0000
ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo
037ooooo00?o0000ooooooooool01?l000000`0000006ATI01TI6@0201TI6@040000000c<c<0<c<c
00000080C4a<00Ko000006IVIP1VIVH0000007moOol0000209VIV@04o`00002c/k?o0000o`0000L0
c<c<0_l000020;>c/`07o`00002IVIWo000007moO`000000IVIVo`00000204a<C005o`00000c<c<0
<c<c03<c<ol000000`0I6AT00`00003o0000o`00001Co`0000?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000
ooooooooool01Ol000000`0000006ATI01TI6@0201TI6@060000000c<c<0<c<c0000001<C4co0000
0P1VIVH01@000000Ogmoo`00002IVIWo00000080/k>c00Co00000<c<c03<c<`0c<c<1_l000000`3<
c<co0000o`000005o`00008000000_l00000101<C4`000000000000c<c<2000000<06ATI0P00001C
o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003oooo
o`0300000?oooooooooo037ooooo00?o0000ooooooooool01Ol000000`0000006ATI01TI6@0301TI
6@03o`00000c<c<000000080C4a<00Oo000006IVIP000000Ogmoo`00002IVIWo00000080/k>c00Go
00000<c<c03<c<`0c<c<o`0000050>KViP?o000000<0c<c<o`000?l000001?l00002000000;o0000
00D0C4a<0000000c<c<0<c<c0000000401TI6@0300000?l0003o0000053o00000oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0
<Oooool00ol0003oooooooooo`06o`0000030000000I6AT06ATI00806ATI00@0000003<c<`0c<c<0
00000P1<C4`02Ol00000IVIV0000001oOgoo000009VIVOl00000/k>co`0000020<c<c004o`00003V
i^H0i^KV0>KViP?o00000`3Vi^H2o`000080c<c<0_l000001`2IVIWo000007moOol00000IVIVo`00
001<C4`00P0000000`0c<c<000000000000301TI6@0300000?l0003o000004oo00000oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`08o`0000050000000I6AT06ATI01TI6@0000000P0c<c<03_l0
0000C4a<04a<C?l00000IVIV0000001oOgoo000009VIVOl00000/k>co`00003<c<co00000P3Vi^H0
1?l00000oooo0?ooo`3oool4o`0000040>KVi_l0003o00000<c<c0Co000000<0Ogmo000000000000
0_l000001@1<C4co000003<c<`0c<c<0000000<06ATI00<00000o`000?l00000C_l00003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo00So000000<0000001TI6@0I6AT00P0I6AT040000000<c<c
03<c<`000000C4a<o`00001VIVH0000007moOol00000VIVIo`00002c/k?o00000<c<c?l000020>KV
iP03o`00003oool0oooo00D0oooo00?o00000>KViP3Vi^H00ol000001`2c/k?o0000o`000?l00000
Ogmo00000?l000000P1<C4`010000000<c<c03<c<`00000301TI6E3o00000oooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Ooo
ool00ol0003oooooooooo`09o`0000030000000I6AT06ATI00806ATI0100000003<c<`0c<c<00000
04a<C?l00000IVIV0000001oOgoo000009VIVOl00000/k>co`00003<c<co00000P3Vi^H00ol00000
oooo0?ooo`050?ooo`0=o`00003Vi^H0i^KVo`00003<c<co00000;>c/ol00000VIVIo`00001oOgl0
0000o`00000204a<C0040000000c<c<0<c<c000000<06ATI00<00000o`000?l00000C?l00003oooo
o`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo00[o000000<0000001TI6@0I6AT00P0I6AT03@000000
<c<c03<c<`000000C4a<o`00001VIVH0000007moOol00000VIVIo`00002c/k<00_l000020>KViP03
o`00003oool0oooo00H0oooo00go00000>KViP3Vi^Ko00000<c<c?l00000/k>co`00002IVIWo0000
0000001VIVKo00000080C4a<00@0000003<c<`0c<c<000000`0I6AT00`00003o0000o`00001;o`00
00?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool02ol000000`0000006ATI01TI6@0201TI6@05
0000000c<c<0<c<co`00001<C4`00ol000001@1oOgoo0000o`000?l00000/k>c00?o000000<0i^KV
o`000?l000001`3oool02_l00000i^KV0>KVi_l00000c<c<o`00002c/k?o000009VIVOl000020000
00;o000000D0C4a<o`00000c<c<0<c<c0000000301TI6@0300000?l0003o000004[o00000oooool0
0ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000oooo
ooooool0<Oooool00ol0003oooooooooo`0<o`0000030000000I6AT06ATI00806ATI00@0000003<c
<`0c<c<000000P1<C4`01?l00000000007moO`1oOgl2o`0000030;>c/ol00000c<c<00;o000000<0
i^KVo`00003oool01P3oool04_l00000i^KV0>KVi_l00000c<c<o`00002c/k?o000009VIVOl00000
Ogmo0000001VIVKo000004a<C0000000<c<c000000D06ATI00<00000o`000?l00000B?l00003oooo
o`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo00go000000<0000001TI6@0I6AT00P0I6AT200000005
03<c<`000000C4a<04a<C?l000000P0000000`1oOgoo0000o`000002o`000080c<c<00?o00000>KV
i_l000000_l000040?ooo`0Bo`00003Vi^H0i^KV0>KVi_l00000c<c<o`00002c/k?o000009VIVOl0
0000Ogmo0000001VIVKo000004a<C0000000<c<c0P00000401TI6@0300000?l0003o000004Oo0000
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`0?o`0000030000000I6AT06ATI00806ATI00/0
000003<c<`00003o000004a<C?l00000IVIV0000001oOgoo000009VIV@03o`0000030<c<c?l00000
i^KV0080i^KV00?o00000?ooo`3oool00P3oool04Ol00000i^KV0>KViP3Vi^Ko00000<c<c?l00000
/k>co`00002IVIWo000007moO`000000IVIVo`00001<C4`000000080<c<c00<0000001TI6@0I6AT0
0P0I6AT00`00003o0000o`000016o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<0
0000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool04?l0
00000`0000006ATI01TI6@0201TI6@040000000c<c<0<c<c000000;o000000D0IVIV0000001oOgoo
000009VIV@03o`0000030<c<c?l0003o00000080i^KV1?l000040>KViP0=o`00003<c<co00000;>c
/ol00000VIVIo`00001oOgl0000006IVI_l00000C4a<0000000203<c<`030000000I6AT06ATI00<0
6ATIB?l00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d00000
0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo017o000000<0000001TI6@0I6AT0
0P0I6AT00`000000<c<c03<c<`02000000;o00000P0000000ol00000VIVI09VIV@02o`000080c<c<
0_l000070>KViP08o`00003<c<`0c<c<o`00002c/k?o000009VIVOl0000207moO`0500000?l00000
C4a<04a<C00000000P0c<c<00`0000006ATI01TI6@0201TI6@0300000?l0003o000004Go00000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000
ooooooooool0<Oooool00ol0003oooooooooo`0Co`0000@06ATI00T0000003<c<`0c<c<0<c<c0000
001<C4co000006IVIP0000001ol00000103<c<co0000o`000?l000020>KViP?o00000P3<c<`02_l0
0000/k>c0;>c/ol00000VIVIo`00001oOgl0000006IVI_l0000204a<C0040000000c<c<0<c<co`00
00@06ATI00<00000o`000?l00000A?l00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
00000?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01?o
00000`00000201TI6@060000000c<c<0<c<c03<c<`000000C4a<0_l000020000000307moOol0003o
000000So0000103<c<`2o`000080/k>c00So000009VIV@2IVIWo000007moO`000000IVIVo`000080
C4a<00@0000003<c<`0c<c<00000100I6AT00`00003o0000o`000013o`0000?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool05_l000001@0000006ATI01TI6Ol0000000000080<c<c00?o00000000
001<C4`00_l00002000000;o00000P2IVIT2o`0000040;>c/ol0003o0000o`000080c<c<00?o0000
0;>c/`2c/k<00P2c/k<02?l00000VIVI09VIVOl00000Ogmo0000001VIVKo00000P1<C4`010000000
<c<c03<c<`00000401TI6@0300000?l0003o000004?o00000oooool00ol0003oooooooooo`0Ioooo
o`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003o
ooooooooo`0Fo`0000030000000I6AT06ATI00806ATI0P00000203<c<`050000001<C4`0C4a<o`00
001VIVH00P000002o`000080VIVI00Co00000;>c/`2c/k<0/k>c0_l000040;>c/`09o`00002IVIT0
VIVI09VIVOl00000Ogmo0000001VIVKo00000080C4a<00D0000003<c<`0c<c<0<c<c0000000401TI
6@0300000?l0003o000004;o00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Go`000003
0000000I6AT06ATI00<06ATI00@0000003<c<`0c<c<000000P1<C4`01Ol00000IVIV06IVIP000000
Ogmo00;o000000<0VIVIo`000?l000001ol0000309VIV@04o`00001oOgl0Ogmo00000080IVIV00Co
000004a<C01<C4`000000P0c<c<00`0000006ATI01TI6@0201TI6@0300000?l0003o000004;o0000
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`0Io`00008000000`0I6AT01?l00000000003<c
<ol00002000000?o000000<00000o`00000000001?l0000909VIV@04o`00001oOgl0Ogmoo`000080
IVIV00Co000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@0201TI6@0300000?l0003o0000
047o00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?o
oooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Ko`00008000000`0I6AT200000080
<c<c0P0000001@1<C4co0000o`000?l00000IVIV00<000001?l0000309VIV@;o00000P1oOgl20000
0080IVIV00Co000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@0201TI6@0300000?l0003o
0000047o00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=0000
00?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0No`0000@06ATI0P00000203<c
<`8000000P1<C4`01?l00000IVIV06IVIP1VIVH4000000?o00000P1oOgl2000000<0IVIV00?o0000
04a<C01<C4`00P1<C4`01@000000<c<c03<c<`0c<c?o000000@06ATI00<00000o`000?l00000@?l0
0003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo01ko000000<0000001TI6@0I6AT00`0I6AT2
00000080<c<c0`000004o`0000<0IVIV1@00000506IVIP03o`00001<C4`0C4a<0080C4a<00D00000
03<c<`0c<c<0<c<c0000000501TI6@0300000?l0003o000003oo00000oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`0Oo`0000030000000I6AT06ATI00@06ATI0P00000303<c<`8000000P1<C4`3
o`0000T0IVIV00?o000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT0
6ATI00<06ATI00<00000o`000?l00000?ol00003ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo
023o00000P00000601TI6@8000000`0c<c<2000000<0C4a<2Ol0000404a<C0030000000c<c<0<c<c
00<0<c<c00<0000001TI6@0I6AT00`0I6AT00`00003o0000o`00000oo`0000?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool08_l00002000000H06ATI00<0000003<c<`0c<c<00P0c<c<3000000`0
C4a<00<0000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0401TI6@0300000?l0003o000003ko
00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo
00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Uo`0000<000000`0I6AT01000003o0000
00000000000303<c<`L000000`1<C4`2000000H0<c<c00<0000001TI6@0I6AT01@0I6AT00`00003o
0000o`00000no`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0
S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0:?l00002000000D06ATI
0`00000703<c<`<000001`0c<c<00`0000006ATI01TI6@0601TI6@0300000?l0003o000003ko0000
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`0Zo`0000030000000I6AT06ATI00D06ATI1000
000<03<c<`030000000I6AT06ATI00H06ATI00<00000o`000?l00000?ol00003ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0a
ooooo`03o`000?oooooooooo02_o00001000000701TI6@`000002@0I6AT00`00003o0000o`00000o
o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003oooo
o`0300000?oooooooooo037ooooo00?o0000ooooooooool0;ol00003000001T06ATI00<00000o`00
0?l00000?ol00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d0
00000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03;o00000`00000E01TI6@03
00000?l0003o0000043o00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooo
ooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0eo`0000030000
000I6AT06ATI01406ATI00<00000o`000?l00000@Ol00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo03Ko00001`00000901TI6@0300000?l00000000004Co00000oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`0mo`0000T00000Aol00003ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`0300000?oooooooooo06/00000300I6ATF000000?ooooo00<00000ooooooooool0<Oooool00ol0
003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooooooo
ool0HP0000000ol00000000000000002000001<06ATI00<00000o`000000000040000003ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wo
oooo000Jooooo`0300000?oooooooooo0680000000?o00000000000I6AT05`0I6ATA000000?ooooo
00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00<00000ooooooooool0H000000O01TI6@h000000oooool00`00003ooooooooo
o`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0`00003oooooooooo`1M000000h06ATI1@00000?01TI6@h000000oooool00`00003oooooooooo`0a
ooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00
003oooooooooo`1K000000T06ATI00<00000o`00000000001000000503<c<`D000002`0I6AT=0000
00?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool0E`0000000ol000006ATI01TI6@0601TI6@@0
00004@0c<c<00`0000006ATI01TI6@0801TI6@d000000oooool00`00003oooooooooo`0aooooo`03
o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooo
ooooo`1F000000L06ATI0`00000F03<c<`030000000I6AT06ATI00L06ATI3@000003ooooo`030000
0?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0300000?oooooooooo05@000001`0I6AT2000000L0<c<c3000000703<c<`800000200I
6AT<000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o
0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0DP00000701TI6@8000001@0c<c<4
000000`0C4a<00?o00000000000000001P0c<c<00`0000006ATI01TI6@0501TI6@`000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00`00003oooooooooo`1@00000003o`00000I6AT06ATI00D06ATI00<0000003<c
<`0c<c<00P0c<c<3000001<0C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0501TI
6@`000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`1?000000H06ATI0`00000303<c<`80
00000`1<C4`?000000D0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6@`0
00000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`1=000000H06ATI0P00000403<c<`800000
0`1<C4`00ol00000000006IVIP0>06IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0
0`0c<c<00`0000006ATI01TI6@0501TI6@/000000oooool00`00003oooooooooo`0aooooo`03o`00
0?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`1;00000003o`00000I6AT06ATI00@06ATI00L00000o`00000c<c<0<c<c00000?l00000000000<0
C4a<00@00000o`00001VIVH0IVIV3?l0000406IVIP030000001<C4`0C4a<0080C4a<00<0000003<c
<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6@/000000oooool00`00003oooooooooo`0aoooo
o`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`1:000000L06ATI00<0000003<c<`0c<c<00P00000304a<C0<0000000@0IVIVo`000?l0
003o0000301oOgl2o`000080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0203<c
<`030000000I6AT06ATI00D06ATI2`000003ooooo`0300000?oooooooooo037ooooo00?o0000oooo
ooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo04T0
00001P0I6AT20000000303<c<`00000000000080C4a<0`00000206IVIP;o00000`1oOgl8o`0000D0
Ogmo00Go000006IVIP1VIVH0IVIV0000000404a<C0050000000c<c<0<c<c03<c<`0000001P0I6AT<
000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000
ooooooooool06Oooool001[ooooo00<00000ooooooooool0A`00000601TI6@8000000P0c<c<00`00
0000C4a<04a<C00200000080IVIV0ol000000`1oOgoo0000o`000002o`0000P0VIVI0ol0000307mo
O`05o`00001VIVH0IVIV06IVIP0000000`1<C4`01@000000<c<c03<c<`0c<c<0000000H06ATI3000
0003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`0300000?oooooooooo04L00000100I6AT01P00003o000003<c<`0c
<c<00000o`000080C4a<00<0000006IVIP1VIVH00_l00000101oOgoo0000o`000?l0000409VIV@Oo
00000`2IVIT01Ol00000Ogmo07moO`1oOgoo000000<0IVIV00D0000004a<C01<C4`0C4a<00000003
03<c<`030000000I6AT06ATI00@06ATI30000003ooooo`0300000?oooooooooo037ooooo00?o0000
ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo
04H00000100I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00@0000006IVI_l0003o00000P1o
Ogl01?l00000VIVI09VIV@2IVIT4o`0000L0/k>c0_l0000209VIV@04o`00001oOgl0Ogmoo`0000<0
IVIV00D0000004a<C01<C4`0C4a<0000000303<c<`030000000I6AT06ATI00@06ATI30000003oooo
o`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`0300000?oooooooooo04@000001@0I6AT01@000000<c<c03<c<`0c<c<00000
00<0C4a<00<0000006IVI_l000000P1oOgl2o`00000409VIVOl0003o0000o`0000@0/k>c1Ol00004
0;>c/`03o`00002IVIWo000000<0Ogmo00Co000006IVIP1VIVH000000P1<C4`01@000000<c<c03<c
<`0c<c<0000000H06ATI3@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo04<000001@0I
6AT00`000000<c<c03<c<`020000000704a<C000003o00000000001VIVKo000007moO`02o`000080
VIVI00Co00000;>c/`2c/k<0/k>c1?l000050<c<c005o`00002c/k<0/k>c0;>c/ol000000P2IVIT0
1?l00000Ogmo07moOol0000206IVIP040000001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT0
100I6AT=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo
00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0@@0000000ol000006ATI01TI
6@0301TI6@040000000c<c<0<c<c00000080C4a<00@0000006IVIP1VIVH0IVIV0ol0000209VIV@;o
000000<0/k>co`000?l000001_l000040<c<c005o`00002c/k<0/k>c0;>c/ol000000P2IVIT01?l0
0000Ogmo07moOol0000206IVIP040000001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT0100I
6AT=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o
0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0@000000601TI6@040000000c<c<0
<c<c00000080C4a<00<0000006IVIP1VIVH00ol0000209VIV@So00001@3Vi^H3o`000080c<c<00Oo
00000;>c/`2c/k<0/k>co`00002IVIWo00000080Ogmo00?o000006IVIP0000000P1<C4`01@000000
<c<c03<c<`0c<c<0000000H06ATI00?o00000000000000002`000003ooooo`0300000?oooooooooo
037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
00000?oooooooooo03l000001@0I6AT01Ol00000000003<c<`0c<c<000000080C4a<00Oo000006IV
I_l0003o000007moOol00000VIVI00;o000000D0/k>co`00003<c<`0c<c<o`00000;0>KViP04o`00
003<c<`0c<c<o`000080/k>c00?o000009VIVOl000000P1oOgl00ol00000IVIV0000000204a<C005
o`00000c<c<0<c<c03<c<`0000001@0I6AT?000000?ooooo00<00000ooooooooool0<Oooool00ol0
003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooooooo
ool0?@0000000ol000006ATI01TI6@0301TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01@00
0000IVIV06IVI_l00000Ogmo00;o000000D0VIVIo`00002c/k?o00000<c<c002o`0000@0i^KV0ol0
00050>KViP04o`00003<c<`0c<c<o`000080/k>c00?o000009VIVOl000000P1oOgl00ol00000IVIV
0000000204a<C0050000000c<c<0<c<c03<c<`0000001@0I6AT?000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0?P00000401TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01P000000
IVIVo`000?l00000Ogmoo`000080VIVI0ol000000`3<c<co00000>KViP020>KViP?o00000P3oool0
0ol00000i^KV0>KViP030>KViP08o`00003<c<`0c<c<o`00002c/k?o000009VIVOl0000207moO`03
o`00001VIVH0000000<0C4a<00@0000003<c<`0c<c<000001@0I6AT@000000?ooooo00<00000oooo
ooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[o
oooo00<00000ooooooooool0?@00000401TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`00`00
0000IVIVo`00000207moO`03o`00002IVIWo000000;o00000P3<c<`00ol00000i^KV0>KViP02o`00
00H0oooo00Go00000>KViP3Vi^H0i^KVo`0000020<c<c006o`00002c/k<0/k>co`00002IVIWo0000
0P1oOgl00ol00000IVIVo`00000204a<C0050000000c<c<0<c<c03<c<`0000001@0I6AT@000000?o
oooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00<00000ooooooooool0?000000401TI6@05o`00000c<c<0<c<c03<c<ol0
00000P1<C4`00ol00000IVIVo`00000207moO`05o`00002IVIWo00000;>c/ol000000P3<c<`01?l0
0000i^KV0>KVi_l000090?ooo`04o`00003Vi^H0i^KVo`000080c<c<00Go00000;>c/ol00000VIVI
o`00000207moO`03o`00001VIVH000000080C4a<00D0000003<c<`0c<c<0<c<c0000000501TI6@03
o`0000000000000000h000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go
00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0j00000003o`00
000I6AT06ATI00<06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C00300000?l00000Ogmo0080
Ogmo0_l000020;>c/`06o`00003<c<`0c<c<o`00003Vi^Ko00002P3oool01_l00000i^KV0>KVi_l0
0000c<c<o`000080/k>c00?o000009VIVOl000000P1oOgl00ol00000IVIV0000000204a<C0050000
000c<c<0<c<c03<c<`000000100I6ATB000000?ooooo00<00000ooooooooool0<Oooool00ol0003o
ooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0
>`00000401TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`00`000000IVIVo`00000207moO`;o
00000P2c/k<01_l00000c<c<0<c<c?l00000i^KVo`0000X0oooo00Co00000>KViP3Vi^Ko00000P3<
c<`01Ol00000/k>co`00002IVIWo00000080Ogmo00?o000006IVIP0000000P1<C4`01@000000<c<c
03<c<`0c<c<0000000D06ATI4P000003ooooo`0300000?oooooooooo037ooooo00?o0000oooooooo
ool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo03X00000
100I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00<0000006IVI_l000000P1oOgl01Ol00000
VIVIo`00002c/k?o00000080c<c<00?o00000>KVi_l000002P3oool01ol00000i^KV0>KViP3Vi^Ko
00000<c<c?l000000P2c/k<01Ol00000VIVIo`00001oOgoo00000080IVIV00<0000004a<C?l00000
0`0c<c<00ol000006ATI01TI6@0301TI6A<000000oooool00`00003oooooooooo`0aooooo`03o`00
0?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`0i000000@06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C004o`00001VIVKo000007moO`;o
000000@0VIVIo`00002c/k?o00000P3<c<`01?l00000i^KV0>KVi_l000090?ooo`;o00000P3Vi^H0
1?l00000c<c<o`00002c/k<4o`00000307moOol00000IVIV0080000000<0C4a<0000000c<c<00P0c
<c<00`0000006ATI01TI6@0201TI6AD000000oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0h
000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0050000001VIVKo000007moOol00000
0P2IVIT00ol00000/k>co`0000020<c<c004o`00003Vi^H0i^KVo`0000L0oooo0_l000030>KViP03
o`00003<c<`0c<c<00;o000000L0VIVIo`00001oOgl0Ogmoo`00001VIVH0000000<0C4a<00@00000
03<c<`0c<c<00000100I6ATF000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0=`000005
01TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01@000000IVIVo`00001oOgoo00000080VIVI
00?o00000;>c/ol000000P3<c<`01Ol00000i^KV0>KViP3Vi^Ko000000D0oooo0_l000040>KViP03
o`00003<c<co000000;o000000L0VIVIo`00001oOgl0Ogmoo`00001VIVH0000000<0C4a<00@00000
03<c<`0c<c<000001@0I6ATF000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0=@000000
0ol000006ATI01TI6@0301TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`00`000000IVIVo`00
000207moO`05o`00002IVIWo00000;>c/ol000000P3<c<`00ol00000i^KV0>KViP020>KViP03o`00
003oool0oooo0080oooo00Co00000>KViP3Vi^H0i^KV1ol000000`2IVIWo000007moO`02o`000006
06IVI_l00000C4a<04a<C000003o00000P0c<c<00`0000006ATI01TI6@0301TI6AL000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00`00003oooooooooo`0f000000D06ATI00@0000003<c<`0c<c<000000P1<C4`0
1?l00000IVIV06IVI_l0000207moO`05o`00002IVIWo00000;>c/ol000000P3<c<`00ol00000i^KV
0>KViP020>KViPGo00000`3Vi^H01_l00000c<c<o`000?l00000/k>co`000080VIVI00?o000007mo
Ool000000P1VIVH20000000304a<C0000000<c<c0080<c<c00<0000001TI6@0I6AT00`0I6ATH0000
00?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool0=@00000501TI6@040000000c<c<0<c<c0000
00<0C4a<00@0000006IVIP1VIVKo00000P1oOgl01Ol00000VIVIo`00002c/k?o000000<0c<c<00?o
00000>KViP3Vi^H01`3Vi^H2o`0000050<c<c?l00000/k>c0;>c/ol000000P2IVIT00ol00000Ogmo
o`00000206IVIP040000001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT00`0I6ATI000000?o
oooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00<00000ooooooooool0=@00000501TI6@040000000c<c<0<c<c00000080
C4a<00@0000006IVIP1VIVKo00000P1oOgl00ol00000VIVIo`0000030;>c/`04o`00003<c<`0c<c<
0<c<c0?o00001@3Vi^H01?l00000c<c<0<c<c?l000020;>c/`06o`00002IVIT0VIVIo`00001oOgoo
00000P1VIVH010000000C4a<04a<C?l0000303<c<`03o`00000I6AT06ATI00<06ATI6P000003oooo
o`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`0300000?oooooooooo03@000001@0I6AT01@000000<c<c03<c<`0c<c<00000
0080C4a<00@0000006IVIP1VIVKo00000P1oOgl00ol00000VIVIo`0000030;>c/`;o00001@3<c<`5
o`0000040<c<c?l0003o00000;>c/`;o000000<0VIVIo`000?l000000_l00000101VIVH000000000
001<C4`200000080<c<c0P00000401TI6A`000000oooool00`00003oooooooooo`0aooooo`03o`00
0?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`0c00000003o`00000I6AT06ATI00<06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000
001VIVH0IVIVo`000080Ogmo00?o000009VIVOl000001@2c/k<2o`0000D0c<c<1ol000001@2IVIWo
0000o`00001oOgoo00000080IVIV00@0000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@03
01TI6Ad000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool0
0ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0d000000D06ATI00D0000003<c
<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIVo`000080Ogmo00Co000009VIV@2IVIWo0000
1P2c/k<5o`0000<0/k>c00?o000009VIV@2IVIT00_l0000207moO`04o`00001VIVH0IVIV00000080
C4a<00D0000003<c<`0c<c<0<c<c0000000601TI6Ad000000oooool00`00003oooooooooo`0aoooo
o`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`0c000000D06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0040000001VIVH0IVIV
o`000080Ogmo00Go000009VIV@2IVIT0VIVIo`00000;0;>c/`;o00000P2IVIT00ol00000Ogmo07mo
O`02o`000080IVIV00@0000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@0401TI6Ah00000
0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00`00003oooooooooo`0c000000D06ATI00D0000003<c<`0c<c<0<c<c
0000000304a<C0040000001VIVH0IVIVo`000080Ogmo00?o000009VIV@2IVIT00P2IVIT?o`000003
07moOol0003o000000@000000P1<C4`00ol00000<c<c03<c<`02000000@06ATI0P0000000ol00000
00000000000L000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0<`00000501TI6@050000
000c<c<0<c<c03<c<`0000000`1<C4`01@000000IVIV06IVIP1VIVKo00000080Ogmo00?o000009VI
V@2IVIT02P2IVIT2o`0000<0Ogmo0_l00002000000@0C4a<0P0000000`0c<c<000000000000501TI
6B8000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0b000000H06ATI00D0000003<c<`0c
<c<0<c<c0000000404a<C0050000001VIVH0IVIV06IVI_l000000P1oOgl<o`000080Ogmo0ol00000
0`1VIVKo000004a<C00304a<C08000000P0c<c<00`0000006ATI01TI6@0401TI6B<000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00`00003oooooooooo`0b000000H06ATI00D0000003<c<`0c<c<0<c<c00000004
04a<C0030000001VIVH0IVIV0080IVIV0_l0000:07moO`Co00000P1VIVH200000080C4a<0P000000
0ol00000<c<c03<c<`02000000D06ATI9@000003ooooo`0300000?oooooooooo037ooooo00?o0000
ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo
038000001P0I6AT01@000000<c<c03<c<`0c<c<0000000@0C4a<00?o00000000001VIVH0101VIVH3
o`0000<0Ogmo1?l0000306IVIP<000000`1<C4`010000000<c<c03<c<`0c<c<2000000H06ATI9P00
0003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`0300000?oooooooooo038000001P0I6AT00`000000<c<c03<c<`02
03<c<`030000001<C4`0C4a<00<0C4a<0P00000606IVIP?o0000101VIVH3000000@0C4a<0P000003
03<c<`030000000I6AT06ATI00D06ATI9`000003ooooo`0300000?oooooooooo037ooooo00?o0000
ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo
038000001P0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<00@0C4a<0`00000606IV
IP@00000101<C4`3000000@0<c<c00<0000001TI6@0I6AT01@0I6AT00ol0000000000000000U0000
00?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool0<P00000601TI6@030000000c<c<0<c<c00@0
<c<c0P00000704a<C0H00000101<C4`4000000<0<c<c1000000601TI6BX000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`00
6_ooool00`00003oooooooooo`0b000000L06ATI00<0000003<c<`0c<c<01@0c<c<3000000X0C4a<
1000000603<c<`030000000I6AT06ATI00H06ATI;0000003ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oo
oooooooo03800000200I6AT00`000000<c<c03<c<`0703<c<`@000000P1<C4`4000000L0<c<c0`00
000701TI6Bh000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0b000000T06ATI00?o0000
03<c<`0c<c<02P0c<c<2000000P0<c<c0`00000701TI6@80000000?o0000000000000000;0000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`0300000?oooooooooo038000002P0I6AT00`000000<c<c03<c<`0?03<c
<`@000002@0I6ATb000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`00
00?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0<`00000:01TI6@<0
00002P0c<c<4000000/06ATI=0000003ooooo`0300000?oooooooooo037ooooo00?o0000oooooooo
ool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo03@00000
300I6AT:000000`06ATI=`000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo03@0000000?o
000001TI6@0I6AT07@0I6ATi000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0=P00000L
01TI6C/000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool0
0ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0i000001D06ATI?`000003oooo
o`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`0300000?oooooooooo03/00000400I6AU2000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0>P0000000ol0000000000000000<00000003o`0000000000000004400000
0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Ooo
ool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000
ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00
003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Ioooo
o`006_ooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003o
ooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0
S@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`00
0?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003ooooooooo
o`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=
o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003oooo
o`0300000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`03
o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooo
ooooo`2=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo
00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oo
oooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooo
oooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=0000
00?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`030000
0?oooooooooo08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go0000
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2=000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo037ooooo00?o0000
ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo
08d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2@ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Iooooo`006_oooonD000003?ooooo
U?l0000Kooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
QOooool2o`000<Gooooo0_l00012ooooo`00P_ooool3o`000003ooooool0003ooooo0<7ooooo0ol0
00000ooooooo0000ooooo`11ooooo`00P?ooool2o`0000;ooooo0_nY_NP2o`000;oooooo0_l00002
ooooo`;oZKgX0_l00011ooooo`00OOooool3o`000003oooooonY_NSoZKgX00?oZKgX00?o0000oooo
ool00000^oooool3o`000003oooooonY_NSoZKgX00?oZKgX00?o0000ooooool00000@?ooool007[o
oooo0ol00003ooooo`KoZKgX00?o0000ooooool00000^?ooool3o`0000?ooooo1_nY_NP00ol0003o
ooooo`000010ooooo`00N?ooool2o`0000Cooooo2?nY_NP01?l0003oZKgXooooool0002eooooo`;o
00000oooool9ojVmj004o`000?nY_NSoooooo`0003oooooo001eooooo`?o00000_ooool<ojVmj005
o`000?nY_NSoZKgXooooool00000/Oooool3o`0000;ooooo3?nY_NP01Ol0003oZKgXojVmj?oooooo
000003kooooo001cooooo`;o00000_ooool?ojVmj005o`000?nY_NSoZKgXooooool00000[oooool2
o`0000;ooooo3onY_NP01Ol0003oZKgXojVmj?oooooo000003kooooo001`ooooo`?o00000oooool@
ojVmj006o`000?nY_NSoZKgXojVmj?oooooo0000Zoooool3o`0000?ooooo4?nY_NP01_l0003oZKgX
ojVmj?nY_NSoooooo`0003gooooo001^ooooo`;o00001?oooolBojVmj006o`000?nY_NSoZKgXojVm
j?oooooo0000ZOooool2o`0000Cooooo4_nY_NP01_l0003oZKgXojVmj?nY_NSoooooo`0003gooooo
001[ooooo`?o00000_oooolFojVmj003o`000?nY_NSoZKgX00;oZKgX00?oooooo`000?ooool0Y?oo
ool3o`0000;ooooo5_nY_NP00ol0003oZKgXojVmj002ojVmj003ooooool0003ooooo03_ooooo001X
ooooo`?o00000_oooolIojVmj003o`000?nY_NSoZKgX00?oZKgX00?oooooo`000?ooool0X?ooool3
o`0000;ooooo6OnY_NP00ol0003oZKgXojVmj003ojVmj003ooooool0003ooooo03[ooooo001Voooo
o`;o00001?oooolKojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000ooooooooool0WOooool2o`00
00Cooooo6onY_NP00ol0003oZKgXojVmj002ojVmj003ooooool0003ooooo03[ooooo001Sooooo`?o
00001?oooolMojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ooooooooool0VOooool3o`0000Co
oooo7OnY_NP00ol0003oZKgXojVmj003ojVmj003ooooool0003ooooo03Wooooo001Qooooo`;o0000
1?oooolPojVmj003o`000?nY_NSoZKgX00CoZKgX00?oooooo`000?ooool0Uoooool2o`0000Cooooo
8?nY_NP00ol0003oZKgXojVmj004ojVmj003ooooool0003ooooo03Sooooo001Nooooo`?o00000_oo
oolTojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ooooooooool0Toooool3o`0000;ooooo9?nY
_NP00ol0003oZKgXojVmj005ojVmj003o`000?oooooooooo03Oooooo001Looooo`;o00000_oooolW
ojVmj003o`000?nY_NSoZKgX00GoZKgX00?oooooo`000?ooool0TOooool2o`0000;ooooo9onY_NP0
0ol0003oZKgXojVmj005ojVmj003ooooool0003ooooo03Oooooo001Iooooo`?o00000ooooolXojVm
j003o`000?nY_NSoZKgX00KoZKgX00?oooooo`000?ooool0SOooool3o`0000?ooooo:?nY_NP00ol0
003oZKgXojVmj006ojVmj003ooooool0003ooooo03Kooooo001Gooooo`;o00001?oooolZojVmj003
o`000?nY_NSoZKgX00OoZKgX00?o0000ooooooooool0R_ooool2o`0000Cooooo:_nY_NP00ol0003o
ZKgXojVmj006ojVmj003ooooool0003ooooo03Kooooo001Dooooo`?o00000oooool]ojVmj003o`00
0?nY_NSoZKgX00OoZKgX00?oooooo`000?ooool0Qoooool3o`0000?ooooo;OnY_NP00ol0003oZKgX
ojVmj007ojVmj003ooooool0003ooooo03Gooooo001Aooooo`?o00000oooool`ojVmj003o`000?nY
_NSoZKgX00SoZKgX00?oooooo`000?ooool0Poooool3o`0000?ooooo<?nY_NP00ol0003oZKgXojVm
j008ojVmj003ooooool0003ooooo03Cooooo001?ooooo`;o00000ooooolcojVmj003o`000?nY_NSo
ZKgX00SoZKgX00?oooooo`000?ooool0POooool2o`0000?ooooo<onY_NP00ol0003oZKgXojVmj008
ojVmj003ooooool0003ooooo03Cooooo001<ooooo`?o00000_oooolfojVmj003o`000?nY_NSoZKgX
00WoZKgX00?oooooo`000?ooool0OOooool3o`0000;ooooo=_nY_NP00ol0003oZKgXojVmj009ojVm
j003ooooool0003ooooo03?ooooo001:ooooo`;o00001?oooolgojVmj003o`000?nY_NSoZKgX00[o
ZKgX00?o0000ooooooooool0N_ooool2o`0000Cooooo=onY_NP00ol0003oZKgXojVmj00:ojVmj003
o`000?oooooooooo03;ooooo0017ooooo`?o00001?ooooliojVmj003o`000?nY_NSoZKgX00_oZKgX
00?o0000ooooooooool0M_ooool3o`0000Cooooo>OnY_NP00ol0003oZKgXojVmj00;ojVmj003o`00
0?oooooooooo037ooooo0015ooooo`;o00001?oooollojVmj003o`000?nY_NSoZKgX00_oZKgX00?o
ooooo`000?ooool0M?ooool2o`0000Cooooo??nY_NP00ol0003oZKgXojVmj00;ojVmj003ooooool0
003ooooo037ooooo0012ooooo`?o00000oooooloojVmj003o`000?nY_NSoZKgX00coZKgX00?o0000
ooooooooool0L?ooool3o`0000;ooooo@?nY_NP00ol0003oZKgXojVmj00<ojVmj003o`000?oooooo
oooo033ooooo000oooooo`?o00000ooooom2ojVmj003o`000?nY_NSoZKgX00coZKgX00?oooooo`00
0?ooool0KOooool3o`0000;ooooo@onY_NP00ol0003oZKgXojVmj00<ojVmj003ooooool0003ooooo
033ooooo000mooooo`;o00000ooooom5ojVmj003o`000?nY_NSoZKgX00_oZKgX0_nY_NL00ooooooo
0000ooooo`1Zooooo`;o00000_oooom6ojVmj003o`000?nY_NSoZKgX00goZKgX00?oooooo`000?oo
ool0;oooool003[ooooo0ol00002ooooodSoZKgX00?o0000ojVmj?nY_NP02?nY_NP6ojVmi`03o`00
0?oooooooooo06Kooooo0ol00002ooooodSoZKgX00?o0000ojVmj?nY_NP03_nY_NP00ol0003ooooo
ooooo`0^ooooo`00>?ooool2o`0000CoooooBOnY_NP00ol0003oZKgXojVmj005ojVmj0SoZKgW00?o
ZKcWooooool00000IOooool2o`0000CoooooBOnY_NP00ol0003oZKgXojVmj00>ojVmj003ooooool0
003ooooo02kooooo000eooooo`?o00001?oooom;ojVmj003o`000?nY_NSoZKgX00;oZKgX1onY_NL6
ojVli`03ooooool0003ooooo063ooooo0ol00004oooood_oZKgX00?o0000ojVmj?nY_NP03onY_NP0
0ooooooo0000ooooo`0]ooooo`00<oooool2o`0000CoooooC_nY_NP00ol0003oZKgWojVmi`06ojVm
i`SoZKcW0_nZ^nH00ol0003oooooooooo`1Mooooo`;o00001?oooom>ojVmj003o`000?nY_NSoZKgX
00ooZKgX00?oooooo`000?ooool0;Oooool0033ooooo0ol00003ooooodooZKgX0_nY_NL00ol0003o
ZKgWojVmi`03ojVmi`;oZK_W1_nY_>L6ojZkiP03o`000?oooooooooo05Wooooo0ol00003oooooe7o
ZKgX00?o0000ojVmj?nY_NP04?nY_NP00ooooooo0000ooooo`0/ooooo`00;Oooool3o`0000?ooooo
ConY_NP5ojVmi`03o`000?nY_NOoZKgW00KoZK_W0_nY_>L00onY^^GoZ[_VojZkiP04ojZkiP;oZ[[U
00?o0000ooooooooool0E_ooool3o`0000?oooooE?nY_NP00ol0003oZKgXojVmj00AojVmj003o`00
0?oooooooooo02_ooooo000[ooooo`;o00000ooooomAojVmj0KoZKgW00?oZK_Wo`000?nY^nL01?nY
^nL6ojVji@;oZ[_V0_nZ^N@4ojZji@03o`000?oooooooooo05?ooooo0_l00003oooooeSoZKgX00?o
0000ojVmj?nY_NP04OnY_NP00ol0003oooooooooo`0Zooooo`00:?ooool3o`0000;oooooE?nY_NP5
ojVmi`;oZK_W00Co0000ojVkionY^nOoZKWU1onY^^D00onZ^>?oZ[WTojZii003ojZii0;oZ[[U00?o
Zk[Tooooool00000DOooool3o`0000;oooooFonY_NP00ol0003oZKgXojVmj00AojVmj003ooooool0
003ooooo02[ooooo000Vooooo`;o00000_oooomHojVmj0;oZKgW00KoZKcWojVkionY^nOoZK_Wo`00
0?nY^nL3ojVii@?oZK[U00?oZKKRojZhhonZ^><00_nZ^><3ojZii003oj^hh_n[^^CoZk[T00;oZk[T
00?o0000ooooooooool0COooool2o`0000;ooooo0_nY_>L6ojVmj0;oZKcW1_nY_NP00onY_>OoZKgX
ojVmj004ojVmj0;oZKgWAOnY_NP00ol0003oZKgXojVmj00BojVmj003o`000?oooooooooo02Wooooo
000Sooooo`?o00000ooooomGojVmj0KoZKcW0_nY^nL00ol0003oZKWUojVii@03ojVii@04ojVjiOnY
]^;oZKKRojVfhPCoZ[SS00CoZ[WToj^hh_n[^>;oZkSR0_n[^^@2ojfjh`03o`000?oooooooooo04Wo
oooo0ol00003ooooo`CoZKcW0_nY_NP2ojVkiPCoZKcW0_nY_NP2ojVkiP?oZKcW0_nY_NP2ojVli`Co
ZKgW0_nY_NP2ojVli`KoZKgX00?oZKgWojVmj?nY_NP0=onY_NP00ol0003oZKgXojVmj00BojVmj003
ooooool0003ooooo02Wooooo000Qooooo`;o00001?oooomFojVmj0SoZKcW0onY^ND00ol0003oZKWU
ojVii@02ojVii@03ojVeh_nY]^;oZKKR00;oZKKR0_nZ^><2oj^eh0CoZkSR00?oZk[Tojfjhon]^^<0
0_n]^^<00ol0003oooooooooo`16ooooo`;o00001?ooool5ojVli`03ojZjiOnY^nKoZK_V00?oZK_V
0_nY_>L2ojZii0CoZK_V00?oZKcWojZjiOnZ^^D01?nY_>L2ojVmi`;oZ[_V1?nY_>L2ojVmj0;oZKcW
0onY_NL2ojVmj0;oZKcW=?nY_NP00ol0003oZKgXojVmj00CojVmj003ooooool0003ooooo02Sooooo
000Nooooo`?o00001?oooomEojVmj0SoZKcW0_nY^^D4ojVii@03o`000?nY^NGoZ;CQ00CoZKGR0_nY
]^82ojZbgPCoZkGP0_n[^>800on]]n3o[K[Sojfjh`02ojfjh`03ojnkh_l0003ooooo04Cooooo0ol0
0004ooooo`;oZK[U1?nY_>L3ojZji@?oZK_V00?oZ[KQojZii?nZ^N@00onZ^N@2ojVkiP03ojZfh_nZ
^^GoZ[[U00;oZ[[U0_nY_>L2ojZgh`CoZ[_V0_nY_>L2ojZii0CoZKcW00?oZKgWojZki_nZ^nH01?nY
_>L2ojVmj0;oZKcW0onY_NP00onZ_>OoZKgXojVmj00YojVmj003o`000?nY_NSoZKgX01CoZKgX00?o
0000ooooooooool09oooool001cooooo0_l00004oooooeOoZKgX1_nY_>L00onY^^KoZK[UojVji@03
ojVji@;oZKWU00?oZ;CQo`000?nX]>400_nX]>42ojVehP;oZJoL1?nZ/]h2oj^eh003ojfcgOn]]n3o
[KOP00;o[KOP00?o[K[Sojnkh_n_^n800_n_^n800ol0003oooooooooo`10ooooo`;o00001?ooool2
ojZii0CoZK[U00?oZKcWojZgh_nZ]n801?nZ^^D01?nY^nKoZ[KQojZfhOnZ]^43ojZii003oj^`g?nZ
]^;oZ[KR00;oZ[KR0_nZ^^D2oj^ag@CoZ[OS0_nZ^nH2oj^dh0CoZ[WT0_nY_>L00onZ^>?oZ[_VojZk
iP02ojZkiP;oZKcW0_nZ^nD4ojVli`04ojVmj?nZ_>OoZ[cWojZli`;oZKgX0_nZ_>LVojVmj003o`00
0?nY_NSoZKgX01GoZKgX00?o0000ooooooooool09_ooool001Wooooo0ol00003oooooe_oZKgX0_nY
_>L00onY^nKoZK[VojVjiP02ojVjiP;oZK[U0_nX]>83ojRdh@04o`000?nX]>7oZ;CQojR]f`GoZJoL
0_nZ/]h00on/[]Wo[K?Mojfcg@02ojfcg@;o[KOP0_n`^=l4ojnkhP03ooooool0003ooooo03gooooo
0ol00003ooooo`;oZ[OR1?nZ^N@2ojVji@03ojZcgonZ]n;oZ[OR00;oZ[OR0_nZ^^D2ojZ`g0CoZ[KQ
00CoZ[WToj^`g?n[/=coZk3L0onZ]^85oj^ag@;oZ[OS00?oZjcHoj^dh?n[]>000on[]>02ojZii003
oj^agOnZ^>?oZ[SS00;oZ[SS0_nZ^nH2oj^ghPCoZ[_U0_nY_>L01OnZ^^GoZ[cWojZlionZ_>OoZ[[U
00GoZ[cW0_nY_NP2ojZlib7oZKgX00?o0000ojVmj?nY_NP05OnY_NP00ooooooo0000ooooo`0Voooo
o`005_ooool3o`0000?oooooGOnY_NP00onY^nOoZK_VojVkiP02ojVkiP;oZK[V0_nX]^<4ojRdhP;o
Z;CQ00?o0000ojR]fonX[M/00_nX[M/3ojV_g003oj^Ze_n/[]Wo[:kI00;o[:kI0_n]/md2ok6cfPCo
/;SO0_n_^n800onb_^?oooooo`00000kooooo`?o00000oooool2ojZdh@CoZ[OR0_nZ^N@2ojZ_f`?o
Z[?O0_nZ]n82ojZZePCoZ[3L0_nZ]^42oj^Wd`CoZk3L00?oZ[KRoj^Xe?n[Z=@00on[/Md00on/X<_o
ZjcHoj^/f002oj^/f0?oZkCP00?o[:OBoj^agOn[/Md00_n[/Md2ojZhh`;o[:oJ1?n[]n82ojZki@;o
ZkKQ0onZ^^D01?nZ_>OoZ[[UojZjiOnZ^^D3ojZli`;oZk_U1?nZ_>L2ojVmj003ojZlionY_NSoZKgX
01_oZKgX00?o0000ojVmj?nY_NP05_nY_NP00ol0003oooooooooo`0Uooooo`005?ooool2o`0000Co
ooooG?nY_NP00onY_>OoZK_WojVki`02ojVki`;oZK_V0_nX]n@4ojRfh`;oZ;CR00GoYZcKojN/fonW
[=_o0000ojN/f`04ojR]f`04ojV_g?n[Z]KoZj[Foj^ZeP;o[:kI00?o/:gEok6cf_na/mX00ona/mX2
ok2hg`03okBkgonb_^?o/[kS00;o/[kS00?oooooo`000?ooool0=oooool2o`0000?ooooo0_nY/ml4
ojZdh@;oZ[OR00?oZZ_HojZ_fonZ[m/00onZ[m/00onZ/mooZZ?@ojZZeP04ojZZeP;oZ[3L00?oZYk:
oj^Wdon[Ym<00on[Ym<2oj^`g003oj^Mb?n[Z=CoZjSD00;oZjSD00CoZk7MojbPbon/X<_o[:3;1?n[
[=P01?n[]>3o[:OBojbWd_n/Ym82oj^ag@03ojfScOn/[m[o[:oJ00?o[:oJ0_n[]n82ojf^f0CoZkKQ
00?oZ[[UojbfhOn/]^401?nZ^^D00onZ_>OoZk_Uoj^ki@02oj^ki@;oZ[cW00?oZk_UojZlionZ_>L0
0_nZ_>L2ojVmj0;oZ[gW6?nY_NP00ol0003oZKgXojVmj00FojVmj003ooooool0003ooooo02Gooooo
000Aooooo`?o00000ooooomLojVmj0GoZKcW0_nY^nL2ojRhi@CoZ;OT0_nX]^<00onV[McoYZcKojJ/
f`02ojJ/f`;o00000_nW[=/2ojR]f`03ojRUdon[Z]KoZj[F00;oZj[F00Co[:kIok2]eOn`[MGo/:gE
0ona/mX00onf]]Wo];_OokBkg`02okBkg`;o/[kS0ond`N@00ol0003oooooooooo`0booooo`?o0000
0oooool00onY/]ooZK?OojVcg`02ojVcg`;oZ[CQ00?oZJSEojZ[f?nZZmP00_nZZmP3ojZ_f`04ojVM
b_nZXm3oZZ?@ojZSd0?oZZ[F00?oZIG1ojZNb_nZW/X00_nZW/X3oj^Wd`03ojVB_On[WLSoZig800;o
Zig80_n[Z=@00on[Tkko[:3;ojbPb`03ojbPb`;oZjcH0_n/V/@3ojbWdP04oj^agOn]Xlgo[J?=ojfS
c@?o[:oJ00?o[j;;ojf^f?n][]P00on][]P2oj^fh@03ojj^f?n/]^7o[;KQ00;o[;KQ0_nZ^^D2ojbg
h@?oZk_U00?o[;SRoj^kiOn[^nD00_n[^nD2ojZli`;oZ[cV1?nZ_NL2ojVmj003ojZmionY_NSoZKgX
017oZKgX0_l0000IojVmj003ooooool0003ooooo02Cooooo000@ooooo`;o00000_oooomMojVmj0Ko
ZKcW0_nX^^H4ojRhi@;oZ;OT00?oYZkNojJ]g?nV[M`00_nV[M`3o`000004ojN/fol0003oYZ;AojJR
d@CoZ:GC0_n[Z]H00on]Y]3o/:gEok2]e@03ok2]e@04ok6cf_nf]]Wo][KIokJff@;o];_O00?o^<3P
okC1i?nd`N@00_nd`N@00onfaNGo0000ooooo`0booooo`;o00000_ooool5ojVbg`?oZK?O1?nYZ=D4
ojZ[f004ojZ_fonYWL[oZIg:ojVMbP?oZZ?@00CoZZ[FojVE`OnYUL7oZIG11?nZW/X00on[Ym?oZI:m
ojVB_@04oj^Mb004oj^Xe?n[TkkoZi>noj^C_P?o[:3;00?o[8feojbJa?n/V/@00on/V/@00on/Ym;o
[YJnojfSc@04ojfSc@04ojb_f_n_X/_o[j;;ojnRb`?o[JkH00?o/J?:ojj^f?n^[]P00_n^[]P2ojbf
h@;o[k3I1?n/]n401?n[^nGo[;SRojbhh_n/^>82oj^ki@;o[;[S1?nZ_>H2ojZmi`03ojZlionZ_NOo
Z[gW00;oZ[gW3onY_NP3o`000003ojVmj?l0003oZKgX01WoZKgX00?o0000ooooooooool08oooool0
013ooooo00?o0000ojVmj?nY_NP0GonY_NP2ojVli`;oZK_V1?nX^^H2ojRhi@03ojJah?nV[]koYZkN
00;oYZkN0ol00002ojJ/f`04ojBPdOnVX]7oYZ;Ao`0000;oYZ;A0_nXYM<00onZWl_o[JK@ojfVd002
ojfVd0?o/:gE00?o]JoCokJffOnf]]T00_nf]]T01Ond^moo^<3PokS0h?nh`>3o]<7T00Co]/GU00?o
0000ooooooooool0<?ooool00ol0003oZ;?QojVbg`07ojVbg`03ojVcgonXY]CoZ:KD00CoZJSE0_nZ
ZmP00onXVLKoZIg:ojVMbP02ojVMbP;oZZ?@00?oZ8jkojVE`OnYUL400_nYUL43ojZNbP03ojR9/onY
T[goZI:m00;oZI:m0_n[WLP00onZR;;oZi>noj^C_P03oj^C_P04ojbPbon/SKGo[8feojb=]@Co[9[4
0on^U[h3ojfSc@03ok2E^on_X/_o[j;;00?o[j;;00Co[JkHok6Sb_naXl[o/J?:0_n^[]P00onbY/co
[k3Iojn`f@03ojn`f@;o[;OQ00Go[k?Kojbhh_n/^>;o[;SRojnfgP05ojbjh`;oZ[cV00?o[;_UojZl
ionZ_>L00_nZ_>L4ojZmi`_oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX01SoZKgX00?o0000oooo
ooooool08_ooool0013ooooo00?o0000ojVmj?nY_NP0G_nY_NP2ojVli`CoZK_V0_nX^^H00onW]>;o
Y[7PojJah002ojJah0?o00000_nV[M`00onSWm;oY:3AojBPd@02ojBPd@;oYZ;A00?o0000ojJRdOnX
YM<00onZWl/4ojfVd004ok2]eOne[m?o]JoCokF_d`;o][KI00Co_;gJokS0h?nh`>3o^<3P0_nla^83
okK5i@03okK7iol0003ooooo037ooooo00?o0000ojRchOnX/n401_nY/]l2ojRWeP?oZ:KD0_nYZ=D0
0onWUlKoZ9W6ojRIaP02ojRIaP?oZIg:1?nXS[/4ojVE`@03ojZNb_nXRK?oZ8Vc00CoZI:m00CoZig8
ojZ8/_nZR;;oZXRb1?n[Tkh4ojb=]@?o[9[400?o[XZ`ojjF__n^U[h00_n^U[h01?n]Xlgo/9Fkok2E
^on`UK/3ojnRb`03ok>G^_naXl[o/J?:00;o/J?:00Co[ZkHok:Vc?nbY/co/ZK<0on_/=T00ondZm3o
[k?Kojncf`02ojncf`04ojbhh_n_]]ko[kKNojnfgP?o[;[S00?o[kWQojbkiOn/^nD00_n/^nD2ojZl
i`;oZkcV1?nZ_NL2ojVmj003ojZmionY_NSoZKgX00;oZKgX0ol00009ojVmj003o`000?nY_NSoZKgX
01OoZKgX00?o0000ooooooooool08_ooool0013ooooo00?o0000oooooonY_NP0FonY_NP6ojVli`;o
ZK_V00?oYkKTojNdh_nW]>800_nW]>83o`0000;oYZkN00?oXZ7Doj>Od_nSWm800_nSWm84ojBPd@;o
YZ;A00?o0000ojZObonZWl/00onZWl/2ojfVd005ok>Vc?ne[m?o]JoCokF_donm]]<01?nl_MX00onh
`>3o_<KRokc6hP02okc6hP05okK5iOnfanOo]/OWokK7iol00000<Oooool01?l0003oZ;?QojRchOnX
/n42ojVbg`03ojNYf?nXYmKoZ:OF00?oZ:OF00?oZ:KDojFHb?nWUlH00onWUlH4ojRIaP03ojVMb_nV
R[OoYXZg00?oZ8jk0onYUL400onWPjgoZ8VcojR9/`02ojR9/`;oZI:m00?oZ86YojZ8/_nZR;800_nZ
R;83oj^C_P;oZh>Z1?n/SKD01?n/V/Co[XZ`ojj:/?n^R[03ojjF_PGo/9Fk00Co[j;;ok>G^_ncUk[o
/iNj0_naXlX00onfVkgo/ZK<ok:Vc003ok:Vc004ojn`fOndZm3o]:_@okB[d0;o[k?K0_nd/MD4ojnf
gP04ojbjhon_^N7o[kWQojnih@;o[;_U0_n]^n@4oj^liP;oZ[gW00?oZkgWojZmionZ_NL00_nZ_NL3
o`0000goZKgX00?o0000ojVmj?nY_NP05onY_NP00ol0003oooooooooo`0Qooooo`003oooool01?l0
003ooooooooooooooomJojVmj0KoZKcW00?oZ;WUojNfi?nW]^@00_nW]^@3o`0000?oXZCG1?nRXM@4
oj>OdP;oY:3A00GoXiC6ojJIb?nVVLSo0000ojJIb003ojZOb`03ojjMaOncY/co/jK<00;o/jK<00Co
]JoCokffdonm]]?o_KKC0_nl_MX3ol;6g@;o_<KR00Oo_L_UokK7ionfanOo]/OWokC7j?oooooo0000
02oooooo00Co0000ooooooooooooZ;?Q0_nV[Md3ojNYf0?oZ:OF00CoY9_=ojFHb?nUV<SoYIS80onW
UlH3ojRIaP04ojF8]_nVR[OoYXZgojJ:]`CoZ8jk00?oZIG1ojN3[OnWPjd01?nXRK<01?nYT[goZ86Y
ojR1ZOnXPJT4ojZ8/P04oj^C__n[Pj[oZh>Zoj^3ZPCo[8fe1?n^R[02ojjF_P;o/HZ]1?n`UK/4ok>G
^P04ok6Sb_nfVkgo]Y^mokJK_@?o/ZK<00Go^J;2okB[d?ndZm3o]:_@ok^[b@05okBae@;o[kKN00Co
];KKojnihOn_^N7o[kWQ0_nb^^04ojfki0;oZkcV00?o[;gVoj^mion[_NL00_n[_NL3o`000003ojZm
ionY_NSoZKgX00goZKgX00?o0000ojVmj?nY_NP05onY_NP00ooooooo0000ooooo`0Qooooo`003ooo
ool00ol0003oooooooooo`02oooooe[oZKgX0_nY_>L00onX^^KoZ;WUojRii@02ojRii@?o00001?nS
Z=X3oj:Te`CoXZ7D0_nSWm800onOTLGoXiC6oj>DaP02oj>DaP;oYYW800?o0000ojJIb?nZWl/00on^
WLD2ok>Vc003ok^/bonm]]?o_KKC00;o_KKC00?o_;gJol;6gOo2a]d00_o2a]d4okg;i@05okK7iond
anSo]<OXokC7j?l00000;oooool01?l0003oooooooooooooool3ojJ]g@?oYjWH00?oZ:OFojBKcOnT
Vld00onUV<P4ojNGaP03ojRIa_nUR;KoYHRf00?oYXZg0onXS[/00onUOj[oYh>]ojN3[@02ojN3[@?o
Z8Vc1?nXPJT4ojZ8/PCoZh>Z0on/SKD00on^PZGo[XZ`ojj:/002ojj:/004ojjF__naRZgo/HZ]ok6:
[@?o/9Fk00?o]8f]ok>G^_ncUkX00_ncUkX5okJK_@05ok:Vc?niX/;o^J;2okVR`_ndZm000onkZlT3
okBae@;o^k?B0ond]]/00on_^N7o/[[Pok:jh002ok:jh0;o[K_T00?o[kgTojbmi_n/_NH00_n/_NH3
o`000003oj^mionZ_NOoZ[gW00;oZ[gW0_nY_NP00onZ_NSoZKgXojVmj00:ojVmj003o`000?nY_NSo
ZKgX01OoZKgX00?o0000ooooooooool08?ooool000oooooo00?o0000ooooooooool00ooooomHojVm
j0;oZKcW0onX^^H3o`0000CoY:gN1?nSZ=X3oj:Te`;oXZ7D00CoWI76oinAaOnOTLGoWi751?nSU<H2
ojJIb003ojVD`?l0003o[Yg500?o[Yg500Co/jK<ok^/bonk[<_o^jc;0_nm]]<2olO2e@?o`/KM0_o6
cn42okg;i@;o_<kX0_ndanP2ok76j@03o`000?oooooooooo02cooooo00?o0000ooooooooool00_oo
ool00onV[MgoWjSLoj6Qe002oj6Qe0CoY9_=0onUV<P2ojNGaP03oj>9^OnUR;KoYHRf00;oYHRf0onV
R[L00onXS[_oYGnZojEoZP04ojN3[@;oZ8Vc00?oYgbTojR1ZOnXPJT00_nXPJT3ojZ8/P03ojYmX_n[
Pj[oZh>Z00?oZh>Z00?o[8feojj2YOn^PZD01?n^R[05ok6:[@04ok2E^ondSJgo]8f]okB=[@;o/iNj
0_niTk04okJK_@Co^J;21OnkZlT00ond/MGo^k?Bok^cdP02ok^cdP03okBffoni^][o^K[J00?o/[[P
00?o]KkQojnmi?n__N@00_n__N@3o`000003ojfni_n[_NOoZkgW00;oZkgW0onZ_NL4ojZmj0coZKgX
00?o0000ojVmj?nY_NP05_nY_NP00ooooooo0000ooooo`0Pooooo`003oooool00ol0003ooooooooo
o`04oooooeCoZKgX1OnY_>L3o`000004ojJehonU/N7oYK7QojFah@CoY:gN0_nSZ=X01?nLUlgoW9;9
oibBbOnLT/T3oifAaPCoWi750_nSU<H00onSS;coZIC0ojVD`002ojVD`004o`000?n^WLGo[Yg5ojjM
a@Co^jc;00?o_KKColO2eOo7`]D00_o7`]D01?o2a]goa/oQolK?hOo7e^D3okc>j003okW=jOnaa^Wo
/LKY00?o/LKY00?o0000ooooooooool0:oooool00ol0003oooooooooo`02ooooo`?oWjSL0onQXM@3
ojBKc@;oYIS800CoWhbooj>9^OnSRKWoXhVi1?nUR;H2ojJ:]`04ojAmZ_nUOj[oYGnZojEoZPCoYh>]
00CoZ8VcojMlY?nWO:CoYgbT1?nXPJT00onZR;;oZWfRojYmXP05oj^3ZPCo[X:U0on^R[000onaPjCo
/HZ]ok6:[@02ok6:[@Co]8f]00Co/iNjokVC/?niTk3o^I>`0onfVkd2okjL]P?o^J;200Co`ZNnok^[
bOnkZlWo^j_90_o4//T3ok^cdP03ol:le?ni^][o^K[J00;o^K[J00Co/[[PokFnhOne_^7o]KkQ0ol0
00000ona_nGo[KkVojfniP02ojfniP;oZkgW00?oZkkWojZmionZ_NL00_nZ_NL5ojZmj0_oZKgX00?o
0000ojVmj?nY_NP05_nY_NP00ooooooo0000ooooo`0Oooooo`003oooool00ol0003oooooooooo`05
oooooe;oZKgX1?nY_>L2o`000003ojNhiOnV]N?oY[GS00;oY[GS0onU/N42ojB]gP04oifLd_nLUlgo
W9O=oibGc@CoW9;90onMTLH3oinAa@04oj>Da_nSS;coXhbloj><_0?oZIC000?o0000ojjMaOn^WLD0
0_ngXL<2ok^/b`;oakW<0oo7`]D2olo@f@05olK?hOo7e^GoamKUolOFiOnlc^P00onicNT2ok76j@;o
[lCY00?o0000ooooooooool0:oooool00ol0003oooooooooo`03ooooo`?oWjSL0onQXM@00onTVlgo
Vi;:oin<_`03oin<_`?oXhVi0onUR;H00onVR[OoY7fZojAmZP04ojEoZP?oYh>]1?nWO:@4ojR1Z@Co
ZWfR1?n[PjX4ojj2Y@;o[XZ`0_naPj@4ok6:[@Co]8f]1OniTk000onfVkgo_YbfokjL]P02okjL]P05
okVR`_o2Ykko`ZNnol:W__nkZlT01?o4//T01?nk/m;o`[cDol:le?o2_=@2okVjfP;o_L;N00Co]KkQ
o`000?l0003o]/?T1?na_nD2ojfniP03ojfoion[_^OoZkkW00;oZkkW0_nZ_NL3ojZnj0?oZ[gX2onY
_NP00ol0003oZKgXojVmj00GojVmj003o`000?oooooooooo01kooooo000?ooooo`03o`000?oooooo
oooo00KoooooD_nY_NP3o`0000CoYkSU0_nV]N<01?nRZ]goWj?HoinSf?nOXmP4oifLdP?oW9O=0onL
T/T3oifAaP;oWi7500?oWXNjoj><_?nSS;`00_nSS;`4ojVD`005o`000?ngXL?o]j73okNQ`onk[</0
1?o7^L`01?o7`]Gocm3Iolo@fOo?d=T3olOFi@;oa=SX0_nicNT2okC:jPCo[lCY00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`03ooooo`;oWjSL00CoT:GSoiFKeonEVmOoUI_G0onKT/X3oin<
_`?oXhVi0_nUR;H01?nQOZgoY7fZojAmZ_nTOJX4ojEoZP;oYh>]00?oYWVQojMlY?nWO:@00_nWO:@4
ojR1Z@CoZWfR0on[PjX00on^OIoo[X:Uojj2Y@02ojj2Y@04ojj:/?naPjCo/H>Tok63Y0?o/HZ]00?o
]hRTokB=[OndSJd00_ndSJd00onmSjOo^I>`okVC/002okVC/0Go_Ybf1?o2Ykh5olBbb@Co`[cD00?o
b<[Lokg2g_l000000_l000001?ne_^7o]/?TokK3i?nf`n@2ok6oi@03ok32ion]_nOo[KoW00;o[KoW
0_n[_^L3oj^nj0?oZ[kX1?nZ_NP;ojVmj003o`000?nY_NSoZKgX01OoZKgX00?o0000ooooooooool0
7Oooool000kooooo00?o0000ooooooooool02?oooom>ojVmj0?o00001?nX^^H2ojNhi@03ojB`hOnR
Z]goXZ[M00;oXZ[M0onOXmP3oifLdP?oW9O=0_nLT/T01?nFP[_oVH>joiV3^_nIPkX4oij7^P?oXhbl
0onYU<000on`U[co]j73o`000002okNQ``GoakW<0oo?d=T2omCLgP03olOFiOo4f>Soa=SX00;o_]C[
1?ndb^X2ojo4j@;o[L7Y00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`?oT:GS
0_nEVmL3oi^BbP?oWhbo0onSRKT00onUR;KoXGj]oj5n[@04ojAmZP?oYGnZ00CoYh>]ojIiXOnVNJ7o
YWVQ0onWO:@3ojR1Z@03ojYjW_nZOJ;oZWfR00;oZWfR0_n[PjX2ojimW`Co[X:U1OnaPj@01?naRZgo
]hRTokN8Y?ngR:@2okB=[@;o_HnW1?niTk000oo4VZco_YbfokjL]P02okjL]PCo`ZNn00CockK1olBb
bOo4//Woa;;90_o>`ll2ol:le0?o00000_nm`]h01Onnb^Co]/?TokK3i?nf`nCo]LOX00Co/<;W0_n]
_nL2ojg0j0?oZkkX00?oZkoXojZnj?nZ_^P00_nZ_^P3ojZmj0coZKgX00?o0000ojVmj?nY_NP05onY
_NP00ol0003oooooooooo`0Looooo`003_ooool00ol0003oooooooooo`09oooood[oZKgX0ol00004
ojVli`;oZ;[V0_nV]N@3ojB`h@CoXZ[M0_nOXmP2oifLdP04oiB8`onDQ;koU8BnoiB4_PCoUX:k0onI
PkX3oij7^PCoXhbl00SoZIC0ok2F_?n`U[co/9JlokNQ`ol0003o]j73ol>]``?oakW<0_oEbm000oo?
d=Woe=cNomCLgP02om?Th`03olCHj?nne>_o_]C[00;o_]C[0_ndb^X2ok36jP;o[L7Y00?oZkoXo`00
0?ooool0:Oooool00ol0003oooooooooo`06ooooo`?oT:GS0_nEVmL2oi^BbPCoWhbo00?oXhVioib0
]?nQOZd00onQOZd3ojAmZP?oYGnZ1?nVNJ44ojMlY003ojR1ZOnZNYkoZWZN00CoZWfR00?oZh>Zojim
Won^OIl00_n^OIl3ojj2Y@Go/H>T00Go/HZ]okN8Y?ngR:Co]hRTokB=[@03okf?Y`?o^I>`0_o4VZ`3
okjL]P;objNe0_o2Ykh3olnf`@03olBbbOo>`looc/??00?o00000_o8b]`00oo6e^Ko_/[Tokk:i002
okk:i004okK3i?neanSo]LOXokG7j0;o/<;W0_n_`nP4ojg0j004oj^nj?n[_nSoZkoXoj^oj0?oZ[kX
1?nZ_NP<ojVmj003o`000?nY_NSoZKgX01KoZKgX00?o0000ooooooooool07?ooool000kooooo00?o
0000ooooooooool02ooooom5ojVmj0?o000000?oZKgXojVlionY_>L00onY_>L2ojNiiPCoY[GT0onT
/>42oj:Zg@03oiVHdOnFSl[oUXo:00CoU8S30onDQ;h3oiJ2^`?oVH>j1?nNQkX2oj><_003ojR;]on`
U[co/9Jl00?o/9Jl00Go0000ol>]`oo3[L?o`jg3olNic003omG;d003omoOe?oDg=kodnCS00;odnCS
0_o<hnP2okkDj`05okO?jon`a^[o/<KZok36j_n]`nT01?n[_nP00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Oooooo0_mZXO42og:Fi@?oVi;:0_nOS;l00onCQL7oW82doib0]004oj5n[@?o
Y7fZ0_nUOjX00onUN:;oYWVQojIiX@02ojIiX@CoYgbT00CoZ86YojYjW_nZNYkoZWZN0onZOJ85ojim
W`;o[X:U0_ncP9h4ok63Y0Co]hRT00?o]8f]okf?YonmSjL00_nmSjL01?niTk3oa9Z/olBJ[?o4VZ`2
okjL]P?objNe00?o`ZNnolnf`Oo?]/400_o?]/43o`0000?oe=SK00Cob<[LolKFi_o6e^Koa]KV0_nn
b^@3ok[?jP03okG7j?naan[o/LOZ00Co[l?X0_n]`>P2ojc0j0;oZkoX1OnZ_^P2ojZmj0goZKgX00?o
0000ojVmj?nY_NP05onY_NP00ol0003oooooooooo`0Kooooo`003_ooool00ol0003oooooooooo`0<
oooood7oZKgX0ol00005ojVmj003ojVlionX^nOoZ;_W00CoYkWV0_nV]N@01?nQZmkoWJ;HoifRf?nM
X]P3oiVHd@?oUXo:0onDR<<3oiB4_P?oUX:k0onIPkX3oij7^P03oj22/onXRkOoZ8^g00;oZ8^g1?n`
U[`01?o3[L?o0000ol>]`oo3[L<3omG;d0;ogmoD0_oRkMP01?oCi>?oc>?XolcSj?o3gN`4okO?j`04
ok36j_n]`nWo[L?Yojg3j@;oZkoX00?oZ[kXooooool00000:?ooool00ol0003oooooooooo`08oooo
o`;oJZ7a00CoLYKUohB<don4S=?oQ8cC0onCQL43oib0]0?oXGj]0onTOJX01?nUOj[oYGRRojEhX_nU
N:83ojIiX@CoYgbT1?nZNYh3ojYmXPGo[WfO00Co[X:Uok>0W_ncP9ko/h2N1?naPj@4okN8Y0Go_HnW
00?o^I>`olBJ[?o4VZ`00_o4VZ`01?nnW;KobjNeol^W]Oo;YkD2olnf`@?o000000?ogM3<olk3cooD
f=/00_oDf=/01?o=j>Woa]KVolKFi_o6e^H3okgJkP;o^/oZ00?o/lg]ok77j_naanX00_naanX2ojo3
j0;o[L;Y0_n/`>P2oj^oj@OoZ[kX3onY_NP00ol0003oZKgXojVmj00FojVmj003ooooool0003ooooo
01_ooooo000>ooooo`03o`000?oooooooooo00gooooo?OnY_NP3o`0000OoZKgX00?oZKcWojRkionX
^nL00_nX^nL2ojNiiP03ojBah_nQZmkoXJ_N00;oXJ_N0onMX]P3oiVHd@;oUXo:0onDR<<3oiB4_PCo
UX:k0onIPkX01?nNQk[oX8:coj22/onPP[<3ojR;]`?o/9Jl0_nlWk/01Oo3[L?o0000omC1aooD`LOo
eL_@00;ogmoD0ooRkMP00ooLlmkoc>?Xol?Mk002ol?Mk0;o]lo[0_nbb>/2ojg3j@03oj_0jOnZ_^So
Z[kX00;oZ[kX00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o78SY00CoLYKU
ohB<don4S=?oQ8cC0_nCQL43oib0]0?oXGj]0onTOJX4ojEhXP?oYWVQ1?nWO:@4ojYjWP;oZWfR0_n^
Ni/4ojimW`04ojj2YOncP9ko/h2Nok>0WP?o/H>T00?o^HJNokN8Y?ngR:@00_ngR:@5okf?Y`Goa9Z/
0oo;YkD3o`0000;ockK10_oMd<`2omo_f`05omCHfoo=j>WocNSYolgXjOo6e^H00onmf^h00oncdo7o
/lg]ok?=k@02ok?=k@;o/LOZ0_n^aN/2ojg2j@;oZl3Y1?n[_nT7ojZnj0ooZKgX00?o0000ojVmj?nY
_NP05_nY_NP00ol0003oooooooooo`0Jooooo`003_ooool00ol0003oooooooooo`0>ooooocWoZKgX
0ol00008ojVmj0CoZKcW0_nX^nL2ojJgi@?oY;7R0onQZmh3oifRf0?oVISA0onFSlX3oiB8``?oU8Bn
0_nFP[/01?nCMk3oVG^aoiUk/OnINk44oj22/`CoZ8^g00Ko/9JlokbO^onlWk_o_9nkol>]`ol00002
omC1a`03onKJbOoOgmCoh^gH00;oh^gH00?og??Nom;_iooBknL00_o3gN`2ok[Ck@;o//S[00?o[/?Z
oj_0jOn[`>T00_n[`>T3ojZnj003ooooool0003ooooo02Kooooo00?o0000ooooooooool02_ooool2
oab8j@03o`1/f_n4S=?oQ8cC00?oThG10_nLP;@4oj5n[@;oY7fZ1?nUN:84ojIiX@;oYgbT00?oZGRL
ojYjW_nZNYh00_nZNYh01?nZOJ;o[W^KojikVon^Ni/4ojimW`Co/h2N0onaPj@01?niQYko]hRTokN8
Y?ngR:@2ol6?XPCo_HnW00?obibWolBJ[?o4VZ`00_o4VZ`3o`0000?og;nl00?ockK1omg@c?oMd<`0
0ooOkm/2olOki`05olgXjOnmio?o_NOcokgWlonmf^h00oncdo42ok?=k@?o[/O]00?o[/G[oj_2j_n[
`^X01?n[`>T2oj^oj@OoZ[kX4?nY_NP00ol0003oZKgXojVmj00FojVmj003ooooool0003ooooo01[o
oooo000=ooooo`03o`000?oooooooooo013ooooo=OnY_NP3o`0000coZKgX0_nY_>L2ojNjiPCoY[OU
00?oY;7RoibTf_nGV=<00_nGV=<3oi6<bP?oSH;20on<N[X3ohaf]@?oSgFb0onCMk04oiUk/@?oX8:c
0onXRkL00onbTKGo_9nkokbO^`02okbO^`;oe<7700?o0000omC1aooVf/T00_o]l<P01OoRkMSog??N
om;_iooBknOoanC]00?o^]?]00?o/l[[ojk3j_n^`nX00_n^`nX2oj_0j@GoZ[kX00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0=ooooo`04o`1/c?l0K=[o7VoOoai_g`;oThG10onLP;@3oj5n
[@03ojAmZ_nQN:GoXGRU00?oYGRR1?nVNJ400onWO:CoZGRLojUhW004ojYjWP04ojYmX_n^Ni_o[W^K
ojikV`Co[WfO1OncP9h01?naPjCo^HJNokV6W_niQYh2okN8Y0;o`HnR0onmSjL2ol^LY`06olBJ[?l0
003o0000o`000?oD[:oobjNe1?oL_k`00oo/ilWogM3<omo_f`02omo_f`;oao_W0_nalOD2okgWl`;o
/=[e0_ncdo43ojg:k`;o[/O]00?oZl;[oj_2j_n[`^X00_n[`^X2oj_0j@03ojZojOnZ_^SoZ[kX00Co
Z[kX00?oZKkXojVmj?nY_NP04OnY_NP00ol0003oZKgXojVmj00FojVmj003o`000?oooooooooo01Wo
oooo000=ooooo`03o`000?oooooooooo013ooooo<onY_NP2o`0000coZKgX00?oZKcXojRkionX^nL0
0_nX^nL3ojNjiP;oY[OU00CoXJgPoibTf_nLY=[oW:CJ0onGV=<3oi6<bP?oSH;20on<N[X3ohaf]@?o
SgFb0onCMk03oiUk/@CoX8:c00?oZ8^gok:A]OnbTKD01?nlWk/01Oo>/[koe<77omC1aol0003oi][9
00;okO3800?oio_7omkmdOoBknL00oo7i>d01?njdngo/l[[ok?:joncb^/2ojk3jP03ojc0jOnZ_^So
Z[kX00CoZ[kX0_nY_NP00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00oooooo00Co087K
oai_gomRNMCoHWWD0onLP;@2oj5n[@04oiUi[OnQN:GoXGRUoj5hY@?oYGRR1?nVNJ43ojUhW0CoZWZN
1?n^Ni/3ojimW`03okAoVoncP9ko/h2N00?o/h2N00Go/H>TokV6W_niQYko^HJNokN8Y003ol6?XP?o
_HnW00CobibWo`000?l0003oa9Z/0ooD[:l5ombo_004oncWbOo@olSod?o8omo_f`;oao_W0_nalOD3
oj[Mn@04ok3JmOn[c?7oZlcaoj_<l@;o[L[_00?oZ/?/oj_2jon[`^/00_n[`^/2oj_2jPGoZ[oY0_nZ
_^P5ojVnj1?oZKgX00?o0000ojVmj?nY_NP05_nY_NP00ol0003oooooooooo`0Hooooo`003Oooool0
0ol0003oooooooooo`0AooooobooZKgX0ol0000<ojVmj0CoZKcX0_nX^nL01?nW^NKoY;CTojBdi?nT
]>@4oj6]h0?oW:CJ0onGV=<2oi6<bP?oSH;20on<N[X3ohaf]@?oSgFb0onCMk03oiUk/@?oX8:c00?o
YhF`ok:A]OnbTKD00_nbTKD2okbO^`;oc[:n00Koe<77onKJbOoVf/Wo0000ong`b?oWnlL2omkmd@03
omCih_o7i>goanC]00;o^mK^0_ncb^/2ojk4jP?o[<3Y1?nZ_^P4ojVmj003o`000?oooooooooo02;o
oooo00?o0000ooooooooool04Oooool00olNKmooHWWDohUj_002ohUj_0?oVGV]0onQN:D4ojEhXP?o
YWVQ1?nYN9`3ojYjWPCo[W^K0on^OIl00ondOi_o/h2Nok>0WP03ok>0WPCo^HJN00?o]hRTol6?X_o1
Sj800_o1Sj83o`0000;obibW00Goa9Z/omB/[ooD[:ooe:b_oncB^P03ombo_0;ok>O900Cod?o8oiG_
a_nEklKoTno^0onQgO`2oj[Mn@;oZ<_b0_n[c?400onY`ncoZ/?/oj[3k002oj[3k0;oZl;[1onZ_nT7
ojVnj1GoZKgX00?o0000ojVmj?nY_NP05_nY_NP00ol0003oooooooooo`0Gooooo`003Oooool00ol0
003oooooooooo`0Booooob_oZKgX0ol0000@ojVmj0;oZKcX0_nX^nL3ojNiiP?oY;CT0_nQ[N001?nG
WMSoSho?ohn?con?Sll3ohR1a0?oQ7Fk0_n=P/83ohaj^P?oS7Je0on?MK83oi=g/0CoVG^a00?oX8:c
ojN5/?nWQK001?nbTKD01?nlWk_oc[:noljb__o>/[h2onG?`@03onKJbOl0003oio_700;og_gA00?o
e?WRolSYkOo8jNd00_nke^h2ok?;k0Co[/CZ00?o[<3YojZnj?nZ_^P01?nZ_^P3ojVmj003o`000?oo
oooooooo02;ooooo00?o0000ooooooooool04_ooool2of9ie0;oRGZl0onINJd3oj5hY@CoYGRR0_nV
NJ400onXMigoZGRLojUhW002ojUhW0;oZWZN00?o[g^KojikVon^Ni/00on^Ni/00on^OIoo]7nKokAo
V`05ok>0WPCo^HJN00?o]hRTol6?X_l000000_l000000onmSjOobibWol^LY`02ol^LY`?oe:b_0oo/
d[X01OoL_kcok>O9oncWbOl0003oK=kQ00?oV]Wm0_nQgO`2ojK:lP;oZ<_b0_nX`^`3ojW3k0;oZ/?/
0_nY_nT5ojZoj@OoZKkX6?nY_NP00ol0003oZKgXojVmj00FojVmj003o`000?oooooooooo01Oooooo
000=ooooo`03o`000?oooooooooo01?ooooo9onY_NP3o`0001;oZKgX0_nY_>L4ojRki`03ojNii_nS
/^?oWJWO00?oWJWO0onGWMP2ohn?c`?oR8740on4MK/3oh9^/`?oS7Zj0on<M[D3ohme/P?oTgN`0_nI
Nk400onMNjcoYhF`ojN5/002ojN5/0?o/Y6e1?o>/[h2onG?`@05ooC/^oo[mj_o0000omkmdOoDnN80
0oo8jNd00onkf>ko/l_/ok?;k002ok?;k0;o[/CZ0_n[`>T3ojZnj0OoZKgX00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Cooooo`03of9ie?n9N[coRGZl00?oVGV]0onQN:D4ojEhXP03ojIi
XOnXMigoZ7NM00CoZGRL0_nZNYh00on_Ni_o[W^KojikV`03ojikV`04ojimWondOi_o]7nKokAoV`?o
/h2N00Co_8NLokV6W_niQYko^HJN0ol00003ol6?XPGobibW0ooD[:l3oncB^P;oh_^b0onGdod2oi[I
o@?oY<Ob00?oY/[bojS1k?nX`N`01?nX`^`00onY`ncoZKoYojVoj@04ojVoj@03ojZojOnY_^SoZKkX
00KoZKkX6onY_NP00ol0003oZKgXojVmj00FojVmj003o`000?oooooooooo01Kooooo000=ooooo`03
o`000?oooooooooo01Gooooo8_nY_NP3o`0001CoZKgX1?nY_>L2ojRki`04ojJgi_nS/^?oXk;Soj>b
h`CoWJWO0_nGWMP3ohn?c`?oR8740_n4MK/3oh9^/`?oPfZ^0on6JZ/3ohme/P?oTgN`00?oVG^aoiek
[?nMNj`01?nWQK02ok:A]@;o`j:g0_o>/[h3onG?`@04ooC/^oo[mj_of?NUo`0000;od_gM00Cob>W]
ok_Hk_nkf>ko^mS^0_ncbn`2ojk4jP;oZl3Y1OnZ_^P7ojVmj003o`000?oooooooooo023ooooo00?o
0000ooooooooool05?ooool3ohUj_0?oVGV]0onQN:D3ojEhXP?oZ7NM1?nYN9`00onZNYko[g^Kojmk
V`05ojikV`04ojimWondOi_o]7nKokAoV`?o/h2N00Go_8NLo`000?l0003o0000okV6WP05ol6?XPCo
bibW0_oR^Jh00ooD[:ook=:joncB^P02oncB^P03on;k/_nU`^koYL;^00CoY<C`0_nTao800onX`>_o
Z<7/ojS1k002ojS1k0;oZ<;/1onY_nT4ojVnj2;oZKgX00?o0000ojVmj?nY_NP05_nY_NP00ol0003o
ooooooooo`0Eooooo`003?ooool00ol0003oooooooooo`0GoooooakoZKgX0ol0000HojVmj0;oZKcW
00?oYk[WojJgi_nV]nH00_nV]nH3oj>bh`;oWJWO00CoTIOFohN6c?n7Q/coQhK<0_n?Sll3ohR1a0;o
Q7Fk0on2K[<3oh=Z[P?oQVZ[0on<KJX3oiAbZP?oWG^/1?nWQK000onbTKGo`j:gol>R]`02ol>R]`09
oljb__oUcl7oiLo1ooC/^oo[mj_of?NUom?m^ooBoMgo000000;oanc^0_nkf>h2ok;;k0;o[/CZ00?o
Zl3YojZnj?nZ_^P01?nZ_^P8ojVmj003o`000?oooooooooo01oooooo00?o0000ooooooooool05_oo
ool2ohUj_0?oVGV]0onQN:D2ojEhXP04ojAgX_nXMigoZ7NMojQgW@CoZGRL00?oZWZNojmkVon_Ni/0
1On^Ni/4okAoV`04ok>0W_l0003o0000o`0000?o^HJN0_o7Til3ol6?XP03omBSYOo;W:OobibW00;o
bibW0_oR^Jh01OoD[:ook=:joncB^_o/d[[oh_^b00CoYL;^0_nTa?000onX_n[oZ<3[ojS0j`02ojS0
j`;oZ<7/0_nY_^T5ojVoj@CoZKkX9_nY_NP00ol0003oZKgXojVmj00EojVmj003o`000?oooooooooo
01Gooooo000<ooooo`03o`000?oooooooooo01Sooooo6_nY_NP3o`0001[oZKgX0_nX_>L3ojNji`;o
Y[OV0_nQ/><2oiZVgP?oTIOF0on7Q/`2ogmg`0?oNFZf0on4MK/2oh9^/`?oPfZ^0on6JZ/3oha]ZP?o
U7:Z1?nMNj`3ojN5/0Go`j:g0_oUcl402?odk;_ojoN[omSgYOnbgWOo_o>Tom;mgOl0003oanc^0_nj
enl2ok;;k003ojg3j_n[`>WoZl3Y00;oZl3Y0onZ_^P;ojVmj003o`000?oooooooooo01kooooo00?o
0000ooooooooool05oooool01?l0B<SoVGV]oiUi[OnINJd3oj5hY@03ojEhX_nTMj;oY7NR00CoZ7NM
0onYN9`4ojmkV`Co[W^K0_ndOi/3o`000004ok>0W_nlQico_8NLokb7W0;o^HJN0_o7Til3ol6?XP;o
e:>U0_o;W:L3on:i[P;om_2`00Cok=:jojK0k?nV`>coY/3/0_nU`^h2ojRnj@?oZ;oZ0_nX`>/4ojVn
j@;oZKgX1OnY_^PYojVmj003o`000?nY_NSoZKgX01KoZKgX00?o0000ooooooooool05?ooool000co
oooo00?o0000ooooooooool06OoooolFojVmj0?o00007OnY_NP3ojRli`03ojNjionU]nGoYKOU00Co
XK3S0_nJY]h3oi6GeP;oQhK<0omoMl02ogUZ]P;oMf:^00CoQ7Fkoh9^/on2K[?oPVjc0_n3JZh3ohIZ
Z`?oS6fZ0onDLZX4oiek[0?oYhF`00?o]Y6aol>R]oo3X[L00_o3X[L01?oM_[[oiLo1ooC/^oo[mj/2
ok;NM`06olgofoo4jo3o^]O_o`000?njenoo/LW/1?n]`nX2oj_0j@GoZ[kX2onY_NP00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01Sooooo0omhLl02oj5hY@04oiUgZonTMj;oY7NRojAgXPCo
Z7NM0onYN9`4ojmkV`?o[W^K0ol00002okAoV`03ok>0W_nlQico_8NL00;o_8NL0_niQYh2olNCW`?o
`HnR0_oDXjD00oo;W:Ooh[V^on:i[P02on:i[P;om_2`0_nW_^X00onV`>coZ;kYojRnj@04ojRnj@04
ojRoj_nY_^SoZKkXojVnj0;oZKkY1OnY_NP2ojVnj2coZKgX00?o0000ojVmj?nY_NP05_nY_NP00ol0
003oooooooooo`0Cooooo`003?ooool00ol0003oooooooooo`0Joooooa?oZKgX0_l0000OojVmj003
ojRlionW^^OoYk[W00;oYk[W0onU]nD2oj6`h`03oiNSg_n<TmGoS9?E00?oOh3:0on7Q/`2ogmg`0;o
NFZf0omgHZh3oh9^/`?oPfZ^0_n6JZ/3oha]ZPCoU7:Z0onMNj`2ojN5/0;o]Y6a0oo3X[L2omfn^P05
ooKS]Oo/l9KoaN1dok;NMoo=om/00oo4jo001?njenoo0000ok79k?nabN`2ojg3jP03oj_0jOnZ_^So
Z[kX00CoZ[kX3?nY_NP00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00?o04S8
ogQc`?mhLl000onIMj/3ojAgXPCoZ7NM0_nYN9`00on^Nico[g^KojmkV`02ojmkV`04ojikVol0003o
0000okJ1V`Co]7nK00?o/h2Nokb7W?nlQi`00_nlQi`01?niQYkoai>OolNCWoo7Til2ol6?XP?oe:>U
00CobibWon:i[_oR^Jkoh[V^0oofl;000onW_^[oZKgXojVmj002ojRnj@GoZKgX0_nY_^PgojVmj003
o`000?nY_NSoZKgX01GoZKgX00?o0000ooooooooool04oooool000cooooo00?o0000ooooooooool0
7?ooool>ojVmj0?o00008?nY_NP3ojRli`;oYk[W00CoY;KVoin_honO[n?oWjoS1?nGXmh2ohbCe@;o
Oh3:0omdK[h2ogmg`0?oNFZf0_mgHZh2ogUOZ@04oh9^/on3JZkoPfZ^oh=Z[P?oQVZ[0on<KJX3oiAb
ZP?oWG^/00CoYhF`okJA/OnfTK7o]Y6a0_o3X[L3omfn^P03ooKS]Oo/l9Ko/]ig00;ob?kP0_o4jo02
okODk`03ok79k?l0003o[L;Z00CoZl3Y0_nZ_^P2ojVnj0koZKgX00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Iooooo`;oN7?00onIMj/4ojAgXP?oZ7NM0_nYN9`00on^Nico[g^KojmkV`03
o`000003ojikVonfPI_o]X6K00Co]7nK1OnlQi`00oniQYkoai>OolNCW`02olNCW`04ol6?X_oDXjGo
e:>UomBSY@Coh[V^0_ofl;15ojVmj003o`000?nY_NSoZKgX01GoZKgX00?o0000ooooooooool04_oo
ool000cooooo00?o0000ooooooooool07?ooool;ojVmj0?o00009?nY_NP00onX_>OoYk[WojNji`03
ojBfiP?oWjoS0onGXmh2ohbCe@?oOh3:0_mdK[h2ofeP/`03ogmg`?miJ[KoNFZf00;oMf:^0omiGjT3
oh=Z[P?oQVZ[0on<KJX3oiAbZP;oWG^/00?oZ8:/okJA/OnfTK400onfTK401_o3X[OogKjjomfn^_of
hkGok?2FolGPM0;ob?kP0_o0i_42okODk`;o[lO/00?o0000ojg2j_n]`^X00_n[`>T2ojZnj0;oZKkX
3onY_NP00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo0_mhLl03oiUgZ`CoY7NR
0onXMid00onYN9co[W^Lo`000002o`0000;o[g^K00Co[W^KokJ1VonfPI_o]X6K1?ndOi/5okb7W003
okV6W_o7Tiooai>O00;oai>O00Go`HnRomBSYOoDXjGoe:>UooCC[P02on:i[P;om_2`A_nY_NP00ol0
003oZKgXojVmj00EojVmj003o`000?oooooooooo01;ooooo000<ooooo`03o`000?oooooooooo01go
oooo1onY_NP3o`0002KoZKgX00?oZ;cWojNjionW^^L00_nW^^L3ojBfiP03oin_honDXmooQi7G00;o
Qi7G0omgO</2ogn0bP?oM6jn0_m]H;<2ogUZ]P?oMf:^0_miGjT3ogePYP?oQVZ[0on<KJX3oiAbZP04
oiek[?nXPZcoZ8:/ojR2[0Co]Y6a0_oM_[X2ooKS]@05onc`U_l0003oaO_XolGkj?o0i_400ondd>h0
1?n_anco[<7Yojc1jOl00003oj^oj@03ojZnj?nY_NSoZKgX017oZKgX00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Jooooo`;oN7?00onIMj/3ojAgXP;oZ7NM0ol000000on^Nico[g^Kojmk
V`02ojmkV`03ojikVonfPI_o]X6K00;o]X6K0_ndOi/00oo0Rigo_8NLokb7W003okb7W0Goai>O0ooD
XjD3ooCC[P03on:i[_nY_NSoZKgX04OoZKgX00?o0000ojVmj?nY_NP05OnY_NP00ol0003ooooooooo
o`0Aooooo`002oooool00ol0003oooooooooo`0Oooooo`?oZKgX0ol0000XojVmj0?oZ;cW0_nW^^L0
1?nS]^KoWJoToif_i?nM[n@3oiBSg`?oQi7G0_mgO</2ofUX_P?oM6jn0_m]H;<2of]HZ`03ogUZ]_mg
HZkoMf:^00;oNEnY0ommH:H3ohETY@?oS6fZ0_nDLZX00onJMZSoZ8:/ojR2[002ojR2[0Co]Y6a00?o
cZ^eomfn^_ofhkD00_o/l9H2olGkj0;o^moa0_ndd>h00on^aN_o[<7Yojc1j@02ojc1j@03o`000?n[
_nWoZ[kX01GoZKgX00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`;oN7?00onI
Mj/2ojAgXP?o000000?oZ7NMojikW?n^Ni`00_n^Ni`3ojmkV`Go]X6K0_ndOi/2ol2;W@Co_8NL1Oo7
Til3omBSY@?om=>^BonY_NP00ol0003oZKgXojVmj00EojVmj003o`000?oooooooooo013ooooo000;
ooooo`03o`000?oooooooooo01oooooo0ol0000/ojVmj003ojRlionV^^OoY[[W00?oXkKV0onM[n@3
oiBSg`;oQi7G0_mgO</3ofUX_P;oM6jn0_m]H;<3of]HZ`;oMf:^0omiGjT2ogePYP?oQFBU0on?K:H3
oiYfZ0CoZ8:/0onfTK42olj[]@05oo3D]OofhkGol^fBojgd^?o5nnP00_nkgo400onac>go[/G[ojk5
j`02ojk5j`;o[<7Y00?oZ[oXojZnj?l000000_nZ_^PDojVmj003o`000?oooooooooo01Wooooo00?o
0000ooooooooool07?ooool00omhLl3oVGN[oiUgZ`03o`000004ojAgX_nXMigoZ7NMojYlXPCo[W^L
0on_Ni/5okJ1V`;o]7nK0_o0Rid3okb7W003olnKXOo7Tiooai>O00;oai>O0_oQ/jL00ooDXjGom=>^
ooCC[P02ooCC[TcoZKgX00?o0000ojVmj?nY_NP05?nY_NP00ol0003oooooooooo`0@ooooo`002ooo
ool00ol0003oooooooooo`0Looooo`?o00000ooooolYojVmj0CoZ;cX0onV^^L00onS]^KoWK3Uoif`
i@03oi>Th@;oQ9;I0omaNlh2ogMlb`;oJFRn0_mOF;800omdK[koKF2cofeP/`02of]HZ`03ofeEY_mg
HZkoNEnY00;oNEnY0ommH:H2ohETY@?oSfbV1?nJMZP4ojR2[005okJA/Oo>ZkGocZ^eolj[]Oo`e;D0
0_obkI82ol;cl004ok_OlOnac>go/Lc]ok7<k@;o[/G[00?oZl3YojZoj?nZ_nP00_nZ_nP00ol0003o
Z[kXojVmj00EojVmj003o`000?oooooooooo01Sooooo00?o0000ooooooooool07?ooool3o`000005
oiUgZonTMj;oY7NRojAgX_nXMid00_nZO:84ojikW0;o[g^K00?o]hBMokJ1VonfPI/00onfPI/01?nd
Oi_o`8^Mol2;WOo0Rid3okb7W003olnKXOo7Tiooai>O00;oai>O0_oQ/jL01?oDXjGom=>^ooCC[_od
dji=ojVmj003o`000?nY_NSoZKgX01GoZKgX00?o0000ooooooooool03oooool000_ooooo00?o0000
ooooooooool06Oooool3o`0000Oooooo:OnY_NP2ojRlj0;oY[[W0_nS]nH4oif`i@?oTjCQ0_n4T]T2
og5kcP04oeiT`?mgO<_oJFRnofUX_P?oGeRb0_m]H;<2of]HZ`;oKEFV00?oMf:^ogUOZOmiGjT00omm
H:H3ohETY@?oSfbV0onJMZP4ojR2[0?ocZ^e0_o`e;D00oobkI;o`_?`ol;cl002okOGl@;o/Lc]0_n]
`nX3oj_0j@;oZ[oX0_nZ_^P00ol0003oZKgXojVmj00EojVmj003o`000?oooooooooo01Oooooo00?o
0000ooooooooool06Oooool3o`000004oooooom5K=CoAFcDodE/e0;oY7NR00CoW7jaojYlX_nZO:;o
ZWbR1?n^Ni`2ojmkV`03okN4WOnfPI_o]X6K00?o]X6K00Co]7nKol2;WOo0Rigo`8^M0onlQi`2olnK
X@;oai>O0ooQ/jL00ooDXjGom=>^ooCC[P1?ojVmj003o`000?nY_NSoZKgX01CoZKgX0_l0000@oooo
o`002oooool00ol0003oooooooooo`0Fooooo`?o00002ooooolWojVmj0;oZ;cX1?nV^^L2oj>giP;o
WK3U00CoTjOSoh>FgOn3U]goPiKM0_m]O]<2og5kcP;oGVC00omYJ;h2oemH/P03oe]>ZOm]H;?oJeR[
00;oJeR[0_m]EJH2ogUOZ@?oOF2V0on5I:D3ohm/YP?oVWJX1?nXPZ`3olj[]@04oo3D]OobkI;ol^fB
okcVl`;o]mOa0_n_an`2ojg3jP03oj^ojOnZ_^SoZ[kX00CoZ[kX0_nY_NP00ol0003oZKgXojVmj00D
ojVmj003o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool3o`0000Gooooo0_m5K=@3
oian/@?oZWbR1?n^Ni`00on_Ni_o]hBMokN4W@05okJ1V`04okAoVoo0Rigo`8^Mol2;W@;o_8NL0oo?
Vj42olNCW`?ohK>W0_oTki000ooddjkoZKgXojVmj01>ojVmj003o`000?nY_NSoZKgX01CoZKgX00?o
0000ooooooooool03_ooool000_ooooo00?o0000ooooooooool05?ooool2o`0000oooooo9OnY_NP4
ojRlj0;oY[[W00CoY;SWoijbi_nN/^KoW[;V0onCYn<3oh>Fg@05ofendomDHlGoE6?5og5kc_mNI<00
0_m@D;<00omYJ;koGeRboemH/P02oe]>Z@03ofeP/om[F:_oJeR[00;oKEFV0_mbEj@00omiGjWoOF2V
ogePYP03ohETY@?oSfbV1?nJMZP2ojR2[0;o_9J`00GocZ^eoo3D]Oo`e;Gol^fBokcVl`03ok;?k`03
ojo7k?n[`NWoZl7Y00?oZkoY0_nZ_^P6ojVmj003o`000?nY_NSoZKgX01?oZKgX00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Dooooo`;o00002Oooool01?m5K=CoW7jaoian/OnLO[44ojYl
XP?o[W^L00?o[g^KokN4WOngQ9d01OnfPI/5ol2;W@05okb7W?o?Vj7oci^QolnKXOo7Til01?oQ/jL2
onC_T5;oZKgX00?o0000ojVmj?nY_NP04_nY_NP00ooooooo0000ooooo`0?ooooo`002_ooool00ol0
003oooooooooo`0Booooo`?o00004_oooolUojVmj0;oZ;cX0_nW^nP3ojBhi`?oW[;V0_nCYn<3oh>F
g@;oKGkC0_mDHlD2oeiT`0;oD52c0_mOF;83oe]>Z@;oJeR[0_m]EJH3og9GY0;oOF2V0on5I:D3ohm/
YPCoVWJX00GoZ8:/okbF/?nlU[3o_9J`olj[]@02oo3D]@05oo;]T_nff_;o//o_ok;?kon]a>/01?n[
`NT00on[_nWoZ[kXojZnj007ojVmj003o`000?nY_NSoZKgX00goZKgX1_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01;ooooo0ol0000;ooooo`04odE/e?nLO[7oW7jaoian/@CoZWbR
0on^Ni`01?n_Ni_o]hBMokN4WOngQ9d4okJ1V`Go`8^M00Go_8NLolnKXOo?Vj7oci^QolNCW`03on6c
Y`;oi>n@DonY_NP00ol0003oZKgXojVmj00=ojVmj0Kooooo00?o0000ooooooooool03_ooool000[o
oooo00?o0000ooooooooool03oooool3o`0001Kooooo8_nY_NP4ojRlj003ojNkj?nT^NSoY;WX00?o
WkCW0_nEZnH3ohFLhP;oK8GJ0_m>J<d2oeASa@04oci;]omNI<3oD52coe1@/`?oGeRb0_mKCZT2of]H
Z`?oKEFV0_mbEj@2ogaMX`03ogePY_n5I:GoQFBU00CoSfbV0_nJMZP00onYPjco_9J`okbF/002okbF
/0;ogkff00?ol^fBokKJl_n_b>d01?n]a>/2oj_1j@GoZ[kX1onY_NP00ol0003oZKgXojVmj009ojVm
j0[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?ooooo`?o00003oooool00om5
K=CoW7jaoian/@04ojYlXP?o[W^L1?ngQ9d3okJ1V`03olFCX_o0Rigo`8^M00?o`8^M1?o?Vj44on6c
Y`03onC_T?nY_NSoZKgX05?oZKgX00?o0000ojVmj?nY_NP02OnY_NP:ooooo`03o`000?oooooooooo
00gooooo000:ooooo`03o`000?oooooooooo00cooooo0ol0000Jooooob;oZKgX0_nX_>P00onW^nSo
Y;WXojBij002ojBij0?oWkCW0_nEZnH3ohFLhP;oK8GJ0_m>J<d2oeASa@04oci;]om@D;?oD52codQ4
Z@;oGeRb0_mKCZT00omMBjCoJeR[ofeEYP02ofeEYP;oLUNT0omlGJ<3ohETY@?oSfbV00CoVWJXojV3
[?nYPjcoZH>/0onlU[02omnm]P04oo[[Won_b>go[lS]ojo8k@;o[LC[0_n[_nT2ojZnj003ojVnj?nY
_NSoZKgX00WoZKgX00?o0000ojVmj?nY_NP01OnY_NP=ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool03?ooool3o`0001;ooooo00CoAFcDoian/OnLO[7oW7ja0onZO:83ojikW0Co]hBM
0onfPI/00oo5Tj;o`8^Mol2;W@03ol2;W@Coci^Q00Com]V^on6cYooQ/jOoi>n@EonY_NP00ol0003o
ZKgXojVmj005ojVmj0gooooo00?o0000ooooooooool03Oooool000[ooooo00?o0000ooooooooool0
2Oooool3o`0001kooooo8?nY_NP2ojRlj0?oYk_X0_nT^NP01?nQ]nSoV;3WoiR`ionH/>L3ohVTiP;o
LY3Q0_m?M=P2odiXc@04obi:_OmDHlGo?T^goci;]`;oD52c00CoB4BYoemH/_mKCZWoFdjY0_mMBj@0
0om[F:_oKEFVofeEYP03og9GY0;oO5fS0on8IZD2ohm/YP03oiMcZ?nYPjcoZH>/00;oZH>/0_nlU[03
omnm]P03ok7?kon_b>go[lS]00;oZl7Z0_n[_nT00onZ_^SoZKkXojVnj002ojVnj0[oZKgX00?o0000
ojVmj?nY_NP00_nY_NP@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool3
o`0001Gooooo00CoAFcDoian/OnLO[7oW7ja0onZO:82ojikW003okJ:YongQ9go]hBM00;o]hBM0_nf
PI/2olFCXPGo`8^M0oo?Vj43ooKI[P03on6cYonY_NSoZKgX05KoZKgX00?o0000ojVmj?nY_NP00_nY
_NP@ooooo`03o`000?oooooooooo00gooooo000:ooooo`03o`000?oooooooooo00Kooooo0ol0000R
oooooaooZKgX0onX_>P01?nW^nSoYK[XojFjj?nU^^P2oj6gj0?oV;3W0on9Y>H2og:@h@;oCgCH00?o
CVS=obi:_Ol^B[d00_lnBkL2oe1@/`;oB4BY0_mKCZT3oee;Y0;oKEFV0ombEj@2ogaMX`?oR6JU0onG
LjP4ojV3[0;o_9J`0_oO_KH01Oojjioo[LC[ojg4jon]a>_oZl7Z00GoZ[kX0_nY_^P<ojVmj003o`00
0?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`?o0000
6Oooool3oian/@?oZWbR00?o[W^LokJ:YonfRZL01?ngQ9d2okJ1V`?oaI>R0oo0Rid01?oL[ZWoci^Q
olnKXOo?Vj43ooKI[U[oZKgX00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`00
2_ooool00ol0003oooooooooo`03ooooo`?o00009_oooolOojVmj0?oZ;cX0_nU^^P01?nS^NSoW;CY
oibdjOnL]>T2oi2/j@?oO9gX0_mKQ^<2odmdf007obEAaom>J<go;TZmobi:_OlnBkOo<3V[oe1@/`02
odQ4Z@?oFdjY0_mMBj@00omTCJ;oKEFVog9GY002og9GY0?oO5fS0_n8IZD4oiMcZ0CoZH>/00Co_9J`
omnm]_oO_KKo[/O]0_n]a>/00on[_nWoZ[kXojZnj003ojZnj0_oZKgX1Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool3o`0001kooooo00Co
W7jaojYlX_nZO:;oYYS70onfRZL4okN4W@03okJ1Voo5Tj;oaI>R00;oaI>R0oo0Rid2omb^Z@;oci^Q
0ooffJiFojVmj0Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`002Ooo
ool01?l0003oooooooooooooool3o`0002[ooooo7onY_NP00onX_>SoY[_XojJkj003oj>ij0?oW;CY
0_n@[>T3ogbMj0;oFhKS00?o:VCFodmdf?lUDLL00_l^B[d01_lnBkOo<3V[oc0iZom@D;?oB4BYodLo
Y0;oFdjY0_mMBj@2ofA=XP03ofeEY_mbEjCoLUNT00?oO5fS0on8IZD3oiMcZ0CoZH>/0_oO_KH00ooj
jiooZl7Zoj_1jP03oj^oj@04ojZnj?nY_^SoZKkXojVnj0SoZKgX2Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooooooo0ol0000Rooooo`03ojYlX_nV
V<OoYYS700Co]XZW0ongQ9d00onfPI_oaI>RolFCXP02olFCXP;o`8^M0ooL[ZT01?o?Vj7om]V^ooKI
[_offJiDojVmj0Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`002Ooo
ool4o`0002oooooo7?nY_NP2ojRlj0?oY[_X00?oXkWXoj2hjOnP^>T00_nG/^X3ohRYj`?oKI[[0_m1
P>D01_lZI=Ko9E77o`0//_l^B[go4Rn]oci;]`;o<3V[0_m8A:T01?m7?jCoFdjYoee;Y?mMBj@3ofA=
XP;oLUNT0omlGJ<3ohQVY@?oUg>X1?nYPj`01?o7XkCogkffoo[[Won[`NX5ojZnj0;oZKkX1_nY_NP<
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool4o`0002Gooooo0onVV<L4
okJ:Y`?o]hBM1Oo5Tj82ol2;W@?og:jY00?oci^QooKI[_offJh0D_nY_NP<ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03Oooool000Wooooo0_l0000aoooooacoZKgX00?oZ;cXojNl
j?nW_>P00onU^nP3oj2hj@;oUk;Z0on8ZN/3offJj`07od60iOl0E]7o03Nmo`0g_Ol0;;;o;TZmoci;
]`02oc0iZ`;oB4BY00CoAcnToe]>ZOmMBjCoGD^T0omTCJ800om_E:?oLUNTog9GY002ogaMX`?oR6JU
1?nGLjP2ojV3[0;oaj>d00?om]jcojZojOnZ_^P01?nZ_^P7ojVmj0oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Cooooo`;o0000:?ooool2ojJHa`Co]XZW0ongQ9d5olFCXP03ol2;
WOoL[ZWog:jY00;og:jY00?oci^QooKI[_offJh0D?nY_NP?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03?ooool000_ooooo00?o0000ooooooooool0;ooooolJojVmj003ojRmj?nW
_>SoYkcX00;oYkcX00?oYK_Xoj>jjOnS^^T00onM]n/3oi>bk0;oPJ[_0_mRVo02obb1j@05o`1FdOl0
=kgo03Nmo`0//_lB;jd00_l`>J/01?lY;j?oB4BYodLoY?m7?j@3oee;Y0;oI4fR0_m_E:<00ombEjCo
O5fSogaMX`03ohQVY@CoUg>X00GoZH>/olNS]?o7XkCoaj>dooKN/`02ojZoj@03ojZnj?nY_^SoZKkX
00GoZKgX4oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool09_ooool2ojJHa`?o]XZW0_ngQ9d2olfX/`CoaI>R00?o`8^Momb^ZOoL[ZT00_oL[ZT00ol0
003oZKgXojVmj01=ojVmj1?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<oooo
o`003?ooool00ol0003oooooooooo`0`oooooaSoZKgX0_nX_NP2ojNlj003ojJlj?nS^^WoXk[Y00;o
Xk[Y00?oWKO[oibhk?nL^>`00_nA]>l3ogn^lP;oGjCe0ol/PNT00ol0=kgo02bboa8_[@02oc0iZ`;o
:BnS0_m7?j@3oee;Y0;oI4fR0om_E:<3ogaMX`?oR6JU0_nGLjP01?n/R:ooaj>dolNS]?o7Xk@2ooKN
/`04ojZojOnY_^SoZKkXojVnj1[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02Gooooo0_nVV<L3okJ:Y`04okN4WOo=Z;?ocJRcolfX/`CoaI>R1OoL
[ZU:ojVmj1[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`003Oooool0
0ol0003oooooooooo`0_oooooaSoZKgX1?nX_NP2ojJlj0;oXk[Y0_nR^^X3oibhk0;oTKC_0omo[_82
oenTm@?o:8k]00?o03Nmo`0//_lB;jd00_l`>J/01?lY;j?oB4BYodLoY?m>@J82oee;Y0;oI4fR0om_
E:<2ogmQYP05ogaMXon8IZGoR6JUohQVYOnGLjP00_n/R:l3olNS]004ooKN/onZ_^SoZKkXojVnj1co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Go
oooo00GoYYS7okJ:YonfRZOo]XZWokN4W@03olfX/`CoaI>R00ColNW1omb^ZOoL[ZWog:jYBOnY_NPL
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool000kooooo0_l0000`oooo
oaSoZKgX0_nX_NP01?nX_>SoY[cYojJljOnV_>T2oj:jjP03oj:kjonL^NgoW;W]00;oW;W]0onB^?02
oh:em@?oJ;7j0_lmY_H01?l01IGo00ZKo`0LXOl`>J/2obT_X`;oAcnT00CoCT6Roee;Y?mTCJ;oI4fR
0om_E:<3ogmQYP;oR6JU00?oTg:Zojb8[on/R:l00_n/R:l00oo7XkCom]jcooKN/`0Pooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool06?ooool2o`0002Kooooo0_nfRZL00on<k>kocJRc
olfX/`02olfX/`?oaI>R0ooajL400ooL[ZWoZKgXojVmj015ojVmj23ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`004?ooool00ol0003oooooooooo`0_oooooaOoZKgX0onX
_>P01?nV_>WoYKcYojFljOnU_>T2oj:kj`;oW;W]00?oWK_^oiJklOnF^o400_nF^o43oh^lmP07og^n
o?n?aO[oSlGjohO<o_l01IGo00ZKo`0LX@02obT_X`;oAcnT0_m>@J83ofA=XP;oKeBS0omoHJH3oi=b
ZPCo[8R_00?oaj>dooKN/oofg[<08Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool09_ooool00on<k>kocJRcolfX/`02olfX/`04olFCX_oajL7olNW1
oo7Y`DKoZKgX9?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo000Aoooo
o`03o`000?oooooooooo02oooooo5OnY_NP2ojRmj0?oYkcY0onU_>T4oj:lj`;oWK_^0_nF^o42oibn
l@?oU/7e00KoSlGjoic6mOnLa_GoW<Keo`0:Vol07:42obT_X`04obX_X_m7?jCoCT6Rodi1XP?oI4fR
0_m_E:<3ogmQYP?oTg:Z1?n/R:l2om^o_R?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02Kooooo1?o=Z;<00oo5Tj;oooooooooo`02oooood3oZKgX
:_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo000Booooo`03o`000?oo
oooooooo02oooooo4onY_NP4ojRmj003ojNljOnW_NWoYkgY00?oYKcY0_nR_>/00onT_N_oX;g]oj2m
k@02oj2mk@03oibnlOnQ`>ooXL3_00?oW/?b0_nLa_D2ojC4l003o`00Q?l07:7o:BnS00;o:RnR0_m>
@J800omKBZGoI4fRofA=XP03ofmDX`;oOf6V1?nCLZX3ojb8[`;ofknn8oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09_ooool2olfX/`Oooooo?OnY
_NP/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool001?ooooo0_l0000`
oooooa?oZKgX1?nX_NP3ojNmj@04ojFljOnV_N[oY[gZojJmjP;oY;g[0_nP_Nd2oj>nk@?oXL3_00So
W/?bojC2k_nT`^koY<;^ojC4l?nW`^go00ZKo`00Q0;o:BnS00Ko:RnRodLoY?m>@J;oCT6Roe]:YOmT
CJ83ofmDX`;oOf6V1?nCLZX2ojb8[`?ofknn9?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01cooooo0_l0000`ooooocWoZKgX<?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00_ooooo000Eooooo`03o`000?oooooooooo02oooooo4onY_NP3ojRmj0?oYkgY0_nV_NX0
0onW_NWoYKk[ojFnj`02ojFnj`03oj>nkOnV_n_oYL3]00?oYL3]0_nT`^h2ojO1k0;oYl;]00?o0024
o`0BVolY;j<00_lZ;j82odi1XP;oFdZU0om_E:<3ogmQYP?oTg:Z00Co[8R_om^o__oK_kkofknn9_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0;ooo
oolbojVmj3Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`005_ooool0
0ol0003oooooooooo`0^oooooaCoZKgX0onX_NP01?nW_NWoZ;gYojRmjOnX_NT2ojNmj@;oYKk[0_nW
_^X2ojJoj`;oYL3]0_nW_n/2ojO1k003ojRoj_nY`>[oZL3Z00;o002400?o:BnSobX_X_lZ;j800_m>
@J82oe]:Y@;oKeZZ00CoKeBSogmQY_moHJKoOf6V0onCLZX01?n/R:oofknnom^o__oK_khWooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0^oooooboo
ZKgX>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo000Gooooo`03o`00
0?oooooooooo02kooooo5?nY_NP3ojRmj0?oZ;gY0onW_NT2ojNnjP03ojRnjOnW_^[oYkkZ00;oYkkZ
00?oYko[ojRojOnX_nT00onX_nX2ojW0jP06o`00Q?l04Y_o:RnRobX_X_ld=jKoCT6R0_mKBZD3ofmJ
ZP?oOf6V0_nCLZX2ok:G^`;ofknn:?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0;_ooool/ojVmj3cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0;ooooo`006?ooool2o`00033ooooo4onY_NP00onX_NSoZKgXojVmj003ojRmj@03
ojNmjOnX_^WoZ;kY00?oZ;kY0_nW_^X2ojRnj@?oZ;oY00?oZ;oZooooooooool00_ooool00ol008Co
:RnRobX_XP02oc@gYP?oFdZU0_m_FZX3ohad/P03oi=bZ_nbUk_o/YNk00;o/YNk00?ofknnoooooooo
ool09oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo0_l0000`ooooobOo
ZKgX@?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`00
0?oooooooooo02gooooo5onY_NP00onX_NWoZKgXojVmj002ojRnj@03ojVmj?nY_^WoZKkY00;oZKkY
00?oZ;kYooooooooool02?ooool01Ol006So:RnRobX_X_ld=jKoCT6R00;oFdZU0_m_FZX3ohad/PGo
/YNk:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0;OoooolRojVmj4Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`00
6oooool00ol0003oooooooooo`0]oooooagoZKgX0_nY_^T=ooooo`04o`0BW_lZ;j;o=3NVoc@gYP;o
FdZU0om_FZX3ohad/PCo/YNk;?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0;OoooolOojVmj4Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`0^oooooa[oZKgX4Oooool01OlZ;j;o=3NV
oc@gY_m;CK;oFdZU00?oKeZZ0on<M;83ok:G^bgooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02kooooo6?nY_NQ>ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02_ooool001gooooo00?o0000ooooooooool0;_oooolDojVmj1Kooooo
00?o01:Noc@gY_ld=jH00_m;CK800omKBZGoKeZZofmJZP04ohad/P03ok:G^oo]n<7ooooo02gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02kooooo
5?nY_NQBooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool001kooooo0_l0
000_oooooa7oZKgX6Oooool00ol09:oo=3NVoc@gYP02od]=/P?oKeZZ0_n<M;82okg2gS3ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`;o0000;_oooolBojVmj5Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`008?ooool00ol0003oooooooooo`0]
ooooo`_oZKgX7oooool01?l09:oo=3NVod]=/_m;CK83ogMib004ohad/_nm`]ko_L;Nokg2gS3ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02cooooo
3?nY_NQJooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0027ooooo00?o
0000ooooooooool0;Oooool8ojVmj2;ooooo00Co02B_od]=/_m;CK;oBdfb0omgNLP2okg2gS;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02gooooo
1onY_NQNooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool002;ooooo00?o
0000ooooooooool0;Oooool4ojVmj2Oooooo00?o06GFod]=/_mgNLP00omgNLP00onm`]kooooooooo
o`0aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0]ooooo`CoZKgXHOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo000S
ooooo`;o0000;Oooool00ol0003oooooooooo`0Yooooo`;o06GF0_mgNLPfooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0:_ooool2o`0002gooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02Oooool002Kooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`1Tooooo`05o`000?ooooooooooooooool00000;oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo06Cooooo00Go0000ooooooooooooooooo`00000;ooooo`009oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo06Gooooo00Co0000oooooooooooo0000<?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06Gooooo00Co0000oooooooooooo00002ooo
ool002Sooooo0_l0000Xooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool00000<Oooool2
o`0002Sooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00000;ooooo`00:_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool00000<oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool000002oooool002_o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo000003?o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo000000[o
oooo000/ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J?ooool2o`0003Cooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`1Xooooo`;o00002_ooool002gooooo0_l0
000Sooooo`03o`000?oooooooooo06Oooooo0ol0000eooooo`;o00008oooool00ol0003ooooooooo
o`1Wooooo`?o00002_ooool002oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1S
ooooo`Co0000>_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06?ooooo1?l0000=
ooooo`00<?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo063ooooo0ol0000ooooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0H?ooool3o`00017ooooo000aooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0G?ooool4o`0004?ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`1Looooo`Co00005?ooool003;ooooo0_l0000Nooooo`03o`00
0?oooooooooo05Sooooo1?l00018ooooo`;o00007_ooool00ol0003oooooooooo`1Hooooo`Co0000
6?ooool003Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Dooooo`Co0000C_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Cooooo1?l0000Looooo`00=Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo0ol0001Cooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0DOooool3o`00023ooooo000fooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0COooool4o`0005Oooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1=ooooo`Co00008oooool003Oooooo0_l0000Iooooo`03o`000?oooooooooo04Wo
oooo1?l0001Looooo`;o00006Oooool00ol0003oooooooooo`19ooooo`Co00009oooool003Wooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`Co0000H_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo04Gooooo1?l0000[ooooo`00>_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04?ooooo0ol0001Wooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0@oooool3o`0002oooooo000kooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0?oooool4o`0006_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0o
ooooo`Co0000<_ooool003cooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0001`oooo
o`;o00004oooool00ol0003oooooooooo`0kooooo`Co0000=_ooool003kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0gooooo`Co0000M_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03Oooooo1?l0000jooooo`00?oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03?ooooo1?l0001kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
<oooool4o`0003kooooo0010ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?oo
ool3o`00083ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`ooooo`?o0000@_oo
ool0047ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`Co0000Q?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo1?l00015ooooo`00@_ooool2o`00
00gooooo00?o0000ooooooooool0:?ooool4o`0008Wooooo0_l0000=ooooo`03o`000?oooooooooo
02Sooooo1?l00019ooooo`00A?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Co
oooo1?l0002?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool4o`0004go
oooo0015ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`0009Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`?o0000DOooool004Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co0000V?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01gooooo1?l0001Dooooo`00Aoooool2o`0000Sooooo00?o0000
ooooooooool06Oooool4o`0009gooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0001H
ooooo`00BOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0002Soooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4o`0005cooooo001:ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool3o`000:Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`?o0000H?ooool004_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0>ooooo`Co0000[?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00kooooo1?l0001Sooooo`00C?ooool2o`0000?ooooo00?o0000ooooooooool02_oo
ool4o`000;7ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0001Wooooo`00C_ooool0
1?l0003oooooooooool00008ooooo`Co0000]oooool01?l0003oooooooooool00008ooooo`Co0000
Joooool004oooooo00?o0000ooooool000001Oooool3o`000;cooooo00?o0000ooooool000001Ooo
ool3o`0006oooooo001@ooooo`;o000000?oooooo`000?l000000_l00030ooooo`;o000000?ooooo
o`000?l000000_l0001booooo`00DOooool2o`000<Gooooo0_l0001fooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-1.41844, \
-1.14991, 0.01418, 0.01418}, {{208.5, 389.375}, {315.688, 169}} -> {-4.23892, \
-1.14991, 0.01418, 0.01418}, {{9.625, 190.438}, {154.375, 7.6875}} -> \
{-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, 389.375}, {154.375, \
7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoClassificationRegions[pdf1, pdf2, pr, x, y, classColors, gd, 
        Axes \[Rule] False, Frame \[Rule] True, FS];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.00495 .53114 m
.03154 .53218 L
.06053 .53318 L
.08777 .53398 L
.11396 .5346 L
.12855 .53488 L
.14183 .53509 L
.15563 .53527 L
.16183 .53533 L
.16867 .53538 L
.17534 .53542 L
.17899 .53544 L
.18241 .53545 L
.18405 .53545 L
.1856 .53546 L
.187 .53546 L
.18778 .53546 L
.18852 .53546 L
.18939 .53546 L
.19018 .53546 L
.19102 .53546 L
.1915 .53546 L
.19193 .53546 L
.19267 .53546 L
.19347 .53546 L
.19432 .53546 L
.1951 .53546 L
.19597 .53546 L
.19689 .53546 L
.19855 .53545 L
.20033 .53545 L
.20229 .53544 L
.20581 .53543 L
.20911 .53541 L
.21525 .53537 L
.22188 .53531 L
.23567 .53513 L
.2426 .53502 L
.25019 .53487 L
.26481 .53451 L
.2781 .5341 L
.30497 .53301 L
.33248 .53147 L
.35896 .52951 L
.38711 .52684 L
.41423 .52356 L
.4403 .51963 L
.46806 .51439 L
.49478 .50807 L
.52319 .49956 L
Mistroke
.55055 .48901 L
.57687 .4758 L
.59156 .4666 L
.60487 .45675 L
.63184 .43022 L
.64511 .412 L
.65945 .38522 L
.66035 .38316 L
Mfstroke
.00495 .99505 m
.03154 .99505 L
.06053 .99505 L
.08777 .99505 L
.11396 .99505 L
.14183 .99505 L
.16867 .99505 L
.19719 .99505 L
.22467 .99505 L
.2511 .99505 L
.27922 .99505 L
.3063 .99505 L
.33234 .99505 L
.36006 .99505 L
.38675 .99505 L
.41512 .99505 L
.44244 .99505 L
.46872 .99505 L
.4967 .99505 L
.52362 .99505 L
.55224 .99505 L
.57981 .99505 L
.60634 .99505 L
.63456 .99505 L
.66035 .99505 L
s
1 1 .5 r
.00495 .53114 m
.03154 .53218 L
.06053 .53318 L
.08777 .53398 L
.11396 .5346 L
.12855 .53488 L
.14183 .53509 L
.15563 .53527 L
.16183 .53533 L
.16867 .53538 L
.17534 .53542 L
.17899 .53544 L
.18241 .53545 L
.18405 .53545 L
.1856 .53546 L
.187 .53546 L
.18778 .53546 L
.18852 .53546 L
.18939 .53546 L
.19018 .53546 L
.19102 .53546 L
.1915 .53546 L
.19193 .53546 L
.19267 .53546 L
.19347 .53546 L
.19432 .53546 L
.1951 .53546 L
.19597 .53546 L
.19689 .53546 L
.19855 .53545 L
.20033 .53545 L
.20229 .53544 L
.20581 .53543 L
.20911 .53541 L
.21525 .53537 L
.22188 .53531 L
.23567 .53513 L
.2426 .53502 L
.25019 .53487 L
.26481 .53451 L
.2781 .5341 L
.30497 .53301 L
.33248 .53147 L
.35896 .52951 L
.38711 .52684 L
.41423 .52356 L
.4403 .51963 L
.46806 .51439 L
.49478 .50807 L
.52319 .49956 L
.55055 .48901 L
.57687 .4758 L
.59156 .4666 L
.60487 .45675 L
.63184 .43022 L
.64511 .412 L
.65945 .38522 L
.66035 .38316 L
.66035 .99505 L
.63456 .99505 L
.60634 .99505 L
.57981 .99505 L
.55224 .99505 L
.52362 .99505 L
.4967 .99505 L
.46872 .99505 L
.44244 .99505 L
.41512 .99505 L
.38675 .99505 L
.36006 .99505 L
.33234 .99505 L
.3063 .99505 L
.27922 .99505 L
.2511 .99505 L
.22467 .99505 L
.19719 .99505 L
.16867 .99505 L
.14183 .99505 L
.11396 .99505 L
.08777 .99505 L
.06053 .99505 L
.03154 .99505 L
.00495 .99505 L
F
0 g
.00495 .53114 m
.03154 .53218 L
.06053 .53318 L
.08777 .53398 L
.11396 .5346 L
.12855 .53488 L
.14183 .53509 L
.15563 .53527 L
.16183 .53533 L
.16867 .53538 L
.17534 .53542 L
.17899 .53544 L
.18241 .53545 L
.18405 .53545 L
.1856 .53546 L
.187 .53546 L
.18778 .53546 L
.18852 .53546 L
.18939 .53546 L
.19018 .53546 L
.19102 .53546 L
.1915 .53546 L
.19193 .53546 L
.19267 .53546 L
.19347 .53546 L
.19432 .53546 L
.1951 .53546 L
.19597 .53546 L
.19689 .53546 L
.19855 .53545 L
.20033 .53545 L
.20229 .53544 L
.20581 .53543 L
.20911 .53541 L
.21525 .53537 L
.22188 .53531 L
.23567 .53513 L
.2426 .53502 L
.25019 .53487 L
.26481 .53451 L
.2781 .5341 L
.30497 .53301 L
.33248 .53147 L
.35896 .52951 L
.38711 .52684 L
.41423 .52356 L
.4403 .51963 L
.46806 .51439 L
.49478 .50807 L
.52319 .49956 L
Mistroke
.55055 .48901 L
.57687 .4758 L
.59156 .4666 L
.60487 .45675 L
.63184 .43022 L
.64511 .412 L
.65945 .38522 L
.66035 .38316 L
Mfstroke
.00495 .99505 m
.03154 .99505 L
.06053 .99505 L
.08777 .99505 L
.11396 .99505 L
.14183 .99505 L
.16867 .99505 L
.19719 .99505 L
.22467 .99505 L
.2511 .99505 L
.27922 .99505 L
.3063 .99505 L
.33234 .99505 L
.36006 .99505 L
.38675 .99505 L
.41512 .99505 L
.44244 .99505 L
.46872 .99505 L
.4967 .99505 L
.52362 .99505 L
.55224 .99505 L
.57981 .99505 L
.60634 .99505 L
.63456 .99505 L
.66035 .99505 L
s
.66035 .00495 m
.66133 .00495 L
.66241 .00495 L
.66342 .00495 L
.66439 .00495 L
.66542 .00495 L
.66642 .00495 L
.66747 .00495 L
.66849 .00495 L
.66947 .00495 L
.67051 .00495 L
.67152 .00495 L
.67248 .00495 L
.67351 .00495 L
.6745 .00495 L
.67555 .00495 L
.67656 .00495 L
.67754 .00495 L
.67858 .00495 L
.67957 .00495 L
.68063 .00495 L
.68166 .00495 L
.68264 .00495 L
.68369 .00495 L
.68464 .00495 L
s
.66035 .00495 m
.66133 .01071 L
.66241 .01708 L
.66342 .02316 L
.66439 .02908 L
.66542 .03549 L
.66642 .04177 L
.66747 .04856 L
.66849 .05524 L
.66947 .0618 L
.67051 .06894 L
.67152 .07599 L
.67248 .08295 L
.67351 .09058 L
.6745 .09817 L
.67555 .10654 L
.67656 .11496 L
.67754 .12344 L
.67858 .13297 L
.67957 .14278 L
.68063 .15411 L
.68166 .16628 L
.68264 .17981 L
.68314 .1878 L
.68369 .1981 L
.68392 .20344 L
.68418 .21018 L
.6843 .21409 L
.68442 .21849 L
.68453 .22357 L
.68456 .22534 L
.68459 .22758 L
.68461 .23005 L
.68464 .23644 L
s
1 1 .5 r
.66035 .00495 m
.66133 .00495 L
.66241 .00495 L
.66342 .00495 L
.66439 .00495 L
.66542 .00495 L
.66642 .00495 L
.66747 .00495 L
.66849 .00495 L
.66947 .00495 L
.67051 .00495 L
.67152 .00495 L
.67248 .00495 L
.67351 .00495 L
.6745 .00495 L
.67555 .00495 L
.67656 .00495 L
.67754 .00495 L
.67858 .00495 L
.67957 .00495 L
.68063 .00495 L
.68166 .00495 L
.68264 .00495 L
.68369 .00495 L
.68464 .00495 L
.68464 .23644 L
.68461 .23005 L
.68459 .22758 L
.68456 .22534 L
.68453 .22357 L
.68442 .21849 L
.6843 .21409 L
.68418 .21018 L
.68392 .20344 L
.68369 .1981 L
.68314 .1878 L
.68264 .17981 L
.68166 .16628 L
.68063 .15411 L
.67957 .14278 L
.67858 .13297 L
.67754 .12344 L
.67656 .11496 L
.67555 .10654 L
.6745 .09817 L
.67351 .09058 L
.67248 .08295 L
.67152 .07599 L
.67051 .06894 L
.66947 .0618 L
.66849 .05524 L
.66747 .04856 L
.66642 .04177 L
.66542 .03549 L
.66439 .02908 L
.66342 .02316 L
.66241 .01708 L
.66133 .01071 L
.66035 .00495 L
F
0 g
.66035 .00495 m
.66133 .00495 L
.66241 .00495 L
.66342 .00495 L
.66439 .00495 L
.66542 .00495 L
.66642 .00495 L
.66747 .00495 L
.66849 .00495 L
.66947 .00495 L
.67051 .00495 L
.67152 .00495 L
.67248 .00495 L
.67351 .00495 L
.6745 .00495 L
.67555 .00495 L
.67656 .00495 L
.67754 .00495 L
.67858 .00495 L
.67957 .00495 L
.68063 .00495 L
.68166 .00495 L
.68264 .00495 L
.68369 .00495 L
.68464 .00495 L
s
.66035 .00495 m
.66133 .01071 L
.66241 .01708 L
.66342 .02316 L
.66439 .02908 L
.66542 .03549 L
.66642 .04177 L
.66747 .04856 L
.66849 .05524 L
.66947 .0618 L
.67051 .06894 L
.67152 .07599 L
.67248 .08295 L
.67351 .09058 L
.6745 .09817 L
.67555 .10654 L
.67656 .11496 L
.67754 .12344 L
.67858 .13297 L
.67957 .14278 L
.68063 .15411 L
.68166 .16628 L
.68264 .17981 L
.68314 .1878 L
.68369 .1981 L
.68392 .20344 L
.68418 .21018 L
.6843 .21409 L
.68442 .21849 L
.68453 .22357 L
.68456 .22534 L
.68459 .22758 L
.68461 .23005 L
.68464 .23644 L
s
.68464 .00495 m
.69723 .00495 L
.71097 .00495 L
.72386 .00495 L
.73627 .00495 L
.74947 .00495 L
.76218 .00495 L
.77569 .00495 L
.7887 .00495 L
.80122 .00495 L
.81454 .00495 L
.82737 .00495 L
.8397 .00495 L
.85283 .00495 L
.86547 .00495 L
.8789 .00495 L
.89185 .00495 L
.90429 .00495 L
.91754 .00495 L
.93029 .00495 L
.94385 .00495 L
.95691 .00495 L
.96947 .00495 L
.98284 .00495 L
.99505 .00495 L
s
.68464 .99505 m
.69723 .99505 L
.71097 .99505 L
.72386 .99505 L
.73627 .99505 L
.74947 .99505 L
.76218 .99505 L
.77569 .99505 L
.7887 .99505 L
.80122 .99505 L
.81454 .99505 L
.82737 .99505 L
.8397 .99505 L
.85283 .99505 L
.86547 .99505 L
.8789 .99505 L
.89185 .99505 L
.90429 .99505 L
.91754 .99505 L
.93029 .99505 L
.94385 .99505 L
.95691 .99505 L
.96947 .99505 L
.98284 .99505 L
.99505 .99505 L
s
1 1 .5 r
.68464 .00495 m
.69723 .00495 L
.71097 .00495 L
.72386 .00495 L
.73627 .00495 L
.74947 .00495 L
.76218 .00495 L
.77569 .00495 L
.7887 .00495 L
.80122 .00495 L
.81454 .00495 L
.82737 .00495 L
.8397 .00495 L
.85283 .00495 L
.86547 .00495 L
.8789 .00495 L
.89185 .00495 L
.90429 .00495 L
.91754 .00495 L
.93029 .00495 L
.94385 .00495 L
.95691 .00495 L
.96947 .00495 L
.98284 .00495 L
.99505 .00495 L
.99505 .99505 L
.98284 .99505 L
.96947 .99505 L
.95691 .99505 L
.94385 .99505 L
.93029 .99505 L
.91754 .99505 L
.90429 .99505 L
.89185 .99505 L
.8789 .99505 L
.86547 .99505 L
.85283 .99505 L
.8397 .99505 L
.82737 .99505 L
.81454 .99505 L
.80122 .99505 L
.7887 .99505 L
.77569 .99505 L
.76218 .99505 L
.74947 .99505 L
.73627 .99505 L
.72386 .99505 L
.71097 .99505 L
.69723 .99505 L
.68464 .99505 L
F
0 g
.68464 .00495 m
.69723 .00495 L
.71097 .00495 L
.72386 .00495 L
.73627 .00495 L
.74947 .00495 L
.76218 .00495 L
.77569 .00495 L
.7887 .00495 L
.80122 .00495 L
.81454 .00495 L
.82737 .00495 L
.8397 .00495 L
.85283 .00495 L
.86547 .00495 L
.8789 .00495 L
.89185 .00495 L
.90429 .00495 L
.91754 .00495 L
.93029 .00495 L
.94385 .00495 L
.95691 .00495 L
.96947 .00495 L
.98284 .00495 L
.99505 .00495 L
s
.68464 .99505 m
.69723 .99505 L
.71097 .99505 L
.72386 .99505 L
.73627 .99505 L
.74947 .99505 L
.76218 .99505 L
.77569 .99505 L
.7887 .99505 L
.80122 .99505 L
.81454 .99505 L
.82737 .99505 L
.8397 .99505 L
.85283 .99505 L
.86547 .99505 L
.8789 .99505 L
.89185 .99505 L
.90429 .99505 L
.91754 .99505 L
.93029 .99505 L
.94385 .99505 L
.95691 .99505 L
.96947 .99505 L
.98284 .99505 L
.99505 .99505 L
s
.66035 .38316 m
.66133 .38084 L
.66241 .37823 L
.66342 .37568 L
.66439 .37314 L
.66542 .37034 L
.66642 .36754 L
.66747 .36444 L
.66849 .36131 L
.66947 .35818 L
.67051 .35468 L
.67152 .35113 L
.67248 .34754 L
.67351 .3435 L
.6745 .33937 L
.67555 .33467 L
.67656 .32979 L
.67754 .32472 L
.67858 .3188 L
.67957 .31248 L
.68063 .30485 L
.68166 .29626 L
.68264 .28615 L
.68314 .27991 L
.68369 .27152 L
.68392 .26702 L
.68418 .26117 L
.6843 .25769 L
.68442 .2537 L
.68447 .25161 L
.68453 .24898 L
.68456 .24735 L
.68459 .24519 L
.68462 .24256 L
.68464 .23652 L
s
.66035 .99505 m
.66133 .99505 L
.66241 .99505 L
.66342 .99505 L
.66439 .99505 L
.66542 .99505 L
.66642 .99505 L
.66747 .99505 L
.66849 .99505 L
.66947 .99505 L
.67051 .99505 L
.67152 .99505 L
.67248 .99505 L
.67351 .99505 L
.6745 .99505 L
.67555 .99505 L
.67656 .99505 L
.67754 .99505 L
.67858 .99505 L
.67957 .99505 L
.68063 .99505 L
.68166 .99505 L
.68264 .99505 L
.68369 .99505 L
.68464 .99505 L
s
1 1 .5 r
.66035 .38316 m
.66133 .38084 L
.66241 .37823 L
.66342 .37568 L
.66439 .37314 L
.66542 .37034 L
.66642 .36754 L
.66747 .36444 L
.66849 .36131 L
.66947 .35818 L
.67051 .35468 L
.67152 .35113 L
.67248 .34754 L
.67351 .3435 L
.6745 .33937 L
.67555 .33467 L
.67656 .32979 L
.67754 .32472 L
.67858 .3188 L
.67957 .31248 L
.68063 .30485 L
.68166 .29626 L
.68264 .28615 L
.68314 .27991 L
.68369 .27152 L
.68392 .26702 L
.68418 .26117 L
.6843 .25769 L
.68442 .2537 L
.68447 .25161 L
.68453 .24898 L
.68456 .24735 L
.68459 .24519 L
.68462 .24256 L
.68464 .23652 L
.68464 .99505 L
.68369 .99505 L
.68264 .99505 L
.68166 .99505 L
.68063 .99505 L
.67957 .99505 L
.67858 .99505 L
.67754 .99505 L
.67656 .99505 L
.67555 .99505 L
.6745 .99505 L
.67351 .99505 L
.67248 .99505 L
.67152 .99505 L
.67051 .99505 L
.66947 .99505 L
.66849 .99505 L
.66747 .99505 L
.66642 .99505 L
.66542 .99505 L
.66439 .99505 L
.66342 .99505 L
.66241 .99505 L
.66133 .99505 L
.66035 .99505 L
F
0 g
.66035 .38316 m
.66133 .38084 L
.66241 .37823 L
.66342 .37568 L
.66439 .37314 L
.66542 .37034 L
.66642 .36754 L
.66747 .36444 L
.66849 .36131 L
.66947 .35818 L
.67051 .35468 L
.67152 .35113 L
.67248 .34754 L
.67351 .3435 L
.6745 .33937 L
.67555 .33467 L
.67656 .32979 L
.67754 .32472 L
.67858 .3188 L
.67957 .31248 L
.68063 .30485 L
.68166 .29626 L
.68264 .28615 L
.68314 .27991 L
.68369 .27152 L
.68392 .26702 L
.68418 .26117 L
.6843 .25769 L
.68442 .2537 L
.68447 .25161 L
.68453 .24898 L
.68456 .24735 L
.68459 .24519 L
.68462 .24256 L
.68464 .23652 L
s
.66035 .99505 m
.66133 .99505 L
.66241 .99505 L
.66342 .99505 L
.66439 .99505 L
.66542 .99505 L
.66642 .99505 L
.66747 .99505 L
.66849 .99505 L
.66947 .99505 L
.67051 .99505 L
.67152 .99505 L
.67248 .99505 L
.67351 .99505 L
.6745 .99505 L
.67555 .99505 L
.67656 .99505 L
.67754 .99505 L
.67858 .99505 L
.67957 .99505 L
.68063 .99505 L
.68166 .99505 L
.68264 .99505 L
.68369 .99505 L
.68464 .99505 L
s
.00495 .00495 m
.03154 .00495 L
.06053 .00495 L
.08777 .00495 L
.11396 .00495 L
.14183 .00495 L
.16867 .00495 L
.19719 .00495 L
.22467 .00495 L
.2511 .00495 L
.27922 .00495 L
.3063 .00495 L
.33234 .00495 L
.36006 .00495 L
.38675 .00495 L
.41512 .00495 L
.44244 .00495 L
.46872 .00495 L
.4967 .00495 L
.52362 .00495 L
.55224 .00495 L
.57981 .00495 L
.60634 .00495 L
.63456 .00495 L
.66035 .00495 L
s
.00495 .53114 m
.03154 .53218 L
.06053 .53318 L
.08777 .53398 L
.11396 .5346 L
.12855 .53488 L
.14183 .53509 L
.15563 .53527 L
.16183 .53533 L
.16867 .53538 L
.17534 .53542 L
.17899 .53544 L
.18241 .53545 L
.18405 .53545 L
.1856 .53546 L
.187 .53546 L
.18778 .53546 L
.18852 .53546 L
.18939 .53546 L
.19018 .53546 L
.19102 .53546 L
.1915 .53546 L
.19193 .53546 L
.19267 .53546 L
.19347 .53546 L
.19432 .53546 L
.1951 .53546 L
.19597 .53546 L
.19689 .53546 L
.19855 .53545 L
.20033 .53545 L
.20229 .53544 L
.20581 .53543 L
.20911 .53541 L
.21525 .53537 L
.22188 .53531 L
.23567 .53513 L
.2426 .53502 L
.25019 .53487 L
.26481 .53451 L
.2781 .5341 L
.30497 .53301 L
.33248 .53147 L
.35896 .52951 L
.38711 .52684 L
.41423 .52356 L
.4403 .51963 L
.46806 .51439 L
.49478 .50807 L
.52319 .49956 L
Mistroke
.55055 .48901 L
.57687 .4758 L
.59156 .4666 L
.60487 .45675 L
.63184 .43022 L
.64511 .412 L
.65945 .38522 L
.66035 .38316 L
Mfstroke
.5 1 1 r
.00495 .00495 m
.03154 .00495 L
.06053 .00495 L
.08777 .00495 L
.11396 .00495 L
.14183 .00495 L
.16867 .00495 L
.19719 .00495 L
.22467 .00495 L
.2511 .00495 L
.27922 .00495 L
.3063 .00495 L
.33234 .00495 L
.36006 .00495 L
.38675 .00495 L
.41512 .00495 L
.44244 .00495 L
.46872 .00495 L
.4967 .00495 L
.52362 .00495 L
.55224 .00495 L
.57981 .00495 L
.60634 .00495 L
.63456 .00495 L
.66035 .00495 L
.66035 .38316 L
.65945 .38522 L
.64511 .412 L
.63184 .43022 L
.60487 .45675 L
.59156 .4666 L
.57687 .4758 L
.55055 .48901 L
.52319 .49956 L
.49478 .50807 L
.46806 .51439 L
.4403 .51963 L
.41423 .52356 L
.38711 .52684 L
.35896 .52951 L
.33248 .53147 L
.30497 .53301 L
.2781 .5341 L
.26481 .53451 L
.25019 .53487 L
.2426 .53502 L
.23567 .53513 L
.22188 .53531 L
.21525 .53537 L
.20911 .53541 L
.20581 .53543 L
.20229 .53544 L
.20033 .53545 L
.19855 .53545 L
.19689 .53546 L
.19597 .53546 L
.1951 .53546 L
.19432 .53546 L
.19347 .53546 L
.19267 .53546 L
.19193 .53546 L
.1915 .53546 L
.19102 .53546 L
.19018 .53546 L
.18939 .53546 L
.18852 .53546 L
.18778 .53546 L
.187 .53546 L
.1856 .53546 L
.18405 .53545 L
.18241 .53545 L
.17899 .53544 L
.17534 .53542 L
.16867 .53538 L
.16183 .53533 L
.15563 .53527 L
.14183 .53509 L
.12855 .53488 L
.11396 .5346 L
.08777 .53398 L
.06053 .53318 L
.03154 .53218 L
.00495 .53114 L
F
0 g
.00495 .00495 m
.03154 .00495 L
.06053 .00495 L
.08777 .00495 L
.11396 .00495 L
.14183 .00495 L
.16867 .00495 L
.19719 .00495 L
.22467 .00495 L
.2511 .00495 L
.27922 .00495 L
.3063 .00495 L
.33234 .00495 L
.36006 .00495 L
.38675 .00495 L
.41512 .00495 L
.44244 .00495 L
.46872 .00495 L
.4967 .00495 L
.52362 .00495 L
.55224 .00495 L
.57981 .00495 L
.60634 .00495 L
.63456 .00495 L
.66035 .00495 L
s
.00495 .53114 m
.03154 .53218 L
.06053 .53318 L
.08777 .53398 L
.11396 .5346 L
.12855 .53488 L
.14183 .53509 L
.15563 .53527 L
.16183 .53533 L
.16867 .53538 L
.17534 .53542 L
.17899 .53544 L
.18241 .53545 L
.18405 .53545 L
.1856 .53546 L
.187 .53546 L
.18778 .53546 L
.18852 .53546 L
.18939 .53546 L
.19018 .53546 L
.19102 .53546 L
.1915 .53546 L
.19193 .53546 L
.19267 .53546 L
.19347 .53546 L
.19432 .53546 L
.1951 .53546 L
.19597 .53546 L
.19689 .53546 L
.19855 .53545 L
.20033 .53545 L
.20229 .53544 L
.20581 .53543 L
.20911 .53541 L
.21525 .53537 L
.22188 .53531 L
.23567 .53513 L
.2426 .53502 L
.25019 .53487 L
.26481 .53451 L
.2781 .5341 L
.30497 .53301 L
.33248 .53147 L
.35896 .52951 L
.38711 .52684 L
.41423 .52356 L
.4403 .51963 L
.46806 .51439 L
.49478 .50807 L
.52319 .49956 L
Mistroke
.55055 .48901 L
.57687 .4758 L
.59156 .4666 L
.60487 .45675 L
.63184 .43022 L
.64511 .412 L
.65945 .38522 L
.66035 .38316 L
Mfstroke
.66035 .00495 m
.66133 .01071 L
.66241 .01708 L
.66342 .02316 L
.66439 .02908 L
.66542 .03549 L
.66642 .04177 L
.66747 .04856 L
.66849 .05524 L
.66947 .0618 L
.67051 .06894 L
.67152 .07599 L
.67248 .08295 L
.67351 .09058 L
.6745 .09817 L
.67555 .10654 L
.67656 .11496 L
.67754 .12344 L
.67858 .13297 L
.67957 .14278 L
.68063 .15411 L
.68166 .16628 L
.68264 .17981 L
.68314 .1878 L
.68369 .1981 L
.68392 .20344 L
.68418 .21018 L
.6843 .21409 L
.68442 .21849 L
.68453 .22357 L
.68456 .22534 L
.68459 .22758 L
.68461 .23005 L
.68464 .23644 L
s
.66035 .38316 m
.66133 .38084 L
.66241 .37823 L
.66342 .37568 L
.66439 .37314 L
.66542 .37034 L
.66642 .36754 L
.66747 .36444 L
.66849 .36131 L
.66947 .35818 L
.67051 .35468 L
.67152 .35113 L
.67248 .34754 L
.67351 .3435 L
.6745 .33937 L
.67555 .33467 L
.67656 .32979 L
.67754 .32472 L
.67858 .3188 L
.67957 .31248 L
.68063 .30485 L
.68166 .29626 L
.68264 .28615 L
.68314 .27991 L
.68369 .27152 L
.68392 .26702 L
.68418 .26117 L
.6843 .25769 L
.68442 .2537 L
.68447 .25161 L
.68453 .24898 L
.68456 .24735 L
.68459 .24519 L
.68462 .24256 L
.68464 .23652 L
s
.5 1 1 r
.66035 .00495 m
.66133 .01071 L
.66241 .01708 L
.66342 .02316 L
.66439 .02908 L
.66542 .03549 L
.66642 .04177 L
.66747 .04856 L
.66849 .05524 L
.66947 .0618 L
.67051 .06894 L
.67152 .07599 L
.67248 .08295 L
.67351 .09058 L
.6745 .09817 L
.67555 .10654 L
.67656 .11496 L
.67754 .12344 L
.67858 .13297 L
.67957 .14278 L
.68063 .15411 L
.68166 .16628 L
.68264 .17981 L
.68314 .1878 L
.68369 .1981 L
.68392 .20344 L
.68418 .21018 L
.6843 .21409 L
.68442 .21849 L
.68453 .22357 L
.68456 .22534 L
.68459 .22758 L
.68461 .23005 L
.68464 .23644 L
.68464 .23652 L
.68462 .24256 L
.68459 .24519 L
.68456 .24735 L
.68453 .24898 L
.68447 .25161 L
.68442 .2537 L
.6843 .25769 L
.68418 .26117 L
.68392 .26702 L
.68369 .27152 L
.68314 .27991 L
.68264 .28615 L
.68166 .29626 L
.68063 .30485 L
.67957 .31248 L
.67858 .3188 L
.67754 .32472 L
.67656 .32979 L
.67555 .33467 L
.6745 .33937 L
.67351 .3435 L
.67248 .34754 L
.67152 .35113 L
.67051 .35468 L
.66947 .35818 L
.66849 .36131 L
.66747 .36444 L
.66642 .36754 L
.66542 .37034 L
.66439 .37314 L
.66342 .37568 L
.66241 .37823 L
.66133 .38084 L
.66035 .38316 L
F
0 g
.66035 .00495 m
.66133 .01071 L
.66241 .01708 L
.66342 .02316 L
.66439 .02908 L
.66542 .03549 L
.66642 .04177 L
.66747 .04856 L
.66849 .05524 L
.66947 .0618 L
.67051 .06894 L
.67152 .07599 L
.67248 .08295 L
.67351 .09058 L
.6745 .09817 L
.67555 .10654 L
.67656 .11496 L
.67754 .12344 L
.67858 .13297 L
.67957 .14278 L
.68063 .15411 L
.68166 .16628 L
.68264 .17981 L
.68314 .1878 L
.68369 .1981 L
.68392 .20344 L
.68418 .21018 L
.6843 .21409 L
.68442 .21849 L
.68453 .22357 L
.68456 .22534 L
.68459 .22758 L
.68461 .23005 L
.68464 .23644 L
s
.66035 .38316 m
.66133 .38084 L
.66241 .37823 L
.66342 .37568 L
.66439 .37314 L
.66542 .37034 L
.66642 .36754 L
.66747 .36444 L
.66849 .36131 L
.66947 .35818 L
.67051 .35468 L
.67152 .35113 L
.67248 .34754 L
.67351 .3435 L
.6745 .33937 L
.67555 .33467 L
.67656 .32979 L
.67754 .32472 L
.67858 .3188 L
.67957 .31248 L
.68063 .30485 L
.68166 .29626 L
.68264 .28615 L
.68314 .27991 L
.68369 .27152 L
.68392 .26702 L
.68418 .26117 L
.6843 .25769 L
.68442 .2537 L
.68447 .25161 L
.68453 .24898 L
.68456 .24735 L
.68459 .24519 L
.68462 .24256 L
.68464 .23652 L
s
1 0 0 r
.02 w
.65005 .67979 Mdot
.65668 .68481 Mdot
.59171 .65175 Mdot
.68367 .7168 Mdot
.5952 .62518 Mdot
.71124 .65959 Mdot
.60847 .7135 Mdot
.69326 .52667 Mdot
.50542 .79038 Mdot
.55928 .68614 Mdot
.5095 .68259 Mdot
.53672 .60827 Mdot
.58606 .73753 Mdot
.4895 .76409 Mdot
.62638 .61225 Mdot
.74825 .81755 Mdot
.93934 .54181 Mdot
.83996 .59467 Mdot
.61716 .56623 Mdot
.64383 .66297 Mdot
.413 .93191 Mdot
.657 .52576 Mdot
.67051 .56303 Mdot
.68115 .64248 Mdot
.59556 .68462 Mdot
.56929 .62799 Mdot
.61831 .53748 Mdot
.51308 .74161 Mdot
.53978 .56649 Mdot
.49507 .79977 Mdot
.7424 .59105 Mdot
.81972 .62257 Mdot
.57556 .65221 Mdot
.4916 .8486 Mdot
.77097 .49496 Mdot
.64574 .78233 Mdot
.49111 .78536 Mdot
.53569 .66691 Mdot
.52763 .6027 Mdot
.84176 .68743 Mdot
.93055 .48793 Mdot
.6626 .59538 Mdot
.84272 .55947 Mdot
.57997 .6131 Mdot
.5388 .74502 Mdot
.55823 .76882 Mdot
.46589 .70795 Mdot
.82912 .61117 Mdot
.87626 .70158 Mdot
.53714 .70769 Mdot
.56971 .69113 Mdot
.58497 .73133 Mdot
.54687 .69647 Mdot
.58764 .6659 Mdot
.47336 .73841 Mdot
.78593 .52091 Mdot
.71271 .63947 Mdot
.62159 .6575 Mdot
.50007 .70082 Mdot
.53988 .71435 Mdot
.52718 .75876 Mdot
.74763 .56479 Mdot
.52518 .63743 Mdot
.60522 .68696 Mdot
.79329 .61222 Mdot
.77146 .54188 Mdot
.76264 .72656 Mdot
.68448 .5752 Mdot
.46482 .63585 Mdot
.64189 .77375 Mdot
.7346 .68207 Mdot
.7226 .56857 Mdot
.71153 .69934 Mdot
.98087 .43904 Mdot
.3534 .74427 Mdot
.39863 .71988 Mdot
.51531 .72348 Mdot
.58228 .62538 Mdot
.60727 .74229 Mdot
.68046 .61449 Mdot
.55276 .62253 Mdot
.57378 .65458 Mdot
.6418 .65208 Mdot
.64402 .49992 Mdot
.60874 .73215 Mdot
.72805 .44625 Mdot
.64336 .57809 Mdot
.65717 .67016 Mdot
.64459 .67234 Mdot
.46239 .7058 Mdot
.81452 .54997 Mdot
.5847 .595 Mdot
.51679 .87463 Mdot
.75966 .62446 Mdot
.79928 .41831 Mdot
.57611 .74639 Mdot
.48189 .71917 Mdot
.50346 .69933 Mdot
.65963 .61345 Mdot
.5893 .73849 Mdot
0 0 1 r
.21576 .23234 Mdot
.26975 .16427 Mdot
.11913 .16651 Mdot
.30344 .29015 Mdot
.26816 .3324 Mdot
.44663 .3428 Mdot
.12413 .22867 Mdot
.19752 .18487 Mdot
.5082 .26994 Mdot
.41855 .4026 Mdot
.44765 .42777 Mdot
.27869 .20796 Mdot
.05963 .09343 Mdot
.42768 .35195 Mdot
.3609 .32313 Mdot
.39867 .30202 Mdot
.34392 .19089 Mdot
.47317 .33556 Mdot
.16826 .23958 Mdot
.19858 .29752 Mdot
.14636 .19379 Mdot
.31764 .3829 Mdot
.14206 .23241 Mdot
.14997 .2323 Mdot
.32126 .21147 Mdot
.09944 .23781 Mdot
.26482 .2127 Mdot
.18113 .23056 Mdot
.37267 .29599 Mdot
.14025 .20346 Mdot
.19719 .21514 Mdot
.35377 .39947 Mdot
.46072 .38115 Mdot
.2848 .26599 Mdot
.17426 .17323 Mdot
.08962 .13828 Mdot
.32459 .19569 Mdot
.38428 .43663 Mdot
.38869 .33703 Mdot
.22474 .14049 Mdot
.2948 .28537 Mdot
.25422 .31305 Mdot
.39567 .36039 Mdot
.17688 .21705 Mdot
.37578 .35926 Mdot
.40113 .24029 Mdot
.30186 .28588 Mdot
.01724 .25916 Mdot
.4162 .34275 Mdot
.19592 .1887 Mdot
.38861 .29146 Mdot
.06219 .23088 Mdot
.12206 .22931 Mdot
.21064 .27561 Mdot
.35626 .27534 Mdot
.28917 .36697 Mdot
.39682 .35107 Mdot
.15573 .1008 Mdot
.38772 .32089 Mdot
.1662 .31889 Mdot
.4925 .36156 Mdot
.17004 .13977 Mdot
.35686 .32156 Mdot
.22553 .33815 Mdot
.11958 .1047 Mdot
.38219 .29668 Mdot
.2313 .18202 Mdot
.22873 .14192 Mdot
.13533 .09302 Mdot
.50496 .4203 Mdot
.19178 .17123 Mdot
.25002 .22972 Mdot
.18912 .15469 Mdot
.37225 .34249 Mdot
.19943 .19805 Mdot
.3148 .19297 Mdot
.37583 .30953 Mdot
.30685 .24309 Mdot
.25071 .26039 Mdot
.35709 .3544 Mdot
.19295 .20118 Mdot
.4004 .36134 Mdot
.44861 .30828 Mdot
.18071 .28262 Mdot
.24863 .29856 Mdot
.25092 .27624 Mdot
.21645 .21592 Mdot
.14201 .21429 Mdot
.13492 .12334 Mdot
.2032 .2098 Mdot
.12607 .25385 Mdot
.0869 .18025 Mdot
.27367 .19217 Mdot
.23478 .24927 Mdot
.35376 .22148 Mdot
.3736 .34655 Mdot
.13787 .16273 Mdot
.30839 .22589 Mdot
.36216 .29126 Mdot
.22991 .25276 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00ool0000Po`000040oooo003oo`00023o00000@3oool00003o`00001oool0Oooo0;X0Oooo
00?o00000?ooO`3oogl0G@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0;X0Oooo00?o
00000?ooO`3oogl0G@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0;X0Oooo00?o0000
0?ooO`3oogl0G@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0;/0Oooo00?o00000?oo
O`3oogl0G03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0;/0Oooo00?o00000?ooO`3o
ogl0G03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0;/0Oooo00?o00000?ooO`3oogl0
G03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0;/0Oooo00?o00000?ooO`3oogl0G03o
ogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0;/0Oooo00?o00000?ooO`3oogl0G03oogl1
0?ooo`7o00000@3oool00003o`00001oool0Oooo0;/0Oooo00?o00000?ooO`3oogl0G03oogl10?oo
o`7o00000@3oool00003o`00001oool0Oooo0;/0Oooo00?o00000?ooO`3oogl0G03oogl10?ooo`7o
00000@3oool00003o`00001oool0Oooo0;`0Oooo00?o00000?ooO`3oogl0F`3oogl10?ooo`7o0000
0@3oool00003o`00001oool0Oooo0;`0Oooo00?o00000?ooO`3oogl0F`3oogl10?ooo`7o00000@3o
ool00003o`00001oool0Oooo0;`0Oooo00?o00000?ooO`3oogl0F`3oogl10?ooo`7o00000@3oool0
0003o`00001oool0Oooo0;`0Oooo00?o00000?ooO`3oogl0F`3oogl10?ooo`7o00000@3oool00003
o`00001oool0Oooo0;`0Oooo00?o00000?ooO`3oogl0F`3oogl10?ooo`7o00000@3oool00003o`00
001oool0Oooo0;d0Oooo00?o00000?ooO`3oogl0FP3oogl10?ooo`7o00000@3oool00003o`00001o
ool0Oooo0;d0Oooo00?o00000?ooO`3oogl0FP3oogl10?ooo`7o00000@3oool00003o`00001oool0
Oooo0;d0Oooo00?o00000?ooO`3oogl0FP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo
0;d0Oooo00?o00000?ooO`3oogl0FP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0;d0
Oooo00?o00000?ooO`3oogl0FP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0;d0Oooo
00?o00000?ooO`3oogl0FP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0;d0Oooo00?o
00000?ooO`3oogl0FP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0;d0Oooo00?o0000
0?ooO`3oogl0FP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo00`0Oooo0ol00?lC07oo
o`?o003oV@1oool00ol00000oomo0?ooO`1I0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1o
ool02`1oool5o`00oa40Oooo1Ol00?nH07ooo`03o`00003oogl0oomo05T0oomo0@3oool1o`000040
oooo00000ol00000Oooo07ooo`0;07ooo`Go003o4@1oool5o`00o`80Oooo0ol00?nC07ooo`03o`00
003oogl0oomo05T0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0;07ooo`Go003o3P1o
ool8o`00o`0307ooool00?oo003o00?o003oTP1oool00ol00000oomo0?ooO`1I0?ooO`40oooo0Ol0
00010?ooo`0000?o000007ooo`1oool0301oool3o`00o`h0Oooo2?l00?l207ooo`Go003oTP1oool0
0ol00000oomo0?ooO`1I0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool07@1oool5o`00
o`D0Oooo1Ol00?nB07ooo`03o`00003oogl0oomo05T0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`0M07ooo`Go003o1P1oool3o`00oi<0Oooo00?o00000?ooO`3oogl0F@3oogl10?ooo`7o
00000@3oool00003o`00001oool0Oooo01h0Oooo0ol00?nN07ooo`03o`00003oogl0oomo05P0oomo
0@3oool1o`000040oooo00000ol00000Oooo07ooo`0R07ooo`?o003oVP1oool00ol00000oomo0?oo
O`1H0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool08@1oool5o`00oiT0Oooo00?o0000
0?ooO`3oogl0F03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0240Oooo1Ol00?nI07oo
o`03o`00003oogl0oomo05P0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0Q07ooo`Go
003oV@1oool00ol00000oomo0?ooO`1H0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0
8P1oool3o`00oiX0Oooo00?o00000?ooO`3oogl0F03oogl10?ooo`7o00000@3oool00003o`00001o
ool0Oooo01D0Oooo0ol00?lD07ooo`?o003o3@1oool3o`00oh00Oooo00?o00000?ooO`3oogl0F03o
ogl10?ooo`7o00000@3oool00003o`00001oool0Oooo01@0Oooo1Ol00?lB07ooo`Go003o2`1oool5
o`00ogl0Oooo00?o00000?ooO`3oogl0F03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo
01@0Oooo1Ol00?lB07ooo`Go003o2`1oool6o`00ogh0Oooo00?o00000?ooO`3oogl0F03oogl10?oo
o`7o00000@3oool00003o`00001oool0Oooo01@0Oooo1Ol00?lB07ooo`Go003o2`1oool6o`00ogh0
Oooo00?o00000?ooO`3oogl0F03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo01D0Oooo
0ol00?lD07ooo`?o003o0`1oool3o`00o`L0Oooo1Ol00?mn07ooo`03o`00003oogl0oomo05P0oomo
0@3oool1o`000040oooo00000ol00000Oooo07ooo`0a07ooo`Go003o1`1oool3o`00oh00Oooo00?o
00000?ooO`3oogl0E`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0340Oooo1Ol00?n:
07ooo`03o`00003oogl0oomo05L0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0S07oo
o`?o003o2`1oool5o`00oa<0Oooo0ol00?md07ooo`03o`00003oogl0oomo05L0oomo0@3oool1o`00
0040oooo00000ol00000Oooo07ooo`0M07ooo`?o003o0P1oool5o`00o`/0Oooo0ol00?lC07ooo`Go
003oL`1oool00ol00000oomo0?ooO`1G0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0
701oool5o`00o`0307ooool00?oo003o00?o003o2`1oool3o`00oa<0Oooo1Ol00?mc07ooo`03o`00
003oogl0oomo05L0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0L07ooo`Go003o00<0
Ooooo`00ool00?l00ol00?l607ooo`?o003o00<0Ooooo`00ool00?l00ol00?lB07ooo`Go003oL`1o
ool00ol00000oomo0?ooO`1G0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0701oool5
o`00o`80Oooo0ol00?l607ooo`[o003o4`1oool3o`00og@0Oooo00?o00000?ooO`3oogl0E`3oogl1
0?ooo`7o00000@3oool00003o`00001oool0Oooo01@0Oooo0ol00?l607ooo`?o003o301oool:o`00
o`P0Oooo0ol00?mo07ooo`03o`00003oogl0oomo05L0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`0C07ooo`Go003o501oool5o`00o`0307ooool00?oo003o00?o003o1P1oool5o`00ogh0
Oooo00?o00000?ooO`3oogl0E`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo01<0Oooo
1Ol00?lE07ooo`?o003o0`1oool5o`00o`D0Oooo1Ol00?mn07ooo`03o`00003oogl0oomo05L0oomo
0@3oool1o`000040oooo00000ol00000Oooo07ooo`0C07ooo`Go003o6P1oool6o`00o`D0Oooo1Ol0
0?l807ooo`?o003o2@1oool3o`00o`D0Oooo0ol00?mP07ooo`03o`00003oogl0oomo05H0oomo0@3o
ool1o`000040oooo00000ol00000Oooo07ooo`0D07ooo`?o003o3P1oool3o`00o`X0Oooo1_l00?l6
07ooo`?o003o201oool5o`00o`L0Oooo1_l00?l207ooo`Go003oG`1oool00ol00000oomo0?ooO`1F
0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0901oool5o`00o`T0Oooo1_l00?lA07oo
o`Go003o1`1oool7o`00o`0307ooool00?oo003o00?o003oG`1oool00ol00000oomo0?ooO`1F0?oo
O`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0901oool5o`00o`X0Oooo1_l00?l@07ooo`Go
003o1`1oool7o`00o`0307ooool00?oo003o00?o003oG`1oool00ol00000oomo0?ooO`1F0?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool08`1oool6o`00o`T0Oooo1ol00?lA07ooo`?o003o
2@1oool6o`00o`80Oooo0ol00?mP07ooo`03o`00003oogl0oomo05H0oomo0@3oool1o`000040oooo
00000ol00000Oooo07ooo`0S07ooo`Go003o2P1oool7o`00oa80Oooo0ol00?l:07ooo`?o003oIP1o
ool00ol00000oomo0?ooO`1F0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool08`1oool5
o`00o`X0Oooo2?l00?l=07ooo`So003o201oool3o`00ofL0Oooo00?o00000?ooO`3oogl0EP3oogl1
0?ooo`7o00000@3oool00003o`00001oool0Oooo02<0Oooo1Ol00?l607ooo`?o003o0P1oool9o`00
o`X0Oooo2Ol00?l707ooo`Go003oIP1oool00ol00000oomo0?ooO`1F0?ooO`40oooo0Ol000010?oo
o`0000?o000007ooo`1oool08`1oool5o`00o`D0Oooo1Ol00?l00`1ooooo003oo`00o`08o`00o`T0
Oooo2Ol00?l707ooo`Go003o1P1oool3o`00oed0Oooo00?o00000?ooO`3oogl0EP3oogl10?ooo`7o
00000@3oool00003o`00001oool0Oooo02<0Oooo1Ol00?l507ooo`Go003o00<0Ooooo`00ool00?l0
2?l00?l907ooo`So003o201oool5o`00o`D0Oooo1Ol00?mL07ooo`03o`00003oogl0oomo05H0oomo
0@3oool1o`000040oooo00000ol00000Oooo07ooo`0T07ooo`?o003o1P1oool5o`00o`0307ooool0
0?oo003o00So003o2P1oool3o`00o`X0Oooo1_l00?l607ooo`Go003oG01oool00ol00000oomo0?oo
O`1F0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool03@1oool3o`00o`h0Oooo1?l00?l<
07ooo`Co003o0P1oool3o`00o`80Oooo0ol00?l707ooo`?o003o3@1oool5o`00o`P0Oooo1Ol00?mL
07ooo`03o`00003oogl0oomo05H0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0<07oo
o`Go003o301oool6o`00o`0307ooool00?oo003o00?o003o1@1oool5o`00o`H0Oooo0ol00?l607oo
o`Go003o301oool5o`00o`T0Oooo0ol00?mM07ooo`03o`00003oogl0oomo05H0oomo0@3oool1o`00
0040oooo00000ol00000Oooo07ooo`0<07ooo`Go003o1`1oool3o`00o`80Oooo3Ol00?l407ooo`Go
003o1@1oool5o`00o`D0Oooo1Ol00?l<07ooo`Go003oJ@1oool00ol00000oomo0?ooO`1F0?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool0301oool5o`00o`H0Oooo1Ol00?l00`1ooooo003o
o`00o`0;o`00o`80Oooo1ol00?l507ooo`Go003o1@1oool5o`00o`d0Oooo0ol00?lG07ooo`?o003o
D01oool00ol00000oomo0?ooO`1F0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool03@1o
ool3o`00o`L0Oooo1Ol00?l207ooo`Co003o00<0Ooooo`00ool00?l01Ol00?l00`1ooooo003oo`00
o`05o`00o`H0Oooo1Ol00?l607ooo`?o003o3@1oool3o`00oaL0Oooo1Ol00?m?07ooo`03o`00003o
ogl0oomo05H0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0G07ooo`Go003o201oool5
o`00o`80Oooo1Ol00?l907ooo`?o003o0`1oool3o`00oa00Oooo1Ol00?lF07ooo`Go003oC`1oool0
0ol00000oomo0?ooO`1F0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0601oool3o`00
oa00Oooo1Ol00?l=07ooo`Ko003o3`1oool5o`00oaH0Oooo1Ol00?m?07ooo`03o`00003oogl0oomo
05H0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0O07ooo`?o003o2P1oool3o`00o`d0
Oooo1ol00?l?07ooo`Go003o5`1oool3o`00oe00Oooo00?o00000?ooO`3oogl0EP3oogl10?ooo`7o
00000@3oool00003o`00001oool0Oooo00?o003o6`1oool5o`00oaT0Oooo1ol00?l@07ooo`?o003o
J`1oool00ol00000oomo0?ooO`1F0?ooO`40oooo0Ol000010?ooo`0000?o000007ooool00?l01?l0
0?lJ07ooo`Go003o6@1oool6o`00o`0407ooool00?oo003oo`00og/0Oooo00?o00000?ooO`3oogl0
EP3oogl10?ooo`7o00000@3oool00003o`00001ooooo003o00Co003o6P1oool5o`00oaX0Oooo0ol0
0?l207ooo`Go003o1P1oool3o`00og40Oooo00?o00000?ooO`3oogl0EP3oogl10?ooo`7o00000@3o
ool00003o`00001ooooo003o00Co003o6`1oool3o`00ob00Oooo1Ol00?l507ooo`Go003o?01oool3
o`00oc40Oooo00?o00000?ooO`3oogl0EP3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo
00?o003o?`1oool5o`00o`D0Oooo1Ol00?lk07ooo`Go003o<01oool00ol00000oomo0?ooO`1F0?oo
O`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0>01oool3o`00o`P0Oooo0ol00?l607ooo`Go
003o401oool3o`00obP0Oooo1Ol00?l`07ooo`03o`00003oogl0oomo05H0oomo0@3oool1o`000040
oooo00000ol00000Oooo07ooo`0g07ooo`Go003o1P1oool5o`00o`H0Oooo0ol00?l@07ooo`Go003o
9`1oool5o`00oc00Oooo00?o00000?ooO`3oogl0EP3oogl10?ooo`7o00000@3oool00003o`00001o
ool0Oooo02l0Oooo0ol00?l507ooo`Go003o1P1oool5o`00oaT0Oooo1Ol00?lX07ooo`?o003o<@1o
ool00ol00000oomo0?ooO`1F0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0;P1oool5
o`00o`@0Oooo1Ol00?l607ooo`Go003o2@1oool5o`00o`/0Oooo1Ol00?mL07ooo`03o`00003oogl0
oomo05H0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0^07ooo`Go003o1@1oool3o`00
o`P0Oooo0ol00?l907ooo`Oo003o2`1oool5o`00oe/0Oooo00?o00000?ooO`3oogl0EP3oogl10?oo
o`7o00000@3oool00003o`00001oool0Oooo02h0Oooo1Ol00?lL07ooo`Oo003o301oool5o`00o`@0
Oooo0ol00?mB07ooo`03o`00003oogl0oomo05L0oomo0@3oool1o`000040oooo00000ol00000Oooo
07ooo`0_07ooo`?o003o0P1oool3o`00oaP0Oooo1ol00?l<07ooo`go003oD@1oool00ol00000oomo
0?ooO`1G0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0<`1oool5o`00o`/0Oooo0ol0
0?l:07ooo`Ko003o301oool=o`00oe40Oooo00?o00000?ooO`3oogl0E`3oogl10?ooo`7o00000@3o
ool00003o`00001oool0Oooo03<0Oooo1Ol00?l:07ooo`Go003o2`1oool3o`00o`h0Oooo3_l00?m?
07ooo`03o`00003oogl0oomo05L0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0c07oo
o`Go003o2P1oool5o`00oah0Oooo3Ol00?l:07ooo`?o003o@@1oool00ol00000oomo0?ooO`1G0?oo
O`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0=01oool3o`00o`/0Oooo1Ol00?lO07ooo`Ko
003o00<0Ooooo`00ool00?l00ol00?l907ooo`Go003o@01oool00ol00000oomo0?ooO`1G0?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool0@`1oool4o`00oal0Oooo1Ol00?l207ooo`Go003o
2@1oool5o`00od00Oooo00?o00000?ooO`3oogl0E`3oogl10?ooo`7o00000@3oool00003o`00001o
ool0Oooo02/0Oooo0ol00?lE07ooo`Go003o7P1oool5o`00o`<0Oooo0ol00?l:07ooo`Go003o?`1o
ool00ol00000oomo0?ooO`1H0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0:P1oool5
o`00oa@0Oooo1Ol00?lJ07ooo`?o003o00<0Ooooo`00ool00?l01Ol00?l?07ooo`?o003o@01oool0
0ol00000oomo0?ooO`1H0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0:P1oool5o`00
oa@0Oooo1Ol00?lI07ooo`Go003o00<0Ooooo`00ool00?l01Ol00?mA07ooo`03o`00003oogl0oomo
05P0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`0Z07ooo`Go003o5@1oool3o`00oaX0
Oooo1_l00?l207ooo`Go003oD@1oool00ol00000oomo0?ooO`1H0?ooO`40oooo0Ol000010?ooo`00
00?o000007ooo`1oool0:`1oool3o`00oaX0Oooo0ol00?lF07ooo`Ko003o0P1oool5o`00oe40Oooo
00?o00000?ooO`3oogl0F03oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo04L0Oooo1Ol0
0?lF07ooo`Go003o0`1oool3o`00oaH0Oooo0ol00?li07ooo`03o`00003oogl0oomo05P0oomo0@3o
ool1o`000040oooo00000ol00000Oooo07ooo`0l07ooo`?o003o201oool5o`00oaL0Oooo0ol00?l5
07ooo`?o003o501oool5o`00ocP0Oooo00?o00000?ooO`3oogl0F03oogl10?ooo`7o00000@3oool0
0003o`00001oool0Oooo03/0Oooo1Ol00?l707ooo`Go003o6P1oool3o`00o`0307ooool00?oo003o
00?o003o101oool3o`00o`D0Oooo0ol00?l407ooo`Go003o=`1oool00ol00000oomo0?ooO`1I0?oo
O`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0>`1oool5o`00o`P0Oooo0ol00?lJ07ooo`[o
003o0`1oool5o`00o`<0Oooo1Ol00?l307ooo`Go003o=`1oool00ol00000oomo0?ooO`1I0?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool0>`1oool5o`00obD0Oooo2_l00?l307ooo`Go003o
0`1oool5o`00o`@0Oooo0ol00?lh07ooo`03o`00003oogl0oomo05T0oomo0@3oool1o`000040oooo
00000ol00000Oooo07ooo`0l07ooo`?o003o9P1oool5o`00o`0307ooool00?oo003o00?o003o0P1o
ool7o`00o`0307ooool00?oo003o00?o003o?P1oool00ol00000oomo0?ooO`1J0?ooO`40oooo0Ol0
00010?ooo`0000?o000007ooo`1oool0HP1oool8o`00o`80Oooo1Ol00?l207ooo`Oo003o00@0Oooo
o`00ool00?oo003o?`1oool00ol00000oomo0?ooO`1J0?ooO`40oooo0Ol000010?ooo`0000?o0000
07ooo`1oool0H@1oool9o`00o`80Oooo1Ol00?l407ooo`Go003o@`1oool00ol00000oomo0?ooO`1J
0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0H@1oool:o`00o`0307ooool00?oo003o
00?o003o101oool5o`00o`l0Oooo0ol00?la07ooo`03o`00003oogl0oomo05X0oomo0@3oool1o`00
0040oooo00000ol00000Oooo07ooo`1>07ooo`?o003o401oool:o`00o`0307ooool00?oo003o00Co
003o101oool3o`00o`l0Oooo1Ol00?l_07ooo`03o`00003oogl0oomo05/0oomo0@3oool1o`000040
oooo00000ol00000Oooo07ooo`1=07ooo`Go003o401oool3o`00o`0307ooool00?oo003o00?o003o
00<0Ooooo`00ool00?l01?l00?lF07ooo`Go003o;`1oool00ol00000oomo0?ooO`1K0?ooO`40oooo
0Ol000010?ooo`0000?o000007ooo`1oool0C@1oool5o`00oaD0Oooo0ol00?l307ooo`Go003o5P1o
ool5o`00obl0Oooo00?o00000?ooO`3oogl0F`3oogl10?ooo`7o00000@3oool00003o`00001oool0
Oooo04d0Oooo1Ol00?lL07ooo`?o003o601oool3o`00obl0Oooo00?o00000?ooO`3oogl0G03oogl1
0?ooo`7o00000@3oool00003o`00001oool0Oooo04h0Oooo0ol00?l^07ooo`?o003o>@1oool00ol0
0000oomo0?ooO`1L0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0EP1oool3o`00obD0
Oooo1Ol00?lh07ooo`03o`00003oogl0oomo05`0oomo0@3oool1o`000040oooo00000ol00000Oooo
07ooo`1E07ooo`Go003o901oool5o`00ocL0Oooo00?o00000?ooO`3oogl0G@3oogl10?ooo`7o0000
0@3oool00003o`00001oool0Oooo05D0Oooo1Ol00?lT07ooo`Go003o=`1oool00ol00000oomo0?oo
O`1M0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0E@1oool5o`00obD0Oooo0ol00?lh
07ooo`030000003oogl0oomo05d0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1F07oo
o`?o003o201oool3o`00oeD0Oooo00<000000?ooO`3oogl0GP3oogl10?ooo`7o00000@3oool00003
o`00001oool0Oooo0600Oooo1Ol00?l>07ooo`?o003o@`1oool00`000000oomo0?ooO`1N0?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool0H01oool5o`00o`d0Oooo1Ol00?m107ooo`030000
003oogl0oomo05l0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`1P07ooo`Go003o3@1o
ool5o`00od40Oooo00<000000?ooO`3oogl0G`3oogl10?ooo`7o00000@3oool00003o`00001oool0
Oooo0640Oooo0ol00?l>07ooo`Go003o@01oool00`000000oomo0?ooO`1P0?ooO`40oooo0Ol00001
0?ooo`0000?o000007ooo`1oool0L`1oool3o`00od40Oooo00<000000?ooO`3oogl0H03oogl10?oo
o`7o00000@3oool00003o`00001oool0Oooo08`0Oooo0ol00?lW07ooo`030000003oogl0oomo02P0
oomo0ooo000f0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0R`1oool5o`00obH0Oooo
00<000000?ooO`3oogl09`3oogl5ool003D0oomo0@3oool1o`000040oooo00000ol00000Oooo07oo
o`2;07ooo`Go003o9@1oool00`000000oomo0?ooO`0X0?ooO`Goo`00=@3oogl10?ooo`7o00000@3o
ool00003o`00001oool0Oooo07`0Oooo0ol00?l<07ooo`Go003o901oool00`000000oomo0?ooO`0Y
0?ooO`Goo`00=@3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo07/0Oooo1Ol00?l<07oo
o`?o003o901oool00`000000oomo0?ooO`0[0?ooO`?oo`00=P3oogl10?ooo`7o00000@3oool00003
o`00001oool0Oooo06X0Oooo0ol00?l>07ooo`Go003o<P1oool00`000000oomo0?ooO`1U0?ooO`40
oooo0Ol000010?ooo`0000?o000007ooo`1oool0J@1oool5o`00o`d0Oooo1Ol00?la07ooo`030000
003oogl0oomo0640oomo0ooo00020?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0J@1o
ool5o`00o`h0Oooo0ol00?la07ooo`030000003oogl0oomo0640oomo1Ooo00000`3oogl0ooooo`00
00010?ooo`0000?o000007ooo`1oool0J@1oool5o`00od40Oooo00<000000?ooO`3oogl06P3oogl3
ool004D0oomo1Ooo00000`3oogl0ooooo`0000010?ooo`0000?o000007ooo`1oool0JP1oool3o`00
od40Oooo00<000000?ooO`3oogl06P3oogl5ool004@0oomo1Ooo00000`3oogl0ooooo`0000010?oo
o`0000?o000007ooo`1oool0[@1oool00`000000oomo0?ooO`0K0?ooO`Goo`00A@3oogl3ool00080
oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`2/07ooo`030000003oogl0oomo01`0oomo
1Ooo001:0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0Z`1oool00`000000oomo0?oo
O`0N0?ooO`?oo`00B`3oogl10?ooo`7o00000@3oool00003o`00001oool0Oooo0:T0Oooo0P00001_
0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0Y`1oool200000740oomo0@3oool1o`00
0040oooo00000ol00000Oooo07ooo`2U07ooo`800000L`3oogl10?ooo`7o00000@3oool00003o`00
001oool0Oooo0:@0Oooo00<000000?ooO`3oogl0L`3oogl10?ooo`7o00000@3oool00003o`00001o
ool0Oooo0:<0Oooo00<000000?ooO`3oogl0M03oogl10?ooo`7o00000@3oool00003o`00001oool0
Oooo0:40Oooo0P00001g0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0W`1oool20000
07T0oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`2M07ooo`800000I`3oogl3ool00140
oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`2K07ooo`800000J03oogl5ool00100oomo
0@3oool1o`000040oooo00000ol00000Oooo07ooo`2I07ooo`800000?@3oogl3ool002X0oomo1Ooo
000@0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0UP1oool3000001/0oomo0ooo000P
0?ooO`Goo`00:@3oogl5ool00100oomo0@3oool1o`000040oooo00000ol00000Oooo07ooo`2D07oo
o`8000007@3oogl5ool001l0oomo1Ooo000Z0?ooO`?oo`004@3oogl10?ooo`7o00000@3oool00003
o`00001oool0Oooo0940Oooo0`00000O0?ooO`Goo`007`3oogl5ool003h0oomo0@3oool1o`000040
oooo00000ol00000Oooo07ooo`2=07ooo`@000008P3oogl5ool00200oomo0ooo000o0?ooO`40oooo
0Ol000010?ooo`0000?o000007ooo`1oool0R@1oool4000002L0oomo0ooo001S0?ooO`40oooo0Ol0
00010?ooo`0000?o000007ooo`1oool0Q@1oool400000940oomo0@3oool1o`000040oooo00000ol0
0000Oooo07ooo`2107ooo`@00000F03oogl3ool003X0oomo0@3oool1o`000040oooo00000ol00000
Oooo07ooo`1m07ooo`@00000F`3oogl5ool003T0oomo0@3oool1o`000040oooo00000ol00000Oooo
07ooo`1g07ooo`H00000>`3oogl3ool000L0oomo0ooo000G0?ooO`Goo`00>@3oogl10?ooo`7o0000
0@3oool00003o`00001oool0Oooo0700Oooo1`0000100?ooO`Goo`001@3oogl5ool001H0oomo1Ooo
000i0?ooO`40oooo0Ol000010?ooo`0000?o000007ooo`1oool0H01oool@000004L0oomo1Ooo0005
0?ooO`Goo`005`3oogl3ool003X0oomo0@3oool1o`000040oooo00000ol0000000000000000;0000
04D0Oooo4000001=0?ooO`?oo`001`3oogl5ool000D0oomo1Ooo001D0?ooO`40oooo0Ol000010?oo
o`0000?o00000?ooO`3oogl02`3ooglT000000_o00005P00001L0?ooO`Goo`001`3oogl3ool000L0
oomo0ooo000D0?ooO`?oo`00;@3oogl3ool000h0oomo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`2/0?ooO`Goo`009`3oogl5ool002/0oomo1Ooo000=0?ooO`40oooo0Ol000010?ooo`0000?o
00000?ooO`3oogl0[03oogl5ool002L0oomo1Ooo000[0?ooO`Goo`003@3oogl10?ooo`7o00000@3o
ool00003o`00003oogl0oomo0:d0oomo0ooo000X0?ooO`Goo`00203oogl3ool00200oomo1Ooo000=
0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0f@3oogl3ool000P0oomo1Ooo000P0?oo
O`?oo`003P3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo0>@0oomo1Ooo00040?ooO`?o
o`00:P3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo0;`0oomo0ooo000U0?ooO`Goo`00
0`3oogl5ool002T0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`2F0?ooO`?oo`004`3o
ogl3ool000`0oomo1Ooo000B0?ooO`?oo`00403oogl3ool000@0oomo1Ooo000Y0?ooO`40oooo0Ol0
00010?ooo`0000?o00000?ooO`3oogl0U@3oogl5ool00140oomo1Ooo000;0?ooO`Goo`002`3oogl3
ool000<0oomo1Ooo000F0?ooO`Goo`00:@3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo
09D0oomo1Ooo000A0?ooO`Goo`002`3oogl5ool000X0oomo1Ooo00020?ooO`Goo`005`3oogl3ool0
02X0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`2E0?ooO`Goo`004@3oogl5ool000`0
oomo0ooo0000103oogooo`00ool00?oo00070?ooO`Goo`000P3oogl5ool004@0oomo0@3oool1o`00
0040oooo00000ol00000oomo0?ooO`2F0?ooO`?oo`004`3oogl3ool000D0oomo0ooo00080?ooO`Go
o`001P3oogl5ool000<0oomo0ooo00150?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0
/`3oogl5ool000L0oomo1Ooo00070?ooO`?oo`00C03oogl10?ooo`7o00000@3oool00003o`00003o
ogl0oomo0;<0oomo1Ooo00070?ooO`Goo`00EP3oogl10?ooo`7o00000@3oool00003o`00003oogl0
oomo0;<0oomo1Ooo00080?ooO`?oo`003@3oogl3ool004L0oomo0@3oool1o`000040oooo00000ol0
0000oomo0?ooO`2d0?ooO`?oo`00603oogl5ool001P0oomo0ooo000[0?ooO`40oooo0Ol000010?oo
o`0000?o00000?ooO`3oogl0X`3oogl3ool001<0oomo0ooo000C0?ooO`Goo`005`3oogl5ool002X0
oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`2R0?ooO`Goo`004@3oogl5ool00180oomo
1Ooo000G0?ooO`Goo`00:P3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo09<0oomo0ooo
000<0?ooO`Goo`004@3oogl5ool001<0oomo0ooo000H0?ooO`Goo`00:P3oogl10?ooo`7o00000@3o
ool00003o`00003oogl0oomo0980oomo1_oo000:0?ooO`Goo`004@3oogl5ool002l0oomo0ooo000[
0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0TP3oogl7ool000X0oomo0ooo00090?oo
O`?oo`001`3oogl3ool002<0oomo0ooo00070?ooO`?oo`00;P3oogl10?ooo`7o00000@3oool00003
o`00003oogl0oomo0980oomo1ooo00090?ooO`?oo`002@3oogl5ool000D0oomo0ooo00030?ooO`?o
o`007@3oogl5ool000D0oomo1Ooo000]0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0
T`3oogl6ool000P0oomo1Ooo00080?ooO`Goo`00103oogl5ool000030?ooOooo003oo`0000?oo`00
703oogl5ool000D0oomo1Ooo000]0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0U@3o
ogl3ool00080oomo0ooo00040?ooO`Goo`00203oogl5ool000@0oomo1Ooo00000`3oogooo`00ool0
0003ool001`0oomo1Ooo00030?ooO`Ooo`00;@3oogl10?ooo`7o00000@3oool00003o`00003oogl0
oomo09T0oomo1Ooo00030?ooO`Soo`001P3oogl3ool000D0oomo1Ooo00000`3oogooo`00ool00003
ool001<0oomo0ooo00070?ooO`?oo`000`3oogl7ool002h0oomo0@3oool1o`000040oooo00000ol0
0000oomo0?ooO`2I0?ooO`Goo`0000<0oomoool00?oo00002Ooo000>0?ooO`?oo`000`3oogl3ool0
01<0oomo1Ooo000<0?ooO`Goo`00<03oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo09T0
oomo4Ooo000Z0?ooO`Goo`00303oogl5ool00300oomo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`210?ooO`?oo`005P3oogl3ool000030?ooOooo003oo`0000[oo`00:P3oogl5ool000d0oomo
0ooo000a0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0P03oogl5ool000d0oomo0ooo
00090?ooO`Ooo`0000@0oomoool00?oo003oo`007`3oogl3ool000X0oomo0ooo00120?ooO`40oooo
0Ol000010?ooo`0000?o00000?ooO`3oogl0P03oogl5ool000`0oomo1Ooo00090?ooO`?oo`007@3o
ogl3ool000D0oomo1Ooo001>0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0P03oogl5
ool000`0oomo1Ooo000X0?ooO`Goo`00103oogl5ool004h0oomo0@3oool1o`000040oooo00000ol0
0000oomo0?ooO`210?ooO`?oo`003@3oogl5ool002P0oomo1Ooo00040?ooO`Goo`00CP3oogl10?oo
o`7o00000@3oool00003o`00003oogl0oomo0980oomo0ooo000;0?ooO`?oo`000P3oogl3ool000/0
oomo0ooo00080?ooO`Goo`001@3oogl3ool004l0oomo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`2O0?ooO`[oo`001@3oogl3ool000030?ooOooo003oo`0000?oo`00203oogl3ool005P0oomo
0@3oool1o`000040oooo00000ol00000oomo0?ooO`2O0?ooO`[oo`00103oogl:ool00100oomo0ooo
001@0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0W`3oogl:ool000@0oomo2_oo000?
0?ooO`Goo`00C`3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo09D0oomo0ooo00070?oo
O`Woo`001@3oogl5ool000030?ooOooo003oo`0000?oo`003P3oogl5ool004l0oomo0@3oool1o`00
0040oooo00000ol00000oomo0?ooO`2D0?ooO`Goo`001`3oogl8ool000H0oomo0ooo00020?ooO`So
o`002`3oogl5ool004l0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`2D0?ooO`Goo`00
2P3oogl5ool000/0oomo2Ooo000;0?ooO`?oo`00D03oogl10?ooo`7o00000@3oool00003o`00003o
ogl0oomo09@0oomo1Ooo000:0?ooO`Goo`002`3oogl9ool005h0oomo0@3oool1o`000040oooo0000
0ol00000oomo0?ooO`2E0?ooO`?oo`00303oogl3ool000`0oomo2Ooo001N0?ooO`40oooo0Ol00001
0?ooo`0000?o00000?ooO`3oogl0S@3oogl3ool001H0oomo0ooo000:0?ooO`Soo`004`3oogl3ool0
04T0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`2<0?ooO`Goo`002`3oogl3ool000H0
oomo1ooo00080?ooO`Soo`004@3oogl5ool001/0oomo0ooo000Z0?ooO`40oooo0Ol000010?ooo`00
00?o00000?ooO`3oogl0S03oogl5ool000X0oomo1ooo00030?ooO`Soo`00203oogl7ool00140oomo
1Ooo000J0?ooO`Goo`00:@3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo08`0oomo1Ooo
000:0?ooO`Soo`000P3oogl8ool000T0oomo1_oo000A0?ooO`Goo`006P3oogl5ool002T0oomo0@3o
ool1o`000040oooo00000ol00000oomo0?ooO`2<0?ooO`Coo`00203oogl;ool000<0oomo1ooo000;
0?ooO`?oo`00303oogl3ool000@0oomo0ooo000K0?ooO`Goo`00:@3oogl10?ooo`7o00000@3oool0
0003o`00003oogl0oomo08/0oomo1Ooo00070?ooO`coo`001P3oogl3ool001X0oomo1Ooo000R0?oo
O`?oo`001`3oogl3ool00200oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`200?ooO`?o
o`001`3oogl6ool000L0oomo1Ooo00030?ooO`?oo`00903oogl5ool002/0oomo1Ooo000O0?ooO`40
oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0O`3oogl5ool000H0oomo1_oo00050?ooO`Ooo`00
:P3oogl5ool002/0oomo1Ooo000O0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0O`3o
ogl6ool000D0oomo1Ooo00050?ooO`Ooo`00;03oogl3ool002`0oomo1Ooo000O0?ooO`40oooo0Ol0
00010?ooo`0000?o00000?ooO`3oogl0O`3oogl6ool000H0oomo0ooo00060?ooO`Goo`004@3oogl3
ool00180oomo0ooo000e0?ooO`?oo`00803oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo
06h0oomo0ooo000?0?ooO`Soo`00303oogl6ool000l0oomo1Ooo000@0?ooO`Goo`00E`3oogl10?oo
o`7o00000@3oool00003o`00003oogl0oomo06d0oomo1Ooo000?0?ooO`Soo`001P3oogl3ool000<0
oomo1Ooo000?0?ooO`Goo`00403oogl5ool005L0oomo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`1]0?ooO`Goo`004P3oogl5ool000D0oomo1Ooo00020?ooO`Goo`003`3oogl5ool00100oomo
1Ooo000C0?ooO`?oo`00@@3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo06d0oomo1Ooo
000B0?ooO`Goo`001@3oogl5ool000<0oomo0ooo000A0?ooO`?oo`004P3oogl3ool001<0oomo1Ooo
00100?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0KP3oogl3ool001@0oomo0ooo0006
0?ooO`Goo`00403oogl3ool000@0oomo0ooo000X0?ooO`Goo`00@03oogl10?ooo`7o00000@3oool0
0003o`00003oogl0oomo08l0oomo0ooo000@0?ooO`Goo`000P3oogl5ool002L0oomo1Ooo00100?oo
O`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0P`3oogl3ool001`0oomo1Ooo00020?ooO`Go
o`00:03oogl3ool00440oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`1Q0?ooO`?oo`00
7P3oogl5ool000L0oomo0ooo000A0?ooO`Koo`0000<0oomoool00?oo00000ooo001/0?ooO`40oooo
0Ol000010?ooo`0000?o00000?ooO`3oogl0H03oogl5ool001d0oomo1Ooo00060?ooO`Goo`00103o
ogl3ool000P0oomo3?oo001]0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0H03oogl5
ool001d0oomo1Ooo00060?ooO`Goo`000`3oogl5ool000H0oomo3Ooo001]0?ooO`40oooo0Ol00001
0?ooo`0000?o00000?ooO`3oogl0H03oogl5ool001h0oomo0ooo00070?ooO`Goo`000`3oogl5ool0
00H0oomo1ooo00000`3oogooo`00ool00003ool006d0oomo0@3oool1o`000040oooo00000ol00000
oomo0?ooO`1Q0?ooO`?oo`00:P3oogl3ool000@0oomo1Ooo00060?ooO`Goo`00103oogl3ool006h0
oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`2B0?ooO`?oo`0000@0oomoool00?oo003o
o`00203oogl3ool007H0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`280?ooO`?oo`00
1P3oogl5ool008@0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`270?ooO`Goo`001@3o
ogl5ool000D0oomo0ooo001l0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0Q`3oogl5
ool000D0oomo1Ooo00040?ooO`Goo`00N`3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo
08L0oomo1Ooo00060?ooO`?oo`001@3oogl5ool001@0oomo0ooo001T0?ooO`40oooo0Ol000010?oo
o`0000?o00000?ooO`3oogl0R03oogl3ool000l0oomo1Ooo000C0?ooO`Goo`00H`3oogl10?ooo`7o
00000@3oool00003o`00003oogl0oomo09/0oomo0ooo000D0?ooO`Goo`00H`3oogl10?ooo`7o0000
0@3oool00003o`00003oogl0oomo08P0oomo0ooo000W0?ooO`Koo`00HP3oogl10?ooo`7o00000@3o
ool00003o`00003oogl0oomo08L0oomo1Ooo000W0?ooO`Goo`00HP3oogl10?ooo`7o00000@3oool0
0003o`00003oogl0oomo08L0oomo2?oo000T0?ooO`Goo`00HP3oogl10?ooo`7o00000@3oool00003
o`00003oogl0oomo08L0oomo2Ooo000T0?ooO`?oo`00H`3oogl10?ooo`7o00000@3oool00003o`00
003oogl0oomo08P0oomo2?oo002:0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0R03o
ogl8ool008X0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`280?ooO`Ooo`00R`3oogl1
0?ooo`7o00000@3oool00003o`00003oogl0oomo08P0oomo1Ooo002=0?ooO`40oooo0Ol000010?oo
o`0000?o00000?ooO`3oogl0R@3oogl3ool008h0oomo0@3oool1o`000040oooo00000ol00000oomo
0?ooO`3B0?ooO`?oo`00A@3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo0=40oomo1Ooo
00140?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0d@3oogl5ool004@0oomo0@3oool1
o`000040oooo00000ol00000oomo0?ooO`3A0?ooO`Goo`00A03oogl10?ooo`7o00000@3oool00003
o`00003oogl0oomo0=80oomo0ooo00150?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0
o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol0
00010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?oo
O`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0R03oogl3ool008l0
oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`270?ooO`Goo`00SP3oogl10?ooo`7o0000
0@3oool00003o`00003oogl0oomo08L0oomo1Ooo002>0?ooO`40oooo0Ol000010?ooo`0000?o0000
0?ooO`3oogl0Q`3oogl5ool008h0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`280?oo
O`?oo`00S`3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo0?l0oomo6`3oogl10?ooo`7o
00000@3oool00003o`00003oogl0oomo0?l0oomo6`3oogl10?ooo`7o00000@3oool00003o`00003o
ogl0oomo0?l0oomo6`3oogl10?ooo`7o00000@3oool00003o`00003oogl0oomo0900oomo0ooo0027
0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0S`3oogl5ool008H0oomo0@3oool1o`00
0040oooo00000ol00000oomo0?ooO`2?0?ooO`Goo`00QP3oogl10?ooo`7o00000@3oool00003o`00
003oogl0oomo08l0oomo1Ooo00260?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0T03o
ogl3ool008L0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`3o0?ooOa/0oomo0@3oool1
o`000040oooo00000ol00000oomo0?ooO`3o0?ooOa/0oomo0@3oool1o`000040oooo00000ol00000
oomo0?ooO`3o0?ooOa/0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`3o0?ooOa/0oomo
0@3oool1o`000040oooo00000ol00000oomo0?ooO`3o0?ooOa/0oomo0@3oool1o`000040oooo0000
0ol00000oomo0?ooO`3o0?ooOa/0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`3o0?oo
Oa/0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`3o0?ooOa/0oomo0@3oool1o`000040
oooo00000ol00000oomo0?ooO`3o0?ooOa/0oomo0@3oool1o`000040oooo00000ol00000oomo0?oo
O`3o0?ooOa/0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`3o0?ooOa/0oomo0@3oool1
o`000040oooo00000ol00000oomo0?ooO`1b0?ooO`?oo`00Y@3oogl10?ooo`7o00000@3oool00003
o`00003oogl0oomo0740oomo1Ooo002T0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0
L@3oogl5ool00:@0oomo0@3oool1o`000040oooo00000ol00000oomo0?ooO`1a0?ooO`Goo`00Y03o
ogl10?ooo`7o00000@3oool00003o`00003oogl0oomo0780oomo0ooo002U0?ooO`40oooo0Ol00001
0?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3o
ogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo
0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o0000
0?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?oo
O`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`00
00?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3o
oglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol00001
0?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3o
ogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo
0Ol000010?ooo`0000?o00000?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`0000?o0000
0?ooO`3oogl0o`3ooglK0?ooO`40oooo0Ol000010?ooo`00ool0000Po`000040oooo003oo`00023o
00000@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-6, -5.00005*^-6, \
0.00348436, 0.00348436}, {{0, 287}, {287, 0}} -> {-1.01089, -1.01089, \
0.00704453, 0.00704453}, {{0, 287}, {287, 0}} -> {-1.01089, -1.01089, \
0.00704453, 0.00704453}}]
}, Open  ]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 574}},
WindowSize->{693, 551},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 60, 0, 62, "Title"],
Cell[1817, 53, 281, 6, 46, "Text"],

Cell[CellGroupData[{
Cell[2123, 63, 42, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2190, 67, 53, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2268, 71, 36, 0, 43, "Subsubsection"],
Cell[2307, 73, 166, 4, 63, "Input"],
Cell[2476, 79, 174, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2687, 87, 53, 0, 43, "Subsubsection"],
Cell[2743, 89, 207, 4, 63, "Input"],
Cell[2953, 95, 84, 1, 47, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3086, 102, 40, 0, 49, "Subsection"],
Cell[3129, 104, 73, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3239, 110, 36, 0, 49, "Subsection"],
Cell[3278, 112, 130, 2, 63, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3457, 120, 59, 2, 39, "Section"],

Cell[CellGroupData[{
Cell[3541, 126, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3626, 130, 55, 0, 43, "Subsubsection"],
Cell[3684, 132, 157, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3878, 141, 39, 0, 43, "Subsubsection"],
Cell[3920, 143, 244, 6, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4201, 154, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[4265, 158, 249, 5, 79, "Input"],
Cell[4517, 165, 29448, 571, 296, 4483, 258, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[34026, 743, 60, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[34111, 747, 46, 0, 43, "Subsubsection"],
Cell[34160, 749, 147, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34344, 756, 43, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[34412, 760, 91, 1, 47, "Input"],
Cell[34506, 763, 453027, 11105, 333, 281148, 8980, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[487594, 11875, 51, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[487670, 11879, 158, 2, 63, "Input"],
Cell[487831, 11883, 49457, 1388, 296, 15022, 958, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[537349, 13278, 61, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[537435, 13282, 76, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[537536, 13286, 55, 0, 43, "Subsubsection"],
Cell[537594, 13288, 157, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[537788, 13297, 52, 0, 43, "Subsubsection"],
Cell[537843, 13299, 282, 5, 95, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[538162, 13309, 39, 0, 43, "Subsubsection"],
Cell[538204, 13311, 176, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[538417, 13319, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[538481, 13323, 251, 5, 79, "Input"],
Cell[538735, 13330, 29589, 573, 296, 4486, 258, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[568385, 13910, 60, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[568470, 13914, 46, 0, 43, "Subsubsection"],
Cell[568519, 13916, 147, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[568703, 13923, 43, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[568771, 13927, 91, 1, 47, "Input"],
Cell[568865, 13930, 445811, 11117, 333, 283559, 9111, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1014737, 25054, 51, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1014813, 25058, 158, 2, 63, "Input"],
Cell[1014974, 25062, 46901, 1229, 296, 12584, 801, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1061936, 26298, 52, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[1062013, 26302, 61, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1062099, 26306, 48, 0, 43, "Subsubsection"],
Cell[1062150, 26308, 203, 5, 63, "Input"],
Cell[1062356, 26315, 213, 5, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1062606, 26325, 55, 0, 43, "Subsubsection"],
Cell[1062664, 26327, 157, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1062858, 26336, 39, 0, 43, "Subsubsection"],
Cell[1062900, 26338, 229, 5, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1063166, 26348, 39, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[1063230, 26352, 251, 5, 79, "Input"],
Cell[1063484, 26359, 27810, 550, 296, 4494, 258, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1091355, 26916, 60, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1091440, 26920, 46, 0, 43, "Subsubsection"],
Cell[1091489, 26922, 147, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1091673, 26929, 43, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1091741, 26933, 91, 1, 47, "Input"],
Cell[1091835, 26936, 319713, 7147, 333, 235545, 6105, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1411609, 34090, 51, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1411685, 34094, 158, 2, 63, "Input"],
Cell[1411846, 34098, 42013, 1168, 296, 12640, 801, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1453920, 35273, 62, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[1454007, 35277, 61, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1454093, 35281, 48, 0, 43, "Subsubsection"],
Cell[1454144, 35283, 203, 5, 63, "Input"],
Cell[1454350, 35290, 201, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1454588, 35299, 55, 0, 43, "Subsubsection"],
Cell[1454646, 35301, 157, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1454840, 35310, 39, 0, 43, "Subsubsection"],
Cell[1454882, 35312, 229, 5, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1455148, 35322, 39, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[1455212, 35326, 251, 5, 79, "Input"],
Cell[1455466, 35333, 28743, 562, 296, 4483, 258, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1484270, 35902, 60, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1484355, 35906, 46, 0, 43, "Subsubsection"],
Cell[1484404, 35908, 147, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1484588, 35915, 43, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1484656, 35919, 91, 1, 47, "Input"],
Cell[1484750, 35922, 330547, 7481, 333, 239453, 6353, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1815358, 43410, 51, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1815434, 43414, 158, 2, 63, "Input"],
Cell[1815595, 43418, 54674, 1962, 296, 24786, 1588, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

