(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   7537760,     202595]*)
(*NotebookOutlinePosition[   7538496,     202621]*)
(*  CellTagsIndexPosition[   7538452,     202617]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Feature test for sky/ground classification", "Title"],

Cell[TextData[{
  "This notebook  assumes that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated."
}], "Text"],

Cell[CellGroupData[{

Cell["Local definitions", "Section"],

Cell[CellGroupData[{

Cell["Turn off integration warning message", "Subsection"],

Cell[BoxData[{
    \(\(Off[NIntegrate::ncvb];\)\), "\[IndentingNewLine]", 
    \(\(Off[NIntegrate::slwcon];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Read whole image", "Subsection"],

Cell[BoxData[
    \(\(ReadWholeImage[file_, \ 
          dir_: "\<.\>"] := \[IndentingNewLine]Module[{im, 
            d}, \[IndentingNewLine]im = 
            Import[dir <> "\</\>" <> 
                file <> "\<.ppm\>", \ "\<PPM\>"]; \[IndentingNewLine]im\
\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Read in split images", "Subsection"],

Cell[BoxData[
    \(\(ReadSplitImages[file_, \ 
          dir_: "\<.\>"] := \[IndentingNewLine]Module[{im1, im2, raw1, raw2, 
            d1, d2}, \[IndentingNewLine]im1 = 
            Import[dir <> "\</\>" <> 
                file <> "\<_A.ppm\>", "\<PPM\>"]; \[IndentingNewLine]im2 = 
            Import[dir <> "\</\>" <> 
                file <> "\<_B.ppm\>", "\<PPM\>"]; \[IndentingNewLine]raw1 = 
            im1[\([1, 1]\)]; \[IndentingNewLine]raw2 = 
            im2[\([1, 1]\)]; \[IndentingNewLine]d1 = 
            DeleteCases[
              Partition[Flatten[raw1], 3], {255, 255, 
                255}]; \[IndentingNewLine]d2 = 
            DeleteCases[
              Partition[Flatten[raw2], 3], {255, 255, 
                255}]; \[IndentingNewLine]{d1, d2, im1, 
            im2}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute 1D pdfs", "Subsection"],

Cell[BoxData[
    \(\(ComputePDF1D[data_, 
          which_:  Red] := \[IndentingNewLine]Module[{colors, pos, 
            d2}, \[IndentingNewLine]colors = {Red, Green, 
              Blue}; \[IndentingNewLine]pos = \(Position[colors, which] // 
                Flatten\)\  // First; \[IndentingNewLine]d2 = 
            N[\(\((#[\([pos]\)])\) &\) /@ 
                data]; \[IndentingNewLine]stats = {Mean[d2], 
              StandardDeviation[d2]}; \[IndentingNewLine]pdf1D[stats, 
            x]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["One-dimensional decision boundary", "Subsection"],

Cell[BoxData[
    \(\(ComputeDecisionBoundary1D[pdf1_, pdf2_, 
          x_:  x] := \[IndentingNewLine]Module[{sol, lpdf1, 
            lpdf2}, \[IndentingNewLine]lpdf1 = 
            Log[pdf1] // PowerExpand; \[IndentingNewLine]lpdf2 = 
            Log[pdf2] // 
              PowerExpand; \[IndentingNewLine]sol = \(\((#[\([2]\)])\) &\) /@ \
\((Solve[lpdf1\  \[Equal] \ lpdf2, x]\  // \ 
                  Flatten)\); \[IndentingNewLine]If[
            Length[sol] \[Equal] 1, \ \[IndentingNewLine]sol\  // \ 
              First, \[IndentingNewLine]If[
              sol[\([1]\)]\  \[GreaterEqual] 0\  && \ 
                sol[\([1]\)]\  \[LessEqual] \ 255, \ sol\  // \ First, \ 
              sol\  // \ Last]]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Expected error (1d)", "Subsection"],

Cell[BoxData[
    \(\(ExpectedError1D[pdf1_, \ pdf2_, \ 
          x_:  x] := \[IndentingNewLine]NIntegrate[
            Min[pdf1, pdf2], {x, 0, 255}]*100;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Expected error (2d)", "Subsection"],

Cell[BoxData[
    \(\(ExpectedError2D[pdf1_, \ pdf2_, \ x_:  x, \ 
          y_:  y] := \[IndentingNewLine]NIntegrate[
            Min[pdf1, pdf2], {x, 0, 255}, {y, 0, 255}]*100;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify image (1d)", "Subsection"],

Cell[BoxData[
    \(\(ClassifyImage1D[im_, db_, 
          which_:  Red] := \[IndentingNewLine]Module[{class, colors, pos, gr, 
            bl}, \[IndentingNewLine]colors = {Red, Green, 
              Blue}; \[IndentingNewLine]pos = \(Position[colors, which] // 
                Flatten\)\  // 
              First; \[IndentingNewLine]gr = \((List @@ 
                  Orange)\)*255; \[IndentingNewLine]bl = \((List @@ 
                  Blue)\)*255; \[IndentingNewLine]class = 
            Map[If[#[\([pos]\)] < db, gr, bl] &, 
              im[\([1, 1]\)], {2}]; \[IndentingNewLine]ReplacePart[im, 
            class, {1, 1}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify image (2d)", "Subsection"],

Cell[BoxData[
    \(\(ClassifyImage2D[im_, pdf1_, pdf2_, \ 
          which_: {Red, \ Green}] := \[IndentingNewLine]Module[{class, 
            colors, pos1, pos2, lpdf, gr, 
            bl}, \[IndentingNewLine]gr = \((List @@ 
                  Orange)\)*255; \[IndentingNewLine]bl = \((List @@ 
                  Blue)\)*255; \[IndentingNewLine]colors = {Red, Green, 
              Blue}; \[IndentingNewLine]pos1 = \(Position[colors, 
                  which[\([1]\)]] // Flatten\)\  // 
              First; \[IndentingNewLine]pos2 = \(Position[colors, 
                  which[\([2]\)]] // Flatten\)\  // 
              First; \[IndentingNewLine]lpdf\  = \ \((Log[pdf1]\  // 
                  PowerExpand)\)\  - \ \((Log[pdf2]\  // \ 
                  PowerExpand)\); \[IndentingNewLine]class\  = \ 
            Map[If[\((lpdf\  /. \ {x \[Rule] #[\([pos1]\)], 
                          y \[Rule] #[\([pos2]\)]})\)\  > \ 0, \ gr, \ 
                  bl] &, \ 
              im[\([1, 1]\)], {2}]; \[IndentingNewLine]ReplacePart[im, 
            class, {1, 1}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Colors representing two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Data colors", "Subsubsection"],

Cell[BoxData[{
    \(\(data1Color = Green;\)\), "\[IndentingNewLine]", 
    \(\(data2Color = Blue;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(style1\  = \ {data1Color, 
          PointSize[ .02]};\)\), "\[IndentingNewLine]", 
    \(\(style2\  = \ {data2Color, PointSize[ .02]};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification region colors", "Subsubsection"],

Cell[BoxData[{
    \(\(class1Color\  = \ RGBColor[1, 1,  .5];\)\), "\[IndentingNewLine]", 
    \(\(class2Color\  = \ RGBColor[ .5, 1, 1];\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(classColors\  = \ {class1Color, \ class2Color};\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Default plot range", "Subsection"],

Cell[BoxData[
    \(\(pr\  = \ {{0, 255}, {0, 255}};\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Image file names", "Section"],

Cell[CellGroupData[{

Cell["Image file names", "Subsection"],

Cell[BoxData[{
    \(\(TrainingFile = "\<blue3\>";\)\), "\n", 
    \(\(TestFile = "\<blue4\>";\)\)}], "Input",
  Background->RGBColor[1, 1, 0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set file names/paths", "Subsection"],

Cell[BoxData[{
    \(\(TrainingDirectory = "\<small_split_images\>";\)\), "\
\[IndentingNewLine]", 
    \(\(WholeImageDirectory = "\<small_whole_images\>";\)\)}], "Input",
  Background->RGBColor[1, 1, 0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set directory", "Subsection"],

Cell[BoxData[
    \(\(SetDirectory["\</Users/nechyba/Desktop/lecture5/sky_feature_selection/\
\>"];\)\)], "Input",
  Background->RGBColor[1, 1, 0]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["One-channel classification experiments", "Section"],

Cell[CellGroupData[{

Cell["Read in training and test images", "Subsection"],

Cell[BoxData[{
    \(\({d1, d2, s1, s2} = 
        ReadSplitImages[TrainingFile, \ 
          TrainingDirectory];\)\), "\[IndentingNewLine]", 
    \(\(trn = 
        ReadWholeImage[TrainingFile, 
          WholeImageDirectory];\)\), "\[IndentingNewLine]", 
    \(\(tst = ReadWholeImage[TestFile, WholeImageDirectory];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show training and test images", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{trn, tst}, {s2, s1}}], \ 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
%%ImageSize: 400 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0178571 0.47619 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0178571 0.477324 0.357993 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
D6DBD8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
6E8279687C71B2BCB8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7D918983969084989080928CA2AFABBFC8C6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
83968C8798938B9C9A8B9B9D89999D86969A869798A6B3B3E1E5E6FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
82978F8A9C978C9D9D8D9DA08E9DA38C9CA48A999E8B9B9E8B9C9E8C9E9EC5D0D0E3E9E8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7F948D899E9A8A9E9D8DA0A190A2A58EA0A58DA0A08EA09E8D9F9D8EA19F8EA39F8DA49D
8EA69BC8D4CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
859C928AA19B8DA39F8DA3A18DA2A08DA2A08DA29F8EA29D8CA09B8DA19C8EA29A8FA49B
90A79B90A79B94AB9DAFBFB3CAD5CDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
82978F89A1988AA39A8AA19B8AA19B8BA29B899F988A9D958DA19891A59C92A69D93A79F
93A79D93A69C95A79D94A69C97A99E90A297C5CECAE1E5E2FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
859B93879F9887A09986A09A879F978AA1978BA0978DA1998DA19A8FA29D90A49D92A59D
94A79E95A79E96A69F99A9A197A89F96A79E94A59B94A69A76857FB8BFBCD1D3D4FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
81948D899E968BA29B8BA29C899F9C869C99899E9B8CA09E8EA19F8EA1A090A4A090A39D
92A59E96A79F95A49E99A9A297A6A099A9A197A89E95A79E97ABA08EA195728177838A86
AAAFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
8294898BA0988CA49D889E9D889F9E879DA0889DA0899FA08DA1A08FA2A191A3A393A6A4
94A7A497A8A397A9A198AAA098A8A098A8A19BACA49AACA398ACA296ABA195AA9E8CA195
7E90846A7B6C78817AA2A5A2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
879B918EA39D8EA5A38BA4A48AA2A68BA1A5899FA1889EA08BA0A08DA2A292A6A493A6A4
93A6A394A7A396A9A196AAA099ABA19BACA39AAAA699AEA799ADA798ACA498ADA499AEA5
97ADA395AA9D8CA0906370685C6760B8C0BACFD1D2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
889E968DA49E8EA5A48DA4A68DA3A78CA2A78BA0A68A9FA38CA1A28EA3A390A5A491A6A3
93A8A295AAA296AAA294A7A098AAA39BACA69BADAA9AAEAB99ADAA9BAFAC99ADAA99ADAA
9AAFAA9AAFA79CB1A698AC9F87978E7887805D656852575EC0C6C2E0E3E0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
849A938BA19B8BA29E8CA1A0899EA08A9FA38CA1A58BA0A38CA1A38DA3A28FA6A591A9A7
92AAA595ACA596ACA395A9A598ABA997AAA998ABA89AACAB9AADAB9AAEAB9BAEAC9CB0AD
A0B3AEA0B4AD9FB0A7A0B3A67C8B83626B6A666F6E727B7999A89B94A397B1BDB4CFD8D1
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
8698958C9F9F8EA2A58B9FA5889DA2889DA18BA0A28CA1A18CA1A090A4A490A4A790A5AA
93A9AC92A8A993A9A697ABA89AAEAD98ACAD99ACAC9BADAC9CADAB9CADAAA0B1AFA2B2B0
A1B2ADA0B1ABA1B1ABA2B5AC899992656D6F666D6E8F9D949BAAA09FACA3A4B3A7A6B5A9
A7B6ABB8C2BCCCD1D0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
8899998D9FA58FA1AA8C9EA88B9EA78DA0A88FA2A78FA1A390A3A491A3A690A3A891A5A9
91A6A991A8A991A7A894A8A998ACAE96ABAF97ACAD9BAFAD9EB0AC9EADAC9FAEAFA1B0B0
A3B3B2A3B4B2A5B5AFA5B5AF9CACA895A3A08F9B9797A69EA3B2A7A5B2AAA7B5AEAAB6AF
AAB5B0ABB5B0A8B2ADA9B3ACD4DAD5EAEEEBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
849697899BA28DA0AA8D9FAB8B9DA98C9CA68D9DA68E9FA491A2A792A3A88FA1A693A6A8
93A8A992A7A892A7A994A8A99AAEAF9CB0B19AAEAD9AADAE9AAEAD9CAEAD9EAEACA0AFAE
A1B1AFA2B3AFA1B2ACA5B5AEA5B5ADA4B3AAA1AFA7A3B2A9A6B5ABA8B4ADA8B5B0ACB8B4
ADB7B3AFBAB6AEB8B3ADB9B2AAB4ACACB9ABABB9A4D5DBD1EAECE7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
819899889EA08BA0A58C9FA88B9DA88B9CA48C9DA38C9CA38E9FA590A2A790A3A792A4A5
92A5A693A6A992A7AA93A7A997ABAB98ACAC9CAFAE9AADAE9DB0B09AADAE9EB0B0A0B1B3
A2B1B5A2B2B4A1B1B1A4B5B2A6B5B0A6B3AEA6B4AEA5B3ADA5B3AEA8B5AEAAB7B1ABB8B3
ACB7B4ADBAB6ADBBB5AEBCB5ACBAB0AABAACAEBEABADBDAAADB9A8C2CCBFD8DFD6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
809697889FA28CA2A88CA1A9889DA68A9DA58C9DA58E9FA88E9FA98E9FA890A2A993A5AB
92A4AA93A6AD94A7AD94A7AC95A6AB96A7AC99ABAF9AABB19CADB29DADB49FAFB5A2B3B8
A2B1B7A2B0B5A2B0B5A2B1B4A6B4B6A6B2B3A8B5B5AAB7B6A9B6B4A9B5B0AAB6B0ACB9B5
AFBBB8AEBBB8ADBBB6ADBBB4ADBCB1ADBCADB1BFADB1BFADB1BFAEB2BFAFB0BDAFB2BDB1
C2CAC2D7DFD8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
839699899EA38DA2A98B9FA9899EA78A9EA68B9CA48DA0A68FA1A98D9EA793A4AB93A3AB
94A6AD93A4AC94A6AD94A4AC95A4AC95A3AC95A4AC96A6AD9AA9B09BA9B09EACB3A2B1B7
A3B2B8A4B1B6A4B0B5A6B2B6A4B1B5A7B3B4A8B3B3A8B4B3A9B5B2ADB8B4ACB8B6ACB8B6
AEB9B7AFBAB8ADBAB7AEBDB5AEBDB3AEBDAFB1BFB0B3C0B0B2BFAEB3BFAEB3BEAEB6C0B1
B4BFB0B1BFB0ADBBADD2D9D1E5EAE5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
76868C8C9FA1899DA48599A48497A3869BA4889BA38D9FA68EA0A88FA0A98E9FA791A2A9
92A3AB92A4AB93A5AB93A4AA96A6AD99A7AE99A8AF97A7AE97A7AE9AA8AF9AA8AF9BA9AF
9DACAFA1AFAEA3AFAEA7B3B3A6B2B5A6B1B4A6B2B1A7B3AFA9B3B0ACB7B4ADB8B7A9B4B3
AAB6B6ABB8B6ABB9B4ABBAB2ABB9B0B0BFB2B0BFB0B0BDADB0BDACB3BFADB3C0ADB5BEAC
B4BFACB5C1AFB4C0B0B1BEADAFBDAA97A491BEC0BADCDDDAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7C8E90839899879CA1879BA48497A38497A48496A38B9BA78E9EAB8E9FAC8D9FA98C9FA8
8FA3AB8DA1A890A4A891A4A894A6AA95A8AB96A9AA96A9AA98ABAB98AAAC98A8AB9CAAAE
9DACAE9FB0ACA3B2AEA4B1ADA7B4B0A9B5B1AAB6B1A9B6B1A9B5AFA8B4AFAAB7B3A8B4B3
A9B6B6A9B6B5AAB7B3ACB9B4AFBBB5AEBBB1B0BEB1B2BFB1B1BEAFB2BEAEB3BFACB5C0AC
B4BEACB6C0AFB5BFB0B5C0AFB6C0AEB4BDACABB4A3A7B09EBDC3B7CBCEC8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
819591899B9A8B9EA2889BA38496A28597A2879AA38A9BA28C9CA38C9DA58D9EA68D9FA6
8DA1A88EA3A88FA2A590A4A692A5A991A5A790A5A693A7A795A7A797A8A99AA8AB9DABAC
9DAAAB9FACACA2AEAFA3AFB0A4AFAFA7B2AFA7B2AFA9B5B1AAB6B1AAB5B0A9B4B1AAB8B4
A8B5B4AAB8B4A9B6B0ACB9B2AFBAB2AEB9AFB0BCB1B3BFB2B3BFB2B3BFB1B5BFB0B4BFAD
B5BEADB7C1AFB8C3B1B6C2B0B7C2AEB6C0ABB6BEACB5BDACB4BEAAB3BDA8ACB8A2BEC7B7
A4A1A3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
768886869B9A889DA1879CA3879AA48699A6889CA8899DA68B9EA68C9FA58C9FA58B9EA5
8A9FA68DA2A68FA3A592A5A791A5A892A8AC90A7A894AAA995A8A699A9A89BABA99FAEAC
A1ADAEA2AEAEA6B0B2A8B1B2A5AEB0A9B3B2A9B3B0ABB5B2AAB4B0ABB5B2ABB5B2ADB8B5
ADB9B4ABB7B1ADBAB2AEB9B2AEBAB2AFB9B0B1BCB2B2BDB2B3BFB3B5BEB3B4BFB0B6BFAF
B6BFADB8C2AEB7C1AEB7C1AEB6C0AFB5C0AEBAC4B1B9C2AEB9C2ADBAC3ADBAC4ACBDCAAD
7D7F73494343A8A7A3E2E5DEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
748886809597869AA1889DA7889BA8899CAA889AA9899DAA8B9EAA8A9EA78DA1A890A2A9
8FA1A991A3AB91A4AA91A4A893A7AA96A9AE94A7AD95A9AE99ACAF9AABAE9CABAE9EABAE
9EADAFA1AEB0A4B1B2A7B2B2A5B0B1A5B1B2A8B6B4A9B5B2ABB7B4ACB6B7ACB7B8ADB8B9
AFBBB8B0BBB7B1BDB6B1BCB7B2BBB6B1BAB5B3BEB7B3BFB7B4BEB5B3BFB3B5C1B3B6C1B0
B8C1AEB9C1ADBDC5B1BBC2B2BBC2B4BBC3B6BBC2B5BDC3B6BEC5B4BDC6B1BCC6ADBECAAC
B7C3A47D816F5E5A55B1BCA1989E8CD4D9CEE8EBE5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
71848582959B8599A3869AA68497A58599A58598A5869AA5889DA68BA0A88DA1A78C9FA7
8C9EA98EA2AB8FA5AB8BA0A68DA3A691A6A995A9AE96AAB197A9B397A9B29BABB29CABB0
9BAAAF9EADB19DADB09FADB1A0ADB2A3B0B3A6B3B4A6B4B4A8B5B7A7B3B7A8B2B6ABB5B8
ACB6BAACB5B8AEB8B7ACB5B4AFB6B5B0B8B5B1BCB9B0BCB8B3BFB8B2BDB5B3BEB5B5BEB2
B6BFB3B7BFB2BAC0B1BAC0B4BCC2B8BAC2B9B9C1B7B9C2B4B9C3B4BBC4B2BAC4ACB8C3A9
B8C2AAB5BEA9AFB4A3B4BAA7B6BDABB5BFAAB2BDA6C4CCBAB0B0AEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
79898C81939D8093A18093A28195A28598A38599A28498A1879BA4899DA58BA0A88A9FA8
8B9FA98B9FA78AA0A88BA0A88C9FA690A2A995A7AE94A5B095A6B297A6B298A5AF9AA9B1
9CABB29CAAB19CAAB29DABB3A0AEB4A3AEB3A4AEB3A4AFB4ABB4B8AAB3B7A9B2B7AAB3B9
ACB3BBACB4B9ADB7B8ADB6B6AFB6B4AFB6B3B2BAB6B2BBB7B3BCB6B3BDB6B4BFB4B3BEB2
B2BDB0B4BEB0B5BEB0B6BFB2B9C2B6B8C2B6B7C4B6B5C2B5B5C2B2B6C3AFB7C3AEB9C4AE
BAC3ADBCC3AEBAC1ABBBC1ADB9C0ACBBC3ADBDC4ABBAC3A9ACB19DA9AD9AC1C6B5EDEFE8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7B8A9081949E8498A48398A38296A28396A18497A28699A48699A6879AA68B9DAB8A9CA9
8B9EA88EA1A98CA0A88CA0A88EA1A990A3AA93A4AC94A7AD95A4AE96A4B19AA8B49AA7B5
9CAAB69FABB49FACB5A0ACB7A3B0B9A4AFB7A6B2B6A6B1B4A8B2B3A8B1B3A8B1B4ACB6B7
AEB7B9B0B9B9B0B9B8B0B9B7B0B8B3B1B9B3B4BDB5B4BDB4B5BDB5B4BDB3B4BDB2B3BDAF
B4BFAFB4BFAFB4BEAEB5BEB0B6BFB0B4BEB0B6C1B2B8C4B4B8C3B3BAC5B3B9C4B3BAC3B2
B9C3ADBAC3ACBDC6ACBFC6ADBFC6ACBEC5ACBEC5A9BEC6A9BFC7A9BCC3A8BBC2A6BBC3A5
BAC3A3DDE3D2EEF0E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
76878C80949A83979E849AA08397A08699A48597A38597A68699A6899BA78998A58C9CAA
8C9DAA8E9FA88FA2A991A4AA8FA1A990A1AA90A1AE94A4B098A6B097A4B198A5B39BA7B5
9CAAB69CABB49CAAB39EADB6A0AFB7A0ADB4A1AFB2A4B1B2A7B1B1A9B2B1ABB4B4ACB6B6
ACB4B6ADB7B7ADB6B6AEB9B6AEB9B4AFBBB2B0BCB1B2BEB1B3BDB3B2BCB2B2BDB3B3BEB3
B2BCB1B8C2B4B8C2B3B8C1B3B9C2B3B9C3B0B9C4B1BAC4B2BCC5B4BBC3B4BCC6B7BBC4B6
BCC5B4B8C2AEBAC3ADBDC5ACBFC7ABBFC8AAC0C7A8C1C8A7BEC5A6BFC7A8BFC7A6C0C8A5
BEC8A3BBC6A1BAC69EB6C19ADCE3CEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7081887E929883969E85979F84969E8598A08697A18798A28698A28697A08899A28C9CA5
8C9BA78D9CAA8F9FAB8F9FA890A1AA94A2AC95A3AE95A3AE96A3AE9BA7B19BA7B39AA6B2
9AA7B39CA9B39CAAB29BA9B29CA9B39EACB3A2AFB4A4B0B3A6B0B1A8B2B0ABB3B2ACB6B6
ACB5B8ACB5B7ACB5B8ADB6B7ADB8B5B0BBB4B0BBB3B0BBB2B4BDB3B4BDB4B4BCB5B6BDB5
B8BFB5B9BEB4BBC1B5BBC0B6B9BFB5BAC2B4B8C0AFBAC2AFBDC3B3BDC4B5BAC1B4BEC5B6
BEC6B3BDC6B0BCC6AEBEC9ADBEC9ABBDC7A6BFC8A4C1C8A5BEC5A5C1C7A8BFC6A6C0C5A5
C1C7A5BEC8A3BCC6A2BBC6A1BCC7A0BCC89FC0C7ADD0D2C3FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
73848C80929A8397A08597A18496A08496A38396A2879BA4879BA2879BA18C9EA58D9FA7
8E9EA98E9CA8909FAD93A3AF95A2AE96A4AF97A4AF96A4AE99A6AE9AA8AE9AA8B19CAAB5
9BA9B59DA9B49DABB5A0AEB79EADB49DABB1A1AFB1A2B2B0A5B3B0AAB6B2A9B3B0ADB5B3
ABB3B4ADB6B8AEB7BBAEB9BBAFBABBB0BBBAB0BBB7B2BEB8B4BEB6B4BCB3B4BCB3B6BFB8
BAC3BBBABFB7BDC3B9BABFB7BABFB4B9C0B3BAC3B3BAC2B1BFC6B4BFC5B4BEC3B4C1C7B5
C1C8B2BFC7AEC0C8B0BFC8AFBEC8ABBEC7A8C0CAA7C1CBA7BDC7A5BFC8A8BEC7A7BEC6A7
C0C9A9C0C9A6BDC7A2C1CCA5C1CBA5BFC9A4BEC7A2BDC7A2B9C3A0CED5BCEFF2E9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7A8F8E869B9C899EA38899A48594A38696A78596A78698A7879BA8879BA4889BA48D9EA8
8D9EAB8EA0AB8DA1AD8FA2AD90A1AD93A3AF94A4AD93A4AC97A7AE99A7AF9AA7B09BA9B3
9FABB49EAAB29FABB39FADB3A0AEB4A1AFB1A1B0B1A3B2B4A3B3B2A5B3B0A6B1AFAAB4B0
AEB7B4AFB7B6AEB7B7AFB8B7AFB9B7AEB7B5B0BBB7B0BBB7B0BCB7B0BBB6B2BBB6B5BDB8
B8C0BBB6BCB8B7BFBABBC1BBBBC2B8B9C2B6B9C1B4BAC3B3BBC4B3BEC5B5C0C7B7BCC4B2
BDC4B0C1C9B2C0C7B0BFC7AFBBC5ABBBC5AABFC8AABEC9A9BCC7A8BDC6A8BDC5A7BEC7A8
C1CAA9C1CBA8C1CBA6C2CCA8C1CBA6C0CAA6BEC7A3C0C9A5BFC8A7BEC7A7BDC6A6BAC5A4
D7DCCCE6E8E1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7D909284969E8799A38796A48793A78996AC8999AE879AAC899DA9889DA4899CA38A9EA4
8A9EA78C9FA88DA1A98EA1AA91A2AC91A2AE92A3AD92A4AC96A8AF97A6AE9AA7AF9AA7B1
99A6B09DAAB29EABB1A0ACB2A1ACB19FAAAFA1AFB1A4B2B4A5B2B4A4B2B4A5B0B2A8B2B2
ABB4B5ACB4B6ADB6B6AEB8B6ACB6B5ABB5B4AEB8B6B1BCBAB0BBB9B0BBB8B1BAB7B3BDBA
B3BCB9B5BDB9B6BEB9BAC0B9BBC2B9BABFB6BABEB8BBC0B8BBC1B8BBC2B8B9C1B7BAC2B6
BBC4B3BDC7B3BDC6B1BEC8B1BEC8AFBEC6ADBFC7AEBFC6ADBFC7AEBFC7AFC1C9B0C0C6AD
BEC3ABC0C6AAC0C9AAC1CCA8C1CBA7C0C9A8BEC8A7BFC8A9BEC7AABFC8AAC0C8A9BDC5A8
BBC4A7B6BFA4B8C1A6DCE1D3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
8291958695A08998A88797AA8896AC8695AC8392A98395A9879BA9899DA88A9EA78C9FA9
8DA0AA8EA1AB8EA2AC92A3AD91A0AB94A2AE94A3B096A6B295A5AE9AA8AF99A7AD9BA7AD
99A5AE97A4AD9CA9B09EABB1A1ACB1A2AEB3A1AEB1A3B1B3A3B0B0A4B0B2A6AFB2A7AFB2
A9B2B4AAB4B4AAB3B3AEB8B6B0BABBAFB8BAAEB7B8ADB7B7AEB9B9B1BABBB3BCBCB5BCBC
B5BCBDB7BCBDB8BDBCBBBFBDBBBFBDBCC0BCBBBFBABCC1BBBAC0BABCC4BCBCC4BABBC4B7
B9C3B2BBC5B3BCC5B2BDC7B3BDC7B3C0C8B6C1C8B5C0C6B4BFC6B4BEC5B2C1C7B2C3C8B2
C3C7B0C3C7B0C1C7ACC3CAADC1C7A9C2CAACC2CAAEC1C9AFC0C8ADC0C8ACBFC6AAC1C9AC
C0C7ACBDC5AABBC2A8BBC4A8B8C3A6C8D0B9D7DDCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7E8F958495A18698A78495AA8395AC8495AB8396AA8598A9869CAA869CA8889BA88B9DAA
8E9FAC92A3AF91A0AD92A0AD94A1AD97A4B199A4B398A5B398A6B398A8B09AA8AF9AA8AE
9EACB19CA8B09BA8AF9DAAB0A0ADB2A0AEB29FACB2A0ADB3A3B0B5A4B0B5A7B1B6A8B2B5
AAB3B7ABB5B7AAB6B5ADB8B6ADB7B7B0B8BAB1BBBEB0BABCAFBAB7B1BCB8B5BCBBB7BDBC
B7BBBBBABEBEBBBFC1BDC1C3BCC0C3BCC0C1BCC0C0BCC0BFBABFBCBBC2BDBAC2BBBDC6BA
BFC8B9BEC5B6BEC5B5C0C6B7C0C6B7BFC5B6C0C6B7C1C8B8C1C9B9BFC8B8C0C8B7C1C8B6
C3C8B4C5C9B4C3C8B1C5CAAFC2C8ADC2C9AFC3C9B1C3CBB1C3CBB2C1C8AFC1C9ADC1CAAD
C1C9AEC1C9B0C0C9AFBEC7ACBEC9ADBCC7ABBBC7AAB7C3A6C6CFB9ECEFE8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7A8D948295A1879BA98698A98394AB8293AA8496AA8698AB8699AC889BAD8A9DAF8D9DAF
8EA0B091A2AF92A1AE95A1AF949FAF96A2B196A2B196A3B199A7B298A6AF99A7AF9BA8AF
9EACB19CAAB0A0ADB29EAAB1A2ADB4A3AFB6A6B1B7A3AFB7A4AFBBA5B0BDA5B1BAA4AFB7
A6B2B8A7B3B8A9B6B9ABB8BAACB7B8AFB9BAADB6BAB0B9BEB0B9BCB1BBBCB4BBBDB6BBBE
B6BABDB7BCBEB8BEC1BBBFC2BDC2C2BBC1C0BBC2C0BAC1BEBAC1BCBDC3BCBCC2B9BFC6B9
C2CABABDC5B5BEC4B3BEC5B3BDC4B2BEC6B4BEC4B6C0C7B8C0C8B9C1C9B9C1C9B6BEC6B3
C1C7B3C5C8B2C5C9AFC4C7ACC4C8ACC5C9B0C4C8B1C5C9B3C4C9B2C3C9B0C2C9AEC3C9AD
C4C9AEC3C8AEC3C9AFBEC5AEBDC4ADBFC7AEBEC6ACBDC6AABBC5AABAC4A8B9C3A6DBE1D2
ECEFE8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7D8E9181939B8598A38697A78394A68898AA8897AA8999AE8596AE8697AE8899B08A9CB2
8C9EAF91A3B092A3AF92A0AE94A1B094A2B294A3B195A4B297A5B39BA8B59DA9B69DABB7
9BA8B59CAAB4A0ACB2A1ACB2A2ADB3A3AEB4A3AEB6A3ADB7A2ACB9A4AEBDA4AFBDA5B0BC
A6B1BCA8B5BDA7B4BCA9B4BDACB5BDADB5BDAEB6BEADB5BEB0B8C1B1B8C0B3B9BEB5BCBF
B5BCC0B8BFC2B6BEC2B8C0C1B4BCBDB6C0BFBAC3C1B9C2BFB8C0BDBDC4BEB9BFB9BBBFB8
BEC4B8BEC5B7BFC8B8C1C8B6BFC5B4C0C7B6BEC4B6BFC6B7C0C8B8C1C8BAC1C8BAC2C9B6
C4C9B2C4C9B0C5CAAFC5C9ADC6CBAEC3C7ADC5C8B1C6CAB5C5C9B5C6C9B4C5C9B1C4C8AF
C5C9AFC6C9B1C6CAB3C3C8B3C2C8B4C0C6B1C0C8B0BFC6ADBEC4A9BEC7A9BEC7A7BAC6A6
B6C3A6A8B29AD7DDD0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7A8C8F82939B8395A18596A68596A58796A68999A78797A88596AA8699AB899CAE8A9DAF
8B9FAD8C9FAD8DA0AD8FA1AE90A0AE91A0B291A0B191A1B198A6B49AA7B599A5B59AA5B6
9AA5B89DAAB89EACB6A0ACB5A1ADB4A0ADB6A0AEB6A2AFB5A3AFB8A6B1BDA6B0BDA5B1BE
A5B1BFA6B2BFA6B2BFAAB3C0ACB5BFAFB7C0AFB7C0B2B9C2B0B7C2B2BAC3B0B9C0B3BDC1
B5BFC2B6BEC2B5BFC1B6BFC0B8C1BFB6BEBCB4BCBAB6BEBCB5BEBBB8C1BDB9C1BBBBC2B9
BEC4B9BEC3B9C0C6BDC1C6BEBEC3BABFC3B9BEC4BABEC3B9C1C7BBC0C6BAC0C5BAC3C9B9
C7CBB9C4CAB3C2C8B0C5CCAFC5CAACC6CAAEC5C9B1C5C8B2C5C8B2C2C6B2C6CAB4C3C7B2
C3C6B2C2C6B1C4C7B1C3C5B2C5C9B6C2C6B3C2C6B0C1C5AEC0C6ACBFC6A9C0C8A9BDC5A9
BBC4AAB9C3A9B5C0A7B3BFA8C5CEBDCCD1C8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
788A928397A08699A78497A78597A88597A68696A68698A88496AA879AAC889DAB899DAB
899EAC8A9EAC8A9CAA8B9EAA8D9EAC90A0B191A0B393A2B696A3B698A6B69BA8B799A5B5
9BA7B79CA9B79CABB69DABB69EADB79EADB7A0AEB8A2AEB8A6B2BAA7B2BBA6B1BBA5B0BA
A6B1BDA5B2BDA7B3BDA9B3BEAAB2BEADB6C0AEB7BFAEB7BEAEB6BEAFB9C0AEB8BEAFB8BF
B0B9C0B1BAC0B3BBC0B4BABEB5BCBFB6BEBFB6BEBFB6BEBEB6BDBDB8C0BBB9C1BBBBC1BA
BBBFB9BBBFBABEC3BDBFC4BEC0C6BEC1C8BEC0C7BEBEC3BDBDC3BBC0C6BCBFC5B9BFC5B6
BDC2B1C0C6B2C0C7B2C0C8B0C3C9AFC3C7AFC4C7B1C1C5B1C3C7B3C1C7B3C2C9B4C3C8B3
C1C7B3C2C6B2C4C9B4C1C6B3C4C9B6C3C6B4C1C4B1C2C5B1C0C5B1BEC5ADBEC5ACBDC4AA
BEC7AEBCC7ADB6C1A8B5C0A9B6BFA9B5BFA8B3BFA6BFC7B7EAECE7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7F93998396A0869AA68598A8879AAB879AAB8395A88599AB869AAA869AA98699A7879BA8
8A9FAC8CA0AD8EA2AF8FA2AF91A3B191A1B293A1B595A1B795A2B696A3B598A5B59CA8BA
9AA7B89BAAB79CACB69EADB6A2AFB7A2AEB6A3AFB9A4AFBAA5AFBBA8B3BBA9B4BBA8B4BB
A8B4BBA8B4BCA7B2BCACB5BFACB4BEADB6BFACB6C3ACB6C2ADB7BFADB7BEAFB9C0B1B9C2
B2B9C0B1B8BFB4BBC0B5BBC0B6BCC1B6BEC2B4BEC1B4BEC0B6BDC0BAC2C2BAC0C0BBBFBF
BCC1BFBCC1BDBDC3BDBCC3BCBBC3BCBBC4BCB9C1BCBEC4C0BEC4BEBDC3BDBCC2BCBFC4BC
BFC5B8BEC4B5BDC3B5C0C6B6C0C6B1C2CAB3C1C8B1C0C7B1C2C8B3C3C7B3C2C7B3C4C9B4
C6CAB6C5C9B6C1C6B4C2C6B4C4C8B5C4C7B6C2C6B4C1C6B4BFC5B2C1C7B0BFC6B0BFC6AF
BEC6AEBEC7AEBDC6ADBBC2ABBBC2ABBBC2ABBAC2ACB5BDA9B5BEAAB1BDA4D4D9CEE6E7E3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7A8C978396A18599A88598AD8698AD869AAE869AAD889DAC859AA8899DAB899DAD899DAB
8BA0AC8EA3AD90A4B08FA3AF90A3B193A3B494A4B794A4B894A4B697A7B697A7B59AA9B8
9CABB99DACB79FAEB89FAEB7A3B0B8A6B3BAA6B0BBA4AEBAA7B1BCA9B4BDA9B4BBAAB6BD
ABB6C0ABB7C0AAB7BFABB9C0ACB9C0ADBBC2AAB6BFADB9C4AFBAC4AEBAC2AFB8C0B2BAC3
B3B9C1B4B9C0B5BBC2B6BCC2B9C0C5B7BDC5B7BEC5B9C2C7B9C1C4BCC4C4B9C2C0B8C0C0
B8C0BEBAC2BDBBC4BDBBC4BCBBC4BABBC3BCBDC4BDBFC7C0C0C5C2C1C6C2C1C6C2C3C8C5
BFC4BFC1C7BDC3CABEC2C9BEC1C8B9C3CCBAC3CBB6C4CCB5C5CDB6C4CCB5C3CAB5C2CAB6
C2C8B7C3C9BAC1C8B9C2C9B9C2C8B8C2C9B9BFC5B7C1C6B7C0C6B6C3C8B5C3C9B5C2C8B5
C1C8B6C0C6B3C2C8B2C2C8B1C1C7B1BFC6AFBFC6AFBEC4AEBDC5B1BBC3B0B7BFADB4BCAA
AAB39FD3D9CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
788A968092A28496AA8496AD8395AE879AB18599AC8698A98598A78799A88C9EAC8C9EAB
8C9FAA8EA2AB92A4B091A3B08F9FB08F9FB28FA0B391A3B493A4B395A6B298A8B498A7B2
9BABB69BABB69CACB59FADB5A1AFB7A2AFBAA6B0BBA2ACB7A5B0B9A8B2BBA9B3BBAAB5BC
AAB5BDACB6BFACB6C0ABB8C1ACB9BFAAB7BCAAB7BDADB7BFB1B9C1B2BAC3B4BBC4B5BAC3
B4BAC3B5BBC3B7BCC3B7BAC2B8BBC4B6BAC3B8BCC4BAC0C3BAC0C3BBC1C2BBC0C0BBC1C0
BBC1C1BBC2C1BCC5C1BDC5C0BAC2BABFC5BBBDC2B9C0C5BDBFC4BDBFC3BDBFC3BFC0C5C1
BFC4BFC3C7BEC1C6BCC0C5BAC1C8BAC0C7B6C1C8B5C4C9B4C5C9B6C6CBB9C3C8B8C2C8B8
C1C7BAC1C7BCC1C9BDC1C8BCC1C8BAC3CABAC1C7B8C1C7B6C3C7B3C4C8B3C5C9B6C5C8B7
C3C7B8C3C7B7C4C8B5C2C6B2C1C7B2C0C6B0C0C6B0BFC4B1BEC4B3BCC2B1BBC1B0B8BEAE
B6BCAEB5BDADA8B0A0B8BEB2C6C9C4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
798B968192A28696A88696AD8091AA8192AA8094A68396A68699A5899BA68999A7899AA8
899BA98A9DAB8D9EAC8F9EAD93A0B08F9DB0909FB290A1B393A5B495A7B295A5B098A7B4
98A7B797A7B59BABB69FADB7A0ADB8A0ABB7A1ABB8A1ABB7A4AFB8A6B0B9A8B0BAA9B1BA
A8B1BCA7B1BEA7B1BDAAB5BFAAB5BFABB6BFADB8BFAEB7BDB1B7BDB1B8BCB3B9C1B4BAC2
B3B9C1B4BAC2B6BBC2B7BDC0B8BDC3B6BBC2B5BBC0B5BBBEB7BDBFB8C0BFB8C0BEB9C0BF
B7BEBDB7BEBEBAC1C1BABDBEBABEBCBBBFBBBCC1BBBDC2BBBEC3BDC0C5BFBFC3BFC1C3BE
C3C5BFC2C5BDC1C3BBC3C6BDC1C6BBC1C7B8C2C7B6C2C6B3C3C8B5C3C9B6C0C7B4C1C8B8
BEC4B8BEC3BABEC3B9C0C8B9C1C7B9BFC5B7C0C7B7BFC5B5BFC5B2C3C8B2C3C6B0C2C4B1
C2C6B2C1C6B1C1C5B0C1C5B0C0C5B2BCC2B0BDC2B1B9BEAFB8BDAEBCC1B1BAC0B1BAC0B2
B9BEB2B8BDB0B6BAACB3B8AAB1B7AAA0A699B4BBAFE7EAE5FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
758A927E929D8294A38393A78293AA7F90A98094AA7F94A78497A68497A78799AB8899AC
879AAB889CAB8A9BAA8C9CA98E9EAD8F9DAE91A0B28E9EB18FA0B492A3B592A0B396A4B5
96A4B597A5B49AA8B69DABB89FABB7A0AAB8A1AAB9A2ABB9A2ACB7A2ACB4A6ADB5A8AFB8
A9B1BBA9B3BEAAB4C0ABB4C1ACB4C4AAB2C1ACB4C2ADB4C3B2B8C3B0B7BFB3B9C1B3B9C2
B3B9C2B4BAC3B4B9C1B5BAC1B8BDC5B8BCC6B6BBC4B4B8C0B4B9C1B5BBC1B6BCC1B5BCC0
B5BDC0B6BCBFB7BBBEBABDC0BCC0C2B9BCBDBABDBCBCBFBEBEC1BEBFC2C1BFBFC1BFBFC0
BFBFBFC2C1C0C0BFBFC1C2BFC0C2BFBEC1BDC0C5BEC3C7BDC1C7BCC1C6BCBEC3B9BEC4B9
BEC4B9BEC3B8BFC3B6C0C5B6C4C6B8C3C5B8C1C5B6BFC3B4BFC5B3BFC5B2C4C7B3C3C4B3
C1C3B4C1C5B8BEC2B5BDC3B5BBC1B4BAC0B4BEC4B5BBC0B2BABEB1BABFB1BBBFB3BBC1B5
B8BCB2B8BCB1B6BBAFB4BAAEB4BBB0B1B9B0AEB6ABABB4A8A7B3A2D2D7D0D7D6D8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
788E937C929B8296A18295A48092A58092A88093A98396AB8396AA8597AA8899AE8C9DB2
8B9BB18D9FB18B9BAD8D9BAE8F9EB0919EB092A0B193A1B495A3B695A4B797A5B695A3B4
95A4B496A3B49AA7B89DAAB99FACBAA0ABBAA0A8BBA3A9BBA4AAB9A5ABB9A4AAB6AAB0BB
ACB4BFACB2C1ABB2C0ABB3C2ADB5C3ADB4C2ADB3C5B1B6C7AFB5C5B1B6C4B3B8C3B4B8C3
B4B7C4B4B8C4B5B9C3B7BAC3B6B8C1B9BDC6B6BCC5B5BAC3B6BCC5B4B8C2B7BBC3B8BEC6
B9C0C8B6BCC4B7BDC3B7BDC1BABFC2BCC0C3BBC0C1BCC0BFBDBFBDBFC0BFC1C1C2C0C0C2
C0C0C3C2C0C2C2C1C4C1C0C3C2C1C3C1C1C1BFC0C0C0C3C2C1C4C2C0C5C0BDC2BDBEC3BD
BEC3B9C1C3B9C0C2B7C1C3B7C3C4B7C4C6B8C3C5B6C2C5B5C3C6B6C2C4B5C3C5B6C3C5B5
C2C3B7C1C2BABDC0BBBDC2BBBDC2BBBCC1B8BBC1B6BBC0B3BCC1B4BAC0B2BAC0B0B9BFAF
BAC0B2B9BEB1B8BDB1B5BAAFB4BAB0B5BAB1B3B9B0B0B7ADAEB7ACAEB7AF929797919995
9C99A2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7587948094A08195A38397A77F93A38092A38091A58395A88494AA8394AB8796AE8997B0
8998AF8C9AB08C9CB18C9BB08E9AB0909AB1929DB395A1B497A3B696A1B597A3B697A4B5
99A7B59AA6B59BA7B79BA7B69BA5B69DA8B99DA5B9A2A7BBA5A9BDA6A9BCA7A9BEA9ACBF
ABAEC0ACB0C2ADB1C3B0B6C4AFB6C3AFB5C3B0B6C6B2B7C7B0B4C4B1B5C3B1B5C2B3B7C2
B4B7C0B4B7C0B5B8C2B4B7C0B5B9C0B5B9C1B6BAC1B4B9C1B6BBC2B9BCC3B7B9C1B9BCC3
BABEC4BABDC3B9BBC2B9BBC2B9BCBFBABEBFBCBFBEBCC1BCBCC1BBBEC2BBBEC2BABFC0BB
BEBEBBBBB9B7C0C0BCC1C0BEC0BFBDBFBEBDC0C0BEC0C1C1BFC0BFBDC0BEBDC1BCBDC1BA
BEC3B8BCC0B4C0C2B6C2C2B6C1C2B6C0C1B6C0C3B6C0C4B5C1C3B3C0C2B1C0C1B0BFC0AE
BEBFB0BFC0B3BDBFB5BABEB7BAC1B8BBC2B8BDC3B7BBC1B2BBBFB1BABFAFBABFADBAC0AC
BBC2AEBBC0ACBBC0ADB9BEAFB8BCB0B7BBAFB5BAACB4B8ABB2B7ADAFB7ADACB6AAAAB4A7
91998D5C5C5885837D948E90FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7586927B8E9E7E90A37E90A67D8FA57C8EA37F90A78092A88294AA8394AD8697AF8897B0
8896B18D9CB48C9CB28E9DB58F9DB5919EB5929EB692A0B795A2B896A2B898A3BA96A2B9
99A4B99AA7B89AA7B798A4B49BA7B79DA8B9A0A9BCA1AABEA4ABBFA6AABFA8ADC2A6AAC1
A6AAC1A8ACC1A9AEC2AAB0C2AAB1C2ACB4C4AEB5C4AFB5C5B0B7C7AFB7C4AFB7C2AFB8C2
B1BAC3B2BAC2B2B9C1B2B8C1B2B8C0B4BBC1B4BBC0B3B9C1B5BCC4B7BCC3B8B9C3B9BAC3
BABBC4B9BAC2BABCC3B8BAC0B9BCBFBABFC0BAC1BFBAC1BBBABFB9BBC1BABBC1B9BDC3B9
BBC0BABDC1BCBDC1BCBEC3BFBCC1BCBDBFBBBDC1BDBEC2C0BDC3C1BDC3C0BDC3BEBABFB9
BCC1BABEC4BAC0C4BAC0C2BAC1C1BBC2C4BDBCBFB9BEC3BABDC2B7C0C5B6C1C4B5BFC2B3
BEC2B4BDC0B6BEC2BBBEC4BDBAC0BBB9C1B8B9C2B8B8BFB6B9BEB6B8BBB4B7BAB1B6BAB0
B8BDAFB8BEAFB7BBAEB7BCB1B7BDB3B5BBB1B4BAAFB4B9AFB3B8B1B2B8B1AFB6AFACB4AB
ADB7A8A8B2A292998931252B3A3132999595CBC9CAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7A8B988092A38093A98092AA7E8FA97C8DA68194A98193A88294A88293AA8695AD8694AD
8A98AF8B9AB08897AD8C9AB18F9CB3919FB5909FB5909FB590A0B693A2B894A1B994A1B8
94A2B896A1B897A4B798A5B69BA7B89BA7B89AA5B99CA6BAA1AABDA2AABCA5ABBDA6ACC0
A6ACC2A7ACC1A6ABC0A8AFC2A8B0C2A9B1C2ABB3C4AEB5C6ACB3C4ACB4C4ACB4C1AFB9C5
B2BBC6B2BBC4B1B9BFB3BABFB4BAC0B4BBC0B3BAC0B1BAC0B2B9BFB3BAC3B4BAC3B6BBC4
B7BCC4B6BBC3B8BBC3B9BDC4B6BCC2B4BBBEB8C0C0B7BEBCB6BDBBB6BDBAB7BEBBB7BFBC
B7BEBCB9BDBCBABFBDBABFBEBBC1BEBBBFBDBBC0BDBBC0C0BCC2C3BAC1C2BAC3BFB8C1BC
B9C0BBBAC0BABBC0BBBBBEBBBFC0BFBDBEC0BCBFC2BBBFC0BBBFBDBBBFBABABEB8BABEB8
BBBFB8BBBFBCBBC0BCBBC2BEBBC2BFBBC2BEB8C1BAB8BEB9B9BDB8B9BDB8B9BEB8B8BEB7
B7BEB4B7BEB4B5BCB2B4BCB2B5BEB6B4BCB5B2B9B3B2B9B2AEB5B1ACB5B0ABB4AFA9B3AC
A8B2AAA7B1A8A9B4A771726F4D494B383033352D2E31282C979396C9C7C9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7888997D8EA37D8EA87F90AC7E8EAB7C8CAB7E90A98193AB8091A98392A98796AD8C9AB1
8A98B08C9BB18C9BB08D9BAF8E9CB18F9EB4909FB692A1B790A0B593A3B795A5B995A3B9
95A2BB94A0BA95A0B897A2B79AA5B99CA9BB99A5BA98A4BA9CA7BB9FA9BBA1A9BAA3AABE
A5AAC1A6ACC4A6AEC6A4ADC4A6AEC1A5AEC0A7AFC0AAB2C2AAB2C2ABB5C3ABB6C4ADB8C3
ACB4BFAFB7C1B1B8C0B3B9BFB5B8BFB3B6BFB2B7BFB1B9C2B0B9C3B2BBC5B1B9C2B3B9C3
B3BAC5B1B9C5B2B8C2B4BAC2B6BBC5B5BCC4B6BCC3B6BEC1B6BDC0B7BEC1BAC1C3B9C0C4
B7BFC2B8BEBFB9BDBEB9BCBCBABFBCBBBFBEBABEBDBCBDBCBCBEBFBCC0C1B9BFC1B9C1C0
B8C0BDB8C0BDB9C0BDBABEBEBABDBFBBBEBFBCC0C0BABDBEBABDBFBABDBDBBBFBEB8BCB9
BBBEBABCBFBCB9BDBCB8BDBEB7BCBDB8BDBCBABEBCB9BEB8B8BCB6B9BEB5B6BDB3B3BCB1
B4BEB3B5BFB6B2BDB4B2BCB3B1BCB2B1BAB2B1B9B4B4BCB7B1B9B3AEB7B0ACB4ADABB3AF
AAB4AFA9B3AFA9B4AEA4AFA88D948F514F524743444441413B363B332F375C5962959599
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
74849B7A89A57D8EAB7F8FAE7F8EAD7F8EAD7E8FA97E8EA58091A58292A58593A78B99AE
8A97AE8796AA8B9AAB909FAF929EB08F9BB18E9CB5909EB7909FB6909FB492A0B494A0B6
96A1B995A0B897A1B798A2B69CA6B799A4B79CA6BA9FA8BDA0AABD9FA8BAA3A9BBA2A8BB
A5ABBFA7ADC3A4ACC3A4ADC2A5AFC3A4AEBFA7B0C0A8B0C0AAB3C2AAB2C0ABB4BFAEB6C0
AFB6BFB2B8C1B1B7C0B2B5BEB2B3BCB4B5BFB5B8C1B4B9C2B2B9C3B3B9C3B5BAC4B5B8C4
B5B9C5B3B9C5B1B9C5B1B7C0B2B8C1B3B9C2B4BCC3B4BAC2B4BAC0B6BDC1B5BDC1B5BCC0
B5B9BDB7BBBAB9BCB9BBBCB8BCBDB9BBBDBCBBBCBBBCBCBBBBBBBBBABDBEBBBFC1B8BCBD
B6BCB9B7BEBAB7BCBBB9BCBEBABDBFBBC0BFBABDBDBBBFBFB8BBBBBABBBBBBBEBBB9BDB8
BABEB8B9BCB7BABCB8B9BAB9B9BBB9B9BCBAB7BAB8B7BBB6B6BAB4B5BAB2B3BBB2B1B9B0
B2BAB1B3BCB4B3BCB3B3BCB1B3BCB0B1BAAEB1B9AEB2B8B0B1B9B0B0B8B0AEB6AEABB2AC
AAB1AEA8B1ADA8B1ABA7B2A9A8B3AA98A09B7B7C827C808373787A3838432F323825282D
23262B58595D8F9191FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7484997A8BA47D8DA87B8BAA7E8DAC7E8FAC7D8FA97F91A77E90A47F91A38495A48695A5
8896A98897A88896A78A99AC8B99AD8997B08C9AB38E9DB48F9FB391A1B494A1B494A0B3
98A1B79AA3BA9BA5B99BA5B69AA3B59AA2B69AA3B99EA9BD9DA8BB9EA9BBA0A9BBA4ABBC
A3AABEA2AABFA1A9C0A2AAC2A1AAC1A5ADC1A5AEC0A5AFC0A7B2C1A7B0BDA9B3BEACB5C0
AEB7C0B0B8C0B1B7C0B3B7C0B3B6C0B6B8C1B4B6C0B3B7C0B3B7C0B3B7C1B5B8C2B7B8C4
B8B9C5B4B8C4B3B9C6B0B8C4B1BAC4B1B8C2B3BCC3B3BBC3B4BCC2B4BBBFB5BDC0B6BDC0
B7BABEB7BABCB8BABCBABDBEBABCBFB8B9BFBAB9BFBDBCBFBBBBBDB9BCBDB8BCBDB8BCBC
B5BBBBB4BABCB5BDBEB5BBBEB6BCC0B7BBC0B9BDC0B8BDBEB9BCBDB7BBBCB6BABBB7BAB9
B8BCBAB8BBB8B9BBB8BABAB9B9B9B9B9BBB9B6B7B5B6B8B5B5B8B5B6BBB8B3BBB6B1B8B4
B2BAB4B0B9B2B0B9B2B2BBB1B0B9AFB0B8ADB0B6ADB1B8B3AFB5B5AEB4B3ADB4B1ACB3B0
ABB3B0A8B0AEA7B0AFA6AFACA5AEACA5ADADA5ADB0A1ABAE9CAAA981928F272939292F37
25292F2024291E232320231B92938CC8C9C5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7486967A8DA37C8DA87A8BA97D8EAA7C8DA87D8EA87D8DA78091AA8293AA8496A88597A8
8596A78896A98997AB8997AB8897AB8A98AE8D9AB08F9DB18E9EB18F9EB0909DB1949FB4
97A2B79AA4B899A3B799A2B89CA5BA9DA6BC99A3BC9BA6BC9BA6BB9BA7BA9FA8BAA1ABBB
A1AABDA0A8BFA1A9BFA3ABC2A6AEC3A5ACC2A7AEC3AAB2C6ABB2C5ACB3C4AAB1C2ABB2C1
ABB2C1AEB5C3B0B5C2B1B7C1B1B7C0B0B7C0AFB7BFB1B8C0B3B7BFB2B6BEB3B9C1B5B9C0
B4B8BFB2B8C0B2B7BFB2B9BFAEB6BDAEB7BFB0B9C0B1B9BFB2BAC0B3BABEB3BABCB5BDC0
B7BEC1B7BCC0B6BABEB7BBBFB6BBBFB4B8BFB5B7BEB8B9BFB8BBBEB7BCBFB5BCBFB6BCBE
B5BBBEB4B9BDB6BABFB8BBC0B9BCBEB7BBBDB8BBBEB6BBBDB4BABBB3BABBB2B9B9B4BBBA
B6BEBCBAC0BDBABDBCBBBDBDBABBBAB8BAB9B7B8B7B4B6B6B4B6B7B4B8B8B3BABAB1B9B8
B0BBB7B0BBB6AEB9B4AEB7B3AFB8B4AFB6B3AFB4B1B0B7B6AEB3B5AFB6B7AAB2B4AAB2B4
A9B2B4A7B1B3A6B0B2A5AFAEA5ADADA3AAACA5AEAEA0ACAC9EABAC9CAEAB6D787E505762
383D49303440272A342A2E31343A35485143282A25959596C8C8C9FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
768A987B90A37E91A97E8FA97C8DA87D8DA7808FA88391AA8492AC8493AD8596AE8395AA
8495A88795A98896AD8A99AF8A9AAF899AAF899AAF8C9CB08E9EB38D9CB48F9EB5909FB6
929FB595A2B797A4B996A2B999A4BC98A4BC98A3BC99A5BC99A5BA9BA7BA9EA9B9A0AABA
A1AABBA0A8BAA1AABCA3ABC1A5ACC4A6ACC6A5ACC5A6AEC5A8AFC4A9B1C4A9B1C4ABB3C5
ACB5C5ABB3C3ADB5C4AFB6C3AFB6C4AFB7C4AEB7BFAFB7BDB1B8BDB1B7BCB3B9BFB2B8C0
B2B7BFB1B7BCAFB3BCB1B5BEB1B7C0B1B8C1B0B8C1B1B9C2B1B8C1B2B9C1B3BBC1B1B9BE
B2B9BDB3BABEB2BABFB1B8BDB1B9BFB2BABFB4BABFB6BBC1B6BBC2B6BBC3B4BAC0B4BBC0
B5BABEB7BBBFB6B9BEB5B8BCB5B9BCB5BBBDB5BBBEB6BCBFB3B9BAB1B8B7B3BBB8B5BBBA
B7BCBDB7BBBCB8BCBEB6BCBFB4BABCB7BCBCB5B8BAB5B8BAB4B8BCB1B5BAB0B7BAB1B8BB
B0B8B9AEB6B7B0B8B8B0B8B9B0B6B8B0B6B9AFB6B7ADB5B4ABB3B2AAB2B1A9B2B2A7B0B0
A7B0B2A6B1B2A7B3B2A8B3B2A4AFAFA1ABACA2AEACA1ADAC9FADAD9CABAA9AA8A798A6A3
727A8061667248475D4A4A5E93A39D84908B51565B515A571D1A23544F578D8A8FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7484977B8CA37E8FA87D8FAA7D8EAA7C8BA8818EA9838FAB8490AD8390AC8391AD818FAA
8390A98593AD8693B18695B28899B48899B4899AB28D9DB38E9CB58C99B68F9CB88F9CB7
909EB6919FB694A0B698A4BB97A3BE98A4BE99A5BE9BA6BE9AA5BB9BA4B99CA5BC9FA8BC
A1A9BCA1A9BFA2A9BFA2ACC2A1A9C4A3ACC7A3ACC6A4ADC4A3ACC2A7B0C4A6AFC5AAB1C6
A7B0C5A7B0C5ABB3C7ADB4C6AFB6C6AFB7C4AEB8C1AFB9BFADB6BBAFB7BFAEB6BFB0B7C0
AFB6BFADB5BEB0B5BEB1B6C0B2B7C3B2B7C1B1B7C0B3B7BFB2B6BEB4B7BFB4B8C0B2B7BE
B0B9BEB0B9BDB1B9BFB1B8BDB1B9BDB0B9BCB2BABEB6BDC0B5BBC0B5BBC2B4B9C0B3B8C0
B6B9C0B4B6BDB6B7BEB5B8BDB6BCBDB6BBBCB7BBBCB7BABBB5B9BCB6BCBDB7BDBBB6BBBA
B6BABCB6BBBFB4B8BDB5BABEB4B9BCB6BABBB5B7BBB5B7BCB5B8BDB4B8BDB0B4BCAEB3BB
ADB4BAAEB7B9B0B9B7B2BAB7B2B9B7B1B7B4B0B6B4ACB4B2A7B0AFA9B2B1AAB3B4A9B1B5
A8B1B5A9B2B5AAB4B5A6B1B3A4AEB2A2ABAFA1ABAEA2ADB1A1AEB19FACAF9DA8AC9CA7AC
9BA4AB98A2A88E979E8B949A8F999C929E9C8E9B9893A2964C4E5116101F1B162318141D
504D53868588FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
6C78917B8AA57D8CA97C8CAA7C8BAB7C8CA9808EAA818EA9828EAA838FAA828EA9838FAA
8592AB8592AB8693AD8694AE8797B28799B28697AF889AB08C9DB38D9DB38F9BB4909AB3
919BB4929CB6939DB9959EBB969FBE97A1BE99A4BF9CA6BF9BA6BE9CA5BD9EA8BC9DA6B9
A2A9BEA2A8C0A2A9C1A5ADC5A3ABC4A2AAC4A4ACC5A3ACC4A5AEC2A6AEC1A6ADC1A9AFC4
A8AEC3A9B0C2ABB3C3ABB3C1ACB4C0ABB3BEADB5BFACB4BDACB6BEAEB7BFACB3BEACB3BE
AEB4BFB0B5BFB2B7C0B2B7C3B0B4C3B1B7C3B0B7C2B1B6C0B2B6BFB3B7BEB6B9C0B0B4BB
B1B5BDB4B9C0B4B8C0B3B8BEB2B8BDB1B6BBB3B7BDB3B9BEB4BABEB3B8BBB3B9BEB1B6BD
B1B6BDB3B7BDB3B5BDB5B6BDB4B6BAB5B8BAB3B7B9B3B7BBB4B9BCB4BBBDB6BDBDB5BDBD
B6BBBDB6B9BCB5B6BCB3B5BDB4B6BDB3B6BCB5B7BDB4B6BCB3B6BDB2B5BBB1B5BAB2B8BA
B1B8B9AFB7B7AEB7B3ADB6B0AEB6AFAEB5AEAFB4B1AEB4B2ABB4B4A9B2B2A9B1B2AAB2B5
A8B0B5A8B0B6A7ADB4A8AEB4A7AEB3A5ADB2A2AAB0A2ACB39FAAB19DA7AE9BA5AC9DA7AE
9DA5AD9FA7AE9BA4AA99A3A898A1A697A1A4969FA28F9B9C87948F4B50552F2F3725252B
1D1B2216131A1E1D209A9A99C9C8C9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
707E927A89A17F8DA97F8DAC7C8BAB7B8AA97D8DA78090A68493A78290A58291A8818FA8
8291AB8493AC8493AC8696AE8797B08393AE8495AF8695AE8694AC8A98AE8C99AD8F9AAE
8F99B0909BB3919EB7929DB695A0B899A2BC98A1BB99A2BB9AA4B89AA4B59CA6B59DA5B7
A0A7BAA0A6BC9EA5BDA0A8BFA2A9BFA1AAC0A3ACC2A3ADC2A3ACC0A2AABCA7AEBEA7ACBD
AAB0BFA8AEBFA8AFBEA9B1BCA9B1B9ACB3BBAAB1BBABB2BDAAB1BCABB3BEADB1BCADB2BC
AFB5BEAEB4BEB1B6C1B0B3C1AEB2C1ADB1C0B0B5C1AFB4C0ADB2BEAEB4BDB0B4BCB3B6BD
B2B6BEB0B3BDB1B5BDB1B5BDB1B6BDB0B4BDB3B7BEB2B7BDB1B7BCB1B6BCB0B6BBB0B5BD
AFB4BCB2B6BEB3B5BEB4B5BDB4B6BBB5B7BCB3B6BCB3B7BBB2B7BBB2B8BBB1B6BAB1B5BB
B2B7BDB0B4BCB2B5BCB2B5BBB1B5BBAEB4BAADB3B8ADB2B8AEB4BAAEB2BAADB3B9ADB4B7
ABB3B4ACB3B4AEB7B4ACB5AFADB7AEABB3AFAEB5B2ADB4B3AAB3B4A7B1B2A7B0B1A5AEAF
A7AFB3A8ACB4A6A8B4A7A9B4A7ABB2A6AAB2A7ABB5A3A8B4A0A8B49EA8B39FA8B09CA5AD
9CA3AC9BA3AB98A1A998A0A997A0A8989FA8979FA8939BA3909D9F8B989686948C68716E
35333E33313A29262E3332353637382C2C31929296C8C8CAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
74829078889C7C8CA57D8CA87E8DA97A8AA57B8CA3808EA3808CA17F8CA27D8BA17D8DA5
7D8DA67F90A88192AA8393AC8596AF8593AD8694AD8796AD8794AB8895AB8D98AE8F99B0
8F99B18D97AF8D96AF909AB2949DB4979FB6979EB599A1B7969EB499A2B49DA7B69CA5B6
9AA3B79BA2B89BA4B9A0A8BC9DA6BA9FA9BC9FA9BF9FA8BEA4ADBFA3ACBDA5ABBAA7AFBC
A7ACBCA6ACBBA5ACB9A8AEBAAAB0B9ACB2BAACB2BAAAB1BBA8AFBBA8AFBDA9AFBCAAB0BC
ABB1BCABAFBDAAAEBDABB1BFAAAEBBABAEBDADB1BEADB2BDAFB2BFAFB3BFADB2BCADB2BC
ADB2BCACB0BAADB2BAAFB3BAAFB2B8AEB2B9AEB3B9B1B6BBB0B4BCB1B4BCAFB1BAADB0B9
B0B4BAAFB4BAB0B5BBAFB0B8AFB1B8B0B1B9B2B2BAB2B3B9AEB3B7B0B6BAB0B5BAB0B4BC
ADB2BBAEB3BDAEB4BCADB3B9ACB3B7ABB1B6ABB1B6ABB2B7ABB2B8ACB0B9AEB3BBABB0B7
ACB3B7ADB3B7ABB1B4ABB2B3ACB2B2AAB1B0A9AFAEA6ADACA7AFAFA6B0AFA4AEAEA3ABAE
A5ACB1A5AAB1A6A9B2A6A8B1A2A4ADA3A6AFA2A6AFA1A6B09EA4AF9EA5AC9AA3A898A0A8
989FA8979EA7979EA7979DA6969DA4949BA090989F8F97A08F999F8B969A8B95988B9596
7B8487747F806770745D666A40434D3334433E424D515A5B6A6D7089888EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
6B7C86798B9A7C8DA37D8EA67A8AA57C8DA57A8BA27B8CA17C8BA1808EA67F8EA77D8DA7
7C8CA77E8FA78091A88292AA8593AD8593AE8695AE8595AC8896AC8A97AD8E9AB18D97B0
8E99B18D97B18E99B38D98B28F9BB3949FB5959FB6979FB797A0B6949EB494A0B495A1B5
96A0B698A2B79AA5BA9BA7BA9CA9BA9CA9BB9FA9BD9CA6BE9EA8BFA2ABC0A3ABBEA5ACBD
A7ADBEA7ADBEA5ABBCA6ADBCA5ACBAA6ACB9A7AEBCA8AFBFA7AFBEA7AFBEA7AEBCA9B0BD
A8B0BDA7AEBCA6ADBDA9AFBFA9B0BFAAB1C0ABB2BFABB2BFA9ADBEABAEBDAAADBCAAAFBD
A9B0BBABAFBAABAFBAADB1BCAEB2BCAEB3BCACB1BAADB3BAADB2BBAEB3BCADB1BBAEB3BA
AEB3BAADB2B9AEB3BAADB1BCADB0BCAEB1BBB0B2BCADB1BAABB0B8ABB1B9ADB4BCB0B5BF
ADB3BDADB2C0ADB3BEA9B0BAA9B1B7ABB4B8ACB4BAABB2BBA9B1BBAAB1BBAAB0B9A9AFB6
A9AEB5AAAFB5ACB1B8ABB1B7A9ADB3ABB0B4A9AEB3A5ACB2A4ACB2A7AFB2A6ADAFA4ACAF
A4AAB0A2A8B0A3A9B2A2A8B1A0A6B0A1A7B19FA6B19BA3AD9BA3AC9BA4AC9BA4AC98A2AA
98A2AA98A3AA98A3A9979FA7959DA5959FA5939DA2949DA0929B9E8F999C8F989C8C959B
8A949A879096848F94818D9279868C78848C78858E7A888F68757A25283A343D42474954
83858AFFFFFFFFFFFFFFFFFF
6C7C86748695798C9D7C8EA3798AA57A8BA77B8CA77B8CA77B8CA67B8CA57C8CA57B8CA6
7C8DA87D8DA77F92A88091A88393AA8695AC8495AD8395AC8596AC8796AC8997AE8A95AE
8995B08995B18A97B38996B48C9AB48E9CB5909CB5919BB9929DB98F9CB7909EB9919FB7
909EB693A0B894A0BA95A2BD96A4BD95A4BB9AA7BD9BA6BE9BA6BF9DA7BEA1ABBFA1A9BA
A3AABDA5ACBFA5ACBFA4ABBEA4ABBDA5ACBEA6ACBFA4ABBEA5ADBFA5AEBEA4AEBEA5ADBD
A6AFBEA6AEC0A6ACC1A8AEC2A8AFC2A8AFC1A7AFC1A7AFBFA8B0BFAAB0BFACAFBDAAAEBA
A9AFB9AAAFBAAEB2BDADB3BDADB2BEACAFBFACB1C2ABB2C2ABB2C1ABB2C0A8AFBBA8AFB9
AAB1BBA9B1BAA9B0B9AAB0BCA9ADBDABB1BFACB2C1ABB2C0ABB1BFA9AFBCA7AEBAA9B1BB
A9B0BBAAB1BCACB2BCAAB1BBA9AFBBA9B0BBAAB1BDAAB1BDAAB1BFA7AEBBA8AFBAA8AFB8
A6ADB5A8AEB5A7ADB6A9AEB7A9B0B7A9B0B8A7ADB8A5AAB5A4AAB4A3A9B3A3A9B2A3AAB1
A1A7B2A3A9B6A3A8B7A0A8B6A0A9B69FA9B59BA5B398A2B099A4AF99A1AD97A1AC96A1AC
94A1A993A0A9939DA8939CAA929BA8929CA6919DA5909BA28E999E8E999C8F9A9E8D989D
8B969A869295839093829093818F927E8B927D8A947B87927A89916F7D856E8181334048
131A270C1219808285C0C0C1
6A7C83788A957B8B9C7B8BA0798AA57888A67383A47385A67588A7798CA7798BA47B8CA5
7B8BA77D8DA77E8FA67F90A48393A38594A48491A58493AB8293AB8494AC8796AD8896AE
8995B08995B38793B38995B58996B28A98B28E9AB48F99B6909BB98F9AB9909BBB919DBA
909DB5919EB694A0B993A0BA92A0B992A1B996A4BA9BA7BE9BA6BD9DA7BDA0A9BDA2AABD
A2A9BCA3A9BCA4AABEA5AAC0A3A8BFA4A9C0A6ABC1A2A8BEA5A9C1A6ACC1A5ACC1A3ACBF
A3ADBCA3ACBEA4AABFA4AAC0A6ACBFA6ACBEA6ACBCA7ADBFA6ABBDA7ACBCA9ADBBA8AEB9
A9B0B8AAB1BBA8ACB8A9ADBCAAAEC1ACAFC4ABAEC3ABAEC3A9ACC1A7ABC0A5AABEA6ACBB
A7AEBBA9AFBCA9ADB9A8ACB9AAADBAA9ABBBA9ACBEAAAEBDA9ADBCA7ADBBA6ACB9A7ADBA
A8AFBBA7AEB9A9AFBAA8AEBBA4ABB7A7AEB9A8AEBAA7AEBAA6ACB9A5ABB8A7AEB8A6ACB6
A6ADB6A7ACB5A5ABB5A3A9B6A2A9B6A2A8B3A5ABB5A4AAB6A0A6B49FA4B39FA5AF9FA6AE
9FA6AEA1A6B3A1A6B79CA1B59DA4B699A1B298A0AF9CA4B499A2B297A2B196A2AF94A1AB
93A0A8939EA7949CA9939DA98F9AA78F9BA48F9CA08D9A9C8C999B8E989E8C97A08A969D
89959B828E93839195839195849097828C96828D957F8D937C8A8E7A888B7582857B8C88
3741470A0C1808091106050C
6B7C88798A987C8D9F7B8BA57A8AAA7788A97485A67487A57588A47689A37B8CA57D8CA6
7C8CA97E8FAB8294AC8092A68294A68393A58391A78495AD8394B08394B08596AF8593AC
8895B08792B38894B68796B58998B28D9AB1929DB58E96B1919AB7919BB9919AB9929CB8
929CB4939EB4949FB4939EB395A2B596A2B697A3B79BA5B99CA6BB9BA3B99EA7BCA0AABA
A2AAB9A4A9BBA2A7BCA3A7BEA5A9C1A5AAC0A0A7BDA0A8BDA2A8BCA5AAC0A5AAC2A4ABC1
A4ADBFA6ACBEA5AABFA7ACC0A6ACBDA4ABBBA7AEBCA7ADBCA7ACBCA6ACBAA6ABB7A6ADB5
A7AEB6A6ACB7A7ADBAA8ADBEA8ADC1A6ABC0A7ABC1A8ACC3A6AAC1A6ABC1A8ACC0A7ACBC
A9AEBCA9AEBAA8ABB9A7A9B8A9ADB9A9ADB9AAACBCA8ABBAA8ACBAA8AEBBA6ACBAA6ACBA
A7ADB9A7ADB9A6ABBAA8AEBBA8AEBAA8AEB9A7ADB7A9AEB7A8ACB9A8ADB9A9ADB8A8ADB7
A9AEB7A7ACB5A5ABB6A2A8B4A2AAB4A0AAB4A0A8B49FA7B59FA6B49FA6B4A1A7B49EA4B1
9EA3B0A1A6B39EA2B59FA4B99CA3B79AA2B39AA1B19BA3B29BA3B3979FAE95A0AE94A0AD
919CAA939EAC939EAB919DAC8D9BA98C9BA58B9AA18A9A9F8A989D8C989F88949E87949E
87969D829095838F93859095848E97828B97818B967C89907A868A7B878A7982867A8487
7784842F3244252638201F2F
6A7A8B798B9E7E8FA57C8BA67B8AA97887A97788A8788BA77A8FA67D90A57D8DA67E8DA8
7F8EA98091AB8192AA8293A88395A78595AA8592AB8593AE8594B18394B18395AF8696AE
8896AE8A97B28997B28895B08B98B08F9CB1909AAF9198AF929AB3929AB5939BB7919AB4
969DB5959DB5969EB5959FB697A3B797A3B39BA5B39CA5B69EA7BB9EA7BE9EA7BD9EA7BB
A1A9BCA5ADC0A4A8BEA4A9C0A5A9BFA4AABFA4ACC0A3ACBFA6ADC0A5ABC1A4A9C2A3A9C1
A5AAC0A5AABDA4AABBA7ADBCA8AFBFA6ADBDA5ACBCA7ACBDA7ADBEA3A9BBA4ABBAA4ABB8
A6AEB8A4AAB7A6ADB9A8AEBEA8AFC1A6ABC0A6ABC1A5A9C0A7ACC1A8ADC4A7ACC3A8ADC0
A8ADBDA9AFBEABAEBFACAEC0ACB0C0ABAFBFAAADBDABAEBBAAAFBAA9ACBAA9ADBBA7ACBB
A7ADBAA6ACBAA8AEBEA6ACBBA6ADBAA7ADBBABB1BFACB0BEADB1BEAAAEBDA9AEBCA9AEBA
A7ACB6A5ABB5A6ADB7A4ADB7A2ABB5A1ABB69FA9B49CA5B29DA6B39EA8B49FA8B49FA7B4
9EA5B2A0A8B59CA4B59CA4B899A1B59AA3B49BA5B49AA3B19AA2B298A2B494A0B193A0AF
939FAD929DAB939FAC929EAD909CAC8C9CA88A9AA28B9BA08A999B8D9C9D8B9A9E899A9D
8A999A86959586949487919586909687929A838E9A7E8B987B88957D89937E888F7D858C
7A838A74818766737B617174
68778B76899E7B8CA4798AA47C8CA87A8BA87789A6788BA47689A37A8BA57D8CA67E8EA6
7E8EA87F8FA98090A9818EA68594A88694AB8592AC838FAC8290AC8391AD8696B28795B3
8796B28997B38895B28C99B28F9CB38E9AB18E99B18F99B3919AB3919AB4929AB5949CB5
989FB7969EB7949CB6949EB595A0B496A2B399A5B49BA5B49CA6B99AA4BB9BA6BC9FA8BD
9DA6BB9CA4BB9CA4BC9FA7BEA0A9BFA0A9C0A0A8C0A0A8C2A0A8C4A2AAC5A1A9C5A2A8C3
A3A9C3A4AAC0A4ABBFA6AEC0A4ACBCA5ABBCA6ABBDA5ABBFA5ACC1A2A8C0A1A9BFA2AABE
A4ACBCA5AEBCA4ACB9A4ADBCA3AABDA3AABFA4AABFA5ABBFA6ABBFA7ABC2A8ACC5A8ACC3
A7ACC0A5ABC0A5AAC0A8ABC1A9ACC2A8ABC2A9ACC1A8ABBDA7AABCA5A8BDA6AABDA5A9BC
A7ACBDA5AABCA7ADC0A7ADC1A7ADC0A6ACBEA6ABBDA6AABFA7ABBFA5ABBFA5ABBEA3A9BA
A5ABB9A5ADBAA3ABBBA3ACBBA1AAB8A0A9B6A0A8B7A0A8B79FA8B69FA8B79EA7B59CA5B3
9CA6B39CA6B49BA5B299A4B197A3B395A1B298A2B397A1B3949EB097A3B497A3B493A0B2
909EAE919DAD8F9BA78D99A68E9AA78D9AA78D9CA68B9AA28A999D8B9B9B89999C85969A
859598859497849396849095828E95838F98818E99808E997E8B977E8B957F8C977B8792
78858C76848A7282856A7C7B
6271897589A1768BA6778AA5788AA7798AA67889A67788A57586A57889A67C8BA87B8BA6
7C8CA68090A98491AA8491A98693AA8996AD8592AA8491AA8492AA8491AA8491AE8793B3
8794B38894B48894B38995B48B97B58A95B28D97B28F98B48F94B29198B5929AB6939CB8
939CB6929CB6919BB6939DB6939EB695A0B695A3B594A3B498A4B997A2BA98A5BC9AA5BF
9BA5BC9CA4BB9FA7BF9EA7C19DA6C19EA6C09EA6C0A1A9C29FA7C39EA7C39EA7C3A0A7C3
A1A8C49FA7C0A4AAC1A5ACC0A4ABBDA5AABCA5ABBDA2A8BDA4AAC2A4A9C4A0A6C39FA7C2
A2AAC0A3ABBFA2ABBEA2AABFA2A9BEA1A8BEA2A8BFA6ABC1A6AAC0A7ABC1A5A9C3A5A8C3
A6AAC4A4A8C3A4A7C3A6A9C5A7AAC6A5A8C6A6AAC6A4A8C3A5A8C3A5A9C3A5AAC3A2A8C1
A3AAC0A4ACC0A4ABC0A4ABC1A4ADC2A5ADC2A2A9BEA3AABEA4AABDA3A9BDA2A8BDA2A8BD
A3ABBDA3AABCA3A9BBA3AABBA2A9BCA1A8B9A0A5B7A1A7B9A0A7B99EA6B89DA5B799A2B3
9AA4B39CA5B49BA4B398A2B197A2B198A3B197A0B198A0B397A0B0949FAE949EAF919DAD
919EAE919FAD8F9CAA8C98A68B98A58C98A58C98A38B97A18B97A089959E87949D84919C
84939D84949B839298839096818E96818F99818E997D8B967C8A947B889479869278848E
75848C7483897180826E807D
68778B72859F758AA7788AAC778AAC7789AB7385A77485A77587A77A8CA8798AA57C8CA6
7E8EA77D8CA6828FA88490A88591A98893AE828DAB8490AB8591AB8591AB8491AB8994B0
8892B18A91B28A93B38893B28C96B38E97B39199B49298B69499B99196B79297B99299B9
929AB7929BB6929CB9929CB8939FB8919DB794A1B694A1B594A0B696A1B897A2BC98A2BE
96A0BB9DA6BF9DA4BD9DA4BE9CA3C09DA5C19BA5C19DA7C29EA7C2A0A7C19FA7C09EA6C0
9FA7C19FA6BFA1A8BFA3A9BEA3A9BEA3A9BEA2A8BDA2A8BDA2A8BEA3A8BFA4A9C2A4A8C1
A3A8C0A2A8C0A2A8BFA2A8C0A1A6C1A2A7C3A2A7C1A6ABC3A4A9C0A3A8C0A5AAC1A4A8C0
A4A8C3A6AAC6A7ABC8A7AAC6A7AAC6A5AAC5A5A9C3A5A9C3A4A8C3A7ACC5A5A9C3A3A7C3
A2A9C4A1A9C3A3ABC3A3AAC1A4ABC0A4ABC0A1A8BEA3AABDA4ABBCA3AABDA2A8BCA4AABF
A4AABEA2A9BCA2A6BAA2A7BBA2A8BBA1A6B89EA4B69FA6B79EA3B5A0A6B79CA4B59BA3B5
9BA3B49BA4B49AA3B498A2B3979FB098A0AF99A1B1979FB199A2B397A0B0959EAD939CAC
919CAD8F9AAB919CAC929DAB8F9BA78E9BA78B98A48B97A48C97A58B96A38892A08692A1
8693A085939D86959C86919C85909D818C9E7D889D7A869A798697788795798893788891
77888E74868A7385846E817C
65758A72859D7388A4758AA87486A97184A86F82A67488AA7387A87588A8778AA77789A6
7888A47D8DA77D89A8818DAB8290AB8491AC8491AC8491AB8693AB8795AD8795AD8896AC
8894AB8995AD8792AD8995AF8A94AF8C96AF8E97B08E97B29198B69199B89097B89099B9
8F98B8919AB6909AB4919CB6939DB9929DB8939EB7939EB4929DB3949EB598A3BA98A3BC
97A1BA97A0BC99A2BE98A1BD98A2BE9AA5C29BA7C39AA6C299A4C09CA8C09AA6BE9DA7BF
9CA5BD9FA8BEA0A9BDA0A7BB9EA6BA9FA6BCA1A8BD9FA6BCA1A7BDA0A5BCA1A6BEA0A4BD
A2A8C0A1A8BF9FA6BD9FA7BE9EA6BF9FA6C1A1A9C5A2AAC5A2A9C2A2AAC1A1A9C0A0A8C0
A2A9C0A3AAC3A5ABC5A3A7C3A4A9C1A2A9BFA2A9C1A1A6C0A0A5BFA3A7C0A2A7C2A4A9C3
A3A9C3A1A9C2A1A9C19FA8C0A1A8BFA1AABEA1A9BE9FA8BB9FA9BB9FA6BBA0A8BDA4ABC0
A4ABC1A2AABE9FA6BB9DA5B99DA6B8A0A7B89EA5B59DA6B59FA8B79DA5B99AA1B79AA2B6
9AA2B599A2B198A1B096A1AF969FAF979EAF989FB0959DB0969FB0939BB0939DB1929CAF
909BAC8D98A88C98A78F9AAA8D98A78F99A78D98A68A96A48A94A48791A1858F9F85919F
84909D82919A819099818F98828E99838C9D828DA07C8A9D78899977899676879374858D
74868A7285866F82806F847C
69778C6F809B6F84A17085A37286A67487A87286A77186A86E82A57286A8758AA97587A6
798BA87C8CA87C8BA8808FA9808EA8818EA97F8CA87F8FA87F8FA88191AA8292AA8291A9
8392A98593AB8894AD8993AF8A94B18B96B18993AE8993B08D96B3909AB68F99B88D98B7
909CB88F9AB3919CB38E98B28E99B78E99B78D99B48F9CB4909CB4939EB5949FB6959FB7
97A0B9939CB8949CBB959CBA959FBA96A0BB95A0BB94A0BC93A2BD95A2BD95A0BA949FBA
99A3BF97A1BD98A3BA9CA5BB9CA4BA9CA4BA9CA5BB9DA6BD9CA4BA9CA5BA9BA3B99DA4BA
9DA5BC9EA7BC9CA6B99DA6BB9FA7BF9FA6C19EA6C09FA8C39FA8C3A1A9C39EA6C0A0A8C0
9FA7BE9EA5BF9FA5BE9EA5BC9EA6BC9DA5BB9FA7BE9EA7BD9CA4BA9EA4BDA0A7C09EA6C0
9FA7C09DA6BF9DA6BF9DA6BD9CA6BA9EA7B9A0AABA9EA9BB9DA7BA9CA3B89CA5B89DA5BA
9DA5B99EA6BA9EA5BA9CA4B79BA2B69BA3B79BA3B69BA4B89BA5B899A2B896A0B6959EB4
979FB4969FB196A1AF949FAD939DAD949CAD919AAD909CAD8E99AA8E99AA8F9AAC909CAF
8E9AAD8E9AAB8C97A98A94A68991A48A93A58992A58792A38691A28591A2818E9F808D9F
8190A07F8F9E7D8E9B7F8F9B80909C7E8C987D8B98798697768796788A9773849172838D
7184897083836E817F697D77
6673906B7D9D6E84A56F85A67184A67687A97485A97386AB7287AA748AAA758BA8788CA8
788BA87A8CA87B8CA87E8EA97F90A98091A98291A97E8DA77F8EA88191AA8191AB8293AB
8192AA8291A88794AD8895B18794B28895B18C99B18C99B18C98B08D97B38E98B88C97B8
8B97B88D99B98F9AB7909CB98F9CBB8D9BBA8D9AB78E9CB58F9DB5919DB5949EB7949DB9
979FBB969EBB959DBA959DBB969EBB939CB994A1BC95A2BD94A1BD97A2BE9AA5C098A1BF
98A1BF97A0BD9AA1BD99A0BC9AA2BF9DA5C19EA7C09CA6BE9AA5BC9DA7BC9DA7BB9CA4B9
9DA6BB9EA7BE9EA8BC9CA6B99FA7BD9EA6C29FA7C3A0A8C4A0A8C4A1A8C4A1A7C4A1A8C4
9FA8C49FA8C3A0A9C2A0A9C19EA9BF9CA7BD9BA7BF9DA9C19CA7BF9CA5BD9DA4BD9DA5C0
9BA4C09EA8C29DA9C19EA9BF9EA9BC9FABBBA0ACB9A1ACB9A2ABB9A1ABBAA1AABCA0A8BD
A0A8BEA1A9BE9FA7BC9DA4BA9FA5BA9DA4BA9FA8BE9EA8BC9EA8BC9CA5B99BA5BA9AA3B8
9AA3B897A1B697A0B696A1B695A0B5929EB2919DB2919EB1919FAE929EAF929CAD929CB0
909AB18E99AE8D98AD8E99AE8C97AA8E9AAC8B98A98896A68796A68694A68390A38492A7
8491A88493A77F90A37D8DA27C8EA17D8F9E7D8E9C79889B78879C7A8B9D768796768993
74888D72868671868170857B
6A75947585A77688AB7586AA7383A77586A97788AD7787AE7587AB7387A9778AA87B8BAA
7A8AA97D8CAA7E8FAA7F8FA98090A7828FA7848FA98691AC8591AD848FAF8490B08490B0
8693B28693B28793B28892B28991B08A94B18A95B08C98B2909BB48D97B38F99B98F99BC
8D97BA8C95B68C95B69099BB919BBB8F9ABB8D99B8909CB5939EB5949CB4969DB6989EB7
989FB6979DB4989EB6979CB79BA0B9979CB8989FB99AA3BC9AA2BC989EBB9AA0BD9CA4BE
9CA3BC9AA1BB9CA2BB9CA1BD9C9FBE9EA1C09EA3C19EA3C09FA5C29EA3C0A0A6BE9DA4BA
9BA1B79FA6BBA1A8BD9EA4BAA0A5BBA2A7BFA1A5C2A1A6C4A1A7C4A3A8C3A3A8C3A2A8C3
9FA4C29FA6C29FA6C39DA5C19EA6C09DA6C09DA6C29EA8C29CA5BFA1A8BDA1A7BCA0A5BC
9DA3BD9DA4BF9DA3BE9FA7BFA0A7BFA1A7BE9EA6B99FA7B8A0A5B7A0A6B7A0A7B9A0A8B9
A1A8BC9FA6BCA0A6BBA0A5BA9DA1B69DA1B59CA1B69EA3B89EA3B89CA1B59AA1B599A1B4
99A0B59AA0B5999FB5979DB6959DB6939CB5939DB2949EB1949DAF939BB09197AE8F95AB
8F96AB8F97AC8B93A98C93AB8B93A78B96A78A95A58894A28692A28693A5848FA4848FA5
8590A9808CA67B88A17C8BA17B8B9F7A8A9B788698788497798699778598758293778691
75848E7484887081806A7C77
656D8A707E9D7281A57080A47483A77381A87381A87685A97786A97787A97787A87987A9
7B8AA97C8CA97C8CA77E8DA6808DA68491AA828DA88690AC848EAE848FB18491B5828FB4
828FB48491B38593B38694B28894B18993B28B94B38C94B48D98B68C98B78E98B99099BA
8C96B68B96B78D98B8919BB98F99B68D96B38F98B48F99B4929CB5939DB5939CB4949DB4
959DB3969DB299A0B4979DB4999EB6989DB5989EB7989EB8989EB99AA0BB9CA1BE9BA0BE
9AA0BA9BA1BB9DA2BC9EA2BD9EA1BF9EA2C09CA1BF9BA1BE9DA3C09CA3BE9CA2BB9EA5BA
9EA5BA9EA6BAA0A5B8A1A6B9A1A5BAA1A3BA9EA0B99FA2BCA0A4BFA2A6C0A0A4BEA1A5C1
A1A4C2A1A4C3A0A3C2A1A5C3A0A4C0A0A4C0A1A6C0A1A7BEA2A8BCA2A8BA9FA3B79EA2B8
A1A5BCA0A5BD9CA2BC9DA5BDA0A5BFA1A6BE9EA1B99FA2B9A0A4B99FA1B7A2A4B9A1A4B8
9EA2B79DA3B79BA1B79DA3B89DA2B6999EB29BA2B49BA1B69AA0B699A0B599A1B6989FB4
989FB1999FAF999CAF9A9FB3959CB3949BB1939BB09097AD949BB0959BB19296AD8E93A9
9096A98E94A78E96AA8C93A88891A48994A387929E86919D87939F838D9E858FA0848DA1
848CA48189A47D88A37E8AA1818EA07C889B7B879A778396758193788496778295758192
73808F7180896F8181697C76
656F8B6F7C9B7383A47484A87282A67482A67382A67887AA7989AB7B8BAC798AAA798BA8
7A8BA67C8DA57D8DA47F8FA6808DA7828EAA7F8BA9818DAD838EAF848EB0828FB08290B2
8190B08091AE8192AD8393AD8695AE8794AE8794B08A94B38995B38995B38A95B28B95B1
8F98B68F98B78E99B6919DB8909BB3909AB38E97B2909AB5909AB4929DB5909CB3919CB3
8F99B2949DB4979FB5979DB6969CB8969DB9979CB9999EBA999DB9979CB99A9FBC9CA2BE
9CA3BD9CA3BB9CA1B99BA0BA9CA3BE9BA1BD9AA1BC99A2BA9BA3BA9BA3B99AA2B69BA6B7
9AA6B69AA4B49BA2B29FA4B5A0A5B9A0A4B99EA3B7A1A6B9A0A4BAA2A6BEA2A6BEA1A5C0
A1A4C3A0A4C2A2A6C4A0A4C29FA3C19EA3BF9EA6BD9CA4B89DA4B69DA4B79DA3B69DA3B6
9DA4BA9DA5BD9DA4BD9EA5BC9DA1B89FA3B89FA3B89C9FB69FA1B99FA2B99FA2B8A0A4BA
9EA4B99CA3B9989EB5989EB59AA2B7999FB499A0B399A1B599A2B7969EB6949CB4959EB3
97A0B3979FB1959DAF959DB0959CB3929AB19099AF8E95AA9099AC9097AB8F95A98D93A6
8C92A78890A48890A38992A38790A28793A48593A184929E83919B808F9A83919F808D9F
828DA0818CA27F8BA17D899F7D899D7B87997A8495798393758092758194768397718091
6F7F8C6E80876A7D7F677C76
636F8A6F7D9B7480A37481A67381A67380A47683A47A88A87C8AAB7A89AB7989AA788AA6
7689A5798AA57B8BA47F8DA5828EA9828DAD808CAD818EAD808CA88490AB8592AE8391AF
8190AF8190AD8091AA8292A98392A88491AB8590B08893B48C98B68D98B38E98B18E96B0
9098B48F98B7909BBA8E99B88E9AB68D97B29098B19097B09298B29098B18D97B08F99B1
919BB39299B3949CB7969BB99399B8959CBA969DBA989EBA989CBB979CBC999EBC989EB9
99A0B7989FB59BA1B69DA3B89CA1B99BA3BB9BA4BC979FB7989FB59AA2B49BA2B39BA3B3
98A2B299A4B39AA4B39AA3B39DA5B69FA6B9A0A7BBA0A6B89FA5B59FA4B59FA2B6A1A3B9
A0A4BCA0A5BDA0A6BE9DA2BB9C9FBB9DA2BD9CA2BD99A0B89BA3B79CA4B79DA4B89EA5BA
9CA1BA9AA0BB9CA3BB9DA5B99BA1B69EA3B59FA4B79FA3B99C9FB69B9FB49A9EB29DA0B4
9FA4B69CA2B4989EB3979DB5979FB498A1B1979EB0959CB1969EB5969EB5939DB3939DB3
939CB1949CB19199AF9099B18D97AE8D95A98C96A78E98A78E96A68D95A68E95A58C92A4
8A91A18B94A38891A18A92A18A91A38890A28591A282909D808F9A808E99818F9C818C9D
828BA080899F7E889F7C88A17D899F7B86997982937A8395778196747F967381986E7E91
70808C6A7C826B7E7E687C77
626D856E7B98727E9F7380A4717DA37380A47683A27582A37885A77A88AA7988A8798AA7
788AA7798BA6798AA57B8BA57D8BA67F8CA8808CAA808CA9808CA5808DA38490A68490A8
8590AB8392AB8392AA8493A98694A98594A98693AC8692AE8892AE8B95AE8A93AB8D96AD
9096B09297B49096B69197B79096B48F95B19298B19198B19195AE9298AF9399B2929AB0
8F96AC9398B09398B19399B4949ABA9299BB939AB9949BB6949BB6949AB69499B7969DB9
98A0B8989FB5999FB3999EB4999DB7969AB8979EB7979FB4989FB0999FAF9B9FAF9A9EB1
999FB299A1B2979EAF99A1B0989FB099A0B599A0B798A0B698A1B29BA3B19EA4B1A0A5B3
9FA3B59FA3B7A0A5B99EA3B79CA1B69AA0B59AA1B8979EB4969FB497A0B5999EB59DA2B9
9EA3BB999FB79AA1B99AA0B7989FB39AA0B39CA1B29EA2B69EA2B69C9FB49A9EB2999DB1
9C9FB49A9EB29B9FB5989FB6969DB3969CAF949BAD959CAF939AB0949BB3959CB2959EB1
929BAD8F96AA9098AD9099AF8B95AC8A93A68C96A48F97A39096A18E95A18E95A38C92A2
8C93A38B92A188909E888F9D898F9E8A92A3858EA1818C9E7E8B9B7D8A97818D9A80899A
828B9D838A9E80879F7C839E7B829E7B839B7A8198797E97787D99767E98737F966E7E90
6C7D876C7E836C807E6A7D77
626D896D7B9971809F7380A1727EA37380A47583A67380A47784A87886A97683A77786A8
7A8AA97C8CAA7C8CAA7C8BA97D8CA87F8FA9808EA87F8CA6828EA7838DA6838EA7838EA9
828DA8828EA8818EA88290AA8391A98593AB8594AC8895AE8895AD8A95AC8B95AA8F97AD
8F96AD8F95AC8E95AE8F96AF9198B18F96B08E95B09098B39096B0919AB0929AAF9299B0
9399B09399B29499B4959AB6949ABA949BBB959CBC949BBA929AB9939AB99299B7949CB6
979EB6979DB4969BB39A9EB6999DB6959BB7979EB9989FB7989FB49A9FB59CA0B69A9FB3
9AA1B199A1B099A0AF989EAE969EAE969EB2959DB497A1B596A0B39BA4B49AA1B29DA2B5
9DA2B59EA3B89EA2B99DA2B89DA4BA9CA3B99BA1B79BA1B89BA3B899A0B7989DB5989DB5
989FB6989FB7979FB799A0B8979DB59AA0B69BA0B59BA1B69BA1B59B9FB49CA0B49D9EB4
9C9CB59B9BB69A9CB6999EB5989EB0979DAE959CAC959CAC959CAE939AAE939AAE929AAE
929AAF929BAE8E97AB8D96AA8D97AA8B94A58E97A58E94A28E93A09095A38A90A08A919F
8A949F8C95A0878F9C868D9E868B9F888EA1868EA1838BA0838AA082899E80889C80879C
82869E81859E7F849D7C839D7C829E7B829D787E9A787F9B757E9A757F99737F946C7A8C
6C7B8A6A7B8367797D667978
656F886F7D9B71809F7482A27481A1737FA27481A47480A57684A77683A57885A77D8BAB
7B8AAB7D8CAC7B8AAA7C8BAB7D8CAB8291AE808DAA808CAB818DAA848FAA828EA9818EA9
818EAA838FAA838FA98390A98593AB8491A98692AB8792AC8893AC8B95AD8D98AF8B95AA
8D98AB8D95A98C94AC8C93AD8C93AD8F97B28F95B28F96B28D94AE8E96AF9095B09095AF
8F95AF9197B39298B59096B59197B69298B7959BBB939BBB939BBB939ABA949CBA949CB8
979EB7989FB6979EB4969DB2969DB3959CB4959CB6959CB7989EB9979DB8969BB5999FB5
989FB3979EB0959CAD959CAD959FAF949CB0989FB69AA2B899A2B899A0B7999FB59CA1B6
9CA0B59B9FB79C9FB89EA2BD9EA4BD9EA4BCA0A5BA9DA1B49DA1B39B9FB29A9FB49AA0B6
999FB699A0B799A0B79AA0BA999FB9999EB79C9FB89A9DB79A9DB8999BB69A9DB49C9EB5
9D9DB59B9CB69A9DB6969BB0959CAD969DAF959CAF929AAC929BAC929AAD8F97AB9199AD
8D95AB8D96AA8E97AA8E98AB8E97AB8E96A78D93A48D93A48C91A28A90A28C92A4868F9F
88929D868F9A88909E878E9F838C9E838A9E868EA1838B9F828A9F81889E7F869F80859F
8084A08084A17B819F7A819E79819D767F9B757E98727C95737D96747F96727E906F7B8C
6D798A6A788768788264767B
636D876B78966E7D9D707FA17380A4737FA3737FA37380A37582A57582A37886A57C88A9
7D8BAA7B8BA77C8BA77F8DA97F8CA8828FAC818FAD7E8DAE7F8BAC7E8AA98490AD838FAC
8591AE8490AE8490AC8590AC8592AE858FAC8691AE8995B18792AE8893AF8793AD8896AD
8A97AE8A94AD8C95AE8A92AC8B94AD8B93AF8D95B18C93AE8F96B09095B29096B29096B2
9197B29398B1949AB29599B49399B4949AB59499B79398B89398B9949AB9939AB7959DB8
989FB8969CB6959BB59399B3979DB4969CB4979EB6989EB8989DB9989DB59BA0B49A9DB1
989CB2999DB3979EB2969DB1979EB1959CB1969DB3989FB699A0B99AA0B999A0B99A9FB8
9B9FB79C9FB79B9FB8999DB89A9EB89BA0B69C9FB49B9FB29C9EB19EA1B49DA1B89C9FB8
9C9FB8999DB79A9FB89C9FB9999CB69A9EB79A9CB99A9DB89B9EB7999CB5989BB3999CB2
9B9DB3979AB2969AB2949AAF959CAE949AB0949BB29299B09099B09099AF929AAD9198AC
8F95AA8E94AC8F96AE8C92A88F95AA9095A98D92A88A8FA58B91A6898FA4878EA3868EA3
858EA2838B9F888EA3868CA1858BA1858AA38389A28187A28087A17E859F7F839F7C809C
7D819E7B7F9D7C829E797F9A777E97757C95737B9270798E707A8E717990727B9070798F
6D768C6A768867768262737A
65728B6D7A98707E9F717EA3737FA5727DA4727DA37380A47783A67884A47884A27985A6
7987A87A89A87B8BA67B8CA67F8FA97F8DA87E8DAC7F8DAF818FAF7F8EA98290A8828EA7
8390A8838FAA848EAC848EAC8590AE8590AB838FA98691AD8792AE8690AC848FAA8794AC
8896AD8A96AD8D96AF8E97B08D96B08E99B58B94B08D97B18C96AE9198B19094B19298B4
9199B2949CB2969CB1959BB09397B09599B49398B59399B69299B6939AB5949CB5949AB3
969BB4959BB49297B39399B5939AB4959BB5969CB6959BB7969BB8989CB59A9EB5989DB3
9A9EB4979CB2969DB3949AB0939CB0939DAF969EB0969EB2989FB5979EB5979EB69A9FB6
979CB3979CB29A9DB59B9EB7999DB5989DB3979CB0999EB19A9FB49D9FB59B9DB69C9FB8
999CB6989DB59BA0B69BA0B4999CB1999DB2999CB3979AB2989CB2989DB2979CB1989DB3
989CB3959BB3949AB39298B09396AD9396AE9498B18F95B18C95AF8C95AD8B94A88E96A9
8E94A89095AC8F94AE8D93AC8B92AA878FA48C93A68C90A68A8EA68B8EA88B91AA888DA8
878EA7848BA3838AA1848BA18488A28588A48387A48288A67C84A179819C7D849B7D829A
7C819B7A7F9C79809B77819B727C97727D95737D95717B93707B906F78906D768E6A748D
68748B677487657481627179
636F896B7794717E9D7480A5747DA5757EA5747CA3767DA37981A47B83A47A82A37C86A8
7A86A67A88A77C8BA87D8DA87B8AA67E8DA87D8EA77E8EA88090A9818FA77F8EA37E8FA2
8493A48590A48992A88891A7868FA88793AB8591A98791A88992AB8891AB8790AD8992AF
8992AF8B94AF8F97B28E96B48E97B58C95B28C94B28D96B48D96B38C96AF8E96B18E98B2
8D98B0919AB0939BB09198AD9299AD9398B09398B29399B4939AB29398B0959AB29399B2
9499B39196B09096B19096B49095B39198B4939AB7929AB8949AB5949AB3959CB3959CB2
969CB4989EB6959BB4949AB1959EAF959FAE969FAE969EB1969EB4949CB4989FB6979DB5
989DB3979BAF999CB39B9EB7989CB4979DB3969DB1969CAE989DB1999DB2989BB2999CB7
979BB5959AB3969CB0949AAC969CAD979CAC969BAE9499B09499B19398B19498B1949AB3
9498B49397B39196B19297B09398B09195AC9195AD9095AD8E95AE8B94AB8B95AB8C95AA
8A92A68B93A98C92AA8B91A98C94AA8991A68992A28A8F9F8A8DA18A8EA5888CA5878CA7
838BA57F899E808B9D7F879A81899D81879F7F859F7F88A37C85A079849C798399788096
797F98797E99777C9A757D9C727B997079966E76926E77916D748F6A728F6A729069718D
636F886572886271815F6F75
666F856973926F7B9B727D9F757FA1777EA2767AA3767AA27A7FA57880A37A83A47D87A4
7C88A37C89A37E8AA37F8CA47F8DA7808EA8808EA67F8DA4818EA47D89A17F8CA27E8CA2
8290A4828FA18690A2848DA1878FA7888FAB8991AE8A92AE8A93AD8991AB8A91AD8A8FAE
8E92B48B8FB28C91B28F95B38C93AD8890AB8E94AF8E95B18D94B28991AE8893AE8794AD
8895AC8D99AB919AAC8F96AB9197AC9197AB9198AC9299AC9197AA939AAC939AAC9598AD
9296AE9298AF949BB19399AF9399AF9399B08F95AF9097B19199B09197AE9198AB9297AA
9296A99398AC9399AE939AAD949BAC929AA8949CAA949BAC959AAF9499B0959AB1979BB1
9699AF979AB09799B0979AB1969AB0949AAE969CAC959BA89599A8989BAF989BB2989AB3
9799B09598AD969AAD9599AB969AAA959AAA9699AA9495AB9496AE9495B09697B39597B3
9397B29397B29495B09497B09295AE9296AE9195AD8E94AA8D93A98E95AC8D93AA898FA5
8B91A6898FA58A91A88A90A58A91A38C93A48A91A1898F9F8B8DA08B8FA2888BA18688A4
868AA68287A180899F7D859A7D84987C83987E849A7E849B7C8299798099777F99757C96
767C97777E98757A987279987078977078966E75936C73926C749468708F666D8B666F8B
65708A636D85616F805E6D76
696D826F7490747A98757C9A777D9D777A9D777AA1787BA47B7FA67D83A57E88A37C87A1
7B83A07D86A17C86A07C87A07F8CA5808EA6828FA4828EA2808CA3828CA6838DA77F8BA6
8390A88692A68891A58890A5898EA88C90AE8D92B18A90AE8A92AD8A91AB8A8FAD8D92B0
9094B48E92B48B8FAF8B91AF8B93AC8E94AB8C91AA8C91A98A8FAB888DA9848BA7848DA6
848CA2848A9F888CA38B8DA68C90A68B91A58991A48C95A48E96A48F96A49096A69298A8
949BAC9097A9929AAB929AAB949BAB949BAB9399AD949BB09097AC9197A9939AAA9397A7
9498A89599AA989DAD9599AA9498A8969BA9969BAA969AAB979AAE9597AD969AB09497AE
9599AF9698AF989AB0999BB29A9CB29699AE969AAC969AA99699A89899AA9797AB9798AE
9698AD979AAE9598AB9699AA9699AB9698AA9598AB9294AA9394AC9496AE9293AC9294AE
9597B09597B09293AD9395AE9293AD9092A99194A99193A69093A58D91A58C91A48B90A2
8C92A28D93A4878EA1878DA2898EA3898FA3888DA1878B9D888C9D8B8E9F88889E8687A1
8486A38085A27E849F7D859A7D85977E84967E83978085997D81977C7F997B809A797E99
787D96777B947478937378957178976D74976A72946C75936C75916C748F68718A68708A
686E88656B8360697C5F6B76
6B6E82767B937A819B7A809D7C809E7A7D9C7A7B9E7D7FA37D81A57D82A47F86A181889E
7F859C8288A08289A28089A37F8BA4828FA48290A2848FA1848EA0868EA3858CA68188A5
818AA4848EA38791A28990A28A8FA58D90AB8B8FAE8B90AE8B90AE8A8FAB8C91AB8C90AB
8F92AE8D91B08C90AD8B90AB8E94A99096A98E93A68D92A58B8FA68A8EA9888DA9858CA4
848A9E84879B86879D85839D85839F82829D7E81997F86997F8795838996858A98888E9B
8A909E88919F8C95A28F9AA6929DA8919BA7949BA9939BAB8F96A9929AAA939BA7939BA5
959BA6969AA9979CAC969CAD9297A8959BA8979CA7969AA79698A99799AD969AAE9399AD
9197AB9599AD979BAE9698AB9696AD9495AC9598AB9599A99598A9989AAB9898A99797AB
9697AB9598AB9496A99395A7979AAA9799AB979AAF9295AB9194A89294A79294A89395A8
9595A99494AA9292AB9596AD9395A89295A59193A58F91A38F91A38C90A18A90A08C91A0
8C929F8E93A08E91A18C8DA28A8CA386899F888DA1878B9F888D9F8A8D9D898A9D88889F
8686A18285A17F849E7B83977D84957D82957D81957F82987F819A7C7F997A7E96797E95
797C927A7C92797B927678927477947074946B71926A718F6B748B697386696F856A6E85
666981676A8365697D5C6270
6B6E82777C91777D95787C96797B967B7E987B7D997C7F9C7D7F9E7F839F80859F80849A
81869B81879E848BA2828AA1828CA1838FA1848F9D85909D848D9D8890A2858DA1868DA3
868EA28A90A18B92A28B90A48B90A68C8FA88C8EA88C90A98B8FA88B90A88A8FA68D92A7
8F93A88D91AA8D92AC8E93AA8F96A98F95A59195A48F91A39092A68F93A88F93A88F94A8
8D91A58E91A48C8DA18B8BA287849F86859D8282998082947F818F80818E80808F7E7F90
7C7E90787D8E797F8F797F8F79808F818893878D968B929B8D949D9099A0929A9F939B9F
929AA19399A59197A5939BA69098A3939CA6929AA2949BA1969BA3989BA69496A59296A5
9498A6959AA99698A99899A99697A99394A79295A69296A59497A59497A49294A29695A6
9697A89396A79497A89599A8969AA89496A79698AB9497AB9195A79194A69598A79395A3
9595A39292A29596A59192A291949F91949D91949D8E929C8C909B8C919D8A8F9D8A909B
888E988B91978D91988B8E998A8B9D8989A087889D898A9D8B8D9D898A9989889889889B
83829981819A81849C7E82987B81947C82927D82927E80947F81957C7E93787A8E797C8F
787A8E77778B77768B76768D72738D72748E6D718C686E87686F846970836A6F816A6D7E
66677B65687A646877606771
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0178571 0.97619 0.357993 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
101008100F07100F0911100B11100D12110E12110D15130D14130C15140D16130E13120D
14130C13140C11120B11120D11130C13140D14150D11120B11120B10120B0E100A0E100B
10130D10140F11130F10120F12140F13140F15140F14140E14140D13130C15160F161710
16171014160E14160D15180F14160E14150D12140E13161114171013160F13150D13140C
14150D15150D17170F17170F171610181814161713171915171914161713141512141612
14161212141011140E12150D12150D12130C14150E141610151711151713151713171914
17191414151014151113131014141116171317191317191115170F161812151811151811
15181215181117191116150E16160F161611161510171610161610161612151612161714
14151314151313141113121016151114140F13130D13130E12120C13130D10110D11120F
12130D11120D14130F13130F12120E11110D12120F11110E110F0C0E0C090F0E090E0E0A
0E0F0A0F110A10130C0E120C0D100B0C0F090B0D070A0D060C0E080B0D080B0B060B0A07
0E0F0B0C0E0D0B0E110B0C110D0B110C090E0C0A0A0B0D0A090A0A090B0B090C0D0C0F12
010207010204020203010204020106020107020108030208030206030205020106010105
020104040204040204050203
1619161B1F1B1E211E1E211F1D1F211E22251F24211E231C1B20171A1F151C21141E2415
2025161F24151F23141E21131F22141E20141E22141F24151F24161E24151A1F131C2115
1B21141A21141B21151D231820241A21241C20231B21251B22261A2227192126191E2419
20261A222A1B232C1A252D1C232B1A252A1B23261923271B262A1C242A1A23281A242B1B
262C1C272D1C2A2F1E282C1E282B2124271F25291F262C21232B1D262F1F262E1D272D1D
282F1F262B1E282C1F272B1D262B1C252B1B262D1C262C1D272D1E262E21222A1D242B1B
262D1C252C1C272F1E262C1C252B1C2B3220262C1B262D1A282F1D2C3121242919292E1D
262A1C282C1E292E1F2D31202D31212C2F202C2F222C2F212D3125292D21272B1D252A1A
262C1B252C1C282D1D2A2F1D2A2F1D2A2E1E2A2B1F282A1F292D202A2D2323251E22241C
2123181F211721221822241A20211B20221B22231B2023191F20161B1D12242718212316
2224162225162124141C20121B20111D20111D20111B1E101A1D111B1E12191C111B1E12
191F13171E15171F161E27210C0E160D0C130D0D0D090B08090B07141A100D110B010201
020201020401010201010201020203020204010204010404010403010301010301010301
010401020401040301050301
97AE989CB49F9FB9A29FBAA17D917F20242B191B1F191D1B1114110F120C0F120913180B
181C0E191D0E1A1E0F1B1D0E1C1F0F1B1F0F1C200F1D20101A1D101C20131C20141F2216
1E23171D23171F251A1E23191E23191F241B20241B21251B2125192127182025171E2215
1F25171C24151E26142227162327182427182224162326182426191F2114202215212416
222819222719252A1A262A1E262921242620262922242A20252B1D272D1C282E1B292E19
292D192A2E1F292A1F292C1E292D1D292E1D272C1B2A301D292F1D272D1D272D1D292E1D
2A2F1D292F1B29301E252B1A282D1A292E192B301A2A2F19292E18272C19252A17262B19
262B1B25281A27291B282A1E2B2E222C2F222E31222F32232D31232A2F202B30202C3220
2A321E2F36213036233035232E32223136263135282E32242F34252F32262D2F252B2E23
282B202A2F222B2E222E30242D2F25272B20272A1E26281C24261A26291C25291A242717
252715272918252817252A172528162326152529182428182226172328191F2316202416
2024152124141B1F0F1C22101B200D171B0C171C12171B14151914181E151A1F14161B0D
15190C15190E13160D12150D171A0F181B10171B12141711141912131710141813141814
151A13161C12151A11161A12
97AE9C9DB7A5A1BBA59FB9A199B29A414B49121418191E1B161A17131712151A10161C0E
1A200F1A210E181F0E191E0E1B210F1E24121F23111F22111F21141F1F151F211920221B
21231B21241B20241C1B20181D241A1E251B1F261B1F271A1F26181F27181F2515212616
242A1A242B19212917222917252A17252A18252917242618252719242618222417242719
23261B22281A242A1B282D21262B2224282023281E262C1E272E1B292E182B30182A2D17
2C301B3234223030212D2E213232242F31222E30202E3020282A1D25271C25291C262B1C
3039232A331E252F1A262D1A272E18292F19272D17272D17282D18292E1A262B17252817
26291B26291D27281D2929212929212B2E242D30252E32252C32232C3221272E1C28311C
2B331C2D331D2E341E2F351F2B311E2E34222F34232E32212E32233335263134252C3023
2C2F252B2F252B2F232E31232D31232A2E21282C1C272B1B27291B26291A272B1A272C1A
282B1A272A1A27291A25261825271827291B26271B23241B22241A22251A2024191F2417
2024172026181F26171F25172126181D2215181D12181F15171C15161B14151912171B10
181C10191B1117180E181A101A1A12191A14191915151715151714151815171A16161915
171B15181D16171C15151912
94AD9B9FBBA8A2C0A99FBAA29DB9A06D81721F24271C2120171B18131813141911151B10
171D101A21111D24121E24151E211321241622251623231623231922231C21221C1F201B
1E20191C20191F251D1C231A1D25191D25181E26181F28181F27151F27141F2613222916
252A17232714242915262B1926291A252819242819262A1A272C1C262C1B262A19262A1A
24291925291A25291A272B1F252A2022281F21271D262E1E29331D2D341A2C311A2E301C
2E2F1D2E2E1E3231232F2F223031233031243031233133242C2F21292C202A2D22282C1F
262C1A262F1A262F1A242C17273018282E182A2F192B311A2B2F1C2B2E1E292B1C282C1C
25291C26281F26271F2A2D24282B222A2D242D32252E33252B31222A32212B331F2D341D
2E351D3137202F34202B2F1E2D32222D32232F33262F34272F33252F3324313526313526
3034262F35272E34242E33222D321F2E34202E331F2D311F2B2E1E292C1D292E1D2A2F1F
2A2E1F282C2026291E282B1E26291C25271B25261C23241B23251B24271B202718202718
202717242A182228142228172025171E23161B2216191F16171D14171D13181F13192010
1B1F0F1B1D0F1B1A101B1B111D1F151C1E141C1D171A1D19171B17181B16191D17171B15
181D151A2014171B10181A0F
74827097AE929AB5999EBB9F9EBC9F90AC8E435146111615191E1910140F0F130C12160D
151910181E111A21131C22161E221621251A22261B252A1C23271A23251C21241A212419
2124181F23151D22151E23161F25171D23141F26151F2715232918262B1A252A1A202718
252C1C252A1A242A1A282D1E282C1D282C1C282C1C282C1C25291A282C1A282C19272A1B
2326172226171F251820261B21271E212920252B21292F22272F1E29301C2D331E2E341F
2E33212E30203033222D30202F34232F34262F33243133223031202F301F2F3021292C1D
282E1B282F1B262D18262C16282D172B301B2B311C2C331E29301E292E1E282D20272D1F
252B1C252B1B252918292D1E2B2F202C2E212C30212C30202B30202E35232D3422303724
333A263237263135282F322930342B2D31282D33282D33262E34262F35272D34262E3423
2E34222E34222D33202F362030361F3135213233223132243032262D30252A2E23272D21
2A3023262D20262E20272E1D282D1C272B1C242719242618232618232618222516232815
2328142328132125131E21141F22171D20171A1F171A2017191F13171D11171D10181E0C
171D0A181D0B181C0D181C0F1B20141C2015191F141B21151B21161A2015191F15181E13
171E10181E10181D1015180C
282D22424C3B57644F798E6D859F7A95B48A63795A0F120D12160F0F140C0D100C0E100D
131710161C10181E121A21131C221520261720271923271722261621251623251925291B
24281B25291B22251723261724281823271623281622281725291A23261A22271C22291D
22291B22291A242B1B232A1B252A1B262C1B2A2F1D2B301C282D1A252919272A1B26291A
24281A23291A23291D22291D262E22232A1E242C1D252C1E28301F28321C2730192C331B
2D331C2C311E2D33202D32202E35232E33243237293336273334223333212E2E1C30321E
2C311E292F1C262C19242D19262E1A242C1B262F1C252E1928311C272E1D282E1E282D1D
282E1C272C1A2628172B2C1B2E2F1E2C2D1D2D2E202E30212B2F202C32222C33222E3422
31372431362534372932352A31362B2F34292D31252C31222E33232C32232D3325313826
3137242F35222C311F3036223236223435213334223031212A2E1E2D3221272C1D282D1D
282E1D252C1C252D1B232B17252B16282D18272B1A252718242617252819232616242816
2226152125131C22101D23141E23161B20161A2017192015181D11181C1013170C171D0F
14190A131809131608171B0D181D10191E11191F111D24161B22151A2114191F12191E11
161B0B16190817190A14160A
191F1320261A1F241822291A38432A5465434D5D3E22261823281D1D2218171C14141810
181E13181E12181F141C23161F271720261823281A23281A23281A23261A24251D27271E
27291E272A1E25291B25261924251620241323271423261523261724291B24281C262A21
252B2023291E252C20272E21282E20272E1E262E1B29301C2A2F1B272B19282B1B2B2F1F
292D202B2E202A2F202A3020282E1E282E1C292F19262F1827301B242C172930192C321B
2C301A2E301B2F321D2F331F2D32212E34233136273132243233243031222F31202E311E
2A2E1B2A301B29311C272F1D252D1B202818202817242C19252C1C292F1E292D1D292D1E
282C1D272B1C262A1A2B2E1B2D311D2C301C2B2E1D2D301F2C301F2D321F2D331F2E3321
2E3321323725343A2A32362A31362B3137292F36252D34212D34212F36233139262F3825
2F37243139252F35242F332233362235372333342131321E2E301C2D301B2B2F1A2C311D
2C311D292E1D2A2F1E2A2F1D282D1A292E1A2C311E292E1D292F1E242A1B242819242918
2125151F21142124152025151E22131E22151C21151A2013191F0F191F0E191B0C191B0F
1A1B0F181A0D17190C191B0C1C1F111B1F10161B0F1A1F121B20141A1F14181B1115190F
15190D14180A1315090F1005
0F130B1318111519111619131D211821271B21291B1E23171D23151B2112192010171E0D
161D0C181F101A2013171D111B22141E2516232718252A1A24291A222618232619262A1C
272B1D272A1D262A1C262819272B1A262B19232817232618242819262B1B24281D262A20
272C21272C21272D22282C21252A1F23281C282D1D2A2F1C2B311D292E1C2A2E1E2A2C21
2C2F242A2D232A2D222B30222C30212B301E292E18262B17272E1A2A301D2A311B2F351E
2F341F3034203233212F301F3031213235253437283234253537272F31222D2F202F3322
2D32202D321F2B321E2A321E29321E262E1B232C1A242C1A272E1D262B1B272C1C292E1E
2A2F20262C1E23291B262D1B2A321D2A2F1B2C311F2D32202E32212D33202D311F2E3320
2F3421303722323724343828353A2C32392A2E34252C32202D341F2F36212F3623303725
3138263137263235263132233232223234223132213233203435212E301D2C2F1D2C301F
2B301E2C301E2A2E1D282D1C2D311E2A301B2A2F1C2B30202B3222272E1E232B1B242818
2529182225162224172123162224162123162023151E21141E21131D20101D22101A1C0D
181A0D191A0D18190D181A0D1B1D0E1B1D0D1A1C0D1C1F12191C0F181B0F181A10181A10
15180E12160A101106111307
0E120B11140C11120A16180F1719121B20181C22181B22171A21151B21141B22141A2113
1A20121A2111191F12171E0F1C23111E24121F2513222616202414232617232618232618
252718252819262A1C25291B272D1E262C1F252C1D252B1C23291C22281C262B2026291F
282D20272B1F262A1C282D1E272C1C272A1C2B2E1F2A2E1F2C31202B301E2C31202A2F1F
2A2F1F2B30212C3222292E1E292E1E2B3020292E1E272E1C2B301E2C321D2C311F2D331F
2F33203135212D2F1E2F312031332233372733372733372735392B3439293136272F3525
2F35232E34222E36202C351D2D341D2A321B2B341E2E35202C321D2A2F1C282D1B2B301C
2B301F2A30202A311F29331C29341B27301828311B2B341E2E34212E34222F3321303523
2F34212E341F2E311F343625353828363B2A343A283239263037222F361F303720313822
343B26343A273137243236233537243132212F2F212E2E1F3032213031202F30212D3121
2D31212E33222D33212D33222C30222A2F1F2C31212D31232A2F222A3222283020232A1A
222A192127162227162427172529192224172225172123161F21152022152124141E2110
1E1D0F1E1E101C1E121C1E111A1C0D1B1D0D1C1F0F1B1E11171C0F171B0F171B0F191E11
111509111509101408121609
080A040B0E050C0F0514150B181A13181C16181D15181D141C211A1F231A1C21151F2316
1D2114191F12181D101A20121C23111E26121E2712212916212715222817262A1B252819
272A1B27291B282C1D282D20272D22252C21262D21262F21262E23252B20262D21262D1F
2A2F1F282C1C26291B282B1B272B1B282A1C2D2E1E2C2E1E2B30202C301F2E3421303623
2F35222B302028301F2930212B30202B31202C32232A32222A311F2A311F282F1D2C321F
2C311E2C31202D32212C30212D312330352532392833392833392A32382A30362A32382C
2D33262C32232A321F2B341F2B341C2B341B2B341A2F381F2F36203136222F33212E2F1F
2C2F202C30202B311F2A321D29331A29331929331B2C341E2E3321303523313624333926
33382531362231362030351E3135203439243036223034233237243136213138212F361F
3138222F36213036233137243237243235233031232F2F212D2D1E2D2E1F2A2C1D2A2E1E
2A2F1F292E202C31222D32212C2F202B2E20292C222C30232C3023292E2129301F1F2616
2028161F27131E2611202712232816252A192227161E22141B1F131C20142124161E2013
1D1F131E21151D1F151D1F151D20141E20121C1F0F1B1D0E1C1F0F1A1C0E1A1D0E1A1E0F
191C0E141A0C14190E13170D
070A030A0D04111609171C0F1D23151B1F1415160F151511191B14161811171A12181E13
1A20141C23151C23131C24111B230F1E27111E28111F28131F2715202718252A1A262A1A
25291A272C1C2B2F1F2A2E20292F23262C22262E23272F24283026293025282F22252C1D
282F1E282D1C282D1B2A2F1B2A2F1B282C192A2E1B2D311F2F34202E321E2C311D2E3320
2D31202D31212B30222C31242D32252C31242A2F232B31222C33222D36232B34212A3321
28301E2A321F2D34202C331F2D33202E3420313824313826323A28303927343B2B343A2C
323A2B2E38272D37242D36212C351D2B351A2E371B2D361D2F351F2F36212F35212F3321
2D31202E32212F34222D33202D341F2C341E2A321E2C321F303622303623313725303623
32382232371F32361E343820323621333822343923333824333926323724313522303522
3137223136243238263339263239253036232F34232C30212A2C1E2B2D212C2D212D2F22
2A2E202C30202D32212D32212B2F1F2D30222C3023292D202A302029301F292F1E252D1A
262F1A222B16212914202713252A18252A1A2428172428182126161E24141E24141C2012
1B1F121A1D13191C14181A121A1D132024161D1F13191A1019190D1C1C0D1C1C0C1B1C0B
1B1E0E16190B15190B111609
090B040D10060E11060E120812170A15190B16180A11140B0E110B090B070D110913170D
171E10181D101920111D24121D25121D25121F27141E2616202819212819242A1B252B1B
242A1929301C2B331D2B321E2B311F293020252C20272F22272E22262D21283023283023
2932232A31202D34222C301F2B2F1E292E1D2A2E1D2B301D2E331E2E321D30351F30341E
30321C30331D2C2F1E292C1E2B2F202D32232D32252D32262B30242D33252E35262D3424
29311F272F1C29311D2B331D2E371E2F361E323922333A25313A252E3823333B26333C27
313C28303B26313C27323D262F39212F3A21313C21313920333A2130361E31371F313522
3335253235263034262F34243137242E351F2D341D2D351D2E331C2F331E323722323922
31371F33381E32341A35381F3439223238223138223037223239243238223037222E3420
3238223338253439273339263239263137253036242E33232A2E22292D232A2B222B2E22
2C30232C30232C30212A2F202C31222C31232C32242A2F21262D1D272F1D262D19262E19
252E18262E18242B1621271323281624281623271823291B222A1C20281A2026181D2215
1B2013191D101B1F131A1E121E21162022171E20161B1C111B1B101B1C0F1C1D0C1A1C0A
1A1C0A191B09161909131508
060804070904060902090D030B0F040F1305151B0A1318091013070A0C040C0F060F1409
0D10070C100612180C191F121D24151E2415222A1921291B21291C232B1D222B1B232B1B
212A18242D18263019262F1928311B29321E28301F262D1E292F202A2E202E34242C3121
2E33222F33222D32202E32212E33222F35232E33212D32212E3521313622323723313621
3035202F35212E31202C2E1E2B2D1E2B2F212B2F212D32242E33252E33262E34262E3524
2D36242E37242C35212B341E29311A2B341D2D35202E37222F3823303A23323C25323C25
343C25353D27353E27343C25353D24323A21343B23333A22323723323822333A22323721
3336223436243335253034233036233036232E351F2D331D2E331C2F341D32382031371F
31371F33371E33381E363B223A3E27373B273135232E3520303721303721313822313923
313923333B243238233036212D331F2F35222E34213036232D32222C2E222C2F242E3125
2D31242E32242D31232C30222B30212C30212C31222C31202B311F2B311E272C16282D16
282D16292E1A2A2E1B22261522271823271822271921271921281A212A1B202619212517
2022152123162326171D20121E22122125151F21141D21131D21131B1D101B1D0F1C1D10
1C1E101C1E1018190E14160B
0406060608050507020609010609010C10030E13030F14041015030F1103101105101207
1012090D0E060D0E070D0F0714180D1A1E101E2310222716232A19242D1A252E1A232C18
222B19232C19232C17262F1927301B28311E28301F29311E2C331F2D321F2F33222F3322
2F33233034243235253337253236243136243136242E34232D35222E37242E37232F3522
3036233137243134233132202D2E1C2D301F2C2D1F2D30202D31203034242F36262F3727
2D35252C35232C35232D36242933202C37212B36202C37202E3820313A24323C23323C22
353E23363E24373E26343B24333A23353B24353A24363A27363C28353B28363C28333824
3437223536223335233235223035232F35222D32202C331E2C331D2D331D30381F2F371F
323923333923343B22343C22363E26373D27373E273239232F3520323722353C25353D25
343B23343B232F36202F37202E361E2C331C2E351F3037212E33202D33212D31232E3225
2E32253033233032222D30232D2F242E31242D32222C32202A301D272D18242B14262D14
242913272A172B2E1D292C1D24281B25281C23271A2025181F261920281A1F27191C2215
1E22151E22142025161D22131B200E2023101F23122023121D2011191B0F16190E1B1E13
181C12191D1316181014170E
040907060B05070A02060A0204070105080107090105080109090110110315150A1A1B0E
16170C1112090D0F060A0C05080C040E13061318071B210D1F2611232C1627311C26301A
27311E262F1E28311E28321E262F1D252E1A27311A29331B2931192C321B3036202E311F
2F33222F332331352733392A3238283339283137272E35242E36252F3824303824333A25
333A243238253338253133202E2E1C2E2F1D313221303222303523313624323825323926
2E38252D36242E38242F3925303A242F3820323B212E361F2D351D2E3520303621313822
343C24353D24343B24323922323821353A23333821363B25383C28383D2A373C29343A26
353A24373A243537253335243237262E34232C32202C331D2C331D2C351E2D361F313B21
323A202F371F333A21333B22323923363C25373D283339253136242E32202F3421333926
363E29333A26353C27333C25313A22313921323A20333B212D351D2E341E2F3521303423
3136263036273034272F33272E31272D30262B2F232C30222A2F1D283019272F17242C14
262B16262B182A2E1D292D1E292E20272B1F24281C24291E1F231A1E21191D21181F2517
1F26161F25171E26171D24171D22151A1F111A20101D22131E21121E21121B1F10191E11
191D13191E13151A0F11160B
050A06050903070B02080C02070B010307010205010407010909010A0701151406191A0B
18190B1315090C0E040C0D020B0C02080901090C021115061C200F222717262C1D293021
2B35272B35282C372729332228331F26311A242F162631152A34182C341A2F341D333521
33352434362832342A31352D30352C31372D2F372B2E372A303927313B26333C27343A25
373C2536392235382234362035362137392536382634362833362A34392B303627323926
303A262D36242C36222E3723313A23343C22323A20333920333921333722333722323722
323825333925323824353C27383E28353B24383F25363D2439412A383E283B432A3A3F26
373A243739253738263437253135252F36262C33232A34202A331F2B35212B351E303C21
303C1E303B1D2F371B313A1E323A20353C24373F26353C27323826353A2B313629303629
333A2A353D2C363E29353E29343E28323D24323B2132392031381F2F3620313723323624
30352531352831362A3035292E33292D30272E3227282D212A301F29311D28311B2A301A
2A2F192B301C2D311D2E301D2C2D1E2B2C1D2C2E20292A1E232419212218202217202318
20251A20261B21271C23281F23281E20271A1D24161E25161E22121E22101E22101B1F0E
1B2010191C0D18190A131607
070C03090C050B0E050D10040B0D030A0C01080A010A0D020B0B010A09010D0D010E0D02
1010040F0F021110020E0E020D0B020C08020905010A0702100E091C1D172729232B3029
2C342D2A352D2C382C2A382629372229341D2A361A2A35162B37162E35172D311830321D
34362534352734362A30342C30352F2D352F2E372E2E372C313B2A343D28363D27363B23
373B22383A213D3E253A3C263B3C273A3C2A383A2E35362E34362E34392F343B2C333D29
313D262F3B242E3721313A21343C22383E23383D233C3F273C3E293A3B293A3B2A37392C
35382B3A3F2E373E2B363F2A39412B384128363F25343C22373E243A40253B41263C4129
3A3C2A3A3C2C3637293335293235293037282B34252C36252C36242B35212A361D2D391C
2F3C1A313E19323D16333C19373F22363C23373F2739412D393F2F383E30343C2F32392E
2D35282F3826323B26343E25354025343E22333C2032391F353B22353923353A25353626
36382B33372D31352D32372E30352C2D32282D32272B32242A33222A332129321D2B341D
2C321B2C2F1C2D2F1C2F301D2E2C1C302E202F2E222C2B2129282024251E23241D21241D
22271E21261E21281F22291F22291F20271B1F27181F26152027131D240F1E260F1F2710
1F260F1E250E1E220C171808
0A0C050D0E061212081011060D0E050A0A030809010B0C020A0B010C0D020A0C01070801
0B0A010E0E020F0E040F0D040F0E060E0A060B06060A05080804091413151B1C1D232827
28302B2A352C2936282A392529392028371C2A361A2C3818303A1930381C31361E333722
34382735382B33382B32372C32382F323B30323C2E313B2B333F2A323C27373E273D432A
3C41283E3F263F3E283F3E2C3E3E2F3A3A2F3A3C32383C33383D34373E32353E2F333D2C
353F2B343F28343C24373E24383F243D40263D3E28403F2C3E3E2F3B3A2F393A323A3C33
383D32353B2F383F2F363F2C39442C3A44283A42283940263A3F263A3D253D412A3C3F2C
3D3F313C3F33383D31343A2E353D2D313B2A2E38262F3A262D37222E381F2B351A2A3315
2B35152E3715313A16343D1A363A20363B23373E2937402B36412E35413036412F333F2C
323C27303A212F381A313A19333B1A323B1B343B1E373A21393A26383726353428333329
31322830352C3139312C342C2C352A2931262A33242A31212C34222E37242C34212D341F
2E331E2F301F313120323122333125312F262D2A232C2C25282B25272B252227211D231D
1F261E1E261C20291D212A1C232B1C222A191F28142029132029121F280F1E250B20260C
1F240B20240D1F210E1D1C0D
0F120A0E10090E11090C0E060709030507030608020C0E050E11060C0F020B0F02090B01
0B0C010C0E031011060F0E050B0A040806020704020A07080C090B0B080C100F14181B1E
222926262F282833292735252835222C38202D391F2D381E30381E2F361C303720303423
353828373A2D33372D34392F373C33343B31323C2E303B2A313D28313C24364025384026
3940273A3F273A3D283A3B283D3F2D3A3C2F3B3E30393D30383D32363C30353B2E373E2F
38402E37402C363E28383D26393C243B3D253D3D283E3D2B3C392E3B39303B3D35373935
353933383F3536403237422E39442B3B452A3A4227383F25383E27393C293D402C3D3F2E
3F41323E42333A4134363E31353E2F343D2B333E29303B232E38202F381C2D35182B3217
2A32162B32162C34162F371730361C30361E333A24333A26323929333B2D343E2C333C28
323B25303A202E371C31381A333A1B34381B363A1E373A2138392438392737372B323228
2E31272B3128282F272A322B2B33282C34262E36262E35232C311F2E34223034232F3320
31331F30311E323120312F20302D213332272E2E262E30282B2E29262B2622282120261E
1F271D1E251B20281B2029191F2817212A172029172127142027121E250F1A200B1F240C
20240F20220F1F210E1D1F0E
10150E0D100D0B0D0A0A0C080B0D0A070A060608030709020A0D04080902070902090A01
090B010B0D020A0A020A09020908020605010502010F0E0817161218171617161A19191E
1C1E2522262A252E2D27322D26332A2A35282C35252E3823303821303720313821333823
3539263A3B2C3A3B2E37392E383A30353930353B2F353E30323D2B333E2A35412A364127
3A4328394227394126393F253C40283B3F2A3C402D3C41313A3E32393F33393E33373E32
353D3136413236412F343E28353C23383E243A3E243A3C253C3D283D3C2B3C3C2F393C32
363931353A31363D3138433039442F3B472E3F492C3E482A3D462B3D432B3E422C40442F
3F422E4042313F43333B40333C433338413035402E333D2A2F38242E35202D321C292F19
2B321B2C331B2B31192D341A2D331A2F351F313622353A25373C28363B29383D2B343A27
343A26323925333C25333C2231391E31391D333A1E353B1F373B21393C253A3C28353626
3133252F33282D30282C2F272D31272E34272F35252F35252E34233036252F3523303623
2E33202F321F30321F323321302E20302D22312F232E2D232D2E232C2F24292C2125281E
23291D20251B20251A20271A1E25191F26182129192227192227182226161F24131E2311
1F23111F22111E21121D1F12
0C110B0C0F0C090C080A0D080B0E08080A06060904070A05070703080904090B04080A03
080A02090B0207090106080105070105050104030105050111130C1F221A2E322B333732
3033332C30302B31312C34322E38332A332E29322827312328312028301F2B311E2B311D
2F342031372335382834372B35382D363A2E33382D363D302F382A313A2A313B26353F28
343C26353E25353D24343C22373E25373E2639402B3A422D383E2B363C2B383F2F373D30
39413236403236413135402E37402B373F27373F26353C23383D24373C233A3E273B3F2A
3B3E2C3A3D2C373D2B373F2C3C46303D482E3D472C3C452A3D462C3B432B3D432D393E29
3B402B3D412C3D422E3D43313C43333B42323A4231363E2C2F36242D34212B311F2A311E
2A311E2B311D2C311D2D341E2B301D2A2F1B2D321C2E331E313421323722313722333924
343A25353C26353E28374229364027333E22333C20323A1F2F351C34381E393E243A3C26
3738253436273133282E2F252E30252E32263035292F35282B33262B33262A33242B3321
2C311F2D321F2F341E32331E302F1D2E2B1C2F2D1E2F2E1D302F1C2B28182E2D1C2B2C1E
27291E25271F22251D22261D20251F1F241D1F241D1E251B1F25181C22161D22151F2416
2226162024141F21141C1E13
080C04090C050A0D060A0A040809030909040C0D060F110B10110B0E0E0910110A0D0F06
0B0E03090C02070A0105070105070103050103050103050102030112160E394532394233
343A31343B33333A33333932374136333D33272F2821281F1F271B1F2516202514232815
242A16252A162A2F1A2E342231362734392A373D2C3A42303A422F363F2B37402A394029
363D2739402A383E2839402A383F29383F2A383F2939412A39412B383F2A38402B383F2A
393F2C3B42303A3F313940303941303A412E3A412C353D25373E25373F24374024394124
383F25394028383F29373F273B43293A43273C432A3D432D3C422F3C4332393F2F373E2C
373E2B393F2B3A412B3B422C3B412C3C432D3D452F373E293339252E35212C33202C3220
2B311D2D341F2D331F2C321D292F1B2A2E1C2B301D2B311D2D321D2D331D2D341D323920
363C22373E25373D2738402B38412B37402A353E263239222F351E323920343B2231381F
3338213339232F34222E33222F32212C3020292D1E2D30202E34252D34262C32252D3325
2D32242C31212E34203035212E301E2E2F1E2B2A1B2A29192C2D19292915272814252716
27291A26271B21231A23251D21231E22261F21271F20271E1D231A1C221A1F251B1C2218
1D231921241B21221B1D1E17
060B03060A010B0E030E0E040B0A030C0C0511130A14180F171A11141711161A1314180E
1216090C0F05080B03050702070802070803040601030401050803040702161C101D2315
2E342447523B323928313728384230333D2E191E17161A1411150E12160C13190B1A1E0D
1E210F1F20102427152C301E323826363C2B38402E3B432F39412C3A432C3B432A3D462A
3E452941462C41462E40442E3F432E3C422D3B412D3C432D3C432E3D43303F463039412C
3B432D3B422E3E42313D42313D42323F44313E442D3B402A3A40283B42283E472A3C4529
3C46293A43283B44293C45293B45283C452840482B4248304449334247363E44333B4132
393E2E373D2B39402C3A432C3940293C442C3B432D3B432E39402C353C282E35222E3322
2E34212D331F2F35203138222F35202D32202D32212E331F2D331D2D331F2C321D2E361F
2F3620313821333B23353D25353C2738412B38432B384129343B24343C24313823323825
303724333B26333A26323A262E35232F36222F37212E341F2F3523333928333A29303626
2F35242B2F222F35242E34222F35222F35212D32202C2F1E2C311D292E1A282D17272B18
282C1B262B1B262A1B24271B25291F252A1F23291E20261B1F271B1E251A1E24181E2518
1F26191F241A21241A1E2018
070A060A0E07090C04080A03090B03080A030B0F090E110C141910171D13181D15192015
161C110E13090A0E04060A02070A02040602050803020502030602070B030B10050C1003
0F1305272C19282D1C2A2E1E3E47323D4734272E221C221B1114110F100C10100A12120A
15160D19190F2427192C301F343B27363D293B43303B442F3A442D39422B3C442D3C452B
3F462C41462E4348314147313E432D3E442F3D422E3E432F4147324147334047323E4630
3D45323D45333E45314146314044324045313D422D3D432E3B412D3E462E3D462E3E482F
3C462F3E472E3D472B3D462A3F492C3F472B434C31444933434835444A38434A38434A38
3E44323A402D39402B373F29373F283A422A3B422D3D44323F47353A4231333B2C31392B
2F37292E37253039253139253139222F371F2E341D2E341C2E351C2D331B2D311B2D311C
2D321F2B301F2C34212D3723323B26313C2632402836422A343E26343E26343E26333D27
323923303721303723333B253139252F37233036232D33212E33223036243037252B3221
2D32232F35252D31222C301F2B301E2C321F2E35222D341F2C321C2A2F192A2F18282D18
282D19272C1C272C1E23271E24291F23281E232A1E21291C2128191F26171F27161F2717
21291A232A1924291B212417
090C0B080B090C0F09080B05050702040502050702090C080B0E0B10130F141812151A13
1419110F130B0B0E04080B01060802050602040502040603040604090C07080C05080C03
080A02080B030D100711130A242B1B303A28262F1F22291C1F23171D1F15191A13151511
15161216161120231A272B212F352833392A3941303A433139422F38412D39402B3A422C
3C432D3E462F3E452F4049323E462F3D432F404632414834414934434B36404833424A34
434C35414A35414A334047304146304348313F43303F45333E44343E45333D4531404932
414B33404A313E482C3F4B2C404B2C3E482C3E472E414831424A36434839474C3D44493A
444B394148354249383B433338403038402E38402D3C432F3F47323F47313B432F373E2D
373E2F373E2D363E2C323B29323B26303A2330382030371E30371E2D341B2E341C2F351D
3035202E311F2E331F2D341F2F3724333E28313D27333F2A35422B334029333F27323C24
2E38212D37212E3721313A23323B253139253238252E33212F3321313321303220313422
3034232F33233035252D31242C32252A32242A31232B33212D34212D331F2B321B292F19
2B301A292E19282C1C262A1C272C2024291E23291D232B1D262C1F23281B2126181F2517
1F26171F26172027191E2318
14191B0F13150C0E0F080A08050804050702030501080B0410140911160A0F140811140A
11140B0E11080B0E060B0E040709030709030506020606030809060B0B05080A03040502
0606020708030708040A0B050B0F0712170C13180D14180F171A0F171B0E1A1E11222619
23261A1F23171F241A23291F2A30262F372A343D2D38412F38422D37402B3A432D39422C
383F2C39402E3D46313E4A323F4B33404932444D34414A32414931424B34444C35474E36
444C35404934414934404931424A32434A3240452F4046303F46323F4732414932414A32
424B33434D36414C33404B30404C30434D33424C34414B34414B35434B36464B36464B36
464B35444A334146344349383E44343D44323A422E3A402B3F442C3E432B40452E404631
4247353D4331393E2D353B2B313929353E2B353D28323A22313821303720323921303721
3135233034233036232D32212F36252E35242E37242E38252F3A252F3B24303B23343F26
333D24333C243139232F37232E3724333B273137242E33212B2F1E3034222E3220303222
2F31212D30202D31222F33232D32232D31262B2E232D32242B32222C32202B311E2A301B
292F1B2A301D2A2E1E272B1E262A1D25291D24281D23261B24281C23271A2024171F2617
1F25171E25161E24171B2214
171D24161D23151B2111141B0C0F130B0F10090B0C0E120E11150F0E11080B0E040D1005
10140911140B1012090F10070C0D050B0A030C0B060A09050A0907090807060504040402
0302020404030709050C0F080E11090C0F070A0E080D10090D10070A0D030E1207171D10
242D1B28321E2B36222C36242F3929303B2C313C2B313B28343E2A343E2A333C27353D27
363E2A37412B39432D39462E39462D3C4930404C32424B33444D34454D37464D39474D3A
454C37454D37454E37464F37464F36474E35464D36454C374149343F48323F4831424D32
424D34445036424E343F4B343F4C343F4B32404B31424E33404D31414C2F414A30444A32
424730454A324449324446334448344348333F462F3E462C3F452A3F43283F442845492F
454A324348334145333E44323A422F3A412C374027353C25343C24323922313621333824
3136212F35202E351F2D33212D32222E33263037272E38252F3825303A262E3A22323E23
364124374023374025343C233138223137243238263137252F34222D32202D311F2E3320
2E32212E31202D2E1E2E31212E33232E31252D30243036272B3223282F202B321F2A2F1D
2B2E1E2B2F1F272B1C272B1C262A1B26291C24271C20251A20241920261C1E251B1E241A
1E25191A20141C23151B2013
242C31232A2F21272B1E24291B2125151A1E1114171316171113120B0B0B0B0D090E1109
0F140A10140911130A0E10070B0E050D0D050D0C060D0D08100F0D0F0F100A0B0C050506
0404040507050E110E12161011140D0E120B0D11090C0F080C0F0A080B06080B040A0D05
0F14091A21132D3623353F2A3B452E3A4530373F2E363E2B353D2A333B2A333A292F3726
2F372A2E3628313A2A333E2B36422D3A462F3C48313F4931434C36454C39444C39454D3C
474F3C48523C47513A48543B465037454F37454F37464F38434C36434D35414A31424D31
424C33454F36414C353F4A35404C333E4A2E3E4D2E3F4D30404E30404C2F404A2F424B31
434831454A3444473544473542473542473440473041472F40472B3D432642472A43482B
42462D4348314347334044334347354249333C452F3A422A383F27363C26343926303623
2E33213136233135222E321E2F33202E3321313826303827303A26313C292F3A27303B25
313D23344024374025353D243138242E34222E34233137272F35242F34222E35202D331F
2D321F2E33222C2E202D2F222C2E222E31252E32222D33212C32222A2F1F2B301E2C321D
2B2F1D2B2E1D292D1E272C1F24271A22251922271C20261C21281E1F251C1F261B1C2317
1B22151B23141D23131B1F10
23282F262D30242B2B232A29242A292329272026252025251518191012130E10100F120E
11160E11160C11150A0E12060B0E040A0C040E11080E110811130D0F110E0F11100D0F0E
0607080708081014101519141216110C0E0A080A05070A04080A04090B04090C04090B03
080A030F14091A1E10232717282C1C3137263A41313C44333A4332384132353E3130382D
2C332A272F26242B22232B1F2D3727343F2B39452E3E4930434D34454D37444C38434C3A
434B39414A37444D384650394751394650394A553C49543A475037454D34454D34444B32
444B32465036444D36454F39454F38424E34404D30434E30444F30454F31424A2F454A32
434733444838454839434738434837414835414932434E33454F32444C2F454C2E454B2D
464A2D40442C3F432F3E43344148363E46303D462E3E472D3D462C393F28353B252F3520
3035232E32212E33203033203033212F3322303727323A292E37262F3A28303B29303B27
2E39242F3A23353F25363F25353D25333925313726313726313725333927323826303624
2C31202A2F212A2E23282C212A2F222D32232D33232C33202C301F2B301D2C331C2C341B
2D341B282B18292A1B28291E24261B25281C22261C1F241B23291E21271C20261C1E2519
1F24141E23121E21111B1F0D
292F322B3035272C2E242A2B252A29282E2B272E2D242A2D23282A1E2225181C1D141917
161A1312170C0D12050C10020B0F030C10050F14071015080F12090E100B0D0E0C0F100E
0D0E0C10110C151812161A1112160D10140B0C0F04060901070A01080A02090A04090C04
090B050A0C0910140F141713191C17191B172F362A3F4938434E3A424D39404A39353E30
2D3528242B201C2119171A161A1F18252D212E362836412E3E4A33444E36434C34404934
414936404935424A36444A38464D3B48503D48523D475239465137444F35465137465034
485033464E34485036474F38454D36444E37444E36434E34424C32424C32434B34474D35
464C37464B39464A39474B3A484D3D484E3B474F3A454E37454E37464F36464F33444D30
454C3141462D3E422D3D43303B42313D44343D44313F48323C442F3A412D3C442F38402C
353A293034242F3422323824313722303623303624343B282F3826303A27323D27323E27
313D252E3821303A22323C24353C26363C28353B292F35242E33232E3423323826323826
3339262F34232E34232D32222B30212C33252E34242E35222C311F2A2F1D2E34212C321E
2B2F1C2C2F1C2D2F1F2A2C1F272A2025281F23261D21251B22271D21241A2024171E2315
2024152024142124131E2111
2A2E2C2B2F302A2C2F282B2B262928262B28272C2B282E30272C31262D30252C2D222927
1E241F151A120F130B0D100811130A0E0F090E0D0A100F0D10100C070505050606060707
0708060F110A15180D191F10171D0E11170A0D11040A0D010B0D03080A030D0F070D100A
0C0E090A0B090A0A0B0F0E1012121314141419191624282033392C3C4434464F3C343B2D
292F2321271A1B1F14191B13171912181D1523291F2D3628343F2C3B46303C48303E4930
414A32404933404834414937424837434B39434D39414D37424F37425036444F35445032
444E2F464F30475031464E32454E34414A33414A33414B33414C33404B32424C34444D37
464C38464B37454937474B3B464A3B484B3D464C3A414934434C35424C32444E32424B2F
42492D42492D3E422C3B3F2B3A3E2E393E303B42323C43323A42333A423139412F38412B
373F29333923323922343A222F36202E35212D35232F3826303825303B26303C222F3B21
303C20303C202E391F303A21313C22343D243137243137253036232F36212F361F323923
363C26333A233137242F35222C322029301E282E1C2B311D2A301B2B311C2A2D1D2C2F21
2D2F212C2F202B2E21292A2026271F24261E22251C21231A2022171F22162023161D2013
1F23142225162023161C2114
242C272A31292E322B2F322B2F302C2C2E2B2F312F2C2E302A2B322E30372F3237303436
272C2B191D1C171816141212131111120F120F0C120D0B110A090F06060B050508060707
0405030A0C04171D0D1C2210171C0C1114080D0F050A0C030B0D060B0D070F120B12150B
0F100A100F0C0D0C0A0F0D0D1715131A18151615131818151B1B1722231C2B2E24282C23
1F231B181C130F1009191D141F251A232A1D252D1F262F202A34212D3924323E2836432B
3D4830424C34444E37424B38424C38444F3A445039445138465438495639485438485336
485336485334465134444E33434E31455036445037445036424E35424E34414B33434D35
464F39474F39494E3A494E3A4A4E3C4C503E4C523E4A503C464E38474F37444D32434C31
454E33454E354249324247334044323D43323F46344049354049353E47323C463039442E
3D4A2F374228384227353F24323A20323A223038232F3825333B27313B26323E26323D23
323C22323D24333C24363F26374026384029363D29353B28303624313723313821343A22
393E26383F26373E28333A242E36202B331F2B331E2B331E2C321E2E331F2B301E2C301F
2C31202D32222E3323282D1E25291B282C1E282B2125281D24281C24291C22271A222718
222817202717202618212618
18201F1E251D242A1F292B232B2D262D2F292F322E2F31303032342F323731383B37403F
3038362227271F22231E1E2217151D11111A0E0F190D0E1806061105040F04040A020405
0305030608021217091A2011191D1016160D11110A0D0D070C0D090F120E151714181A15
1618151012110D0D0E101213141314181717141113131212151413151413191A151C1F17
16191112150C1010080D0C051C1F11252B1C252B1F1D231A1B23181A21161E2618252E1D
2E392436422B3B48303F4B33414E34424E33445234455536455235495439485238475038
495339495339485338475237455036444F36444F36475138444E36454F36424B34424C36
444D37464D39484E39494E3A4B4F3A4B4F394D513B5458425256424D523D4A503A494F39
474D38454C38454C37454C35454D35434932434A32434C33424B334149333F48313D4730
3D49323B472F39462C374327354122323E22313A1F323A21333E25343E25373F27363E29
353F29333D28343B26363C28353B27383F2A373F2A37402B353E2B343D27333C222E361D
30351E333920333A21343C22313A202D361D2C331B2A321A282D19292E1A292D1C2B2F1F
2E32212C32222A2F212C3121282C1D23281B262A1D25281B25291C24271C22291D21291D
222B1C242C1D21281A232819
1B20221B201D181D171B1E171F221D2628222E322B30332F3237343137362E35372F3739
3139392E3635282E2E272C2F22262E21242E20222E1B1E291517210E0F19090A1306070D
05070905060511160E181D11171C1015160E13130D14130F131311151413191B181E221E
2026231F2521181C1B171B1C191D1C14171A1111150F0F110F10100E100E0F110C14170F
11140B0F13080D10050B0C03252C192F37222D36231B2216181F1413170E13180E14190E
191E121E2516262E1C2E3722343F263B462B414E30444F3347533548523849523949543A
4A553A475335465435475439485539465238465239454F37465038475038484F39495038
494F39494E3B494F3B474C39494E3B4B4F3B4D513D50533D51543C4F523B4C513C4C513C
494F3A454E3A465039424C34434D3340482E414730434931434833444936434936404834
3F48343C453138422D374228354022333D1F333C20313A20323B22344025384327333E25
343F27323C25363E29363C2A383D2C383E2E38402E353C2A373F2A37402A363E27313823
2D351E2C351C2D361C2D351C31391F2E361C2B32192A2F172C311B2D331F2A2E1E2B3021
2A3022292F202B30202A3120293120262E1C232B19212816202716242919242A1A202819
1F251822281C202519202517
2024241C1F20191D1B171B16171C151D201821231924271F2A2D272D312F2F3533303837
363F3B2E37342B33312C34332E343630353730343930333B2C2E372528321E212A11131D
0B0E1508090E0D100F141711161B1214181114140D13130E14140E1819121E211A1D201C
222724232A27252C28242B27272D281A1E1D1315170E0F120E0E100E0F0F101110121411
1115100F120D0E110B0C0F07191F111D25142028151E26151C2313171C1014160C14150D
15170E14170D14170D191E112229162B341D364025404A2D434D31465134475136495236
49543449553848543849553A4B573C49543B49543C48543B465239454E37464E364C523A
4B523B4A523D494E3B494E3A494F394A503B4A4F3A4F543C4D51394E523A4F543D4D553C
4C533B475138465138444F35475236485338454F36444C34444C35444B37444936414735
4149353C44313B432E3C452B384226343D20343D20353F21343D22353E23374024363F24
353E25363E26353C27343B27373E2B373D2A373F2B363D29363D29373E29353C28323B26
313C242F3A212E39202B361E2D361E3038202D331F2B311D2A2E1E2D32222C3122293021
2931212A3121282F1F29311E28311C232C17252E18252E18232C17242C18242C18202917
202818242B1A23291A1F2517
1D23211F22211C1D1E181A19191C171B1C161B1B151C1D181C1C191F1F1D232522272D2A
2F3732313A333039312F38332D34322E333432353932353C3437403237402E343C272D35
1D232A181D2114191B161B17191E17161B1314181014180F1719101A1D14171912141712
181B161E231E282E272C322A2F362D2C342C1C201D181A18151315110F110F0D11101013
11121313161510141210171012190F171F0F18200D181F0C181F0C161B0B141809141809
131609111508111508121609191E0E191B0A232713343B213D4529444E304852334B5436
4A55374854394853384753394A563B4A563C4A563E49553E48553D46513A47503A47503B
49533F49543E47513A474F384850384A4F384B51394C4F384D513A4C513A4B513D4B523E
4A533E47513B444F37444F36454F36454F37444F36444E36465038475038454B37454B37
444B363F46333D44313B432E3B442B363F27394326394424384223373F243841253A4227
3A4228394029373E29333A27333926303624333927363D29363D28353D28323A25353D27
353C25353D25343D24353D242F371F30361E2F35212F35232E33222E33242E33262D3325
2C32222B311F272C1A272D182A311B272F1926301A262F1A252D19262E1A232B17222A17
2129151F2813222918212618
131617282B272120231D1B1F19171C18171A181718191818161515141412131613171C16
20271F262E232B3527333C303138303136302F323130333632343C343840343A40323A3E
2F373B283134222B2B2027241C231E161A17171B17171B15171B14191D151518110F120C
0F110D1216101F241B272B202D322630352A30352B2C302A262A271E202217191F15161D
111419111417171C1A1B221B1A21181A221418200E1A210E171E0C141A091319090F1506
0F150511140512160614170716190A1214061616081D1E0B2E2F19383C26434A33485239
49543A4B573D4B573B4A583949583949563949543B4A563C49553D47513B46503D46503D
49533F4A543E4A553C465035465032474F33474D34484D35494C35474B36494F3C484F3E
464F3C46503A465037455036444E35444D35444D35434C34434C35474E37444933454936
474D39444B383E45363C4335394231363F2D36412C3642283540243640243841243A4327
363D23353C24373C263339263339273035272E3426313827323A26323925313924313A23
31382132392131382031381F2E351C2E321C2E331F2E32212E32232D30252E33252D3322
2F34232E33222A2E1E262C1B282D1C262C19252C1A252C1A282C1B282F1C282F1E242B1C
2027171E25141E25131F2314
70787139413830342F2A2B2B27282A2323261E1C201C1A1D191818171814131611131711
131810151A10222719292D1E2F332935383033373033363335373B393C41383C43353C43
32393F313A3D2D3537262E2F2026281E23251E20221E1F1E1C1E1C1719191315150F1011
0D0D0D1619161F231B1E22191D1F151E2117282C232C312A2E332E2D3331292F2F1E2324
191E1F171C1D1B211C1C231C1D251B1B21161A1F111B21101B1F1115180B13150B111309
10120A10120812140917180C17180E15150B1615091715051D1B0A1E1D0D363B253F4730
4750364B53384E573B4D58394B583A4B573A4A553A4A563B4A563B4C583E4A553D47523C
4751394A533A495339464F35475135465035464F35474E36464C34474D35494E38495038
454C38454C37454E36444D36444C35444D34454C34444B34464C36474E36484F36474D36
464B38454A3942493A3F463A3C43363A4233363E2E323D2A333F28323E24353F24353F24
353E25333C27353C273339262F35232F35243036242C31212F3622333925333B26313925
323A253139243038222F37202C341E2C341E2E341F2C311F2B2F1F2B2F202E32232C3121
2B30202C31202B3222282F20252D1D232B19222917252A19292E1C262C1C262D1D252B1B
23291A232A1A2128161F2310
FFFFFFFFFFFFA2A7A54E5A53474F4B3F44423639392D302E2427211F22181D21171C2017
1E21182123181F2015201E172725242D2D2C2E2E2D2F2F3136393A393D403A3F453B4448
384146343E422F383B2F38392B31332C3432303835292C2C25272C1F1E2615131D100D17
0E0C1517171C1C2021181B1B1214120E100D131712181C18222823282F2A2B332C222923
1E261F242C23222B211F281E1D251A181E14171D101C21121B1F10191A0C14150A15150B
13130C10100911100A12120B13130C17170F18180E202111232412242715292F1A353B22
3F4529464C314B52384F563B4F583F4E59414B56414B57424A563E4A553B4A54394D573A
4E553A4B51384D5239494E37494E3949503A474F38495138485035495136474D33464B31
454A32474C33484F37484F39494F3A484E39474B39474B39444B39434B36454F35454D33
474F34444A344549364347373E43353E4435393E2F353C2C323B29333F28323F24323E23
313D22333C22363F24343B22323920313820353D25333923313621313623323824323825
333928313928303A272E38252E37242E38232D37222C36202C321E2D31202C2E1F2E3121
2E31212E32252D32262C3226272E22232B1F242C1E242B1C272D1D252C1E222A1C21291C
22291B232A1A2229161F2611
FFFFFFFFFFFFFFFFFFFFFFFFDCDFDFB2B8B870807C5F6E6C444F4F404A4848514B4C554A
4A51453739342D2D2C2D2C302D2C322B2A302422272320242B2A2B2E303235393C383D41
394142363F412F373B2C34382E3738323A39363F3D363E3D393F4034373C2929341F1E2C
1B1A271E1F281E212613151A1012130F0F0E0E0E0D111210141512171A171D221E1F2722
28312929342A29342A26312720281D1C24161B22121B21121D21121A1C0E17170B17180D
16170D13130A13120B12120B14140D0F0F0C1212103C463544523D495940435238414D33
3F482C3E462B43492F464C344A513B4B533F4B55414B57404A573E4B553B4A52394E553B
50563C525A3F50563D50543C4C503B4A503C4C523B4B52394B52364A5135474E33474D33
484D354A4E354B4F37484D394C513D4A503E464C39444A37444E39444E37444E35434D34
454F35454D35464D35464B35464A37454A364146333C4031393F2F36402B343E27343E24
353E23363E25363E25363E25363E25363D25353C26343A26353C273238252F36222F3623
2E37242D37262F39262F39262F39272E38262F3A272E38262E36262C31232B2F212C3123
2E32252D30252B2F252A2E25282E25252C22262D22242B1E262D1E242B1C23281B22271A
2128192129182027171F2616
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0E5E59EABAE7A8B8F7D908E81958F
7F93896C79735F6A6665726D484F532727321F1E271A181E18161B1C1C1F2627272D312E
353A37373E3D363F4031393D3943443C47473E48483D46493E454A3B4047393E46333A44
2F353F2C313A1D212C15172112131A111013131312131311100F0E10100C10120F141713
2831282831292D372C283126242C2320281E1E261B1D23191C2117191E15171B12171B11
15180D16170C15160B19191115140F1818121D1E1834392E525F4B57675057694F556649
4C5B3F455339444F35434C33454F354750384A533B4F573F4C553D4D563D50593E4F583E
4D563E4F584050573D50583C4E563A4E55394E543A4E543B4D533B4B523B4D533C4B513C
4A4F3A494E36494E35494E36484E37494F39484E36474D35485037474F38464F38455037
475238475037464D36464D36464C35464B344247314148333E45303B422E3A412C353B27
343B27333B2736402A363F2A343F2A323D28333E28323B28333C2A323D28313C28313B27
303926313B26303A252F38252F3827343D2D333C2F30392E323B2F2F35292D32262C3125
2D31252B30242B3124293023292E222B30232A2F23282C22282C2025291B22251922261A
21261A25291B24291B21241A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC4CFCFA8B9B5
8AA2988BA2948A9E918CA0926E7C76201F2C1F1E271B191F17151A1412151514161F201F
2427242A2F2B343D38363F3B434F4845524B404B47404A4A3C44483C444A394149394149
3A434E38424B363E46262B361B1E291619201313191312160E0D10110F0F12100F191C16
2A3228242C24252C24282F25282F24232B212329201E231D1E231F1F241F1F261E1C2119
1A1E151A1E14191D121D1F141A19111D1D162A2A2026241C494E3E55614B4D5C46495743
4E5E475162464E5F404758384654334752344851334A52384B523A4A51394C543B4D5A3E
4A563C4D5A3E4F5C3F4B573B4D563C4E553B4E553B4E523C4F533E4E53404D5140494F3F
49504048513E485139485038474F37485037474F34494F35484C35484C38474C3A444C39
46503C434C3A444D3A434C38424A33424931414A31424A31454A314247313E45303B4230
383E2F343A2A333C2B313A2C303A2C303C2A2F3C26313E26323F26344026323D25323B26
343B263239253239263036243037252F35252F3729313A2D2F3A2B2E38282D36252A3222
2931212931212A33212C35222D33212B2E1F2F31232C2F23292D1F26291B22251822251A
21231C25281F23251E21231D
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC7D2CB91A79792A896899E8D515C582021292122261C1C1D161516161415151313
1716141C1D19222521272C28323A3339423B3D433D3E45413F45473E45493E454A3E474B
40474E3F464C3E464E3F484F3A424831383D23252A1D1D221A191F16141B110E15222525
2227251D221F1B201B22291F272F22252B1E22261B23291F222820242B2222281E232A1F
20271D20271B2025191B1E151A1A141616131B1B171C1C175D6B525E6F5644513F2F382C
313A2D35402D4F62424F623F51623E4F5F3B4855364751374A523A4A523D48523C46513A
46543B49573D4E5B404B573D4D573F4C563E4D543C4C523D494F3B4A513E4B52404A5241
49514047503F47503E46503C47513A4A5339485035474E34494F36484D37474E37474F3A
464D3C454D3A464F3B444C38424B35424A32434B32464E33454B32434831444833424933
3E4533383F2E333D2C2E3828313B2B303A28313D26323E23313B20323B21343B24333A25
333A253037223239233239243138252C34222D37233139263039263038293138252C3220
2D3321292E1D292F1E28301E28301D2A311D2D31202D31222A2E2025291E21251A1E2117
23251A24281E21241E20231E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE4EAE5CAD6CC7C8F7F414A472E32302729281D1C1F1A181B171616
161514171815191A15171A141D201A23262030342C3C4039404540434844454D4A454D4D
474F51444E52424C50414D4E404A4B4148493E4344393C3F35373C282731211E2A2B2C2F
21222614151A131517181B17181D161C21191F241B20251C21281C1F271A20261922291A
232A1A242A1B2225191F21171C1D181A1A191F201F1B1E1D3640353C4739272D252C3228
2529201D2016252D1C3D4B31556847596D4C56684B505F454A563F49543F46503E404B3A
3F4C3A424F3C47543F4A58424C58434C57424B564049553B4A553B4D563B4A553949523A
4B533C48503D474F3F49523F49543C49543B465035475135475035485036464D36474F36
495039464D38464D3B454D3A454E38454E38424A34434C34434D33434C3141482E424A31
4048313D46313B4330394030343B2D343A2A323A27313A26333C25333C24323A242E3621
2C35222D37222D3722313A252E36233038252E35232E35232F36242F3625323826323924
3037222D34202B322028301F2831222A32222B31212A322128301F252C1D22281C22281B
242A1A23271922261A20241B
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBBC4BF848F8B3F45462F323626252C222026
201F201C1B191B1B161918141818141818151715122828202F2F29393C353F453F424945
454E4C465251404B4C3E484A414C4B424A4D444A4D464C4E44484D4144493C3E47373A42
23242F17162211111B1012170E10140F11131215131A1F191D231A1F251B1E2318202719
232A1A262C1D24271B25271F26282227292826282A202527191C1F191D1E1A1D1D21231F
1F201C1C1E1A191C18191D18313B2C414F3B4F6048586B4F596C504B58433640312F382B
2E382A323C2E364132414D3A44513C4A574048563E49573F4B583C4E5C3B4A56364C5636
4B543749513949523C48503A46513848543A475237465136475136465134475135474F35
474D33464A33464B34494F39474E38485038475037454D35454D34444D333F482F404831
3F4731424A34424A343D45303A412F383D2D343A2933392A343A2A363D2B363E2A343E2A
2D37262A33222D34212E33202E33202F35212E34202E3420303823323923313822303822
2F37212E37232D34232A3121282F22262F20293321262F1E242C1C272F1E22291A1D2316
1F2616222615232716212316
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA5A8A9696B6E313336
2C2E2C2425211E1F1B1C1B191A1917171513171211171211181412221F1B33322C3F433C
3F4641434D49434E4B444E4D414C4C434D4E454D4D444A4C44494B494C50494B53464853
3C3E4A3134401F222D13132013131C1111171112151415161A1E1B1E231E1F241F20261C
232A1F262B1F26291F25271F34373034373531343723242A1E1E2417171D17171C1B1D1D
1C201C1A1D191B211B1B211B181F181F271A242D1D313D2954674A5062472B3525232B1E
1C22171A21151A20142F392539432D444E3649543C4A56404A553F4C583E4B573B4B573A
4955384853374B55384B5237484F36464E37495239454F37444E36444E36455038444D34
444C3042492F454B32464C33464B32484D35474D35484D38474C3A4449384148363F4634
3D45323E46313F48313F48303F47303F46303C422D3B3E2B38392B36392B34392C32392B
2E36272D35242D34222C341E2D341D2D351D2A341B2831192C341B2F371E2D361E303722
2E34222D34262C3329252B23232A22232B20252D21262E21272F1F252E1D232B19202816
222916222613212412202311
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCECFCF
9FA29E3A4037272C2422271F1B1D191919171814131A14131812111A14141E1917252320
2E302D363B383D4540404945444E4A47514D49514D474F4B474C4A47494B45464D454650
454852454A5440454E31373E1D1F291B1D2516191E11121915181E1D2224202625212824
232A25242B252429232225203437303F453D424843363B382B2E2F2223261B1A1F1C1D20
1A1D1F1A1D1C1A1E1B161B17131713181E131D2415181F0F252E1D2A342221291A1B2214
1B21141B2114171D11232A1B2B32203C462F404A32444E37444E394C573E4C593D4D593C
4C58394954374E57394B5135494F364A5138484F38464F39454E39454F3A46503B46503B
454D35424A313D442D3E432B3F432A42462E454B33454A35474C38474D3A444A39404739
4046383E46343D45303C442F3D44303D432E41452F3D402C3B3D2E3C3F30373B2F33382E
31372C32372B2E35242C34212E37222F39212F381E2C351E2C321D2D341F2B321D2F3521
2D34232D35272D362A2A3127252D23262F24232A1F242D1E262F1F262F1D242D18252E17
272E16272D1322260F20240F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCED0CE979A98292A2A2323261F1D201C19191D1A191D1B1A1D1B1A1F1E1B
1F1D1B2121202628253033303F453F474F474C544D4D55514C5252494C51464951454851
4146514B565B424C524853533D46453A41403134391F202B1A1B27292D35272D3321282B
1F27262029251F272220262020211E2D302B383E393D453E3C433D39413B313532262B2B
2025261C1F21171B1A1215130E110F171C141A20151A1F131D2216232A1C262D201D2418
1B22151C23171E2519293324333E2A38452E3E4931424C30434C304952354951334A5335
4D55394D54394F573B4B53394B53394A54394953374A553949543A4A533A4B543B4D543E
4E523D4A4F3A464A38434835414631404730404730404730414731444C34424B34424935
4249374047363C44333F47363F47363C45323E46313C44303B42313C42323A4031394031
39412F3A422E363F2A343C27363D29363C29333A26323A273038282C35272A3225293224
2A33242A34242B35252E38282B34252933232B3422292F1E2B301F2A301E2C321D2B311A
2B3018282E16282C17262915
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FA2A16262672A2B312D2F333235372B2C2D272828
25262522242124262226282330342D34383241463D494D464F514F4F52534E53584A5157
434B52414C4F424E4E46524E4B57534A525249505344484F383C46353C442125311B2028
161D20141B1C161B18171B171414141715182120223437333C423C40473F4149403E4840
2E3633252C2D1E2326171C1C10141210141114161215191221281D252D1F2A3223252D1E
242C1C222A1A1E2416262D1F2B3121323925353C273C43293D4429444A30484D33484D33
494F334C51364C52394D543A4B533A4953394954384B56394953384951384A503B4C513F
4E53414D513F4A4F3D464B3A434A36424A34434D353F49333F4A343E48313D462F3E4830
3F47313E46313A42303C45323C453239422F37412E36402D37422F36402D38412E35402D
39422E38412D37412B363F2B38402D38412E383F2D363C2D323B2E30392E2F392D2B352A
2A33272831232730202832202933202B341F2C36202B331C2A2F192A2F1A262A1A282C1B
272C19252A17282A1B27291B
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFADB2B1888F8D4F54574C5452
444B44383D3634372E31312A302F29302E2C3533313836344343404849484D52514F5756
4C585549565047524C47524D4E58554E55574E535B4D555E4C555D475358343E472C353D
1A23291C2324171A1B131317110E141A15181A14143C3C323B3A343938353739363A3E3B
3F45413E474339443F27302D12181612171310141012150F262E20262D1F292F1F2A301D
29301D29321E2B311E272C1A2326172223151F20122629182F311F3F432C474E33475036
4A5337495235495137484E37474D36474E3749513A48523947513847523949533E49533F
4D574249523E46503A454F38444E36444E36434E35434F37414C353F4B333D49313C4A30
3D482E3D462F3D462F3B452E3A43303B443139433037412E3944303A453137422E34402B
34402B35402A353F2B343F2B38422D38412B39412C373F2D353B2C343C2D333C2D313A2D
2F382B2C36272831212933212B35212C36212C34202B331E2B311C2C331E2A2F1B292F19
282E18262B17282C1B282D1C
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3E7E4C5CDC6
8B9D8C545F594B534C474D4644444043423E3F3F3A3635323433323736374141424A4D4D
4A524F4E58504F5A4E535F52535D554F57564B52584D535D5058614F5A634C586149555C
3D484D364041252A2E2323271D171D1E161A27222146453D2C2728282527231F23232023
2F3230373F3A3C473F3D4C3F232E25151D1511170D0D100714180E161B0F191D0D212513
242918282F1E272D1C24291B212519282D2021251A1F21181E1F163D45315C6A4C586548
586547535C434E553F49503D474D3A454C38454C38424B36424B37444D38454F3C47523D
48523B49553C48523B454F37434D35414C34424E35435136414F34445034404D313F4A30
3E482E4048314148313D44313D43343B43343942323A43323B473337422E37442E37442C
37432A374228384128363E27363D27363C28373E2A363D2B353D2D343D2B333C2A2E3727
2E37282D36272A34242A34222933212B33202C321F2C301E2B2F1D2B2F1D292E1A252A16
232716272B1A262A19262C1A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFDEE1E0BCC3C0727A797D887E86937F46484245474041413B3D3A383E3A3A3C393A
3E3D3F4244424B514950594E535E52535D564E57554E545854575D52575E4D535E4E5660
4D585F4D5B5D485454404A4A3335362824283937353F3F392520232320241B171E161219
1615181B1D1D2328232931282731251A2319171D12171E1112180C14190D14180D14170C
181C101A1F131C2014171C1313161121281E252C20282D22282C213136274D58405F6B52
6270566371595C6953505A48494F3F4246353D41313A3F303B41303E4233414736444C38
47513B48513E454F3E444F3D3F4B38414E37404F34415032414F32424D30424D32424C31
444C324147324248353E44353D45373C463938433537423039463037442D38442C37432A
3B452C3A422A383E2A373E2B323928303827303927323B28313C29313C28313C27303B25
2F39232E37212C351F2B341D29301C2B301E2D301F2C2D1D2D2F1E2D2F1F2B2C1D282A1B
272A1B282B1D282C1E25291E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFD0D5D1B9C4B7828F7D75816D53584D56594E5152494B4B45
45444140403B3E3F3941433B484D434D534A525953545C58585D5E565B5E52575D50575D
4E565B4B585A4E5C5C525F5B525C574C504F494A4B3B3A3D221E291E1D281A192414121C
14141A121417111513131813141B13131C13141C111921121C23131A1F12181C0F191B0F
16180E191C1115150C11120910100A11110D161712191A121B1C152A2E2332362C485141
525E4B5D6D5762745E6678605865513E44352E2F2227261B27251A302E2135352839392B
404432444A37434D3B434F3D3F4C383F4D3440503041502D414F2D434F2C404A2941472A
42482F4348333F45353F46373B42353B443738433536403035412C3542293541273A4428
3940283B4129383C283A3E2B383C2D363C2E323A2C313B2E2D362A2B35282C37242E3A23
2F3A212F3A1F2E391D2C361C2D361C2D331C2F331D2F301F3132212F2F1F2E2D202C2C21
2B2D242B2E2525292022251E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0D6CAABB1A4919A89858D7E7B8273
666D5E4E534346493A4042353A3A313D3E363E403B4649464E5252545B5B545D5E525D5C
4E5A594C58574B5756525D5B58625D5C625F595D5F555A603839472D303F222532181B27
15182313171C1016170D13100B100B12190F1A22131F2814232C17232B172126141F2313
1E22131A1C0E161809110F05110E0714110D16141019171516131314131618161A262826
313632414C424F5F4D5A6C535061485A6B4B4148323738282F2B232E28262721222B2825
33332A393E323D45363F49343C47303C482C3B4828404B2A3E482A3D45293C42273C4228
3C432D3B422F394030394133374033343E30363F2F38402D38412A3741273A42273E452A
3D442B3D432C3D422D393D2B373C2C363E2F343C30313A2D2C35282C35282B34262B3523
2C37232E38212F3A222E3A212C371F2C351F2F36202D311F2B2E1E2A2D1F2B2E212A2D23
282C23282C2325291F22261C
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBEEEAD4D9D1A5B1A2
909B8C86937E5156493D4137363A322F312B2C2D282C2B293636334B4F494E5550535C59
56605C545F5C505B5B505B5B545D5C59615E5A615D5D63625C6263555C603E444B333A40
252B33191E2411161A0C12120A100B121A0E1B2311252F182D37212F3A222B341C212914
1D220F191B0A14160613140512110716130B1B180F1F1C12201D18211F1C221E1C1E1C1B
23222233363140483D515E4923281E272F202A332344513959664B575E48525645494B3C
3F40343B3E333D42353F45363F45343C432F3C442B3C43283C4529394028383F27383F29
373D29353C28363D29383F2E383F30353C2E343A2B343A29393E2B3B412F39402D383F2C
39412D393F2D38402E38402B363D28363E29363D2A3139272D35262D34262C33252C3325
2B33262B34272B34272B35262C36242C35232C342129311E2A301F2A2F1D2A301C272C1A
2A2F1D2B2F1F2A2E1C272C1B
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EAEDEAD0D8D07B877C474E4D3E443F373C3430332A2C2D232A28202C28233B3B34434540
4A4F4B505853545E5A58645D5D696159635C565E575A615A585F5A59625E57615F535F5C
4A57553742421E24271418180F130F171D111D2616222B1828321B2E38212B341D242B15
1D200F16160A1010060E0E0711120A13130E282B202122181D1C1250593D474D34282720
444B403D4239363B342F342D26292118191313130D0F0F093A43307F94708194737D9072
565F51515A4E4D544A494F43474B3E4247384147323D462D3E492C3D472B3C442A3A4329
373F25373F26353C27363B28393E2B373C2C32372934382935392B34382C343A2E343B2E
353D30333C2E323C2B333D28333F26323E24313C222E381F2E36212E35222D33212D3322
2A32242931262831272A34282A35252A35242B36212B361F29331E29321C2A3118293017
292E18282D19292C19282B19
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBCC2BD8A928A474E47383D34363B2C31332635352A32312B32302F
3230303433334348424F574E5761555963575B6557586255545D53555F5558655956635B
52615B55655C3A45401A1F1F1A1F1A181D15181E141A20121C22121E2413212516242918
1E221314150D13110E11100F0F0E0E12101023241F1513132F332EABC89EA8C5A06A7C6A
4752494650452123201E1F1B16161318181313120F12100E141211788C6D95AD8A8BA082
84987F6B7A6C67766864726162705C5C675655614D515E464D584047523A454F38434B36
3F47323D432F3A3F2B393C2B393B2C373A2A34372B33362A32352933372A3135282F3429
2F36292C35272933242D37262B35242C35242D38242D38212C371F2B341E2B331F2A3220
2A32212931212A34252B34252B35242932202B34202A321C29321D29321B2B321A272E18
272B17262C1A262C1D242A1B
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA2A3A184887F5D63574B4E4640403D3D3B39
3633312E2B282926232C2A25404437494E4159604E5A63515A65534C56495662504E5948
4A57484857484D5D4C384437252C211F26181D2114181C0E191B0E191A0D1D1D12202118
1F201718191214130D14130D14131012100F1615141C1C1B1D1D1F6371607B8F78B1D3AA
697D6533392C262A1D1E1F1516150D120E0B14100E141010100E0E363D3395B18E889F82
869C817A8D75545F535A6655606D5B6D7B687D8F7980947B7D8F7677876D68745C606753
5B6051565B514F544A474E433E44383A4035393C34363931353930373B2E33382B323829
3138282F37292D35292C33282E35292C33272A33252D36232D361F2A311A2E341D2B311C
2A301E29301F28301F283122262E1F28301F262C1B282E1B262B19272C1A262A1B242919
212718242C1E232B2021291E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE8EBE6BCBFBA676962595A54
373032352F2E2E29282824222A2822303027393C2E474C3A464D3A353A2E383F30323A2A
2C35253039283B4631424D342B31202D31212428191F2115191A1018180F1D1D1522231C
20221C1616131315101316101316101414101E1F1B202221232623222624313833677864
6576613E47391E1F1725251A130E0B110C0A0F080B0E060C0F0B1147504881988188A089
7F967F869C80798B726B77635B62555D66588A9C8286987E8A9C8092A3858595785E6555
646A5E6C74696D776C687368626D5F5B6558535D5249524A454C4740473F3E463B3D4438
3B4335384034323A312F332C2E332A2D32272C30232C301E2D321D2E301B31321C31341D
2E331F272C1B1F27161A2013171D10191F121B21141E2315242919282C1C272A1D24271B
25281D22281D20271E21291F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD9D9D8
9E9A9C3A34343B373337342E34322A3534283435263030212E2E1E2B291C252519202215
222616252918303520373C263135232C2F2024261C1E1F191B1C181A1C171F201D242522
1E211D1B1E19171915181B14181B1214171014151122241D2C3126343A2D373F32434C3C
485240434B3A1D1E1721231C1B1917171214140E14110B130F0B1338393A6D7B6E718474
7C927B82977C899C7F8A9C7F8091787C8B737D8F7582957985967B84947A93A58A84937F
555C57585F5851565174806E85957D5E675D59625B5A655E616D64637066647166616F61
5E69595962524F5648454A3F393A3234352C3436293134232D2F1E30311E32321F2F301F
2C2F20222518191C100F1308090C04060802090B05090C05171C0F1D2314222718242719
24261C24271D20241B1E2319
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA6A6A28C91814D5040494D3B4447353F3F2F3230232F2D222A291E28271B
262818272A192F31203B3D2C393B2D31312828282222231E1D1E1A1E201C252724282B27
2527222226201E211C1B1D1A1B1E1712140E11110D14130E191B12272D1F343B2947523A
454F37373E2A2C322225281D20211B1D1D191C1B1B1918181A1A1A181919292D2940483D
4C55485D66549AAD8D93A48993A58992A4878FA0838D9F828C9E83899982889984899B86
7989796E7A6D656E62636D5FA0B6978EA3895B665C5B675D545E56535C546E7E6D788A76
7C8F787D9078798B736C7A66636E5C5E6756555C4B4D5241484D3B4447343D3F2C35382A
30352A282C23181B120D1109090C05050701050702030501020401090B050E110616190B
1E2113232717232919252D1D
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFC4BA989E8F595C4C4343344244323B3E2B3C3F2A
373A233639223537263C3B2D3E3C3038372D2D2D2526261F1F1F191F1F1923241E282922
2B2E282E312A2B2F2A2023231B1D1B1112100F120E0E110D12150F161A13252A1D282F1F
2A301F2D3220262A192122151E1E181B19191F1F201B1B1E3B433D383E3A3F4840454F45
49524640433C62685C9AAB9288978392A38B89998290A1898EA1898C9F898DA18B8CA08A
869B858598808093797C8F767A8D737F93787B8E777A8D7570826C6D7D6A6C7C6B738572
7788767A8C787B8E787C8D777B8D767E8F767D8C74778371717D6D6D7A6A6572635B675B
4B564B272D291E231D171A140B0C07070803040502020301020301010301010301040401
161809212512242915252A19
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1E3DEA09F9E5F61566F7761707960
5B614C515643474B3C45473A43433737342C312F272B2A2126251E20201920201924251C
2727202B2D252C2F282325221E1E1D171717141414121513121613171C171C221A232B1F
282F2029311F2126161E20141C1A161A18171816192020253E444467776B647769657868
697A655D6958454742C0D9B47786767788785B675D5F6A5E7C8F79859780899C848CA18A
889D878CA389556357657662829578788B70788A747C917B8096808097807F967D778B74
778875758475768376738276748475758673788673778473788572778573778574778673
7B8E773A413D1315180D0E0D0202020102010102010102010102010103010306010B0D03
101305181C0B242915272B18
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7E9E4C0C7B3
9EA68F8A917C777C6957574C52504546423739362C3333292A2B2226271F28281E2A2C21
2A2C23282A2122231E1E1F1B1A19191A191A141517171A191D221C232A20252C212B3125
2C32262E36282B312025291B24251E20211C1E1D1C1A191D515E54A7C7A2768D73556653
55634E40473B464C42889B81718370758B756071605B6A5872846C7F937A83987F869B84
889C868DA48A4047434C544CA4BD993D403C5C675E98AF967082736C8071738977798C7A
758576728074748178727E7974827A74837774847474827174826F6F7C686F7B676E7B65
6C7A643336320F0C11070306050304030202020203010102010201020401090B031A1C0F
1E2112222717232A17242A17
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFDBE0CFC0C5AD91957B8488725554484647363F422F373D2B3034263031242F2E21
2C2D2028291E22221B1F201A1C1E181A1B18191B181D1F1C2326212D32272E3327303629
30342A3034283035282E32262D31262729201B1C15191A131618113E493655654A383F2F
393F2F2E33282C31272B3028252A2372896A64775C64755C6E7F6775866F778A73798D78
7C907D8096816B7B6C72826E95AB8C3C403F4A514FA0BA9F8BA08A68776A849882778676
444646575D5A7A847D717C786C79736F7E7371817172806F75856E6F80686D7C6564705B
4E58482F342D1312130E0C0D0B080A070406070505030202030402090B0710130D222619
282E1D2930202A32212A3321
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFD5DBC8949E7B51503A5759404F513C494B3A464637403F32
39372D302E2527271E23251C21231A1E21191E201822231B282C2131352837392B393B2E
36382C37382D33342A2F30262C2D242F32292729211E20191B1D171718141719131D1E17
1C1C161B1C1720231D22261F1A1E193B46365C6C50657559869D786B7D6255624E465045
56635B63756B718777728775788E796A7D70697C707A917D94AE9289A085899C84666F63
28232E2E2D3891A692535C5C41454A63716775897457635650594C616F5967776064745D
4C5A48272D27191C1A1110100A080A0806080705050504030302021D23172930212B3221
2C33212B3123282C21272C20
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFE0D9BAB9AE909378949C7B7F84685D5C4B
4440383C3B322E2F252A2E21282C1F272A1F28291D29281E2B2C2435372C3E4132414436
3D4035373A3230332B2C2E28282A25242622262A2222261D1F2319191D141E20181A1B14
1616101B1C141F211822251D1F221D181C17242A212B332843513C44523B44513B303528
2D33262D322A4754465768546477605363514A584C718770738973788E777C917C738273
2E2D3634393E758B797C937E424C476A7A6872846E3F463D16131631342E6E7F674E5A4A
353E363039301C201C181C180D0F0D0709070709050508020608032A35214050353F4C34
323C292C3524282E2026291F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF2E9C8D1B89BA286
453F3B4F4F4542443A3D40333A3F2F3B402F3C3E303C3E30393A2F3C4033494F3E4D5442
3D42383A3E37373C352E322D2A2D2B282B282A2E28292D2525292122271D24271E1F211A
18181221241824281C272A2022241C1E211B1A1D18181B1621271D272B20282A2026291F
24271C22261A25291D293023697F5E4C5A42353B2C2A2E26505B4A535E515C695F758778
798F7E5969615E7162697C696D816A70826C6E7F6D515A542C2D324F564E576055586357
4149411B1F1F1C211D151A130E110C0A0C08070905090C070E120A13190D405035495B40
3C48363540332B3328222920
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CDD0C2999A8D8C937C787D68696F5A6569555F62505A5D4D4E5144474D3F46483C44473A
4043383C3D363839363638353538343638363134322E322D2F332D2D322B2B302922251E
1B1B171C1C1820221A23261B20221B1C1E1816181321231C30352A2E3227292D2320201A
1E1E171C1E151E24181C2115282F1E323B27353D28303623282D1E23251C22242030342F
62725F4651483E48414852485D6C5A667866697C6D6A7C6D6371656A786A555C56464D4A
4F5C4F1B201E181D1A0E120D0B0E07090B040A0A0612130F11120F0E0F0F141716181D19
1F251E374234333D31282F27
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFD1D6C9A6B092888E757D826A656855585B4C5355474B4B4148483D
4242384040383D3C354D51444D5348484E4441453C373A3232362E2D31292C3029272A25
20231C1C1D1621241A24281C23261B1E21171A1B142628212B2E262B2F252A2C23272821
21221C20221A1B1E151B1D1314140B18180E1C1E12232517202215191A10161811151511
39413353614E202422252C28252B2B2F39345262546173606475626372635F7062343E3A
39463B3744351A201911151012160F12130C12100C12100E110E0E0D0A0C0C090B0B090B
0B090C1717171D1E1C262A24
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAEDE4CED4C595A0837377616F735D63635657554E
4E4D474A4A4442423B5A645168785F697A5E6472563335282C2C2327261F22221D232321
2323212223212628232629222227221E221F202321373F36383F352F332A2C2E25272920
28281F2A2D2325271E1B1C1415150B1110061A1B0D2020101A190C1210080E0D080D0C08
1A1C1555644C29302728302A1F25231A201E171B1A2C372A36412E2D3324363E2E404C3A
50604B47543F0D0E091618121B1E17181B151B1C17171614110E110B060D0C070E0B050B
0D060D0D08110E0A121B1C1D
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAECE5B5BBA89FA78E6C6B61
5F5F5858585053544A45463D464B3D525C46454E3D34392D2E34282A2E2523241F212220
2323232A2D2A2B302C2B302D2B302D23272725292A4B574C424E44364037323A3031372C
2F342A2F342A2426201A1A17110F0D121209191A0E1E1F111D1F1216170D11100B0C0B09
0B0A09171813191C18181B18141817131816141A171C231C1C23171A2112191E0F161A0E
25291A292D1E1E201624281C22261D21241B363C2D2B2F24262821201F1D201C1C1C1718
181215130C13100A14130F17
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD5DACE
A2A59A67675F67695E52524A4D4E4648493F3F4238383D332F322D292B27272926222423
272B282D322C31372F2F342C2E322A2D2E2A2D2D2C34373434393533393132393031392E
333C302F372E252B252224221C1C1A191A161C1F171F24181B1F14171C1110130C11150B
0F110813140D171A12191D18151916111511121610171D14171C10151A0E16190E16190E
13150C191B13191D151C2119191D181A1D18252B1F343B28343B25292C193435213B3A29
2F2B212C29222725221E1D1C
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCD1C5838A776A6D60616357505147494A40393934343330302E2E2A2B2B
29292A2A2D2B2F332F30342E2F332C31342B32342B2B2B25292924252822272A232D3127
31382C2C31282B3028292E28232622272C242C3428232B211C221915191211140E0D100B
0C0F0A141812161B141A1F19161B1512161111160F161C1215190F12160C10130B0E120A
0E120A0D100810130B15161013140F1C201822271B282E1D2C301A1D1D0936371F211B12
35322B2925242F332B323A2F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEAEEE7BDBFB97F86796A6D644A47464A48453B3738353132
332F2F312D2D2F2B2D302E2E2D2B2A2C2B272F302A2C2D2627282225262022251F23261F
22251E242620242A23282F26252C24273026384531252E1F1B221713171211120F10120D
10130D1417101A1E161B1F181A2016181E121920141D2416191F12181D1111160E0F130E
0F150F0D120B080B040B0D060B0C060D0D050F0F0715150B1D1E121A180F4C533B110D0B
67715D5D6A551012101E241C
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7EAE49DA0967B816F57584A525243
4B493B443F353F39333F3A332E29282E2A272D28252B2724262320262521282C24252B22
20261C1F261C232A1F21291F222B1E242E1D232F1D242E1D1E2516181F12171C1015190E
15180E191C11181C101B1F141C2116191F141B21181D24191D23181C2318121B110D130D
0F150F0C120C0A0E06090C04090A050808040A08070907050A0A05090B030D1004161A0B
1B200F232915212714191C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC4C8BC989A8D
6A6B5C575549524F424B483D4442373B392F33322A2A282324221E23231F212320222721
21281E1D2419191F15191F1421291B1A21121C22111F27141F25151F24161E23171C2217
1A2017191E15161911191C141B1F151D23171F26191E26191C26181A2518182215151F10
111A0D0F150A0D13070C10050D10070C0D050B0A05080804070904070A03070A010C0F02
111406181B0A1213050D0D03
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFBCBEB66C6D605B5D4E5154444A4B3E3E3F3737373235352F32312C2C2C2A262827
2326251F23211C211D191E181D231A1A20171A2014202619232A1D22281C20271D20271D
22291F1F261B1C23171F2717222B17232C1827301A212B15222C151F29151F27171C2314
1C23131B2210161C0D181C0D14160B13130914160C11120C0D0F090C0F080C11070C1006
0C100712150A1011090C0A05
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFDEDFDCB7BAB46667634F4E4C48494542443C3B3C3332312C2B2929
2523272120231C1D201E21211C211D171A17131512121612141813161B15151B13171C14
191E15191F141B2216182010171E0D1A210F1C24101B230F1B220F191F0D19200E19200F
181E0C171E0B1A210E1A1F0E191B0F16160D15160D10120B0E100B0B0E0C0C0F0C0D110C
0C100B0D0F0C0E0E0C0B0A08
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0E1DE989C917179643E3C343C3936322C30
271F28211B251F1B242020252020251D1E221415190F11150F11130D0F0E0B0D0810140C
10150B0D13090E150B0E1407121A09141B08151E09131A05121902171E051A2008161A07
13160510130312150713140912140A11120D1114100D0F0D0A0C0B0708070B0D0A0E110D
0C0E0D0C0F0D0E100C0C0B09
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB0B0AE736D7449424E
2F2738282030221B29201A241C172017141D17141C14151A1013150F131111151011160F
10150E0D130C0A1009070D06111A0D17210D131D08151D06141D03161F05181F07141805
151706121306131507100F0710100A13130D13140F10120C0C0F0A0B0E080A0E0811150F
0C0E0D0C0E0D0F100F0F0F0C
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
938E9B36313E3631372C2428231A1F1E171B1D191A19171818191A181919161917111413
1418160E10100B0D0D0B0D0C0D110C13190D141B0C151E0D111B09101906131A07161E0A
151B0A161C0E181A0F16160B14140C13130B13130C14150C0F12080E11080E10070F120B
11130E12131112131111120F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCFCDCD9B96963127282A2022241B1E1E17191C16181C18181B1818181417
1410141512151310120D0A0C121311181C17191E15161C11161E11151C0E171E0D151C0B
151B0D151B0E151A0F14190D14160D12140D11130E13160E14170C0F13060B0D030C0C04
0F0F080E0D080D0D080E0E08
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9792935F5858251C1C241D1E201B1C1D18181A1415
181214171417161414100F0E0E0F0B13160D171C101A21131C24141C25131C2311171E0E
161B0F151B0F151B0F14190E11150D0E110A10140E12161011160B1014090F1307101106
0E10040E0E03121408101408
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9591935B555C1F1922221D25
231F261B192115151A1012110C0E0C0E110D12160F171D141A21161E24171C2115171C12
171C13151B141015100F120D10140E11150F14181111160F0E130A0E12090E11090F120A
0F13091114090E0F05080902
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC6C5C89FA2A2
282A301F21291A1D231417191012110E120F1115101519131A1F1A1F231D1C1E18191913
191A131A1D18141714141713141712151A11151911161A1312150F0F110C0F120D0F130F
1216100E110B080B05060702
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC7C8C98F90921E211C22271C1B1F151A1B121718101A1B151D1C181E1C181D1B18
20201D1F201D1C1E1B1B1C18191C17131611181C14171B141418131013110C0F0E111413
1217140E110E080A07020302
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF979A91595B502123151F21151C1B161C18161E1A17201E1B
20201C20221E1D201D1D201C1B1F1B181B17191E17191F171519131418121014100C0F0D
0C0F0C0A0C09060705020301
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF92938F5958571B161A1D191B20201D
23241E22271E1F251E1E241D191F19181D18191E181A1F17191F161318120E100C080A08
080A08060604050302040301
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC5C4C68A888C151317
151413191A15181C1614171415191515171417191415171013160C0E10080807040B0A08
0E0D0A090706080504080503
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C3C3C488878815141319171616151314140F15160D16170D13130B0C0C070B0A050C0B06
0F0E080C0A05090703090704
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF9495935958561E1E1B16161015140E1514131312120E0E0F0E0F0E
0F110D0F110A080703080601
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8E8E8E5555562123231B1B1E15161C0F1016
0B0D0F090B0A070904060602
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3C2C58B8A8E111018080811
04040B030305020302040403
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3C3C6
83848905070B040506030303
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF818384414144
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.392007 0.477324 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
10110910110811110A11110B10100E13131115161217181216170F16170F181810171810
181A10171B1014170D14170E15170E16180F18190F17190E15180E14180D13160D11140D
13170F131810141810131811151812181A13181913191913191A12191B11191B12191C13
191D14191D13191E121A1F13191E12191D11171A11171B131A1E141A1E13181B11181B10
191B111A1C111D1F131C1F131C1D151C1E171B1D161C20191C20191B1F171A1E16191C15
1A1E15181C14171B13181C12191C11181B111A1C121A1D131B1E151B1F181A1F181B1F17
1D20181B1E151A1D14191C14181A141B1E171C1F161C20141A1E131D20161B1E141B1F15
1C20161C1F161E20161D1F131C1D131D1E151D1E161D1E151D1E161B1D161A1D151A1D16
181B15181B15181B14191B131B1C141A1B13191B12181911181A111A1C13161711151611
15161015160E17171017171215151114140F16171216161215141011100B13130B13140D
13140C13150D15190D12170D10150C11140C0F12090E11080E10090E11090E0F070E0E07
0F110B0E13100E12140D10170E0E180F0C150E0C0E0D0E0B0A0C090C0E0C0C100E080B0D
010205000002000101000001000003010005000006000006000004000003000003000002
000001020001030101030000
3940383D453D404941414B4339403D23282B1B1F201C211C171B15161B12171B0F191F10
1C21121C20121D21121D20111D20121C1F111D20121D21121C21121C22131A1F131B2013
1C21141A20131B22151C22171E231820231A1F231A20231A2024182125172024171D2215
1D23171E2518202816232A19232A1923281922251822261924281A222718212617222718
242A19252A1A272C1C262B1D262A2024271F24271E242A20232A1D242C1C252E1C262D1B
282E1C262C1D262A1E272B1D262B1C252B1B262C1B272C1C272D1D262D1F232B1D232A19
252C1A242B1A262C1B262B1B252B1A292F1C282E1B282D19282F1B292F1D252A19262B1A
262A1B25291B272B1C2A2E1F2C30202B2F202C2F212D2F212C30222A2F22272C1E272C1B
272D1B282F1C292F1E2C301E2A2F1D2C30202C2E20292B1F2A2D202A2E2226292024261D
23261A22251923251926261C25261D22241C22241B2123191E21161F2115222516212416
2224152225152125151F22131D21121D20111D21111C20101C1F111C20131B1F121B1E12
1B1F12191F111920111F29190D100D0C0E0C0C0E0B0B0D0B0A0C0911150E13180F070905
060702060803050703040603060704060705060805050805050805050804050704050805
050804060903060803080803
94AA9699B19D9CB6A09DB8A08FA69040494812141A191D1C1316140F120E0E120911150A
151A0C171C0C171C0D181C0C191E0D1A1F0E1B1F0D1B1F0E1A1D0F1A1D111B1E121D2015
1E22171D22161D23181D22181D22191D23191D23191E23191F24181F25161F25161D2215
1E24161E25151D25131F26142126162226162225152124162224172022151E20131F2215
21251720261822271824291C25292023261F22261E24291F23291B262B1A272D19272C17
282C182B2F1D292B1E282B1D2A2C1E292D1D282C1B282D1B282C1C252A1A252A1A262B1B
282F1C2A311C262E1B242B1A252A18272D18282D17282E17282D17272C17242915242816
25291923271825271927291C292A1F2A2D212C2E212E31232C31222A2F20282D1D29301E
29311D2C331F2E34202E33202D31212E33232F34252D31222E31222E32242E30242B2D22
282A20282C21292E212C2F222C2F24272B2026291C25281B23251925271A242819232717
2426162527172427172327162426162325152427172326172024162125171F23171E2215
2023151F23131C21121C21111B1F10181C0E151A0F151911151813151A13161B1115190D
14190C14180D13160C11140B14170E171910161811131611121510121611121611131613
141912151B12141911131710
97B09E9BB5A49FBAA59DB8A19BB59D627367191D22151919161A17121612131810151A0E
171E0E19200D181F0E181E0E1A200F1C21111F22111E20101F21131F1F151E20181E2019
1F211A1F221A1E231B1A20181B21181C23191C23191E25181D25171D25151D24131F2514
222716222916222915222815232817242817232716232617242718232717222516222617
222618222619232719262B1E262A2023271E21261C232B1C252D1A282E172A2E16292C16
2B2D192F301E302F202C2C1F3030222E2F212D2F202E2F1F292C1E25271B25281C25291C
282F1C2A341E232C18242C18252C17272D17272D16272C15282D17292E1A262A18252817
25281925271B25261D27271F272720282A222B2E242D30242B31222A3120272E1D272F1A
2A311A2B321B2D331C2C321C2A301D2B301E2D32212D32222D30222F31233033242D3122
2C30242B2F242A2F222B30222C30212A2E1F282D1C272B1B27291A262919252A19272C1A
272B1A272A1A25271A24261824261824251925251B22231A21221922241A1F24181E2316
1D22151F25161E25151E25161F25171D2215181E12171D13161A14151A13151A11151A0F
181C0F171A0F17170E17180F191911191A13181A13161815141714131613161915151814
151913171C14161B13151810
8FA6949BB5A0A0BDA59FBBA39EBBA0849D88394540181C1D191E1A13191311150E13180F
141A0E171D0F1A21111C22131C20131F231521241722231622231721221B20221B1E2019
1D1F181B1F171C22191B21181C24171C23161C24151D26151E26142027141F2513202715
23291722261523271525291825291925281924271824281924291A252B1A252A18252919
23271822261822271823281B23281E20261E20261D242C1D27301D2A311A2B311A2D301B
2D2F1C2C2D1D2F2F212F2F212E30212F31242F30232F31222D2F21292B1E2A2C20282C1F
252B1A252E19252D18242B16262D16272D17282E182A30192B2F1B292C1C272A1B262B1C
23291B24271C23261C282A20282C21292D222B2F222C32222A30202931202A321F2C331E
2F351E30361F2F34212C2F202C30222B30232C32242E32252D32242E34242F33242E3323
2E33232E33242C32222D33212C321F2D321E2D321E2D31202B2E1F2A2D1F272C1D272C1E
282C1F282C1F252A1E262A1D272A1C24271A23251A2224192224192326192025161F2616
2026152228152127131F24141F23161D22151A2015181E15161D13161C11161D11181E0F
191E0C191C0C191A0D19190F1B1D121B1E13191C141A1D16171B15161A15181D16171B14
161B12171E12161B0F15180D
5D6959798B738DA58894AE929AB79897B5955F745E1A201C1014110F140E0C100A0E110B
11150D151B0F181E11191F131A1F141E231720251922271A222618212519202317202317
2023172023151D21141E22141F24161E23141E24131F261421271623281824291A202618
22291A222919212718242A1B252A1B262B1A272C1B272B1A252A19252918252A18252919
2326172025161F25171F251A20261D20271F232A1F262C20262E1E272F1B2A311C2B311C
2D321E2C301F2D31202C2F1E2D31202E33232F33242F31213031202E2F1E2D2E1E2A2C1B
292D1B272D1A242B17242B16262C17282E19292F1B28301B282F1C272D1C272D1E262B1D
252B1B242A19242816272A1A2A2C1D2A2C1E2B2D1F2C2F1F2A2F1F2B31212C33212D3422
3037243137253034262F32282F33292C31282B30262B31242C32232C32242C32242C3322
2D33212E33212B311E2D331F2F351E30341F3032202F31212D30222B2F23292E21262B1F
272D20242B1D232C1D242C1A252B18252A19242718232517222416222517212315212513
2226132126112024101C20111E21161B1F15191D16181F16171E12161C10141A0E151B0C
141A09151A09151A0A15190B181D10191E12191F121A20141B2114191F14171E13171D10
161C0E161C0C171B0D15180C
22281C2F3628424C3A5463496B815F839F75728B64242A1E10130E12180F0F120D0D100C
12160F151B10161D10191F121B22141D24161F251721261721251621241721241723251A
23271B24281B23261822241622251620241421261422271522261722251822251A21271C
21291B21281A22291A23291B242A1A252B1B272D1A292F1A282D1A252918252819252819
24281A242A1A242A1C22291C232B1E232A1D232A1B242C1B252D1C252F1A262E18293119
2A30192A2F1A2C301D2B311E2C321F2C32212F34263134263132223132212E2E1D2E2F1C
2B2F1B292E1B252C18242C18232C18222918232B1A242C18262E1A272E1C272C1C272C1C
272C1B262B19252817282A182C2E1C2B2D1C2B2C1D2C2D1E2A2E1F2A2F1F2B31202C3220
2E342130352332362731342930352A2E34282D32252B31212C31212C31212C32232E3624
2F36232F35222C321F2D332031352132341F3233202F301F2B2E1D2B2F1E282C1B272C1B
272D1B252B1A242B1A232B18232B16262C16272C19252918232617232717232616222615
2124151F23121D21111B21111D22141B2015191E14171E13171C10171C0F13170B15190C
15190B13170913160815180A171C0E181C0F171D0F191F111A2013191F13171D11161C0F
14190B141707141608121408
14190F191E131B20151B2115282F1E3C472E414F34262C1C2126191C2116171C1213190E
151B0F161D10171E11191F131C23151E241621261822261922271922251822241A24261B
25271C25281B24281A24261824251620241221251221251422251624271923271B24281F
242A1F22281D232A1E252C20252C1F242A1C242B1A272D1A292E1A272B19272A19292D1D
292D20292C20292D1F282E1F292E1E282D1B272D18262D16262E18252D18262D172B311A
2C311B2C2E1B2E301D2E311D2D311E2D33223035253033243132242E30212D2F1E2D301E
2A2E1C292E1A28301A272F1C262E1B2129181E2616212818232A1A262B1B272C1C272B1D
272B1D262A1B242719272B192A2E1B2B2F1B2A2E1C2B2F1D2B2E1E2B301D2C311D2C311E
2C321F2F34223238263237283036293036282D34242B311F2C321F2E34212F37242E3623
2D35222F36232F35232E312230322032342132332130311E2F301C2D2F1A2A2D192A2E1B
2A2F1B2A2F1C292E1C282D1C282D1A282E19292E1B292E1D292F1D242C1B222818232817
2125151F21131F22131F23141E22131E21131D20141A1F121A1F10181E0D181C0B181A0C
18190D17180C16170B16180A191B0D1A1D0E171C0E181D10191F12181D12161A1014170E
14160C1216091113070E1004
0E120A10140D12150E14160F171A131B21171E25191D23171B20141A1F12181E0F171F0E
161C0C161D0D181F11161C10181F111B22131F2515222717222617212517212517242719
25281A25281A25291B242719252919262B1A24291822271722271823281A23281B24281E
262A1F262A20262B1F272B1F25291E23281C262B1C282D1C2A2F1D292E1C282D1C282B1E
292C21292D21282C20292E1F2A2E1F2A2E1E282D1A252A16252B18292E1B292F1B2C321C
2E331E2F331F2F321F2E2F1E2E2F1F3133233236263134253335263133242E31202E3221
2D33212C311F2B321D2A321D29311C272F1B242D1A252D1A272D1B262B1B262A1A282D1C
292E1E272C1E242A1B252D1B28301B282F1A282F1C2A311F2C311F2C311F2C301E2D311F
2E331F2E341F2E33203236253338293238292F35252C32212C331F2C341E2C34202F3623
3038263137263034243032223132213132212F2F202E2F1E32331F30301E2C2F1D2B2E1E
2A2E1D2C301E2A2E1C292D1C2A2E1D292E1B282D1B2A2F1E2A2F20262E1F242B1B222919
2328172225162124152123162124162022151E20141D21131D20131D1F101D200F1B1E0D
181A0C18190C18190D18190C191B0B191C0B191C0B1A1D0F171A0E15190D16190E171A0F
14170C1115080F12050F1105
0B0F070E11090E100712130A15170F171C151A1F16191F15191F151B20151A20131A2113
1A2012181F10161C0F161C0F1A210F1C23101D23111F25131F2413212414232616222416
23251724261725281A24281C252B1D242B1E242B1D232B1C22291C21271C23291D25291E
262A1D272B1E25281B262A1B262A1B26291A2A2C1C282C1D2A2F1F2A2F1D2B311F2B301F
2A2F1F2A2F1F29301F282F1E282D1E292E1E292E1E272E1D282F1D2A301C292F1D2A301E
2C311F2E321F2B2E1D2B2E1E2E31213033243237273237273337283136283035272F3325
2D33232C32212C331E2A341C2B331B29321A29321B2B341D2B321D2B301C292D1C2A2E1C
2A2E1D292E1E282F1D28321C27321926301726301829321C2B321F2D33212F3321303522
2F34212D321F2D321E3034203236233539263339263036232E35212D341F2F361E2F361E
3138223137233036233035223236233032212E2E202D2D1F2D2E1E2D2E1E2C2D1E2A2E1E
2B2F1F2B2F1F2B30202C31212B2F21292D1F2A2E202B2F22292E22282F2028301F22291A
1F27161F26141F25132025142227162125162123162022151D1F131D1F131F21121E2111
1D1D0E1D1E101C1D121B1D12191B0E1A1C0D1B1D0D1A1C0E181B0E161B0E161B0E171B0E
13170B101409101409111409
060902070B020B0E04111409181B11181C141619131619121A1E171C1F181B1F141C2014
1B2013191F12181E10181F1019210F1C24111D25111F28131F27141F2615242919242819
25281926281A272B1C272B1E272C20242A20242B21262D22262D22252C21252C20252C1E
272C1C272C1B252919262918272B1A272A192A2C1B2B2E1D2B301F2B2F1D2C311E2E3420
2D32202A301F272E1F282F202A2F202A301F2A2F21292F2029301E29301E272F1D29301E
2A301D292F1E2C311F2B301F2B30202D322230362531372632382831382830362931372B
2F35272B32242A322029321E29321B2933192B34192D351C2E351E2E34202F34212D301F
2C2E1F2B2F1F2B301E2A311D29311A29331A28311A2A311C2C321F2F3322303523313624
31372430362130351E30351E2F341E3137213036203035213035233035213036202E341F
2F361F2E34202F35223137233036223034222E31212E2F202B2C1D2B2C1D2A2C1D292C1D
292D1D292D1E2B2F202C31202B2F1E2A2D1E292C20292D212A2F22292E1F282E1D212818
2029151F28131E26111E26112127142329172327161F23141C20131B20131E22141D2013
1C1E121C1E131B1E141A1C131B1D121D1F111C1F0F191A0D191B0D191B0D191B0C191C0C
181B0C15190B13180B11160B
070A02090C030D110512170B181D10191D1115170E12120C13161011140E12150D14190F
171D111920121B22121B22101B230F1C240F1D260F1D26111E26141E2416212617242918
242718252A1A292F1D292F1E282E20262C20242B21252C22262D23272E23262D21252C1E
262D1E272D1D282D1C292E1B292E1A272B19272B192A2F1C2C311D2D311D2C311C2D321D
2C301D2C2F1E2A2E1F292E202B30222B30232A2E222A2F222B30212C33222B34212A3221
27301D262E1C29311D2A311D2B311D2C331E2F36213138243038262E3724313927333A29
3139292E38262C37242C36222C361E2A341A2C361A2C351B2D341D2E341E2E341F2E3220
2D30202D31212D32222C32212C33202B331E29311C2A311C2D331E2F34202F35222F3522
30362031371E30341B32351D31351F3136203137213136213137243036222F33212E3320
2F34202F34213136243238253137243036232E34222C3020292C1E292B1F2A2B202B2D20
2A2E1F2A2F1F2A2F1F2B301F2A2E1F2A2E1F2B2F21282C1F272C1D272E1D272D1C242C1A
242D18232C161F28131E26122228152429172327162227172127171D23141C22131B1F12
191D11181B10171B11171A11181B121D21141D1F14191A1017170C1A1A0C1B1C0B1A1B0A
191C0A16190A131708111407
060903090B040A0D040B0F050D12061115071417081215090D1109080B05090C060F1409
12180C13180C161C0E1A21111C23121C24121D25131E26161F261820281922281A23291A
222918252D1928311B28301B28301C282F1E242C1E252D1F252D20262C20282E21282F21
2930212A301F2B321F2B311F2A2F1D2A2F1E2A2F1E2A2F1D2C311D2D321D2F341D2F341D
2E321C2F311C2C301D282B1C282C1D2B2F202B30212B30242B30242B31242D33242C3323
2A322028301D28311C29311B2B331B2C341C2F361F3037222F37222D3722303923323B24
313B26303B26303A25313C26303A222E381F313A203139203137202F351E30361E313520
3134223134243033242F33232F35232E35202C331D2C331B2C321B2D311B30351F303620
30361D31351C31351A33361D3539223338223037212F36212F37213037213036212E3520
3037213137223238253137242F35222F36232F34222D32212A2F21292B212A2C222A2C22
2A2E222B2F222A2F21292E1F2A2F202B2F222B3023292E20262C1C272E1C252B18252B15
252C15262D17252C162126122126142225152125162126182027191F27191F26181D2315
1B20131A1D111C1F121B1F121C20131F22161E20151B1D111A1B0F1A1B0D1A1C0C191A09
191B0A191B0A17190B131508
040503050703040701060900080B010B10021217061218081014050A0D020A0D040D1006
0C10060B0D050D110713180C191E111C21131F261521291921281A222A1B212A1A222A19
202817222B17232C17242D17262F1927311C262F1D252C1C282F1F2A2F202B30212D3222
2D31212E32212E31212D31202D32202E33222E33212C31202C33202E35212F3521303521
2F34202E34202D31202C2E1D2B2C1D2B2E1F2A2D1F2B2F212D31222D32242D32252D3424
2C35232C35222B34212A331F28311B2A331C2A341E2C351F2C36202F3922313B24303B22
323B23343C25353D25333B24333A23323921323922323922323722313722323922313621
3135203335213233222F32222E33222F35222C331E2B311D2C311B2C311B30361D2F361E
30361F30361E32371E343920373D24373B263237242F35202E351F2F351F313721313821
3038213239223037212E351F2C331D2B321E2C321F2E35212D33212B2E202A2D212C2F23
2C2F232D30222D30212A2E202A2D202B2E202B30212B301F2A2F1E292F1C272C16272C14
252B13272B16282D1A2427172125172226182125172026181F26182028191F26181D2315
1D21131F22152124151E20121C20101F23121E21121C20111C20121A1C0F181A0D1A1C0F
1A1C101A1C0F17180E13150B
030606040705040701040700030600070A000B0E010B0E010C0F010E1102101104101106
1012080E0E060C0D060A0C050E100814190C191D0C1E2411212715222A17242C18232B17
212A17212A18222B17252E18262F1A262F1C272F1C27301C29311C2B301C2D311F2D311F
2D31202E31213033233135243135243135243035232D33222C33222D35222C35212D3521
2E35223036223135232F311F2C2D1A2B2D1B2C2D1D2B2E1F2C311F2E33222F34242E3625
2C35242A34222B34212C35222B34202A341F2C361F2B351E2B351E2D36202F3821313A21
333B21353D23353C24333A22313821333923323822343924363B27353B28353B27323724
3236213336213335223134212F33222E33212B311F2B311D2B331C2B321B2D351D2E361E
313820303721323920333A21333B23343B24353C263239232E341F2F341F313721333A24
333B243239223037212F37202E361D2C331C2E351E2F361F2D331D2B311E2D31212D3122
2E32242E32222F31222C30222C2E232D30232B30212B2F1F292E1C272C18242B14232B12
232912242914282C1B282C1C25291C24281C2326192025191D23181E24181D23181C2216
1B21131C22141D23141C21121A1F0E1B200E1C200F1C21101C20101A1C0F16190D181C10
171B11171B1215180F11150C
0308050309030509010509000307000205000306000406000606000B0A01131207181A0C
17180C1212080D0F06090C03070A02090D030D1203141A071C220E212914252E19252F1A
26301D272F2027311F27311E26301D242D18232D162630182831182A31192D341D2E321E
2E31202F32233033263035293035283137293036282E35262D35242E36232E3823323925
3339233238233136233033202E2F1D2F301D30311F3132222F3323303524303524303725
2F37252C36232C36232D37232E38222F381F30391F2F371E2D341C2D341E2E341F2E3520
313722333B23323922323922313821333921323820343922373C26363B27373C27353B26
3439223639233537243235223135232E34232B32202A311D2A311B2B331D2A341D2E391F
30391F2F371E30381E31381F303820343A23363C26333A253036232F34222D3220303624
343C28333B27333B27333C25313A2330382131391F32391F2E351C2D331D2E341F2F3421
2F34242F34262F34262E32252D31262B2F252B2E242A2E21292E1D282F19262E17242B14
252A14262B17292D1B282C1C292D1E272B1D25291C24271C20231A1D20171D20171E2216
1E24161E24161D24171D24171D23171B21131A20101B20111D21121C20101B1F0F191D0E
171C10171B1015190D101409
040904040903060A01070B01070A000508000205000306000708000806000F0E02151406
1516081213060D0E020B0B000B0B010809000607000C0E021416091D211324281B292F21
2A33272A34292B362828332327331F25301A242F162530142833152B34172C321930331D
31342133342532342830342C2E332C2E352C2D352B2C35292E3727313A26313A25323823
353A2134382035382135372035362036382435372634352831332833372B313628303725
2F39242C36232B34212C35202F3821333B2132391F32381F343921343822333622323623
313624333826333824343B26353D27353C25353D23343C22353E25373E263A4128393F26
373A243638243637253335243134252E34252A332329322029331F29331F29341D2C381E
2F3C1D2F3B1A2F391930381A31391D343B21353C24353C2732392634392A32372A2F3428
2F3628313829343C28343D27323D26313C2330392030371E30371E30371F303621313522
3034243035272F34293035292E33292C30262C3126292E21282D1E28301D28301B283019
292E18292E192B2F1B2C2E1B2C2C1B2B2B1C2B2D1E292B1E2424192121171F20161F2218
1F23191E241A1F251B21271D21271E1F251A1D25171D23151E23131C210F1C210E1B200E
1A200E191E0C181B09131606
070B03080C040B0D040C0F030C0D030A0B01080A00090B00090A000909000A0B000A0A00
0C0C010C0C000E0D010E0D010C0B010C09020905020805020A070515151221221E272A26
29312B29332C29362B29372728372127341C2734182935162A35152D35162D32182F311C
32352333362733352930332A2F342D2D352E2D372D2D372A303A29323C27353C26363C24
373C23383A213B3C243A3B263B3B283A3A2A38392E36372E34362F33382E333A2D323B29
313C272F3B242E3821303920333C21373D22383C223B3E263C3E29393A2938392A37392C
35382C363B2D363D2C353D29373F29374128363F25343D22353D22383E23393E243B3F27
3A3D2A393B2B37392B3335293135282F36282B34252B35242B35232A352029341C2A3519
2C38172E3A17303A15323B17363D1F363C22363C25373F2A373F2D363E2E343D2E323B2D
2F37282D36242F3721313A20333D21333C1F313A1E31381E343920353823343724343626
33342832362B30352C2F352D2E342B2B31272A312529312229312129322028311D29321C
2B321B2B2F1B2D2E1B2E2F1D2E2D1D2F2D202E2C212C2B2128281F25261F21241C1F221C
1F251D1F251C1F261C20281D21291E1F271A1E26161E25141E26121C240E1C240C1D250E
1E250D1E240C1D210C191A09
0A0C050C0D050F10060E10060A0B03070801050700090A010B0C010A0C01090B00070800
0809000C0C000E0E040D0C040D0B030B09030905030904070803080C090E1515181D2121
242B2727322A28342827362428372027351C29351A2B36192E38182F361A2E351D303520
32362433372932362A30362B32372D313A2F303A2D2F3A2A313C27303B25333C243A4027
3A40273B3E263C3D263D3D2A3D3D2D38392D383A2F373B30363B32363C31343C2E333C2B
343D2A343E28333C25353C23373D233A3E243C3D273E3D2A3D3C2D3A392F393931383A32
353A31353B30363E2F353F2C37422A3943283A4227373E24373C24383C253A3C273B3D2B
3C3E2F3C3F32383D31333A2E323A2B313B292F39272E38242C36202C361D2B3519293315
2A32132B33142E3714313A1733391C33371F343B25353C28343E2B333E2D333E2D323E2B
313B262F39202E371A2E3717323B1931391933391C36391F373923373725353427323127
2F30272D31292E352D2A322C2A32292932262A33232A32212A31202D35222D34212C321E
2E321D2E2F1D30301F313021312F23312E252D2A232B2A24282B262529252127211D231D
1D241C1C241A1F271C1F281A20291A2029181F28141E27121F28111E270E1C230A1D2409
1E220A1F230C1E210D1C1C0C
0E120A0D100A0C0F080A0D05070904050703040601070A020B0E030A0D02080B00080A00
080A000A0C010D0E030D0C030A08020604010402000805040D0A0A0C0A0D0D0C11131519
1B1F21222927252F282532262633232935212B37202C371F2F371D2F361C2F361E2F3521
32352437392B35372D33372E353930343930323A2D303B2B303B27313D25333E25363F25
373F25383F25393E25383B253B3D293A3C2C3A3C2E393C2E373C30363C30343A2E353C2E
353D2E353E2D353E2A353C26353B23383B233A3B253B3B273B392A3B392D393930373933
333732353B32353D3135402E37432B3943293A4327384025383E26383D283A3E2A3D402D
3E3F2F3E40313B4132373E31353E2F343D2C333D29313B252D37202D361C2C3319293016
282F162A31162A30152C33152D34192F351D313721323825323927323929343C2A333B27
313A242F38202E371E30371B30371A30361932381C35391E363821363824363728323227
2D2F252B3026282E26282F272930262B33262C34252D34222C311F2D32202E33212E3220
2E321E2F2F1C2F2F1E2F2F1F2F2C1F302E222E2D242C2C252B2D27272B2523282120251D
1F261C1D251A1E25191F27181E26171E26151F27162026152026131E24101B200C1C220B
1E220D1E210E1E210E1C1E0D
0D120D0C100C0A0C09080A060A0C08070A07050703050801070901070901060801070901
080A01090B0108090008080007060005040004020008060315150E1818151A1A1B1D1D21
1F202622262A242C2C262F2D26322B2732292933252A34222C35202D351F2D341E2F3620
323723353827383A2B37382D35372D34382E33382D343B2E313B2B303B28323D28343F26
363F25363F24373F24363D23393E253A3E283A3E2B3B3F2E383E2F373D2F373D30363C31
353D30343E3135402F333E29333C24353C22373C23383B22393B243A3B273A3B2A393B2E
373A2F35392F353B2E37402F37422E39452D3D482C3D47293C46293C432A3D412B3D412B
3D402C3E402E3E42303B40313B4232384130353F2E333C2B2F37252C331F2B311C282E19
292F1A2A311A2A301A2B321A2B311A2C311C2E331F313621343925353926353A27323825
313724313824323A24323D23323B2030391C31391C32381D34391E353920383A24363826
3334253033272D30272B2E252B2F252C31252E34262F35252C33232D33242C33232D3321
2D321F2D311E2E311D30311E302E1E2E2B1E302D202E2D212C2B1F2B2C1F2B2C1F272A1F
23261C20241B1F23191F24191D24191C24181F26191F25182025172024161E22121D2211
1F23111E22101D20101B1D10
0A0E080A0D09080B07080A05090B06070904050803070A05070904070803090A04070902
060900070900050800040600030500030400020200030300080904171A132E3429353B31
3135312C302E2A302F2B32312F38332C3630283129252E23252E1F252D1C262C1B282E1A
2A301B2C321D2F342131352733362A35382B33382C353B2E323A2B303929303A27343D27
333A25343C25343C24333B22343C23353C25363D28383F29363E29353C29363D2B363C2C
373D2E373F30363F30353E2D363E2B363E28363E27343B23353B22363B22373C23383D26
393D28393D29363C29353D2938422C3B452B3C452A3A432A3B432B3A422C39402B373D29
383E293A3F2A3B402B3B412D3B42303A412F3A4230363E2B3037242C33202B311E29301E
292F1C2A311D2A301B2B311C292F1B272D192A2F1A2C311C2E311E2F331E2E341F303620
333922343B25343C26363F28364028333E23323C2130371D2E341C30361C353A20363A22
3537223335243033252D2F232D2F232B2F222B30242D32252B3224293124283023293120
2A311F2B301E2D321D2F321D2F2E1B2D2B1B2B291A2C2A1A2E2D1A2B28162B291729291A
26281B24261C22241C21231C20241D1E221C1E231C1D231B1D23181B21161C21161D2215
1E23152023151F21151B1D13
060A01070A02080B030A0B040908020808020B0D050E110A10120B0F0F0A0F110A0D1007
0B0E03090B01060900040600040600030500020300020400010300070A06273021323C2B
333A2D373F33343B3131372E353D31353F33242A241D231C1A20161A1F131B21101E2311
2126122226132529142B301D2E3423323828353B2A39412D39412D353F2A363F28384028
373F27393F28393E29393F29383E29383E2A373E29383F2938402A383F2A383F2A373F29
383F2A3A402D393F2F383E2F393F303A402E3A412C363C26363C24363D23384124384123
384024383F25384027373F273841263942263B42283B422B3D432E3C42313A4030373C2C
363C2A363C2A373F2A39412B393F2A3A412B3B432D383F2A343A263037212C321F2A301F
2A301D2B321D2C321E2C321D2A301C282D1B2A2F1C2A2F1C2B301C2B311C2B321C2E351D
333A20343B22353B24363E27373E29363F29353F28333B2430371F30371F31392030371F
2F35203238223136232E33212E32212C311F2A2F1D2B2F1E2C32212E35252D33252C3224
2D32242B2F212C32202E34202E321F2C2F1D2B2B1B2929192A2C19282915262713242614
25271724261822241921231A21241D21251E22271E1F251C1D231A1B21181D22191B2117
1C21171E21181F21191D1E17
050A02060A01080B010A0B020A0A01090A020D100811150C151910151810151911161A10
13180B0C1006080B030508010507000507010405000204000305010306010B100614190C
1F24153B452F373F2B303625373F2D3741301D231A171C1510140F0E120A0F1308141709
191C0B1C1D0E202111292D1B2F3522343A28373F2C39422D38412C38412A3A432A3B4429
3C44283F442A41452C40452D3E432D3B412B3A402C3B412C3C422D3E432F3E442F3B432C
39412B39412D3B412F3D422F3C41303D422F3C422C3B4029393F283A41273C45293C4529
3A44283942283A43293B43283B44283B45283F472B41482E4248324147343F45343C4332
3A3F2F363C2A373E2A383F2A373F273A412939412B3A412E3A412E363D2A2F37252E3423
2C33222B331F2C331E3036203036202D331F2C311E2C311C2C321B2C321C2B311B2B321C
2C331E2D341E2F3720313923323A25343D27354028374028333C24323A22313823313723
3037233038233138233139242E36232D35212E35202D331E2D331F2F36253138262D3423
2C32212A30212C31212C32202C311E2C331E2D331F2B2F1E2A2F1C282D18272C17272B17
272B19262B1B25291A23271A22271D23281D22291D1F261A1E25191E25171D24161D2416
1F26182025192024191E2017
050805070A06080C040709020608010608010709040A0D080F130C12170F151A13171D14
151B110F140A0A0E04060900040801040601030501010501010401040902080D030A0E02
0A0E02161B0C1E2213202415333A273D48332C362721281D15181311130F100F0B10100A
12130C15160E1E2015272B1C303623343A28383F2C3A432F39422D38402B39412B3A422B
3C442A3F452C41472F3F46303C422C3C412D3C422F3D43303F45314047323E45303E4631
3D45313C45323D46313F45303F432F4044303D412E3C412E3B412E3C432F3B442D3C472E
3D472F3D462E3D462B3C46293E472A3E472A3F482D414830424734424836424937424938
3F45343C432F3A402D373E2A353D29373F2A39402B3B432F3E46323B4331363D2D31392A
2F372A2F37273039252F38253038222E371F2E351D2D331B2E351B2C321A2B31192C311B
2C311C2B301D2B301D2C34202F3823313C26313E27333F28333E28333D26333E25313B25
2F38222E36202F37213139223139232F36222E35222D33202C31202E33212F35222C3321
2C31212E33242C31222B2F1F2A2F1E29301E2B311F2B331E2B321C2A2F19292E18282D17
272C17262B18262A1B24281C23281D22281D21291D20291B20281A1F26171E26151E2516
1F2617202717212818202417
0B0E0E090C0B0A0D09070A040406010304000204000608030A0C070D110B10140E12170F
1317100E130A0A0E04070B00040700040501030401020401030503070905080B04060901
050701060701080B030B0E05151A0F232C1C212A1B1E25181D21141D20141A1C12171912
1718131617101B1D1522271D2B3025303629353D2D39413038402E373F2B373F2A39402B
39412B3A412D3C442E3E47303E47303D442E3E45304048333F4731404933404933414933
424B344048333F48323E462F3F452E4147303E432F3D43303E44323C43323D44303E4730
404A323F49313D482D3E492C3E4A2B3E482C3D462E3F472F414934414836454939444938
444A374148344048363D4535384030373E2D373F2C39402C3C432E3E452F3B422D393F2D
383F2E373E2D363D2B323A28303825303A242F38212F371E2F361D2D331C2D341C2E341D
2F331E2E321F2C311E2C321D2C34202F39242F3B252F3B26323F28313E28313D25323B24
2E39222E37202C351F2E36212E38233038243037242D33202C301E2E321F2F311F2F3120
2F32212D30202E32232D31232B30222A30242930222931212C32202C321E2B311C292F19
292F18282D17272C1B25291B252A1D24291C22271B22281B23291D23271A2025171E2416
1D24151D24141E25161D2316
13171C0F14180C1113080B0C0608070407040305020608030E12081014080D12060D1105
0F12090D10080B0E060A0E04080B02070902060702050501060604080905070802030400
030300050502060702080A04090B040D11080F140B10140B12150B12160A14180B1D2214
23281A22281921271A232A1E272F242C3428303A2A343D2C353E2B353F2A37402A363F29
363D2A373F2B3A432E3C462F3C48303D4830404A32414A32404930414A32434B34454C35
444C35414833404833414931414A32424A324147304046303E45313D45313E46303F4931
404A31424D34414C333E49303F4B313F4B31414A32414A333F4A33414B33424933444A34
4349324348314147324146343F44333D43313A422D39402A3D42293D42293E432A3F442E
4247323F44313B3F2F363C2C323A29343D29343D27333A233038202F361F30371F30361F
3035202E33202E34202C321F2D33222C33232C35232D36232C37232D38232E3921313C23
333E23333C23323A223038222F37223038243238252F34222B301E2D311F2D311F2E3120
2D30202B2E1E2B2D1F2D30202C30212C31242B2E232C30242A3122282F1E29301D282E1B
282D1A292E1C292E1D272B1C25291B24271B23261B21251A2125192125191E23171D2216
1E24161C23151C22151A2114
192026192026181D251418201013190C1013090C0E0C0F0E1014100D0F090A0C040C0F05
0E11070F12081012090E0F060C0D040B0A030A09030A09050A08060A0909050505030302
0201010202010708050B0E080E11090C0F07090C050A0D060B0F06080B03090D040F1409
1A2112232C1A2A34202E3724303B28323D2C313B2B303927313A27323C28313A26323925
333B27343D2936402B37422B37442B39462D3D49303F4830424B33444D36444C37454C39
444B37454C37444E37454E36454F36464D35444C35444B364149343F48323D4730404B30
414B31424D34414C343D4A323D4B323D4A303E492F3F4B303E4C2F3E4A2D3F492D414830
40462E4348304348324346324246324247333F462F3E462D3E45293B40243D422641462B
43482F4347314044313E44313C42303B422E384029353D25343B24333923303521313622
2F33202F34202E341F2C321E2B30202C32222F35252E36242D37242E38252E39232F3B21
323E22353F22363E23343B223037212E34212F35243036252E33212C311F2C311D2C311D
2C311E2D311F2C2D1E2C2E1F2D30212D2F232C2F232D33232B3222282F2029301E2A2F1C
292D1C2A2D1D282B1C26291C24281A24271923271C1F241A1E24191E241A1E241B1C2219
1C2318191F131A20131A2013
232A2F232A2E21282B1F25281D2326181E2015191B1418181113130B0C0C0A0A090C0F09
0E13090F13090F12090D0F06090C040A0C040B0B040C0D060F0E0B0F0E0F0C0D0D070809
0404050304040B0E0B10141010140E0C100A0B0E07090C060B0E07070A04060902080B03
0A0D0413180C2229182E3622343D2739422D38402E363E2D353D2B333B2A333A2A2F3627
2D34272B32272B35272E3928313D2A36422C3A462F3D4730414A33434A36434A38434B3A
444C3A454F3A455038465138455037454E36444E36454F37444D35434B33414931404A30
414A30434C34424B35404A35414B333E4A2F3D4B2D3F4D2E404D2F404D2F3F4A2E414A30
4147304347334347344144334045334046333E452F40482E3F482C3E452841462942472A
42462B41452D4145303F43324145334147323D452D3A422A384027373D263439242F3521
2C311F2D32202F34202D311D2C311E2C311F2E35232F37252E37262E39272E39272E3924
2E3A22313C22343E23353D233239232F35222D33212F35242F34232E34222E34212D3320
2C311F2B301F2A2D202A2C1F2A2D202C2E222C31212B31202B3120292E1D292F1C2B311B
2B301B292C1A272A1B262A1D23261A21241820251A1F251A1F261C1F261C1E251A1C2317
1B22141A21121B20111A1E0E
23292E262C30242B2C222928232927242A27212726202626191D1F1316180F11120E110F
10140E11160B1014080D11050A0E02090C030C0E050E11060E11090E100C0D0F0D0D0F0E
0909090709070E120D14171211160F0C100B080B04050701060801070902070902070A02
0608010B0F0613170C1C1F13212417272A1E343B2B3C44333D47343B4433374031323B2E
2B3329252C2321281E1D231B232B1F2D3927343F2B3A452E404A32434D35434C36414936
414A37404936414A36434C37454F38454F3947523C48533A465036444C33444C33444C32
434A30454D34444D35444D37444E37424C35414C32414C30424C2F424D2F41492F434830
434733434736444838434738434838424836414934424C32434D32434C30444C2E444B2C
45492D41452C3D422D3D42323D44343D45313C452E3C452D3C442B384028363D26323823
3035232E32212D31202E32202F33212F33222F35243139272E38262C37252F3A272F3A27
2F39242D3822303B22343D24333B243338243338262F35252E3424303625313726303624
2D33212B30202A2F22282D21282D212A30232C32222C32202B301F292E1C2A311B2B331B
2B321A292D18292A1A27291D24261B24261C23261C1F231A20261C21261C1E25191D2417
1E23141D22111D21101B1E0D
282D30292E32262B2E242929232827262B29262B2A242A2C242A2C2026281C2122171C1B
161B1512170D0D11060B0E020B0F030B0E040C10050F12070F11080C0D08090B070A0B0A
0B0C0A0D0F0A11140D14180F12170C10140A0B1004070A00060900070901080903080B04
080B050809060B0D0A10131014161315181521251E343D2F3C4634404B37414C39384231
2C3426262D201E241A171B151519131D231A262D21303A2A38442F3F4A33404B333F4832
3F48333F4733404833414835434A38454C3A454E3A444F38444F36424E34434E34434E32
444D30444D30464E33464D34444C34414A34414B34424C33414B31404A31414B32444B34
454B36444937444836454938464B3A464B3A454C38434B36424B35434C34444E32434C2F
42492E41452C3C412A3B3F2C393F2E3A41303A41303C44313B432F38402D39412E38402C
353B293136242E33212F35212F36202F35212E34223037242F37252E3824303B252F3C23
303C232D381F2D371F2F3921323B23333A253238253035242D33212D33212F3622313724
3137243035232D34212D32212A30202A30212B31212C33202A2F1C292E1B2A301D2B311E
2A2E1C2A2D1C2B2E1E292C1F26281E24271E21241B20231A2024191F22181F22171C2113
1E22141F23131F22131D2011
272C2A2A2E2C2A2D2D292B2B282A28272A27282C29282C2E262A30272B31272C2F262B2B
212723181C1710140E0E100A0F100A0F0F0B0D0C0A0E0D0C0E0D0C070607030304040505
040504090C0612170C181D0F171D0E11160A0C1003090C01090C02080A020A0C050D0F08
0B0D080A0B070909080C0B0B1110111413121616131C1D18272A2133382B3D4434363D2F
272D2120261916190F171A11171A13181E151F251B2730232E392635412B38452C3A462D
3E482F3F4932404933404835404736414937414B37404D36414F36435036444F35444F31
445030444F2F454F30444D31444D32414A32404A323F4A323F4B323F4B31404A32424B34
444C36454B36454A37454A39464A3A474B3B474C3B424935424A34424B32424C30414B2E
41492D42492E3F442D3C402C393D2D383D2F3A40313B42313A423239423039412E37402B
374129343C25323921333A212F361F2D341F2D34212D36242F37242E38242F3B232E3A1F
2F3B1F2F3B1F2E391F2F3A20313B21333C243138233137242E34222E35212E351F313721
353A24353B243238242F35212B311F282F1D282E1C292F1C2A301A2A2F1B292E1C292C1E
2B2E1F2A2D1F2A2E20272A1F25271D23251C22251C21231A2022171F22161F22151E2113
1D21121F23131F23151C2114
202723252C242A2F262D30282E2F292C2D292D2F2C2C2E2E2A2B302C2E352F3238313639
2B31301C2120181A19151415131013110F130D0B110B091007060E05040B030307040505
0305030507011218081A200F171C0C1215080C0F05090B020A0C040A0D070F110B12140C
10110C0E0F0B0C0C0A0D0C0C1311111715141614131413121818141B1B1722241D24271F
1D221916191210110A12140C1B1F1421281B242B1E232B1D242D1D26311E2A3621303B26
37432B3D4830404C34414B36414B36424D37424E36435136435235475437475237465135
465135465133465034444E33424D31434D33434F35434F35424E34414D34414B33414B33
434D36444D37474D38484E38494E394A4E3A4A503B4B523C494F3A474E37444C33434C32
434B33444C34424A334248324146333F44313E45323F49333F49333D46313C453039442D
39472D38452B374227364024323C203039203039212F3722313A25323B26323C26323C23
313C23313C24313A23343C25353E26363E28353C27353C2831382530362330372030371F
353A22363C23353C24333B232F37202C341E2A321C29321C2A311C2B311D2A2F1C292E1C
2C311F2B30202C3221292E1F25291B25291C262A1F25281D24281C23271C21261A212619
2027182027171F2617202517
171E1E1A211C1E241B22251C262821292B252D312B2E312E2E31312E32342E3437323A3B
313938272D2D2025251F212419192114141E11111C0F101B0A0A1506051003030B010205
0103030305010D1106161C0E181D0F16170D11120A0E0E080D0D090E0F0C131412171915
171A171216140E10100E1011121313151516131113110F1112121111110F131410171912
15190F11130A0F10070B0B0216190C252B1A262C1E1D2319191F16161C13181E131C2416
242D1C2C362234402A39442D3C482F3E4A2F414F31435233445033465136475138464F37
485238475237455135455136445035424E34434E35444E36434D35434D34434C34424B35
424B36444B37464C38474B38484C39494D384B4E3950543F5155404D513C4A4F3A484E39
464C38444B37444B37434B34434B334148304048304149314149324147324047313D462F
3C47303B462F38442B364227344022313D2030391F30391F303A21323C23343F25343D26
333C26313C26323B25343B27353A26363D29373F2A363E2A343E2A333D27333C232E351E
2C321C30361D30371E30381F30381E2D351C2B3219293018282D17272C19282C1B292D1D
2B301F2A2F20292F202A2F20272D1D232A1A24291B23281A21261822261921261A20281B
1F281A21291B202719202517
1B20221A1E1E171C18171B141A1D1720221C282B232C2F282F332E3036332E35342D3436
3038382E3735282F2E272D2E252A2F24292F24263122242F1C1E281415200E0E18080911
04060B0305060B0F0A14180E161A1012150D12130C12110D12110E1413111A1B171D211C
2025221F25231C221F1A1F1E1A1F1E15181A0F11140D0D110D0D0E0C0E0C0D0F0B10130D
10140C0E11080C0F050A0C021A201029321E29331F1F2719191F1414180F12160C12160C
15190F181D101E2415242C1A2C36203440253C482B414D30455033465135475037475238
485336475235455334465437475539465238455138454F38444E37454E37464D36484F37
4A5038484E3A484E3A464C38474C39484D3A4A4F3B4E523C4E523A4E513A4C513A4B513B
4A4F39454E38454F38434D34434D33414B304047304147304147324248344248353F4634
3E46343B443138412C374229353F23313C1D313A1D313A1F313B20323D23364025343E24
323C24313C24323B25343B27353A29353B2B363E2C343B29353C28353E28353D27313924
2D351F2B341C2B351C2A331B2C351C2D361C2B321A292F182A2E192B311E2A2E1E292E1F
292F20272D1F292F1F29301F272F1E252D1A232B182029151F27142128162329181F2717
1D24161F25191F25181E2415
1F22221D2020181C1B161A17161A14191D151C1E151F2119232520282A272B2F2C2C3432
313A38313A362B34302B32302C33332E33343033373033392E31392B2E37232730181C25
10131B0B0D120B0E10101410151A1115191113150E12130D13130D1617101A1B151A1C18
1D211E202724252C27252C27272E282026221519181011130F0E100D0C0E0E0D0E101110
0F13100F120F0D100C0C100911170B181F0F1A22101B221119200F161B0E13160A12150A
13150B12140A12150B13170C1B22112229142C331B3942273F482C434D31465033485134
48523347533647523747533849553A49543A48543B47533B465239454F37444D35485038
49513A48503B474E3B474D38474D38484E39494F394C523A4C50384B50384C523B4C533C
4B523B465038444F36434E34434E34465136444F36434C34434B34434B35434934414735
4048343C44313B422E3B442C384227353F22343D20353E20343E21343D21353D22363E23
363E24353E26343B26323825353C28343A27343B28343C28353C28353C27343B26323B25
313B242F3A222E3A202D381F2C351E2E361E2D331F2C321F292E1D2B30202B3022292F21
282F20282F1E272D1D262D1B272F1A232C17232C16232D16232C16232B16222A16202815
1F2715212917232A181F2516
181D1C1E21201C1C1E17181A171816181A16181914191A151919161918171B1C1A202521
28302A2D362F2E372E2F38312D35312D33312F333430333831333C31353F2F353E2B3239
232A301D2227171D1F171D19181E17151A1413171012160E15180F171B1216191011140E
121510171C1721261F292F252E342A2E352B242A241C1F1C1819191311140E0E12100F13
0F1113101313111413111712121910161D0F171F0C171E0B171E0B151A09131708111506
1115061014050F140510140615190A1518081A1D0A292E17373C2240482B465032495235
49533647533847533746533848553A49553A49553C47533C47533C455139444E38454E3A
47513D49533D47523A454E36464E35474E35484E36484D364A4E37494E374A4F3B484F3C
48513D46503A444E36434E35434E35434D35434D34434D34444E36464E38434A35434835
444A364047333B43303A422E39422C353F28354026374224364022363F23373F23394125
384024373E26363C263339253138252F3523303625333B28343B27333A26303824313923
323A23333B23323A22333B212F361E2D341B2E331E2E33222D32212C31222C31242C3224
2C32222B311F272C1B252B18272E19252D18252E19242D19242C18252C19232B18212916
2028151E26121E26141F2415
1B201F292D282526251F1D201A191D19181C181619171618151314131211111311131712
181E171E251B272F212E362830372C31362E2F332F2F323231333834363E34393F32383F
2F373C2B3436252F2F2028271B2220161B1A161A18171A16161A15161A141418120E110C
0D0F0B10130E1B1F1722261C262A1E2B2E222D32282D312A292E292427261D1F2317191F
12151A1114181519181A201A1A21181A2115171F0F181F0D171D0C1319081217080F1406
0E13050E110310150513170715170912130712120519180722210E2C2D193B412B444D34
47513749553B4A563A49563849573747543647533848533949553B47513A46503B454E3C
47513C47523C48533A455034444E31454E32464D33464C33474B33464B34474C38474E3B
444C3A444D38444E36444F35434D33414A32424B33424B32424933444B34444A33444934
454B37434A373F47373C433539413236402E343F2B344029333E25333E22363F22374024
353E23343B23353B253338253137252E34252D32242D33242E3623303824313823303822
2F382130372030371F2F361E2D341C2C321A2D311D2C301F2B2F202B2F222C30232C3121
2C31202C3120292F1F262B1B252B1A242B18222A17232A17262B1A262D1B262E1C242B1A
2127171E25151E24131D2211
53635749554B353C363136322C2E2E28292B2221241E1C1F1B1A1A18191414171012160F
1318101519101C1F132224172A2B2230332C31342E303331333638373A3E373B41373D44
333B41313A3E2E3739293132232A2B2127282125271F21221C1F1E18191B1314170E0E12
0B0B0E1012121C201B1C201A181B13181A121F221A252A22292E292B322E2A312E212726
191F1E181E1C1B211C1B221A1C241A1A2016171C10191E0F191E0F16180B121409101208
1011090E0F0810110813140A15150C15160C1414091715061B19081C1B0A292C19393F28
4148304850344C54384D56394B573A4B573B49553B49543B48543A49553B49543A47523A
485138485038485037464E34454D34464F35454E35464E35454C33464C34464C34474D35
444A34434934444C34434B35444B35444C35444B34444A33444A35444B35464E34454C34
454B354449364248373F45383C4235394132363E2E323B2A303B26313D24323E23333D23
323C23313A24333B253339242E35212E34202F36222D33202D33202F3522313824313823
3038243038242F37232D35202B331E2B341E2C341E2B321E2A2F1D2B2E1E2C2E202C2F20
2A2F1E2A2F1F2A3020282F20252C1D222A1A212918222917252B1A242A1B222A1B232A1B
22281A2228192128171E2310
71867D72867C65776F5E6D6557625D4C5452454C4A3A413F282C2923282022271D22261D
24281E24261C2222191F1E182320202B2A2B2A2A2B2A2A2C31323335393A373B41394044
384145343D422F383B2C35382B32342C34332F38342D33322A2E3024252C1A192313101B
100D1715131B1B1D20161A1C1113130D0E0C0E110E1316131A1E1A212723252C27232A24
1F2720232C23242E24202A201E261B192014171D10191E101A1E10191A0C14150913130A
14140B1010080F0F08100F0911110A13130C14140D212315282C1A292F1B2C341E343C23
3A412541472A464C314B52384D543B4D563F4B554149554049563E48543B4953384B5538
4D55394C53394D52394A4E38494D38484E39464E38485037484F35484F34464E32444B30
444A31454A32484E35474D37484E3A474D3A464B38454A38434A38414936424C33434C32
444C32444A324348334247354045353F44343C4131373C2D323A2A323D28313D24313C22
313C21323B21343D22343B22323920313820333A22333923323722303622303522303623
3037252F38272E38262E38242D37242D37232C37222B35212A321E2C311F2B2D1D2C2F20
2D31212C30232C30242B3024282F23232B20232B1E232A1B242B1B252C1D22281B1F2719
21271A2128182028161E2612
7E928983968E85989283959081928F7A898877878470807E596768515D5D55615D5A675E
5A665A484F4834373636383B33343B2C2C332221271E1C2122202328282A303234343839
363D3D363F4031393C2B33382D3538313A3B353E3E363F3F384041373A3F2F313A252633
20202D20212B1E202714151C1012150E0E0F0D0D0C0F0F0E11110F131411171B171A1F1B
242C25283229293429263127212A1F1C23171A21131A20121A1F12191C0F16160C16160C
15170C13130912120912120B13130C100F0B100F0E30362A4A58434D5E464B5C4246543A
414C313E472C3F472D434A31464D3647503A4A533E4A553E4A563D4A543B4A53394B5339
4D543A50573E4F563D4E533B4C503A4A50394B513A4A5139495036495034484E34474D34
474C34484C33494D35484D37484D39494E3B464C38444A35444C36444D36434D34434D33
444E34444D34454C34464C34454A354549344145323D42303A402F363F2B343E28333C24
333C23343C23343C24353D25353D25333C24333B25333925333A263139252E36232D3522
2C35232C36232D38242E37242D37252D38262E38272D37272D36272B32242A2E212A2F22
2C30232C2F232A2E23282E23262C23252B22252B21242A1E242B1D242A1C22271A212519
2026182128182027171F2415
82968C8698918A9B988A9A9C8A9A9E88979D86979A8697988495987F90947F9292829793
82978E798B826C7B746F7E775C67652C2E381B19241A191F1513191614191D1D1E262826
2F3330343938353E3C323B3C3943423F4A493F4A493C46483B44483A4147383F46353C45
3239432E353F242934191C2713141E1010161111131111110F0E0D0E0D0C0F0F0C11140F
232A22262E26293127293227242C232129201E261B1C22191B20181A1F17181C14171B12
15180F14170C15160C18190F1716101616101F20182A2B23464E3E515F4A53654C53644A
50614549583E455337434E33434E32444F344750374C543B4B533C4B533B4D563B4D573C
4B553C4C573E4E573D4D563B4D56394D54384D53384C523A4C513A4B503B4B503C4A503C
484E3A474D38474D35474D35464C35474D37474D35474D34474D34454D36444D37434D36
454F37454E37444B36434B35434A334349314148313F47313F46303C432D3A412C353D28
333A27323A26333C29343D2A323C2A313C29303B27303B26313B27313C27303C262F3A25
2F39252F38242F39242E36232D3625323A2A313A2C30382E30392D2D35282C32252A3023
2A30232A3022293022293022282E20292E212A2E21292C21262A1E24291A212417202418
20241923261A24271B202319
80948E869A948A9B9A8B9C9E8C9DA18C9CA38A9A9F8A9A9C8A9B9C8B9D9D8A9F9E8BA19D
8AA2998BA3968AA1928CA1927E90843E43481A19241C1B2117151A141115131113171616
1D1F1D2225222C332E323B363B453F404C443F4A443E47463D45473B4348384048384047
3A434C3A434B3740483036402327311D202815171D121217100F130F0D100F0E0E141614
252B24222922202720252B22272E22242B2022281E1F251D1E241E1F241F1F251E1D231B
1B20171A1F15191E131A1D1319191118181223231B23231A3F433456624C505F493E4B3A
43523E495A414D5F414A5C3B47573547543345503147503449503849503848513849553A
48563A4A573B4D5A3D4B573B4A553A4C553A4C543A4C523B4B503B4B503E4B513F4A503E
484F3F474F3E464F3A464F37464E36474F36464F34474D32474C34464B35464B38444B38
444C3A434B39434C3A424B37414933424830414930424B304349304247303F45303C4330
393F2F343B2B313A2A2F392A2E392A2F3A292F3B26303C24303C23323D23323C24323B25
3239243137243037233036232F36242D33222C342530382A2E38292E37282D36242B3221
282F1E272E1E29311F29321F2B321F2A2F1D2D2F1F2C2F21282D1F25291C212417202217
20221A23261D22251D20211C
7F958D879D968A9F9C8B9F9F8DA0A28D9FA28C9F9F8DA09D8C9E9B8C9F9C8DA19C8CA29B
8CA49A8DA59890A79891A8958FA5926C7C712E3235222426202020181718151314141212
1413111818151C1E1A1E231E282F28303830373D363B413C3D43423E45473E46493F474A
40474C3F464C3E464D3F484E3C454A373F422C303424252A1F1F251A182014121A1E1E21
2327261A1E1E171B181B211A22291D22281C2025191F251B21271E21281E20271C21281B
20281B20281A1F25171C1F1419191216151318181519191645503E5E6F5544513F2D352A
2C34282B34253E4B324C5F3D50623E51623F4C5B3B47533847503848513B47513D454F3A
43503A44523A4A573D4B573E4A563E4B553F4B533B4A513A474F3948503B49523D49513D
48513E474F3E454E3D46503C46503A475138464F35464E34474F35464D35464D35464D37
454D39444B39454D3A434B39414935414A33414931434B31434A3142482F414730414832
3E453139402E343D2B30392930392A2F3827303A25303B22303A2030391F313821303822
2F36222F37222E36213038232F37232D35222B35212E36232E36242F37262F37252D3320
2D32202A301D272E1C252E1C252E1D282E1D2A2F1E2B301F292E1F252A1D2025191E2317
20241722261B20241B1F221C
849B9189A0988AA29C8BA29E8BA09E8BA09E8BA09C8A9F9A8B9F998DA09A8DA1998FA39A
90A59B90A69B92A89B92A79994A999889C8C5D6B63383F3D3034322021231C1B1E191719
161515171614181913161712191A151D1F1925272134362F3B3E383F443F424844434A49
454E4E444E50414B4E3F4A4C3F4A4A4047494046473D4144393C40313139282731292A30
24252A14141B101117121515141814151915191E171C21191E241A1E25191D2417202617
212918232A192226181F22171E1E181C1C1A1E201F1D2120242A262E372D252C24262A22
23271F1C1F171B20152C362446563B536749576A4C54654A4E5C4349553F424D3B3C4636
3A46363D4938424E3B46533F4855414A574249554048553C49553A4C563A4A5437495237
4A5238484F3B464E3C47503D47513A47533A454F35444F33464F34464E33454E34454C34
474D35464C36454B37454C38444C37444D36424B34414A33414B32424A3040482E40482F
3F47303E46313D45313A412F353C2D33392A323927303726313926333B25323A24303824
2B34212B34212B33202E36212D35212E35222D34212D34212E35222F35232F3623303722
2F36212D341F2B321F29301F272F20283020293020293120262E1D252C1C21281A1F2518
2127172126162125171F2318
81988F879F9588A09888A099879E9889A098889E97889C948A9F968EA29990A39B91A59D
92A69D92A59B93A49B95A59C96A79D93A59B899B91798A8057625F383C402E303524242A
2221231D1C1A1B1A161818151615121615121513111D1A1525231D2F302A393D36404640
424B47454F4C404B4B3D48493E494A40494B43494C44494C43484C43464B41434B3C3F48
2C2E391E1E2A1416200F10180E0E150E0F131012121519151A1F191E221B1D23191E2418
212819242A1B24281B24261D262822282929282A2C212527191C2017191C17191C1D1F1D
1E201B1B1C19181B17171B1721281E323D2D3E4C374D5E4457694D52624A3641312A3326
262F232831242C35283743313E4B3545523B47543D48543D49553B4B593A4A5637495435
495335475037485139485039454F36465038465037465035454F34444E33454F34454E33
464C31444830444A32474C36464C36474E35464E35454D35444B34434B333F48303E462F
3D452F3F47314048323E46303A422E39402E363C2A343929333828343A29333A29323B29
2D37262A33232B32202B321E2C321D2D331E2C331E2B331E2D341F3038213037202F3720
2E35202D35222B3423282F22252C20232C1F273020262F1E232B1A242C1B232B1A1D2415
1D2415202514212514202314
839890869D95879E97869F99869D97879D95899E968A9E978CA0998DA19C8DA19C8FA39B
91A49C93A59C94A49D97A79F96A69F95A59D94A59B93A59A86988E6F7D7750595835393C
313432292B2521221D1C1D19191A1617151416121116110F1711101B1714282420353630
383E393E4642414C47424D4A414C4B424D4C444C4C444B4A44494945494B47484F454651
41434E383B472B2F39181A2614141F1111190F10151112151619191B1F1D1D221E1E241D
21271E23291F24281E24251E2F322B363A35363A3A292C301F1F2518181F15151A17181B
1A1C1B191D19191F191A201A161C161920161E2718242F1C3E4D3448593E2E3926222A1B
1C2316181F13161C0F242C1C323B273E473045503848523C48523D49553C4A563B4A5639
4954384753364953364A5136474E34464D35474F37454E37434C36424C36434D37434C35
424B3140482E41482E42482F43482E454A31464B33464B35464A384449384147363E4534
3C44333C44303C452E3D452E3D452E3D452E3D422C3B3E2B383A2A36382A34382C32382B
2D35272C34242B32212A321E2A331C2C351D2A341A2831182831182B341B2B341B2D351F
2D34212C33242B3328262D25222921222920232A20232B20242D1E242D1C232B18202815
2129142328122024101E210E
81938B879C938AA09989A09B889E9B869B9A869C9A899E9D8CA09E8EA09F8FA2A08FA29E
91A39E94A59F95A49E96A59E96A69F96A69F97A89E95A79E96AA9F92A69B82938868766E
58635A4A54482C322B262C251D201C1919181715151813131712111812121A1514201D1A
2626232C2F2D343A363A413D40494447504B48514C48504B464C4A46494A44454C44454D
43464F444A544248513A4046282C3422252B1B1E2413141B12141C1B1F24202628202726
222926222A24212823212520292C26383D363E443E3B413D3034332A2D2D1F20231C1D20
1B1E20191C1C171B191518161015101419111A2114181F0F1D2415262F1D232B1B192013
181E11192013191F131D2417293120353F283C472E404A32424C354852394A563A4B5639
4B56394953374C55374B5336494F35484F36484F36464E37454F38454F39465039464F39
474E37444C343E452F3C422B3D422A3E432B41462F424731444834454B37444A37404737
3F46373D45353B43303B432F3B42303B422F3E452F3C412C3A3E2C3A3E2E383B2E33392D
32382C33392B3037262D35222E35212F38222F371F2D361F2B331E2B321F2A311E2A311F
2B32212B34242B3426293226272F24252D22242C20232B1D262E1D252E1C252E19242D17
272E15262C1323281021250F
83958B8B9F968CA39D889F9C859D9D869D9F869C9E879D9F8A9F9F8CA0A08FA2A191A4A3
92A5A394A6A295A8A095A89F96A79E98A8A198A9A298AAA397ABA295AAA095AA9F91A69A
899D907A8D7E5F6F6249524A3437352C2D2E2525271E1B1D1D1A1B1F1E1E1F1E1D1F1E1C
1D1D1A1E1E1C212220282A27363C3640473F474E464C534D4D53514A4E51474A51444852
404650454E55444E53455051434D4B3F4745393F412C2F3720212D272B35262C341E252A
1C23241B24211C231F1C221C1B1D1A2123202E312E373D383B433C3B433C363D372E3431
242A291D2122171C1C1215150E110F111510161B13171D121A1F1421281B252C1E21281B
1C24161C23171C2317252D1F313B2937422C3B462E3E482D40492C454D31484F32484F32
4A51344C52374C53394B52384951384852384852374954374853374750374A513A4B513C
4C503C4A4E3B464B394348374147333F46304047303E472F3D462F3F48303F48313F4731
3F47333F46333B42313C44333E46353942303A432F39422F37402E39412F394030373F2E
37402E39412D373F2A343C27363D29353C293339263239273038282D3528293225283124
2831242831222832222A34232933232932212A332029301E292E1C292F1C282E1B282D19
282D17272C16262A16252816
879C928DA39B8CA4A08CA3A38AA2A68AA1A5899FA2879D9F899E9F8BA1A18FA3A291A4A2
92A5A292A6A194A7A094A79E97A99F99AAA29AAAA599ACA798ACA697ABA597ACA497ADA5
97ADA496ACA093A8997A8A806C797067746B454B4D32343C373B3F3D41433133362C2E2F
292B2A2729252628222729232B2E2730322D383A3441433D4A4C484D4F4F4E52554B5356
454E52424C4E414C4C434E4B4954504A53524A5154474E543E444C3A4149272D381C222C
141B21131A1C141A181317151110121311141A17192D2C293B3F393C423B3E453D3C453D
363E392D3434252C2D1B21211115140F13101013101216101E251A252C1F293021272E1F
232C1B232B1B20271722281925291A2A2F1D2D321F343923383E253E442A454A2F474C32
474D32494E334A50364A5138495138475037475037485337485237475036484F394A503D
4C52404B513E484E3C444B38424935414A33414B333F4A333D48333D48313C462F3C462E
3D462F3D452F39422E39422E3B433038412F36402D343E2C353F2D36402D353F2C333E2B
353F2C363F2B353F2A343D2A353E2B37402D373F2C363C2C333B2D30392C2F392C2D362A
2A3327283123252E1F262F1E28311E2A341F2A341E29321C293019292E19262B19262B19
262B1824281626281826291A
879E968CA39C8BA29F8CA3A28BA1A48AA0A4899EA4899EA38A9FA18CA1A28DA3A28FA4A2
90A6A192A8A094A9A092A69F95A8A298AAA499AAA698ACA998ACA999ADAA98ACAA98ACA9
9AAEAA9AAFA99AAFA59AAEA28A9B9175827C656F6E596064727C7778847C666E6C606A66
576259414840363A3234352E31302B302D2C34312F3533313A39383F3F3F474A4A4C5352
4C57544A565049554D49544D4C56524D55564C52584C515B4C545D49545B3F4A52354048
242E3520282B171B1E141418120F151711151A141535332B3A393233322F313030323432
393E3A3D45403B4640323E3818211D1117130F130F0E100B1C2317212719232919272D19
282F1B28301D2A301C272D1A2226162123151D1F111E2012252718363B27495237495237
4A54394A5337495136464D35464C35464D36464D37465038444E3745503747513B47513D
48533D48523C465039444E37434D35424C34414C34424E35404C343F4B323D4A303C482F
3B462D3D462D3D452E3B432D3A432F3A423038413037402E38422F38432F36422D34402A
333F29343F29343E28333D29353F2A363F29373F2A363D2B353B2B333A2B323B2C2F382A
2D36292C35262832222831202A34202A342029321E2A311D2A301C2B311C292E1A262C17
242B15252A16252A17262B1A
849A9389A0998BA19D899E9E879C9F879DA0899FA2899FA2899FA08BA1A08DA4A48FA6A6
91A9A692AAA594ABA395A9A497AAA896A9A896AAA898AAA999ABA999ACA99AADAB9CAFAC
9EB0AB9FB1AA9EB0A79FB2A6899A90626C6A626A6A737D7992A09596A59998A89C9AAA9D
95A79773807758615C535B554D524C52564D45443E3937343534323634343C3A3B424344
454A4948504B4D574C515C4F525D535058554C53564A50584F555E5058614C56604A555E
4450553D484B323A3C292C302220241E181C2520204140392F2A2A252124211C211D191E
2323242D312F343E373844392B382C161F1713190F0D120810150B13180C14180B181D0D
1E24142128182329191F26171C2116262B1F252A1E21251B1F21182F34265563465B684B
5B684B576349515A4449513E464C3A434A37434A364047353F4734404936424B38454F3B
46513B48523B46503B444E38424C35404C343F4C33414F34404F33414D31404C313F4A30
3F492E3F472F4047313D43303C42333A423438413238423039443136422D36412C36422B
364229374127373F27353D27343B26323925343B27343B28333B29323C29323C282F3826
2D36252C352529332229322027301E28301E2A301E2A2D1D2A2D1B2A2E1C282C1B252A17
222616252919252A19252A1A
8597948A9E9D8DA0A38B9EA4899CA3899DA28A9FA18BA0A08CA09F8EA1A18FA2A68FA3A8
91A6AA91A8A991A7A694A8A798ACAB97ABAC97ABAB99ABAB9CADAB9CACAA9EAEADA0B0AF
A0B1AEA0B0ACA0B1ABA1B3AC95A59F747F7F6E7777838F8A9DACA19EACA2A3B0A7A6B4AA
A7B5AAA1ADA6949F9A87908D828C868D9B8A646C5F4B504645484040403B3F3C3A3D3A3A
3C3A3C3E3E3D4347414A50474F584D505A514F58534E555653575C53575D4E525B4D535D
4C565D4C585C4B58584652503D434231313434323340403B272326201D221B181F151219
1312161516181A1E1C20261F222A20192319151C11161D0F141A0D13180C13180C14170B
15180D171B10181C1115190F10130D161B141E231A22271C23271C2B31233E4634555F48
5C68506270586070585865514D5544414636363A2C333628353829383B2C3C40303F4533
434B37464E3A444E3C424E3D3F4B383F4D363F4E333F4E30404E2F414D2E404C2E41492E
424A2F4147314045333D44343C43353B443737423435402F35432D35422B35422A364228
384329394229373E28373C2A3439293037272F37263038272E39282D38262E3A252F3A23
2E38212E371F2B341D2B331C2A311B2A301C2B2F1D2B2C1C2D2E1D2D2D1D2B2B1E28291B
27291B272A1D262B1D24281D
8697988B9CA08C9EA78B9DA88A9CA78B9DA68C9EA68EA0A48EA1A38FA1A490A2A690A3A7
8FA4A790A6A78FA6A792A6A796AAAC95ABAE96AAAC98ACAB9BAEAB9BADAA9DACAB9FAEAE
A0B0AFA2B2B0A2B3ADA4B4ADA1B1AB9AA9A495A29D97A59DA1B1A6A3B1A9A7B4ADA8B5AF
A9B4AFABB5B0A9B2AEA9B3ADA7B1A9A5B3A595A49186927D686F616166595E605654554D
4C4D4742423C3E40373E3F3742453C474C434C514B4F5552535959555A5C52595C50575B
4C55584A56574B59594F5C59535E595157544D505145474925222E201F2C1A1A2615131E
12111A1012170F13130F15100F160F111910121A101720101C24121B2211191D0F181B0E
171A0E181B0F15150B1111080E0D070F0E0A13130F1616101617121D1F19292C25373D32
48524452604F596A5660735B5D6E554B5641373A2A28271B26231929251C2D2B21323026
383A2C3F4533414A37414C393D4A353C4A313D4C2D404E2B404D2B404B2A3E48273E4527
3F452B4045303D43323B433339403337403336403235403034402B344128344025384226
394127394028393D28383A28373B2C343A2D32392C2F382C2C362A2933262A35242C3722
2C38202E391E2C381C2C371C2C361B2B331B2D321C2D301E2E2F1F2D2E1E2D2C202A2A20
292B22282B2324282021241D
839797869A9E8A9EA58C9EA98B9CA88A9BA58B9BA38C9DA38E9FA490A1A68EA0A58FA3A5
91A4A691A5A790A5A791A5A697ABAB99ADAE9AADAD99ACAD99ADAD9AACAB9CADAC9EAEAD
9FAFAEA1B1AFA0B1ADA2B3ACA4B4ACA3B2AAA2B0A8A0AFA7A3B2A9A5B2ABA7B4AEA9B5B0
ACB6B2AEB9B5ADB7B3ADB8B2ABB6AEA9B6AAABB9A7A8B6A19FAA979AA593939D8C899283
777F6F5E64544A4F3E3F4234393B303738303738323B3D3A4649484E5453525A5A525C5B
505B5A4C58574A56554D5858545E5B59605D5A5F5E585C60484C543C414C292D3A1E222D
181B2613171E1015180B1210090E0A0E140B1820111E2713232D17252E18232A15202513
1D21111A1E0D161808121105110E05120F0916130D1916111714131512151613171C1A1B
262927353D3647544555664E46563F46553B4551373B402D3D403037352D2F2B292E2A26
313028363A2E393F323C45333B45303B462C3A44283C47273C46283A42273A40263A4027
393F29383F2B373E2D373F30363F31343D30333C2D353D2B373E293840283841273A4228
3B422A3A412A3A402B393E2B363B2A353B2B343C2C30382C2C34272B34262A32252A3323
2B34232B36222C37212D38212B351F2A341F2C341F2B311E292D1C292D1D282C1E272B1F
272B20282C21262B1F23271B
7E9597849B9D899FA38A9EA6889CA5899BA38B9BA18B9CA38C9DA38D9FA58EA0A690A2A5
91A3A591A4A792A6AA91A6A895A8A996A9AA99ACAC99ACAE9AACAF99ACAE9CAEAF9EAFB2
A0B0B49FAFB3A0AFB1A1B1B0A4B3B0A4B2AFA5B3AEA5B3AFA5B3AFA6B3AEA7B5AEA9B7B1
AAB6B3ACB8B4ACB9B4ACB9B3ABB9B0AAB9ABACBCAAADBCAAADBBA9ADBAA9AEBAA9AAB6A7
9BA69992A08D67706140443C3538322F332C2B2D272A2A252D2C283C3D38464A444E5550
525A57535D5A515C5A505B5A545E5C57615C585F5A5A605D5B61605860604A51543E464A
31393E1F252B151B1F0E14140A0F0B0E140B1921111F291429341D2E39212B351C222A14
1D210E181A091113040F11031010051211081A190F1E1D121E1C1326241B28261D221F1B
26252431332E393E36464F3F3036291C211722291B2B34234A573D606C505E6750565C49
474B3D3F43373F43374045373F45353C42313C422C3B43283B4428394127373E26373F26
353C26343B25343B26353C29363C2C353B2D323829333928363A29383C2C373D2D363D2C
373F2C363E2D363E2C363E2A353E27343D27343C263038242D34232C33232B31222B3223
2A31242931252931262933262A34242B34222A332029311E292F1D282F1C282E19262C18
272C19292E1C282C19272B18
809697859C9F8AA0A58A9FA8889DA6879CA38A9BA38C9CA68D9EA78C9DA68FA0A891A3AA
91A3A991A3AB93A5AB92A5AA93A4AA94A4AB95A6AC97A8AE9AAAB09BABB29EADB4A0B0B6
A2B1B7A1AFB5A1AEB4A2AFB4A3B1B4A6B2B3A7B4B3A8B4B3A8B4B3A8B4B1A9B4B0AAB6B2
ADB8B6ADBAB7ADB9B6ACB9B4ACBBB1ACBBADAFBDACB0BEADB0BDADB0BDAEB0BDAEB2BDB0
AFBBAFABBAAC92A094626C66474F4A3A403831362D2D2F242A2A1F2B2921312F2A3B3B37
3F413F474C495059535560595A665E5A655C565F56565E56555D57565E5956615C55605D
4E5B5943504D2C343413171811151213180F1A21131E2615232C1727301B28311B252B16
1E221016170A100F070E0D080E0F0810100B23261C1F20181C1C155661466D7C5A34382D
3D443B41483E3238312A2E2922231E18191312110D0E0E082023196E80618BA17D849878
6D7B67556054555F5450584C4C5345474E3F434A373F48303E482D3E482C3C452A3B442A
384026363E26353B26353A26373B29363B2A32372831362732362833362A31372A31382B
323A2D30392B2E37282F39262F3B242F3A222F39212D371E2C351F2C34202C33202A3120
29312128302327302528322629342429332129342029341E28331D28321A293118282F16
272D16272C18262B18272B19
7E9195879C9F8B9FA5899CA6869BA5879CA4899BA28C9EA48D9FA78D9EA68FA0A791A1A9
93A3AB92A3AB92A4AB92A3AA93A3AB95A3AB95A3AB94A4AC96A5AD99A7AE9BA9B09EACB3
A0AFB4A1AFB3A3AEB2A3B0B3A4AFB3A4B0B3A5B1B1A6B1B0A7B3B0AAB6B2ACB7B6ABB6B4
AAB6B4ACB8B6ABB7B4ACBAB3ABBBB1ADBCAFAEBDAEB0BDAEB0BDACB2BEACB2BDACB3BDAD
B3BEAEB2BEAFAFBDAEA0AE9F8A9888626C6141453E3B4034383B2E38392D34342D33312F
312E2E2F2E2E35363341453E4E564A555E51596355596355566053525C51576356566357
515F5651615747564C252D291D241D191E17181D13171C10191E0F1A1F0F1D2012202416
1F231516170E13120D11100D0F0E0D0F0D0D1919171716141E1F1E7F9377A6C29E94AF90
5F705F3D453B2B2F271B1C1716161215140F13110F11100E0E0C0C47514194AD88899F80
889C8170816F62716361705F63715D626F5D5E6B595D6B5558664E505D454C564048513C
444B384146353D42313A3E2E383C2D373A2B33352A32352A3134283236293035282E3327
2E34272C34262932242A34242A34232A33232B35232C37212C361F29321C29321C29311D
29301E27301F28312128322228322228311F28311D28301A272F1A272E19282E19262C18
242916242A19242A1C22291B
76888D84989A879BA28598A28295A28497A28498A1899CA48D9EA78E9FA88D9EA78E9FA7
90A1A98FA1A991A3A991A3A893A5AA97A7AC97A7AC95A6AD95A7AC98A8AD98A7AD9AA8AD
9BAAAD9EADACA1AFACA4B1AFA6B2B2A6B1B3A6B2B1A6B3AEA8B3AEA9B3AFABB6B4A8B4B2
A7B3B3A9B6B5A9B7B3A9B8B2AAB8B0ADBBB0AEBDAFAFBDAEAFBBABB0BCABB2BEABB2BDAB
B3BDABB4BFADB3BFAFB2BEAEB1BEACA5B19F82897C72786C71776B60655B47494442423E
363332302B2A2A262326241F3132293F43364C5242545B4957614E4A52444C5646485342
424F3E404E3E465543424F3D2A34252026191F24151A1D0F17190C17180C1A1A101E1F16
1E1F1818181212120C11120B12110D12100E1615131B1A1A1B1B1C3B413B5D6D5D92AE8E
7D95783A4435282C1F1E1E1417150D100D080F0B09100B0C0E0B0D2529257C94788EA78A
839A7F80957B63715F586453596453636E5E7D8E7883977D83967C819276758368646D57
6167565E645959605650584E464F4340473B3C4238393D35373B33353A3034392D32382A
3239292F38292E36292A31272C32282B32262930232A32202C331D2A311A2C321A2C321B
2B311D282F1D252D1B242C1D232B1C232B1B242A19242A19252A19262B1A26291A232719
21261821291B21281D20281D
7C8F8F829595869A9D879AA28496A28395A28395A18899A38B9BA68C9DA88C9DA78B9DA6
8CA0A88CA0A78DA1A68FA2A591A3A792A5A893A6A894A7A795A7A796A8A996A7AA9AA9AC
9BAAAB9DACABA0AFACA2AFACA4B0ADA6B2AEA7B3AFA8B4AFA8B4AEA7B2AEA8B4B0A7B4B2
A6B2B2A7B3B3A7B4B1A9B6B1ADB9B3ADB9B1AEBBB0B1BEB0B0BDB0B1BDAEB2BEACB3BDAA
B3BDABB3BDADB4BFAFB4BFAEB4BFADB4BEABB0B9A7ABB3A2A9B2A09CA5957C807673786C
3C353736302F302A2A2A26242825202D2D243334273B3E2E3E44313235272F34262B3122
272F1F29301F323B273B452D3036232A2E1E2528191E2015191A1116170F1A1B1420211B
20211B18191513151113160F13160F12130E181A161E201D2529232529242B312B4D5A4B
5968564A564522251D1D1D15191611110D0C0E090C0D050B0C070E353836738673839A85
7D957F83997F81947974826B677260616A5A7B8B7483957A86977C8C9D808C9E806D7864
5B615762685F646D64697368697565616B5D596358515A524D56504A534B475046444C41
41493C3D4438383F3532372F2F322A2C30262B2F232B2F1E2A2F1B2C2F1B2E301A2E311B
2D301C252A191E2414161C0F12170B11160B14190D161A0F1E221425291A25291A24271A
24261B22261C1F241C1E251B
7D918C859895899C9E879AA18497A18496A18598A28799A18A9BA28B9CA38B9CA48B9EA4
8BA0A68CA1A68DA1A48EA2A490A3A68FA4A78FA4A591A5A592A5A596A8A799A8A99BA9AA
9DAAAA9EAAABA0ABAEA2ADAFA3ADAEA5B0AEA6B1AEA8B3AFA8B4B0A9B4AFA9B3AFA9B6B2
A9B5B3A8B5B1A9B5AFABB7B0ADB8B0ADB7AEAEBAAFB0BCAFB1BDB0B3BEB0B3BDAFB4BEAE
B4BEADB5BFADB6C1AEB5C1AEB5C1ADB5BFAAB5BFABB4BDAAB3BDAAB4BFA9B1BCA6A9B59E
63625C3B3436403C383D3C333A392E37372A3738283233232C2C1D2A281C252419202115
2023142325152B2F1C3539253538262C2F2226281E1F201A1B1C181A1B171E201C222421
20221E1B1E1A171A16171914181B1314160E11130D191A1525291E2D3326363E2F444D3B
48533E424C38262A1F20221A1D1D19181515151114130D13110D13211F234E564F5E6D60
70836E798C73899C7E8B9D8087987E82937980917782957985977B84947B8A9B828B9B85
6670665C655D545A54626B5E8B9D83768371555E57555F595B665F5D6A61647266697867
67756364715E5C665550574945483E3C3E34383B2F35382831332231322032321E30311F
2C2E2025291C191C100F1208080B030407000608020508020C0F0615190D1B2012202315
21241722251A21251A1F2418
7588867F9493859A9E869BA28699A48699A6879AA7879BA6899CA68B9EA58A9DA48B9EA5
8A9EA58B9FA68DA1A590A3A591A5A891A6AA90A5A892A8A994A7A796A7A699A9A89CABAA
9FACACA1ADAEA4AFB0A6AFB0A5AEAFA5AFB0A7B2B0A9B3B0A9B3B0AAB3B1AAB4B3ABB7B4
ACB8B4ABB7B2ADBAB2ADB9B2ADB9B1AEB8B0B0BBB1B2BDB3B2BDB2B3BEB1B3BEB0B4BEAE
B4BEABB6BFABB8C1ADB7C0ADB6C0AEB5C0AFB8C2B1B9C2B0B9C1AEB9C2ACB9C3ABBCC9AC
9EA7905B58524A474279816B6B715D5459485257444345353736283131232D2D1F2A2B1D
282919282A182C2E1D3839293A3A2D3233292A2A2323241E1D1E191C1D18222420262924
2629242528222125201C1F1C1A1D1812140F0F100C10110C15170F1C20152B31213A422D
3B442E363E292B312024271A1F20181C1C181B1A1A1A1A1A1D1F1D1D201E252925363D34
434B3F484E427E8C7397A98C8FA18792A48890A1858EA0848D9F858A9B84889984889B86
8193807584736E7A69697564889A808FA5896B7A6A616F615B685B555F55626F62758774
798C767C8F777B8E7673836D6C7B66697561646D5A58604E535A494E5442464C393C4132
363C30282E251C221811150D0A0D06060801040600010300000100030501070A030D0F05
181A0D212414222716232A19
7387857D929384989F869AA48699A68699A78698A78699A7889CA8899DA78A9FA68DA0A7
8D9FA88FA2AA90A4AA8EA2A790A5A894A7AB94A7AD93A7AC96A9AF97AAAE9AAAAE9BAAAD
9BAAAD9EADAFA0AFB0A2AFB1A3AFB1A3AFB1A6B3B3A7B5B2A8B5B2A9B4B5AAB4B6ABB6B8
ACB7B7AEB9B7AFBAB5AEB9B5B0B9B5B0B8B4B0BBB6B1BDB6B2BDB5B1BDB2B2BEB2B5C0B0
B6C0AFB7BFAEBAC1AFBBC1B1BAC0B3BAC2B6B9C1B5BBC1B4BCC4B4BBC4B0BAC4ACBCC7AB
B9C6A89CA48D75746A9FA692A9B19C9DA79295A089777E6A49493D444636434734434731
3F432B3C4028383B283B3B2D3D3C3039382D2D2D2527271F21211A1E1E1720201A24241D
282A232C2F272C30292325241D1E1D1213120F100E0D100D0F120D1317111D2319242B1D
272D1D29301D252A182022141C1C161918171B1A1B1B1A1D303534444D47434E464E5C50
505B4E4C53474D504993A38A8A998484938080907B808F7A899C84899C858A9D878B9F89
879C858599817D9077778A72798B727C90757B8F767B8F76778A73738670738570738571
7486737788767889767889767889757A8B747C8B73798673748070717E6E6E7C6C677466
5C6A5C363F381C201D171B16090A06040501020300010200000100000100000200020400
0C0E031A1D0C222713252A17
7284857D90958295A08396A48296A38396A38497A38497A2859AA3889EA58A9FA58A9EA5
899DA68A9FA88CA2A88A9FA68A9FA58EA3A792A5AB94A7AF94A7B196A7B197A8B099A8AE
9AA9AF9BAAAF9BAAAF9CAAB09EACB1A0ACB1A3AFB1A4B2B3A7B3B5A7B2B5A6B1B4A8B2B6
A9B2B8ABB4B8ACB6B6ABB4B4ACB3B3AEB5B3AFB9B5AFB9B7B1BCB6B1BCB5B2BDB4B3BDB2
B3BDB0B4BDB0B6BEB0B8BEB2BAC0B6B9C2B8B8C1B7B7C0B4B6C1B3B7C3B0B7C2ACB7C1A9
B6C1A9B6C0AAB3B8A6B2B8A6B6BDABB6BEABB5C0A9AEB9A1787A706D6F647C836F818A71
7279635B614F525747484B3D4444393D3A313230272D2C2327261E21201A20201823241B
26261F282A22292B242224201D1D1C181718141315111413121713171D171B211A21291D
272E20293120252B1A1F22141B1C151B19171815171C1A1F373D3E7588776D8270617464
6476625A67544A4F4698AB908EA28B718373647365515B5271816D82957D849880899E86
889D878AA1885F6F60485349859A7C72836A6F7E6B7B8D797D917C7A907B7A907A778B75
76897575847474827572807572817573837374837174827175827074816E74816F74826F
788A734F5B501212170B0B0C010101000000000000000000000100000100020400090B02
121406171A0A1F2411232814
79898E7E91998093A07F93A08094A18194A08397A08397A08498A1869AA3899DA6889DA7
899DA68A9EA68A9EA68A9EA68B9EA68DA0A691A3AB92A4AD93A4AF95A3B096A4AF98A7B0
9AA9B19BA9B19CA9B19CA9B29EACB3A2ADB3A3AEB2A3ADB2A7B0B5A9B1B5A8B0B5A9B2B6
ABB4B9ACB4B8ACB5B7ADB5B5ADB5B3AEB5B2B0B8B4B1BAB5B2BAB5B2BBB4B2BCB2B2BCB0
B1BCAEB2BCAEB3BDAEB3BCAFB5BEB2B5BFB3B4C1B3B4C1B2B3C0B1B5C2AFB6C2AEB8C2AE
B8C2ACB9C1ABBBC1ABBBC2ABB9C0AABAC1AABCC3A9BBC3A8B4BBA2AEB39DADB39CB0B99F
ABB4999CA38A8D937B696A5A5C5A4E4B483D3D3B2F3535292D3024262A2027271E292A1F
2A2B2125281D20221B1D1D191A1A171817171515161618171B1F1B242920272D21293023
2B31252C32262B3122262B1D25281E22231D1D1C191818183036317B927688A48052624D
4D5A463F4839393E3464715E5F6D5D6A7F69697D675A6A566A7B647A8D747E927A82967F
849882899F86616F614045419AB18F51594E4248468FA48D7F948066786B7185747A8E7B
6D7B6D6C786D717C74727D7871807972817672827373817174826F707E696E7A656A7761
616D5A3F453D14121509050805030403010202010201000100010001030005070216180D
202314222717232A19242C18
7A898F7F929A8195A08297A18195A18296A18397A28497A38497A48698A5899AA7899BA8
8A9CA88C9EA88DA0A88C9FA78DA0A78EA1A890A1AB93A5AD94A4AD94A2AF97A5B199A6B3
9AA8B49CA9B39DAAB39EABB5A0ADB6A1ADB6A2AFB4A4B0B2A6B0B1A7B0B1A7B0B3AAB3B5
ABB4B6ADB6B7AEB7B7AEB7B5AEB7B3AEB8B1B1BAB2B2BCB1B2BBB3B2BBB2B2BCB2B2BCAF
B1BCAEB3BEAEB3BEAEB4BDAFB5BFAFB4BFAEB5C0AFB7C2B2B8C3B3B8C2B1B9C3B3B9C2B2
B8C2AEB8C2ACBAC2ABBCC4ABBDC5ABBEC6AABDC4A8BDC4A6BEC6A6BCC4A6BBC3A6BBC4A4
BAC3A2BAC5A1B4BE9AA2A98A93997E71745F4948374447323C422F353A2A333427313124
2F2E222A2A1F24241B1F20191C1E171A1C16191B161C1E1921241E2D31272F3327303528
3134293033283034282E31252C30252B2E241E1F17191A1216181024291D3A4532313829
2E3225282C22272B22272C2420251E4E5D496B7F6162735873866A71836A70816B6D7E6B
718574778C7B7387756E806D889E835E6A5F42494A8AA08B92AB92798C7A7C8F7B7F917D
3D3F404345487581786F79755F686668766E6E7D6E6E7D6C6D7D686C7C656B7B6467765F
515C4A363E33191B190D0C0D0B080A080507060404030202020101080A061417101F2318
272C1C292F20282F20293020
74868A7D919581959B83979E82969E8396A08496A18395A38596A38697A38797A28A99A6
8B9BA78C9CA78D9FA88EA1A78EA0A78F9FA890A0AB91A1AD95A3AD96A4AF97A5B199A5B2
9AA7B39BA9B29AA8B19CAAB39DABB49DABB39FACB0A2AFB1A4AFB0A7B0AEA9B2B1ABB3B4
AAB3B5ABB5B5ABB5B5ACB6B4ACB7B3AEB9B1AFBAB0AFBBAFB1BCB1B1BBB1B1BBB2B1BBB1
B2BCB1B5BDB2B8C0B2B8C0B3B8C0B2B8C1B0B8C2AFB9C2AFBAC3B1BAC2B3B9C2B3BAC3B4
BBC3B3B9C3AFB8C1ABBBC4ABBDC6AABEC6A8BEC6A6BFC7A5BDC4A4BDC4A5BDC4A5BEC6A4
BEC5A2BBC6A1BAC59EB7C29BB5C19AA8B48D6F71575E60485B5D46575A45525441464537
3E3C3133312829292024261C22241A1F21191E1F1720221924271D2F322635372A383A2D
383A2D36372C3233292D2E25292A222A2C23282B2220221B1C1E171517121516111A1B14
1919131819141B1E1820231C1C1F1A24292047543E505E46738866697C5E58674F3C4538
434D444E5B5465786A6B806E6F846F6A7E6D627568728876849D83879F84859A81707D6D
2E2B332B29346E7E737282763C414555605A7487725A67593A40394C564665755D61705A
4A564530392F1C201D12131209090A060506050404040301020200171C122B34222C3523
2D35232B3121272C2025291E
6F8088798C9380949C83969E83959E84959F8495A08597A18598A084979F8799A08A9AA3
8B9AA68C9AA78E9DAA8E9EA9909EA993A1AB95A2AD95A2AD96A3AD98A4AE98A6B098A5B1
99A7B29AA8B29AA7B19BA9B29BA9B19BAAB19FAEB1A2AFB2A4AFB0A6B1AFA8B2B0AAB3B3
ABB3B5ABB4B6ABB4B8ACB6B7ACB6B6AEB9B5AFBAB4AFBAB1B1BBB1B3BBB2B3BBB2B5BCB4
B7BEB5B8BEB4B9BFB4BABFB5B8BDB3B8BFB3B8C0AFB8C0AEBBC1B1BCC2B3BBC1B3BCC2B4
BEC5B2BDC6AFBBC4ADBCC7ACBCC8AABBC6A6BDC6A3C0C8A4BEC5A3BEC6A6BEC5A6BEC4A5
BFC6A4BDC6A2BBC5A0BCC7A1BBC6A0BCC7A0AFB8949EA3859BA183A2AA8997A080747761
45413A3F3D3533332A2C2F23292E20292D202A2B1F2B2B202B2C2332332A3F4233434738
3E4337373A3231362D2C2F29282A2624262224282123271E20231A1B1F151C1F161C1D16
1615101A1B1220221723261C21231D1B1D191A1F1823281F313A2B37412F38412F303628
2A2F22272B21343D3045524162765D556550424E415363536B7E69728771748976768778
515A573F48495D6E637C937C56655763736171836D4F594D1C1A1D292A285F6C59546050
3942392A322C1F2420181B170F120F080A08050804050802060902181F113F4F33445439
38442F2D3626282F2224281E
75878C7F929883979F8497A08394A08294A18294A28497A3859AA38599A0889BA28B9DA5
8D9DA88E9CA88E9EAB8FA0AD92A1AE94A2AE95A2AD94A3AC96A4AC98A5AD99A7AF9AA8B3
9BA8B49BA8B39CA9B39EACB59EADB49CABB09EADAFA1B0B0A3B2AFA6B4B0A7B1AEAAB3AF
ABB3B2ACB4B5ADB5B8ADB7B8AEB9B8AEB8B8AFB9B6AFBBB5B1BCB5B1BAB3B2BAB3B4BCB6
B7BFB9B8BDB7B9BFB7BABFB8BABFB5B9C0B3B8C0B2B9C1B0BDC4B2BDC4B3BDC3B3BEC3B2
BFC5B0BEC7AEBFC6AEBEC7AEBCC6AABBC6A8BEC7A6BFCAA6BCC6A5BCC6A6BDC5A6BDC5A5
BFC8A7BFC8A6BDC7A2BFC9A4C0CAA4BFC9A3BEC8A2BEC7A2BBC5A1BCC5A4BAC5A3AAB494
7172625250465355494B4F41454A394449374346364345363F42353D413544493A494F3F
41473A383C34373B353034302C2F2C292C2B2A2E29292D26272B2324282024281E22241C
1919131B1C1521231A24271D21241C1D1F1A181B1617191521261D272B2126291F23251D
2022191F221721261923281C48563E505F4438412E2F3427373E3140483C4751485C6A5F
7387765E6E635464595F71606779646C7E696D7D6C5F6C61414745494F4B5D665B4D534D
616F5E1B1F1F1B201D1116100C100A070A05050804090B060D100A0F130B2833223B4A34
3845333641332F382D242C22
7A8E8E83979986999F8698A28493A28594A68595A88597A88599A7869AA48599A2899BA4
8B9CA78B9DA88C9FAA8DA0AB8E9FAA90A1AD92A2AC90A2A993A5AB96A6AD99A6AE99A7B0
9BA8B29DA9B19DAAB19DAAB19FACB29FACB09FAEAFA2B0B2A2B0B2A3B2B1A4B0AFA7B2AF
AAB4B2ADB5B4ADB5B6ADB7B6ACB7B4ACB6B4ADB7B4AFB9B6AFBAB6AEB9B4AFB9B5B2BBB6
B5BDB8B4BBB7B5BDB8B9BFB9BAC1B7B8BFB5B8BFB4B9C0B3B9C1B2BBC3B4BDC3B5BBC2B3
BBC3B0BDC6B0BEC6B0BDC6AEBCC5ACBBC4A9BCC6A9BDC7A9BCC6A9BCC4A9BCC5A8BDC5A7
BEC6A8BFC8A7BFC9A6C1CBA6BFCAA5BEC8A4BDC7A3BDC7A4BDC6A5BDC6A6BDC5A5BBC6A5
B0BB9B959A82979F868D957C777D676F745E6669566062505154464A4E4145483C434538
3F41353B3C34393935383935373A35383A373437342F322E2F332D2D322B2B3029252922
1B1D18191A151D201821241A21231A1C1E161719121D1F182B2F262D3227292D2221221C
1E1F181B1C15191E141B1F141C2013282E1D2C321F2C3220262A1B2022181D1F19212420
4550434C584B343C38363E38475347576758627564677A6A657567687769626E64323638
48544A242B251F251F0D110D0C10090A0C050A0A040F0F0B0F100D0D0D0C0E0F0F111412
14181528302631392E272E26
7E909384969C8697A28696A58693A68693A98695AB8596AA869AA8879CA4889CA2899DA3
8A9DA58A9EA68CA0A88EA1AA8E9FAA90A0AD91A2AD91A3AB93A5AC96A6AD98A5AD98A5AE
98A4AE98A5AE9CA9B09EAAB09FABB09FAAAF9FABAFA2AFB2A3B0B2A3B0B3A3AEB1A5AFB0
A8B1B2AAB2B4AAB3B3ACB6B4ACB6B5ABB5B5ABB5B4AEB8B6AEB9B7AEB9B7AFB9B7B1BAB8
B2BBB9B3BAB8B4BCB8B8BDB8BAC0B9B9BEB7B9BDB7B9BEB7B9C0B7B9C0B7B8C0B6B8C1B4
B9C2B1BAC4B0BBC4B0BCC7B0BBC6AEBCC6AEBEC6AEBEC4AEBEC4AEBFC6AFC0C7AFC1C6AE
BEC3ACBFC4ABBFC6A9C0C9A8BFC9A6BFC8A7BEC7A8BEC7A9BCC5A8BEC6A8BFC7A9BEC6A8
BCC5A8B8C0A4B7C0A4B5BEA2ADB69A9AA286888F75767B645B5D4D585A4A5051454B4B41
45453C4141393E3C364C5043586150515A4B4C5446393D3230322A2B2D26282A24272924
21231E1C1D181F211923261B21261B1E20181A1B1624261F2A2E262C2F262A2C2225271F
22231C20221A1E21181B1D1314140B13130918190D1F20121E1E1217170E13140D11110C
23261D56664F2F372E242A25212727232B2936413A5262515D6E59576454576556435045
3E4C403F4D3C1E241C0D110C11150F12130C12120D13110F100D0D0C080B0A070A090609
0A060A0E0D10151516202320
80909485949D8595A48596A88595AA8494AB8192A98294A88498A7879CA7879BA5899DA7
8B9EA98DA0AB8DA0AB90A1AB91A0AB93A1AD94A2AF94A4B195A4AF97A6AE98A6AC99A5AC
99A6AD97A4AC9AA7AE9CA9AF9EAAB0A0ACB19FACB1A0ADB1A1AEB0A2AFB1A4AFB2A5AEB1
A7B0B3A8B2B3A9B3B3ACB6B4ADB7B6AEB8BAAEB7B9ADB7B8ADB7B7AFB9B8B2BBBBB3BABA
B4BABBB6BBBCB7BCBCB9BDBDBBBEBEBABEBCBABFBBBABFBBB9BFB9BAC1BBBAC3BABAC3B7
BAC3B4BAC4B3BBC4B3BDC5B3BDC6B3BEC6B4BFC6B5BFC6B5BEC5B4BDC5B2BFC5B2C0C7B1
C2C6B0C2C6B0C0C5ADC2C8ADC0C6A9C1C8ABC1C9ADC1C9AEC0C8AEBFC7ACBEC6AABFC7AA
BEC6ABBEC5ABBCC4A9BBC4A8B9C4A7B5C1A3AEBA9DA4B0938990777D836B7072605F5D53
524F4A4E4D4747483F4B4F425C695366775B6373563A3F2E2D2F2428282022221D20211E
2222202323222628242629242329241E23211D21203740373D473C31372F2C3127292B22
282A202A2D232629201C1D1613130C10100616170A1D1D0E1B1B0C1211090D0C070A0905
0F0F0B3740312B33292127221B211F171E1C1419181E261E293323252C1C272E1E303928
3F4A3847543D1C1F1615171021251B191B151F211A1D1D191412130F0B100D080F0D060D
0D060C0C050E0C0610141217
7C8E9483959E8597A58395A88293AA8293AA8395A98396A88499A8869AA8879BA9899BA9
8C9DAC8FA0AD8F9EAC919FAC92A0AC95A1AF96A2B195A2B196A4B196A5AF97A6AD99A7AD
9BAAAF9BA8AE9CA8AF9BA8AF9EABB19FACB19FACB29FACB2A0ADB4A2AFB6A4AFB5A4AFB4
A8B1B5A8B3B6A8B4B4AAB6B5ACB6B6AEB7B8AFB8BBAEB8BAAFB9B8AFBAB7B2BAB9B5BBBA
B6BBBAB7BBBBB9BCBEBBBFC1BCC0C2BBC0C0BBBFBFBABFBEB9BEBBBAC0BBB9C0BABBC3B8
BFC8B8BCC4B4BCC3B2BDC3B3BDC4B4BDC4B4BDC4B5C0C6B7BFC7B7BEC8B7BEC7B6BEC6B4
C0C6B3C3C8B3C2C6B0C3C7AEC1C7ABC1C8ADC2C8AFC2C9B0C2C9B1C0C7AEBFC7ACC0C8AB
C0C8ACC0C7AEBFC6ADBDC5ABBDC6ACBCC6ABBAC5A9B9C5A7B4BFA3ADB69BA6AF958B907D
6C6D6358575155554D494A4242453B494E3F454C3C353A2E2E3429282C232426201F211E
202220272A272B2F2A2B302B2A2F2B2629282427283B443D434E44353E36333B3230372D
2F352B2E342A2528221C1D1A12111010100A15160D1B1D101C1E1017190E10100A0D0C07
0C0B0711100C161913161A16141816111513111612171E16192015171E10171D0E161A0D
1A1C112225181C1F151D221721261C1B1E162E34273136282B2F2325271E26241F26231E
1F1919191316140F15110D15
7A8D9381959D8396A48598A88394A88293A88495A98597AA8496AB8598AC889AAE8A9BAF
8C9DAF8FA0AE91A1AE929FAD939FAE94A0AF95A1B195A2B096A4B097A5B098A5AF99A7AF
9BA9B09BA9AF9EABB09EAAB0A0ABB2A1ADB3A3AFB6A2ADB6A2ADB9A3AEBBA3AEBAA3AEB7
A4B1B8A5B2B8A6B4B8A8B6B8AAB5B8ACB5B9ACB5BAADB5BBAFB7BDAFB7BBB1B9BCB4BABD
B5B9BCB5BABDB6BCC0B8BEC0B9BEBFB9BFBFB9C0BFB8C0BDB8BFBBBCC2BBBBC0B8BCC2B7
BFC6B7BDC5B5BDC4B4BEC5B2BCC4B1BDC5B2BDC3B4BEC4B5BFC7B7BFC7B8BFC7B7BEC6B3
C0C6B1C3C7B0C3C7ADC3C6ABC3C7ABC3C7ADC2C7AFC4C8B2C3C8B2C3C8B1C2C8AEC1C6AB
C3C8ACC3C8ADC2C7AEBFC5AFBDC4ADBDC5ADBDC5ABBCC5AABAC3A9BAC3A8B9C3A6B5C0A3
A4AE957F837575796A61635752534B4E4F4544463C3B3E3533362F2B2D29292927232524
2527262B2F2B2E342D2F352C2D322A2E30292E2E2A2F302D2F322F2E332D2E332B2F352B
31392D2E362C282E272326231E1F1D1B1D181E211A1F241A1B2115161B1110130D0E1109
0D100811120B151811181C161519150F13100F130E131810151A1013180C13160B12140B
10120912140C141810181C15171B15181B161E23192C3322303720282D162B2C1732301F
302D212A261F2C2C26282A24
7C8E9081939882959F8495A48293A48595A68796A88797AA8595AB8495AC8597AD8899AF
899CAE8DA0AD8FA1AD8F9FAD909FAD91A0B092A0B092A0AF95A3B299A5B39AA6B59CA7B6
9AA7B69AA8B49DAAB29FABB1A1ABB2A1ACB3A1ADB4A2ACB5A1ABB6A2ACBAA3ACBBA3AEBB
A4B0BCA5B1BCA5B1BBA7B2BCAAB4BDABB4BCACB4BDAEB5BEAEB5BFAFB7BFB1B8BFB3BBBF
B4BCBEB5BDC0B6BDC1B6BEBFB5BDBDB4BDBCB6C0BDB6BFBDB6BEBCB9C1BDB8BFB9B9BEB7
BCC2B6BCC3B6BDC5B7BFC5B7BDC3B4BEC4B5BCC2B5BCC3B5BFC6B8C0C6B9C0C6B9C1C7B7
C3C9B3C3C8B0C3C8AFC4C9ADC4C8ACC3C7ABC3C7AEC4C8B1C4C8B2C3C6B2C4C7B0C2C6AE
C3C7AFC3C7B0C3C7B0C2C6B1C2C6B2C0C5B1BFC6AFBFC5ACBEC3A9BDC5A8BDC6A6BAC5A6
B7C2A5B0BBA0AAB49B9AA38D80867570746557595051544A3E3E393736333230312C2B2C
292829292A2A2C2E2C2D302D2D302B2E302931332A2B2C2427282124261F24261F272B22
2B3026292E25282D25272C252529232429222E3729262F231C241915191210120E0C0F0A
0B0E0910130E151913181D17171C1513181112170F161C11151B1013170C0F130A0E110A
0D120A0C0F070B0F0710120B0F100B1619111B1E14202516272B181E1E0D40442A211C13
38352E44473E2324212A3128
788B8F8092998293A08395A48395A48495A48696A58697A78495A78497AA879AAB899CAC
889CAC899EAB8A9DAA8C9EAB8D9EAC8FA0AF8F9FB090A0B194A2B397A5B399A5B598A3B4
98A3B59AA7B69CAAB59DAAB39EABB39EABB59EACB5A0ADB5A2AEB6A4AFBAA5B0BBA4AFBB
A4B0BDA5B1BDA5B1BDA7B2BDA9B2BDACB4BEADB5BEAFB7BFAFB6BFB0B8C1AEB7BFAFB9BF
B2BBC0B3BCC0B3BCC0B4BCBEB5BDBEB4BDBCB4BCBAB5BDBBB4BDBBB6BFBBB7C0B9B8C0B8
BBC2B7BDC2B8BEC3BBC0C5BDBFC4BCBDC2B9BEC4BABDC2B9BEC3B9BFC4B9BEC3B8BFC5B6
C2C7B5C2C8B3C0C7AFC2C9AEC3C9ACC3C8ACC4C7AFC2C6B0C3C7B1C1C5B1C3C8B2C2C6B2
C1C6B2C0C5B1C2C5B0C2C6B1C3C6B4C2C5B3C1C4B0C0C4AEBFC5ACBDC4AABEC6A9BCC4A7
BBC3A9B9C3A9B5C0A7B3BFA7B1BCA5A0AA968E96857E84765F605852504B43413E3B3835
38343035302E312D2C312D2C2D2A292927242B2A252B2B2527272124241F23251F22271E
20231C20231C232820252D24232B21232C212F3B292934231B2317141A1111150E10120D
10120B12160E171B12191E14191E14181D12171E121B2215191F13181E1212170F0D120C
0D120D0C100B070B04080B04090A040A09040B09040E0D0614150B14130A2D31201A1910
363A2E5C6A51171A131A1F16
798C9381959E8497A48396A58497A88496A68395A58495A78396A88598A98699A8879CA9
889CAA899DAB899CAA8A9CAA8C9EAC8E9FAF909EB192A0B493A0B496A3B497A5B498A5B5
98A5B59AA7B59BA9B49BAAB49DABB59EABB59EABB6A1ADB8A3B0B9A4B0B9A5B0B9A4AFB8
A4B0BAA3AFBAA5B0BAA8B2BCA8B1BCABB3BDADB6C0ACB5BEACB5BCACB6BDACB6BCAEB7BE
AFB7BEAFB8BDB1B9BEB3B9BDB3B9BDB4BCBEB4BCBEB5BDBDB4BBBCB6BEBCB8BFBBB9BFBA
BABEBABABEB9BBC0BBBCC2BBBDC3BCBEC5BDBDC5BCBCC2BCBDC2BBBCC2BABDC3B9BDC3B6
BBC1B1BDC3B0BDC4B1BEC5B1C0C6AEC1C6AEC1C6AEC0C4AFC0C5B1BFC5B2C0C6B1C1C6B1
C1C7B2C1C5B1C1C6B2C0C5B2C2C6B4C3C6B3C0C3AFBFC2B0BFC3B1BDC3ADBCC3ABBBC3A9
BCC4ACBBC6ACB7C2A8B5BFA8B6BFA8B6BFA8B5C0A7ACB7A09DA5928E97826F7361595B4B
535242474338423D35403B3437332D302D272D2A2629252224211E22211D242721232821
20261C1E24191D25191E251A212A1C212A1A1F2917212A181D2414191F11171D10151A0E
14190E171A10171A0F191C121A1E14181E14191F151C23181C23171A2217141E130E160D
0D140C0C120B0A0F06080B040809040808030707030705030607020608010709000E1205
161A0A1E24101E230F181B0B
7D919882969F8498A48497A78597AA8598AA8396A88497A98499A8869AA88699A7869AA7
889DAA8A9FAC8CA1AD8DA0AD8FA2AF90A0B092A0B393A1B693A1B594A2B495A3B399A7B7
9AA7B89AA8B69CABB69DACB5A0AEB6A2AFB6A2ADB7A2ADB8A3ADB9A6B1BAA8B3BAA7B3BA
A8B3BCA7B2BBA7B2BBA9B4BDAAB4BDABB6BEAAB4BFAAB5C1ABB6C0ACB6BEADB7BFB0B8C0
B1B8C0B1B7BFB2B9BFB4B9C0B5BBC1B5BCC1B3BDC0B3BDC0B4BCBFB8C0C1B8BFBFB8BDBE
B9BFBDB9BFBCBAC1BBBBC2BBBAC2BAB9C2BAB9C1BABBC1BDBEC4BEBDC3BDBCC2BDBEC3BD
BEC3B9BDC3B6BDC3B5BFC5B7BFC6B4C0C8B3C0C8B1BFC7B0C1C8B2C1C7B2C1C6B1C2C7B3
C3C8B4C4C8B5C0C5B4C0C5B4C2C6B4C2C7B5C0C4B3C0C5B4BFC4B3C0C5B0BFC5B0BFC7B0
BEC6AFBDC6AEBCC4ACBBC2ABBBC2ABBBC1AABAC2AAB7BFAAB7BFACB3BEA8A7B19B919885
8085736666595755494F4C404746393E3D3237362D2D2B25282621252521222320212420
20261F1C231A191F15171D131B23171A2113181E0F1E24131F25161F24171E23171C2318
1B2218191F16161B12171B111A20141C23151F26171E26161D27161B2515192214161F11
131D0E11180B0F15070C11050D0F060C0D040B0B040A0A05070904060902060901080C00
0C10021216061113050B0A01
798B957F929E8396A58497AB8395AC8599AE8599AC859AAA8498A7869AA9899CAB889CAA
8A9EAB8CA0AA8FA3AE8FA2AE8EA0AF90A0B291A2B492A3B593A3B494A5B496A6B498A7B4
9AA9B69BAAB69DACB69EADB5A0AEB6A4B0B9A4B0B9A3ADB9A4AFBAA7B2BBA8B3BAA8B4BB
A9B5BDAAB5BEABB6BFAAB6BFABB8BFABB9BFA9B6BDAAB6C0AEB9C3AEB9C2AEB7C0B0B8C1
B2B9C1B3B8BFB3B9C0B5BAC1B7BDC3B6BCC4B5BBC4B8BFC5B8C1C4BAC2C2B9C1BFB8BFBF
B8BFBEB8C0BDBAC3BDBBC4BDB9C2BABAC3BABCC2BBBEC5BEBEC4BFBFC4C0BFC4C0C1C5C3
BFC4C0BFC5BCC2C8BDC1C7BCC0C7B9C0C8B8C1CAB6C3CAB4C4CBB5C4CBB6C2C9B5C1C8B5
C1C7B6C1C7B8C0C7B8C0C7B9C0C7B8C1C8B8BFC5B6BFC5B5C0C6B5C1C6B3C3C8B5C2C7B5
C0C6B5C1C6B5C1C6B2C1C6B0C1C6B1BFC5AFBEC5ADBDC4AEBDC4B0BBC2AFB9C0ADB5BCAA
AFB8A6A1A997858A7A696D5E5C605050524643443D3A3A3537383234342E2F2F2B282927
2425252023221B201E191D191B2019191F18171D141A20151E251920261A1D241A1D231A
1E251B1E261A1C24171D25161F2715212A15232C17212A152029131E26121D25141C2314
1B22121A210E181E0D181C0D15190C13140A13140A11120A0D0F090B0F080B0F080C1008
0B0F070E12080F10090C0B05
7789957E909E8294A78394AC8192AC8495AD8296A98396A78397A58698A6899AA88A9CA9
899BA88B9DA88FA1AD90A1AE8E9EAE8D9DB08E9EB18FA1B291A3B192A4B095A5B196A5B0
98A8B398A9B499AAB49CABB49FADB5A0ACB7A2ADB8A1ACB6A3ADB7A6B0B9A8B1BAA8B1BA
A9B3BBA8B2BCA9B3BDA9B5BFAAB6BDA9B6BBA9B5BAACB6BCAEB7BEB0B8BFB2B9C1B3B9C1
B2B9C1B3B8C0B5BAC1B6B9C0B7BAC1B5B8C1B6B9C1B7BDC1B8BEC0B9BFC0B9BFBEB9BFBE
B9BFBEB9C0BEBAC2BFBAC1BDBAC0BABBC1B9BCC1B8BDC2B9BDC2BBBDC1BBBDC1BCBFC2BE
BFC3BDC1C4BCC0C4BAC0C4BAC0C6B9BFC5B6BFC6B3C1C7B2C3C6B4C3C8B6C2C7B6C0C6B7
BFC5B8BEC4BABFC5BBBFC7BABFC6B8BFC6B7C0C6B7BFC5B5BFC5B2C1C6B1C3C7B2C3C6B4
C1C4B4C1C5B4C1C6B2C1C5B0C0C5B0BEC4AFBEC3AEBCC1AEBBC1B0BAC1B0B9BFAFB8BEAE
B6BDAEB6BDADAFB5A7A3AA9C90968B7A7D7662645F54554F494A413E3F3534332E2C2A29
252125201D221B1A1F1D1F211D211F181C1A1114120F12100F131011151010150E12160F
14191013190E151B11141B0D131A0A141B09161E0B171E0A161D0A161C08161C09161C0B
141A08131807161D0A171C0C16190C14150B13140C0F100A0C0E0A090C09090C0A0B0F0B
0B0E0A0B0D0B0B0D0B0A0A07
7689947E909D8293A38494A98192AA7E8FA87F92A78094A58396A48598A58799A68798A7
8698A8879AA88A9CA98C9CAA909EAD8E9CAD8E9DB08D9EB190A1B293A4B293A3B095A4B1
96A5B595A5B498A8B49DABB69EABB69EA9B79FA8B7A0A9B6A1ABB6A2ADB5A5ADB7A7AEB7
A7B0BAA7B1BCA6B0BCA8B2BDA9B3BEA9B4BEABB5BEACB4BDAFB6BDB1B7BCB1B7BEB2B9C0
B2B8C0B3B9C1B4B9C1B4B9BEB7BCC1B6BAC2B4B9C0B3B9BEB4BABEB6BCBFB6BDBDB6BDBE
B6BDBDB5BCBCB7BCBEB8BCBEB9BDBCBABDBAB9BEB9BBC0BBBCC1BCBEC2BDBEC1BEBFC0BD
C0C1BDC0C2BDBFC1BBC0C3BCBFC3BABEC3B8C1C6B7C1C5B4C1C5B4C1C6B5BFC5B4BEC5B5
BEC4B6BCC2B8BCC2B8BEC5B7C1C6B8BFC4B6BFC4B6BEC4B4BDC3B1BFC5B0C1C5AFC0C2AF
BFC2B0C0C5B2BFC3B1BFC3B0BEC2B1BBC1B0BBC0B0BABFAFB8BDADB9BDAEB9BEAFB9BEB2
B8BCB1B6BBAEB5B9ACB3B7AAB1B7AAA8AFA39FA799939B8B858E7B585A4E3D3938373235
2B232D231B281D18241E1B241E1C241B1C2015161B1012170E11130C0F0E0A0D090E120A
10140B0C12090C13090B12070E1608131C09131C07131B04111801141C03181F06151A06
1315040F110210120411120610110810100B0F110D0E100D0A0C0A070906080A070D100C
0B0E0C0A0C0B0C0E0C0C0C09
748A917A8F987F929F8192A48091A77E8FA87E91A97E91A68195A58396A68597AA8799AC
8799AC879AAB899AAA8A9AA98C9CAB8D9CAD8F9EAF8E9FB18E9FB391A1B591A1B394A1B3
94A1B395A3B498A5B59BA9B79EAAB79EA9B69FA8B7A0A9B8A0A9B6A1AAB4A3ABB3A6AEB6
A8B0BAA8B1BCA8B1BDAAB2C0AAB3C2A9B1C1AAB2C1ACB2C2AFB5C2AFB5C0B1B7BFB2B8C1
B2B8C1B3B8C2B2B8C1B3B8C0B6BAC2B7BBC4B4BAC3B3B8C0B2B8C0B2B7BFB4B9BFB4BAC0
B5BCC1B4BBBFB5BABEB6BBBFB9BEC1B8BDBEB8BCBCB9BCBCBCBEBCBDBFBEBFBFC0BEBDC0
BFBEBFC0BFC0C0BFC0C0C0C0C0C1BFBEC0BDBEC1BDC0C3BDC0C5BDBFC5BCBDC2BABDC2BA
BCC2B7BEC3B7BDC0B5BEC2B5C2C5B7C2C5B7C0C3B5BFC2B4BEC3B3BEC3B2C2C5B3C2C4B4
C0C3B5BFC3B6BDC1B6BBC1B5BBC1B5BABFB4BAC0B4BAC0B2B9BEB1B8BDB0B9BDB1BABFB3
B7BDB2B7BCB1B6BBB0B3B8AEB2B9AFB2B9B0AFB7ADADB5AAA8B3A59AA29768666C534F5A
383042282032261F2C211B251D171F17131A1713191414181114161013121114110F140F
0F130E0D120D090E09060C060A1108131C0C121C08121C06121B03121C03141C05141A05
1216051214071214071111060F0F0811110A12120C10120B0C0E080A0D060A0C060D110B
0D100C0C0E0C0E0F0E0F0F0D
768C937C929A7F949F8194A27F91A37F91A47E90A58193A88395A98294A88595AB8999AF
8A99B08B9BB08A9AAD8A98AC8C9AAE8F9CAF909DAF929FB293A1B495A2B595A3B594A2B3
94A2B295A3B397A4B49AA7B69CA9B79DA8B89EA7B9A0A6BAA2A8B9A4A9B9A3A8B7A7ACB9
ABB0BEABB1C0AAB1C0ABB2C0ADB4C1ACB3C1ADB3C4AFB5C6AFB4C4AEB3C2B1B5C1B3B7C2
B3B6C1B3B6C1B3B7C1B4B8C1B5B7C0B6BAC2B5BAC2B3B9C1B4BAC2B5B9C2B5B9C1B6BBC3
B8BEC5B7BCC4B6BAC2B6BAC0B8BDC0BABEC0BBBFBFBBBEBDBBBFBBBCBEBCBFC0BEBFBEBE
BEBEBFBEBCBEC0BFC0C0BEC1C0BEC0C0BFBFBEBFBFBFC0BFBFC1C0BFC2BFBCC1BCBCC1BB
BCC1B9BDC0B6BFC0B6C0C1B6C1C2B5C1C3B5C1C3B5C1C4B5C1C4B3C0C3B2C2C3B3C0C2B1
BFC0B2BFC0B6BDBFB8BABEB7BBC1B9BBC0B7BABFB5BABFB1BABFB1B9BEB0B8BEAEB8BEAC
B9BEAEB8BEAFB8BDAEB6BAAEB3B8ADB4B9B0B2B8AEAFB6ABAEB5ABADB6ADA2AAA498A19A
616268332E3B3B363B31292B271E2222191D1E181A191518181718181819171817121313
1214141012120C0C0D0B0B0B0D100D12170F141A0E141B0D121B0B0F1807101806141C08
131A09151A0C15190D15170C12130A12120A11110A12130B1012090D10060C0F050D0F07
0F100B10100D0F100E0F100D
7487937D919D7E91A08094A57E91A47D8FA17E90A38092A68193A88293A98494AC8796AF
8795AF8A98AF8B9AB18B9BB08D9AB08F9AB1919CB2929EB395A1B596A1B595A1B595A2B4
98A5B698A4B49AA6B599A5B499A4B49BA6B79DA6B99FA6BAA2A7BBA5A8BCA6A9BDA7AABE
A8ABBEA9ADC0ABAFC2ACB1C2ADB4C1ADB4C2AEB4C3AFB4C4AEB4C4AFB5C3AEB4C1B0B5C1
B1B6BFB2B6BFB3B7BFB2B5BFB2B6BEB4B8C0B4B9C0B2B8C0B4B9C1B6BAC1B7B9C1B7B9C1
B8BBC1B8BBC1B7BAC0B7B9C0B7BABEB8BCBEBABEBDBABEBABABFB9BCC0BABCC0B9BDBFB9
BCBEB9B9B9B6BEBEBABEBFBBBEBEBBBDBDBBBEBFBDBEC0BEBDBFBEBCBFBDBCC0BBBBBFB9
BBC0B7BCC0B4BEC1B5BFC0B4C0C0B6C0C1B7BEC1B6BDC2B4BFC2B3BFC2B1BFC1AFBDBFAD
BCBEAEBDBEB1BCBEB5BABFB7B9C0B7B9C0B7BAC1B5BAC0B3B9BEB1B8BCAFB7BCADB8BDAC
B8BFACB9BFABB9BEABB7BDADB7BCAFB6BAAEB4BAACB3B7AAB2B7ACAFB5ACADB5ABABB4A8
A0AA9D7C80766C6D6233292B3127282C2123251D1E1F17191C16171B17171B1716181414
151012141012130F110D0B0C0E0E0D141611171D13171D11171E11161D0E171E0D161D0C
13190B141A0D14190E13180C12150C0F120B0F110C11140D12150B0F13070B0E030B0B02
0C0C040D0D050C0D060E1008
7586937A8C9C7D8FA27D8FA57C8DA47B8CA27D8FA57F91A78092A88192AA8494AC8695AD
8795AF8A99B18998AF8B9AB28E9CB48F9DB4909DB4909DB4929FB694A1B795A1B994A0B7
96A1B797A3B698A4B697A3B399A5B59AA7B79DA8BA9EA7BCA1A9BDA3A8BDA5ABBFA5A9BF
A5A9C0A5AAC0A6ABC0A8ADC0A9AFC1AAB2C2ABB2C2ACB4C4ADB4C4AEB5C3ACB5C1AEB7C1
B0B9C3B0B9C1B0B8C0B1B8C0B1B7BFB2B9BEB2B9BDB2B9BFB3B9C1B4BAC2B5B8C1B6B9C2
B8BAC3B7B9C2B8BAC1B8BAC0B7BABFB7BCBEB8BFBEB8C0BBB7BEB8B8BEB9B8BEB8B9BFB7
B9BFB8BABEBABBBFBBBAC0BCBBC0BDBBBEBABBBFBABBC1BEBCC1C1BBC1BFBAC1BCB9BFB9
B9BFB8BBC1B9BCC2B9BDC0B9BFC0BABFC0BCBCBEBABBBFBABBC0B8BDC2B6BEC1B4BDC0B4
BCC1B4BBBFB5BCC0B9BCC2BBB9C0BBB8C0B9B7C0B7B6BEB6B7BCB5B7BBB4B6B9B2B6BAB1
B6BAAFB7BCAFB6BBAEB5B9AFB4BBB1B4BAB1B2B9AFB2B7AEB1B6AFAFB5B0ADB4AEABB2AB
AAB4A8A9B3A4A0A999534D4D382F31332B2C2E2526271E1F251D1E221A1D1E171A1A1517
191316171419161315100F0F0C0D0B0F120B13180D171D111A21131C23131B2111171D0D
141A0D141A0F12180E11160C10140C0D110A0F140C11150F0F140A0F13080E11060E1005
0E10050E0F040E10040F1105
7889967C8E9E7E91A67D8FA87D8FA87B8CA77E90A78092A78092A68091A78494AB8694AC
8795AC8A99AF8897AD8998AD8C9AB08E9DB38F9EB48E9EB48F9EB491A0B692A0B7929FB7
93A0B8939FB794A0B695A2B599A5B69AA6B798A3B897A3B79CA6BAA0A9BBA1A9BBA3AABD
A4A9BFA4AAC0A4AAC0A5ACC0A6ADC0A6AFC0A8B0C2ABB3C3AAB2C3ABB2C2AAB3C1ACB5C1
AEB7C3B0B8C2AFB8BEB1B8BDB2B8BEB2B9BFB1B8BDB0B8BEB0B8BEB1B9C1B1B9C1B2B9C2
B4BAC3B3B9C3B4B9C1B6BAC2B5BAC2B3B9BFB5BCBFB5BDBDB5BCBBB5BBBAB6BDBCB6BEBD
B6BEBDB6BCBBB7BDBBB8BDBCB9BFBDB9BEBCBABEBDB9BEBDBABFC0BABFC1B8BFBEB8C0BC
B7BFBAB8BFBAB8BDB9B9BDBABCBDBDBBBCBEBABDBFBABDBFB9BDBDB9BDBAB9BDB8B8BCB7
B9BCB7B9BDBAB9BDBAB8BFBCB9BFBEBAC0BDB8BFBAB6BDB8B7BBB6B8BCB6B7BCB5B6BDB6
B5BCB3B5BDB3B4BCB2B3BBB2B3BCB3B2BBB3B1B9B3B1B8B2AEB5B0ABB3AFAAB2AEA8B1AC
A8B2ABA6B0A9A7B2A88F958E6564653C353B3A3233352E2F2F282C272028201B24252229
28262B1A192215161D0F11130B0D0D0B0D0B0E120C141811181E161B21171B2016171B11
161A11161A141015100E120D0F130D10140D11160F12160F0F130B0D11080D10090D1009
0E12090E12080C0E04070801
7686997A8BA07C8DA77D8EAA7D8DAB7B8AAA7C8DA87E8FA87E8FA78190A78492A98A97AE
8A97AF8997AE8B9AAF8D9BAF8E9CAF8E9BB08E9CB3909FB68F9FB58FA0B492A1B694A2B8
94A1B9939FB8939EB795A0B598A3B79AA5B99AA5B998A4B99BA6BB9DA7BAA0A7B9A1A8BB
A2A7BEA6ABC2A4ACC4A3ABC2A3ACC0A3ACBEA5AEBEA7AFBFA8B0C0A9B2C0A9B4C1ABB6C1
ACB4BEADB4BEB0B6BEB2B7BFB2B6BCB2B5BDB2B6BEB1B7C0B0B7C2B0B8C3B0B9C2B1B7C2
B2B8C3B0B7C3B0B6C1B1B8C0B4B9C2B3BAC3B4BAC2B4BBC0B4BCBFB5BCC0B6BEC1B6BEC2
B5BCC0B6BCBDB7BCBBB8BBB9B9BCB9B9BDBBB9BCBBBABCBABBBCBCBABEBEB9BEC0B7BEBF
B6BEBCB6BEBAB7BDBBB9BDBCB9BCBDB9BDBEBABDBDB9BDBDB8BBBDB8BBBBBABDBCB8BBB9
B8BCB7BABDB9B9BCBAB7BBBAB6BABBB7BBBBB8BCBAB7BBB7B7BBB4B7BBB3B4BBB1B2BBB0
B2BBB1B3BCB3B2BCB4B1BBB1B1BBB1B0B8AFB0B8B1B1B9B3B1B9B1AEB7AFADB4ACAAB1AC
A9B2ADA8B2ADA7B1ACA6B0A99BA59D6F7271504D514D4B4D48454935313A28252F2A2B31
2B2D321E20271B1E24181B1C13161410141011140F141711171B151D1F191C1D19191914
1919131A1D1816191615181314171214180F1419101519111215100E110C0C0F0B0F120F
1115100D110C080B06040501
7282997787A17C8CA87C8CAB7D8CAB7D8DAB7D8EA87C8DA47D8EA38090A28391A38795A9
8996AC8694A88796A78B9BAB8E9BAD8C99AF8C99B28D9CB58E9DB48F9EB2919EB3939FB4
95A0B6959FB7959FB697A1B599A3B498A1B599A3B79DA7BC9EA8BC9DA7B9A0A8BAA1A7B9
A2A8BBA4AABFA3ABC1A2ABC1A2ABC1A2ACBEA5AEBEA6AFBFA8B1C0A8B0BEA9B2BDACB4BE
ADB5BEAFB6BFB0B6BFB1B4BEB1B3BCB2B3BDB4B5BFB2B6C0B1B7C0B2B7C1B3B9C2B4B8C3
B5B7C4B3B7C4B0B8C5AFB6C1B0B7C0B1B7C0B2BBC3B2B9C1B2B9C0B3BBC0B4BBBFB4BBBF
B4B8BCB5B8BAB7BAB8B9BAB8BABBB9BABABBBABABBBBBBBBBABABAB9BABCB9BCBFB6BABC
B4B9B8B4BBB8B6BCBBB6BBBCB7BBBEB8BDBFB8BCBDB9BDBDB8BABBB7B9B9B8BBB9B8BAB7
B8BBB7B8BBB6B8BAB6B8B9B7B8B9B8B8BAB9B6B8B6B6B9B5B5B8B3B4B9B3B2B9B2B0B8B0
B1B8B0B1B9B1B1B9B1B1BAAFB1B9AEB0B8ADAFB7ACB0B6ADB0B6B0AEB5B0ADB5ADAAB1AC
A9B0ADA7B0ACA6AFAAA6B0AAA7B1AAA0A9A48C9094898E92838B8C575D6230333B252A2E
22262A1F21261D1F221D201C24281C1D20141A1B1117180F1818121A18141C1A161D1A17
1D1C191E1F1C1B1D1A1A1C18191B17151813151811171C141317111114100D0F0E0D1110
0F13110D100D070906010201
7384977889A07A8BA67A8AA87B8BAA7C8DAA7C8DA87C8EA67E8EA57E8FA38192A38495A4
8595A68695A78594A68896A98998AC8896AE8A98B18C9AB18D9DB18E9EB1919FB2939EB2
959FB498A1B79AA4B899A3B69AA2B59AA2B799A1B89AA5BB9BA7BA9BA6B99EA6BAA1A9BA
A2A9BCA1A8BEA0A8BFA1A9C0A1A9C0A3ABC0A4ACBFA5AEC0A7B0C0A6B0BDA7B1BDAAB2BE
ACB4BEADB5BFAFB5BEB1B6BFB1B5BEB2B6BFB1B5BEB1B6BFB2B5BFB2B6BFB2B6C0B5B7C2
B6B8C2B3B7C2B2B8C3AFB7C1AFB7C0AFB6C0B0B9C0B0B9C0B2BAC0B2BABEB3BABDB4BCBE
B5BBBFB6B9BDB6B9BBB8BABDB8BABDB6B8BDB7B7BDB9B9BDB9B9BCB8BABBB6BBBCB6BBBB
B4B9BAB3B9BBB3BABCB4BBBDB5BABDB5BABEB7BBBEB7BBBDB6BBBBB5B9BBB3B8BAB4B8B8
B5BAB8B7BBB9B8BBB8B8BAB8B8B8B7B8B9B8B5B6B5B5B6B4B4B5B4B4B8B6B2BAB6B0B7B4
B0B8B2AFB9B2AEB8B1AFB8B1AEB7AFAFB6AEAEB4ADAFB6B1AEB4B4ADB3B4ABB3B2AAB2B0
A9B1B0A7B0AFA5AEAEA5AEACA4ACABA3ABABA4ACAEA1ABAE9DAAAB91A3A04C545D262A37
292E3623282E1F23261E231E23271B25281B2427192022161C1D171B17161C18161F1E1A
1F201C1F211C1D211D1D211B1A1E1A171C18171C16191E17161B141318110F120E0A0D0B
0A0D09080A07040503010201
748796788C9F7B8CA67A8BA77B8CA87B8CA77C8DA67D8DA77F8EA88192A98294A88395A7
8495A68594A78795A98896AB8796A98896AB8A98AD8C9AAF8D9CB08D9CAF8E9CB0919DB2
939FB597A2B797A1B697A1B798A2B89BA4BA97A1BA98A3BA99A4BA9AA5B99CA7B89EA8B9
A0A9BB9EA6BBA0A8BCA1A9BFA4ABC1A5ABC2A4ABC1A7AEC3A9B0C4A9B0C3A9B1C2A9B1C1
AAB1C0ACB3C2ADB4C1AFB4C0B0B5BFAFB6BFAEB5BDAEB6BDB0B6BDB1B5BDB1B6BEB3B7BF
B2B6BEB1B6BCB0B5BCB0B6BCAEB5BCADB6BEAEB7BFAFB8BFAFB8BFB0B7BDB2BABCB2BBBD
B4BBBEB5BBBFB4B9BDB4B9BEB4B9BEB2B7BEB3B6BDB5B7BEB6B9BEB6BABEB4BABEB4BBBD
B4BABDB4B9BEB4B8BCB5B9BDB7BABDB6B9BCB5B9BDB5B9BCB2B8BAB1B8B8B1B8B7B2B9B9
B5BBBAB7BDBBB8BDBCB8BBBCB7BABAB7B9B9B5B7B7B3B5B5B2B5B6B2B6B7B0B7B9B0B8B8
AFB8B6AFB9B6AEB8B4AEB6B3AEB5B3AFB5B4AEB4B2AEB5B2ACB3B3ACB3B4A9B1B2A7AFB1
A6B0B1A5AFB2A4AFB1A4AEAEA3ACACA1AAABA3ACACA0ACAA9DAAAA9BAAA9879697697379
4A505A393D492D2F3D2B2E38484F4D5964583539362C2E2D2121231A161B1813181C1B1A
1E1F1A1F221B1C221A1A2019181E18161B17171B16171C14161B1212160F0B0E0A080907
080806060504040201040100
7589977A8FA07C8FA67D8FA97C8CA77B8BA67E8DA6828FA98390AB8290AB8293AC8191A9
8292A78492A88694AC8796AE8898B08899B08798AF8A9AB08C9CB28C9AB28D9BB48E9DB5
8F9DB4929FB594A1B695A2B896A2BA97A3BB96A2BB98A4BB98A4B998A4B89BA7B89EA8B9
9FA9BA9FA8B99FA8BAA1AABEA1AAC2A3AAC4A4ABC5A4ABC3A5ADC2A7AFC3A7AEC2A9B0C3
A9B1C4A9B1C3AAB3C3ACB3C3AEB5C3AEB5C3ADB6BFADB6BCAEB6BBAFB6BBAFB6BDB1B7BE
B0B6BEAFB6BBAEB3BBAFB3BCB0B5BEAFB6BFAFB6BFB0B6C0B0B6C0B0B6BFB1B8BFB0B8BE
AFB7BBB0B8BCAFB7BCAFB6BCAFB7BCAFB8BDB1B9BEB4BABFB4B9C0B5BAC2B3B9C0B2B9BF
B4B9BEB5B8BDB4B7BCB4B7BBB4B8BAB4BABBB4B9BCB5BABCB2B8BAB1B7B8B2B8B7B4BAB8
B4BABAB5B9BCB6BABCB4B9BCB3B9BBB5B9BAB5B8BAB3B7B9B3B7BBB1B5BAAFB4B9AFB4B9
AEB5B8ACB5B7AEB6B7AFB8B8AFB5B7AFB5B6AEB5B5ABB3B3A9B1B1A8B1AFA7B0B0A7B0B1
A5AFB0A6B0B2A7B2B2A6B1B1A4AFAFA0ABACA0ABABA0ABAB9FADAD9CABAB9BA8A899A6A5
879295767E865E617157596B848F918A97936B747568736E36373A150E1A18131D141218
12101314131215161214151213161313141014151014160E12150A0E0F07070703090705
0C0B070A0806070503070403
718095798AA17B8CA67C8DA87B8CA87A8AA77E8CA8808DA9818DAB828EAA828FAB818EA9
818EA88390AA8492AE8493B08596B28697B38798B08A9AB08C9CB38B99B38D9AB68E9AB5
8F9BB5909CB5929DB595A0B996A1BC96A1BD98A3BD99A4BD99A4BB99A3B99AA4BA9DA6BA
9FA7BBA0A8BDA1A8BFA2AAC19FA8C2A0A8C4A1ABC4A1ABC3A2ABC1A5ADC2A5AEC3A7AFC4
A7AEC4A6AEC3A9B1C4ABB2C4ADB4C4ACB4C1ADB6C0ADB6BEACB5BBAEB6BDACB4BDADB5BE
ACB4BDADB3BDAFB4BDB0B5BFB0B5C0B0B5C0B0B5BFB1B6BEB1B5BDB2B5BDB3B7BEB1B5BD
AFB6BCAFB7BCB0B8BEB0B7BDB0B7BBAFB8BBB1B8BBB3BABDB3B9BDB4B9BFB3B8BFB2B7BF
B3B7BFB3B5BCB3B4BCB3B5BBB3B7BAB4B9BAB5B9BAB5B8BAB4B7BAB4B9BCB5BCBAB5BAB8
B5BABAB5B9BCB3B7BBB3B7BCB3B7BBB4B7BAB3B6BAB3B4BAB4B6BCB1B5BAB0B4BBAFB4BB
ADB4B9ACB5B7AEB6B5B0B8B4B0B7B3B0B6B1AEB4B1ACB3B1A8B1AFA8B1AFA8B1B1A8B1B4
A7AFB3A8B0B4A8B0B4A5AFB2A4ADB1A2AAAFA0A9ADA0ABAF9FABAF9EAAAE9BA6AB9BA6AB
9AA4AB9AA4AA949CA38F989E919A9E929D9D919D9B92A09970797424212D1D192618141F
15131A0F0C121311131D1C1A19171616161114150C15150C12120B0E0D090A09060A0A06
0D0D080C0C06070501080501
6D7A917988A07B8AA77B8AA97B8AAA7A8AA87C8BA77F8CA7808DA7828EA8818DA7818DA8
828FA98490AA8491AB8592AC8695B08496AF8395AC8597AD8899AF8B9AB08C99B08E98B0
8F99B2909AB4909BB6929DB8939EBA96A0BC97A1BD99A3BD9AA5BC99A3BA9CA5B99CA4B7
9FA7BBA0A6BD9FA5BDA2AAC1A2AAC1A1A9C2A2ABC3A2ACC3A3ACC1A2ABBEA4ABBEA6ADC0
A8AEC1A8AEC0A9B0C0A9B2BFAAB2BDAAB2BBABB3BCAAB3BCAAB3BCACB4BDABB2BDABB1BC
ACB3BDAEB3BEAFB5BFB0B5C1AFB3C2AFB3C1AFB5C1AFB4BFAFB4BDB0B4BDB2B6BEB2B4BB
B0B3BBB1B6BEB1B6BEB2B6BDB0B6BCAFB4BAB2B6BCB1B6BCB2B8BCB1B7BAB1B6BBAFB5BB
AFB4BBB0B4BBB2B4BCB3B5BCB4B5BAB4B6BAB1B5B8B2B7B9B2B7BAB2B9BBB3B9BBB3BABB
B4B9BCB3B6BBB3B5BBB2B4BBB2B5BCB0B4BAB1B5BBB1B4BBB1B5BCAFB3BAAFB4B9AFB5B8
AEB5B6ADB5B5ACB5B3ACB5AFACB4ADABB3ACADB4AFADB3B1AAB2B2A7B0B1A6AFB0A7AFB1
A7AFB2A6ADB3A5ABB3A6ABB2A7ACB2A5ABB1A2A9B0A1A9B19FA8B19EA8AF9AA4AC9CA5AC
9CA3AB9DA4AC9AA3AA98A2A897A0A697A0A5969EA4919B9E8C98966973734F545634363A
2220271A171F19151B2C2C2B2826262222201718141514101514121414141010120D0F10
0C0E0D0C0F0A080904060500
71809178879D7C8BA57E8CA97C8AAA7988A77B8BA67E8EA48190A4818EA37F8DA37E8DA5
7E8DA78090A98191AA8393AB8594AD8393AD8392AC8494AC8492AA8795AB8B97AC8C97AB
8E98AE8E98B08E9AB3909BB3929DB5969FB8979FB897A0B897A1B698A2B49BA5B49BA4B5
9DA5B79DA4B99DA4BB9EA6BC9FA6BD9EA6BDA1A9BFA1AABFA2AABEA1A9BBA4AABAA6ACBA
A7ADBCA7ADBDA5ACBBA7AEBAA8AFB8AAB1B9AAB0B9A9B0BBA8AFBAA8AFBCAAB0BBAAAFBA
ACB2BCADB3BDADB2BEADB1BEACAFBEABAFBEADB0BEADB1BEADB2BDAEB2BCADB2BBAFB3BB
AFB3BBAEB2BBAEB2BBAFB3BAB0B4BAAEB2BAAFB3BBB0B5BCB0B6BBAFB4BAAEB3BAAEB3BB
AEB3BAAFB3BAB1B4BBB1B2B9B2B3B9B2B3B9B1B4B9B1B4B9B0B4B8B0B5B9AFB5B9AFB3BA
AFB3BAAEB3BBAFB3BAAFB4B9AFB3B9ABB1B7ACB2B7ABB0B6ABB1B7ABB0B7ACB1B9AAB1B6
A9B1B4AAB1B3ABB3B2ABB3AFABB4ADAAB2ADAAB1AEAAB1AFA8B1B1A6B0B0A4AEB0A4ACAE
A5ACB0A6ABB2A6A8B3A5A7B2A4A7AFA4A7AFA4A8B1A2A7B29FA5B29DA5B09CA5AD9AA3AB
9AA1AA99A0A8979FA7969EA7969DA6959DA5949CA4919AA28F999F8B97998895927A8581
54575C40424A3A3B4237373D3B3D3F29293125262D24252A24272818181C14141A0C0E14
08090E070808040603040501
70808D778798798AA07B8BA57B8BA67A8AA4798AA17C8BA07D8BA07E8BA17D8AA17B8BA3
7B8BA47D8EA67F90A88091A98392AC8392AC8592AC8694AC8593AA8794AB8B97AD8D97AE
8D97AF8B95AE8C95AE8D97AF909AB2949DB4969DB4979EB5979FB4969EB298A2B398A3B4
98A1B598A1B69AA3B99CA5BA9DA6B99CA7B99EA8BC9DA7BCA0A8BDA2AABDA3AABBA5ACBB
A6ACBCA5ABBAA3AAB8A6ACB9A7ADB7A8AFB8A9AFB8A8AEB9A7AEBAA6ADBBA7ADBBA8AEBA
A9AFBBA8AEBAA8ADBBA9AEBDA9ADBBA9AEBCABB0BDACB0BCACAFBCACB0BDABB0BBABB0BB
ABB0BAAAAEB8AAAFB8ADB1B9ADB0B8ADB1B7ACB1B7AEB3B8AFB3BAAEB2BAAEB1BAACB0B8
AEB1B9AEB1B9AFB3BAADB0B8ADAEB7AEB0B8B0B1BAB0B1B8ADB1B6ADB3B7AEB4B9AFB4BB
ADB1BBABB0BBADB2BCAAB1B8AAB1B6A9B0B4AAB1B6AAB1B6A9B0B7A9AFB8ABB0B8AAAFB6
AAAFB5ABB1B5AAB0B4A9B0B3AAAFB1A9AEB0A7AEAEA5ACACA4ACADA6AFAFA4ADADA2ABAD
A3AAAFA2A8AFA3A8AFA4A7AFA1A4ADA1A5ADA0A5AE9EA4AE9CA2AC9CA3AB9BA3A996A0A7
979FA8969EA6979EA6969CA5959CA3939BA090989E8F989E8F989D8B959A8B94988B9597
848E907A8488737E816770765B646A4042514C525E5A65694A52541615221717200A0B14
04050D020306010201020201
6B7C86748693798A9E7B8CA3798AA47A8AA4798AA3798AA17A8AA17C8CA37D8CA57C8CA6
7B8BA67C8CA57E90A67F90A88291A98392AC8393AC8394AB8594AB8694AA8A96AD8B96AE
8C97AF8A95B08B96B18B97B18C98B2909CB4929CB4939CB5959DB5919BB4919DB4929EB4
929EB4949FB596A1B897A3B999A6BA9AA7BA9BA7BA9BA5BC9BA5BD9DA7BEA0A9BDA1A9BB
A4AABCA6ABBDA4AABCA4AABBA4ABBAA4AAB9A5ABBBA5ADBDA5ADBEA5ADBDA4ACBCA5ADBB
A6AEBCA5ADBCA5ABBCA7ADBEA7AEBEA8AFBFA8AFBFA8B0BDA8AEBDA8ADBCA8ACBAA8ADBB
A8AEB9A9ADB8AAAEB9ACB0BBACB0BBACB1BBABB0BAABB1BBACB1BCACB2BBABAFB9ABB0B8
AAB1B8AAB0B7ABB1B7ABB0BAAAAEBBABAFBBACB0BBACAFBAA9AEB8A8AEB8A9B0BAACB2BC
ACB1BCABB0BCACB2BDA8AFB9A7AFB7A9B1B7AAB2B9AAB2BBA9B0BBA8AFBAA8AEB8A7AEB6
A7ADB4A8ADB4A9AEB5AAB0B7A8AEB4A9AEB3A7ADB4A5ABB3A2A9B1A4ABB1A4ABAFA3AAAF
A2A8AFA1A7AFA1A7B1A0A7B19FA6B09FA7B09DA4B099A1AD98A1AA98A0AA98A2A996A1A9
96A1A995A0A995A0A8959DA7939BA4939CA4919BA2919B9F909A9D8E989B8E979A8C959A
899399869095838E92818D917C898F79858C79868F7A8790728087434A593F4A501B212C
070B17060A10030507020203
6B7B8372839077899A7A8B9F798AA37889A47889A67788A57889A6798AA57A8BA47A8AA4
7A8BA67B8BA57D8FA67E8FA68191A68493A88493A98293AA8294AA8495AB8795AC8995AD
8793AE8693B08794B18895B38996B28B99B28D99B38E99B68F9AB78D9AB68E9BB78F9DB8
8E9CB5909DB6929EB893A0BA93A1BB92A1B996A4BA99A5BC9AA6BD9AA5BD9FA9BD9FA8BA
A0A7BBA3A8BCA4AABDA3A8BDA3A9BDA3AABDA5ABBEA3AABDA3A9BEA4ACBEA3ACBEA3ABBD
A4ACBCA3ACBDA3AABEA4AABFA7ADC1A6ACBFA5ACBEA5ADBEA5ACBDA7AEBDAAAEBCA9ADB9
A8ADB8A8AEB9AAAEBAABB0BBABB0BDABAEBFABAFC0AAB0C1AAB0C0A8AFBFA7ADBBA6ADB9
A7AEB9A8AFB9A7AEB7A8AEBAA8ADBCA8ADBDA9AEBFAAB0BFA9AFBDA7AEBBA6ADB9A6ADB9
A7AEB9A7AEBAA9AFBAA8AEBAA7ADB9A7AEBAA7AFBBA8AEBBA7AEBBA6ACBAA7AEB9A6ACB6
A5ACB5A6ACB4A5ABB4A5ABB5A6ACB5A6ACB5A5ABB5A4AAB5A2A8B3A1A7B2A1A7B0A1A7AF
A0A6B0A0A6B3A1A7B69EA5B59EA6B59DA6B49AA4B298A1B098A2AF97A1AE969FAC94A0AA
93A0A8929EA7929CA6919AA7919AA7909AA58F9BA38E9AA08D999D8C979B8C979C8B969B
89959A869194838F93818F92808E927E8B917D89937B88927A8890748289708083566768
242E37090E1803070D010206
697B82758791798A9A798A9E7989A47686A57382A37183A37285A47588A4778AA3798AA3
7989A57B8CA77D8FA77E8FA48091A28292A28391A48190A78192AB8192AB8493AB8694AC
8794AE8793B18592B28693B48795B18996B08C98B38D97B38F99B78F99B88F9AB9909BB9
909BB4909CB3929EB6929EB6919FB7919FB793A1B898A4BA9AA5BB9AA4BA9DA6BBA0A9BC
A1A8BAA1A7B9A2A8BBA3A8BDA3A8BFA2A7BEA3A8BEA1A7BDA1A7BEA4A9C0A3AAC0A2AABF
A2ABBCA2ABBCA3A9BEA4A9BFA4AABDA3AABCA6ABBBA6ACBCA4AABBA5AABBA6ABB9A7ADB7
A7ADB6A8AEB8A7ABB8A7ABBAA7ACBFA9ADC1A9ABC1A9ABC2A7AAC0A5A9BFA4A9BDA5AABB
A5ABBAA7ADBAA7ABB8A6A9B7A7AAB8A7AAB8A7AABBA8ABBBA7ABBBA5ABBAA4AAB9A5ABB8
A6ADB8A6ACB8A6ACB8A7ACB9A5AAB7A5ABB7A6ABB7A6ACB7A5ABB7A4AAB6A5ABB6A6ABB5
A5ABB5A6AAB4A4A9B4A1A7B4A1A8B49FA7B2A2A8B2A2A8B49EA5B29EA4B19EA4B09DA3AD
9DA3AD9FA5B0A0A4B49CA1B49AA1B4989FB2979EAF99A1B098A0B1969FAF95A1AE939FAB
919EA8929DA7929BA8919BA88E99A68C98A38D9A9F8B989B8A989A8B969C8A959D88939C
88959B828E94818D92818F93828E95808B95808A947D8A917B898D798689768185788685
5A67681619270C0D17090712
6C7D8A7587967B8C9E7B8AA37989A87787A87385A67487A57488A3778AA2788AA37B8BA5
7C8CA77C8DA98092AA8092A78092A48192A58290A68392AB8393AE8192AE8293AD8392AB
8694AD8693B18693B38694B28796B08B99B0909AB18F97B09098B38F99B58F99B6909AB5
919BB3939CB2939DB2939DB394A0B494A1B495A1B498A3B69BA4B99AA3B99BA4BA9DA7B9
9FA8B8A2A9BBA2A7BBA1A6BDA4A7BFA3A8BEA1A8BDA0A8BCA1A8BBA3A9BEA4A8C0A3AAC0
A3AABEA4ABBEA3A8BCA5AABDA6ACBDA3ABBAA5ACBBA5ABBAA5ABBAA4A9B8A3A9B6A4AAB4
A4ACB4A4ABB5A5ABB7A6ABBBA6ABBEA5AABFA5A9BFA6AAC1A5AAC0A4A9C0A5AAC0A6AABD
A6ABBBA8ADBAA8ABB9A7A9B9A8ABBAA9ACB9A9ACBAA8AAB9A8ACB9A7ACB9A6ABB8A5AAB8
A5ABB7A6ACB8A5ABB9A5ABB9A6ACB8A7ADB8A7ADB7A8ADB7A8ADB8A8ACB8A8ACB8A8ABB6
A7ACB5A6ABB4A4AAB4A2A8B4A0A9B39FA9B49EA7B39DA5B29DA5B29DA6B39EA6B39DA4B0
9DA2B09FA5B19DA3B49CA2B69BA2B699A1B399A1B099A1B099A1B197A0AF949FAD929FAC
909BAA909CAA919DAB909CAB8D9AAA8A9AA58999A089999F88979C8A989D89959D87949C
86959B829195828F92848F93848E95828B96818B967D889279868D7A868A798388798286
788486545C66373B4B2F3242
69798B7485987B8CA27A8BA47A89A77987A87686A67689A5788CA47B8DA47B8CA57D8CA6
7D8DA77E8EA97F8FA98090A78192A58494A88390A98391AB8392AD8292AE8394AF8494AE
8695AE8895B08895B08894AF8A97AF8D99AF8E98AE8E97AF9098B19198B39199B59199B3
949BB3959CB4949CB4949DB495A0B595A1B298A3B29BA4B59CA4B89CA5BC9CA5BC9DA5BA
9EA7BBA1A9BDA1A7BCA1A7BDA2A8BEA2A9BEA1A9BEA1AABEA2AABFA3AAC1A3A8C1A2A7C0
A3A8BFA3A9BDA3A8BAA5ABBBA5ACBCA4ABBBA4AABBA4AABBA5ABBDA2A9BBA1A8B9A3AAB8
A4ABB7A4ABB7A4ABB7A5ACBBA5ACBEA4ABBFA4AAC0A4A8BFA5AABFA5AAC1A6ABC3A6ABC0
A6ABBDA7ACBDA8ACBEA9ACBFAAADC0AAADBFA9ACBDA9ACBAA9ACB9A8ABB9A7ABBAA5AAB9
A5AAB9A5ABB9A5ACBDA6ABBCA5ABBAA5ABBAA7ADBCAAAEBEAAADBDA8ACBDA7ACBCA6ABB9
A5AAB6A4AAB5A4AAB6A3ABB7A1AAB59FA9B49EA7B39DA5B39CA5B29DA7B39EA7B39DA6B3
9CA4B29DA6B39BA4B39AA3B498A0B497A1B299A3B299A2B197A0B097A0B295A1B2929FAF
909DAD909CAA919CA9909CA98F9AAA8C9BA88A9AA489999F88989B8B9A9B8A9A9C88999B
879899859595859394859194848E94848F97828D987F8B987B89957C88937D89917C858D
79838A7682886C7980647478
6574897183997789A27789A37889A5798AA57688A57688A47487A27788A37B8AA57B8BA4
7C8CA67D8EA77F8FA8808DA68391A78693AA8491AA828EAA818EA9818FAA8492AE8593B1
8694B18795B28794B28996B18C98B18C97B08C97B08C96B18F97B18F98B29199B49299B4
949CB4949DB6929BB5929BB3939EB394A0B295A1B297A2B29AA4B698A3B999A4BA9BA5BB
9BA5BA9AA4B99BA3BB9DA6BE9EA7BE9DA6BE9EA5BF9FA6C09EA6C2A0A7C39FA8C3A0A6C2
9FA6C1A1A7BFA3AABEA4ACBFA3ABBBA4AABAA4AABBA3AABDA4AAC0A2A8C19FA6BF9FA7BE
A0A9BCA2ABBBA2ABB9A2ABBBA2A9BCA1A8BDA1A7BDA3A8BDA5A9BEA5A9BFA6AAC3A5A9C2
A5AAC0A4A9C0A3A8C0A5A9C0A6AAC1A5A8C1A6A9C1A6A9BEA5A8BDA4A7BDA4A8BDA3A8BC
A3A9BCA4A9BBA4AABEA5ABBFA4ABBFA4ACBEA3A9BDA4A9BDA5A9BEA3A9BCA3A9BDA2A8BA
A3A9B9A4ABBAA3AABAA1A9B9A0A9B89FA7B59FA6B5A0A7B79EA6B69EA7B69CA5B59AA2B2
9AA4B19AA4B299A3B197A3B095A1B095A1B196A0B1969FB1949DAF949EB096A1B2929FAF
909DAD909DAB8F9AA88C97A48B97A48B97A48B98A48998A188979D89979B87969A849399
829297829296829195828F94818D93818D96808D977E8B957C8A947C8A947C89947A8691
76838C7583897181856C7E7D
6372896F829A7489A3768AA77689A77789A67687A57585A47485A47687A57989A57A89A5
7B8BA57D8DA68290A88390A78491A78794AB8591AA8390A98390A98290A8828FAB8591B0
8691B28792B38791B28792B18A95B48A94B28C96B18E96B39095B49096B49197B59299B7
929AB5919AB5909AB5919BB5929DB5929DB493A1B493A1B396A3B695A1B896A2BB97A3BD
98A2BB9AA4BB9CA4BC9DA4BE9CA4C09BA4BE9CA4BE9DA6BF9EA6C19DA6C19DA5C19EA6C2
9FA6C29FA6C0A1A7BEA3A9BEA2AABDA3A8BBA3A8BBA1A7BCA2A8BEA3A8C2A1A6C2A0A6C1
A1A8BFA1A9BFA1A9BEA1A8BDA1A7BEA0A7BEA0A6BEA4A9C0A4A9BFA5A9BFA4A8C1A4A7C1
A3A7C2A4A8C3A3A6C2A4A7C3A6A9C5A4A7C4A4A8C4A4A7C3A3A7C2A4A9C3A4A9C2A2A7C1
A0A7C0A1A9C0A2AAC0A2AAC0A2ABC1A3ABC0A1A8BDA1A9BCA2A8BCA1A8BBA1A6BCA1A7BB
A2A8BBA2A9BBA2A7BAA2A7BAA2A8BBA0A6B89FA4B79FA5B79FA4B79EA5B79CA5B699A2B3
99A2B29BA3B39AA2B298A1B196A0AF96A1AF969FB0969FB1969FB0959EAE939DAD919CAC
8F9CAC8F9CAB8E9CAA8D98A78B97A48B97A48A96A28A95A18A95A089949F87929D85919D
83929D84939C839299829097818E967F8C987E8C997C89967A87947A879378859277848F
74838C7382897182846D7F7D
67778B70829A7286A27588A87588AA7386A97183A67183A67486A77789A8788AA5798AA5
7B8BA47C8CA57E8BA5818EA78390A98591AB828EAA818EA9838FA98491AA8491AA8794AD
8792AD8890AF8890B08791B08993B08C95B18E97B19097B39197B69096B69095B69197B8
9098B68F98B59099B6919BB6919DB7909CB7929EB5929EB3929DB3929EB596A1B996A2BC
959FBA99A2BC9BA3BC9BA2BC99A0BE9BA4C09AA4C09AA5C19CA6C09DA6BF9DA6BE9DA6BE
9DA5BE9EA6BE9FA6BDA1A7BCA1A7BCA1A6BCA1A7BCA1A7BCA0A6BCA1A6BDA2A7BFA1A6BF
A2A6BFA1A6BF9FA5BE9FA6BE9FA4BE9FA5C09FA5C1A2A9C2A2A8C0A2A7BFA2A8BFA2A7BF
A2A7C0A3A8C3A5A9C6A5A8C5A4A8C4A3A8C2A3A7C1A3A8C2A3A7C1A3A7C2A4A8C2A2A7C1
A1A7C29FA7C2A1A9C2A1A9C0A2AABFA2A9BEA1A8BDA1A8BBA2A9BBA1A8BBA1A7BCA3A9BD
A3AABEA2A8BCA0A5B99FA5B99FA6B99FA5B79EA3B49DA4B59DA4B59DA3B59AA2B499A1B4
9AA1B39AA2B298A1B196A0B1959EAF969DAD979EAE969EAF969FB1969EB0949DAD929BAC
909BAB8E98AA8E99A98F9BAA8E99A78D99A68C98A58995A28A95A38994A287919F85909F
84919E83919B84929A839099838E9A818B9C7E8A9E7A869B778596778695778793768690
75868D7385897183836F827D
6575896F819870849F7287A47286A67183A66E81A47084A77184A57285A57386A57587A5
7687A47B8AA67B88A67E8BA8808EA9828FAA828EA98290A98290A98391AA8492AB8593AA
8592A88692AA8691AC8793AD8892AE8A94AE8A94AD8B94AF8D95B28F97B58E97B68E97B7
8E98B68E98B38F99B28E98B28F9AB6909BB7909BB4909CB3909BB2929CB4949FB795A0B8
969FB8959DB8969EBB969FBB959FBB97A1BE99A4C097A3BF95A2BE97A3BD97A2BB97A3BB
99A4BC9BA5BD9CA5BB9CA4B99CA3B89CA3B99EA5BA9DA4BA9EA4BA9EA4BA9EA4BB9EA2BB
9EA4BD9FA6BD9DA5BA9DA5BB9EA6BD9EA5BF9FA7C29FA8C3A0A8C19FA8C09EA7BE9EA7BE
9FA7BFA0A7C0A1A7C1A0A5C0A0A6BEA0A7BDA0A7BF9FA5BF9EA3BCA0A5BEA1A6C0A0A6C1
A1A8C09FA7BF9FA8BF9DA6BD9DA6BC9FA8BCA0A8BC9DA6BA9CA6B99DA5BA9DA5B99FA7BC
A0A8BD9FA7BB9EA5BA9CA3B89BA3B69DA5B69CA3B49BA3B39CA5B69BA3B798A0B6979FB4
97A0B397A0B096A0AD949EAC959EAD949CAD959CAE939BAD919AAC919AAD8F99AE909BAD
8E9AAB8C98A88B96A68B96A68A95A58B95A58A95A58893A38792A28690A1828D9E828D9D
828E9C808E9A7E8E977F8D97808D97808B997F8B9C7B879A77879776889574859172838D
7183897083846D817F6C807A
67758C6A7B966D819F6D84A26F84A47386A77285A77185A76E83A57084A67388A87488A6
7689A6798BA77A8AA67D8CA67E8DA77F8DA77E8CA67E8DA67E8DA67F8FA88090A98090A8
8191A88191A78693AA8792AD8893AF8894B08894AE8894AE8B95B08D97B38D98B68B95B5
8D98B68D9AB58E9AB38D99B28C98B68C97B68B97B58C99B28D9BB2909CB3939DB4939DB6
959EB8939CB8919AB9939BB9939CB8939DB8939EBA93A0BB91A0BB93A1BC95A1BB949EBA
95A0BC959FBC96A0BA99A2BA9BA3BA9BA3BB9BA4BB9AA4BB9AA3B99AA3B99AA3B89AA2B8
9BA3BA9CA5BB9CA6B99CA5B99CA6BC9DA5BF9DA5C09DA5C09EA7C29EA6C29EA6C19EA6C0
9DA5BE9DA5BF9DA4BE9DA5BC9CA5BC9CA5BA9CA6BC9CA6BD9BA4BB9BA3BB9DA4BD9DA4BE
9DA5BF9CA5BF9CA5BE9AA5BC9BA5BA9CA7B89FA9B99EA9B99DA8B99CA5B89CA4B79CA4B9
9DA5B99DA6B99DA5B99BA3B79AA1B599A1B69BA3B79AA4B89AA5B899A3B897A0B5959EB4
969EB4959FB2959FB0939EAE929DAD929CAC909AAC8F9AAC8D99A98E9AAA8E99AA909AAD
8E99AD8D98AB8B97A98B95A78892A48992A58993A58692A38591A28491A2808D9E808D9F
808EA1808FA07C8D9C7C8D9C7D8D9C7D8C9A7C8B9879869676859677889774859371828E
7083896F83836E82806B7F79
6774906C7C9C6E82A46F85A67083A57284A77486AA7385AA7186AA7287A97489A6778AA7
778AA7798AA77B8CA87C8DA87E8FA87F8FA7818FA77F8DA77E8CA77F8EA9818FAB8191AB
8192AB8190A98592AC8692AF8691B08792AF8996AF8996AF8B96AF8B96B18D96B58C96B8
8A95B78A96B78C98B68E99B88E9BBA8C99B98B98B68B99B38E9CB4909BB3939CB5939CB6
969EB8959CB8949CB8959BB9959CB9939BB7949EBA95A1BB94A0BB949FBB98A2BE99A2BE
98A0BD97A0BB99A0BB989FBB999FBC9CA2C09DA4C09CA4BE9BA4BD9CA5BC9CA6BB9BA3B9
9BA3B89CA5BB9DA7BC9BA4B89CA5BA9EA5BF9EA5C29EA6C29FA7C3A0A7C3A0A6C29FA5C2
9EA5C29EA6C29EA7C19EA7C09DA7BE9BA6BD9AA6BF9AA6BF9BA6BF9BA5BC9DA4BC9CA3BD
9AA2BE9BA5BF9BA6BF9CA6BD9DA7BC9EA8BB9DA8B89FAAB7A0AAB79FA8B79FA8B89EA7BA
9FA7BB9FA7BC9EA6BB9DA5B99DA3B89CA2B89CA4BA9DA5BA9CA6B99BA3B798A1B699A1B6
98A1B6979FB5959EB4949DB5939EB5929CB3909CB1909DB0909DAD919CAE919AAD9099AD
8E98AE8D97AC8B95AA8B96AB8B96AA8C97A98B97A88795A58694A48593A58390A3828FA4
8290A78290A67E8EA27B8BA17B8B9F7B8C9C7A8B9978879877859A78879B758596758692
74868D7285877084816D827A
6873917381A17484A77384A77282A67282A67584AA7483AA7485AA7386A87587A67888A8
7988A87A89A87C8CA87E8DA77F8DA6818EA6828DA7848FAA848EAC838EAE838FB0828EB0
8390B18591B18592B18591B18890B08992B08993B08B95B08E98B38D97B38C97B68E97BA
8C96B88A94B58A93B48D96B78F99B98E99B98D99B78E99B4919CB3929CB3939BB3959CB4
969DB4969CB2969DB3979DB5999EB6969CB6969CB798A0B999A0BA979EBA999EBB9AA0BC
99A0BA99A0B99A9FB99CA0BB9B9EBD9C9FBD9DA0BE9CA1BF9CA1BF9CA2BF9EA4BD9DA3B9
9BA1B79DA4B89FA6BB9EA4B99FA3B9A0A4BBA0A3BE9FA3C09FA5C1A1A6C1A1A5C0A1A5C0
9FA3C09FA4C19EA4C19DA3C09DA4BE9CA3BE9DA5C09DA5C09DA6BE9FA6BBA0A4B99EA3B9
9DA2BB9CA2BC9BA1BC9CA4BC9FA6BE9FA5BD9EA5BA9EA4B79EA3B69FA3B6A0A5B79EA5B7
9FA5B99EA4BA9DA3B99DA3B89CA1B59CA0B39B9FB39BA0B59DA2B69BA0B499A0B3979EB2
979EB2989EB2989EB2979CB3959CB4939BB3929BB0929AAF939BAE939AAF9096AC8F95AB
8E94A98E95A98C94A98B93A98990A58993A48892A186919F8591A08490A1838EA2838DA2
838DA6808BA57B88A17B89A07B8A9E79879A788698768396768296768396758193758290
74828D7282896F80816A7C78
646D8A6A7796707FA16F7FA37281A57281A67280A57584A87685A87687A87686A87887A8
7A89A77B8AA67B8BA57D8DA57E8BA5818EA7808CA7828DA9848DAD828DAF818EB1818EB2
818EB2818FB08291B08392B08592AF8792B08992B18A93B28A94B38A94B48B96B68D96B7
8D96B68B96B68B96B68E99B78F9AB58D96B28C96B18E97B2909AB3919BB4919BB3929CB2
919AB1939BB1969EB2969CB3969BB4969BB5969CB6979DB7979DB7979EB89AA0BB9AA1BD
9AA0BA9AA1BA9BA0B99CA0BB9CA0BE9CA1BE9AA0BD9AA1BC9AA1BD9BA2BD9AA0B99BA2B8
9CA4B89CA4B89DA3B69FA4B79FA4B89FA2B89DA0B89CA0B89EA2BBA0A5BDA0A4BDA0A4BF
9FA2C09FA2C19FA3C19FA3C19FA3BF9EA3BD9FA4BE9EA5BC9FA5B8A0A6B89EA3B69CA1B6
9EA2B99EA5BC9BA2BB9BA2BB9DA3BB9FA3BB9EA2B99D9FB69EA1B89EA0B79FA1B79FA2B7
9EA2B79BA2B699A0B699A0B69BA1B6989EB299A0B2999FB4989FB5979FB4969EB4969EB3
979FB1979EAE979CAD979CB0959BB1929AB09199AF8F96AC9097AC9299AE9095AA8D93A8
8D94A88B91A68B92A68A91A6878FA38791A286929F85909B85919D828D9C828D9D828D9F
828BA08088A27D88A27C879F7D8A9D7B889A7A8598778295748091758193768294748091
707E8D6E7E896D7E81687B77
636E8A6C79967180A07382A57381A57180A47281A47584A77887A97989AB7889AA7688A7
7789A4798AA37A8BA27D8DA47F8CA6808CA97F8AA97F8AAB818BAC828DAD818DAE818FB0
808EAF7F8EAC7F90AB8091AB8392AB8491AB8591AE8792B18894B28995B28A95B18A93AE
8C95B28D97B58E99B68D99B68E9AB38D99B18D97B18D97B18F98B28F99B28E99B18E9AB1
8E98B1919AB2949CB4959CB6949BB7949BB7959BB7979CB9979CB9969AB8979CBA999FBB
99A0BA99A1B99AA0B79A9FB79AA0BA9AA1BC99A1BB979FB897A0B79AA2B798A1B499A3B4
98A3B398A3B298A0B09BA2B29DA3B69EA4B79EA3B79EA3B69FA4B79FA3B9A0A4BBA0A3BC
A0A3BF9EA3BF9FA4C09EA2C09DA1BE9DA2BE9DA3BC9AA2B79BA2B49BA3B59CA2B59CA2B6
9BA1B69BA2BB9BA3BB9CA3BA9BA0B79CA1B59DA1B69C9FB69C9EB69DA0B69C9FB59DA1B6
9DA3B79BA2B7989EB4969CB3969EB4979FB2979FB1979EB3969FB5959DB5939BB3939CB2
949DB2949DB0939BAE939BAF9199B08F97AE8E97AC8C95A98D96A98F96A98D94A78C92A4
8A90A48890A3868FA18790A2868FA1858FA18491A183919D808F9A7F8E99808E9B808D9D
808B9E808AA07D889F7C889E7C889D7A8698798394788293758091737F92738195707F91
6E7E8C6C7D856A7C7F677A77
616D886A7794717D9E727EA3717EA3717FA37481A27785A47887A77986A97887A97789A6
7588A47789A57888A37B8BA37F8CA67F8BA97F8BAB7E8BAA7F8AA7818EA78390AA8390AB
818FAC808FAC7F90A98090A88290A68390A88490AC8590B08793B28B96B18B95AE8D95AE
8F96B18F97B58F98B88E97B78E98B68C96B18E97B08E95AE8F96AF9097B08F97AF8E98AF
8E97AF9198B09299B39399B59398B79299B9939AB9959CB8959AB79499B8969BB9969CB8
969EB7969EB498A0B49AA0B59A9FB699A0B999A1BA979FB6969EB398A0B199A0B09AA0B1
98A0B198A1B298A1B198A1B199A1B29BA3B69DA4B99CA3B69CA3B39CA2B29DA2B39FA2B5
9FA3B89EA3B99EA4BA9DA2BA9B9FB99A9FB99AA0BA979EB798A0B69AA1B69AA2B69CA2B8
9CA1B9999FB99AA1B99AA2B89AA1B49AA0B39DA1B49DA1B69C9FB59A9DB3989DB1999DB1
9DA1B39BA0B2989DB2959BB3969DB3959EAF959CAD959BAF939AB1949CB3939CB2929CB1
929BAF9199AE9098AE8F97AF8C96AE8A93A88A94A58B95A38D96A48C94A38C94A38B92A2
8990A18991A087909F88909F8990A0878FA1848FA1808D9D7F8D997D8B977F8D997F8B9A
808A9D80889E7E879E7C86A07A859E798499788294788094777F96747D96727E966E7D91
6C7E8B6B7C83697C7D687C77
606B856976926F7C9C727EA1707CA2717EA37481A27381A27583A57886A87785A67787A6
7889A6788AA67989A57A8AA57B8AA37D8AA57E8BA77E8BA87E8BA47F8BA2818DA4828DA6
838DA8828FA9818FA8808FA78392A88492A88492AA8592AC8691AC8993AC8993AA8B94AA
8D94AC8F95B08E94B28F95B38E95B28D93AF8F96AF8F96AF8F95AE9096AD9198AF9299AF
9097AD9196AE9297AF9297B29398B79198B99198B99399B7929AB59299B69298B5949AB6
969DB6969DB4969CB2989CB3989CB59599B6959BB6969DB4979EB1979DAE999DAF999DAF
989EB0979EAF969EAE979EAE969EAE979EB2969DB4969EB596A0B298A2B09BA2B09DA2B1
9EA2B49DA2B59EA2B79CA1B69BA0B5999FB4989FB5969CB4959DB3969EB4979DB4999DB5
9A9FB7989EB5989EB7989FB6969EB3979EB2999FB19A9FB39CA1B49A9EB3999DB2999CB0
9A9DB2999CB1999DB3979DB5969DB2959BAE9299AB949AAD9399AD9299B0939AB0929BAF
919AAD8F96AA8E96AA8E96AC8B94AB8992A58A94A38D94A28E94A08F94A08C92A18B92A0
8B92A18A919F88909D858D9A868D9C898FA0858DA0808A9D7F8A9B7D89987F8A987F8899
80889A81889C7F859D7C829D79809C79819B787F98777D96767C97757C97727D956E7C90
6A7B886A7C83697C7E687B78
636E896B7895707F9D7180A0727FA1717EA27380A4717EA27481A57685A77583A67685A7
7888A87A8AA97B8AA97A89A97B8BA77F8FA87F8DA77F8BA6808CA6818CA5818CA5818CA7
808CA7818DA7808DA7818FA88290A88391A98492AA8693AC8793AC8994AB8993A98C95AB
8D95AA8D95AA8C93AB8D94AD8D95AE8E96B08D94AF8E95B18D95AF8E97AE8F98AE9096AE
9096AE9197B09197B39197B49297B79299B9939ABA939AB9929AB99198B89198B6919AB5
959DB5969DB4969CB2979CB3979CB3949AB4959BB7959CB6969EB5979DB5989DB5999DB3
999FB1989FAF979FAE959CAC949CAC949DAF949CB2969FB4959FB398A1B399A0B29AA0B3
9C9FB39CA0B69DA0B79CA0B89CA3BA9BA2B99BA1B79BA0B69BA1B599A0B5979DB3979CB3
979DB4979EB5979EB6989FB7969DB6979EB59A9FB5989DB49A9FB5999DB49A9DB39C9DB3
9B9BB49B9BB5999BB6979CB4969CAE959CAD939AAB939BAB939BAC9299AC9097AC9098AC
8F97AC8F98AC8D97A98C96A98B96A98B94A58C93A38D93A28C919F8D92A18A91A1878F9E
87929D88919C878F9B858C9C848B9D858C9F868DA0828A9F828A9E80889D7F879C7F859B
80849D80839D7D829D7B819C7A809D79809C777E99757D99747D99747E98727D936C798B
6A7888697A8566787F647779
636D886977946D7C9B707F9F727F9F727FA1727FA2717EA27380A47481A37683A47B89A8
7B89A97B8AA97A89A87A89A97C8AA97F8DAB7F8DAB7E8AAA7F8BAA818CA9828DAA808CA9
818EAA818EAA828EA9838FA98390AA838FA98591AB8692AB8691AB8893AC8A95AD8994AA
8A95A98A94A98A93AA8A92AB8A91AC8B93AE8D94B08C94AF8C93AD8D94AE8D93AF8E93AE
8D94AE8F95B09197B39096B49095B39196B59298B79299B99198B99199B99299B8929AB7
949CB6969DB4959CB3939AB0959BB1949BB2949CB4959CB6969CB8969BB6969BB4979CB3
979DB1969CB0949BAD949BAC949DAE929BAF949CB298A0B698A0B7979FB7979EB5999FB5
9A9FB5999EB59A9EB79B9FB99BA0BB9BA1B99DA2B89DA1B49B9FB19B9FB19A9EB3999EB5
999EB5979DB5979DB5989EB8989DB8989DB6999DB7999CB7999CB7989AB5989AB3989AB2
9A9CB2999AB3979AB49599B0939AAB949BAD939BAF9199AD9099AC9099AC8F97AB8F97AB
8D95AA8B93A88D95AA8D96AA8D95A98D95A78D92A48B91A38A8FA2898EA1888FA1858E9F
858F9C848E9A858E9C858D9D838B9D828A9D838A9F81899E80889E80879E7E849D7D839D
7D829E7D829E7B809E797F9C777E9B757D99737C95707A91707B92727C92717B8F707A8C
6C77896A768766768263757B
636E876875926C7B9A6F7DA0717FA3727EA3707DA1717EA27481A47481A27683A27986A6
7A88A87989A67989A47B8AA57E8CA77F8CA97E8DAB7D8BAD7E8CAC7D8AA8808CA9818DAA
838FAB838EAB828EAB838EAB8390AC848FAB848FAB8691AE8692AE8691AD8590AB8693AB
8896AC8894AC8B94AD8A93AC8A93AC8B94AF8B93B08B93AD8C94AE8F95B08F94B19095B2
8F95B19197AF9298B09398B19397B19398B39298B59297B69196B69298B6939AB6949BB5
969DB6959CB59399B49298B2949AB2949BB2959BB4959BB5959BB7969BB4999DB2999CB1
989BB0979BB0969CB1949BAF959CB0939BAF949BB0969DB3979EB5979EB6989EB7999EB6
999DB5999DB5999DB6999BB6989CB5989DB3989DB1999DB0999DAF9C9FB39C9FB69B9EB7
9A9DB6989CB6999DB69A9EB7989CB4989CB4989BB5989AB6999CB4989CB3979BB2979BB1
989BB1969AB19498B09299AE9298AC9398AE9398B09197B08E96AE8E97AD8E97AB8E96AA
8F95A98D93AA8E94AD8C92AA8C91A88C92A68C91A6898EA4898EA4888EA4888DA4868DA3
858CA2828AA0838AA0848AA18488A08387A18288A28086A27E84A07C839D7D829D7C809B
7B7F9B7A7D9B797F9B787F99757C96747B94727B9270798E6F798D70788E6F778E6E778D
6A758B69748766748161727A
636F896975926D7B9B6F7CA0717DA3727DA4717BA2717DA27580A37782A37781A17985A4
7885A67887A67A89A57A8AA57C8CA67D8CA77D8CA97D8CAB7E8DAC7F8DA97F8EA6808EA4
8290A5828FA7838EAA848EAB848EAB8490AA838EA8848FA98690AC858FAA838EA88491AA
8693AB8995AC8C95AE8C95AF8B94AF8C96B28A93B08B94B08B95AE8D95AE8E94AF8F96B1
8F97B1929AB0939BAF939AAE9297AD9398B09197B29298B49198B49197B29299B29299B2
9399B19399B29196B29196B39096B39198B3949AB5939AB6949AB7959AB4979CB3969BB2
989CB3979CB3949AB2939AB0929BAE929CAD949DAE949CAF959DB3959CB4959CB4979DB5
969BB3959AB0979AB1999BB4989BB4979CB2969BAF979CAF989DB29A9DB3999CB49A9CB6
989BB5969BB3979CB2989DB2989CAF979CAF979BB19599B19599B0959AB0969BB0959AB1
969AB29499B29297B19197B09196AD9094AB9195AD8F95AF8C94AE8B94AB8A93A98B94A8
8B93A68D93A88D93AC8C91AB8B92AA868FA58890A38A8FA3888DA3898CA5888DA7878CA7
858CA6828AA180899F82899D82899F8287A18186A17F86A37C84A177809B7981997A8197
7A7F99797E99777D99767F9A727C97707A94707A936F79926F798F6D768E6B748E69728C
65718A657287647381607178
636E8667738F6D7B9A717EA1737EA3747DA3747BA2737AA1777EA27880A27880A27B85A6
7986A57986A47B89A57C8BA67C8BA67C8BA67C8CA57D8DA57F8EA77F8CA57E8CA27C8CA0
8190A1828FA1858FA3868EA4858DA58590A88590A9868FA98790A9868FA9868FAA8890AD
8991AF8890AE8C93AF8D94B28C95B28A93B08B93B18C94B18C95B28B94AF8B95AF8B95AF
8B96AD8E98AD9099AD9097AC9096AB9197AD9197AF9297B09198AF9197AD9399AF9297B0
9196AF9095AF9095B09095B18F94B18F95B19097B39097B49198B39298B19299B09399AF
9398AF959AB1949AB19298AF939AAD939CAC949DAC949CAE949CB1939AB2949BB3969BB3
959AB19699AE9699AF999CB4979AB2949AB0959BAF949AAB959AAC979BAF979AB0979AB4
9598B39398B0949AAF9499AB949AAA959BAA9499AB9397AD9296AE9296AF9396B09397B1
9297B29196B29094B19195AF9195AE9195AD9094AC8E94AB8C93AB8B93AA8A93A98A92A8
8990A5888FA68A91A88990A78A91A78891A48890A1898F9E888C9E898DA1878BA38589A4
8289A47F889E7D889C7D869A7E859A7E859B7D839C7D859F7B839E78829B778198757E95
767C96777C98757B98737A997079986E78956D75926B738F6C738F69708E676F8D666E8C
636F89626F876170825E6E76
666E8468718D6C769670799B737C9D757C9F7579A17578A1787CA3777EA27882A17A85A2
7A85A17A85A07B87A07C88A17D8AA47E8CA6808DA57E8CA27E8BA27D89A17E8AA27D8BA2
808EA3828FA2848FA0848DA1858DA5878EA98990AD8991AE8992AC8891AA888FAB898EAD
8D91B28C90B28A8EB08C91B08B92AC8890A98B91AB8C92AD8B91AF878EAC858EAA8490A9
8692A98892A68D95A88E94A98F95AA8E95A88E96A98F97AA9097A99097A99197A99296AA
9297AC9096AC9197AD9299AD9198AC9298AD9095AD8F96AF8F96AE8F96AB9096AA9095A8
9094A79296A99398AB9399AC9399AA9299A7939BA8939AAA9499AC9397AD9497AE9599AF
9497AE9597AE9698AE9699B09698AF9498AD949AAA9399A69397A69699AC9799AF9598AF
9599AF9598AD9498AB9497A99498A99499A99497A89294A89193AB9294AF9495B09395B0
9295B09396B09193AE9294AE9193AD9193AC9093AB8D92A88C92A68C93A98B92A8888EA4
898FA3888EA3888EA3888EA3888FA18A91A2898FA0878D9E888C9D898D9F888A9F8588A2
8386A38186A27E859E7C83997A82967C83967D82977C83987C8197797F97777E98757C95
757B95767C967379957177956F76956E76956C74926C73926B7392697190656D8A656D89
656E88626C845F6B7F5D6C77
696D816D728C737995757C9A777D9C777A9B76799E777AA17A7DA47B80A47C84A17C869F
7B839D7C849F7C86A07C869F7C89A27F8CA5818EA4808DA0808BA0828CA4828BA5808AA5
808CA6838FA58690A3878FA2878DA58A8EAA8B8FAE898FAE8990AC898FAA898EAA8B8FAD
8E92B08D91B18A8EAE898FAC8A91AB8C92A98B91A78B90A7898EA7888DA8858BA6838AA4
828BA082889C83879D8789A2888AA2878BA1858BA0868EA088919F89919E8C93A18E95A4
9197A88E95A68F97A7919AA9929AA9939BAA939AAB9399AE9096AB8F96A89198A89297A5
9397A59498A7969BAB9499AA9396A79498A69599A79498A89698AC9497AC9498AE9397AD
9296AC9497AD9698AE9799AF9899AF9597AD9497AA9599A99497A79698A89697A99596AA
9597AC9598AC9497AA9496A89597A99597A99497AA9193A99092A99294AA9192AA9092AA
9395AD9495AE9192AC9294AD9293AB9092A88F93A68F92A48F91A48C8FA38A8FA2898FA1
8B90A08C91A1898EA1878CA1878CA1878CA1868BA0858A9E868A9C898C9D88899C86869F
8585A18185A27E839F7B83987C84967D83957C81947E82977C80977B7E97797D97787D97
787C95777A927579927377937176956D73956970926A72916B748E6A738B677088676E87
676C86656A8361687D5D6775
696C8073768D777D97787E9A797D9A797C9A797B9B7B7C9E7C7FA17C80A27E84A07F859C
7F849A7F859C8288A18088A17F89A27F8DA1818EA0828E9F838D9E848DA1848CA38188A3
8089A2838CA1868FA1888FA1898EA38A8EA88B8EAB8A8EAB898EAB898EA9898EA88A8FA8
8D91AB8D91AD8C90AD8A90AA8C93A88E94A68E93A58D91A38B8FA48A8EA7898DA7868CA4
858BA084899C85869B85849C83819D81819C7D7F987D81967E83937F8492818594838796
848998828A98848D9B87919E8994A08D96A18F96A29098A59097A69098A69199A4929AA3
9299A39398A69598A8949BAA9298A79299A6949AA59498A49597A59598A89497AB9298AB
9196A99297AA9598AB9598AB9596AA9394AA9294A99295A79396A79597A89596A69494A6
9696AA9395A89295A79295A69497A89597A89697AB9396AB9092A79093A59194A79294A6
9394A69392A69292A89393A99193A69193A29093A18E90A08C8E9E8C8F9F898E9E898F9E
8A8F9C8C919C8C909C8B8D9E8A8BA086889F86899F868A9D878B9D888B9B87889A87879C
84839C80819E7E829D7B81977A81937B81937B80927D80957E80987C7E97787B93787C92
777B9078798E77798F75768F7374907072906B7090686E8C687188687185686E83696D82
65687F64677F64687C5D6271
6A6D8073788C767C93777B95787A94797B967A7C987B7D9A7B7E9C7D819D7F849E7F839A
7F849980859C8289A08189A0818AA0808C9F828D9D848E9C828C9C858D9E848CA1848CA1
848BA1878EA08990A0898FA2898FA48A8DA68B8DA78A8EA88A8EA8898EA7888DA68A8FA6
8E92A78C90A78C91AB8C91A98D94A88E94A48F94A38E91A28D90A38E91A68D92A68E92A6
8C91A48C8FA28B8CA08989A086839E84829D8181997E7F937D7F8F7E808D7E7F8D7C7D8E
7B7D8F787C8D777D8E787F8F777F8E7E8691858B95898F998D939D8E979E919A9E919A9D
90989E9198A39096A49299A59098A39099A39299A29399A09498A09699A49495A59194A4
9296A59397A79497A89698A89495A79393A79193A59094A39295A49296A39193A19293A3
9595A79294A69296A69397A69498A69395A69495A99497AB9093A68F93A59396A59395A3
9393A29291A19393A39192A290929F90939C8F929B8D919B8B8E9A8B909C888E9C898F9B
878E97898F968B90978A8E97898A9B87889D86869D86879B898B9C878998878897888799
8382977F7F987F829A7D81977A80937A80917C80917C7F927E80947C7E9277798D777A8E
77798D76768B75748A75758C72728B70718C6D718C686C87666E84676F82686E80696C7D
64667B64667A6367775F6571
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.392007 0.97619 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
2F3A1A2D3A1A2A391C2A38222A37292A382C2B382D2D39312C38322E3736303938303939
313A3A313B38303B38313D39333D39333D3A323C39333C3A333D3B333D39323C3A333E3C
343E3D36413E35403D35423E35413C36443B36433A37443C38463E39473F3B49413C4B42
3D4B423D4B443E4D463F4E47404F48404E48404E4941504A41504941504841504944534A
44534944544A44554C46574D44554B44544C46564E47574E47584E49594E4A5A4F4B5B4F
4B5C504C5D514D5E514C5C4E4C5D4F4D5D4F4B5D4F4D5E514D5E514D5E514B5C4F4B5C4E
4A5A4D4A5A4B4B5D4842553A15200E1018071016060B1003090D02080C02080C02070700
070600070600030300020300010200000200030400030400030300030300030200050203
0502060604060302050202040404020606010605010909030B0B050E0E080F110912130B
14150D15160D15170D14160D13130D10100A0E0D090B0B080C0C080C0C08090A06070803
060803060701050701030500030300020200010200020300030300050601070802050701
0405000606020A0A040F10080F11090F100A10110B0F110B0F100B0D100A0F130B0B0E09
01020001030002030001030000020001010001020000030000030100020500020900010D
01001002000C050407000100
404D45556756425147364041323842363B4A383F4A3B414D393E4D3C41533E44553E4656
414958434C5A45505C47525D48525D48515C48525C49525E49535F47525F47525F46525F
4853604954604954604B56624B55604E575F4C545D4E57604F59624D58624F5A63515B63
515B64515A67525C69545D6B555F6C555D6A565F6C58616E59636E5A646C5B656B5C666C
5D676E5E69715E6A725E6A705F6B705F6B72606D74616F74637175677477687579687578
66757B66757D68787D68797A697A796C7B7A6C7B7B6C7B7D6C7B7E6D7C7E6E7C7D6E7D7B
707E7B707F78707F776E7F725A685C59685A596759576357556154556054515C51363A38
3337353034322C312C292E28292D28282C29282B29272929262727252726242725131117
0F0C130E0D11090A0D07090A070906080A04090C050A0D04090C030A0D04090D060B0D06
0C0E060C0D060F11090F120A0F130B0F130B0F120C0E110D0E110C0E100A0C0E08090C05
090C03090C010B10020D11040E11060E12080E130A0D110A0D10090E10090E0F080C0E07
090B040A0B050B0E050E11080E11080D10070B0E06090C04080B040A0D05090C04060801
060902060902060803060804090C07080B0603050101050103050A030414020316040418
0807170C080B0B0803060701
32384A353C4E343A4F353950353951353952373C52383D52383D53393E55383D56394057
3B41583940573A40573B42583E455B3F465C41495C424A5C424B5D41495D40485E40495E
414B60444C60434B60424A5F454C5F464B5D464B5E474D624A4F654A4F664A50654B5064
4C51664C51684D526A4C52694D536B4D526B4E53694F546950556A505669525969535A6A
545B6C555C6F565D70565D6F575F6F585F705A62725B65735B65735F6876606978606A78
5F6A7A5E697B616C7A626E79646F7A656F7A66707B66717C66717C66727C68747D69747D
6B767D6C777B6D797B6E7C7C707E7E71807F71807D74827D75827E778280768280737F7F
73807F72807D72817A738178748077747F77758079747F7A737E7A707C76707F74393D40
1B1B211B1C1F1114140D110E0A0D090A0C04090C03090C02080B01060A00030600030400
040500040500040400050601050701040501060703070803060502060502070603060703
0608010609010F1308151A0B181D0E1A20101D23131C22131A20121C1F121C1E13181A10
14150C1111080E0F070C0D060B0D050A0B04070A02060900060800040600030400020400
020400030500030500050702090C060A0D06080B020305000304020505040506040D0F06
14160B191A0D16170B11120A
32384B33384F333853333952333952353B54353B53363C54363C53383E55383F56383E56
3B4358383F543940553A42553D45583E465B40485B414A5D424A5F424A5E43495E43495F
434A5F444B60444C61454C62464D62474D62484C63484D64484D654A4F664C51674E5166
4D51654F54674F54684E53674C54674E556950566A505669505669525A6A515A69535A69
545B6A565D6C565D6E575E6F575F6F5960705A62725C65755D65745F68755F6876616A78
616B79626C7A626C79646E7A676F7A68707B67707B66717B66707969737B6A747D69747E
6A757E6B787E6D797D6D7B7C6E7C7C6F7D7E707D7C717F7C727F7E727E7E727E7E727F7F
72807F74827E75827C75827C75817B75807B75807B77817E757F7E747F7B73827A464D50
20202920222517191A1012100E110A0C0E05080C02080C03090C03090D02050801030500
0304000305000403000504000505000908000C0B030B0A03080602060401080702070802
0607010508010D110614180A181C0D1C20111E23141F23151E22131E22111D20101A1C0E
16170B12130A0D0F080B0C05090B05090C05090C04090C02060A01040700040500030500
040700050801040601040600070A01070A010509000204000203000303000403000A0B00
11110514140913130911120B
353A4C353950343953353A53353B51363C52383D53393E55393E563A4056394055393F56
3B42563B41533A41543D44553F45573F465A40485B40475D42495E434A5E444A5F444860
434861434961444B62444B62464C63454C64474E65474D64484E63494E634B4F644D5064
4E52654F54664E53664E54664D54664E56674F556750556851566A52586B51596A525A6A
535B6A555C6B575E6D585E70585E715961725A63725C64735D65735F6874606974626B76
626C77626C78636D79667079666F79676F7A68707B67717B6670786871776A74786A7479
6B767B6B777D6C787D6D797C6F7B7C737E7E747F8075807F73807D73807C73807E73817F
72817E74817D75827D74827B77837D78837E78837F75807E757F7D747F7C73817A50585A
201F2C1E2026191B1D1314140E0F0D0C0D09090B06070904070A03080C02050900030600
0204000203000404000505000405000808000A09010A0903080704050602090A050A0B03
0A0D02090C010A0C020E10051517091A1C0C1E20111F22132024121F220F1E220F1C1F0E
17180B12150B0E120A0B0E07090B05090C05080B03090C03090C04090D02080A00060900
060900070901060801050700080B00070A00030700010300030300040200040100070600
0D0D0411100612130814150C
343A4B34384C353A50363A51373B50393D503C3F533C3F563B3F57393E56393F543B4054
3D42543E42543F435442465742455A42465D444A60434A60434A60434A60434A60434862
444861444A61454B62444B62464C63474D65484E66454D65474E64484D624A4E624C5064
4E52664E53664D53664F55654F556650556750556852576953586A52586A52596A545C6C
545B6C555C6C585E6F5860725960725961735B63735C64735D66745E68745F6973616B74
616C74626D76646F7864707865717966727B67727A68737A68737A6973786973766B7477
6C76786C77796C78796F7A78707B79727E7D737E7D74807E74817D74817D74837D72817C
72827B72817B72817B74847C77847D78837E78827E76807D76817B7580797480795F6866
2626331E20281C2022181B1A1114120C0F0D0A0C09090C05080B01070A00050800040700
040700030500030400030400040600080901090A020A0C050A0C06090C06090D060B0D03
0D12030D12020B0D010A0C01101406161A091B1F0E1E220F1F25121E23111D21101C1F10
1A1D0F161B1012170C0F13090D0F070B0E050B0E040B0E040A0E020B10020C1101090D01
070B01080A02060801040500060800060900030600010400010200010200010100030400
090C040F110611140712150A
343B49363D4C383E4F383D53383E533A3F523C3F513B3F543A4057393F563B41553C4253
3D44533F4554414755434A5943495E43465F444762454964464C65464B64454B63464B63
474C63474D64484F66464E65474E65484F66485067464F674951674951644B51624E5264
4F52664E53664F556650576750566851566953596A53596B54596C535A6C545A6C545B6D
555B6D575E6E585F6F596070585F705961725C63735D66745D66745E6875606B74626C74
616B73616B73626D7564707864707965717B66727A69737A6B757C6C757B6B75786B7678
6C77786D79786C79766E7C76707D79717E7D727F7E73807D72807D74817D75837E73827D
75837E74837E74827E76847F77827E78837E78827D76817C75807B75807B77827C68726F
2D2E3A24252F2022271F2021191B1811120F0B0D08070802050800070A00060A00040700
040701030500030500040601050701090A020A0C040B0F050C10050D11080D11080C1007
0E13060E13070C1006090C030D110712170B181E101B21121E25131F25151C21131B1F12
1B1F12191F11171D10161C1013180C0F14080B10040B10050A0F040C11040D12030B1002
0B0E030C0D03080A00040500050500060700050700040600020300000200000100000200
0608020C0F050F130812170B
343B4A353B4D363C4F363D50363D51393F523A4052393F533A40553A42583C44583E4557
3F47563F4856404856424A59444B5E43485E444660464865484C69484C68464B65484C64
484D63494F67484F69484F694850684950674A51684951684A51664B51644C52644F5365
51546851546851556751576851566852596A535B6C545B6E53596E535A6D545A6E545B6F
555C6F565E70575F6E585F6E5960705C62745D62745E64755E67765F6977626B79626C78
636D7864707A636E7965707B65717B65727C67737D69747E6D767F6D767D69747B6A767B
6C797A6C7A796E7C796E7D796F7E7B707F7D72807E77848076827F778380798481778380
79848179848178848079848077827F7A83807A837F78817D77817C76827C77847C717B75
3B3D4526263024252A2426261E1F1D17181311120C0B0D06080B02080C00080C00090D03
0B0E05080A04050702040603050603080A040A0D050A0D040C11050B0F050C0F060D1208
0E130A0F140B0F130A0C0F070B0D0611150B181E111C22141F25152026171E24161D2215
1E22131A2013161C1013190D10160B0F15090C11070B10060B11070D12080D11050B1002
0B0E020D0E02090B00060900050800050700040700040600030400010200000100010100
0608020C0F050E120810140A
333B4C353C50363D51353C51383F52383F50383F52393F543A41573B425A3C435A3E455A
3E46583D44563F465741485941495B42495E444962474A67484C69484D68464C67474D66
484E67495067484F694950694A50694A50654C51654B51644D52654C51654D52654E5366
4F546751566851576750576651576751586952586A51586B535A6C555B6C555A6D555A6E
555C6F575F70586071595F705B61715D62725E62745D64755E6776606978626B7A636D7A
626C7A636E7B65707B66717C65707B65717B67737C6B767D6D767E6D757C6A737C6B757C
6C767B6B787A6D7A7B6E7B7B6F7C7B71807E727F7E768380778481788381798381798380
79837F7A84807A83807A838078837F7A837F7A837F7C84807B847E78837C76827A788479
4C4E4F24222C26252923242320221E1D1E1715151010110A0C0F06080B03090C030C0F07
0E110A0C0E09090B080708070606060809070A0C080A0C060A0D06090C040A0D040D1107
0E130A10150C10130A0D0E06080A020D1006161C0F1C22142027172027182025181E2317
1D22141B2113171D1013170C10150A0E13090C10070B0F060A0F060B0F06080C030A0D02
090C000A0B00070800050600040600050700040600030400020300010200010200000200
0305000A0C020D10060E1209
353D4E363F50364050373F50373F503940513841533940563B435A3B425B3D435B3E455A
3F46583F4756414959424A5A424A5C444B5E464C62484D65494E65474D64464E64474F63
484F614951624A52654B53674D53694D52684E53674E52664F52664E52664D53664E5567
505668505668505667515867515867525968525A6B53596B555B6C575C6D585D6E595E71
595F715961735B63745C63745E65745F66745E65755D66755F6777616A78636C79636C78
636E7964707966717A67737B67737A67737B69747C6A767B6A757B6C757B6D767D6E767D
6D777D6C787B6D7B7A717E7A72807B75807E727F7F73807E77837F7883807A85817A8482
7B83817B83807B83817B83807B85807A847F7B857F7A847E7A847E79837C76817978847B
545A59231F2824232721212221221F20221B191A1212130C0F110B0E110B0C10090C0F0A
0D100B0D0F0A0C0D08090A060808050908040A0A070A0B08090C07080A040709020A0E06
0F140A12170D11150B0E10060B0B010E1005161B0E1A21131E25151F26171E24161D2416
1E24161C2215181D1114180D10140A0D12080C10070B10060A0E05080B030709020B0D04
090B000A0C00080900050600040600050700060900040600020400020300010300000200
030400090A010C10040C0F06
3740513740523841543841533941533B44553C44583B445A3C435C3D445D3E475D3F475B
3F495A414A5A404959424B5B444E5D464E5F474D60484E62484E61474F61475061485161
4952614952614A51634D52684E526C4F536D4F546C50546A5055695056694F5468505769
515869505666505765525967525A68535A6A555D6E575E6F585E6F575D6F5960705B6272
5D62735C63755C65765D65765E66735F69745E67755F6875606878626B78646D7965707A
65717966737867747867747868757869757A6A757B6B757C6D777E6D777D6E797D6F797E
6F7B7F707D7E707E7A72807873807A75817D74817E76837F7985807A84807B84817D8784
7E87857D85837E85837D85827C86817B857F7B867E7A857D7B867D7B867E79847B7A887E
606B6523212B2323282324262124221F231D1B1E1616181013140E11130D0F120C0E100A
0D0F080E0F080D0D05090B04080800090A020A0A040A0A06090A07070907060805090C08
0F140C12170E12160C0E10060A09010F0F0517190D1B20121D24161F2617212719202619
1F25191E25181A2015151A0F10150B0D11090B0E070A0D05080B03080A03070802080A02
070900080900060700040600040600040700050800060800040600030400020300000200
0507000C0D020E10040C0E05
373E52373F553840573941573941553A42563A42573C435A3E445D3F455E40485F404960
414A60434D60434D5F444E5E475060464F60474E60484F61485262485161485161485261
4B54644C55664D546750556A4F536C4F546E4F546D4F546C4F556A51576A505669505669
51586A515A6B535B6B555D6B545C6C555C6D575F6E575D6E585D6F585E70596172596272
5C63745D65765D66775E67785D66765D66745E67755F6875626A77646B7A646C7A646E7B
65717B6671796773796875786A767A6A757B6B747B6D767C6E767D6F787C6F797B727B7F
727D80717E7E73807E75817E74827E75817F7782807884817A85817A85807C86827D8783
7D86847C85827D85807F87837F89837F88817F89817F89807D887E7D877D78847B7A877C
6C786F2E2E36292A2F292E2C2229241A1F19161B1413140E12130D12120C11110A100F09
0F0E060F0F050B0B01080B01060900080B00080A02090C050A0C06090B07080A070B0E0A
10150C10140C0F13090F10060A0A010A09011618091D211220261721271822261921261A
1F25191E25191A201413190D0F13080C10060B0E050A0D050A0C04080A03070903070903
040600030500010300020400020500040600050700050700030500020500010300020200
0505000B0B021011060F1007
373D54383F563B42593A42593A42583C44563A41553C435840455D40465F404761414963
434C62454E63444E62454E61464F61464E61484F624A5164495364475062485162495162
4951644B53664E55684F546B4F536C4F536E4E546D4F556E4F566D50566A505769515769
52596C535B6E545C6E565E6F565D6E585D70595E72585D70595D705A5E725A60755A6175
5C64765D65775D66765F68765F67765F67755F6976606976626A78646B7C646C7D666F7E
67717D67717D69737D6A757D6A767D6A757C6C757B70777E71787F70787F707A80717C82
727D82737D80747F807782817682817782817982827A84837B85837A84827C86847C8684
7C86847D87847D86827E88837F8983808A837F8A837F89817E887F7E897E7B867C78847B
778478383A3E27282D2C312D2126201619151114100E110C0E100A0E100A0E10090D0F07
0B0C030A0C020A0C00080B00080C020B0E03090C030A0D040A0C04080B030709030B0C06
0E11081012070E10040C0D020908000908011518091C22131F25182027192026191F2418
1E24171E2416191E1112160B0D11060B0E040B0E040A0D040A0C04070A03060902070902
030500010300000200000100010200020300030500040600030400010300010200030300
0909020D0E05101108101209
3940523A41553B42583D435A3E455B3F465C3F465B3F465C41475D414860424A63414963
424A64444D64444D62444E61464F624851624952644C53654B5265495165485265495267
4953664C55694F566D50556F50546F505570515772525873535972535A70545B6D535A6C
535B6C555C6E575F70585F6F565D6F595F725B60755A60745A61735C61745D62765D6377
5F66785E66765D66755F6975616B76606A76626C78636D79646C7A676E7E687181687280
67717E68737E6A757F6B757E6C767F6E787F707A80727B83727B83737E84727D84727E85
727D83767F827780817881827882827982827983827B85847C85847C85857C86857E8887
7F8A877F8A857F89847F8A84808A84818B83808B82828C83828C83818B817E887E7C877D
7C897D45484B25242B292C2B242722191B171112110F0F0B0E0E090F0F090F10080D0E06
0A0B04090B04080A02070901090B030B0E050B0E060B0E05090B04070A02090B040B0D05
0B0E040B0E020A0D010A0C01090A000C0F03181C0D1D23142027172028192027191F2417
2024161F25161B1F1313170C0F12080B0F050B0E040A0C03080A02060903050701050800
020500020300020300020300010300010300030400050600040500020300010100030401
0C0F0510140A12170C10140B
3B43523C43553E445A40455C41455F41466041485F41495E414A5F434B5F434C62434C63
434C62424C5F434D5F454E5F4850614B53644C54654D54664C53664A53664B55694A546A
4B556B4C566C4F586F525970525972525870525A71525971535A72555C72555C71555C70
565E6F575E70596172586071575E705961745A62735961735A63735D65745E66755F6676
6066775F68775F6976606A76626D76626D77636D77646F7B656E7D68707F697183697283
6A74836C76826C77806D777E6E787F707980707B82707C83727E84747E83747E82747E83
757E837881827982827A83827A84837B84837C86847D87857E88877E88877D88877F8989
7F8B88808B877F89857F8A867F8A85808A85818B84838E86848E86838C84808A807D877D
808C7E54585727242D282A2D2629271D1F1C1515120F0F0B0C0D070D0E060E0F060C0C04
0A09030A08040A0904090902080A020A0C040C0E050B0D060A0D06080B050A0C060A0C06
090A04070A03090B030A0D030A0D01101206191D101F2317212618232819222719212518
2023161F24151B201215190D1014090E12070C10060B0D050A0C05080A04050802030500
010400020400020400030300000200010300040600050600030500030400020300030400
0E110814190D151A0E12160E
3B42533C43563F465A40475C41465D41475E41495F3F475F414860434C61444D62444D63
464F6247516248515F4A515F4D53624E54654E54664E55674D56684C55674C55684D566B
4E576B4F586C515A6C535C6E535B6F535B6F555C70555B70555B70555B6F565B70555C72
565D72565D72565E71575F715960725961725A61715A62715B63725C65745E6576606676
626778626878636B79626B78646E78656F7A656D7A666E7D6A707F6B70816C72846C7386
6F76876E75856F78836F79816E797E6F797F717B81727C82737E82767F83767F82767F84
767F867781847881847B85847B85847D87857F89877F89877F8A89808A897E8989808B8C
818D8B828C89838C88838C88838D89818C87818C86818C85848F85858E84838C817F887E
818C7F5E635E27242E28292E2427251B1F1A14171110130A0D10070C0F060D11070B0E05
0B0C04090803080703080A03090B03090B030A0C030A0C050A0D050A0D050A0D05090C06
080B06070A05080B03090C03080A020C0E05161B101D2216212619242819232719222518
2024162025151D2214191E1015190C0F14080C11060B0E040B0E050A0C05070903040601
030500020400030400040400020300030400040600040700020400020400020200030301
0F120914180E161A12151913
3C43533D45563F475941495C41485C434A5E42495F414863424963444C63464F63454F63
4750634A53634A53624D53624F55654F56665056684F57694F58694E58694F586950586A
51586B52596B535B6C545B6D545B6E555D6F555C6E565C6E575D6F5B5F715A5E72585E74
575E74565E72555E71575F705860705A62725C64735D65745E66755F6677616779626877
646979646A7A666C7B656C7B666E7B666F7B676F7C69707E6C71806C73836C72836D7585
717886707884717984727983727A80727B80747C80757D82777E83787F84777F85788189
78818A7982897B83897D86887C86857E87867F89877F8987808A88818B89808A8A838D8D
848E8D858E8C848D89848E88858E89848E89838D86838E84848F83848E83828C81818A7F
818C7E6870682F2C342F3032282A291D221E14191311160B0F12090C0F070B0E070A0D07
0B0D080B0D080B0D080A0D050A0D040A0D040A0D040B0E050B0D050B0E060B0F06090D05
080C05070B03080C03090E030A0D030B0F0512160C1A1E111F241623271824281923271A
2226172227162126161E2214181C0F13170A0E13070C10050B0E030A0D03090C02090A01
060800050500060500070600050500040300030300020400020400010200000100040502
13170B151B0E171C11151810
3B43533D465640495A41485B40475D41485E424A61424963434C65454E65475064485264
4952654A53654C54664D54654E57674E57674F58694F586A4F596A4F5A69515B69535B6A
535C6B545B6C555C6D565D6E565D6F565E70555B6F565C70575D705A5F725A5F72595E73
5960765962755963735961705A62705B64725D66745F6776616A77616B78616A78626B78
636B78656D79666E79656E7A666F7B66707C67717C68717C6B737F6E74826C74816D7781
707984737C85727B83747B82757C81757E80767E80777F817981847A8186798188788189
79818A7A838A7B848A7D868A7F8888818A88818B89818C88828C89838D8A838D8B838D8B
858F8D868F8C868F8B87918B87908A868F89868E87859085848F84838E82858F83838D81
828E80727B7137363C343639333736222423181A181316110E120B0C0F0A0B0D09080A08
0A0C090B0E0A0C0F090A0C05090B020B0D030D0E030D0F030D0E040B0D050A0E05090E04
0A0F040B10040E14040E1405111707101507101407171A0D1D2214212718222818222618
2126162025152128181F25171B2013161B0F11140A0D11060A0E02080C00090C000B0B01
090901070600070600080700060500040300030300020300020200010100000200020401
0D110613190B181D0F181C0D
3C45533E4856404959424A5E434B60434C60434C61444D61444E62465163475264495466
4A54664B56674E57694D57694E586B4E5A6B4E5A6A4F5A6A4F5A6A505A6B4F5A6A515B6A
525C6A535C6A535D6B565E6D575E6E585E70595F71595F72595F72596072595F72585E73
5960775A62765A63745A63715B63705D65715E6673606876616A77626A77626B78636A79
636A79656C7A666F7B666E7C67707D68717E69737E69747E6D757F6E757F6C757F6D7781
707A83737C85747C85757D85777E85787F857880847A82867B82877C838A7B828B7A828C
7B838D7C848B7C85897F8789818989828A89838C8A838D8A848F8B848E8B848E8B86908D
868F8D868D8B868E8B89908D89908C878F8B878F8A879089859188859085869184849083
8591817985783E3F4336393C353A381F2223191B1A1215130E110D0C0E0B0B0D0A090A09
0A0C090A0D090B0D060A0C030A0D020D0E020E0E030E0E020D0E010C0C010D0D020E1005
1115081117081016061015061015060F12040E0F0314150A1F21142327182227181F2516
1E25141D24132027151F26161B2214191D1014170B0F13080C10030B0F010A0E000B0D01
0A0C01090A00090800090900070800050600030400040500030400040300010200010300
0D0F0615180C181E0F181B0C
3E4753404958414B5A424B5E434B5F444D60444D60444E614650634852654853664A5568
4C57694D57694D58694E596C4F5A6C505C6C505C6B505A6A4F5A6B515C6E505B6E505B6C
525D6D535E6D54606E56606F576070585F70585F71585F725A62725961725A61745A6075
5B62775B63785B63775C64755D66755E6774606875606A76626B77616A78646D7A656C7A
646C7A636C7A666F7B67707C6A727D6B747D6B747C6C757B6E777C6E777D6E767F707782
717984737B87747C86747E85767F87767E88777F8879818A7A828B7B838D7B828D7B838D
7C858C7D878B7D878B80898C828B8E828C8E858E8F848D8E848E8F868F8F869090879191
86909086909186908F88918F88928D88938D88938C88938B87928C869389859187839085
8391847C8D7D3B3F422C2F332A2D2B1C1E1C1316120E110C0C0F090A0C070A0C07090B06
080A050A0D050A0C030C0E030E10020E0F020E0E020D0C020E0E010D0D020F0E03121206
1113090E11070B0E03090B01090B010B0B010E0E0317180C1E2013222516222517202416
1F24162024152226162026171B2213191F11161C0F11160A0E13060C11030C0F020C0F01
0A0C010B0D010B0C000A0C000A0C01080B01060900060800050700030400000200010200
0B0C0513150A15180C15170A
404755424A5B444D5F454E60454D61464E61464F614650624851644954654A55664C5668
4E596A4F596A515C6D515C6E515C6D515C6B505C6A515C6A525C6A535E6D535E70535F70
556172546071556070576171586272575F735961755B64745B64735B64745B64755B6475
5C65765D64765D64775C65775D6778606A78626C78626C78636C79636C7B656E7D666E7C
656F7C65717D67727C69737C6C757E6D757E6E767E70777E70797F727B82727A84727A83
737A84737B85747D87747E8676808878818977808978828A7A848B7B868B7B868B7B868B
7D888C7E8A8C7E8A8C818C8E838E90838D90869092858F92869091889191889292869192
86929388949387939187938F89958E8A968C89958A8A978B8A978C88958A869489849388
8494868091824248482325292023231518160F120D0D0F080C0E05080A01080A02090D03
090B010A0C020B0E020D10040E12051012041212061112061110050F0F040F1006101007
0F10080C0E07090B04070902090B030C0D0411120717190D1D2113212616232718222617
21251821261724291A252B1C2027191E24161B2214181F11151C0E141A0C151A0B111507
0E13050F12050E12040E12061116090F14070E13050D1204090D01050800020500020400
090B0312140715180B17180C
434A59444C5F464E63485066484F654951654751644953664B56674C58664D5967505B6A
535C6C535D6D545E6F535D6F535E6E535E6F535E6E545F6F555E6E555E6E565F71566173
5660755660735860735962735A62745A62745C63765D65775B64745B64735D66735C6573
5C65745E66765F66775E66795E677B606A7A626B78636C79636B79656B7D676D80686F81
6770816871816972816C74806E7580717881717781717883737A84747D85747C85747B84
767C85767C86767E89767E8879828A79848A78838979848A7B868B7E898C7D8A8B7D8A8C
808C8F818C8E808C8C828E8E848F8F85908F889491879290889290899291889290879292
8895928895918A95918A95908B96908A968E8A968C8B988D89978B899689899689879589
8696888698864F595326292A1D201E1417140F120C0C0E080A0C04090B020B0D040B0E04
0C0F040D0E040D0E040C0F050E11061014081112081213081113080E11070E11070D0F06
0B0D050B0E060A0D060A0D050B0D040D100410140714180B1B2012212716232817222817
212617232818232A19242C1A232A192027171D24161D24151D25141E25141E2413181D0E
14180912160812170A10160B14190E151B0E171C0F191E0F1115080B0C03060700040400
07070111130817180D181A0E
454C5D464E614852654953684952684B55694852654853664C58694D5A6A4F5B6A525D6D
545E6F555F6F566071546072546171556271556272556072566074576074586174576174
5560755760755A63765B64765C64755D64755E66765E67765C64735C65725B65705D6671
5F68745F68785F677B5F687D606B7E606C7C626D7B636E7A656F7C666E7F687082697184
6971826972816B74826C74826E7583707885717985727987727988757D88757D88767D88
767D88797F8B797F8E77808E78828D79858E79868C79858C7A878E7D8A917D8B907E8D91
808C90828D91828F918291938492938692928996948A95938995938A96938B97958B9696
8B96958A95958C96958F99958F99938E99928D9A928C9A908D9A8E8D9A8C8D9A8C8B988A
8897888A9B88606B612C2E301F2122171A191114120D110C0B0E070A0D040F11080F120B
10130C11130A1011081011081012080E11070E11071012071113080F12080E11080E1108
0C0F060B0E060B0E050B0E040D1204101405111607181D0E1D2213222716232817242917
2328182428172328162329172229162228162026141E26141F27151F28151F27151D2314
1C21121A1F11181E11171D0F191F0F1B21111E22132327171A1B0F1212090D0D050A0803
0707030D0F0813160C161A0F
464D614851654954694955694953684955684956684A56694B57694E5B6B515D6E525D6F
545F71566171566272556272556371566372556370556272566275556275566274566274
5561735762745864745A64735B65735C66745C66735C67715A656F5C68705C67705F6973
606A765F69785E68795F6A7C616C7F646F7F656F7E65707F65707E656E7F677182687385
6972846B74846C75866E76876F77886F78896F7A89707B89707B88727D88727D89757E8A
77808B777F8C77808F7882917783917985927986907A88907A87907C88917E8B927F8D92
808C92818E938290948191958392958593948794948895968996968B98968A97968A9696
8C98978C98978C97958D98948D99928E9A928D9A928D9C918C9A8E8C9A8C8C9B8D8C9A8B
8A98888B9A886E7B6E31343726282A1C20211618191213130F110C0D0F0716190F191C14
16191412151010130B0F12090E11080D10070D10061013061113061013070E12070E1208
0D12060B0F040B10030C1103111706141A09141909161A0B1A1E0F1E2212202515212717
2128172128162228162429172229182128152026142026151F26151E26131F27131E2614
222A172229161E25141E26121E25111E2310202514282D1C2225171B1C1213140C0E0D08
090B080B0D090E130A10150A
444D624650664752684955684955684A56684A56694A57694A58694D596B515D6E535F6F
546071556170566271556170556271576472576571586573576475576476566375566375
5763745863735963745A65755A65765A657559657459667258676F5A68705D68725F6975
5F68765E68785E6A7B5E6A7C606B7D626D7C636E7C666E80666F80666E806871836A7285
6A71846A73846C76866D76866E77876F798A6F7A8B707B8A707B87717E87727E88747E8A
76808C76808D77808F7881917884937986947986937B87927D89927E89907E8990808B92
828D93818F948292958393958494948694938794938895948B97968C98988A96978C9896
8B98958C9A968C9A958C99938C9A928C9A908D9A8F8C9A8E8C9A8E8E9C908F9D8E8F9B8C
8C99898D9B8A79867A3D41453033372327291D2022191B1C14161416181247523E252B22
1114121115120E120C0C0F080B0D060C0D060D0E050F11060E10060E11070D11070C1007
0B0F04090E020A10010F1606141B0A171D0C171C0C13160914160A1A1C0F1E23141F2617
1F26171F26162026172228192329192128162027152026142127162026172027141F2713
232B16242C18222A172028161F27131E26111E2412262D1B262B1B2025171B1E1214160C
0E110A0E120A0C1208090D04
444D614750664853694954694B566A4C56694B56684C57684D58684F5969535D6C55606F
556171546170566472576572566371566372566372576475576376576376576276566276
5864765964765863765A64795B647A5A647A5A657A5965795966775966745B66775D6777
5D67785E687A606A7C5F6A7C5F6B7C606D7C636F7E656E81677183687083697183697281
6972806A74826B75846D76856F788770798B707A8D707B8C727D8B73818975838B76828C
75808E76818F7682917884937885947A87947B88947B87927F8B91808B8F7F8B8F818D91
848F938491938593938794958794938995958995968996968C98988E999B8D999A8E9A98
8D99978D9B978E9C978E9C948F9C93909D93919D91909C91909D92929F92919D8F919D90
8E9C8F8C9B8C8290834B4F52383B402C2F33272B2C2528271C1F1E191C194A5843222A21
11151113171310140F0D110A0C0E090C0D060C0E040D10050D11060D11060C10050D1007
0B0E060A0D050A0E0312180A171D0F191E10151B0D0F140811140A171B101C21151F2518
2025192227192126182227192328192228172128162128162228162026172026161F2515
232A19252D1C222A1B1F27181E26161F28141E26112229142229171F27161E2615192011
13170C1013090D1107090D04
494F5E4B52644C556A4C566C4B556B4B556A4C56694C57674D5865515B68555E6C586270
566271556271566473586675576673566372566373586475596575586575576376576277
57637958647A58657A5A647A5B647B5B647C5B647D5C657D5C677C5D687A5E697C5E697B
5E697A5E6A7B606A7D5F697D626C7F626E81636F82647083667184677284687383687380
6B76806D77826E78856F79866F7A88717C8C717D8E737E8E737F8D74818B76838C77838D
7883917882937781947886957987947987927B89927C8A927E8C91808E91808D91818E92
848F938490938491938692948995958A96978B97998C999B8D999C8E999B8C999A8E9A9A
8F9C9A909D9A909E99909E96919E93929E91929E90919E90939F92939F92929E92919F92
909D908F9C8E8A9788585D5D3A3A4136363C2D2F322C3030262A291A1E1C20251F20261D
1C2319161A1211150C0E130B0D110B0C0F070A0D030B0F030C10040C11050B10040D1106
0C10060A0C05090B040D110714180C181C10181C1113160D10130C161A111B21151F2517
2126192128192027181F2617202717212817202716232918252A182329182126171E2417
22291B262E1E232C1B1F28181F2717202717202716242B172229172027172127181B2113
11160B0F13060D10030A0D02
4A525B4D54604F57684D566B4C566D4B566C4A55694B57684C5867505B69515D6B545F6D
55617054607156627557657957657A566479576578586577586577586578586477596578
59637959637A5964785B65765C66765C66795C657B5D667D5D667C5F677C5F687B60697A
60697A616A7B61697D626B7F636D81626D82636F83646F836570836772826973836A7481
6C76806E79826F7A82707B84717C87727C8B737D8D747E8E747D8E75808D76808E77818F
7A83937B84967984967986967B88957B88947C89947F8C95828E96838F95838E95828E94
8590968591958491948793968895978A97988B98998D999A8C989B8C99998C98988E9A99
8F9C9A919E9A929F9A919E99919D95929C92929E92939F9294A09393A09493A094919F91
8F9D8F8F9D8E8F9C8C6367633A363F39373F3030352D2F322C2F2D2024231C1F1D1C1F1B
1D221A191D1415181010130B1012090E10060B0F030C10030C10030B10030A0E030C1006
0B0F06090C040A0D040F120814190C181B0F1A1D11171A1011130D1518101E221623281A
2328192329192128181F27151F28162029162128152229182128182027171F26171F2517
22291B252C1C212A191F27161F25141F25161F24151F22151E22141E23142025161A2112
10150A0F14060D1103080A01
454E584A525E4E57674E566A4C566A4C576B4B576A4D5A6A4E596A4F596B505A6C535E6F
54617154607155617756627A57647D57657C58657B57637A56637957647A586578596578
5A65785B64795B63785C65755B66755C66775C66795C677A5E677B5E677B60697C626B7B
626B7C626A7E616A7F646D82646D82636E836470846772856872856973836B75836B7582
6C77816D78816C77816F7A85727C8A747C8D747D90757E92768092788193788093798295
7C84977C84987B84977C87977C87967D88967E8896808A97828C96828D95838F96849097
8691978793968794978995988996988A97988C98998E9B9B8D9A9A8D99998E9A9B8E9C9B
8E9C998F9C99909D99929D99939E98959F97949F9794A19693A09592A096929F94919E92
909F90909E8D909F8B717A6E4343453F3F433130362C2E312B2E2B2225221E1F1C20221E
2328201F251B191F1414160C1112080F10060C0E040C0F030C10030B10030C10040C1008
0C10080D10080F120911150B14180D16190E16190D14170C11130A16170D22261825291B
24291A232819212818202817202816212A17212916222A172028171E26161E26171F2618
20281A21291B1F27181D23131A2110191F0F181D0F171B0F15180D15180D151A0E151A0E
12160C0E12080B0F04070B01
464F594953604D5867505B6B505A6C4E596C4B576B4E596D4F5B6E525D70525E70536070
526070536171546273556274566477576578566578576578586577586678596679586578
5A657A5D667C5E667D5D657A5D66795D66785F68785F6979606B7B60697B60697D626A7E
636C7F636C80606A81636D84656F856571876772876973866A73856A73846D77856D7785
6D78866F79886F798A707A8C737C8E747D91757E94767F94757F94767F937881937A8294
7B83967C85957D85977F889880899A80899A818A98818C98838D98858E98859099869099
86919988949989969B8A96988A97998B98998D9A9B8F9D9D8E9D9D8E9D9D8E9C9D8E9D9D
909E9C909E9A919F9A939F9C949F9B95A09A95A09894A19892A09892A09790A095909F93
90A09191A08D93A38D798576494C4B4649473132342B2E2E2B302A252B2421251D262A20
272D2220261B171B1112150A1012071011060F11070D11060E13050D12040D12050E1308
0D110A0F130B12160C12160B13170B12160B12170A11160A1014091215091E2111222717
252919242A19252A19242A19222A19242B1A222918242A162429172127171F25181E2518
1C24171B22151A2113171D10141A0C12180A1115090F13090E11080D10080D12080F1409
11140B11130A0D1007080B03
47525E4955624C58684E596A4F5B6C4E5A6D4D586E4D596F4E5A70515D72505C72505C70
515E705261725160705462715563725664735866755967745A67745A66745B67775A6677
5A66795B667B5D667C5D667C5D677C5C677C5C677C5E6A7C5F6B7C616B7D616A7D616A7E
656E81646D83636C85646D85656F866672876872876872856B74856D77876F78886F7788
6F788971798B717A8D717A8D727B8F747D91767F92768093757E927780917882907A8491
7D85937E86957E8696818998818A99828A9A838A99848C99848E9987909A888F9A89919C
88929C88939D89949C8B959A8B979A8C999B8E9D9F8E9E9F8E9E9E8D9E9D8D9D9D8E9E9E
92A09F93A19E93A09D929F9C939F9C94A09D94A09B93A098919F9793A19992A29790A192
91A29190A18F92A2907F8D7E5155534D524E3233352A2C2C292C2A272B2623272021261E
24292022261F1D1F1818191014170C1213091213081012060C11040B10030C11040D1106
0D10080E11090F120A0F12090F130912160C14190D12170B1014091215091B1E0F222616
242818252A18262C17242B16242B17272D19242B182228162227152024151D2013191D12
161C10151B0F151A0E13180B10140910140A0F120A0D11090B0F090B0F080B0E070C0F07
0D11080E11080D1007090C04
4853604B57644D5A6A4E5A6C4E5A6D4E5B6E4E5C704E5A704F5B70505C71505C71515C70
505C6F526071525F705462715764725865735A67755966745966735C67745D68765C6777
5A66795A66795A667A5B667B5E687C5E687D5E687C5E6A7C5E6B7C5F6B7C626B7C636C7D
656F81646E82646F84646E856470866471876572876873866A73866C76886F7789707789
70798A71798A70798A717B8C737D8E757F907681917781917680917780917882917C8493
7D85937E86947F8895808A96808995828B97848C99838B99858D99868F99868F9889929B
89939C88939B89949A8B969B8D989D8E999E8E9B9F8D9B9E8E9C9E8E9D9D919F9E929F9E
93A09E95A09F94A09D939F9B939F9C94A09E94A19E929F9A919F9892A19991A19891A196
91A194909F9291A191808D81505452545D54323634262928252725242725232624242825
282F282B302823261E191B1414150F1010080F10050F10050D0E040B0E020C11030D1104
0E12070C0F0A0A0C090B0D090D100B11150F13181012170F0E130B0E1309171B0E1F2415
232818252A18252C16232B14242B15232C172129171E26161F26161F23151A1C1015180D
13170C13180B1116090E12060D10060E120910140D0C0F0C0A0D090A0D070A0C050A0D05
090C04090C030A0E04080B03
47535D4A56614C59684E5A6C4E5A6D4D5A6E4D5B6F4E5B704F5A71505C71525D71525D6F
535F6F53617053606F55636F5866725866745966755865765A65775C66795C66795B6679
5A677B5B677C59667B5A667A5D687B5F687D60697E626C80636E82646F82646E80656E81
646F82636F826270826370846471846470846672846873846A74846E76866F7788727A8B
727B8B707A8B707A8C727D8D737D8E777F9079819079818F7881907A83927B84937D8694
7E87957F8895808995818A96818A95818B95838D98848E9986909B86909A869099879199
88929A88949B8A969B8B979C8C979D8E999F8E999E8E9A9F909C9F909D9F93A0A094A1A0
94A09E95A09D96A29D96A39E96A29E96A29F95A29F929F9C93A09A94A29A95A39996A398
94A39692A29493A2928999864C504B4E564C393E39282A2A2527262B2E2B272A29272B2A
2B322C2B312823271F1B1D1815171110110A0D0F070E10070C0F040B0F040C10040C1004
0C10060B0E080A0D090A0D080E140B141A0F141B1112190F0E140A0D1309151B0F1C2315
212919232B19232B16242B15252C16242C17232B182129182028171C2213171C1014190D
10150B10150A0F14080D11080C0F060D11070E13090C0F090A0D06080C04070A01080B01
060A00050A00070C00070B00
47535C4956604C59654D5A6A4E5A6C4E5A6E4D5A6E4E5A714E5A734F5B74515C73515C71
536071556272535F6F54606F5663715865735865745764755864775A657A5C657B5B667A
5A657B5B667C5A667B5A657A5D667B5E677D616A7F636B80656D82656D81646D80646D80
656F82656F83636F83636F826472826471816773816974826B7682707A85727A87737A89
727B8B707A8C717C8F727D90737E90757F9077808F78818E7A84907D86927E85927C8492
7E8795808996818B97818B96818C96828C97838C99848E9A848F9B858F9B86919C87919C
87929B89949B8B979D8D989D8F9A9D919C9F919B9E939DA0939DA2929DA2929EA3939FA4
959FA196A0A1949FA095A1A095A2A097A3A097A3A094A19D95A19C96A19B96A29997A396
96A39494A29293A19092A38D575C5637393A3C413E303332282A2B2B2E2B292C2A242727
242926202521191E1A1518141418140F130F0E110B0E11090D11070D10060C10050D1107
0C10060C10070C10080B10080D130811180B131B0D12190B0F14080C1007181E111F2717
222A19242C1A252C1A262C19272D19242B17242C18222B171E27131A2210161D0F141A0D
0F14090C10080B10070C10080C10070C10060D11060B0E050A0D04080B02050800060900
040700020700020600010400
46515C4955604C59664C596A4E5A6D4E5A6E4D5A6E4E5B704F5B71515D73525D73515C71
525E71545F71545F7054606E56636F5663705764725865725864745A65795C667B5C657B
5C647A5C65785D66785D66785E677961697C616A7D61697C626C7D636D7D636C7C636C7C
646D7D646E7E656F816570836571836572806875806975816C77826F7A83727E87747D89
737C8B717C8B727D8D74808F75809075809077819077818E7A838F7D85917F8694808695
818796828B98828B98828B98828C97828C97838D99848E99858F9986909A87919B88929D
88939C8B959C8D979B919A9D919A9D919A9F939DA1939FA3949FA4949EA4949EA4949EA4
959EA397A0A3969FA2969FA297A2A297A2A096A29E97A39C97A39C97A39B96A29897A395
95A29394A29293A19095A5916770693130363C413F3537362C2D2C2B2E2B2A2D2B292B2B
282B2A1E2122181C1D14161413151011140C0E13090E13070D12040D10020C10020C0F02
0C0F030C10050D12070C11080B10070C12070E13080E12070C10050C1005192012212919
222B1A252E1C262D1C262C1B242919222918222A162029141C2411192010161D10151C0E
10160C0C11080A0F060C11080B10070B0F040B0F030A0D03070A02060801040700050800
040700030700010500000300
46515C4953624C57684B576C4D59704F5A714E5A704F5C72505D73525E72525D71535E71
555F73576374566172555F705762715863725763725865735865735B66765B66795C6679
5D667A5E67785F68776069785F6879616A7C626A7D616A7D636C7E646E7E646F7D646E7D
666F7E67707F6871806771836872846973826A75816C77836E7884707A86737D88747E88
757E89757E8976808E767F9078819078818F7882907883917A85927C85947D86967F8898
81889983899A838A99848C99848C99858D99868E9B878F9C88919D87929D88929C89949D
89949C8B979A8E999A919C9C919B9D919A9F929DA2919DA3939FA495A0A595A0A4969FA3
96A0A398A1A297A1A197A19F97A29F97A39E98A49D98A49C97A49B97A49B96A49996A398
96A39796A39694A39495A6956D786F3133383C4240383C3A3032313134322F32302F3430
2F34301C1F201B1D1D16181511110C1011080D10050C11030B10010C0F010D10030C0F04
0C0F060C0F080D120B0E120C0D120A0C11070C10070D11060D12051116081D2412232B18
252D1C252D1D252D1E242C1E222A1C232B1B222A181E26131A220F161D0E141B0E131A0E
12190E0F160D0D12090D13090C11070B0E040A0D040B0D04080A02050600030500060700
040700030600020500010300
49535F4B56664C576A4C586D4E5A70505C71505B72515C74515C74515D74525D74545D74
555E765760765661755861755962755862735A63755A64755A65765A66775A66775C6778
5E68795F6878606A79616B7A606A7B616A7E616B7E616C7F656F81646E7F666F7F677081
6972826971806872836972846973846A74846D76876F7989717A88717A87737D8A757F8A
757F8877818B78808F797F917A81927B82917B83917B84917C85937E86957F8899808999
838A9A848A9C848B9C848C9C848C9B858C9B888F9E89909F8A91A08A93A08C94A08B959D
8C979D8D979A8E999A929C9B939D9E959EA0949EA2929DA194A0A296A1A397A2A399A3A2
98A2A298A2A198A2A097A29E98A39E99A49E99A4A09AA4A099A49D99A49E99A49C97A39A
97A29997A39797A59498A895768277393B414148463C413E363A37393F38353A332E322B
3338301E1F1D1C1D1917181311130C0F12090E11060C10030C10020D11040D11060D1108
0E120C0E120D0D110C0E120C0F140B0E12080D11070E13060E13051217071C2411232B17
28301D28301F272E20252C20252D20222B1D21291A1E25161A2112151C0E12190C12180C
131A0E11180D0E140A0C11080C10070A0D04090C040A0C04080902060701060500060400
030400020500010400010300
49565F4C59644D59694F5A6E4E596F4F5A70505A70515C72525C72545E73556075545E75
545D76565E77575E775961775963765762745862745862755863755965775965785C6779
5D67795F6978606A795F697A606A7B606A7D616C7E626C7F656E82666F81677081687083
6971846972846972846872826A74836C76846F7987707A87717B89727C89727D8B727D8B
737E8A75808C777F8D7A80907C82907D84917D84917E86927D8691808995808998818A98
81899982899A818A9C838D9E838C9E838C9E868E9E89909D8A929D8B939C8C959D8D959C
8E979C8F999C90999C939C9E949D9F959E9F959E9F949D9E969FA096A0A097A2A297A2A2
97A2A198A2A098A3A099A4A199A4A099A49E9AA49F9AA49E99A39C9AA49B9CA79C9AA499
98A29798A39698A59297A7918391813F4346444A483A3F3D333732343A32343A302D3028
2E32291D1E191B1C1616171111130A0E11070E11050C10040C10030B10040B0E050C0F08
0D100C0E100C0C0D0A0D0F0A0E11090E13090D11050B10020B0E010C10031E2611232B16
272F1A272F1C252E1E242D1F262E20232B1D21291C1E2719192013141C1012190D0F150B
0F150C0D130B0D130A0B0F06080B03080A01080A01070901050600060700060700060600
030400010400010300000200
4A585C4E5B63505C6B505B6E505A70505A72515C73535D72535E70565F70565F71565F72
556074556075565F7758627957637956627855617557627757637758657958647A5B677C
5D697C5D69785E6B795E6B7B5D6A7B5E6B7C626E7E626D7F646D80677082687183677083
6871836972856972856A74856B75836D77826F79826F7A84717B87717C87717D89717D8A
727E8A737E8C76808F7981917B83917C84927C84917D868F7C878E7E8991808996808A99
808B9C818B9D808A9D828B9E848D9F858E9F86909D88929A8B959A8C95998B96998B9598
8E989C8F9A9C8E989A909B9D919D9E929E9E939E9D949E9D969F9F95A09F96A1A296A2A2
96A2A197A2A098A3A09BA6A19BA7A19BA6A09AA59F9AA59D99A59B98A39899A49899A497
98A49697A39698A49497A6928B9A88484B4C404544383D3B2D302D2A2D262B2F26292B23
2C2F251F211A1A1C1415180F11130A0F12070F11040E11040C10050B0E050A0D060B0E09
0D0F0C0E100D0E100B0F100C0E120B10150B1015070E14050E12040C0F031C230F232A16
262B18272E1A262E1D262E1F252E1F252E1F222C1D1E2618181F14131A1011180C10160C
0D12090C10070C1006090E04080C02080B00090C00080A00060800060800060800060801
040600030400010300010100
4A585D4D5A634F5B6A505B6F505A72505B74515B74525D72545F7055606F56616F55606F
5460715561725662765560775562795562775562755664765966795A667B5B677D5B687D
5D6A7B5C6A775E6C785E6A795E6A795F6B7A62707C62717D64717D687380687382687284
6872846871856974866975856974836D7883707984707986707B87727E89727E88737F89
75818C767F8D7981927B82947D84937D86947D85937D86927D87917D87917F89957F8997
7F8B9A818C9C818C9D838C9D848D9D878F9F89929F89939F8B949D8B959C8C969B8B969C
8C989D8D999E8D999D8E9B9D919F9F919FA093A1A094A19F95A2A095A1A293A0A295A2A3
96A4A298A5A299A6A29AA6A29BA7A19BA5A19CA7A39CA8A19BA69E9AA59C9AA69A9AA699
9AA79897A39698A39598A49495A491535756393A3E393D3D2B2D2D252924262A22232620
23261F20231C1C1F17181B1215180F16170D15170B1315090E12070C10070C10080C0F0A
0E110D0F130D10130D11130D12160F12170F11160B1015091115081114051417071D2010
202513242A17272F1B272F1D272F1E252F1E242E1D212B1B1C2416181F12141A0F10160B
0D10070C0F060C10060D11060B0F040B0E030B0F030A0D02070901050701050601070A03
070A02050700030400020200
4B59614D5B64505C6A515C6E525C72525D74515B73525D73525D72546071556371556271
5563725564725765755763765865785664755664725765735966745B68775C697B5E697D
606B7E606C7C606D7A606C78626C7A646F7C65727E67737E67747F677381677383687383
6873846872846A74846A74856B74856E7887727B89737B89747D89747F8B737E8B75808B
78828C78818D7A818F7C83927C84927D85937C85937D86957D87957C87947F88967F8996
808B98838D9C848E9C838D9A86909C88909E8B93A28C94A48C95A38C96A18C979F8D98A1
8C989F8E9A9F8F9B9E909C9E929F9F93A1A095A2A195A2A095A3A196A3A397A2A397A4A4
98A5A398A5A19AA7A19AA6A09BA7A09BA6A09CA7A09CA8A09CA89E9DA89D9DA89B9CA79A
9BA79999A59699A49699A49697A493585A5A3D3D42393C3D2D3031282B2A262A28242824
1F231E1F241B1F261A1D23171B20151D20131A1D0E15180B1014090E12080D11080B0F07
0C100A0F120D11151013171113170F11160C0F140A0E12070C11030C10020C0D011C2010
222716252A18272F1928301A27301A26301B262F1D252E1D2028181B2113171D1211160C
0E12090D11070D12070E13080E12070E11070E11070B0E05070902060801050601060802
070A03050701020400010200
4A56644D5968505C6D515C6E515B71535D74535D75556078545F77535E75546173556372
5563725665735967765966775865775865755966755A67755A68765B69775C697A5E6A7E
606A7F606C7E616D7D626E7B646F7D66717F66717E66727F677281667182667182687382
6975826A75836B77846C76866D76876E7789717A8B737B8B757C8B747D8C747E8D75818D
77828B78828B79828C7A838E7B85907B84917C85937D88957E88957F8796818999828B9A
828B9A848D9C848E9C858F9B87919C88919D8A929E8B94A08B95A18C96A18C98A18D99A1
8D98A18F9AA2909CA1919D9F939F9F95A1A196A1A297A2A397A3A498A4A499A5A49AA7A5
9AA7A499A6A29AA79F9BA89E9BA99F9CA8A09EA99F9EAA9D9EAA9B9CA9999BA7999AA899
99A7989AA7979AA7979AA6969AA7956163603B393F39373A2C2B2D262627232426252A29
1D211F242A21272D2120261A1D22161C1F13181A0D15170B1214091113090E10070C0E06
0C0F080D110A10140E11160F11160D0E12080B0F06080C02070A010709000A0A011E2210
242916272D18272E1828301828311926301927311B27301C232B191F25151A1F1112170C
10140A0F14090E13080D12060D11060C10060D10060B0D04090B03070902050700040601
040600030500020300010300
4A55674D586B515C70525D72525C74525D74545F75556077546076556077566276576474
5665755765765866765966775967775B68785B69785B68785C697A5D6A7C5D6A7C5F6B7D
626D7E636E7F636D80666F816771806973816873816872826872836973846B75856B7586
6A75856B77856E79866D77876E79896F7A8B707A8D727B8C757E8D747F8E768190768291
7682907884917885917985907A85917A87927C89927D8B927F8C95828D97828C99848D9A
838C9A848D9B848D9C858F9D88919F8A94A18B94A08A949E8B96A08E97A28E98A18D99A0
8F9AA1919BA3929DA3939FA296A1A298A3A39AA4A598A2A599A3A59AA5A69CA8A59BA8A4
9DAAA59CA9A49BA8A19AA7A09CA8A29FA9A39EA8A09EA99F9EAB9D9DAA9A9DAB9A9BA999
99A79899A7989AA89899A6969CAA987781763A383C3734372C2A2C2624262323252F3331
2528282527242528231E1F1B22251E23261D1E2116191B0F14150A1213090F11080D0F07
0C0F070D12080D12080D12080E13090F12090D1108090C030608010607000B0C031D2210
252B17292F1C2B311D2B321C2B331D28311C262F1A262F1A242C192026171C2214191E12
14190E11160B10150A1015091115090E12070D10060C0F050C0D040B0E04080A03070A02
060801040600030400030400
4B586A4F5B6E525E74535F74535E75515D73515D71536072546072566274586575576476
5765785663765765765867775867785B687A5967785A68785C697A5C697C5E6B7D606D7D
616D7C646F7E65708066708166718066717F6872816973846972846973856A74866A7586
6B75876B75876C76896E798A6F798A70798D727B8F737C8E757E8E747F8F737F8F758091
7682937884937885937885927A86927C89937C89927C8A92808D94808D94808B96838D99
838D9A838D9D86909F87909E8892A08994A08A959F8A959F8C97A18D98A18F98A09099A0
929CA2929CA2939CA2959EA496A0A397A1A298A2A398A3A39AA5A49AA5A49DA8A69CA8A4
9CA8A49DA9A69CA8A59BA7A59DA9A69EA9A59EAAA39EAAA19FABA09EAA9E9EAB9C9CA99A
9BA89A9BA89A9BA89A99A99799A9988594843D3F403232352D2E2E2827272223222A2C2A
2A2D2C2424262123241F2021414A3D30362B1F21181C1F1316180C1314081113080F1208
0C10050D11050D12070D10080D11090F130A0C1008080B030608010507000B0E051D2412
232A16272F1929321C2A341C2A341C28311B242D17222A151F26141C22131D22131C2114
1B1F12181D1114180D12160B13150A1114081014080F12080D10050A0E020A0E030B0E05
0B0F05080A02060601050501
4C59674F5B6D525F73525E73525F75525E72525E71515E6F525F6F546170556271556473
55647656647656667755657958677A58657A59667A5B69795C697A5C697C5F6B7E5F6B7B
626E7C64707D65717E646F7E66717F6872816873806A75816B75836A74836A7485697484
6A75856B76866C77886E788A6E78896E778970798C727C8D727D8F737F8F748090768291
7783927783937783937986937B87947E89947E89947E8994818B96808B967F8B98818B9A
828B9B848D9D878F9F89909E88909D88919F89929F8C95A28C96A18D97A28E97A19097A2
9199A2939BA1939BA0949CA2979EA5969FA498A1A397A2A297A2A299A4A49CA6A69DA7A7
9DA8A69DA8A79EA9A89CA8A79CA7A69EA9A59EA9A49FA9A3A0ABA29FAAA09EAA9E9DA99C
9CA79B9CA89C9BA99C97A69797A8978A99883F41412F30312E2F2F2A2B2A262825272925
2A2D292224231D21203239323A44372B32251D20151A1D1114160A121307121408101508
0D12050C11060C10070B10080C10080C10070A0D050609010809010608000A0E041C2311
1F2714242E1927311C28321B29321A29311A262E172127101E230F1B1F0F1D2012202315
1E21141D20131C1F131A1C1016170C13130912130916190C151A0A111606131808141A0B
1217090D12060A0C04050601
4D58664F5A6D525F7453607654617655627554617253616F53616F54636F556371556374
5564765665785766795766785967785A67785A68795C6A795D6A795E6B7C606C7D616D7B
626E7C626F7B636F7C636F7D65717F6771826974836B76826A76836A74836B75846A7584
6774836A77866B78886D79896F7A8A707A8B6F798B717C8F737E91737F91758191758291
7783927885937884937984937C86947E87957F8996818A98818A99808A997F8A9A80899B
818A9C848C9C878E9D888F9D89919D8B929E8B939E8D959F8E96A08F97A19098A2929AA2
9199A1949CA0949EA0969FA297A0A397A1A398A1A498A3A398A4A59CA7A89CA6A79CA6A7
9DA7A79EA9A89EA9A79DA8A59DA8A69EA9A39FA8A39FA7A2A1A9A1A1AAA0A0AAA19FA89E
9EA89C9DA99C9CAB9B97A89797AA978E9F8C454A46373B37373B3530332F2A2C27272A24
2D312922241F1D1E1A3A42333C4533343C282226151B1C0D1514091111071114090E1207
0D11050C11050B11070B0F060B0E060A0E05080A03070701080800080800070801191D0C
222916262E1C28311E28311C2B341C2B331B272E192429142226121E21101F2213232617
25281A242919252B1A2326171F201419190F16170D2024152529182125152126121E2511
1D2310171D0C0F1306060901
4D58674F5A6E535E7454607754627755627553607253616F53616E54636F556472546273
5664755967785A687A5967785967765B69765C69755D6A775E6A775D6A785E6A79606C79
616E79616E7A636F7B65717C67727E6873816872836974856A75866975866A7586697687
6876886A78896A78896D7A8A6E7A896F7A8A707A8B707B8E727D8F737F9074808F768291
7883947985947987957984947C87967E8A977F8A97808A99818C9B808B9C7F8B9C808B9C
818B9C848C9D878E9F878F9F88909E89909D8C939F8D959E8F979F9098A19199A2929AA2
9199A1949CA4959EA5949FA595A0A596A2A499A4A698A3A699A4A79AA6A79CA7A69DA8A7
9EA7A89FA9A99EAAA89DA8A59EA9A59FA9A4A0AAA49FA9A3A0A9A3A1ABA2A1AAA39FA8A1
9FA9A09EA99D9CAA9B99AA9A97A89794A691525852353737373A362E2F2C2425221E1F1C
31352B2A2E2320221922251A434D344753351E200F1D1E0F18170C14140B13140A111309
0E12050E12050C11060B0D050A0D050A0C04080902080600080600080701060600181C0F
232917282F1C29321E29331D2A321A293219252E16222A152129141E2313212515252A19
282D1D2A301F2B321F2C321F292D1D25291A2125192830203038242E342129301B282D18
262B16212714161A0C070801
4B58654E5A6B525E72536074546075546174535F71525F6F52626F526271566474566577
57657959677B5A687A5A677A5B68795B67765C68755E6877606A795F6C7B5E6C7B5F6D7B
616F7B61707B63707C67727F69738168738167728468728568738668738769758869768A
6A778C6D798D6D798D6E7A8E707C8D707C8C707C8C717D8D717E8E737F8F74808F768190
7982917A83927A86937A85947C86967E88977F8B987F8B98808A9B818B9C818C9B828D9B
848D9C858E9E848E9F858FA08791A18992A18C95A28E96A18F96A19198A3929AA3939BA2
939BA3949DA5959DA6949EA695A0A897A3A897A4A897A4A997A3AA99A5A89BA6A89DA8A8
9FAAA9A1ABABA0AAA9A0AAA8A1A9A5A0A9A4A0AAA6A0AAA7A0AAA7A1ABA5A1ABA49FAAA2
9FAAA19EAB9E9EAB9B9BAA9999A99799AB9760696235373A33363828282920211E181615
292D233136282D322322241839402B5260402022151D1E1219181014150D14140C12130A
1012071013060E12070E11070D0F050A0B030A0A030C0A030D0C030C0B04080902171B0D
232815292F1A2B311C2A311B272F18252F16212A111C251019210E1A2110202716252C1B
2A2F1F2C33212E36223139242E36212C341F2E3521313A2638402C363D282E351F2A2F1A
282C18272B181D2111101106
4D5A65505D6A52606E546171556074566175556173546171566472576674586577586679
58667A5A67795A687A5C697A5B68795B67785D68785F687B616A7C616B7D616B7D616D7F
636F7F62707E65718067718168738267738267748467738568728769728969748A69748B
6C768D6E778E6E788E707A8F707A8D707B8C717C8C727E8E747F8F758190768290778390
79828F7B858F7E87917E87917E87937E8795818A97828A99838B9B848C9A868F9B868E9C
868F9D86909F86909F86909F8892A28993A48C95A68E96A68F96A59098A39199A2929AA1
939CA2949DA3959DA4959EA5969FA797A2A998A5A898A4A79AA6A99DA9AA9DA8A79EAAA7
9FABA8A0ABA8A0AAA5A0AAA5A1AAA3A1ABA3A0AAA3A0AAA5A1ABA6A2ACA5A0ABA39EAAA1
9EAA9F9EAB9E9EAC9C9CAB9A9AAA989AAB9869736C37383E3032352224241E201D171813
1F2217272A1D2E342325291B4750398DA679343B2A12120C18191213130C111009101007
12120811130711140714160914160811130811120816180B191D0E16190B1214061F2311
272C172A30192A3019262B152228131F28111B220D181F0C171D0B1E2412272E1B293020
2B32212D34223037243139242F36212F3621323923343925363D28343B272F35202A301C
272B19292D19272B181C1F0F
4A58624E5C67525F6E546073566177566178556076546074566273586574596575596676
5A677A5B687C5B697C5C6A7B5E6A785D69785D687A5F697E60697E626B80616A80626D83
636E83646F836470826571816773816674836674846774866773876974896B758B6B758C
6C758C6E778C6E778C6F788D6F7A8D707B8C717B8B717C8C747E8E758091758291758090
7782907984917A84917C86927D87957F8997808A98828B9A838B9A848D9B858E9B848D9B
848E9C8490A08490A084909F8793A18A94A38D96A68D95A68F97A69199A6919AA58F9AA3
919DA4929EA4949FA4949FA5959EA695A0A696A2A698A4A69AA6A89BA7A99CA8A89EAAA7
9EACA79EACA79EACA69FACA4A1ADA4A0ACA39FACA2A0ABA3A3ACA5A4ADA5A1ACA49FACA3
9FABA19FACA09FAC9F9EAB9E9CAA9C9DAC9B76817738383D333635272B2820241E1D1F17
1C1C121D1F13373F2A3F49324C593E95B18144513A10110A1B1E1215150A111204121204
13130512130614160915170A191B0C191B0E18190E222816242C18212915202612272D19
2A311C282F1A242A141E240E1B210D1D240F1E25111F2510222713272C192B2F1D2C3120
2C32222F3625323826313925303723303623323824343926383E29363D293137252D3322
292F1E272F1C282E1B242817
4C58654F5C6B525F71545F76545F77555F77545E76555F76576276586477586477596578
5A667A5C697C5D697D5D6A7C5E6B7B5C69795C687A5E697E5F697E606A7F626C81636E82
636E83636F84636F836371826471816573826775856775886673866774876975896D778A
6E788A6D778B6E778D6F788E707A8D717C8D727D8C727E8B74808D768190768292758191
76828F7884907985937A85957C87987D88987F8A997F8A9A818B9B838E9C838D9C838E9C
828E9D828F9E83909F8491A18693A38995A48B95A58D96A58F98A58F99A48F99A38D99A3
909CA4919EA4939FA494A0A594A0A695A1A796A1A897A3AA9BA6AD9CA6AD9CA8A99DA8A8
9EABA99EACA99DABA79EABA7A1ACA5A1ACA3A1ACA2A2ADA3A4AEA4A4AEA3A3ADA4A1ACA6
A0ABA59FABA39FAAA2A0AAA09EA99E9EAC9E7D877E3D3C4238393A28292822241F1E2018
1C1D111F20134B573C536043525F43859F7246523817190C1E1E10191808151504171706
20211027291A1B1C121B1D13232719232A1A202716262E1A29311B28311A2A321D2B341D
2A331E28301B2229141C230E1E2610232C15262F172A321A2C331C2D33202D32202D3221
2F352632382A333929353C29333927303624323725383E2B3E45303A422C353C292F3526
2A3022272D1E262C1B25291A
4E5969505C6D536073535F75545F75525D74545E75556076566277586578576478596579
5B667B5C687C5C697D5E6A7F5E6B7E5C697C5B677C5D687D5E697E606B7F616C80636F81
646F816370826472846573836573836572826673836874856775856774846873866C7789
6F7A8B6F798C6F798E707A8D717B8D717B8D727E8D727E8D74808F768290788492788392
78838F7985917A87957C87967E88997E899B808A9B818B9B818B9B828D9B828D9C838E9F
83909F83909E85919F8793A38894A58A94A58C96A69098A89099A6919AA6919AA6929DA6
919EA392A0A193A0A394A0A395A1A497A3A798A3A999A3AA9BA5AD9EA7AF9EA8AC9FAAAA
A0ABAAA0ABA99FAAA8A0ABA8A1ACA5A1ABA3A2ACA3A3ACA3A2ACA3A2ACA2A3ADA2A2ACA4
A2ACA6A1AAA4A1AAA2A1ABA19FAA9FA0ADA0828981403E4638383C2D2D2D2122211E1F1B
1A1A132A2D1F5967485360424B563B6374504F593A42472B32321C282612211E0D363824
545C434F58421F20182022192B30232B32222A32202A311E2C331E2C341F2D36202B351E
2A321D2D361F2D351D29301929311A2A331C2B331C2E361E2E35202E34222D32212E3422
303625333928343B29373E2A363C28363B27353B263E4730404A3238422B333D282C3523
262D1E242A1C24281B222518
4E586A505C70525F74525E73535E74535D75545E77566179556177576378586479586579
59657A5B677C5C687B5A677A5C697B5D6B7C5D6A7C5D6A7D5E6A7E5E6A7F5D6A7E616E80
636F806470806472816572816673836774836774836873836775846975866B76886D7789
6E78896F788A70798B707A8A707B8B717C8D727D8E737E90737E91768194778293798592
7884907A86917B87957D87957F8897808A9A818A9C838B9E838B9E828B9D838D9E838D9F
8490A18491A08693A18995A38B95A68B95A68E97A89097A89299A8929AA7929AA5939CA4
949FA394A1A195A2A197A3A299A4A598A2A599A3A89BA5AA9CA6AB9DA6AD9EA8AD9FABAB
A1ABA9A2ABA9A2ABA9A2ABA8A1ACA7A0ABA5A0ABA5A1ABA4A3ACA6A2ACA5A3ACA4A2ACA4
A3ACA4A1AAA19FAAA09FAAA19DAA9F9DAA9B8D988B47484C38393D2E30312325241C1D1B
161613363D2C5665485462464D5A3F434D354B553A63704C5D644455583C3D392A828E6E
8899794B52432D2F2627281F2E32252F34252F35242C33232B33232C35242F39252F3A25
2E3823303A213039202D341D2C321B2D341D2D341C2C331C2D341E2D33202D32212D3221
2E3423313826333928343B28363D29363D28363C274149323E4730353E28323C262A3320
242C1B24291B25281D22241B
4C5768505C6E535E73525D74545E76565D77565E78576079586278586477586577596576
5966775C697A5D6A795C6A785D6B795C6A795C697A5E6B7D5E6B7E5E6B7F5F6C81606C81
616E82626E8164708266718367718367728568748667738568758769768A6B778A6D788A
6D778A6E788A707A8A707A8B707A8D727C90727D91758093767F92788193798392798590
79848E7A85907B85947E87977E8899818B9D818A9C828B9D838D9E848D9E838D9E858E9F
858FA08591A18694A38794A38995A38B97A68F98A79099A6929AA7949BA7949DA6959FA6
949FA594A0A195A2A197A2A299A4A599A3A69AA4A89CA6AA9DA7AC9DA7ADA0A8AEA0A9AC
A1ABACA1ABACA1ABAAA1ACAAA1ACAA9FACA89FABA6A1ADA7A2ACA8A2ABA8A3ABA9A2ACA7
A1ACA5A0ACA39FACA19EAAA09DAA9E9EAC9B93A18F4E4F503A3A3D2E30311F2021171918
111211333B2D5360475361484E5D4446533C57654A6A7B5B707E5D8C9B735C5F4AB4CA9E
88987B42473C3C4134373A2C37392A363A29353C2A343C2A3039272D37262E39272D3826
2E3824313B25303A232E36202C321B2D341C2B321B2A2F1B2D331F2E33212E33212D3222
2E3525303727333C2A353E2B363E2B363F2A363E283E472E3C452D353D27313A2529331F
242C1B23291924281B24261C
4C5967505C6D535F755360775561785660785660765760755964755A6776586675596776
5B68775C6B785D6C7A5C6C7A5C6C795B6A785C6A795F6D7E606C7F5F6B80606C81606C82
616D85616D846470846571846671846672866673876875866875866975876C778B6E788D
6E788D6E798C707A8C717B8E717B90737C93747E947681947781937883927A85937A8591
7B86917B85927E87977E879A7D889B7E8A9C818B9B828B9C838C9E858EA0868FA1878FA1
868FA2858FA38591A38693A48895A48996A48E99A7919AA6929BA4939CA5949FA895A0A9
95A0A894A1A694A1A495A1A498A3A69BA5A99CA6AC9DA7AD9FAAAEA0AAAEA2A9AEA1A9AC
A2AAACA2ABABA1ACABA1ADAAA1ADA9A2AEA8A1ADA8A1AEA8A1ADA8A1ACA8A2ABA7A3ADA6
A2ADA4A3AEA3A2ADA0A1AC9F9FAD9F9FAE9D98A7935154533535382F2F302526251F2120
1817182F332B4E5946525E4A505B47434C3B535F4969785C69765BA1B89086957ABDD8AD
727F6749503E424835373A29343525333525353927343C282F37242C36242D37262D3725
2F3824313B26323C272F38232D33202D3320292F1C272D1B2A301F2D34212F36232E3524
313828333A29353F2A36402B343F2A36402A3540293E492D374025323B212D361E29321C
272E1A272D19262B19272A1C
4C5867505D6D53617453607755617954607755607556617758657959677A5867795A687A
5A68775B69775B6B775B6A7A5B6B7A5B6A7A5B69795D6A7B5F6C7D5F6C7F5F6B7F5E6980
616C84616C856370876471866673866573856573856774836775826975836B76876E7789
6D78896E7B8C6F7C8D707C8E727C8F737D91757F94768192768291788492798591798691
7B88917B88937D88977F899A7F899B808A9D828B9D838B9E838BA0868EA2868FA2868FA2
8691A38590A28592A28695A38897A38998A28C99A3909BA5919CA3939DA4949EA7959FA9
96A1A996A2A795A2A695A2A796A3A899A6AB9BA7AD9CA8AE9DAAAE9FAAAD9EA8AA9EA9A9
A1AAAAA1AAAAA2ACAAA4AEABA4AFABA4AEABA3AEABA2ADA9A1ADA9A2AEA8A3ADA6A5AEA5
A4AFA3A3ADA2A3AD9EA3AE9FA1AC9F9FAD9E9BAA9B595D5E2F2C37312F3428272B212123
1C1B1D2E2F2B535C4C586151474C4230312B3C3F336773595E68539DB18DACC29DAAC29B
59644E383E2C3438252525172525182A2C1F2E32232D32232A2F20282E202A32222C3522
303923323C24323B252F37232D35222B332028301E272F1E28311F2B34202D36222E3623
313825353C29363D2A363D2B353D2A343C28333D283B452D343F27303A222C351C28321A
262E18252C16252A16262A19
4E5B67515E6C546171546074556076555F77535E7556617958657B59667C5A677C5A687A
5967765B68765C6A785B697A5C697C5E6B7D5D697C5C697C5D6A7E5F6C805E6B7F5E6B80
5F6B82606C82626F836470856773856773846773846774836975846974826B75836D7787
6D78886E7A8C6F7D8E717D8F717D8D717D8F747F9276829277839178859078858F79878F
7B88917E88947E88957F88967F899980899C81899D828B9F838CA0868FA28790A28690A2
8692A28591A185939F8796A08897A18A98A28B99A38E9AA58F9AA5929BA6949DA8949FA8
949FA895A1A996A2AB96A3AC98A5AC99A6AC9BA8AD9BA8AD9CA9AC9DAAAD9DA8AA9EAAA9
A0ABA8A1ABA7A4ADA9A5AEAAA5AEAAA5AEACA4AEACA3AEABA3AFACA1AEA8A1ADA4A3AEA3
A3AFA3A4AEA3A2ADA1A3ADA1A1AD9F9FAE9D9DAD9C5D6261302D382D2C33232128201D21
201F203538325F6A5771816843473F302F2D30302D5E69535A634F7785678EA27C819571
4E5A42363D2B2A2F1E1F22151D1F1523251B26291E282C1F272B1D25291D272C1E2A311F
2D35202F371F2C321D292F1E2B32202A332027301E272F1E26301D28321E2B36202D3821
303820323922333925343B27353C273138243037243A422B343D282D36222A321E28301B
262D19232A17242917262B1A
4E5B68515E6D546071545F72545F74566177555F7857627C59657F59667D59667B5A687A
5C69795C6A785D6B795C697A5C697D5D6A7E5D697D5C697C5D6A7D5E6C7F5D6A7E5D6B7E
5E6B7F616E81636F826670856770866972866A75866B75876C76886C76876C76866D7788
6F7A8B6F7A8D707B8E727E8F727E8F727E8F7481907582917683917784917884907A8790
7B88907D89917D88927F88947F88958089987F8A9A818B9C848D9D848E9F858FA08690A0
8791A18792A18694A08795A08A97A38E9BA68F9BA8909BAB909BAA939EAC949EAB949FA9
94A0A896A2AA96A4AB96A3AB98A5AB99A7AA99A7AB9CAAAC9CAAAB9EAAAB9FABAB9EABA9
9FACA7A1ADA5A4AEA8A5AEA8A4AEA7A5AFA9A5AEA9A4AEABA4AEACA3AEABA3AEA7A3AEA4
A4AFA4A2AFA2A1AEA2A1AEA1A0AEA09EAE9D9DAE9B676F6B3E4146303137242429222022
1C1A1B373B3356624F61705A55604F40453B373A3356614E5C6852545F4958654B57664A
4F5C41373F2D29302121261A1D211521241724281A272C1C252A1B212416222517242A1A
272D1C252C1B202418262D2028302129312028321F28311C28311B29321B2C361E2E371D
2F371C2F361C2F361E323A23323A232D332031382439412A343C263037232C33202B321E
2A301E272D1C252B1A272E1E
4D5B67525E6E535F74535E76545F77545F7755607A57627D5A65805A65805A667C5C697C
5D6A7B5C697B5D6A7B5C69795D6A7D5C687E5D6B7E5D6C7E5C6C7C5D6D7B5E6E7A5F6F7D
6170816372826371836471846671856771856973866B76876B75876D77896C77886E788A
6F7A8B6F7A8D707B8E727D8E737F8F73808E74828D7683907683917784927884927A8893
7B89937D8B927D89947F8995818B95828C98828D99828C9B838D9B858E9B85909C86919C
88939F88939E88949E8A96A18C98A48E99A78F99A8919AAB919BAB919DAB939EAB929EA8
94A0A994A1A895A3A896A4A898A5A99BA8AA9CA9AC9DA9AC9EA9ADA0AAADA1AAAFA1ABAD
A1ABAAA4AEA9A5AFA9A5AEA9A5AEA7A5AEA6A5AFA8A6B0AAA6B0AAA6B0AAA5AFA7A4AFA3
A4B0A3A4B0A1A2AF9FA1AD9EA0AE9F9DAC9F9DAE9D79857C454A4D363A3D2C2E2E272825
22211D31322A474C3F4A5245505C4B444E3F39413357664D606F544D59414B573F48533B
454E37353B2A2D322425281D1F221822251924291C22281A1F25161D2113202516232919
252A1C252B1D191C1424281C272D1E272F1E29321E2B341E2C341D2D351D2E351E2F361F
3037202E351F30371F3036212E34202B301E303621384028333A212F371F2B331F2A311F
28301E292E1D272D1E2B3123
4C5A69515D70535F77555F7B55607B55607B55607B57607C5A637E5A657D5D687D5C697B
5E6A7C5E6B7C5E6A7D5D6A7D5E6B7E5E6A7F5E6C805E6C805D6C7F5D6E7E5D6E7C5E6F7D
60707F637181616F806270826471836672856872866A75876C77886B77896C77896F798A
6F7A8B707B8D727D8E737E8E74808E75818D76838F7783927783937782937884947A8795
7C88957F8B97808B97808996808A95818B97828D9A828D9C838E9C848E9B848E9B86929D
88939F88929F8994A08C96A38F99A78F99A89099A99199AA919AAA919CAA929EA9929FA7
94A2A995A2A996A3AA97A5A999A6A79DA8AA9EA9ACA0AAAFA0A9B0A2AAB1A3ACB2A4ADB2
A3ABAEA4ADACA5ADA9A6ADA8A8AFA6A7AFA6A6B0A7A6B0A7A6B0A6A7B1A5A5B1A2A5B1A1
A4B09FA6B19FA5B09EA4AE9EA1AE9E9FAD9E9DAD9D829083484C4D393B3C2F31302A2B28
28272229282238382F494E3F4852403F4838373F2E5463476476554F5C404A563B495338
4349313639272F3122282A1E21231921251A242B1F222A1E1F271A1F2618222A1A242B1A
222A19222819161A0F1A1D11202214222716272E1B2A321D2C341D2E361E2F3720313823
3339252F36233036232E34222D32202A2F1E3137243C442C333A222F371E2B331D29321E
282F1E292E1E2A2F202D3323
4D5A6B515E72535E76545F7A54607C55617D55617B56627A59637A5A647B5D687D5D687D
5D697C5D697A5D697B5D6A7D5E6A7F5C697E5D6A805F6C825D6B805D6B805D6B7F5D6C7D
5F6E7D62717F61707E63727F6573806673826975866A75886B78896B78896C7A8A6E7A8C
707B8D717C8F727E8E727F8D737F8B73808B73818D7583927783937783947884957B8796
7D8896808A96808996808895818896808999838C9C828D9C828D9C848E9F858FA08691A0
8692A08792A08A94A38D98A78F9AA98F99A9909AA8909AA6909AA5929DA6929EA693A0A6
95A3A695A3A797A3AA99A5AB9AA5AA9CA7AB9FA9ADA1AAAFA1A9B0A0A9B0A2AAB0A3ABB0
A3ABAFA3ACACA5ACA9A6AEA9A8AEA7A7AEA6A7B0A7A7AFA9A6AEA7A7B1A6A6B2A4A6B1A2
A4B0A0A5B1A1A6B1A2A5AFA1A3AEA0A0AC9D9EAD9C8B978A484A4E37363B3231322E2D2C
2C2C2A2C2C2732342B4D56434A54403C4533333A2B48533E697A5B515D4349533A495138
454B323A3E2730341F292A1A23241721231722261A23281B24291D24291C232A1B262C1B
2227171C201216180D12140A15160C191C0E282D1A2C311F2E3420303723323925323927
343B27353C283238242F34222E33212A2F1E3137243B432D333B252F38212B341D2B331F
2B3220292F1F272E1D2A311F
4E596E525D74535F78545E7956617D555F7D545F7B56627B58657C5A667D5A667C5B677D
5B687C5A677C5C687C5C697D5E69805D68805D6A815D6A815C6A805E6B815F6C81606D80
606E7F62707E63727D65747E65747D66737F6974836B76876C76896B76896C788A6E7A8D
717A90727C91747D90757F9074808E75818D75818D75818F7783937884977883967C8698
7E87997F8898808899808998818998818A9A838B9B838C9B848E9C848E9F8690A18691A1
8792A18793A08994A38C97A68D98A98E98AA8F9AA8909BA6909BA6929DA7929DA5939FA6
93A1A695A2A796A2A799A3A79AA4A99DA6AC9FA6ADA0A7AE9FA7B09FA8B0A0A9B0A2AAB0
A3ABB0A3ABAFA4ACADA4ACABA6ADABA6ADABA7AEABA7ADABA6ADA9A4AEA6A4AEA4A4AFA3
A3AEA1A5AFA2A5AFA3A4AEA3A3ADA2A2AD9FA0AD9E8C988C494A503C3D413A3B3B383834
32312D2E2C2832332C525B48525D48434C39343B2B424C37697B5A535F444A533B474F36
454B3342472F373A272F2F1F2A2A1C28271C282A1E26271D24261E23251D2023191F2217
1D2114181B0E13160A0F13070D0F060F1207272F1A2C331E303622323825333926323827
3239273239263036232E34212D32202B301E2D3422313C262D37212B351E28321C28311C
2A311E292F1F262B1D2A3220
4E596D515A72535E78545E7B565F7C56617D57627D58637D59657D5B687D5B687D5B687D
5B677D5A677D5C687E5D6A7F5E69805C66805C677F5B687E5C6A7F5E6B7F5F6D815F6C81
5F6C7F616E7F62707D63717C63717D6672816872856A73876A73886C758A6E778B70798D
717A90747C91747D90757E907680917581907682907582917783947883987983987A8498
7B85997E879A818A9D808A9D808A9C828C9C828C9D838C9D838D9E848EA0858FA08690A1
8790A28791A48994A58994A58A95A68C97A88C96A98D98A98F9BA88F9BA6909DA693A0A7
94A0A896A1A997A1A99AA3A99CA4AB9EA5AC9FA7AF9FA8AFA0A7AFA1A8B1A2A9B0A2A9B0
A2ABB1A3ABB0A3ACAEA4ACAEA4ACAEA5ADAEA5ACADA5ACABA5ADAAA4ADA8A4ACA7A4AEA5
A4AEA4A5AFA3A6B0A4A3ADA3A2ACA2A1ABA0A0AC9F919E924D4E544244484347433C3F38
30302A2D2C253030294D53444C53423E45362F34283C44316E825D566547475138485239
464E35454B344347323C3D2C37382B32332A30302A2A2A2424242020211C1E21191E2117
1D2115181B0F13170B1014070E11060A0C042128182F38232F3822313924303925303925
3039242E36232E36212E361F2D331F2A2F1E2C34222F3A252B351F29331C2A331C2B311C
2B311E2B2F1E282B1C292E1E
4D596A505A70555F7756607A555F7A57637D58637E59647F59657F5A657E5B677C5D687D
5B687C5D687E5D687F5D68805E69815E69815D68805D697F5E6A805E6B80606D80606D80
616D81626F816471816673826671836772856973896A758A6A74896D768C6F788E707990
727B91747C92737C90747D91757F937581937681937782947883967984987A85997A8699
7A85987C879A808A9D818A9D80899E818A9E838B9F838C9F848DA0858EA0858E9F8791A1
8891A28892A48A94A68A95A58B97A78C98A88C97AA8D98AA8F9AAA909DA9929EA8949EA7
96A1AA99A2AB99A2AA9BA5AB9CA4AB9EA6ACA0A8AFA0A9B0A0A9B2A0AAB4A1AAB3A0A9B1
A0ABB1A1ABB0A2ABAFA5ADAFA5ADAFA5ADAEA6ADADA6ADACA5AEABA5AEA9A5AEA8A4AEA6
A5B0A7A5AFA5A5AFA4A4ADA4A3ADA3A2ACA3A0ABA196A2985253583C3C434142413D3D38
32312A2F2E253230274A5040494E3E3F433533362B3A3F3170815F59674C454E3A4A543E
48513B464E384B4F3A4748374545373E3E3539383233332E2A292725262220231A1D2014
1A1B1016160D13150B1114090F1208090C041D25162F39252F38253039262E37252D3824
2D38232D38232C36212D37202B331F2A311F2A33202C36222A341F29341E2B341F2B331E
2B311C292E1C2B2E1D2D3220
4D5869505B70545F7556607757617959647C5A637E5A64805B65815A64805B677F5C687D
5B687B5C697C5D697F5D6880606A82606A835F68825F6882606983606A82606B80616D81
626D81616E816370836672866873866973876A748A6C768B6C758B6C758C6E77906F7992
717B93737D93747E937580937480927580927783937883937982937A83947B84977E8698
7E88987F8899818A9B818A9D81899E818A9F828B9F838C9F848D9F858FA08890A18991A1
8991A28A93A58A93A48B94A68C97A88D97AA8E98AB8E99AB8F99AA929DAC949EAB949EA9
969FAA98A1AA99A1AA99A3AB9AA4AA9CA6AB9FA8AE9FA8AF9EA9B19EA8B29EAAB29FAAB1
9FAAAFA1ACAFA2ACAEA4ADACA4ADABA5AEABA7ADABA8AEAAA7AFA9A6AFA7A7B0A5A6AFA3
A5AFA4A5AFA4A6AFA5A6AFA5A4AEA4A2ACA2A0AAA19BA89C6165653E3D434041423E3E3A
36353033312B33312A484B3C4B5140414537313329363A2B6D7D5B667556454B3A4A513F
48503E454C3A5156415D634B5559454C4D3E42423742453B29282626272221231C1C1E14
19190D16160913140912140A1012080E1006171A0C282F1C29301B29301E262D1D252D1D
2831202C37232A352228311E28311D29321C29331D2D381E2D381D2B341C2B331D2B321D
2A301D292F1E2B2F1F2E3321
4D566950596F535D74565F765860775A637A5A637C5A637F5A64805A65815B66805B677E
5A677B5C697C5D687E5D687E5F69806069815E667F5F6780626A81616A80616A80616D82
636E816470826470836671856872856972866A73886C73896D74896D748A6E778D6F798F
727C92757E94757E95757E95757F95757F947680947782937883947983937A84937C8594
7D86958088968088997F889A80899D7F8B9E7F8A9D7F8A9B818D9C848E9D868F9E88909E
88919F8891A08993A18B95A48C95A78C96A78E98A88F9AA9909BA9929CAA939DAA959EA9
969EA997A0A998A2A999A3AA9BA5AB9CA6AB9EA7AC9EA8AD9EA8AF9CA8B09CA9B09DABAF
9FABACA0ABAAA1ACAAA4ADAAA5AEAAA5ADA9A8AEAAA9B0A9A8AFA7A6AEA5A6AFA3A6AE9F
A6AEA0A7AFA3A7AFA4A7B0A4A5AFA3A3ADA2A1ACA1A0AEA0686D6C3937404040423A3A38
3E3F3A42443C474B3F4B50414A4F4041473833372C32372A667757708160444A39474E3E
464D3E414638545B46899A766A725A636A566068564D53482B2B2927292520211B181911
13130A111006100F051010061213091213091416092328142328122125121D21101E2313
262C1B2A321F252D1C1F2516222918262F1C29321C2D381E2D371D2E361C2D341C2D331C
2A301B2A2F1D2C31212D3322
505969545C6E575F7657607659627959647A59657A5A667D5B677E5B687E5D687F5D687E
5B677C5C677C5C677D5D687D5D697E5D697E5E697F616B80616B7F636D80626E81637082
636F816773836872836871846872866972866A74876B75886F7688707788727A8A727B8D
747C90777D94777D96757D97747E96757F95778095788296788396788494788493798494
7C86957F899681899A80899B808A9C7F8A9C7F8A9D808B9C818C9B838E9C848E9B87909C
89929D89929E8B95A08D96A28E96A38F97A5919AA8929CA8939DA8949EA8959EA8959DA7
959EA697A0A69AA3A799A3A79DA6AA9DA7AB9EA9AC9FA9AC9EA9AD9EA9AE9DAAAE9EAAAC
9FABAAA0ABA8A3ADA9A5ADABA7AEACA8AEABA8AEA9A8AFA7A7AFA5A5AEA3A5AEA3A6AFA2
A6AFA1A6AFA2A9B0A4A8AFA3A5AEA2A4AEA3A1ACA2A1AFA36B707235333E3F3F3F373633
5155465358465E644F5A604B4F54434D54433C42353940336070566B7C5F4A5341495240
414739363A2E4E564497AC888B9C7E87957A86947A585F522928282628231E20181A1C12
15160B1112060F0E04100F0514130916170C181A0D1D22101E240E1B220D191F0D191D0D
262B192E35221F231714160E202618252D1C2A331F2F37212F361E3036203137212F3520
2C321E2C321F2D3323303726
4E5869535E6F5962785A637B59637B58647B57637A59657B5B667B5B667C5E687E5F697F
5D687D5B677C5C677C5C677C5D687C5F6A7E5D687E5E697F5F6A7F606A7F616D80616E80
626E806571826872836872846972876A74866A74866A74856D77886F7889717A8A727B8D
747C8F757C92767E95757E97757E97767F967981977981987A81977981967B84957E8799
7F89997F889981899C80889D7F879D80889D818A9F838CA0828B9E828C9F838D9E868F9D
88919E8A929F8B949F8D96A08E97A19098A29299A4939BA6949BA8949DA7949CA8949BA8
959DA897A0A999A3A89AA3A79DA6A99EA6AA9EA8A99FAAAB9FA9AB9EA9AB9DAAAA9DAAA8
9FAAAAA1ABABA2ABABA3ABAAA5ACABA6ADABA8ADA9A9B0A7A8B0A6A6AFA4A6AFA4A6AFA4
A6AFA3A7B1A3A8B0A2A7AFA3A5ADA3A3ADA3A0ABA3A0AEA4737A7A3E3E473E4041363836
5159494F5543626A51616951515745525B49414A3B3B43355A684F697A5C4F59434C5540
40453433342950564491A4838D9F8191A28499AB8C6C7763221E1F2423202022191A1B11
15150B121207110F06111006181B0B1C1F0E1E21111E24121D24121A2111171D0F16190F
3239293D4532151712090A081E24182D362330372232392230361F30361F3236222F3422
2D32222D33222E34232F3625
4C586B515D7155617655607957627C57627C58627A59637A5A647A5B647B5B647C5B677C
5A677B5C697B5D697B5C687A5C697A5D697C5D677D606A7F616B7F5F6A7F606D81616D81
626E81646F836571846772846872866974866A74866A74876D768B6F778C70788D717B8F
727C91737D93747F95757F97777E98787E987A80997A80987980967980947C82967F8497
80859980869A80889B80879B7F869B80879C80899E818BA1818CA1838CA1848DA1858D9E
88909E8892A08A93A08C94A08B95A18C95A18F96A39199A5929AA6939BA89199A8929AA9
949DA9969EA9979FA9979FA898A1A899A3A79BA5A89CA7A89DA8A99EA8AA9DA8A99DA8A7
9EA9A9A1A9ABA1AAABA2ABACA3ABACA4ACABA6ADAAA8AEA9A6AFA5A6B0A5A5AFA4A4AEA3
A5B0A4A4AFA3A5AEA1A5AEA3A6AEA3A4ADA3A1ACA1A0AEA27F888247484D4245453A3E3A
40453C474E3F58604B68745A4F5645535A48454D3D394031515E466A7D5A5563474E5940
4A523B3A3E2F4C52418EA1808A9B7E8C9C8196A689818F752E2D2925221F22221C1C1C16
17160E131209111107121206181B0B1B210E1C21101F25131E24141D2314191C0F13140C
2A2E243E47381A1D1A0B0D0C181E14303A252E3721333A2331371F3036203137232E3423
2D32232E3325313725323825
4B576A4F5B71546077545F7757627A58637C5863795964785A66795C677B5C677C5B667A
5A67795C687B5E6A7B5D69795E6A7B5E6A7C5D687E5F697D606B7F5F6A7F616D81606D81
616E81646F836670846770846772856973876A74886A73896C748B71778E737A8F747C91
747E92758093768095767F97777F98777F987880987881977981967B83957D83957F8395
7D81947E84987F869A7F879B7F879B7F899D7F8A9E7E8A9F7F8B9E818DA0838DA0858DA0
868FA08891A18892A28B94A48B95A58A95A58C96A58E97A6919AA8929BA9919AA8929BA7
929DA7949DA997A0AB98A1AC98A1AC97A0AA9AA3AB9BA5AB9CA6AC9DA8AD9DA9AC9DA8AA
9EA9ACA1AAAEA2ABAEA2AAAFA4ACB0A5ADB1A4ACAFA5ACABA5AEA8A6AFA6A6B0A5A4AFA3
A5B1A4A3AEA3A4AEA3A4AEA3A4AEA3A4ADA3A1ACA2A1AFA48B968E47484D3F4041393B38
3F423B4B51454D53466B79624B52454F5749475041363C314B57446D815F58674A4D5940
4B573E444E3948503E8B9D7B8C9D7F8A9A7D8E9D828F9D824D50462825242524221F1E1C
19191415140F14140D15160C1A1E0F1C21131D22132025152126161F22141A1A0E16150C
1E1F172D31283E47390F11110F130F2932212D35223036232F35222E35212F36232F3421
2E3220313423343827353A28
4E596C505B72525E77515D76535E775460765561755763745865745B67785D697C5B667B
5A677B5B687C5B687C5B687C5D697D5E6A7E5D6A7E5E6B7F5F6B805F6B80606C81616D82
606D82636F82657083666F846670846871876A73876A73876D778A6F798A70798A727B8C
737D8D747E8E757E91768094758096757F967580977782997982987781967A82957C8396
7B81957B82967D84987D85987E889A7F899D808BA1808BA17F8CA0808DA0818DA0838D9F
8690A18791A28790A28892A58994A78894A68A95A68B97A68D98A68F9AA58F9BA3909BA4
919DA6929EA895A0AA96A0AB97A1AC98A1AC99A2AD99A4AE9AA6AF9CA7B09CA8B09DA8AF
9DA8AE9EA9ADA1AAADA2ABAEA4ABB0A3ABB0A4ACAFA3ACABA4ACA8A4ADA7A3AFA7A2AFA5
A2AFA3A2ADA2A3ADA3A4AEA4A3ADA2A2ADA2A0ABA2A0ADA38F9C934A4A513E3E44393A3D
474D475A635550564C6875624951484C564B454F44353C35455042697D6059694F4C5842
4C574247513F4750407F90728A9C7E88977D89987F8997816973643E413C262727212224
1E1F1F191A191818141A1C131D20152123182224182427192527192022151B190F1A1810
515C443F4738596550111211121411252B1F2A31212C32212D32202E33212D33212F3421
2F341F333723363927363927
4E5A6C505D72535F77535F77536077556276546273566373576474596676596678596679
5A667A5B687C5A677B5A68795A67775C69795C697C5E697E5F6A7F5F6B7F5F6B805F6B81
5E6B80616E81626F826370826571856671866973876973876C77896F7A8B707A8B727D8D
717C8D727D8E737F8F7580927581937581947580937780957780967981967A8297798297
7A82977A83977A84967C86987E879A7F899D818A9E818AA0808BA1808CA2818DA3828DA2
8490A28590A28691A28792A48892A48893A58A94A68B96A58C97A48F99A4919BA3929DA3
939EA4929DA6949EA896A0A996A1A998A2AB98A2AC99A3AD9BA7B09CA7B19CA7B09DA8AE
9DA7AC9EA8ABA0AAABA1ABAAA4ABACA4ABADA4ACADA4ACABA3ACA9A3ACA7A2ACA7A1ADA6
A0ADA4A1ADA3A3AEA4A3AEA4A2ADA2A1ADA29EAAA19CA99E8E9B904D505443454A404445
4D544D636D5E52584E5B65584C544B4B5448444D41353B334751416171565C6B514F5B45
4D5744495142495043808F74899A7E88967E89978084917D85937D727D6A201E211F1C21
1B191D161417151313191A151D2016202217222418272A1B2A2C1E2222161C1911191611
63705767775E4751441010131518182F382D2F382C2F38282C34222D34212C34212D3321
2D3421303622333925363A27
4A586A4D5B70505E74515F76525F775462775563755664755765745865755966765A6777
5B68785B68795B68795C6A795A67775B67785D697D606980616B84606B82616C83616D81
5F6C7F616E7F6270816471836572856873886C768B6D768B6E788D727C90737D91737D91
717C91727D92747F927681937682927682937882967781957781957882987A839B7A839B
7B849B7B879B7C869A7F899C80889B808A9E808A9D808BA0808BA1818CA3828DA6828FA6
8390A5838FA3838FA18691A28893A48B96A88D97A78D96A58E98A69098A5929AA6939BA4
939DA4949EA5969FA597A0A797A1A798A2A798A2A89AA4AB9BA6AE9BA6AF9BA6AF9CA6AE
9DA7AE9EA8AE9EA8AD9FA9ADA2ABADA4ACADA3ACACA2ACABA3ADAAA2ADA9A2ADA8A2ADA9
A1ADA9A3AFAAA1ADA6A1ADA59FABA49DA9A09BA89E99A79B8D9B90575C5E45484E4A5152
616C605C655751574A52594B4C54474851443F463A33382E3E4636647457617156525E48
4C5643484F4045493E7A88708D9F828998808B9A8386937F8C9B8385947D2422231B161B
1D1A1C171416141011141210191913212318313424373A2933362724261A1C1D1317140F
545C487E906F55604F1C1D1E141519323C34333D322D37292933222A33212A32202A3320
29311F2B33212F3824333A27
4856684B596C4F5E71505D74515D74535F765563765765775865755966755A66775C6878
5A66795B677A5B677B5B687C59667A59667B5C687E5F69815F6A82606B83616D83616E80
616E7E626F7E63717F6572836873866A76896C778D6F788F707990717A90737C91727D91
737E9274809474809474809375809376819578839777819677829978839A79839B79839B
7A859B7B869C7C879B7E889C7F879C80899E7F8A9F7F8AA17F8BA2818CA3818DA5818EA5
8490A68490A6838FA58691A48892A58A95A78C96A78D97A79098A89098A9919AA9929BA7
929CA5949EA696A0A696A0A796A0A699A3A899A3A99AA4AC9BA4AD9BA5AF9BA5AE9CA7AE
9DA7AF9DA7AF9EA8AF9FA9AFA2ABB0A2ABADA3ACABA4AEABA3ADAAA2ACAAA2ADAAA1ACA9
A2ADAAA4B0ACA2AEABA2AEAAA0AAA79FAAA49DA9A19CAAA096A49A666C6C45474C4C4F4D
88977D595F5054594A5A62524C54483F463E3438342A2D2A353A3163735864745756624A
5059444B524143483B73806792A5848B9C808D9E8389987F89987F8B9B8031312E1B171A
23211E1B1917100D0D0D090A100D0C34382A5B674C606C534A5241282B2424261F22221F
5A64527A8B706E7D663237311413163C473B323A30293126262E20262E1F272F1E29321E
28331E2A331F2E3621323824
4955684B586B4F5B71505D74505C75525E775460765563765663755865785B657B5C657B
59647C5A657E5B667E5C687F5B687D5B677D5C687F5D68805E6A805E6A7F5E6B805F6D80
616E7F626F7D62707F6472836875876B7A8B6C788B6D798C6F7A8D707B8F707B8F727D90
737F90748092737E93737E94747F94757F95768096768097768198758098778199788398
7884987A859A7A859A7B869A7B85997D879E7D89A17D89A27C89A17E8BA17F8CA2818EA4
8490A68490A6838EA6848FA68690A68791A58A95A78D97A98D97A88E98A9909AAA909AA9
909BA8919CA8939EA9939EAA939EA995A0AB98A2AC99A3AE98A2AE9AA4B098A3AF9AA5B1
9BA6AF9DA7AF9FA9B0A0A9AFA2A9AFA2ABADA3ADABA4AEAAA3ADAAA3ACAAA2ACAAA2ACAA
A1ACAAA1ADABA2AEADA3AEABA1ABA8A1ABA6A0ABA59EAAA59BAAA46B7275494B51454746
5960514F54474B50445F6958525B4F444B443A403D2D31303036315767515F6E5356624A
535B474D534341463A68755F91A584899A7D8D9C828C99818B98808F9E844040391D1718
25221F1B18150D0A080907050B0909454E3E849A787E927476876D3A3F3B434A454E564F
64726173846D6F80694952451B1D1B49554332372D2B3226272D20252C1E242D1E252F1D
26311C2A331E2E3520303521
46526749566C4D5A724F5A74515D77515D77535F7754607856627857627959647A5A637B
59627D59647E59657D59657C59657C5B677D5B677F5C67815E69825C69805D6A7F5E6B7E
5E6B7D606D7D616F7E6573826876856A78876A79896C798A6F7A8B707B8E707C90717C91
727D8F727E8F727D90727C92727C92747E92757F94757F95757F95758097768098778198
7882997984997985997985987A85987B869A7C879C7D879D7D899D7E8B9F7E8B9E7F8BA0
828EA3818EA4818EA4828FA38591A48793A48A94A78B95A98A95A88C98A98E9AAA8F9AAA
8E99A98F9AA9919DAA919DA9919DAA929FAB94A0AD94A0AD94A1AD97A3AE98A4AF9AA5B0
9AA5AF9CA6AE9EA9B09FA7AE9FA7ACA1A9ADA1AAABA2ACA9A3ADAAA2ABA9A1AAAAA1AAAA
A1ABAA9FABA99FAAAAA1ABAAA2ABA9A0AAA79FA9A69DA8A59DABA46D757744474E434747
3E433E42473F41473F6C7A67535E5449514C434B46323735313833475242535F4A505A47
4F5546494F443F423B68766390A4878898808C9B848C99848B98828F9E8540413B1D181C
2522211C1B1813130F0E0F0B0E0F0C292F2568795C7B8D6D8394745F68586B7666717E6E
71806E717F6D71816D616E5C3F463D505B4A343C302B3226272D1F232A1C232B1C262F1D
262F1C28311D2D3520313824
4757694A5B6E4E5E73515D74515D75515D75535F76545F7854607A55617B566179576279
58637959657A58657B5B677D5C677F5C687F5B677F5C68815E69835D6A815E6B7F606D80
606C80616D806270816573816978846C7B866D7B886D7A8A6F7A8B717B8E717D90727C90
717C91727D91727E91727C92737E93757F94757F94757F94778196798398788299778198
77829978859B7A869A7986987A86977C88997C889A7D899B7E8B9D7E8B9E7F8C9E7F8C9F
818DA0808DA1818EA2838FA38491A28793A48994A58A95A68B96A78C98A98C99A88D9AA7
8D99A68D9AA78E9AA7909CA7919EA892A0A894A1AA94A0AB95A1AC96A1AC98A2AE99A3AE
9AA4AE9CA6AE9DA7AE9EA8AFA0A9AEA0AAACA1AAABA2ABAAA3ABAAA3ABABA3ACAEA2ABAE
A1ABADA0ACABA0ACABA1ABABA0AAA99FAAA79EAAA59CA8A09EACA1767F7E41424B3C4043
383D3B3F463F4951478194795E6A5A475046454D44323632333830444C3E4B53444F5747
5057484C51453C3E39646E5F94A78A8A9A808D9D838B9B838A998191A286484B43181215
201E1C1A1A1816161412140F12140F161711262A1E525C44829571717F6676836D788771
77867175836F7584706F7E6A63706063725E394035262B21262E1E232B1A242C1928311C
29321D2C3620303824333926
49576A4B5B6E4E5E724F5D72505C71515D7254607655617856627A556179566278556176
58647758667A59657B5A657C5D677E5E68805E68805E6882606A83606C845F6B825F6B7F
606C81626E826471836875846C79846E7C856F7C886F7B8B707B8C717C8E717C8F717C8F
717C91727D93707D94727D95737D94737E93747F94758196768095778296788398798399
78829979849B78849B7B889B7A86997A869A7C889B7D8A9C7E8B9D7F8B9D808D9E818D9E
828E9E828EA0828DA1838FA38390A28491A28794A48A97A48C98A58A97A48B98A48C9AA3
8D9BA48F9BA68F9BA7909CA8919DA892A0A794A2A995A2AB96A1AC97A1AC99A2AD99A3AF
99A3AF9DA6B09DA6AE9FA7AEA0A9ACA0AAACA0ABABA1ABACA2ABADA2ADACA4ACADA2ABAE
A3ACAFA2ACADA2ACACA2ACAC9FABA99FABA89FAAA69DA8A39EACA1818D8544474C3B4042
3537373A3D3850584B7D8C72687460485045464E433135302E2F2A454A3C4D5443515947
525A494F554740423A5E665795A8898A9A808D9D858B9B848A998293A689586151161111
1E1C171816131515131314111314111414111A1A14353B2C6E7E5F57614C6C7960728067
73806974816B7886707686716E7F6B6E7F6A3A4138292E242B3223272E1C272E1A29321D
2B331F2F3622343925333926
4954664C596A4D5B6E4C596D505C70535E73545F76546078566179566279566278566177
58647959657B5A667C5B667C5D677F5D67805D667F5D66805E6882606A835E69815E6A80
606D81626F826673816D79836F7A83707A83707A86717B8B727C8F717C91727D92737E93
727D93737F95727E95737E97727C95727D95757E97768097757F95757F93768093778195
77819579839879849C7B859C7B869B7A859B7D869E7D889D7E8A9C7F8B9D808C9C828D9C
838F9C828D9B838D9C848F9E8390A08491A28794A48A96A48A96A38B98A28C98A38C99A3
8D9AA38E9AA4909CA5909CA6909CA7909DA6919FA794A1A996A0A997A1AA99A1AB99A2AC
9BA3AD9DA5AF9EA6AF9DA6AE9DA7AD9FA9AC9EAAA99EAAA99EAAA99FABA89FAAA7A1ABA7
A2ABA8A2ABA8A3ACA8A3ACA7A2ADA6A0ACA59EAAA49DA8A29EADA286938B474A4F414545
36373738393652584C68745F616B59555E4F41473F2F322F2C2D294043364D5341525945
535A474E5444464A3C5A614F96A7878C9B818D9B858B9B868A9A848EA1875B6455191516
21201B1E1B181C1A1815141212110E12120E16150F363C2A4C573E35382A3B3E316B775F
6E7B65717F68788870798B7073866C708167353B302C31262C3124272D1F262C1C29301E
2A311E2C3220303624333827
4751674955694C596C4F5B6E515B71545E76535E7A535E7A535F7A546179556278566379
57647A58657B59667C5A677D5D68805C677F5C657F5B657F5D66805F68815E68815C6881
606C816370826875826F7B85707B86707A87717B89717B8B737D8F727C91737E92747F93
727E92737E93727D93727C94737C95737D96747E96747F95747E94767F94758092778294
7782937782947884987883997A83977D859A7D859C7D869C7D889C7E899B7F8A9A818D9B
838E9B858E9C858F9E858F9E86909F858FA18892A28A95A28A96A18B97A18C97A28D98A2
8D98A28D99A38F9CA3909CA3929EA4919EA5919FA592A0A695A1A797A0A698A0A798A1A7
9AA3AA9CA4AB9CA5AC9BA4AC9CA6AC9DA8AC9EA9A99EAAA99EAAAA9FAAAAA0ABA8A0ABA7
A1ABA4A0AAA2A1ABA3A2ABA3A1ACA2A0ABA19DA99F9BA89E9EADA189958D484A50424447
363537383A395862555962545A6453545E4F4D5649393D3930332F3E44374B5442515946
5158454B503E464A3B5259488FA2818D9D808C9C848D9D868C9E868FA2885C6557191518
211F1D1D1B191A1A1714141110120D11120C12120B343B294D593D2F31211C181368735C
74836B6F7F6B768871798C72768A6D738768363D30292D25292D23272A21262A1E282D1E
2A301D2C311D2F3420313624
4A54664D576A4F5A6E4F5A71505B73515C75525D78545F7B54617B535F7955617A56637B
56637B57647B58657B59657C5B677E5B667E5B66805B65825D67835E68835D68835D6982
616D846571856975856E7987727D8A717C8A717B8B707B8C717D8E717D8F737E92727D93
717D92717D92717D92717D93737E95737E96758096758196758195758193768192778393
78849478839579839979839B7B839B7E869B7D859A7E869B7F879B7F899C808C9C818E9B
818E9A838F9C848F9E868FA08790A28790A18892A18A939F8A96A08B97A08B979F8B979F
8C99A08D9BA18D9CA08E9CA1909EA3919FA592A0A8919FA795A2A897A2A798A2A799A2A8
99A3AA9AA4AB9BA5AC9CA7AD9CA8AB9CA9AA9DAAAB9EAAAA9EA9A8A0ABA9A2ABA8A2ABA5
A1ACA4A0ACA4A0ADA49EABA49EABA39FACA29DAAA09DAB9E9DAD9F8D9B904A4D52404447
37383A37373850564C4E5449555E504C56484C5749454E43353B3440473A4953414D5743
4F58444B51404144384144398B9D7E8C9E818A9B818B9C848699828A9E84616C5C1D1A1E
2220201D1D1C1A1A1717171316161114150E14160E272B1E5D6B4B3E422E24221C66735D
74856E6E7E6E748574798C757A8D73788B6F3F463C292D273032282D2E242A2C212A2E1E
2B301D2D331E303621333723
4851634C5568505A6F505B72515B75515C77525C78545E7A545F7A55617C56627B56637B
56647B58647B59657C59667C5B677E5B677D5A657F5B66825D67835F68845F6984606A84
636E866772866A74876F7A8A737E8C737F8C737E8C727D8D717D8D707D8F717D91737E92
727E92707D906F7C90717F92727E93747F95747F95737F93758293758192758192768292
7783957983997A839C7A839E7D839E7F869D80879C80879C80899C808A9C808A9C808C9B
808E9B828F9C848F9B848E9B87909E87909E88929E8A95A08B96A18C98A28B98A08A979D
8C999D8D9CA08E9BA18F9BA38F9CA5919EA7929FA9919FA893A1A994A2A998A4AA99A4AB
98A3AB98A3AB99A4AC9BA6AD9CA8AB9CA8A99EAAAA9EA9A89EA9A7A0ABA6A1ABA3A2ACA3
A2ACA3A2ADA3A1ADA49FACA39EABA29DABA19EABA09DAB9D9DAC9C92A1944C4E523E4146
36383D3131334F554A4A4F45494E45464E424B5648475243343B303A433548533E4A553E
4B563D474E393B3D3033342B8091748DA0828A9B818A9C85859883889C856B7A691F1F23
24232321201E1E1E181B1B141A1A13171911191A1320241A2F35272F322840483A718368
75876E71826E748571798C757C8E767D8F754850452B2D2834372D2F31262B2D22292C1E
282D1D2C31202F3423313725
4951644B53674E586C4F5970505A73515B76515B77535D7A56617C56627D56627D55627B
56627C58647C59667C5A667D5A657C5B687D5C687E5E6980606981606880636B84646C85
646E856772866873876D788A727E8D76828F78849076818F748090747F92737F91737F92
737D92707B91727C92737F93727F92727E92748094737F92758092748091758092778394
7682947782977882997A839B7C849D7E869E7F889E7F889D7F899D818B9F818C9F818D9F
808D9F818E9D84909D85909D87919F87919F8892A08994A28A96A38B97A48B98A38C98A2
8C99A08E9BA28F9BA3909BA5919CA8929EAA939FAB93A0AB95A0AC95A1AB97A3AC98A4AC
9AA4AC9AA5AB99A4AA9AA5AB9CA8AB9DA9A99FAAA9A0ABA8A2ACA7A2ABA6A2ABA3A0ABA1
A2ACA0A3AEA1A1ADA1A1ADA2A2ADA2A0ABA1A0ABA2A0ACA09FAB9C9AA898555759414246
3B3E40323234494E444E5346494E43484E434F5A4B434C3F31362C353B2E515E454E5A41
4D563E484E393E4133302F2A78866E8FA1858A9B838D9E88899A858B9D877F8F7C29292D
222022211F1D2120181E1D1319190E14150C16170E20241821241A1F201A21231E6C7D62
76896D71816A7888707D8D747E9076849578565E4E2F3029383A3132362E2D31292A2D24
272C1F2C31212F3525323728
4751654953684C586B4E596D4F5A70505A73515B76525C78535D7955607B56617C55617B
56627B58647B58657B59657A59667A5A677A5A677A5B677C5D687D5E697D626C82636D83
647083667385667384697586707E8C768590788793778492758392748092737F93727E94
737D95717D94717C93717F94707E93707E92727E92727E91758091758091758091778391
7885927884947883967A85997D869B7A849B7B869E7A849D7B869D7E89A0808A9F808AA0
818AA0838CA1848EA0848FA0868FA085909E85919F8692A08793A18894A18A96A38C98A5
8D9AA48D9BA58F9CA6909DA6919DA8929DAA929EAB939FAB95A0AD96A0AC95A0AC98A3AE
9AA4AE9AA5AE9AA5AC9AA6AC9CA8AB9DA9A9A0AAA8A1ABA8A2AAA8A2ABA8A2ABA5A1ABA3
A1ABA3A0ACA29FACA3A1ACA4A2ADA5A0ACA49FABA49FABA39CAA9E9CAC9C5E6261444549
4546463635373F413C474B404C52444D5647525D4D4B5648363E34373F315A694D57654A
505B444D5440464A3C363733707C6A94A78E8A99848C9B878998868C9B888593802C2A31
211E2323221F2020171D1E121B1B0E13140A13150B1F221721261C23291E1515115E6C54
76886B6D7E6678886F7E8F74819277819376535A4B34352F3A3D34363B303035292B3023
2A2E202E3221333726333626
464F6549536A4C586E4D596F4E5971505A73515C75535D77535E7755607957647B56627A
57647B59657B58657A58647959667A5A677A5B677A5A677B5C687C5E697E606A81646F86
6572866674836674816775836C7B8771828D748591748491738190727F8F717D90717C93
727E95727E96707D95727F96727F95727E95737F94737F93758192768291778491778491
7986917884907883917A85957C86987B869A7B889D7B869E7C88A17E89A27E89A17F8AA1
838CA4838CA4848DA4868FA4868FA38691A18692A08793A18895A38A96A38B97A48B98A4
8C99A68A98A68A99A58D9BA58F9DA7919DA9919EAB919EAB929EAB939FAB95A1AD96A2AE
98A4B09AA5B09AA6B09CA7B09CA6AD9CA7AB9FA9AB9EA8AA9FA9A9A0AAA9A2ABA8A3ACA9
A2ABAAA1ACA9A0ACA9A1ACA9A0ACA89FABA8A0ABA99EAAA69AA8A19BAB9F656C6A414247
4245433434343E413C454B424D564A515C4E535F504E5B4C3D4A3C3A46355A6C5059684C
5360464C564042473A3A3B3775836F95A88D8B9B868B9A888896858B9A868493802E2B32
201B232321211E1E171A1A1018190D14160B191B10272C212F372C2E352A292E255C6A54
73856C6E7F6874856D7B8C737F90778093784F584C3539323A4135353B2D3036262D3222
2B301F2F3422333625333725
47516649546A4B566D4D57704F5A73515C76525C77535D78545E79555F79566078566179
56617A57627C58647E58647E58657D59667C5A677C5A657C5C677F5E69815F6B83646F87
6572886674876674866775866876876B7A896E7E8C707F8F727F90727F91727E92727C93
717C94727D94717C95737E96747D97727C96737E96737F95748095758193788593798593
7884937784927783927884947985967B87997B889C7C889D7C889E7B879F7C86A07E89A1
818BA3818BA3838CA4868FA5868FA38790A08893A08993A18994A18894A18995A38995A2
8A96A18A96A28B97A48E99A5909AA6929DA8939DA9939DA9929DA9939FA996A1AA96A0AB
97A0AE98A2AF99A3B19BA5B29DA6B09EA8B09FA9AF9EA8AD9EA9ABA0AAAAA2ABABA2ACAC
A2ACABA0ACAAA0ACA89FAAA79EA9A69EAAA79EABA79CA9A499A79F9CAD9F717B733C3E40
3D413D2F312F4349404B54494C564B5563544F5D4F3F4A3E354034323B2F596B505A6B4E
5260464B5740373D3033352F76866D95AB8C8A9A858B99888A97878B9A88839180333236
1B161D1F1C1F1B1A181B19141A19131718101C1E142D3326444F3D363F324A574760705C
6E806971836B73856F7688747A8C767B8E77525E51373D35394033343C2E3036262E3422
2C32222D3322323826313725
4953674A566B4C586E4E576F4F5972525D76545E78535C79555D7B565F7A586079576179
58607957607A59627D58627D58647E59657F59657F5B66815D67835E68855F6A86626E89
64718A68758C68768C69768D69768B6B788B6E7B8D707C8F717E92707D92717D91717C90
717B92727C93737C96747D99747D99747D99737D99747D97767F97768096758094778295
7681957783967884967984977985977A86997B889B7C889D7E8A9F7E8A9F7E89A07F8AA2
7F8AA1808BA1828DA1838FA0858FA087919E88919E8994A08994A18893A08994A18A96A2
8B96A18C96A28E98A28F9AA3919BA4949DA5949CA6959DA7959EAA949EAB94A0AA95A0AB
98A2AD99A1AE9AA4B09BA4B29BA4B09EA8B19FA9B09EAAAE9EAAAC9FA9ABA1ABABA0AAAA
A0AAA8A0ABA9A2AEA9A0ADA69FACA59FABA49FABA39DAAA19BAA9D9CAD9C737E733B3D3E
3D423E30313043483E4E584A515C4D53605041493F333A31282F28272E26596A515B6F53
49594349564031362A2D2F28707D6795A98B8A99838D9B888D99888C9B8984948336373A
18131A201D1E1E1C181F1D171C1B161616121818112F34275F6D545965514A5447586557
71856F71836E72846F71826F6E806C72876E53604E353A30383E30353B2E3137292F3525
2E34242E3524323926313824
47516848556D4C5A714D5A6F4E5A704F5A71505B73535D77545E78535D76555F76566177
57627857617859637B59647C59657D5A66815965805B65815C67845E6886606B88636E8A
64718B67748D69768F69768E69768D6B778C6D7A8D6F7B8E6F7D916F7C92707C91707C8F
727E92727D93727D95737D99727C98737D98747F98737D97757E96778095747E94757F94
7580947782957886987885987B869B7C879D7D889E7B889E7E8A9F7F8C9F7E8B9E7F8BA0
7F8BA0808C9F808E9F818E9F848F9F86909E88919F8892A08995A08995A08995A28B98A4
8C9AA58C99A48D9AA38F9CA3909CA3929DA3939EA5949FA8949EAB939FAC94A1AD95A1AE
97A2AF98A3AF99A5AF9AA3B09AA4B09DA8B09DA8AE9DAAAD9EAAAEA1ABAFA1AAAEA1AAAC
A0AAAA9FABA9A0ACA9A0ADA89FADA6A0ACA59FACA39EABA19BAB9D9BAC9A7480743F4443
42474336393740473E4F5A4C505C4E535F5140493F38403531392E2D34294D5B4556674C
46523E48554033392C2F312A6D796592A3888998818D9D878F9E8A8E9D8985968237393B
1A171D2220211C1B191B1A161919151516121A1E172931247085656B7E62677863454E47
7B91797288736274623F4B42414E436B816557664E31372A383E2E363B2B333828313725
313724333926343C27323B26
45536846556B48586E49596F4B5A6E4D5A704F5C72515D74515E75525E74536074546074
55617556627857637A57647C58657E5A67815866815A66815A67815C68825E6984626F89
64728A65738B67758C67758C66738A6A778B6C798B6E7C8D6D7B8E707D91717D936F7D93
728095727E94707D94707D96707C96707D95717D94727E94737D94758094758195737F93
737F9075839376859777859878869A7A879D7C899F7B879F7A879E7E8A9F7E8B9D7E8B9D
7E8B9E7E8B9F7F8D9F808D9E838E9F8690A08590A08592A08694A18695A18796A38998A4
8999A48B9AA58C9AA58D9BA3909BA4909CA4919EA6919FA892A0AC92A0AD93A1AE94A2B0
94A1AF96A3AE98A5AE99A5AE9BA7AE9BA8AE9AA8AD9AA8AC9CA8AB9EAAAD9FAAAEA0ABAD
9FABAB9FABAA9EABA99EABA89EABA89DABA79CABA49CABA198A89F9AAC9E7B8980444A4C
3F4445393C3E3B413F464F474B584D5563544B57493C473B373F3534382E383F30414B37
3A42303F4836383E312F302B60695992A4888896828C9C898E9F8E8D9F8C879987393D3F
1410191D1C1E171516151412151611121410252A222F372B5E70566F856763745F454E47
7A8E79768C7659695B161A1D1A1E1D3C463649543F34392B373C2E363B2B343A28323725
343A25363B27363D28343B28
48566649576A4B59704A58714C59724C5A734E5B72505C74505E76525E75525E73525E73
535E7355617656627957647C57647D59657F59658058657F59667E59677D5C697F606E84
63718663728765748967758B68768B6A778B6B778C6D7B8E6D7B8E707D91717E93707E94
6F7D93707E926E7D906E7C916F7D92717E93717E92718092728093748194738095728094
72809274849476859577869977869B78859C78869B7B879D7A879D7C889E7D899F7C899E
7D8B9E7D8A9D7D8A9D7F8C9D818E9D838F9F838FA08491A18493A18493A18595A28797A3
8998A48A9AA78D9AA88E9BA6909BA68F9BA7919DAA909EAB919EAD90A0AE90A0AE92A1AE
93A2AD93A3AD93A3AC96A4AC98A7AD99A8AD9AA9AD9AA9AD9CABAD9CA9AC9EA9AD9FAAAD
9EAAAB9EAAA89EABA89EAAA79DABA79BAAA79AAAA59AAAA498A8A19AABA17A86824B4F54
3C4046454C4A464D47404741505C50556253485244363C3333372F2F33292B30242B3021
2B301F313625383D2D31332A626C5990A2858795818A99878A9C8A899C8B829485313439
16131C1A191D15141414120F15130D13120E272B223033295F6C55778A6E687763637063
708071778B795260540E101516171A1211112528202F3426323629333929323927323826
343A26363C29373C2C35392B
4751634954694B56704C57734C56734B56714D59734F5B75505C75525D76535F76535E75
525E74535F76545F7754617A55637C58647E59648058647F59667F59677E5B6B7F5F6D82
61708264738564738667758868768A69778B6A778B6E7B8E717F91738093738095707E94
6E7D936E7D916D7C8F6E7C8F707C90717C90717D91738093728193718092728094738095
74819576839577859678859979859C78839B7884997A879A7C889C7D899D7E8A9E7E899E
7D899E7F8B9E808D9E808D9D818F9F8290A08290A18391A28291A18393A18594A28594A2
8795A38A98A68D9BA68E9CA68F9BA6909CA88F9CAA8F9DAC8F9EAE8E9EB08F9FB0909FAE
94A3AE95A4AC96A3AC95A3AC98A6AD99A8AD9CA9AE9DA9AD9EAAAD9DA9AC9DA9AC9DA8AC
9EA9AC9EA9A99EAAA79DAAA79DAAA89CAAA79AA9A599A9A397A8A09AABA27B8683494C53
4044484046443D433C32362F4852435A6753535E4C3A40373237302F332B2E33262A3020
262B1A2A2D1B37392734342A60695796A98B8A9A828C9D878B9C87889985839582343839
15131A1B1A1C18171717171417161215141020211928291F616D5376876A6F7E6673826C
72826E7A8D78586459111119110E140F0A0D201E182F3225313424323624343A26343926
343A26353C27363D2B363C2E
464F644952694B556F4C55724D56734D56734D5673505A764F5B76515D76535E76535F76
535E76525D77535F7954617B53617B58647F58657F59667F5966805966805B68805E6B80
606D7F627082657385667485677585687687707F8E7B8A987E8D9D7C8A9C768399707D96
707D956E7D936D7C926F7C91717C91717C91737D92737F93737F92738091738091748094
7581947781957782957783957884977984987985997A869A7B879C7C889D7C889F7D889F
7F8A9E7F8B9E808C9C808D9D828EA0838EA1848FA18591A28592A28592A28592A28694A3
8896A38B97A38D99A38D9BA48E9BA58F9CA7919DAA909DAC8F9DAE8F9DB1909FB192A0AF
95A2AE95A3AF96A4AF97A5AE98A5AE9AA7AD9CA8AD9EA8AC9FA9AB9EA9A99EAAA89EA9A9
9EA8AB9EA8AA9DA9A99EAAA99EAAA99DAAA99CAAA69AAAA498A8A099AA9F85938A45484D
4045463438382E32302425233B42375F6D575965504B56463F463A383D3233382C2E3426
2D32234F583F41443437383153594E94A78C8A9C858A9C858B9C86889882879681454845
16121A201F201D1E1B1C1E191A1B1717171316161024271A5762487B8E6B70816574846B
76856D7787717584713639391C1A1D1F1C1C22201A303123313322333724333825343A26
353B27353C28383E2C373C2D
4850634A53694B556F4C55714D56754F58774F58754F5B76515C77515C76535D76535E77
535E7853607A55617D56617E57627F58658057648058667F59667F57647E5A67815C6880
606C81606D816370846572866674866C7A8D798A9B8294A38697A7808EA378849D717E98
707C946F7C916D7B906E7B906E7B8F6F7C90737E92737E92737F91748093748093758094
7480947681957682957783957985977985987B889B7B879C7B889C7C889C7C889F7D88A1
7D8AA27E8BA17E8B9E808D9F818DA0848FA1848FA3858FA38691A28893A28893A18994A0
8A96A18C9AA38D99A28C99A38D9BA48F9CA6919DA9909CAB8F9BAC919DAF929FB094A1AF
95A1AD96A3AD97A4AD98A5AD99A6AD9AA7AD9CA8AA9CA8A99EA9AA9FAAA79EAAA59EAAA7
9FAAAA9FAAAC9EAAAC9EABAC9DABAA9DABA89CABA59CABA49AABA29AAB9F8FA092474B4F
3B3F402F31322A2D2D2425263439345E6C595865525764524E5A493D4537353B2E2E3327
2C30266C7B5E43483A3A3C364C50488E9F868E9F888C9D878EA0898A9B83899A8051564E
1B151C2321231D1C1C1C1B1A18191717171517181322251B505C457F947172836874856C
76866F7586707588716D7D6855615159665149544134382A3B3E2B383B29313525323726
333A29343C2A373F2D373E2E
444E5D4750644A526B4A536F4C55744E56764E58764E5977505B78505B78505C78515D78
505C79515C7954607B545F7C57627F59648058657F58657F58667F58667E5B68815D6983
5E6A835F6C846370876470886670896F7D937C8CA08091A48091A47C8BA077839A748098
727D94717C906F7B8E6E7A8E6C7A8E6C7A8F6F7C90717D90727D91727E92737F95758097
76819875819777839776829776819776829878849979859C79869D7B889E7C889E7C899F
7D89A17D89A17F8B9F7F8DA0808DA0828E9F838DA08590A38790A58790A58791A38893A1
8893A08996A28A97A28B97A18C98A28E9BA48F9BA68E9AA78F9BAA8F9BAB919DAD939FAD
939FAA929FA993A1A994A3AA98A6AB99A7AA99A7A999A7A99BA9A99DA9A79DA9A69CA9A6
9EABA89FABAA9DA9A99BAAA99BABA89AAAA69AAAA29AAAA199A99E99AB9C90A3934E5756
3D42413134322C2D2C2B2B2B3437325B6856586554566252525E4C454F3F3840312F3628
2C302434382A33342935342E494B4490A28891A28B8E9F8990A28B8B9D868B9C835C6457
1A141A2421221E1B1C1A19181716151717141A191621201B464D3D84997674866C748670
74857374847273856F75896F75896E76896C65735B393D303F4331383B2B2F33252E3325
313728333B28363F2A343B28
444F5D4751634A556A4B55704D57754C57754C57754B57754C59774E5B794E5B784F5D78
4E5C77515D78525E79545F7A55617B57647D56647B55637C56657E57657F5867825A6883
5B68835E6A84626E87636F8865708A6B769175819A78869E78879D748398728095717D94
707B926F7B916F7B926D7A916D7A906D7A906E7A90707C91727D93727D93737F94747F96
747F9875809875809774809875819977849B78849B78859B78879E7A89A07B89A07A89A1
7B89A07C8A9F7E8C9D7F8D9D808D9E828F9F848FA08690A48790A68590A78590A68693A6
8793A48794A48897A58997A58998A48B9BA58C9AA78C9AA88C9AA98E9AAA909BAB929EAC
929FAB92A0AA90A1A991A2AA93A3A995A6A897A6A999A7AA9BA9AA9CA9A89BA8A69CA8A7
9EAAA79EACA99CABA99AAAA79BABA79BABA599A9A299A99F97A99C97A99993A79657615F
454C4C35393A3032313639353C413A576353576554566351515C4B4854433943362C3429
2C31262B2E242929212825213F3E3998A98E9AAC938F9F8B8EA08B8C9F8A8D9E8A6B7668
1D1A1F2223221C1C1B1C1C18191A13191A1117150F1F1E17424838899E7C74866E738472
72827673847772857272896F72896C758B6C5D6B5540463A3F4639383E3133392C30352A
31372A353C2C373F2B353C2A
434E6047516649546C4B54704B56744956734956734C59744C59754D59764C59764D5B76
4F5C76505C77525C79535E7A54617A54627B55627B54607A55637C55647F576681596782
5B67825D69835E6B84606D86626E8865708A69768D6E7B926F7D936E7D936D7B936D7A91
6E7B936C79926B78936A76926B77906D79916E7A916D79916E7A92707B93717D94717E95
727E97737E98747F99747F9975819976829A77849A77849978869B7A899F7A89A179899F
79899F7A8A9D7C8A9C7C8B9B7C8A9C808C9E838FA0848FA28491A58491A58391A48593A5
8694A58794A48795A58997A68997A68B99A78C99A78B99A88D99A98F9AAB909BAB939DAD
959FAD95A1AD94A2AB93A2AB92A1A995A4AB97A6AC99A6AD9AA7AC9CA8AB9CA8AB9EA8AA
9FA9A89DAAA69CAAA69AAAA59AA9A699A8A39AA9A39AAAA198A89D96A79994A7965A6561
464D4C3032362F32323B413C404841596556596656576454515C4D4F5B4B454F432D312C
30332E2C2D28272421231C1E3834339DAD91A2B49992A18C90A08C8F9E8A8E9F8A6C7869
1D1C202323231D1E1A1D1E17191A1117170F16140F23221A4C52418FA58073876E708571
6F83786A7F7777928159705F5F76616B81695865563F48403E453B373E3332392D30372C
30352B343A2D373D2D333B29
424E6345506746526C4A54704A54734852734752734853734854734B56744D59744E5A75
4F5A754F5A754F5A77515C79535F7B53607B54607A535F7955617B56627E576580596680
5B67815B66805C68815E6A83606C84626F8564728767758969778B6A798E6B7A916B7992
6C78956A75946975946B76956B76926B76906C778F6D78906F7992717A93717B93737D95
737F94727E9672809873809775819775819776819876819976829A78849C78859B79869A
7A879B7B879B7C889B7D8A9B7D8A9C7E8B9F818DA1818EA1828FA38390A38390A38390A1
8492A28593A38693A38996A68A97A78A96A88A97A88B98A98C99A98D99A98F9AAA939DAB
959EAA94A0A9939FA894A1AB95A1AE97A3AF97A4AE99A5AE99A5AE9AA5AC9BA6AC9DA7AB
9DA7A89CA7A59BA8A49BA8A59AA6A49BA7A39BA9A19AA89E98A79C96A69992A494545D5B
3A3E412E30342D3030393F383E463C5C6A585A6656586253525B4F4F574C4F574B3F433C
3637342B2828262022231A1F373233A0B094A4B59A93A38D90A08D8E9E898D9F87677365
18171C2021211C1E1B191B1518191017180F16160F1E2017444E3D7E95726A80646A8067
718772586860718878697E6C3F4B446B7E6A5360543D443E3C433A353D3232392F333A2E
33392D353A2D363C2D343A28
404C65424F6845516D4853704A53734A53744953744854734854714A546F4B566E4D5970
4F5B704E5970505B74505B77515C79525E7A535F7A545F7A56627C57637D58647F596580
5A64815B66835D68835E6983616D85626E84626F8564728866748966748B67768E687490
6874916975926A75936C76946D77936B76926B77916E78916E7890707A91717B92727D94
727D93727E94727E95737F957682977783977982977B849B79839D77829B77829A7A859A
7C879A7C879A7C869A7F899C7F8A9D7F8A9E818BA0808BA0828EA1828EA18390A18490A0
8492A08492A08592A18894A38A96A58996A78996A88B98AA8B99AA8C9AAA909BAB919CAB
939CAA939DA9939DA996A0AB97A1AD98A2AD99A3AD9AA4AD9CA5AD9BA4AC9BA6AA9BA6A9
9AA6A79AA8A59BA8A49AA7A499A5A29AA7A19AA69F99A59C98A69B96A69991A193525858
3032393437392F323131342D41483A5E6B5459634F52594A4A4D444A4C4454584E494A44
3F3E3D363335342E3130292D433F3F96A48D9FAE9695A59090A08E8C9D8A8A9E88677567
1A1A20212324191A1A191A1418170F18170E17180E23271A30392B4653405C6E56667C60
596C54586A5363765E91AB88566455536054505F522C322E363B33363C30353A2F353B30
373D30383D2F373C2F33392B
414B64434D6848526D4A54704A54734A53734A54724B56724B55704B556F4B566F4C586E
4F5A6F4F5A70515C74505C75505B764F5B77505B76525D77535E7956617A57627D596381
5A63835C66855E68855E6A84606C85626E86626E8763708963718A64718C65738E66728F
6775916875916975926A76926C77936B77936C7A936B78916A77906D79916E7992707C93
6F7B93707D95727E97717E95747F977680987882987B839A7B839C78829D78839B798599
7B85997C86997D869A7F889C7F8A9E808B9E828B9F828C9F848EA2838FA38591A38491A0
84939E8594A084939F85939E8795A18795A48997A78A97A88A97AA8C98AB8F9AAD919BAD
929CAD929DAC939FAD949FAD97A0AD97A1AB99A2AB9BA4AC9BA4AA9CA5A99AA5A79AA5A7
9AA6A79BA8A69AA8A69BA8A69AA7A59AA6A39AA7A299A7A097A69D95A59A96A7995C6262
313136363A373234303131294044365D664E565E4A45483E3938374848475D615B61665E
4C4D4C4748484544424543404D4D4A88948098A69096A59190A08E889A88889B886C7C6E
1B1B202021211D1D191C1D1518160D17150B15140A2327182E3525343D2D3F4C394F5F47
2A34272F3C2C26302584A07B72896A252B24455242191B19282B232D312730342A34382E
373C2F383E2E373F2E323929
414A61434D67464F6C48516E48517048527049527049526E48526F4A54714C55724B5571
4C57704D58704F5A734F5A75505B784F5A78505B78515C78525D7754607956617B58637E
5963815A64845B66855D68835E6982606C84606C85616E8763708A636F8E647290647191
6572926672916672926774936974946A75946B77946B77936B76926C78936D79946E7A96
6D7A966E7B976F7D98727F98747F98747E98747F9977829A778099767F99768199778398
7984987A86987B869A7D869B7E889C7F8A9D828B9D828B9D828C9E838DA0838EA182909F
83929D83929D84939D84939F8493A28594A38796A68896A78A97A98C97AB8E99AC8E99AD
8F9AAD919CAD929EAD939FAE94A0AD95A0AB97A2AA99A4AA9AA5A99BA5A89AA4A69BA6A7
9AA6A69AA6A59AA8A699A8A798A6A698A5A597A4A396A4A296A59F95A49A98A899666F6A
3433393D403D393B3635352F3D3F36575F4C575E4E4C51463B3E39586156616C62829381
606960595F584445444B4B484B4A497E8779919F8C91A08F90A08F889787869784718070
1E1F242122221D1C191C1C1518180F14130B13120B1F22162D3525384331313C2C20271C
1B22181A21160F140C607655657B58151A122E372A1416121F2119272A212D312734372C
383C2E353B2C343A2B2F3627
414A5F434C65454E6A47506D48526F48517049537249527048516E4B54724C54734C5573
4B55744C56734E58754E59755059774F5977505A78515B79525C79525D77545E7956617B
57627D5963835A64855A64835C67825E6983606B85616D86626E88636F8B636F8D636F90
636E90636E916470936572956672956873956773946974956B76956C79946C79956D7995
6E7A936F7B95707C97727D97747E96747E98757E9A757F9A77829B76819B75819977839B
77839977839978849B7B869C7C879E7D899F7F899F818A9D838D9F818C9E818D9F8290A0
82909E81909D82919C8392A08492A28695A68694A88895A98994AA8B96AB8A96AA8B97AC
8D99AD8F9BAC919CAB929EAC929EAB939FAA94A1A896A3A897A3A698A2A59AA4A799A4A6
9AA5A699A5A69AA8A899A7A997A5A795A3A595A3A394A3A195A4A094A49B98A99A6B746F
37373E4042413A3C39323431454A4052594C555D4F4F594C40473F535E51636F61849680
81907C7C85753E3B3E4845473D3840777F76929F8F8B988994A3918D9C8A899885798777
201F261E1D211C1B1A18181315150E14150D16170F252A1C262C1E242B1E22281C191F16
161C14161C1112170C2B362338452F1218101C221A141813131610252B1F2F3627333B2A
373E2C363E2B333A292E3324
414A5D444D62464F6949526E48526F4850704A53734B54744951714A53724B53734B5272
4B54744D56754D56754D56754E58764E58774F5977505B77525E79515D78535E7A55617D
5661805863835864855A64845C66835F6984606984606A84616C87626E89626D8B626D8D
626F8F636F90626F906371916573926673926672926974946B76946A75946B76946D7993
6E7A91707A92717B94727B93737D93747E95767E97777F9877819976819A74809A77829B
78839A78839A78829979839A7C869C7F879E81889F838A9F858D9F828C9F818C9F838EA0
8491A18593A28592A18591A28792A38894A58996A68996A78996A88B97AA8B96AA8B97AB
8E99AD8F9BAD909BAB919DAC929EAC929EAA93A1A995A1A997A2A697A1A598A2A798A3A7
99A4A798A4A699A6A699A7A897A4A696A4A396A4A296A4A296A5A196A59D98A89C737D76
3C3D424145443A3E3D333735393E39464E42535E4C454D42323634505851636D63869581
8D9D879AAA914B4A4A3D383E35303A6D746F90A0908794878F9F8E90A18D8A9C87798977
1F1F2419181B17161613120F11100A11110814150A2025172127181F23171E2116191E13
171C13141A1112170E12160F11151013181215191312161110140E20271A2D3624313A27
343E2A333D28333C262F3723
40495B434D6246506948516E47516E48516F4952724B54744A53724952724B54734A5272
4B53724C55744D56754D57764C57764C58774E5977505D79535E7A525D7A535E7C55607F
5862835862855863835963815A65825E6883606985616986606B88636D8A626D8B606C8B
606D8B616E8C63718F6472916774926774926773926A75936B75926D77946D77936F7991
6F7A91707A90717B90727C91747F93747F94767F9677819977819977829B76819A768198
7783977983977B84987C84987C84987E869A81899C848B9E858CA0838C9F838CA0828CA1
828CA0848FA18691A38792A48792A48792A38894A38895A38795A38997A78A99A88C99AB
8E99AD8F9AAE8F9BAC909DAC929EAA939EA9959FAA97A1AB96A1A897A2A997A1A897A3A7
98A4A898A5A899A6A797A5A596A4A498A5A498A3A397A3A298A4A197A49D98A79C7B867F
3938414143453D403F37393A3336373D423D525D4E4B5448383B3850564F646B62849080
90A08DA4B89F636A6339373D3A393F646D6591A38F8695848B9C898CA08B889D877B8E7C
22252A13141918191916161314130E13120B12130A17190E1A1F121A1F121B2013191D11
171A111418111218121216130F121312151514181613171412160F1F26182A331F2F3725
323C29313D29323D27303A23
3E485E404C62434F68454F6A47506C47506F4851704852714852714953724A54734B5474
4A53734C55754B54754C55764C56764C58774E5A784E5B79505B79515C7A525D7C545F7E
5762815863825864825863815964815C67835F69845F6986606B895F6A89606C89606C88
606D8B616F8C63718E6370906673926874916673926672916975916A76916B778F6D788F
6F788F707A92717B93717B93727D94737E96737D96757F9A75819C75809B768199778398
7783967782957A84957B85967B85977C869A7F899C808A9D838B9F828A9F838DA1838EA1
828D9F848D9F858FA18590A28791A48793A48994A38995A38794A28896A48A99A78B99AA
8C98AC8E9AAE8E9AAB8F9BAB929DAA959EAA969FAB97A0AB95A0A996A3AA96A3A897A4A6
96A3A697A5A698A7A696A5A496A4A399A5A398A3A196A19F97A29D96A19A99A69A78807B
38333F403E444142444346453E403F3B3F3C545F52525C4F494F474D524A626B5F839280
8B9B8998AB957C887A4041453C3D43636D679AAF99879A88899D8B889D8B8A9E8B819483
282C3314151D191C1E191A1916171213130D11110B14160E181C12181D121B1F131E2215
1D1F161C1D171B1D1A1A1D1E1A1B21191921181A1F15171810140E2028192B3420313925
333C29333D2A323C2A323A27
3E485F404C65424E68444F68444E69454F6C464F6E46516F475170495171485170495272
4A53734A52734B53744D57774D58774D59774E5A784D59784E5979505A79525C7D535D80
565F815862825763825763815763815A66835C67845D69855F6B895F6A8B5F6A8A5E6A89
606D8A616E8A616E8B626D8C636F8E65718E6571906470906974926975916A768F6C768E
6E778F6F7A926F7A956E79966E7A95727E98727E98747F9B75809D75819B758099768197
7783977882977983987A83987B859B7C889E7C889E7D899F7F8BA07F8BA0818DA0818C9E
808C9E818C9E838C9E858FA0858FA18691A38792A38592A28593A38695A58896A58998A6
8B99A98F9AAB919BAC919AAB939CAC959DAD979FAD979FAA95A0A895A2A894A2A693A2A3
93A3A294A4A296A4A395A4A395A4A297A5A397A4A296A2A096A2A095A19C99A79C6D7370
352E3A3D38404140454A4E4D414644393D3A515C4F505A4E51594E4B4F485C635A849280
8A99858B9B84899882454547302D38646E6B9AB09D86998A8B9D8C8697878A9B8880917F
24242C1A19201D1E1E19191715151212120E13120D181A121C1E141C1D152B3122282D1F
20231727272027252542454432343927272D26282918191913140F242A1A2A321E2E3623
323A25333B27333D28303924
404961414B65424D69434E6C434E6A444E6B444D6B444D6C47506E47506F464F6E474F6E
4951714951714A53724B53724C55744C56754D57754E58774F5878505978515A7B515A7D
545D8057608156628158637F57637E5965805A65805B66825C66865E68885F6A895F6989
5F6B89616C89626E8A636F8B646F8C64708E646F8E646F8E67718F68728E6A748F6C758F
6D768F6F79916E7A936F7B946F7C95717D95727C96747E99747E9B747E9C747F9B747F98
7781977982997A83997983997A839B7B869E7C879F7C89A17E8AA27F8BA27F8CA07F8B9E
7F8D9E808C9E828C9E848E9F858FA18690A28691A28592A18693A38795A58795A58896A6
8A96A68D98AA9099AC919AAA929BAA949CAB959DAB969EA8959EA795A0A893A1A593A1A3
94A3A394A3A395A3A294A3A293A2A195A2A295A2A197A2A296A2A194A09D98A69D727976
2D263444414744434944474B3A3E42373C3C4C574D4D594D505A504347446B756890A18B
78847587968183927D41414329243262696798AC9A8A9B8B8D9E8C8997858C9B878D9E86
29272B1E1B1C1C1B1717161114140E14140E15150E1B1D131F22181919144049373A4234
2E322A5861523C3F3D59625B3E4245292A2F292B2A141414191C14282D1D292F1C2B321F
2F3624323926333C272E3925
41485F404862424B68424B6B424C6B414B6B424C6B444D6C444D6C454E6E454E6E474F6E
464F6E48506E49526D49526F4A53714C54734C54724D55744E56775058774F5A77505B78
535D7B545F7D55617D55617B57627A58637C59647D5964805B66835E6985606985616987
606A87626C88626C89626D89616D8B636F8E64708E65728F67728F68738F6A748F6A748E
6B758E6D778E6E788F6E7990707A92707C94707C96717C97727D98727C98737D9A748099
767F997881987982977882977982987983997B869B7D899E7E8A9F7E8AA07E8B9E7D8A9D
7F8C9D808D9E818D9F828EA1838EA08590A08692A08792A28A95A48A95A58993A48A94A5
8B95A68E97AA8F96AA9099A9939CA9939CA8949DA8969FA896A0A796A1A795A2A596A3A5
96A3A496A2A396A2A395A2A395A1A395A1A395A1A396A1A295A19F95A19B96A49C7F8884
2B2835676F694C4E514A4D4E3E42453033384F58524F58514F57523D41426672669EB699
727F718595817683743B3B41312F3B5B61628191868696888E9E8B89978287967F8D9E83
2F2E2C1F1C1A1F1D161B1B1018190E17180D17190E1B1D111B1F1415191222271F4D5847
5A66566E7D6A646D636E796D5C655D484E48363C371B1C1C21231D262A1F292F202D3223
2F3425333927353D29303926
41485E424B63434C67424B69424A6B424A6C444D6F444D6E444C6D454E6E464F6C474F6C
48516D47506B47506B49526D49526F4C55734D56754D56764E567850587B4F5979505C79
525D7A55607D555F7B555F7A58627B58637B59637D5B64805B65815D65825F6783616885
616885626A84616A84616B85626C87646E8A646F8C65718D65728D66738C68748C69758C
6975896C768B6E788D6F7990707992717B94717B96707C97707C97717C98727C99747F9A
7580997681987580967982977B82987B83997C859A7D889C7F8A9D7F8A9D7E8A9C7E8A9D
7F8B9E818C9E828DA0838FA2848FA08590A08792A28993A38994A28893A18994A28994A2
8C96A68E96A98E96AA909AAA929CA8929CA6949DA696A0A796A1A695A1A596A1A696A2A5
96A2A598A3A698A3A697A3A697A2A597A2A396A2A296A2A195A19D94A09996A499869189
2F2C385054544D51504F55513E43422D2F345059534E56524E5650454B4850595394AC91
849882899E86788878565D5C40414B5F666B666E7185948A8FA08E8A9B8486947B7E8E72
2A2A251B18151E1C1519190F18190E181A0E181B0D1A1D0F1C1F121C1F1512120D4A5241
7B8A716F7A69737F70768375707F6F68776640473F2426242A2D262B2F232B31222D3323
2F3424303626343A28313727
434962444A66434A69424A6A42496A43496B43496D444B6C444A6B444B6A454E6A474F6A
464D69464D6948506A49526C4A536E4C53704D54744C54744B54754F577950597B505B7D
515B7C535D7D545E7D545E7C56617D58627C5A637C5C637E5D64805E64815E6481606882
616A84616A83606A81626B82646D85666E8766708964708B65728C65728A66738A677588
6874866A75876B75896D768C6F788E6F7A90707A91717B92707C94727C95737C97747E98
757F97747F95747F947781947A82967C83987C84997D85997D86997E889B7F8A9C7E879C
808A9F828AA0828BA0848CA0848E9F878F9F87909F8792A08892A08892A18893A38A94A5
8B95A68C95A78E96A88F99A99199A8939BA5969EA4959EA2959FA1959EA1949EA295A1A5
95A1A597A3A698A2A597A2A595A1A496A3A296A3A295A2A093A09D93A09A92A1978C9B8E
3A39404244465B635C49514C3A3F3C26292A4D574D4D554D4E564E4C52495F695B91A68B
7686767F907F8293837B897C5C60614C4B556F74757C84808D9B8D8A9A8686957E7D8E74
2829261C1B191C1C1717191017190E171B0F151A0C181B0C262A172A2C1E1714103F4137
7F8F756D7769727E70748374708170697A663C453C1C1F1C2B30272C32272C33252C3424
2D35252E37273038292F3729
43465F45486545496944496A454A6C45496C44486B44496B444A69444A68454C68454C69
464D6A454D6B464E6D49526E4B546F4C536E4C536F4C55704B54714C53734F5677505A7B
515B7C535C7D545E7E56607D56617C57627B59627A5B627B5D637D5F647F5D63805E6581
626A84626B84616B83636C84646D86656E88676F8967708A68708B68728C68738B6A7489
6A75876B75876B74896C758B6F788C6F798D6E778C6F788E707A90717B91727B92757E95
767E96777F96777F957881947B83957C84947B83957D85977D85977E86997F879B80889E
8189A18088A1818AA2828BA0838D9E868F9E868F9E88909F8991A08A92A38B93A58D95A8
8E95A98D94AA8E96A99098A99199A7949BA6969DA4969EA2969FA2959FA1949EA1949FA3
96A1A595A0A7959FA595A0A594A0A695A2A695A2A494A1A194A1A1919F9D8F9D9791A195
46484B4044457381724B524D3C413E27292B4B554B4C564C4D574C474D4450554A7E8D76
7785727B88768796838391807981753E3941646666767D788B978A8896868595817B8D77
30342F1919181E1F1A17191314160F15190F13170D11150A3743294D593D1614104E5447
7A88736C786B717E71738274718373697B68424D412D352D313B2F2E362B2C33272C3526
2C36252E39272E39282D3727
434660444865454967454967464968464869474A69464A69454A68454A69454B6A454B6B
444C6B454D6C464D6E4950714951704A526F4A536E4B556E4C566E4D56704E5774505978
515A7A535B7D555F7F55607D545F7B56607B59617B585F795A617A5D637C5E627F5F6481
606583606785606785616984646C86646B87656C87666E88676E8B686F8B687089697289
6972886972886A73896B748A6C76896E798C6E798B6D778A6F798B717B8D727B8E747C8F
767D91777F92777E927981937A82927B85937A84927B84957B84977D85997F879C8087A0
8188A28188A38189A1818AA0818A9D838C9D868F9D88909D87909F8891A18991A28C94A4
8E97A78F97A98F96A89096A79198A69299A6949BA4959DA4959EA5949EA3939DA1939DA1
95A0A4959FA6949FA594A0A794A1A893A0A892A0A6929FA2929F9F8F9D9B8E9B9792A299
6067672C2936677168535B544046412D2F2F4E584C4D574B4951473C3F3A41443D5B6354
75826B8494798A9B8286957F838F7D3A373E5B5D5E78807A859186849184849584778876
3135341B1B1C1F201D1A1B1715171212150D11140C0E100B35402C4B583F12100B454A3C
75826C6D786B6F7C7072817472837370826F4651472E352E323A2C2D35252C32232E3424
2D34232E37242E37242E3724
41455F42466244476446486646486846486A46496A454969454969444A69434B69434B68
434B69444C6A444C6A464E6C49516F4A52714A52714A54704C56704C56704D56714F5774
505775515979535C7D545D7D545E7B555F7B59617C59607A5A62795C627A5D617C5F637F
5F64815F6582606783636B82636B81656A83676B86686B87676C8A676D89676E88677089
67708969728A6A738A69728B68718A6A748B6974886A74866D77876D77866E7887727B8B
757D8D767F8F7880917981917982907984927883927983937B85957E86977F879A7F869D
7F869E7F879F818BA1818B9F828B9E848D9E858E9D87909D87909D88919F8891A08A93A1
8D95A38F97A49096A49297A69299A69299A5929AA3949DA4939FA3919EA1919EA0919E9F
939FA195A0A2959FA296A1A593A0A393A0A3939FA3939FA1929E9E919D9C919E9993A29A
6F7776292533454948424843373B37383B364D55494C54474D564942483F383C363F433B
65705C88987E92A38B899683859082403C466D747079837C869288859285859485798777
2C2D2F1C1C1E1F1F1E191A1614161011140B1012090F0E093E453456634B110F0F30322E
72816D6B796A6D7B6E70817271837270826F57665532382E292D212B301F2C321F2D3320
2E34212D35222C35232C3422
3E455C40465E454962474866474868464768444668444768444868424865424A64424B65
434C65444E66444D66434C66464F69474F6C48506F48506E4B53704C54704C56714E5773
4F5875505A78525C7B545C7C545E7C545E7C57607D59627C5A627B5C637B5D647C5D647D
5E657F606781616781626B8161697E62697F676C82686B83686B85686D88666D88666E89
666F8A65708967728A67718A666E87676F85666E83646C81656D81676F82656E81677182
6B74846D75866F7888717B88717C8774808A77838E7985917B87947D88967F89997F8899
7F899A7F8A9A818C9A828D99838D9A858E9D858E9D858F9C87919D8A92A08B92A18C93A3
8C93A58E94A69096A59097A49299A5939AA5939BA4929CA1909D9F909EA0919E9F909E9F
93A09F95A19F95A0A095A1A294A0A294A0A3939FA1939F9F919E9D8F9D9A8E9C9791A198
6D76742C28363534372D2D2E2322244C5445515B494F57464E56443F4536393E32353730
575E51A3B99A92A28E8B9988889484474449838C80858F848A95888894868492807E8C77
31322F1716171E1F1B1A1A1516170E14140A1212090E0C05424A3659654E161213363A37
67766964736867786C6A7D6E6C806E687C675565512E3529212619292F1E2C311F2C311F
2B33202D36222C35232A3322
3D445D3F4660434865454867454768454668434667434667424866424965424964434A64
444D65444D65444D66454D67464F6949516D4A516F4B50704C52724E55744D55744D5575
4E587850597A50597B525A7C545D7C545D7C555D7C58607E59617D5A627C5A637B5C667C
5D657D5F667F606781616781616880636A82656D83656C84666C84676E87676D8A676E8C
656F8D65708C67718B687289667087677086666E84656D81666C81666C83626A82626B81
646C81636D7F636B7E656E7F66717F6874806C78836F7B8873808D7582917986937A8894
7C89957D8A957F8C957F8D93808D94838F99848E9A848E9887919D8992A08A91A08A90A0
8B91A48D92A68D92A48F94A49297A4949AA4939AA5929BA2919C9F919C9E919D9E929E9F
94A1A095A1A0949FA0949FA2939EA3929EA5919EA2909D9E909E9E8F9E9C8A9A968EA096
727F782F2D363432332D2B2B1F1C1C575F4D5A65505059454C544131332932342A3A3D32
42453B9AAE8E97AA92909F8F8C9A8A5152518C9786939E908D988C8A988884958182957A
3F46391514121F20191D1D151D1C1319190F17160D110E083D4232616D56201D1F4C534D
66746B61706B5F716A5F716661746361745F343E342A3228272F22282F1F2A31202C3221
2D34212C34222B3322293222
3E435D404662424966434967444868444768434667434767424766434766444866444966
444B67444C67454D68464D6B464E6D48506E48506E4A506F4A51714C53734D53734E5375
515779525879535A7A545B7B565D7B575E7C575E7C585F7E575F7D57607C59627B5B647B
5C647C5E657E5F667F606681606682626883646B84646C85646C86666D87686E8A676D8C
666D8D676F8D69708D6A728C6A728C6A728C6C728B6C72896C72896C718A6A708A677089
666D87646C85636A81646C81656D82626B80636B80636C80666F816871826C75846F7885
717B86747F8975828B78868D7B888E7F8C91818D93848E9487919989919D8A929E8A919D
8B929F8C94A38D94A28E94A19197A29198A19299A0939B9F919A9B919B9C929B9C929C9D
949D9F969DA1959CA1949DA2949EA2929EA1919FA1909F9F909E9D8F9D9A8C9B968D9F95
7D8C823F42443737342F2D2825211E5C624F5B63504F55454A5241383E31353B2D3D4435
3739317B89729BAE9390A0908C9B8E69716E808C827E8984818E888C9E9084978581947C
3D4337161411201F191D1C171E1C171B1A1418161016130F4246386C7A62454B44606B5E
647165637167434C4B33393B4A584C677B61313A2F272F242A332529302129301E2A3220
2B33232C33222C332129301F
3B415A3E455F4047613F4561414563434665414564414765424665444766454767464868
454968454B69444A69444A6B454C6E464D6D454D6B464E6B474E6D494F6E4C50704E5273
4F5374505475525778535979545A79555B79565D79575E79595F7A59607B5A617B5B627A
5C637B5E647D5E637E606481636684636683636583646784646885666A87686C896A6D8B
696C8B686E8C68708C69708C6A718B6A708A6D728B6F758D70768D71768D70778E6F768E
6E768F6D768E6C758B6B73896B73886A70876B7186696F82676E7F676E7D686D7D6A6F7F
6A6F806B70816A70816A72806C76806E7981757E867982897F878D838A92858C94878F95
8890998C939D8D949D8D949C8F979E90989E91999E919A9B919A98929B9B929B9C939B9E
959C9E979DA0969DA1949CA0939D9E929E9D93A09E929F9D929E9D909C998E9C95919F94
7E897F47474A3937382C25254542397F886E575A4E51564B4E5548444B3D3F4737404538
41443B727C6896A58C92A18F8A978B838E87828F885E666B6E7C778DA28F7F927F80937B
3D42391B171621201C1C1A18191815181613151310181614474D3F697862606D5C667563
667463697967373B3C1A1A25282E31556755323D31272F252A33272A3124293122293222
2B34242B33212A321F2A311D
3C415A3D435D40466040455F414660424761424761404662404663414765444768454869
43466943486B444B6C454D6E464E6F444C6E444C6C454D6B464D6B4A506E4C51704D5271
4D52724D52734F5476515676525877545A78575D78575E77585E77595E785A607A5C637C
5C637C5D627E5D6180606383616485636685646785646883636783666986676A86696C86
696C86696D87696F886870896770896870896A718A6B728B6D748C70778C71788C72788F
7178906F788F70798F727B8F747D8F757D8E777E8F777E8E747C8A727A86717884727786
7174876E71876A6E84686D82676E80666E7D6A707F6D73816F7583727785767A88797E8C
7C838F808892838B93868E938993978B96988E999A909B9B909B9B939C9D919A9B939B9C
959D9C969E9B969E9C939D9C929D9B929C9B919D9B929C9B939C9B929B9B919B97919D93
8691864240463734392D282D646A5BA4B6924C4D424B4F444B5045454C3F4148393E4134
4141366A705E919D8595A28F8D988B8A958B7C8582575A62667170899C8C7D8F7F7D907E
3F46431513181F1F201A1A1A1717161716141614131613144950426E7E67647160687765
6B7967707E6C4248451817233942422C343328312B283127283126293126283125293324
2D35232C35212A311F292F1D
3D415A40435E42466142466141466042475F424760424761434762434665434666444667
43476842476943476A444B6C464E6D454C6B454C6B464C6D474D6E4A50704A51714C5272
4E5272505474515675525775535774555A75565C77555B77555B75575D765A60795B6179
5D637B5D627C5E617F60628360628262648365688565688265687F686A81686A836A6C84
6B6D856B6F886A6E87696E86686E876970876A70876C71896E748C6F758C70758B72778D
73798F73788E747A90757B91767B92787F92798092787F90777E8F79808F7B838F7D828F
7C7F8F7B7E91787C8F757A8E73778A7176887074876E72876E73876D71866E7186707386
737687767A8A767C89797F897C838A7F878C838C908890938A92948A93938D9695909897
939B99959C9A969E9B949C99949E99949D99939D9A929C9A919A99919A9B929B99929E94
869185444146322E34322F3177836B839173505445484D414A4F4443483D373A2F35362A
35322759594897A2878D94868E958D8C948D7C817F72777464696A89998B7E8F817C8F7F
3F464416141B1F1F211B1B1B1A1A19191916151311141211505A476F7E625D6754596253
5C66566C78654D554B19181D4953491E2122212623262E2527302528302328302128301F
2C34202D34202C311F2A2E1D
3F425740435941445D42446042456044475F43465E43465E434760424562424463414663
414762424863434965444966454B68474B68474D6B494E6E4A4E704A4F714A4F724C5072
4D51714F537050556F525670535770545A71565C72555B73565B73565C74585E765A6077
5C60795D617A5E627C5F627E61627F626281656683656882676A7F696D80676B7F686C81
696C836B6D846A6D846B6E856B6F866B6E856C6F856E71876F738A6F748A6F748A71768B
71778C73778C767A8E777A90777B91787D907A80907A808E797F8E7A808E7B828E7D838D
7D828F7E83917E84937F86957F84947F83957F85967E83957B8194787E91777C8F777A8B
787B8A767A89767A88757985777B85787C837C7E857E81877E8388808689848B8D868D8F
888F908E9595909795929996949C97949C97949D99929C9B919A9A909897919996929C93
8A9386423E432F282E4F514869715E5153474E4E46494A434B4F45484D413B3E31383A2B
3E3D2D52514098A1839096869AA1969399928589837577746C6E6A8F9D8B81907F7C8D7A
373C3A17161820201D1C1C191A1B17191B1513141016171355624A5D6A50373B2E33362D
4D53436570594F5645201F1C34382E1D1E1B212720232A21262E22272F22272F21282F1F
2B31202D33212D33212B301E
3F40543F415640435A42455D44465E43455C43455C43465C41455D42455F424561414862
3F4660424861444A62444A62454B64464A65464A67484D6B4A4F6E4A4F6E4A4E6E4B4F6F
4C51704D526D4E546E50556F51576F535A6E555C6D555C6F565C71575C73575C74585E76
585E775C60795D60785F627B61637E63637F65658164668065677E676B7E666B7C666B7D
64697D666A7E696B816A6D836A6E84696C836C6F836E70866F718870748A6F73886F748A
71758A73798A74788B76798E777B8F787C8E7A808F7B818F7A7F8D7B808D7C808D7C818E
7D82907E84927D84937D85937F8695808796838B9A848C9A848B9A838B99848B98838796
8185937E83907B808C797D88797D86797C847B7D837B7D827C7E837D81867F8488808588
818789858B8C888D8C8B908F8E9493909896939A98939D9A929C998F98948E98928F998E
8C9786413E41281D246B705E757E685B5E514A48444A4A454D52484A514444493B404434
4245324C4D3B8E9879939C86ACBAA59DA7998A91857F83796B6D658A978183917B798973
383D381412141E1E191A1A15171A14151913121610171C1337422E424D372F34252A2C21
4A513E677659515C451C1D1823261D22271E232920252A20262D20272E21272D22293022
2C32232E34222C32202A2F1D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 300},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001;2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`003Ooooon]0?oooa[ooooo00H04108010?1`0@3`T04A0;014@3@0B4@h2
018A3@0;01DC3@0D4``05A@=01HC3P0C4Pd051<<01<D300A4P/04A8=014C300C50d00P0D5@d2014B
2`09010B2`0>40X03Q0;010C3@0@50l04A<?010B3`0B50l04a@?00805A@?00@051@>01@D3@0C4``0
5AH?0P0F5a001P0D5Ph051H=01DH3`0D5Ph051D=018D3P804aHA00H051L@01<F3`0C5@d04a@<01@E
3@0E5@d201LG3`0301LF400H61@05QLC00805aTE00<05aTD01HG4`0D5A800P0D5Q801P0B51004A@>
018E3@0B5@d04Q<<01@E3P8051H@00<05ALA01DG4`0E5a<00P0G6A@01P0D5A0051DA01<C400D5140
5QLC01LI4`805aTA00`05AL?01HH4P0E61405APA01DH4P0E61405aTA01HE3P0F5Pl05QHA01HE400G
5Q0201HF400301HF4P0E5Q805QLD008051DC00H04a@A01<B400F5A4051@?01<C3@0C4`h2018B300;
01<C3@0@4@d04A8?018C3@0A4Pd051<?01<C3`0B4Ph04A4=018B3`0A4@h00P0A3``0300>30T03`h9
00h>2P0>3`X03a4:010C300>4P`03A0;00`?2@0;3@L02Pd600`>20802`d800/02`/600/:1`0>3`/0
30h=00/>4@0;31403@/A00`93P0<2PX02`d:00T:2P0200T;2`0;00T<3@0<3a800@87004210020P<0
0@8400811P020@L00P4800<220030PH00P030PD00`020@H00@450081100200@2100300D20ooooooo
oooo00gooooo000=ooooojd0oooo6_ooool01P0F6AH06alK01hQ7P0N8Al07AlQ01hR9@807b@Q00/0
7R<L01/P5`0J7aD0724D01hT5@0P9AH07b@E01lS500N8A<07b8D01hP500201hR500;01lT5@0O91H0
7R@E01XO4`0L8AD06b4D01XQ500K8AD07B<H020T6P0Q91`00P0P8a/0300Q9A/08RHJ028W6@0Q9QT0
7R@I020V6P0R:Q/08b`J02D]700S:aX09BXK02<V6@808bLK00/09RXL02@Z6P0S:1X092/K02H/700W
;A`0:RlN02P/7P0X:b4092LO02DY7`0202H/8@0;02<[7@0V;al09RhM02L]7@0X;al09R/N02P/7`0W
:ad09R/L02D[6`0V;A`00P0V;1d02`0W;Ah09RhQ028Z7@0T:a/09RdL02D/700W;ah09R`L02D[700[
<R009R`K00809RdJ00`0:2lM02`a8@0T:AT0:BhM02HZ700X;1h0:BhO02da800]<B40;2lP02`_8P0/
;b4202da9@0602T]8@0W:ad09BXJ02H/6`0U;1`0:2dM0P0Z;ad00`0Z;Qh0:R/O02PZ7`0202T]800;
02X]8`0S9Ah08R@L024S600O8AL08B8H028T6P0P8A/0828K028S6`0P8aT00P0O81H0200K7A8092LH
024S5P0R91H08RDF024T500L81806b0A0P0M81403`0K7Q006QdA01/N4P0K7Q806A`A01/N4P0I7a<0
5ahE01LO5P0N9b4030hF00d<4`0=3@d02@/800T;1`0201@J400400dA2`010P400P8100840@800@81
00D00P83008210010P@00@@400440`0400430@0400440@02104010<100D30@oooooo000=ooooojd0
oooo6_ooool01P2G[YP0W;BO09niXP2O^Z40OI5o020T:`806A/O00/06AdK014D4@0?4P`03a8901<H
2`0H70h06Ad>01XN3`0K7@h071l?01/O3`0201`P3`0801dP400J7A00720C01`P500O8QH07R<G01dS
5`0O9AX201hS6@0?01lT6`0P91/082@K024U6`0Q9AT08BLH020U5`0N8QD07bDG01`T5@0N9Q@08RLF
02<W600T9aP08R@F00808bHH00/092HI01lQ500P8QD08B@F028X6@0R9aT09BXJ02HZ7P0V:B4092HP
02HY8P0202@Z800;02D[7@0W;A`0:2hK02T^6@0Y;AT0:RhO02TZ7`0Y;1h0:BdM02T^7@0W;1/00P0Z
<1d02`0Y;ad09bdM02L]7@0Y;Qd0:RlM02T_6`0Y<1h09B/J02P]6P0Y;QT0:c0J0080:RlI00`0:BhH
02L/6@0U:QL09R/I02H[6`0U:1X09bTK02PZ7P0[;R80;2lR02ha8P0_<R<202da8`0;02X_800[<200
;38P02Xb7P0_=R40<3HS030e8`0^<R80<CHV034e:00^<R@00P0_=2D02`0_<RH0;BlU02/^8`0X:b00
:RlR02/^8P0^<2@0;BlU02L[800W:Qh09RPL008092HJ00`09RTL02DY6P0T9aL09BLE02LY600U:1L0
9BXG02DX5P0S9QD09BTH02@X600R9QL202<X6@0;01lS5P0P91H082@E024T500K7`l0728@01/P3@0G
6``05a`B01LK500E6A@00P0H7QD02`0J7a@05Q/=01DI300E6@h04aH=018E3@0G6Pl061/@01LK4P0D
5a4051TB00804aL@00H051PC01@H500E6Q<05Q`B01DJ4@0F6Q8?ooooo`003Ooooon]0?oooa[ooooo
00H0UjjL09fgY@2Q^jD0WkVQ09VbVP11BdT2018D600;01TN6`0F6QL04aLB01DJ400F70h06R0?01XQ
3P0H7`h06Ah>01/Q3`0N91800P0O8a402`0O8Q407b4D01lO5@0O8AT0828K024S6`0Q91/082@L01/P
600M91X07RDK00807bHK00`07bLJ01lV600O9aP07bDE024V5P0T:QX092/I024Y5`0R:AL09BXG02DZ
600U:AL202@V600;02DW6@0T9QP08R@G02@W6@0S9Q/08RPJ02@Z6`0X;B409R/R02@X800S:1h00P0V
;1h02P0W;Q/0:BhH02/`600Z;AL0;30K038d8P0`<240;BhQ038b900_<B8302h`800:02PZ7@0U9a`0
9BTL02H[700`>B<0:S<N02D_6P0V;AX09bhH02T_6@<09bdG00L0:2dH02T^6P0V:aL09BPG02HY6`0V
:Ad09bPM0080:BTQ00<0:bhT02d`9@0^<RD00P0/<R<02`0/<R409bhL02Pa700[<a`0;C<M02hd7P0_
=Al0:c4N02hd8P0_=2<0;S8Q0080;S8S00/0<cDV034d9@0/<2<0;2lU02/_9@0[;b<0;S4S02da8`0Z
;R40:2`L02L[6`0202LY6`0<02HY6P0W:aX09b`J02P[6P0W:QX09bTJ02DV600U9aP09bTK02HW6`0S
91/08R@J0P0R9AX02`0P91T07b@G020T5`0P9QP07bHG01lU5`0Q9QP07B8E01PM4P0H7aD05a`E0080
5Q/D00/05ATB01LK400H71006A/A01LH3P0H6Q006QXB01TJ500I6AD05ALE01DG500201DH5@0601LJ
5P0F6AD05a/E01PM5P0G71D05ATB3oooool000gooooo[@3ooolJooooo`0609B]V`2O^jP0X/2Y09nj
XP2M^J00KH5b0P0O92L02`0L8B005a/H01<H4`0D6A405A/@01LM400J8A407B@B01hT5@0N8A<08B@F
00808RDF00/08b<F02<S6@0R8a`08B8L01lP6`0N81T0720I01lU7@0L8aX07BDI01dU600201hV600<
01lX600O9aD07bLD01lV4`0R:AH09BXG02<W500T:AD09R/I02HY6P0U:1T092PI0P0V:QX01@0W;1`0
9R`K02HZ6@0V:QX092TI00809BTJ00@09b/O02DZ800R:1l08BLM0P0V;Qh02`0Y<ad0;C@J02`a6P0^
<1`0;RlM02h^7P0b<B<0;blR030a8`0`<B@0<34S0080<C<T00D0;2lQ02T/800Z;B80:2`O02H/6P02
02H_6P0402@/5`0W<1P0:2hH02X_6@80:c4J00`0:blL02/^7P0Y:a`0:2`L02DY700V:1l09RLO02X]
900X:b80:RdT02db9@0^<bD202/a8P0;02Xb8@0[<al0;C@M02he7@0a=b00;c@P02/_7P0]<R80;C8S
02lc9P0_=2L00P0_<bD02`0_<b@0<CDV034e9P0`=2H0;cDW02hd900^<b80;C8O02hd800^<al0;C4O
0080:bhN00`0:B`M02T^7@0Z;al0:RhO02P/800V:Ah0:2/N02HY700U9a/09BHL02<T6`0S9A/202@W
6`8082LH00T082LG02@Z600R:1@08RPG020U5`0N8aH06b8F01TO5P0G7A@00P0G7A<02`0H7a<06B0@
01/O3`0K7@l06aX@01/K4@0M7aD071hD01`M5`0J7AT05a/G008061/F00H06AdG01LK5@0H7AD06R0D
01LK400H6Pl?ooooo`003Ooooon]0?oooa[ooooo00H0M89`09N^TP2J]IT0W[^O09jlW`2@[8h204=A
AP0;014F5@0I7QT041@?00lC300B5Pd05AT@01PN4@0J8A<0728F01hR5P0Q9AX00P0R9Q/02`0U:Q`0
8bLJ02<U700Q91X08B@I024T600O8aD07B8E01hS5P0O9AL07B<D00807bHE00X07bLE02<Y600V:aX0
9BXJ020W600U;1`09BXJ02@Z6P0X;Ah0:2`M100X;1`02`0U:AX0:2`J02P/6@0W:Q/08bHG028V5`0O
9AP082HK024W7P0Q:B009B/Q0080:BlR00/09blN02T`700]<ah0;S@O02hc8@0^<200<3<R02d`800_
=2<0;c@V02lc9002034c8P0;030a800_<1l0;c0Q02T/7@0X;Q/0:2lK02H]600V;1H0:2dG02/`6`0[
<A`00P0/<ah0300Y<1h0:BhN02P]800W;Al09B/L02D[6`0U:AP0:BdN02/_800/;R40;30Q02``8080
:c0P00/0;SDS02dd8P0`=b@0<cXV038g9P0a=BP0;c8Y030d:`0]<BP0;C<X02dc9P0202hd9P0302le
9`0]=2H0;S@S0080;S@R00H0;C<P02lf800`=Ql0<CDQ038c8P0a<R@2030b9P0;02d`9@0Z;R<09bdQ
02X`8`0V;B009RhP02L^7@0X;A`09b/L02@W6@0T9QP00`0S9QP02`0R9AH08bPE02<X500S:1<08BDC
01hQ500O8QL07B0G01XO5`0J81L06AlC00805adA00/05ad@01PN300G7@X061d;01PL3@0H70l06b0D
01`P5@0I7a@06b4E01/Q5P0201XP5@0601TO5@0H7Q<05ah@01PN400H7A005AP<3oooool000gooooo
[@3ooolJooooo`0602P]8P12C3/0EfA?07V>K@25WgX0UKB:0P1SNEX02`0?4Pd04QH?00lD300=40`0
3Q0=01<G400F710061hB01XQ4`0L8QD082HG008082LI00/08bLG028V5P0Q9AH08bDI02DY6`0T:1/0
9BTK028U5`0S9QL092PH02<W5P0202<X5P0<028X5`0U:AX08bHJ028W700R:Ad08RTK028Y6P0T:a/0
8bXK02DZ6`0V;1/0:RlM0P0[<1`02`0X;AX09BTI02LZ6`0V:AX092PJ02<Y6P0S:Ad08RTM02H^8P0S
:Qh092`M00809B`N00/0:30O02Pb700W<1T0;3<K02dc700/<Ah0;C<P02db800^=B<0;S<T038g:@02
03<f9`0;03<d8P0c<b40;RhL030b7P0/<Ah0:BlL02H/6@0T;AT09RhJ02@/6`0V;a`00P0U;QT0300X
<A`09bhM02P^7P0X;Ad0:2hL02L/6P0V:1L0:b`K02h_7P0/;Ad0;BhP02h`8@80:blP00/0;38R02`c
8P0^=280<CLT034f9@0d=bT0<SDZ034f:`0_=2T0;C4U02`a8P0202hc8`0;02`b8`0]<bD0<CPV034g
900_=B80;34O030f8P0b=R80=3DQ03<d8P0`<B400P0Z;Qh0300]<R409b`M02P]7@0X;Qd09B`L02D]
6`0S:aL09B/F02P]600W:aX09BLH02@V5`809BPI00/08bHF02@X5P0R9QD08BDC01`R400M8a@07R<F
01/P5P0J81L06B0E01PM4@0201PL400;01<G300G7@l051T:01<H2@0C5PP05a/=01PM400I7Q406AlA
01dT5P0K8QD00P0J8A@01P0I7a806AhA01HK2`0F6@P05aT:01@F2Poooooo000=ooooojd0oooo6_oo
ool01P0X;B80@T`k05MTC`1iSVd0QImj09FdRP80HgUJ00/03a8=018F3`0?50`03A0<00h@3@0C5a00
5Q`@01PN4P0J8A<0728E020V5`02020W6@0;02<W5`0R9QH08BDF02<U6@0U:A/092PK02DY6`0R9AL0
8bHG02@X600S9aH00P0S:1H0300R:1L09BTJ02<V6P0R9a`08RTM028Y6`0R:AX092/K02<Z6`0U:Q/0
9R`K02X_7@80:c0L00/0:2dJ02DY6@0W:Q/09RTJ02@X6P0S:AX08bTM028Y7@0V;R808bXN02@/7@02
02D/7P0;02P`7`0X<Q`09c0I02`c6`0]<a`0;34N02dc800]<R00;SDS02hc900b=bT00P0c=RL02`0c
=280<c<Q02h^700`<Qh0;34N02T_700V;1T092dI02H^6P0T;1/09RlL00809BhI00`0:34L02L^7@0X
;Qh0:2dM02P^700W;1X09RPG02//6`0^;ah0;2dM02d^800^<24202/_800;02`b8P0/<b80;S@R034g
900a=RD0=3LY038e:P0a=R/0;c@Y02da9@0/<B800P0^<b<02`0/<R<0;C<U034h9P0a=b@0;cDR02`a
7`0`=R80<SHR03@e8@0c=280<34Q0080:RhN00`0;C8Q02L/7@0X;Ad0:2hM02D/700U;A/08b/G02D[
5P0X;AP09b/J02DW600T9QL202DX6@0;02<V5P0T:1H08RHE024U4`0L8Q007B<D01hS5P0K81H06R0G
01TP5@0H7A400P0H71002`0C5``05ad?01@I2P0C60T04aH801LK3@0H7A006AhA01TO4@0M91H06b8E
00806R4D00H06AlB01TN4@0F6`/05QT801LI2P0D5PX?ooooo`003Ooooon]0?oooa[ooooo00H06AlC
020V6P0O91P08RTJ03Q3:P1DID<204eM?P0;028V600S:1d07B8H01LL500D610061hC01PN4P0H7a@0
72<F01lW5`0P9QP0100S:1X02@0S9QX092DM02LW7P0W:Ah09bXN02DY6`0U9QT092DF020T4`0202<W
500<02<V5@0S9QL092TK02@X700V:R409B/P02<Y7P0U;2009bhQ02P^800W;Qh09RhK0P0Y<1`02`0Z
;a/09b/I02P[6`0[;al0:BdP02/^800Z;b00:S0P02P^7P0X;Q`0:BlI00809RlH00/09c0K02@/5`0Y
<1T0;38K02``6P0^<1/0;c8M02lc7`0]<R40;S@S034f9`02034b900;038c900`<B80;c4P02ha7P0Z
;Q/0:S0K02Ta700W;ad09BdK020X600P:1L00P0T;1T0300U;1`0:BlN02T]7@0Y;Ah0:2`M02L[700V
:QX0:bhK02da7@0/<1`0:bhM02d`7`80;30O00X0;C8O02dc7`0^<b40;S<Q038g9@0d>RX0<SHZ034f
:`0a=bT0;cHU0`0]=2402`0_=R<0<CTV02lh9@0_=b@0<CTU02le900_<b80<cHR03Dg8`0c=240<C8N
0080;S0L00`0;C0K02/_6P0/<Ad0;34M02T^7@0Z;ah0:RlM02P]6P0Y;QX0;34N02T^7@0Y;ah202@Z
6`0;02@X6@0T:AP08BDE01lQ500Q91D082DE01hR4`0N8QD0724E01XP4`0I7`l00P0I7`h02`0I6``0
6A/?01XK3`0H6Pd05aT<01TK300L7a406al@01HK3`0J7a806b0D00806QlD00H061/A01DI3`0E6@d0
51P:01<E2@0?40D?ooooo`003Ooooon]0?oooa[ooooo00H03a<;01<H4@0E6A405QTC01dQ600Q9a/2
024Y6`0;01hS5`0M8aD06b4B01TP400G7Pd05Qd<01PO400J81<05adA01/R500N9AH00P0S9aP02`0U
:QX092TJ028V600S9QT09RXL02L[7@0W:Qd09RXL02HX6@0W:aX09R/I00808bPG00D08bHH02@X6@0V
:a/092PM02HZ800202L/8@0502L]8P0X;2409BXO02<X700X;Ad00P0Z;a`02`0[<Ad0:BhL02X^7P0Z
;240;2lT02X]8`0Z;B80:c0R02``8@0[<1h0:BhH00809R/G00/09bhJ02X`7@0Z<A/0;cDN02ld7`0`
=200<S<Q02l`7`0`<B40<SDU03@g:002038d9@0;03Dg9`0_<B80;BlP02lc8P0]<R00;C8O02/b7P0Z
<Qh0:C8N02H^6`0S;1X00P0T;1X0300W;Qd09R/K02L/700Y;Qh0:RlP02H/7P0S:A/09RdK02Xb7@0Z
;a/0;34O02db8080;S8Q00/0;C<P02da7`0^<b00;c@Q030g8P0b=b@0=3PX03Dj;00b>BX0;S@U02`b
800202dd7`0;02lf8@0_=R<0<3LU034h9P0a=bH0<SDV034b8`0b<R80<S@R034b8@0b<b000P0d=B40
300^<1d0;2lM02``7`0[<1h0;30N02X^7@0X;A`0;C4N02X`6`0Z;a`0:c0P02/b8P809bhN00/08b/K
02@X600U:AP08RDF028T5`0Q8aH08R@F024S5P0P8aD07R4D01hQ4`0201dP400;01dR400J70d061X=
01TJ3@0H6@d061X=01/M3P0K7@d06Q`=01`O4P0I70l00P0H6`l201PJ400401DH3P0B5PX04146014C
1`oooooo000=ooooojd0oooo6_ooool01P0>4P/04A@<014B2P0F60l05aTB01/P6080728H00/06b8G
01XQ5@0K8A@06b8D01XQ4`0J81806R4A01TO4P0G7Pl072<A01hT4P0201lU4`03028V5P0P91@08bHG
00808bHH00H09BLH02DX6@0V:Q`09BTK02L]7P0V;1l202D/7@0<02D[700S:A`08RPL02H[800V:Al0
:2dP02L[7`0V:Q`0:2dN02L/700W:Q`0:bhO0P0Z;Ql00`0/<B00:c0N02`a800202X_7`0602/`8@0/
<R80:BhN02T^7P0[<200:BhN0P0W;Q`02@0[<1h0;38M02`a7`0]<al0;c<P034e8@0];ah0;c4P034c
8P0403<g9`0;03Di:`0d>BT0<CHW02le9@0_=B<0;S@R02hf800/=Ad0;C@M02Xb6`0[=1h00P0^=B00
300/<Qd0:RlL02P]6`0[<1`0:c0O02X`800Z<Al0:C<L02Td6`0W<1P0:34K02/d7P80;S@Q00/0;S@R
02lc8@0`=B<0;c@Q02hd7`0^<Al0=3HU03Dh:00f>bX0=3XX038i9P02030g8P0;02lf7`0`=b00<CPR
03@k9P0d>RL0<CLT038f8`0e=b@0<C8Q02l_8@0^;Ql00P0`<R40300`<B00;c0Q02da8@0]<B40;S<R
02dc8@0]<b80;30R02X_7`0/<B40;C4S02X_8P80:S8R00/0:30P02<Z6P0R:QT08BLF028W5P0T9aL0
9BTI028T5`0R9AL08B<F01lQ5@02020R5@0;024T500N8A007Qd?01hN400L7Q8071hA01XL3@0K7@d0
71l?01/N4@0G70l00`0G6`l01@0I7Q404AD9014E2@0@50P04QH900oooooo000=ooooojd0oooo6_oo
ool01P082P@02`h500`?1@0D5@/061XC01PL5P8061dE00/061dD01`Q6P0O8aX0724E01lS5P0M8A@0
6AlB01PM400J818072<A01hV4P0201hW4P0;024Y5P0Q9aD08RPG02HZ6`0U:1T09bXK02LY6`0X;1d0
:2dP02L]8P0U;2400P0V;B40300V;b409RhS02D[800V;B409RdO02X_7`0X;1`09RTK02P[6`0W:a/0
:2XL02d^7P80;2hN00/0:c0P02``7`0^=240<3HS02le8P0[<200:30O02T`8@0[<200:c4P02`b8`02
02Xb8P80:S4O00T0:2lM02`b7`0/<Ah0;34P02db8@0/<240;C4S030e9@0b>BP00P0c>BP02`0c>BX0
<SPZ030f:P0b>2`0;C<V02`b8`0Z<Ql0:c@O02/d700[=1/0:c@J0080;cPO00`0;cHP034f8P0_<b40
;RlO02`_800/<200:c4O02Xb7@0Y<aX0:C<I02Tc6`0/=1h202hc8@0;030e8`0a=R@0<cTV03<h9@0a
=R80<CHP030e7P0a=B00=3TT030f8P0`=2<00P0b=b@02`0a=R40<CPQ02lf7`0a>280;cHQ030f8`0a
=b@0<SLT038e8`0`<B<0;blQ0080;BdN00X0;BhO02X/7@0Z;Qh0:RlO02T^800/<B80;C8Q02`_800[
;R00:B`R0P0/<2<202T^8@0;02T`7`0O9QH082PF01lW4`0N9Q4082LB02<X5P0U:QT08RLF01hR500K
7a<00P0L81@0100Q91H07R0C01dO4`0N8AD201dO5@0501dP500N818071l?01/M3P0L7`l00P0J70h0
1P0J7@h06Qh?01TL3P0D6P`051T>01<G3@oooooo000=ooooojd0oooo6_ooool01P072P<02Pd4014F
2@0G70l07B<E01/O50805AH?00/05ADA01TK500F61405aXB01PN4`0J81@072<E01`S4`0L91406b<?
01hW4@0201hX4@0;01lX4`0O9aD082LH02DZ6P0V:QX09BTJ02L/700[;al0:RhP02T_8`0V;2800P0V
;R<0200W;b@0:30V02T`9@0X;b809B`M02P_7P0X;A`0:2dK0P0Z;a/03`0X;1T0:RhK02da7`0]<Al0
;c@P02hb7P0/<Ad0;S<P02da800]<B40:c0R02`a900]<RD0;34T02X_8`0202/a8P0;02`c8P0]=R<0
:c@Q02Xc8@0X<1h0:S8O02dd800/<al0;C<P02hd800a>2@00P0a>2H02`0b>RP0<3TW03@k:`0d>R`0
<SX[02hh9`0]=b@0;CHQ02`e7@0[=AX0;SLK0080;CHM00`0;cDO02lf8@0_=B40;c<Q02da800^<R40
;c@R02dc800]=1l0;3@N02Xb7P0/<Ql2030f8P0;030f8`0a=bD0<3HS038h8P0b=al0<SHN03@h800b
=R40<cPR03@i8`0c>2@00P0c>BH02`0b=b@0<CDR030e8P0a=b80<CHT038h9P0c>BH0<STU030f8`0_
=2<0;30Q0080:R`N00D0:bdQ02`]8@0];b80:RhP02``800202db8@0502/_7`0]<280;30S02T]800Z
<2000P0Y<1l02`0Y;ah09BdJ02H_6P0R:aH08BTD020W4`0U:QP09BXJ02@X5`0T:1P08BHF00<07R@D
00X0720B01/O4P0J7A<06A`D01PJ4P0J7A<082@F01dO4`0I6Q006AT=0P0L70d01P0L70`06a`;01/N
3P0F6@/05AT;014F2@oooooo000=ooooojd0oooo6_ooool01P092`@03A0600hA1P0>4PP04QL:01DI
2`805QP:00T04A@;00hA2`092`L03A4901<G3@0G7Q0061d@01TP4@0M91800P0M9A8201lW500;01hV
5P0P:1T08BPI02@Z6`0U:a/092XI02T`700[<ad0:c8N02/a7`0Y<2000P0U;2000`0W;b809bhR02H]
8@0202P`8`0702Tb8`0Z<B00;C@R02``7`0[;ah0:BhM02X^7@0202/`7@0;02hc7P0^<Qd0<3DO030d
7P0`<Q`0<3<M02`_7P0Y;1h0:blP02db8`0]<RD00P0]<RH02`0[<2@0;C<U02he9P0]=2@0:C4O02L_
700Y<Ad0:c<M02hg7P0_=Qh0<STR0080<cXU00/0<CXU02hh8`0c>bH0<c`W034l:00`>bH0<C`W038m
9P0_>B40;cXQ034l8@02034i800<03<j8@0`=Qh0<CLO034e8P0c=BD0<SDV030d9P0_=2@0<CLT02he
7`0]=1d0;CDM0P0^<a`02`0_<ah0<SLR038i8P0a=al0<cPN038d6P0e>1l0=3TR038h8P0a>280<3LR
0080<STT00/0<SPR030g8P0^=200<SPR03<h9@0d>BL0<cTV038i9P0a=bD0<3HT02hc8`0202X^8P03
02T]8`0Z:b80:bhR0080;30S00L0;30Q02X_800/<B80;34S02`b900Z;b409RdM00809blM00/09RdI
02H^6@0U;QP09RhH02@[5P0Q9a<08bPF02@X5P0S9aP08bTK028Z7002020X6P0;020V600M8QD06b0C
01TM400K7a<06QhB01hQ5P0P8QL07R0F01/L4@0K6a000P0K70l01P0L7@`06Q`:01XL2P0I6`T05QT9
01<E20oooooo000=ooooojd0oooo6_ooool01P0620@01`T400H90P093@<02`l400lC1@805A/:00/0
4aP9010C1`0:30@030l600lD2@0=40L03106018H300I7a807B@E01hT5@02028Z6@0;024Y6`0Q:A`0
8b/M028[6`0S:a/08BXH02@]600V<1T09RlI02Pa6`0Y<Qh00P0X<1l0300V;Ah0:BlP02X^800^=2@0
;34Q02hc8P0_<b80;C8P02hb8@0^<b80;cDS02hc8@80;C8Q00T0;SDQ034f8P0b=b<0<CHQ030e800_
=B40;S4P02`^7P0[;Ah00P0[;b4202db900;02hc9@0^<bH0;S@V02he900]=R@0;SLT02`e8@0[=1h0
:C4J02/d7@0]=B000P0^=b802`0_>2<0<3XS038l9@0b?2D0=3`U03Dm9`0e?RL0=3`U03Dm900b>R40
=3/S0080<cXR00P0<SLS038h8P0c>R80<SLQ03<f8P0d=R@0<cDU030d8`80<3HS00H0;SDO02dc7@0^
<a`0;S<L02ld7@0b>202034g7`0703<g7P0c>1h0=S/R03Xn9`0g>bL0<CDS02he8003030g8@0:034h
8P0a>B<0<CTS03<k900b>2<0<3HQ02dc7`0_=B80;S@Q030f8`80;C8R00`0;2hR02`_900^<BD0;C4T
02hb900]<B<0;30R02/`8@0/<240;34R02`a800[<Al202/a7P0;02L/5P0X;AH0:2dF02T^6P0Z;Q/0
8RHE028W600S9aP08RLI024W6@0Q:1X00P0Q:Q/02@0P9QT08BDG020R5@0Q8aH08bHG01dP4P0N8Q80
8BDE01lQ500201dQ4`806ad@00H06ad?01`M400L7Q0071h@01PI3P0D5P/?ooooo`003Ooooon]0?oo
oa[ooooo00<010H600H81@051`800P062@403P0<40<03Q<300hC0`0?50@041D300lA0`0@4@D04187
010B2@0=3PH03@h700d?1`0D60d06Qh@0P0N8a002`0R9aH08bXI02@]6P0U;QX08b`H028[6@0S;1T0
8b`G02H_6@0W<1/0:34N0080:30O00<0:C4N02`c7`0]<Ql00P0_<b801@0_<b<0<3@T038e9@0c=bD0
<SHT0080<CHT0P0^=2<02`0]=B80;SLT02hg8`0_=B80<3HS034g900a=2<0<C8P02d^700]<1l0;2dO
0080;C0P00D0;C4P030d900_=RH0;cLW02de9@0202`e8`0402df900Y<b00;3LQ02/f8080;3LP00/0
;SPP034j900b?2<0<S`R03Dn8`0f?R@0=chV03@k900c>R<0=C/T03Dj900203Hj9`0<03Hl:00e>bP0
=S`X03<h900d=b80=CHR03<e8`0b=B80<3DS02le8P0]<R00;3<N0P0/<ad02`0]<ad0<3PO02lg7`0b
>B<0<cTS03@k8P0d?280=ShV03Lm9`0g?RL0<STS0080;cDP00<0<SLR03Dl9@0e?BD00P0d>b<01P0_
=R00;cLP02hf7P0/<a`0;SDO030g8@80;S<P00`0;C<Q02da8`0^<RD0;S8U030c8`0`<R80;C0S02d_
900^<B@0;C8R02`b800Z<1d202L]600;02@[500V;A@092TC02LZ5`0[;Qd0:B`M02@X6`0U:1`08bLJ
020U600O9QT00P0P:1X02`0O9aT0728E01hR5@0N8Q@082DF01dR4`0K80h082<@01lS4P0P8a807B0A
00806A/?00H05QT>01/N4`0H71806AdC01HH400D5`h?ooooo`003Ooooon]0?oooa[ooooo00H010T7
00H;1@072P801PX200@70@05204200L90@0;00D80@092@40414301DE2P0J6`h05QL<014B2@0=3`H0
2P`500P<100>4`H00P0C60L02`0K8@d07bHA02</5P0W<A`09S0J02La7P0V;ah0:34N02Pb7P0V;ad0
9BhJ00809c4J00`0:C<K02Ta6@0/<Q/0<3HP02ha7`0_<b80;c<S034e9`0c>BX0<SPX03<i:00a=bL2
02he900;02hf9@0_>2@0<3PT03<j9@0c>R@0<SPU03<h9@0a<b00;RhL02h_7@0a<R400P0`<R802`0`
=B<0<CHT038h9@0b>BH0;SPU02df900^>2@0;cTU030j900_>200<S/Q0080;SHO00/0;CDM02he800`
=R40<CPR03@l900e?B@0=3/T038i8P0b>240=CXS03<h8@0203Hk9@0;03Pl:00h?BX0=c`Y03@j9P0e
>R@0=cXT03Dg9@0c=B@0<SLV02hd8`0/<R000`0/<ad02`0/=Ah0;CHO034k8@0b>R00;cLO03<j8@0c
>b80<STS03Hl9@0g?BP0<cTU0080<CHT00/0;S8P02ld8@0c>BH0=ShY03<j9P0e?2L0<c`U034j8P0a
>B40<SXP03<k8@0202de7@0<02hd7P0_=B40<3@S034f9P0`=RL0<3@W02lc9`0^<BL0;C0V02/_8`0/
<280:RlM0P0X<1T02`0W;aL092`D02H[5P0V:aP0:RhM02T]7P0Y;R009b/O02@X700T:Ah07b<J0080
7R4I00X07B4H01lU5`0O9QH07bDG01hV5`0M91L07B8E01XO4@0J81007B8C0`0N8A801P0K7a006AhA
01TM4`0I7Q<05AX?014F2`oooooo000=ooooojd0oooo6_ooool01P052PH01@T300L;0P0830801`/1
00<70@800PD100/010L100T90@0:1`405A@601TJ2`0H6@/04aD900`>100<3@802``200P90@0200T<
0P0;014E1P0L80l08RLG02H/7@0Y<240:cDW02/e:00/=bL0:C<R02Pc7`0V<AX00P0T;aH0300V<AD0
:S@H02`d6P0_=1d0<cDQ03<e900d=RP0<S@Z034e;@0`=B`0<CL]02lg:`80;SLZ00/0<3TW034k9P0c
?2L0=3XU03Ll9@0f>B80=CPR03@f800e=R40=cTU03Hh9P0203@f:00;03<f:P0d>B/0<3HW038i9P0`
>RH0;CHT02`f8P0^=b<0<CXS03@l8P0b>R000P0c>B002`0c>B40<cLR03<g8P0b=b80<SPU03<i9@0b
>2@0=C`W03Pn:00e>b@0>3lU0080=SdT00`0>D4Z03Pn:00k@bX0>SlV03Lj900g>BD0=cPV03@g9@0a
=BD0;cHV02`c8`0Z=20202Xc7`0;02/e8@0[=Ah0<3`Q030l7P0`>ad0;cLK034j7P0b>R00=C`T03Lo
9P0e?2L00P0b>2H02`0e>R/0<CHY030f:@0c>RX0=Cd/03Hn:@0e?RT0=3hX038m900b>b40<STP0080
<CPO00`0;cHP034g8`0b=R@0<3DU034e:00a=RX0<3DY02hc:@0]<2L0;S8W02P]8@0Z<1l202Ta7@0;
02Pa6`0Z<1X0:RlI02/`700]<Ad0;S0M02`]7P0[;1d0;2hP02TZ7P0S91T00P0Q8QP02`0P8QL082<H
020U6P0P9Q/08BLL02<X7`0S:1h082LJ01dT5P0N9AH07R8B00<07R8@00D06al>01/P400I70d061T:
01<F1`0?ooooo`003Ooooon]0?oooa[ooooo00H01``300T<1@0;3PD03A0400/=0`0:304200P:0@0;
00X=0P0;2`402PT100d=0@0>3@80410400l?0P0A40803Ph200d;0P0<20800P091@402`0:1`8040h9
01`M5`0W:B<0:c0Y02`d;@0Z=Bd0;3P/02Xh9P0Y=b80:C@M0080:SHJ00`0:SDF02/g5P0^=AL0;C4H
030b7@0d=RD0=3DW03@f:P0`=2`0<3D_02de;`0^=bh202hg;00;034k:P0d?BP0=SdW03Hk8`0g>b80
>3XQ03dn9@0j?2H0>c`W03Xl:P0h>Rh00P0e=Rh02`0d=Rh0=3T_03@k;00c?BT0<CdV02lk900^=b40
<CXQ03@l8P0h?R<0>3dS0080?3lW00/0?3hY03Xk:@0j>bX0=cT/03Dh:`0j?bh0=ch[03Ho:P0i@B/0
>44X03Ho9@0203@l8P0<03Ln900j@2D0>d4V03a1:@0j?2X0>S`/03Hg:@0c=BT0<SDY030g:00[=2D0
;3HU0P0/=R@02`0[=B40:SHM02di700_?1X0<ChI038m5P0c?1T0=clR03Hl8`0g?bL0>D4]0080>Cl_
00/0>3h`03@l;`0b>Bh0;CDX02lh9P0b>bH0=3hU03E09@0d?R80<c`P038i7`0203Dk8P0<03Di8`0e
>RD0=CHV03Hh:`0c=bd0<CD]038g;P0`=B`0;C8X02db9`0[<R@0:S<R0P0Z<b402`0Y<Qd0:c@M02`b
6`0/;a`0;BlL02l`7@0^;1`0<2hP02l^8P0/:b40:BPP008092DN00D08b@M024T7@0R9ah08BHN024X
7`02028Y7`04020W6`0O9aP07bHE020W4`807B@?00H07RH?01lW400O9Pl07RD>01hR300G60P?oooo
o`003Ooooon]0?oooa[ooooo00H02P`500d>1P0B4PP0414600d>1@0:2P<200P90@0;00/<0P0:2`40
30d200X<0@0720402`X100h>0P0?3P@03`d400l>1P0>2PH00P0;1PH02`0:1@P020@901@C5@0K71d0
8bPW02P`:`0Z=B`0:CHX02Xi9@0Y>B00:3LL0080:SHJ00`0;3PH030j6@0`>1`0<CHN03<g8P0d>2L0
=CP[03<h:`0b=b`0<SP_038k<00b?2h2034k:`0;03<o:P0b?2L0=chW03e3:P0l@BP0?SlV03ln:00o
?R`0?Sh_03Xj;`0j?3800P0h?3<02`0h?C@0=chb03Dn;`0c?B`0=Cl[03@o:00d?2@0=chT03Po900m
@2H0?ChX0080@3l/00/0?Sh_03/j;`0i>S80>S`c03Pm<P0e>bl0>3l_03Ho;00iA2`0>T@X03Y2:002
03U09P0<03Xo9P0j?BD0?D4Z03`o;00m?c40?3lc03Pm<@0d>Rh0=Cd]034k:P0^>2H0;cXV0P0]=b80
2`0^>1l0:cDJ02Xc5@0[=AD0;SLE034j5P0d?AX0=SXP03Hk8`0g?RT0=d0[0080=T4^00/0=D4`03I1
;`0c?b`0<S`W030j8@0_>1X0<CXI03<k6P0b>a/0=3/N03Lj8@0203Tj9P0<03Pg9P0e=2P0<c<Y034b
:00`=B`0<CTa02`d;00/=BX0:C4V02Xc900Z<B40;3@R0P0^=b@02`0/=240;C@O02hc7P0_<1l0<C4P
038a8P0c<BD0<BlV02dZ8`0/;2D0:2/U00809b/U00/08RLQ01dS7@0O9Qh07RHL020Y7@0Q:Q`08b/L
028Z6@0O:1@082TC020Y4P0201lX3`0601hU2`0P9P`07b@;020T3@0O8@h07A`=3oooool000gooooo
[@3ooolJooooo`0600lB2P0>40T03Q4900`>1P072@<01@L30P0620802`0<3PD03Q4600`?0P0;3`80
2@/100/<0@0<3P<0414600l>1@0;2P@020H200801`@200/02PL800`92`0;20`040lD01PK7P0R:BH0
9RlX02Pc:@0W=BD0:3DR02`h800202di7`0<02dh7P0`>1h0;cHL030g800`=2<0=CPX03Lj;@0c=bd0
=3T_03Ll<`0d>c40<S`^0P0`>bX02`0a?BP0<C`T03I09@0h@2H0>D0W03Xo9`0j?BP0>S/X03do;@0j
?2l0>ch`0080>Cd`00/0>3db03Hl<00e>bh0=ch_03Q0;P0g@2`0=ShX03Pm9P0i?2@0>cdU03dm:002
03hm:`0;03`i;P0k>C00>cde03Li=@0e>C<0>3le03I0<P0g@Rh0>D@[03]5:P0j@RL00P0h?bD0300h
?RL0>C`Y03e0;00m?bh0?d4b03i2<`0j@C@0=Sha03Dn;`0d?B/0<chY030k8`80;SPP00/0;cPL02de
600[<QL0:S8F02/b5P0/=1H0;cLG030f700`=Qh0<cXT03<j9P02038i:@0;03<k;@0d?R`0<c`X038k
9@0`>R00;SLL034h6P0c>Q/0=3PK03Hj7P0g>R400P0h>B@0300h>BL0=cL[038b:00^<BL0:c4X02P_
9`0Z<R/0:c<X02`d9P0^=RH0;SDS02`a7`80;S@R00/0<3@S02lc800a<al0<34N038a800a;b00<2dQ
03<b9`0^;RH0;S0X02/^:@0202H[9P0;028X8@0P9Qh07bLM01hU6`0P:1/082TI01lX5`0Q:QL082TG
024W500P9a800P0N9@l01P0J80/07b@<020T3`0P8Pl07b4>01dO3Poooooo000=ooooojd0oooo6_oo
ool01P0@5@h03A0=00/=2P0:30P02`d:00L:1P801PP300/01`T200X=10082@801`T200T:0@092`40
2`d200X:0P0:2@802@P200H50@0200D20@0;00l>200G5Q8061LF01LF6P0I6Ah071hU028V:P0U;Rd0
9c8]02Hc:P0Z=BP00P0/=BD0300^>2<0<3PQ030g800a>240<cPS03Di9P0j>b`0>S/^03Li;P0h>S00
=CT`03Dk;`80=Ch`00/0<Sd[03<n:P0e@BX0=T4W03Y3:00i@RL0>D4V03To9@0l@2P0>clZ03a0;@02
03a1<@0;03Xn<P0i?c<0>Chc03Ln<P0e?C40=T4b03I1;`0d?RP0=C`S03Pn900j?R@00P0j?2D02`0l
?BP0?C`[03`l;`0i?380=STa03Dj<@0f?C40>4<`03U4;`0kAbh0?dT/0080?TPZ00`0?DH[03e3:`0n
@R`0@4@_03m2;P10@S40?d<c03]0<`0l@c<0>44`03E0;P0c?BX202lh900;02he800]<Q`0:BlI02/b
6`0/<a/0:c4I02dd6P0]<aX0;cDO034f8P0e>RD00P0g?2P02`0f>bT0>3d[03@j9`0d>RH0<STU03<l
9@0c?280<CTN034i7@0c>Qh0=C/O0080=c/Q00T0>C`U03Xl:00e=RH0<C<U02lc:00]<2P0;2lW02da
9`0^=2L00P0_=BD03P0^=2<0<3HU030f9@0_=B<0<3HS02hc800_<Ql0<38O038c8@0`;R00<2dR034_
8`0^;B<0;BhS0P0/;b@02`0Y;2409BPN02<Y7@0P9A/082DJ020W6P0N9AT07bHH024Y6@0R9aT08RLH
00808RHF00H07b@C01hS4@0O8a407b8A01hQ4P0M7a8?ooooo`003Ooooon]0?oooa[ooooo00H041D>
00d@3@0;3@X02P`800/=2P072PH200H80`0;00L90P0:3@@020T200L90P092P402@/100/=0P0:2P80
2PT200T80P061@400P050P402`0?3PP05aHB01PG5P0G5QX06ATN01`N9@0R9RX09Bh]02Lb;@0V<bX0
:SDX0080;3DU00`0;SPS030h8@0`=b00<CPQ03<h8`0e>BH0>S//03Xk;P0g>Bh0>3X`03Di<00e>bl2
03Dn<00;038m:`0c?RX0=D4Z03I19`0j@bP0>D8W03U19P0i?bD0?40X03/o:P0l@2d00P0l@C402`0j
?S80>Clc03Tn<`0g?S80=Cda03I1<P0f@Bl0=3hX03Dl8`0h?R@0>ShT0080>S`U00/0?3dX03dl:`0l
?2l0>C`b03Hi<@0e>S40=Sda03Q3<00iA2l0>dL^03m9;00203i8:P0<03e6:`0m@b/0?T8/0414;`0o
@Rh0@48a03m3<`0k@3<0?4<c03Q1<00e@2h0<cdZ0P0_>2@02`0^=B00;C8L02T_6@0[<Q/0;3<K02/a
6@0]=1X0;C<J02le7`0a=R80=CXU0080=c`X00/0=S/Y03Pm:`0d>RL0=3XV038i9@0c?2D0<c`R034i
7P0a>Ad0<cXN03Dk7`0203Lk8@0903Tl9@0j?2P0=CHV034c9@0_<bP0;C0X02`_9`0]<BL0;S@W0080
;cDU00h0;S@S030f9@0`=RD0;cDS030f8`0^<b00;c8O030b7`0b<b40<2hP030]8P0a;b<0;RdS02d^
8`80;2lT00/0:B`Q02DX7P0S:Ad082DK020U6P0P9aX07RDI01lV600Q:AT08RLI028W6002028V5P06
01lT4`0N8a407b<A01lR4@0N8A807AlB3oooool000gooooo[@3ooolJooooo`0600`A2`0<3``02@`8
00X=200;3PP020X60P062@@02`072PD01`L300P910092`@020X300P:0P092`801`T100H80@051`40
1@D1008010<100/01@D1014C300O8QX0;S8[03<g<P0`<c<0;30`02/a<@0/=380;SPc02Xc;P0202Tb
:00<02La8`0X<B00:30O02/a7P0[<Ad0;c@P034g8`0e>2P0=3L[03Dh;@0f>Rh0<cP]0P0f?C002`0_
>2X0<CXZ034k9P0e?bP0=3`V03Dn9@0e?B@0=3`R03Ln9@0g?RH0>D0[0080>T8]00/0>3h[03Hl:`0h
?bl0=cd`03U1<P0f@380=T4a03E0;P0g@2/0=clW03Lo9P0203Dl8`0;03Pm900g?2<0>ShW03/o:P0k
?R`0>Sd/03Lm:`0g?b`0?4H`03e8;P0mAb`00P0lABX0300mAR`0>d<[03e3;@0i?RT0>d0[03e1;00m
@Rh0?D<a03a3<`0k@S80>T8a03Hn;080;cHT00/0;C@Q02/a7`0Z<Ah0:S4N02/a7@0/<Ad0;C@N02/`
7@0Z;a/0;C8L02hc7P02034d8@0;038g8P0a=b80<cTT03@j9@0e?2H0=ChX03M2:@0f@2L0<chR03<l
800b>Ql00P0_=A`02`0d>1h0>ChT03Xl9P0g>2D0=3HW034c:00^;bD0;S0U02hb9P0`=BT0;cDX00<0
:c<V00/0:S<T02/c8@0/<Al0;C8O02ld7P0b<ah0<2lM02h[700_;Ah0;bhM030_700202/X600702h]
700[;1h09bTN02DW7`0R9Ad08RHM020U7`0201lT7@0:01hU6`0O9AP0728F01`R5P0M8QD07b@F028V
5P0P91@07b4D01`N4`oooooo000=ooooojd0oooo6_ooool01P0830@02@`500X=1P0:2P@020T300T9
108030d600P03a4;010A2`0>3PT0414:00d?1P0;3P<02@`200L:0@801@L110031@402P020`404QH>
03U5<P0i@S<0=3Xa03@k<`0c>S<0<cTb03M1=P0c?C<202L_:00<024X7`0O9a/07bDF020U500S:1D0
92XF02DZ5P0Z;aX0;S@R034f9`0d>BX0=cd/0P0j@S002`0j@Rl0=Sl[03M0:P0i@2T0=SdW03U0:P0h
?RP0>D0Z03Po:@0h?bX0>3lY0080>D4Z00/0>D4[03Po:P0h@2/0>3lZ03To;00k@S00>Sla03U0<00i
@C00>T4^03Y1;00203Dm9@0;03Ln9@0g?b@0=d0T03U1900h?bD0>D0X03Po:@0g?bL0>d<Y03Y39`0l
@bX00P0m@bd0300l@Rl0?4<b03To;`0g?R`0=ch[03To:`0j@B/0>d8/03]1;00l@bd0?DD_03Ln:@80
<cTU00/0;SDQ02`c800/<R00:c4M02dd7`0]<al0;38M02T_6`0Z;Q`0:c0M02/a7@0202db7@0;02dc
7@0]=1d0<STP03Hl8P0g?RD0=cdW03Q0:`0h@B/0=d0Z03Dn9P0b>B800P0_=Ah0300b>B00=3/R034h
7`0c>240<cTS02ld8P0^<b80;c8Q02``800Y;Ah0;C0P02hd9@80;C@V00/0;38U02dc9@0]<R@0;34Q
02hd800`=B40;S0N02h_7P0[:Q/0:RTI02`]6@0202TY5@0;02LX500U9aH09bTJ02HW6`0Q8aX08bDM
024S7P0R9Ql08BLO020W7P0M8aX00P0L8QX01P0O9A/0728H01dS6@0Q91/08B8K01dN5`oooooo000=
ooooojd0oooo6_ooool01P062`<01PX100/>0`0>3P@02`X300`<1@804A<:00/051P?01LJ4@0D5a40
5QXC01@H3P0B5PT030l500P;0`051`801`P200L80`0200@60@0;00<40@0520<010L201HL400M8aD0
;S@T04MB>`0b>BP0<CLX03Q2<00c?Bh00P0I7QL0300F6Q@04AD>018F300C6@/06Qh=01hQ3`0O8100
92LE02``7P0b>2H0=S`[03Q0;P80>d<_00/0>D4/03Y3;00k@bX0?DHZ03i5:@11AR`0@DH^0414;P0o
@bh0?48]03]1;@0203a3;@0;03a3;P0m@c00?dH`03U1;00k@bd0>d8^03i2<@0m@S40?D8b03m4<@0n
A2d00P0k@2X02`0j@2P0>d8X03i7:P0lABT0?4HY03Y3:00kA2T0?4DY03]5:00lABP0@4P[0080@TP`
00`0A4Tc0497=P0nA3<0>d4b03Tn;P0g?B/0>D0/03Y3;00i@2T0?4@/03]3;@0k@bh203U0;00;03Dl
:00^=B80;S<R02hd8@0]<al0;cDP034h8P0_=B00;C8P02db8@0^<al00P0]<ad02`0]<al0;38M02hf
7`0_=R00<CPQ03<k8`0e?BD0=C`W03Q1:`0h@b/0>44Y0080=3/T00`0=3`T034h8`0b>2D0<3LT03<k
9P0c>RH0<SXV02he8`0_=R80;cLQ02hd7`0_=B<203<i:00;03<j:@0`=RH0;cDT02/_8P0_=B@0;S@R
02le8P0_=B40;C8P02`_7P0/<Ad00P0Y;QX02`0X;AL09b/H02P/6`0V:a/09RXK02@W6`0U:Al09BXO
02<Y7P0P9Q/07bLK00807RDJ00H07R@H01hU600O9QT07b@J024T6P0N81P?ooooo`003Ooooon]0?oo
oa[ooooo00H01`X600X>1`0930@020X300T;0`082P<200/?2@0;00hA300D6A005adC01PM5@0I81D0
5Q`A00hC2@0:3P@01PX200L:0P041P800P0520<02`021@800`H200L;0`0;40D0310300lC1@0W;1T0
:2dL02X^7P0nAc80?DLd00809bhR00`0728K014D4@0?40`0410:018B2P0E5Pd06AT?02@W6@0/<1l0
=3/W03Hm:@0k@c0203]4;`0;03Y4;@0i@R/0?4@]03a5:`0oAR`0@DH^04=8<@11Ac40?T<]03i4;`0m
@Rh00P0n@bl02`11Ac80@DLc0417<P0nAS00?DDb03e5<`0nAC40@DHa0414<P10AC40?D8]0080?D<^
00/0>d4]03i6;P0mARh0?TP_03a6;`0nAbh0?DL[03e6:P0oBB`0?dL[04=<<@0204A9<`0<04=8=@14
BSP0@dXh04=:>00nA380>T0]03U0:`0g?bT0=clX03Y2:P0k@Rd0?D@b0P0oAcD02`0j@S40<c//034i
:`0_=bT0;SLU030i9@0a>BD0<CTR02lg7`0^=1d0;S@L0080;SDL00/0;C<K02da6`0]<A`0;C8O02/`
7`0/=240;CLS038k9P0a?2H0<T0X03I2:P0403@n9P0:03<m9`0b>B<0<3LQ030g8`0c>bD0<CTU02lg
8`0`=R<0;C<Q02hc8P80<3HT00/0<3LU02/b8@0]<R<0;cDU02da8P0/<1l0:c0N02`b7`0^=B80;C@O
02`b700202X_6@0;02X_600X;AP0:2dI02L/700W;1h08bLN02@Y7`0S:1h08bXN024Y700Q:1T00P0O
9QL01P0O9aH07bLG024Y6P0S:QT092TK024T5`oooooo000=ooooojd0oooo6_ooool01P0930/020/9
00`?2@082`D01@L200@50P801@L200/02@`800/>2`0@4`l051PB01DJ4`0D6A403a<;00/>10082`40
1PP200D60P0200@50P0;00@60`041P@02@`700P<1@0830<020X200P;0`0=40L04A<:02@[6`0`>RP0
0P0V;al0300R:A`07b<G01dO5@0I6Q<05ADA01DF4P0F5Q4082<J02L[8@0_=BP0<cTZ03U1<080>T<a
00/0>D8_03Q1;@0i@2/0>T8/03a3;@0nARl0?TD_0419<P0nARl0?D<_0416<P020458=00;0459=013
BcH0@4Pc049:=013C3D0@DXe045:<`10Ac00@DH`04=8<@0o@c000P0oAC<02`0nA3@0?TDc03e5<@10
BC80@D/c041:<@0nB2`0?d//041;;00nB2`0?TL^0080@DPa00`0@TXf04=8>@17C3d0A4Tj04A;>@11
B3D0@TTh03]3<`0h@300>40^03Q0;@0l@bl203m7<P0:03m7<@0k@bl0=ch]03Ln;`0g?Rd0=Sh/038k
:@0b>bH0<3XS030h80<0<3LN00/0;C@K02hd700_=Ad0<3DP02ha7`0^<al0;C@O02lg900c?RP0<CdW
03<o:P0203E2:`0<03=0:@0c?bL0<S`T02hh8@0]=b40;SLQ034j8`0b>bD0<CTU038h9@0^<b40;c<Q
0P0a<b402`0`<R00<C@R030d8`0_<b<0<3DU02da900/<RD0:S8T02Xa8`0[<b40;C@Q0080;C<O00/0
:c8K02T_6@0[<1X0:BhI02P/700V:Q`09b`P02@Y7P0S:Ad08b/M02H/7`0202<X6`06024V600O9AL0
7bHG01lV5`0P9aT07R<H3oooool000gooooo[@3ooolJooooo`0601@I6`0?4aD030h?00P:200520@0
1@L20P031@402@082`@041@9014F2P0?50P04A@:014D2`0>4@P02`h600/>100200L90`801@H200/0
1PH300P91P0;2`D020X300@50P061P801`P300L8100:2`D02`l7018G300201<H3@0<01@H3`0G6Pl0
5a/>01XN4@0R9QT08bHJ01lS5`0O91X08bTO02X`9P0_=bX0=3d]0P0h@Bl02`0h@Rd0=d0[03Y3;@0i
@R`0>3l/03U0;P0mAS40?TXb03m;<`10BC80A4dd0080@DXb00/0@DTa049;=014C3D0Adhf04A<=@10
BC@0@DTd0419<@12BS80@dXb0415;`020416<00;03m6<P0oAc80@DTb045:<P12Bc<0@ddf045<<`10
Bc00@4``04==<`12C3@00P11Bc@03011BcD0@d/f04I;=P16BcH0AT/e04A:<`11AS@0@dTh03i4=00m
A380>T8^03Y0:`80?d@/00/0?T<[0415;P10AS40@TLe03e3<@0i?Rd0=C/[034i:@0e?R/0=CdX038j
8P02034h8@0;030g800b>B40<3LQ034e8`0`=2<0<3HS02db8@0_=RD0;SDT02hg900^>2D00P0_>RD0
300_>b@0<3/S03@o9P0c?B@0<c`T034i8`0_=b<0;SLT03<k9`0a=b@0;S<Q02/_7P80<3@R00/0;S8P
030b8P0_<B40;C0P02da8P0_<b<0;C8S02da9P0[;R<0;C8T02/b8P0202`b800;02/a7P0Z<1/0:BlK
02X`7@0Z;Qh09b/N02HZ7@0U:Ad092PM02<V6`0T:1`00P0S9aX01P0P91L07bHG01lU5`0N9AH07R@G
01/R50oooooo000=ooooojd0oooo6_ooool01P0G7B@05QdS01DK8@0A51/030lC00/?40802@/<00/0
3Q8>014E3`0>4@P02`h400d@1@0@50T04A@;010B2@0?40L030d500/:0`0200`;1P0;00X91@0:2@L0
2@P700H5100410800`8200@40`072@D030l800hA2@0<3`L00P0:3PP0300=40T03A0700X=0`0>4PL0
5ad@02@]6`0X<Qh0:cHR02`f900_>BT0<3//034l:`80<C/X0P0d?RX02@0c?2L0=CdW03Hn:P0g@B/0
>D<]03U6;P0iARd0?4T`041<<P02049;<`0;04A==015CCL0ATdi04M=>P15C3L0ADdg04E>=`16CcL0
ATlf04M>=@16CCH00P15C3L02`11BC@0?dPb03m8<@12CC80@Tdd04A@=P12CS@0?d/d03m<=00oBc80
@4/a0080@Thc00`0@4da045<;`11BS00A4Xb0497<015BS80A4Tb04A6<`14B3@0@dPc03m6;`0nAR`2
03m5:P0;03m3:00oA2P0ADT_04E:<P13B3<0@DDc03i4<P0j@Rl0>T4/03M09`0e?2D00P0d?2@02`0b
>B80<CHQ03<h900a=R40;cDP02he7`0]<b40;C8R02hc9P0`=bL0;SPU0080;cPU00`0<3XV02hj8P0b
?R<0=T4T03M08`0g@2D0=3`S034h8P0a=b@0<SPV034g9@0_=28202db800;02da7`0^<b00;S8Q02ha
800];Qh0;S4Q02hc8`0^<BD0;C0T030f9`0[<R<00P0X;b00100[<Ql0:RlM02/^7P0[;al202L[7005
02HZ6`0V:A`092LL020U6P0P91T00P0P9Q`01P0N9A/07R@J01hU6@0J81@072<E01/P4`oooooo000=
ooooojd0oooo6_ooool01P0T;3408bX_024W:`0N92T06b4U01DJ7P804A@G00/04aHG014C4P0;2`/0
2`d900hA2@0?50X041@9014C2P0>40L02`h500d=1@0200d<1P0;00d=200@3`d03`l@00X;30051@H0
10@400D71@0>4@h04QH@014D3@0>4P/00P0=4@T0300<3`P030l:00P;1P082`@02Pd500lD2@0J8A<0
;CHS03Do:P0kABh0>TD`03Lo;P80=Sh[00/0=CdZ03<k:P0c>RT0;cLV02lg:P0^=RP0<CXZ03<n:`0f
@Rd0>TH_03a8<@0203m9<@0904=<=P15C3T0A4`i04E=?017Cc`0B58l04MA>P18E3/0AU0g0080ADlg
0P16CcP02`13C3H0@dde045:<@12CC40@T`c04E?=P11C3D0?dXe041<<`0nBRh0?Td^0080?dd`00H0
@4h`041<;`10BRl0@T/a04=8<@15BS@204A7=@040497=@12Ac@0@4L`0457;`80@4L[00/0?D<V0497
:P13B2/0@TH]04=8<@13Ac<0@4@c04=7=@12BC<0?4D_03Y2:P0203Po9`0;03Hl9P0d>BH0<3HS02hc
8@0a=R<0<CDR02hb7P0_<b00;S<Q034h9P0`>2L00P0`>RH0300a?2T0;cXW030k9@0a?B<0=40T03M0
9@0e?B@0<CPT02hd8P0^=2<0<CLW02le9080;c@R00/0;SDP02dc7`0]<Ql0;S<R02`^800];b80;2hR
02ha9@0^<R80;C<Q02`b8P0202X_7`0;02/`7P0/<Qd0:blM02/^7@0Y;Ah09b`O02@W6P0R9AT08RLL
020V700Q:1h00P0O9A`01P0O9Q/072<G01/R5@0K8a@07B<C01/O40oooooo000=ooooojd0oooo6_oo
ool01P0S:2l09Rd`02@[:`0S:RT092XY02<Y9`8082HU00/082DU01DH6@0@4Q<03Q0@00lB3P0A5Ph0
4AH<014E2P0>4PH02`h400X<100300hA200:014C3@0?4@h03a4@00d?3P061`P01`P8010D400E6A@0
4QHA00`>2P8020X500`01`X400P:10092`@02@`400T;0`082P<03a@901XN400S9aL0:2`L034g9P0j
@C4203a4<`0;03Y3<P0h@C80=Cha030h;@0/<bX09blV02@[8P0S:al0;CLW03@o:`0iABh00P0nBC00
2`13CC@0ADdg04A<>013C3X0@d/i045:=`14CCP0AU0i04MA>@16D3T0BUDl0080BE@j00<0Ae0g04E=
=015CC@00P14Bc801P16D3H0A4df04E?>@15CcP0@Thd041=<080@dh`00`0A4l`04E?<@12BRl0ADXb
04=7<`14B3P0ADPi04=7>013B3L0@DPe0459<P13CS<204E?<P0;04A<;`15C2h0AD/]04I:;@10A2`0
?d<_03i3=011B3H0?TH`03e6;P0nAbd00P0mAR`02`0i?bP0=C/U02le800`=B<0;S8Q02hc800`<b00
<3<Q02lc8P0`=bL0<SXY0080;SLV00T0;cXX030k:@0`>bL0;STT02lj8`0e?bD0=SlU03Dm9@0c>BD0
0P0a=bH03P0a=bD0<cTW03<i9`0b>2H0<3HT02`a800Z;b40:RhS02P/8@0Z;b80;C8S02dc8`0/<b00
;30O0P0[<1d02`0/<a`0;3@K02dd6`0X:aP0:BXK02PY7P0T9Q/09BPL028V700O91/08bTN00808BLL
00H082HL01hU6@0O91@07R<B01hQ4@0K7`d?ooooo`003Ooooon]0?oooa[ooooo00H0:Blb02/`=@0W
;2h092X[02DZ:@0X;R/202L^;@0;02@Z;@0S:2X07R8U01PL7@0D6AL05QXC018G300=4PD0310200/?
0`0<40D00P0?50L02`0@5@P03a8900h@2`0=3P`03a0>00d>300@4@`05APB01HJ4@0B5Pd041@;0080
30l400`01PT100L:0@082P802@X400T<10092`D02P`9010D3`0D5a<06A`G01TK5`0_=RX203m9>00;
04=>>P12CCT0@4Xi03Dn<00]=BP092/P01`Q6@0G6QH06QlH02D]8@0^=RP00P0f@Bh02`0nBS<0A4hf
04=<=010BC@0@DTf0419=@12BSH0A4Xh04I=>`18D3d0B58m0080Ae8i00/0AU4g04A?=@16DCL0AU0d
04Q@<`16CS@0B50f04M?>015CCH0A4hg04A>=P0204=>=080@T`b00T0@d/d04M==@16C3L0AT/i04I:
>@17BcX0B4dm04Q>>`17CcX00`15CSL02`16CcH0ATlc04A=<015C340@DH]03i2;@0m@c00>d8a03e4
=00mA340?dPb0080?4@_00/0>T4]03a4;`0h@2`0=CXY030d900_=280<SPT034g8P0`=R<0<3HT03@k
:00202lh9P0<030j9`0b?BL0<ShW034m9@0^>240<3XR038l900e?2H0=S`X03Dk:@0_=B@0;S<S0P0^
=2<2038h9P0903<i9P0_=2<0;S@S02db8P0[<240;3<U02hd900^=B80;34O0080:RlM00/0;S@Q02`b
7P0[;a`0;2lL02d_7`0Z;1l09bXP02DX7`0S9Qd08BDK028W7@02024T6P06020T5`0N8aD082@E020T
500Q91<07R4A3oooool000gooooo[@3ooolJooooo`0602X^;00[;c00:R`_02P[:`0V:BP09R/X0P0W
;2/02`0X;S009b`a02H]<00U;2d08RTW01hT7`0E6Q803a<;00d@200A4`X03Pl900803Pd:00/040l=
010@30071@D01@H600H71`0720H03a4:01DH3@0I7a005ad>014G2P0200dA100<00X=0@0;3@<020X3
00d?1`0=40X030h900X;2@0:2P/03`h@018B4`0D51@06ATF0P0T:2002`0c>B`0?4@d04I??00d>bd0
:BlS024W6P0K7a@06A/C01LI4P0H7AD08bTO0080;CHX00/0=3l/03]6<00lB300?TT`045:<P10BC<0
@4Pd0459=`12B3L0@d/i04==>@02045==`09049?=`12D3H0A4le04A@<P14CRl0ATl`04M@<@16CS80
ADhd0080@DXc0P11Bc<03011C3<0@4/b049<=014CCL0AT`h04I;=`15BCL0Ad/k04I:>`18Bcd0AT`j
0459=080@d`e00<0@T`b04A><P12Bbl00P12BBd01P0n@R`0>cl[03Xn;P0i?S00>d8b03a3<P80>T8c
00/0>T8a03U1;`0h@B/0=clY03<i8`0b>B80=3XR02lf800^=B40;CDS02lh9P02030h9@03030k9P0`
?280;c/Q0080<3`P00L0;STO030j8@0a?280=3dT034g900a=bD0<3HS0080;cHQ00/0;cHO038i8`0f
?2H0<cXS034g900_=B80;38P02T`7P0X;Q`0:c4M02X`6`0202/a700;02X]7@0/;b40;BlQ02`_800[
;R40:BXP02HW7`0T9Qh08RDL024S6P0P8QL00P0O8QH01P0P8aH07B0C01lS500R9AH082<F01`Q50oo
oooo000=ooooojd0oooo6_ooool01P0T;2L0:S4Y02hb:`0_<R/0;c0/02`^:`80;c4_00/0;2h`02X[
<P0^<3L0;c8g030d=P0W;2/06AdL01LH5P0D4Q804a4A018?4P0200l<4P0;00d;4@0:2@l01PH;00D5
20061`L010D300X<100G7@d0728@01LL300A50P00P0=3`D0300:30<02`d600/=1`0?4P/04QD;00l@
2P0@3``03@`:00l=3@0G5A<06QPE01HE4`8061PE00/06a/G028S700[;R@0:2`S01lS6`0H71<03a09
01TM500O9AX08bXM02D]7`0202H_800;02Xd8@0]>B@0<ShX03I3:`0mB300@T`d04A>=`12BcP0@T`h
04A?>P14D3T00P14DCP00`16E3P0BEHi04QD>00204QC=P0604QC=016DC@0A4hc04=><@15D3H0A50g
0P14D3H01P12CSD0@Thd045;<`13CCD0ATli04M?>@80BDhj00@0BThl04a@?P1<DSh0BU0l0P16CSP0
2P17CcL0A4db04=<<@15CS<0ADhe0499<P12Ac<0@4@b03e3<P0oAS@30419=@0;03i7<P0lAS00>D@^
03e:;`0g@RP0>48W03Do900b>R00<SXR030h8`0_>2D00P0c>bL0300a>bH0<ShV038m8`0b?280<SdT
03<l900f?bH0=d0V03Q0:@0f?BT0=C/X030f9080<CLS00P0<CPQ03@j8P0i?RH0>3lV03Ln:00c>R@0
;SHP02/c7`80:c<N00h0;38N02hc7`0^<al0:c0N02``7`0/<B00;C8R02hc8`0X;Ah09BTK02P/7P0X
:b409BPM02@X708092TL00H08RLJ028W600R:1L082LG020V600Q9QP?ooooo`003Ooooon]0?oooa[o
oooo00H0620O01hU7@0T:Ql0:B/S02/]9P0];bT202lb;P0;02la<00`<S@0;c8g034h>`0g@3l0<3Pf
028W9`0O8R<07QhR01LE7@0A4AX00P0>3aT02`0=3QP01PHA00D43`0410X00P@500<50`0620804QL9
01XP4@0I7A005QH=00804A4:00`03@d700`=2@0?4Ph05ALD01PJ5@0F61D0418A00d=3P0@4Q<051<D
01PG5`0D4A<201<B4P805A@C00T06AXE01`O5`0F6A404QD<010@200=30D071lA02D[700U:al00P0M
8aX02`0K8aP06R4F01hV600U;Qd0;STT03I2:`0kB300?d/c045>=012CS<0A58d0080AEDf00@0AE8e
04UD>@18DSP0Ae0h0P19DcT00`18DcP0Ae8g04E@=P0204A?=P80Ae4h00`0A4hf04E?=P12Bc@0@T`f
04A==`16CCT0B4hi04U>>P1;CcX0Bdli04eA>`1DF482059F@P0;04eB?@1:D3X0BDli04M=>015C3P0
AD`g04E<=@15CCD0@dTb04=:<P13C3<00P12Bc<02`11BC<0?dPa03e7<00mBC80>dL_03U6;00g@bL0
=D4R038n8P0a>Ql0<SXQ0080<chU00`0=3hU03Lo9`0f?RT0=ClY03<m:00d>bH0=S`X03Dk9`0h?bX0
=clZ03M0:`0e?R/203@m9`0;03<l8P0^=Qd0<3DN03<i800c>R40=3`R034j800]=Qd0;3<K02Xb6P0X
;AT00P0Y;QX02`0Y;A`0:blO02hb8@0/<R80:RlQ02`a8@0X;1d08bPK02HZ7@0U:1/09BTL008092LL
00H08RTM024Y7@0R:a`092`M024X6P0S:1T?ooooo`003Ooooon]0?oooa[ooooo00H0620O01hU7@0T
:Ql0:B/S02/]9P0];bT202lb;P0;02la<00`<S@0;c8g034h>`0g@3l0<3Pf028W9`0O8R<07QhR01LE
7@0A4AX00P0>3aT02`0=3QP01PHA00D43`0410X00P@500<50`0620804QL901XP4@0I7A005QH=0080
4A4:00`03@d700`=2@0?4Ph05ALD01PJ5@0F61D0418A00d=3P0@4Q<051<D01PG5`0D4A<201<B4P80
5A@C00T06AXE01`O5`0F6A404QD<010@200=30D071lA02D[700U:al00P0M8aX02`0K8aP06R4F01hV
600U;Qd0;STT03I2:`0kB300?d/c045>=012CS<0A58d0080AEDf00@0AE8e04UD>@18DSP0Ae0h0P19
DcT00`18DcP0Ae8g04E@=P0204A?=P80Ae4h00`0A4hf04E?=P12Bc@0@T`f04A==`16CCT0B4hi04U>
>P1;CcX0Bdli04eA>`1DF482059F@P0;04eB?@1:D3X0BDli04M=>015C3P0AD`g04E<=@15CCD0@dTb
04=:<P13C3<00P12Bc<02`11BC<0?dPa03e7<00mBC80>dL_03U6;00g@bL0=D4R038n8P0a>Ql0<SXQ
0080<chU00`0=3hU03Lo9`0f?RT0=ClY03<m:00d>bH0=S`X03Dk9`0h?bX0=clZ03M0:`0e?R/203@m
9`0;03<l8P0^=Qd0<3DN03<i800c>R40=3`R034j800]=Qd0;3<K02Xb6P0X;AT00P0Y;QX02`0Y;A`0
:blO02hb8@0/<R80:RlQ02`a8@0X;1d08bPK02HZ7@0U:1/09BTL008092LL00H08RTM024Y7@0R:a`0
92`M024X6P0S:1T?ooooo`003Ooooon]0?oooa[ooooo00H06b0R01/P7@0H7AL06ahG01lR7@0V:282
02hb:`0;030c;`0b=c@0<CLf02he=`0_=cT0<CTi02hf=@0X;Rh09b`_028V;P0Q92h00P0P8Rh02`0K
7RT05ALQ00h?6@092Q<01PL=00D72@051PD04AH>01PM4@0G71005AH>00804a<=00`051<?01<C4@0E
51<06A/H01hR7P0P9R<07bDQ01PL6`0G6a`06AdL01@G6P0A4AD200l?4@0;00l@400>40h03a4<01@G
3`0A50/03a<800d@1@0;30<09B`I02lg8P0]=R<00P0K8QH02`0H7a@04aL>01<H3P0D6@h06AhB01hU
5P0V;Q`0;SLR03@o9P0kAR/0@Dh`0080A4lc00/0Ae<e04QB>019DST0BE@j04YE>P17DcD0AU@e04MD
>@18ECT0AU8h04IB>@0204E?=`0<04I@>017D3P0B4li04U@>019CcT0BDhk04U?>`17C3T0BDhk04]?
>`1=DCd0D5<m0P1AE3`02`1?DS/0C54l04aA?019CcX0ADhj04I@>@12C3@0@ddc0418;P11Ac00@dTa
0080@dPc00/0A4Tf04=9=P10B3@0?dPd03a5<@0h@Rd0=d8X03E08P0c?Al0<c`P034j8002038k8P0<
03A09@0h@bL0<chU03@o9`0b?2D0=ShY03Hl:P0h?B`0>3h^03Q0;P0e?2X0=clZ0P0g@2X02`0f?RL0
<CPS02de7P0/=A`0;CHL02de700a>Al0;SHL02/b6@0Z;aL0;34K0080;C<O00/0:RhN02/`8@0Z<280
:BlP02/`800Z<B00:C4P02H^700S:aT08BPF020W5P0202@Y6@0602@Z6P0P:1T07bDH028X700P9AT0
82DG3oooool000gooooo[@3ooolJooooo`06020T900L7b006AdK01LK5P0G71D07B0H0P0Q8aT02`0T
9al0:RdW02da;`0_=C<0<3Pg03Ho>`0^=c@0:c<a02`d<`0^=3H0<3Dg0080<3@i00/0<3<k02`^=`0U
:3807R4Z014C7@0;3QD020T>00d@3`0D5a405Q/B01@H4@0201@D3@0<01<C3P0D50h061TB01hQ6P0M
81`08RLT02<Z9`0U;2P092/W02L]:00J7Qd04aDG0P0>3a802`0>3Q003Pl?010A400B51404AD@00lB
3@0>4@/030l701TO4@0M9A@082PE00807RHE00D072<C01LL400D5P`051D=01DG3P0201@G3@0401TN
4@0R:AH0:c@M03I09@80@4X]00/0@dda04IA=017DCH0BE8f04UD=019ECP0B5@h04UE>P1;Ec`0BE@k
04UD?00204QD>`0<04IB>@15CSL0AThf04aB>P1;DS/0BU8m04U>>`19CSX0BDli04Y@>`1:CcX0Ce@l
0P1=DCT02`1>DSX0Ce@m04eE?01<Dc/0Ae4h04IA>014CcD0Ae8f04QC>015CcH0A4`d0080A4`e00P0
A4/g04A9=P11AcD0@DTe03a4<@0k@bh0?4D[03Q29P80=3dP00d0=ClQ03@m8P0d?B80=ChS03M0900f
?b@0=ChU03Hn9P0e?2L0=3/W03Ln:`0g?BX0=cl[0080=SdY0P0g?RT02`0e?2P0<S/V034l900_>R40
;STP02/f7P0]=Qh0<3PP02dc7`0[<Ad0:RhN0080;C8R00P0;34R02T`8@0Y<B40:S4Q02P_7`0Y<Ah0
:34L02</5`809BhH00T08b`G02@/600T;1P092`H020Y5`0P:1P092/J02<Y6P0O9AL03oooool000go
oooo[@3ooolJooooo`0601dS8@0O8R4071dN01PJ6@0I71L06a`F0P0K6aD02`0L7AP071`I01lO7@0S
9B809bdZ02lg<P0a>S<0<3Ta02lh<`0]=380;S<d0080<SDi00/0<SDl03@g@00b=d00;S@l02L]=@0M
8bX061dQ01@I6`0F6aL06AhG01HK4`0201@H400<01@H3`0G6A006QdD01LI4P0D5a8061/F01hS7P0X
;RL0;38Z02lf;@0/=2`0720M0P0H6QP02`0E4aD04@lA00l=4@0@41<04A8C01<F5@0@518041L@018I
3`0G7`l0620=00<061l<00@05Q/;01@H2@0D60T04aH90P0A5@P0100B5PT06Ah>01TK2P0S9a<203@k
8@0;03e5:@14CS00B58c04]D=P1:ECL0B5@i04QC>017DcT0BUHk04YF?01:ESh00P19ECh03018ECd0
AU4j04M@>P17D3/0BE<o04UD?P17DCX0Adlh04Q@>01:CcP0Be4i04a?>080CE4j00/0C54j04]A?@1;
DSh0BU<n04MA>`14CcL0A4lf04E?=P15CcL0A4lf04A>=P0204I@>00;04M@>015BcL0AD/g04A;=P0o
AS<0?D@a03]3;P0kA2/0=SlW03U39P0iA2@00P0h@R<0300g?b@0>44U03Y29`0j@RP0>D0Y03Ln:@0c
>RL0<cTV030f900c>BL0=SdY03Hm:080=CdX00/0<SXU03Dm9`0e?2D0=CdU03@m900e?B@0;cLO030f
7P0_=B40;cDS02hc8P0202hc900;02hc9P0]<bD0;38R02/a7`0W;1X09bdH02Xa6`0W;aT09S0J02H_
6P0U;AT00P0V;QX01P0S:aL08RXG024Y5@0O:1<08RTH024V60oooooo000=ooooojd0oooo6_ooool0
1P0C5QL0:2/W024P8`0M6al06ALL01PG6P8061LH00/06APH01HE5@0D51804aHC01LL5P0P9al09RhS
02/e9`0c?300<CP`034f<00202lb<@0;030c=P0b=3`0=3Q003@j@00b>Sh0;cLk02Pa=00R:b/082LT
01`S7P0F6QL00P0G6aL0300G6aD05a/D01TM5@0E61403a8<00lA3@0B5Q007b@K02L[800]<RH0<3DZ
030e:`80;30Z00/09RXW01hP8P0G6Al05AHM014D6@0A51L05a`J01/R6`0J8AP06R8D01PP3P0201XQ
3P0;01LN300D6PT04aT900lE1P0?5@D04A@5018F1P0D5`L05QT:018D1P0F5PP00P0M7P/02`0^;aT0
>3`V04=:<`18DST0BE@j04]G?@1;Ec/0BUPi04UH>@19EST0BE@k0080BUHl00`0BEDm04MA>`16D3d0
AU0m04UC?`1:E3h0BUDl04I@=@16D380Adlc04M==018CCD204U<=@0804M;=P19Cc`0B4ln04I??016
D3X0AU0g04E@=P14CSD204A==@0>04=<=013C3D0@d`e04M>=`14BC<0ADTf04M=>@14BcP0?TDf03a3
=@0i@S40=Sl]03I1;00f@RP203E0900<03I0900h@B@0>T<W03Hm8`0e?2@0=c`V03<i9P0c>BL0<3DW
02hd9P0a>2L0<SXV0P0b>BD02`0a>B@0<CXS034h8@0b>B40<CPP034h7`0^=A`0;S8L02hc7`0^<R40
;S8S0080;C0U00P0;S<U02dc8P0_=2<0;S<R02X^7P0V;1/0:2dL02H/6@809B`J00T0:2`K02P_700X
;a`0:2lN02@[700P9aL07RDD01hU4`0O8a@03oooool000gooooo00<0e]_H0?ooo`3oool0ZP3ooolJ
ooooo`06071hL@0i@CP0<3@_02X[:`0W:2X08b<V0P0N72002`0L6Qd06APH01LH500C5Q404aLA01<H
400E6Q008RLI02T]7P0_<bT0=CP`0080<cL`00/0<cHc03Dg>`0i?440>3a303Dl@`0b>Cl0<CXm02de
=`0V;Rl082HX01hS9@0201hP8P0<01hO7P0L7Q`05aTI01<E5@0?41403@d=01HI5P0O8a/07R8I01dO
5@0N8AL0:2`S0P0/<BX02`0^<bh0;C<a02T_;`0N8b@06AhO01LL7@0K8A`072<L01dU6`0K8AH06QlA
00806b4@00/06alA01DH2`0C5@/04A<9010B2P0@4PP04Q@901LH300G60h05AD;01HE2@0201LE1@0;
01dK2P0N7@d0=S/U03m7<017D3H0Be<h04iG>`1=F3T0BePj04]G>P1:ECX00`1:ES/02`1<F3h0BUDm
04MB?017DCT0BU<j04UC>@16CcD0Ae4e04I@=@16CcD0Adhf0080AT`d00/0Adde04U>>019D3P0AD`h
04E<=`15CSH0A4df04A<=@14CC@0AD`d04A;=00204I<=P0;04M>=P18CcH0Addf04I;>015BST0@TTj
03m6>P0l@cH0>T8c03Hn;P0b?BX00P0c?bP0300b?R@0=ClT03Do900e?RD0<c`W03Dl9`0c>BH0;cDS
02le900`=R@0;34Q02lf8P80<cTU00H0<c/V034i9@0b>RD0<CTT030h8P0_=b0202`d7P0302hd7`0/
<Al0:blO0080:blP00/0;S8S02`a8@0[<200;34P02/b8P0X;b009BdM02<[6@0R:AL09BXI02T^7002
02H/700602H]7@0U:a/08bTJ02<Z6P0Q:1H07b<@3oooool000gooooo00<0KX9i06QlL@2b_;P0ZP3o
oolJooooo`80oooo00@0XZNU04iJD`17Cd/0?dA20P0f>CT02`0]<2h092LQ01lR600M8AL0720G01hQ
600Q8aP07b0E020N5`0W9B@0;Bd/0080;Rh]00/0;bla03Hi>P0i?D00>Sm503]4B00h@DH0=3i202lh
>`0_>3T0:c4c02`d<P02030h=@0<02T/;00U9b`07ahV01DC7@0@3AL03P`E01LG700L824061/K018D
4P0>40d04aLB0P0H71P02`0R:2<0:2lZ02/c;00R:B<07RHO02@/8`0R:b407bPN01dU6P0H7Q@05ad@
0080724B00/06al@01TJ300D5@X05AD;01<C300@40T04A0:018B2`0C4``05aL?01PH3P02020Q4@0;
02<T4P0T9aD0:BlJ03Dk8P0oABT0AT`a04]B>01?ES/0CePo04iI@@1;ET400P1;Ed80301:ESh0BUDk
04YD>@1=EcX0CUDj04]A>01=DST0BDhg04U>>@19D3X0Adlh04UA>080B50e00T0BE4f04M=<`16Bc40
ADXb04M<<`18CcL0B4li04U?>P18CST00P17BcT204A;>@0;04=;=P15CcD0ADdc04M?=014BS@0ADTf
04=7=`0n@cD0?T@e03Tn;`0e?2`00P0b>bT0300c?bP0<SlT038n8`0a?B80<c`R03Ho900d>b80<STP
034h800e?BD0<cTS034f8@80<CHS00/0<SPT038h9@0c>BP0<CTX030j9`0^>2D0;SLT02hh8`0]=b80
;3HP02`b7P0202da800;02`^7`0^<B40;S4Q02hb9@0]<RH0;38V02L^8P0S:al092`N02@[700W;Ad0
0P0U;1h01P0R:Q`08BTL028Y6`0S:QX08RTF01lV4@oooooo000=ooooo`0607fAR@23UY00Q9R@082B
S02R[j/0_lS6Y`3ooolJooooo`@0oooo00l0g=oO0;:h^01`P7`0L81l05m^K014Cdl0@4Y804QAB`1<
EDX0BU5503Li=00];B`0;B``02d/<P0[:S000P0T8RL02`0S82@0:bX[02h`<P0e>C`0>3e103U1@P0f
?d40;cLk02`d>00^=cP0<SXi0080=Slm00`0=Shm03To@00d=c`0:BTd01lN;00K6RL07QlX01hQ9P0C
5AX0418C00l?3P0>3Pd2014B400501@E4P0G6QL07B8N01lW8P0X<BT00P0Y=2X0100V<BL082PM01`T
5P0K8Q8201/Q4P0;01dQ4P0J70h05aL;01LH3@0F5`d04a<:01<B2`0B4P/051@=00l?300B4Q000P0l
ASD02`14DSd0BEU004=B>011CC<0?dP/03i6:`13BBl0AT`d04YA>`1;Dcl0BeE10080BeM000`0BULn
04]E>`1:DST0CUDk051F?01BFSl0D5Hm051D?01<D3/0BU0l04aB>`1;DST204]B=P0;04YA=@17CS<0
Addc04Q==@1:CSD0Bdlg04Q=>@1<DCd0BU0n04I<>@14BSL00P14CST02`14CSL0A4he04===015CcD0
ADde04I==@16BcD0ATXg04E:=P11AS<0?40a0080>Cl_00@0=T0[03@n9`0d?R@0=ChS100f?RD0100f
?BD0=C`V03@j9P0e?2L2038h9@0402lf8P0_=R<0;SLT02dg9P80;cTV00D0;cTW02hh9P0_>RL0;SPV
02hf9P0202`a8`0;02/_8@0/<B<0;S8U02d`9@0[;bD0:RhU02P^9@0U;2809RdR02@[7P0V;Ah00P0T
:a`01P0S:1/08RLJ024X6@0Q:AP082LG01lV5Poooooo000=ooooo`0608>FS027V9<0RibJ08^KW@29
VId0QYJJ0P26UiP00`2V/k<0hNGV0?ooo`2R0?oooa[ooooo203oool02`3PiND0WZ^^07Z;S`1mT8h0
PIF?07nCR@1/NG<0GfYV06EbK@18Ce<09bLb00807ahW00/06QPN01PF6`0L71l09RLW02da;P0e>SL0
=chm03Ho@00a>Cd0>D=403a7A`0203i8B00<03e6B@0nADX0>d1703TnAP0c>T@0;cDo02`a>P0M8B`0
5ALQ018C6P0A41<04a<B0P0C4a402`0@3`h0410<010B3`0D5a<0:34X02Pa:@0]=b`0:34V02@/8`0P
:1h07RHK00807B<I00/0724G01TN5@0G6a805a/A01DH3@0F5``05AH;01TI4@0E50l061PB01dN6002
03@i;P0;059OB`1GIe00EfU?05EVB@1<Fcl0AE<i04A?=@13C3<0ADle04M@>01:Dc/00P1?Ecl0301<
ECd0CEHm051I?P1?F3h0CEHn04mH@01@Ecd0D5Pl04iF>P1>ECT0CU@j04iD>`80CE<k00/0Be8k04eC
?01;DC`0BTlj04U>=P19CSD0BDhf04Q>=`19CcT0B4hf04M==@0204Q@=`0504M?>016CcP0AE0g04MB
>017D3L00P16CCH01016C3D0AT/d0497<@11B3<203i5<00<03]2;P0j@B`0=C/W03@k9`0c>bL0=T0Z
03Ho:P0d?bX0<SdX03<n:00b>bP0<c`Z0P0b?BP02`0a?2P0<C/W030i9P0a>bH0<3XU02lh9@0_>2L0
=3d]03<l;`0`>Bh0<S/_0080;cDY00/0;C8V02`a9@0]<BD0:c0T02/a900Y<2<0:BhR02/`8`0Z;b<0
:2`R02P/800202DY6`06028U6@0R9QX08BHJ02DY6`0T:A/08B@J3oooool000gooooo00H0PYN?08ZL
U`2<WId0SIfP08jMX`2<W:@208ZIWP0508^KWP2;W9h0S9jN0<G@d03SjNP0X03ooolJooooo`/0oooo
00P0a<o?0:Ri]@2:XYP0Rj:D08ZNT@2<X980KWaf020O;0807ahW00/06aTO01LE6P0D4QD05A@F01lP
7`0T9b@0:Rl[03@m>00f?c/0@dm804EBB`02041;A`03041:BP0lA4P0?4A:0080>D5900L0>T=>03Q2
B`0f?TH09R/f01/N:@0F6B004a<I00804a8F00/03Pd@014?3`0B40l06A`F02Xb:00T;2@09B`T02P_
9@0X;b@08b/Q02<Y800201hS7@0;01hS7`0O91l07bHN01`Q6@0J7QD06QhD01TM4P0M7a@06QTA01dM
5P0Z:R000P0V91`02`19CSh0EF5;04eLAP19Ed<0CUi7055RAP1>Gd00AePh04ID<`17DS@0B54c0080
BU8h00T0Be8j04YA>@1<E3/0CEXn04YF?01=FSh0Ce`o04]G>`1=ES`00P1>EC/03P1>DS`0Ce<n04mC
?P1>Dd00CE5004U??`19D400B54n04QA>@18D3P0Adlg04Q@=`17Cc@0BDle0P18C3D02`18C3P0Ad`j
04A<>@16D3`0@d`j04A=>P13C3P0@TXc0499<@11BS40@TXa0080ADXa00`0@TLa03i5<00k@S00>3h_
03@j:P0c?2/0<CX/030j;00`?2X0;c`V034n9P0b?bH203A09P0;038m9@0b>bH0=3/V038i9@0b>BH0
<3HT030g9@0_=BD0;cLY034j;@0_>R/00P0^>2P02`0]=RD0:S8R02Ta8@0Y<B40:S<Q02`e8P0]<b40
:bhO02la8`0/;b<0:BdO00809RTK00H08RDH028U6P0Q8a`09BPO02<U7P0Q8ad?ooooo`003Oooool0
1P1oU8d0RIjJ08ZNW@2=X:40T::U08jPY@80SJ2P00L0SZ2N08fOW@2>XIl0SZ>O08fTW@2>YY/0b=C<
09h0oooo6_ooool>0?ooo`050<OBb`2AYiL0TZRF08VNS@1AG5P00P0P8BT02`0Q8RH071`M01HE5P0F
51D05A<C01LF500L7AT08RDQ02L/:00b>S<0>D8k0080?D<m00`0?TE103m5A`0nADT0?TE:03i7B`10
Adh0?dI<03i6CP0oB4l0>T98034h?@0S9BX201dM8P0;01XI7`0F51/04@hE028U9@0R9bD07B8O01/P
6`0R:Al09blR02D[7P0R9Q/00P0S:Al02`0R:20092/R028X7P0S:Ql082LM020W6`0P9AT06ahE01XJ
500F5Q<06a/G008071`G00/0GF]B05i_EP14DCl0;cP/034j;@0e@2d0Cf9204mR?`1AHSh0Celk04QE
=P0204MA=`0<04YB>P1:DSd0B58l04IA>P16E3/0BELm04iK@01;Ecd0CELo04aF?P1=E3`0C58m0P19
Cc/02`1:DCh0Be9004YB@@19DD00Ae0o04M@?P16D3`0Ae4j04YC>@18D3D0Adhd0080BDlf00/0B4dg
04M>=`17CcX0ATdl04E=>P16Cc/0A4`h049;=@12BS80@d/b04I><`0204E;<P0<04=8<@14B3<0@TTc
03i5<`0h?bh0<cd/02hh:00a>b/0<3XX034m9P0b?R<0<C/P0P0b>b402`0d>b@0<cXU03<j9@0`=b80
<STS038i900a>2D0;3@R02dg8`0a>BH0<3TV0080<3PY00/0<CPU02`b800]<b40:BhM02T_7P0X<1h0
:30M02Xa7@0]<B00;C4R02X^800202DY7P06024U6P0N8AL08bDJ02@X7P0Q91h082<N3oooool000go
oooo00@0QIbB08ZQV`2=Xil0SJ>Q0P2=XZ0208fRW`0508jRW@2<X9/0SJ6L08jRVP2?Y9/00P2@Yi/0
0`2DZid0[knc0<[Ec@2K0?oooa[ooooo403oool00`3Tj^D0b]K<07b?O`02045:A`0;02hb<00W:BP0
7A`O01XH6`0G5QH05QDD01LH5@0I6QD05aXD01dP6P0S9R000P0`=2`0300l@3T0@4E004=8A015CDX0
ADe=04M?D@14CU80@Ta@045=CP10BT/0@DQ903i3A080>C`o00/0=CLl02PW<@0Q7RX0:b`_024R9P0D
5AX04aDG01PK5`0H7AH0724I01lT6`02020U700;024X700O9aX082HI028Y6P0S:QX092XK028U6@0O
8AL071dH01XJ6@0O81l00P0K7Qd02`0f@3D0?4Li02L]9@0/<RP09BTP01dP5P0U;A`0?D/a05EXA`1I
KD`0EVQ;0080D5m500`0BUHo04UD?`16D3h0@4/j03m<>P12Cc`0Ae@o04YH@P1<F4<0C5M204]F@019
EC/204YE>`0;04eF>`1:ECT0BE8j04]C?018D3d0Adlo04UB?`19E3`0BE@k04I@=@17DCD00P17D3D0
1`18D3H0ATdf04M?=P19D3T0ATdh04I=>`15CCX00P15CSP04012BS@0@d`d04==<`13CC<0@d`a0458
;P12BS40@4Pa03e6<@0k@c00>D0`03@k;@0d>RX0<SXW034j9P0c?2D203<l9003038j900^=R40;3DR
0080;CLR00<0<CXU02hf8`0`>2D00P0^=B<03P0_=R@0;cHU02lf9@0b>2H0<STT030g8P0]=200:c8P
02P`7`0X<B80:S8R02/a8@0Z<R40:30O0P0U;1d01P0R:1`08RPK02@Z6P0S9aT08RHJ020T6`oooooo
000=ooooo`0308:GS`29XIP0RZ>J0080RZ6K00h0Rj:K08VOV029WiP0RYfE08fQV02AYI`0TZJM09>W
W`2CYid0TjJL09FWW@2DYY`0UjVN092RU`80aLk:00<0hNGR0?ooo`3oool0U@3ooolJoooooa<0oooo
0P2ka;l02`24Sh/0?dE602lb=P0V9B`08R0V020O800L6aT06a/F01TH500H61@061PE00805aDB00`0
:2PP02l_:@0i?3D0?dDo0499A@15CT`0AU9A041;C00nB4X0@Da;049:C@14BTd204I<CP0;04A8C@11
A4T0?3i703Lj@P0S92l05aHR014A6`0@4QL03Q0D00lA4`0B5A<00P0J7aT02`0M8aX07bDK01hS600P
9aT08bXJ02H/7@0T9a/09BLO02HX8P0W:BP09RPZ008082DW00/06A`O01TM7P0J7Ad08B<O01lP700L
7QX06A`H01TM600a>b`0@Dlk04mPB00205Q[C`0<05U/D01;F4<0=T0a02lh:`0^>2X0<S`^03I1<P11
CCX0A54l04YG@018ESh0BELo0P1;F3`02`1>G3/0BUHf04aF=P1;E3L0BE4i04UB?018D3X0AU4h04QD
>P17DSL0AU4f0080Ae4f00/0AU4d04MA=@17CcD0Addc04I:<`16Bc@0BDli04M>>018D3P0Ae0g04E=
=@0204E==00404A=<`0oB2l0@4Pa03m7<@80@TXd00H0?DD`03Y1;`0h?Bd0=3XY03<i:P0d>RX203Hm
:`0503Hn:P0d?RX0;CLV02Xc8P0]=2400P0^<b00100_=B40;S@P02hd800`>2<2038i8`0;034h8P0`
>280;cLQ02hg8`0]=2<0:S4Q02P_8P0V;b00:C<Q02H_7P0T;1`00P0W;ah01P0R:AX07B<F01lV5P0R
9QD08bLF024S5Poooooo000=ooooo`0608FKT`27WiP0Qj2I08JPVP27WiL0RZ6G0P2;X9L02`2=XIT0
SJ6J08nRW@2@Y9d0TZFM09BWWP2EYih0UZJO09VYX@2GZ9l0UZNN0080U:FK00@0U:JJ07J5O`2h_k`0
dM?DU03ooolJoooooaL0oooo00T0YJRY06U[KP0a<cH0;2h/02@U8@0N7a/071/I01XI5`0G5A<00`0G
4Q402`0H51808QlK03<b;00o@c`0?dI104==B@13CT/0A4i=045<C013CDh0ADe=0080A4Y<00/0A4U;
04U<D019Be<0ATQC03`nBP0a=4007b8]01<C800C4a`04A4G014B5@0201@E5P0;01XN6`0N8ah07b@O
020V700S:Ql09R/O02HY7`0U9al0=3L`03@g=@0a=3L00P0S92X01P0N7R@05aLM01LG700K7Ad0720L
01XM6@806b4K00<061lH01lW6P0T;Ad00P0a?BT0301DIdX0D69702/e9@0S:ah0728G01XQ5@0J81@0
;cTU03U3;@14CSH0BE@l04YF@080BUDo00/0C5Pn04]G>`1;EcX0BEDh04QC=`1;ECP0Be8g04Q?=P16
CSL0BE8i04E?=`0304A>=P0:04E@>014CC@0A4``0499;`15Bc80AT`c04I;<P18CCD0Adde04Q=>080
Ad`j00`0A4Th0458=P0oAS@0?DDb03i6<@0oB340?dP`03m7<00oAS00?48]03/n:`0h>B/203Hi:`0;
03@i;00b>B/0;SHW02de900]=280;3@N02dd7@0]=Ad0:S@K02Pa6@0/=1/00P0_=ah02`0]=Qh0<3LR
02hd8P0]=2H0;3<Y02D[8`0S:R808b/P02D]8@0V;R409blO00809BhM00H08b/I020X5P0R:AH08RHC
024T4P0P8a4?ooooo`003Oooool01P25Vi<0QinH08NPV@26X9X0QinG08ZQU`80Rj2G00/0SJ6I08fQ
VP2?XYd0T:BM09:UW@2DYih0UJNN09JVW`2IZJ40UjRO09JWWP0209BUV`0409BVVP1fQGl0^;nl0=7C
e9@0oooo6_oooolG0?ooo`090:FXZ@1YJfh0<C<f02`^;00T9B407QlK01`K6@0J6AL05aDC00<05a8A
00/061@B028O6`0c<R`0?d<l03m6@@13CDT0@di;04A>C@11C4`0@de>04E=C@0204A:C00;04A9B`19
C500BD]C04I8D`0l?TX0<CA001lR;@0C4b004a<L014A5`0A4QD00P0D5AH02`0J7Q/07R<N01lT7`0P
9Q`08bXO02H[7`0V:Al09BLO03@g<00d=cD0<C@g00808b@Z00H07QhT01LG7@0G5a`06adM01`P700J
7AT201/Q6`0301PO600O9aX092dM0080<CdY00`0E6M:051RA`0[=BD08b/N01`R5`0J8AD06R0D02li
9@0i@bd0A4hf04UD?01:ET0204YE?`0;04aH?P1;Ec/0BeLj04UE>018DcL0BeDh04]B=`18CcH0AThg
04UB>@15CcL00`14CSH02P15D3P0A4dd04A<<012BBl0AD/b04I<<`16Bc80B4de04M==@18CCP204M<
>P0<04A9>011B3H0?dHd03e5<P0nAS40?dPa03m8<00oAc00?dH`03a2;@0k?R/0>3T[0P0f>B/02`0d
>B`0<ST[02hf9`0]=B@0;C@R02`d7P0]=1d0;CDM02Xd6`0X<AT0;3@K0080;cLN00/0;CHN030g8P0^
=280;C@V02`c:@0U:b<08bXR02<[800U;B409RhQ02L_7`0202D^7@0602<[6@0P:1H08RTF028V4`0Q
918082<A3oooool000gooooo00H0PIB=08VNUP2;XY/0Rj:L08VOW026W9T208VNV`0;08bPWP2>XIl0
SZ6P092TX02@Xid0TZFN09JWW`2EY9h0VJVR09NVX02IZJ400P2GZ9h01P2EYih0Uj^P08jQU@1bPGL0
PhZ60:Z_ZY80oooo6_oooolI0?ooo`070<k?c`2OXYh0>T0g02L/900R9al06adI01TI5`0201PD4`0<
01XD4`0H4Q406Q@D01hI5`0U8b00;S0]03Hk>00mAD00@4U504A>BP17DDd0BE5=0P17Cd/02`17C4X0
AdU;04E6C@15AU00ADQB04E:E010ADh0<CLn01dO:@0K7BD05QTN00804A8I00/05APN01dR900P9RD0
8BPT02<Z9@0T:bD092TS028U800d=c00?dDm0498@`0203Hk>00;02/^;`0R8bH06aXO01`M800J7Al0
6QdL01XN6`0F6aL04aLC01PN4`0M91D00P0H7`l0100U;Qd0:S@R024Y6P0K8Q@201/Q500601LM4@0S
:Q/0:c8P03a6;`10BS80A4hg0P14CST02`1<Ech0C5Tm04eI?01<F3T0BE@g04iG>@1;DCD0BDlf04YA
>018CcP0ATli0080ADhi00/0ADlj04I@>`16D3/0ADde049:<@0mA2d0?T<[03m3:P12ARh0AD/c04E:
=@0204M<>00<04M=>P14BST0@4Li0416>00nAS@0?DD`03a4;`0mA300?D<^0455;`0m@2`0>cd^0P0l
?c002`0g>bl0<cP^034g;00b=b/0;SDT02`d8@0^=b80;cTQ02lh7P0/=Ah0;38M0080;C@O00/0:c8M
02le8@0]=2<0;CDW02df:P0Z<BL09BdS02H_900S:Ql092dN02H_7`0202H_7@0602@]600U;QL09bhF
02L]4`0R9Pl082@?3oooool000gooooo00H0PYB908^PV02<Y9d0R9jM08ROWP27WJ0208RMX00;08VO
X02=XJ00Sj:Q096SX`2CYZ@0U:NT09NXX`2GZJ40V:ZP09RXX02HZ:400P2K[:@02@2J[:<0V:bR09J[
X@2EZYh0S:6E07j@Q01ZNf`0N85j0::UXP2?0?oooa[ooooo703oool0103>d<h0UiZH02TZ:P0S8bH2
01lM800<01`I6@0M6QT07A/J01dK6P0O7Q/07adK024Q800V:2D0<3<`03m5?`17CdL0C5A=0P1=EE40
2`1<DU80BDaA04I9D@15B540@DIA04]FF`12C580B5=C03e6A@0j@D00<C@i00807b0[00/06Q/W02T]
=@0W;C<08BP[01lW9P0P:BD07bLR020V800P8Ah0;C0[03Pn>@0203e5?P0;03a3?@0i@C/0<CDb02H[
:`0P9BH071lQ01LK6P0B5A<03Q4?01LL500J81D00P0J7a<0300M8QH08bXL02H]800M91P06b8E01`S
5`0N9AT0:C<T03<n:P0hABh0?TTa049<<080@d``00H0BE8e04UA<`1:DcD0CEDi04eD>@1?Ec/204]C
>@0304YD>@19DcL0BUDi0080BE@j00P0BU<j04]D>`1=E3h0CU8m04Y?>P16BSP0@dPe0456<@<0@4L`
0P11Ac401P14C3@0@T/d0499=@12BCL0@4Lf03a4<`80?dLf00@0?4Db03i6<@0lA300>d8a0P0l@S80
2`0j@340>D0a03U1;`0j@Rh0=SlZ03@l9`0f?BT0=S`Y03<j9P0b>RL0<3PX0080;3DW00/0:S8U02Tb
900Z<b@0:S@T02/e9@0^>2P0:c@U02Tc8`0[=280:BlN02/`7`0202X`7P0602`b7@0[<AX0:c0H02P^
5P0X;1L09RTE3oooool000gooooo00H0Qi^A08jSW@2>YJ<0RjBT08ZRYP2;XJD208VOX@0;08RNX02;
X:00SJ:R09:VY02CYZ@0TjJS09BWX`2FZJ40UZZP09V[X@2K[:<00P2JZZH02`2I[ZL0VJfW09R/Y02H
[J@0VJjU09N]X`2EZYd0S:2@06=`J01LIf00^<2j0080cm7BR`3ooolJoooooal0oooo00l0Wj:Q069R
I`1RHVL0:R/a02d_<`0b=CL0:b`]02LX:00U9RD08R@Q02@V8P0V:2<0<3@]03@h<P11ASd00P19CDH0
2`1?DDl0Ce9C04iCF01:DEL0@d]B045<C`12CTh0AU9>04]GD`1:DU80BE1C0080A4Q?00/0>3a603Dl
A00Q9C406b0X01HM800D6a`05Q/H01LK5`0D51@05aDH024P8P0203@g<`0;03a2?010Acl0@DU003i8
@00^=S<09B`]01hS9P0G71`041@B010D4@0D5Q800P0E6A80300Q:1d09BdO02Xb8`0U;Ah092`L028Z
6P0N91H09RdO02/a8@0b>BD0=C`W03a3:@80?D@Y00/0A4X`04Q=<`18CC<0BDlc04aA=P1<DST0CE@j
04]C>P19DcT0BE@h04]F>@0204UC>00;04UA>01:D3/0C54o04iC@@1=DCl0BTlm04I;>P13BSH0@TXd
04===@0oBC<00P0oBS@01P0nB340?DH_03i8<00oAc40?THa03Y2<080?4Db00@0>D8_03M1;P0f@2d0
=d8_0P0f@2d02`0h@Bh0=D0]03U2;P0h@Bd0=d4[03Ho:`0h@2d0>44^03Po;@0f?2d0<S/^0080<3T^
00/0;cT]02/e:P0Z<bL0:34S02L`800X<R00:C<P02/d7`0/=R00:c<L02X_6@0202X_6P0602HZ6P0X
;1/09b`I02DZ5`0X:Q/09bTK3oooool000gooooo00H0R9jF08fTWP2>YJ@0SJBV08fSY`2<XZL208^P
YP0;08ZOX`2<XJ80SZ>S092UY02AYZ<0TjRR09FZXP2FZZ80U:NP09RZX`2K[:H00P2K[JX00`2J[Z/0
VJfZ09^_[00209V]ZP0609Z_ZP2J[jL0W;6V09R/W`27Uhh0N8N00P1MIFP00`1BEeh0`<K20>3Sh028
0?oooa[ooooo8`3oool02`2]/[40R8n=04mDE`1<E580A4]403Pm=P0d=bh0<C4Z030_:@0`;R`0=C<a
0080>3Hd00/0@d=004Q9B01=DU40CeMF04aHE@19EU00Ae9<04MBC@1>F5D0CUEG04iCF`0204eEGP0;
04aEG@17DeP0=3i702`e?@0J8bT072<T01LJ6`0C4aL04@hD01XE600J51@00P0l?3802`0k>S@0>CPe
03Li=P0j?S/0?dE103i7@`0iA3l09c0]018H5P0B5a<041@@00804QD?00`09RhP02H]7`0Y;al0:S0M
02T`7@0Y<Qh0:c4N02L/6P0S9QL08R<E01lP4P0V:AP202la7`0;03m3;017CS<0Ae0f04YC=`19DSD0
BE4g04Q>=`17CCH0Adhg04UA>P18DST00P17DCP01`17DST0BE<n04UC?`1=Ed80BE8n04I@>P15CcP0
0P14CSH02013CSD0@dlg045<=@11C3D0?d/c03e9<@0lBS00?DP^0P0mARl01P0kABh0>T<`03]4<@0i
@c00=d4^03U4<080>TDa00/0=d8^03A0:`0d@2/0=D0Z03Do:`0d?b/0>48]03Q1:`0i@B`0=cl]03Dk
;00203@l;@0;03<l;@0a>Rd0;cP[02`f9`0X<B40:C<Q02/e8@0/=R40;3@P02/c7P0[<A`00P0/<ah0
1P0Z;a/0:BlI02P^600V:aL0:2`K02P]70oooooo000=ooooo`0608BJT`2;XI/0Rj:N08bQX029WZ00
RYnS0P2<XJD02`2;X:<0S:6S08fSXP2?YZD0TJVW09:ZY@2E[:D0UZbS09FYY@2HZjT0UjZY0080V:^X
00/0VZb[09Z]Z`2J[Z/0Vjj/09b`[@2P/jh0X;B]09n`Y`2P/jH0O8^3069[JP0206I_KP05079kN@2I
Z9/0U:>G0;6m]03?f=40QP3ooolJooooobD0oooo00T0hnOT0<G=aP2;WH`0E5mI04]CC017CDH0A4A0
04=2?P0o?cX00P0f=C802`0d<c80=cHg0451@P1:CDd0BU9?04iHD01?FTh0DemB05=ME@1?EeH0Be9H
0080CE=M00/0D5QQ04mJH`1<F640BEEL03e8C@0f@4409BX^02<S9`0M5ad07QHJ02LR8@0204I5?@0;
02`W:00X9BL08alS02<P8`0_<S00=clj03a7?`0mC3l08bhU01DM5@0A5`d00P0=40L0300D60h05Q/?
01TM3@0Q9A<092TH02P_7P0W;A`092TK024U6@0X;B008BDJ01lQ60807QlF00P0?DDa05aZC01HIDP0
F6E705=L@`1>ECl0BE0m04M=>P80AD`h00h0@T/f049;=`12BcL0A4dh04E??017DSd0B58k04UE?018
DS/0ADlg04===@11C3@0@The04=A=P80@Dld00`0A50d041=<@0oBS00?TP^0418<@11B340?D@a03e3
=00k@c@0>D8b03Y3<P0kAc<203M2;P0;03M4;P0gA2`0=d<Z03M2:00h@BP0=ShW03Hm9`0f?2P0=chZ
03Hm:`0e?Bd00P0d?B/02P0c?2X0;SLW02hg:00]=RL0:S@T02Xd8P0Y<b40:c<P02`b7`0/<1h302/_
7@0602T^6P0U:QH08bLF02L[6P0V:QT09R`J3oooool000gooooo00H0QYRE08bOW`2>XZD0RinU08RM
XP28WJ4208^PXP0;08bQX@2<XJ00T:BT092TY`2@YJX0TjV/09:XZ@2CZJH0Uj^X09Z^[@2H[:d00P2I
[:`02`2K[J`0W:f[09b]ZP2P/Jl0X[:`0:6b[@2P/J/0XK6[0::e[029VI80IFe_0080IVe^00P0SifD
09^ZX02O[:<0Y;>W0:JeZ@2W]Z/0^<:l0<cAd8<0oooo6_oooolX0?ooo`060=kQh02l`l00LWYi07f8
OP26Tgl0ATQ20P15Ad002`11@C/0?CXh03hj>P0l>CX0?Sdo0494@P1;DDT0D5U>05=NDP1CGEH0CUME
0080CUAH00/0E5MM059GGP1=Deh0CUIP04eHG`1=Fed0B5AD041:BP0c=CH0:2@X03Tg=@0203lo>@0;
02DP8`0S82@06aLN01HB6@0F5AP06adM02<X8`0Y<BP09c4U01XS6@0G7A800P0G7Q40300B60`051T=
01@H3@0D5``061`@01XO4`0L81@05a`C01<F4@0Q:1h09B`P02P]8P80:2`Q00/0<CHW04eH@01OJe80
HW1F06=aF@1LJE<0D5Y804U??`12ASD0?D4a03Xo<00203]1<00;03i2<`11AcH0A4`h04MA>`18DCh0
ADln04A??@0oBcP0@Dhg041?=011D3800P11Cc803012CC00@Tdb049<<@14C380@DLb0498=@0nA3D0
?DDg03a6>@0h@cD0=d8`03U6<080=d@]00/0>4@/03M3:P0kAB`0>T8Z03Pn:P0g?R/0<STX030h9`0`
>BL0<S/X034l:@02034l:00;034l9`0`>bD0;cTS02hg8@0/=Al0:c@M02T`700[<1h0;C0O02`]7@0]
;ah00P0];al01P0[;1d0:2XK02LZ6`0X:ad0:2`N02DY7Poooooo000=ooooo`0608RIV@2=WjD0Sj6Z
08bNZ02;WZL0SJ2X0P2?XZL02`2?XJ<0T:>T096SYP2@XjP0TJFY096VZ@2AZ:T0TJNX09BXZ@2H[:h0
UZ^_0080Ujb]00L0Vjn]09j`[02N[J`0Wjj_0:6`/02S/k80XkBb0080YKF_00l0W:bX09FSX02?ViL0
Si^G09NVWP2S/ZL0YK:Z0:Ne[P2Z]Zl0Z[F`0:^e/02X/Zd0ZK>/0=CJe@3Zk^/0P03ooolJooooob/0
oooo00<0d=GA0;W4]`22Sgd00P1ePFd02`1CF4d0EUU>055BB@1;BdD0ADA10410>`0n?cT0@D<k04Q=
@`1=DdX0DUUC0080E5aH00/0F5eN05IKGP1BEed0D5MM04iFF`1;F5X0CUaL059OF`1BG5L0C51?04U:
B`0203/j?@0;028N:@0N7BP06QTT01@B700D51X04Q@G014E4`0C61<051/C01<L4`0D71400P0I8A80
300L8a<06QlB01PL3`0I6`l05QP>01TL4@0E5@`04A89010@2P0A4@d05QLB01TJ4P806a`E00/0:RhS
038f;018DD40DUi;05e]E`1RM5h0IWQP05QUD@0nA3D0;RlR02LV6`0202LU6P0;030^8@0e=BP0>CT[
0414<P14BSL0@ddk04=??@0oC3P0?ddd041@<011D2d00P11Cbd03013Cb`0@4XY0457:P12B2l0@dPc
03m5=@0oASL0>d8e03]4=`0h@cD0=T0`03E1;080=D8Y00/0=D4W03Y4:00i@2P0>d4Y03Pl:00j?R/0
>3`]03Hl;P0b>R`0<C/^02df:P0202/e:00;02`g900^>R<0;cXQ02lj7`0^>Ad0;3HL02df700]<a`0
;c<M02l`7`0a<R400P0_;al01P0^;B00;2`Q02/]900[;RD09BTP028U7Poooooo000=ooooo`0608BF
U`29Vj80SJ2Z08fOZ`2;WJT0S9bV0P2=WJH02`2>Wj@0TJ:W09:SZ02?XJH0TjJX09>XZ@2BYjP0TZNY
09BXZ@2J[Zl0W;2a0080VZj]00/0VZf^09Z^[@2L[Zd0WZj/0:2_[P2Q/Jl0X[>_0:6b[02U]Jh0YKF]
0:BcZP020:6_Y`0<0:>bZ@2V]J/0Z;B]0:Re/02/^;@0[KNc0:nj]P2^^;<0[KVb0:Zd[02/^J/0ZkVT
0P3Efm400`3Zk>L0oooo0?ooo`1j0?oooa[ooooo;P3oool20=3FbP0;0:^aY02AVXT0QHen07^2L`1V
KEh0CU=304I9>P10@SD0>SXa03dn=P0n@3/00P16BDH02`1>DU80E5]K05AMGP1BGE`0CUYI04aHE`1;
EeH0DUeK05QRG@1LHUl0FEeO0080EEYP00/0>3U702d`?`0R9C8061/W01DH8`0C5a`041HG00dC400;
40/04QT?01XR4`0201lX500<02</5`0S:aL08BHD01lS4`0N8Q<06Q`>01HH2@0A3`D04@h701@A3@0F
51006ALE0P0F4a<02`0D4aH061HJ02HX9P0a=S80@Da204mOC@1JK5<0D65805Y[B`11B380=cPX0080
;b/S00/0;RPV02LQ8P0[:2D0<c<Z03Tn<P0mACH0?dTd03a7<00lB2`0>dPX041;:P0203i8:P0<03e5
:@0l@RL0?48X03a3;@0k@Rl0>D0`03U1<`0g@3<0=3h`03Ho;`0h@2d0>44Z0P0g@BL02P0j@RL0?TDZ
03e4:`0m@b`0?D8]03Tm:`0g?2`0=Sh_03@l<00a>Rd302`e:00;02/d9P0[=B<0;3LS02hh8@0_>R80
;SXQ02`g7`0/=Al0;cHP02da7`0[;Qh00P0Z;Al01P0[;R40:RdS02P/8`0X;2<09BTO028V70oooooo
000=ooooo`06086HV@28WZ00Rj2U08bOZ02;WJP0RibT0P2<WJ<02`2<W:<0SYnU092RY`2@XjL0TZBU
09:UYP2CYZT0TZNZ09>WZ@2GZj/0V:b/0080W:n^00/0VZf^09f`/02J[Jh0W[2`0:2a/`2R/KD0X[:d
0:6a/@2T]K80Y[F`0:Jc[P020:Jd[P0<0:Fc[@2U/jh0Z;F^0:Zg/@2[^;<0[;Nd0:fj]P2]^kD0[[be
0:bj/02Z^Z`0[[j[0P2]_JX00`2]^JP0`/bo0=SOeP1j0?oooa[ooooo<@3oool02P3[k^X0e=WA0:Fa
XP2@Vh`0QY=n055FB@0m@CL0=SXb02la:`0/;BP202`[:@0603Hf<`1;CdT0CUE@05=LF@1FH5`0E5mL
0P1@Fe/00`1DGE`0FF5N05YQG@0205eSHP0;05aRH`1EG600?TA;03<j@00U:c<06AhT014F6P0<4Q80
2Q0;018J3P0K8a400P0U;aP0300]=b40;cXR02/d700Q:A@07B8?01TK2P0D5PH04a@5018A1`0F4`/0
6aP?01lL4P8081dH00/08AlL028N700N71/08b8R03<f<@10B3d0DEi902<X7P0W;b00:S<S04AA>@02
05UVB`0;05MNB01BETD0BD/l03m0=00k?S<0?D8e03m5=P0oAC@0?4<_03a4:`0l@bP00P0lABT0300i
@2P0>3lW03Po:@0g?BT0=C`X03Hm:@0h?bh0>3l`03Dl;P0d>R/0=3XY03Tn:`80>d4_00/0>D0]03Po
;00i@Bd0>Cl]03Q0;P0h@2/0=SdX03Hn:@0f?BX0<CTW02de9P0202dd9P80;3<U00T0:c<V02/d9`0[
=2L0:cDV02`f900/=B<0;3@Q02Ta7P0Z<1l00P0Z;ad01P0Z<1`09b`J02X_7@0[;al0:RhL02L/6`oo
oooo000=ooooo`06082FU`28Wj80S::X08bQZ@28WJH0RYfU0P2<WJD02`2>WjP0SYnY08jOZ02@XZT0
TjF[09:TZP2CYZd0U:N]09BW[02EYZ/0UZN/0080VJ^_00H0VZ^a09b]/P2M[K@0Wjne0::c^02R/KL2
0::`]@030::a]02V];H0Y[:c0080Z;Fe00/0Z[Nf0:Vf]02Y]K00Z[J`0:bi]@2_^kP0[[^h0:fk]P2]
^k@0[Kba0:fl[@030;6o[@060;6o[P2b_jl0/;f_0;:m/@32b/80emoHM`3ooolJoooooc@0oooo00L0
j^gZ0=3Hd01kQg`0Adi=03i4?`0g?3@0<3<Z0080;2dS00/0:RPP02`X8`0k>c@0@dE004Y?B`1@F5<0
E5iJ05QTG@1MJF40FF=L05INE`0205YQFP0;05QOFP1IHUh0Ef5O05=OG01:EeD0=d9201hT9`0D61P0
3a<?01LM4@0M9QH00P0R:aP0300X<Q/0;SPQ02/d7@0T:aD07B0?01HF2P0@40H03Ph7014B2P0C4`h0
:2/P024R60807A`B00/0D5Tm04M==00X9b00A4]003e2>@0f>c@0;c@]02HY8@0H6A<04a<=00l?2@02
03Y3<00;07nDL021U7<0OI1b05IOD@1AFTh0CEA:04U?@`17Bch0@TLh0457<P0mARd00P0nBB`0300m
Ab/0?4@Z03Y3:@0g?bD0=clV03Dl9`0f>bP0>Ch[03Ll;00b=bT0=3PY03Di:`80=3P/00/0=3X^03@k
;P0e?C00<c`^038l:`0c?BP0<clV038n900a?280;SPO02hf8@0202he8P0;02dc8@0]<b80:S8T02Ta
9P0X<BL0:S@X02Xe9@0Z=B@0:cHQ02/f7`0Y<ah00P0Y<Q`01P0Z<AP0:C0G02T^600X;AT0:B`I02P[
6@oooooo000=ooooo`0608>FV@29WZ<0SJ:Y08^OZ@29WZL0RYjV0P2;W:@02`2=X:H0Sj6Y08fNY`2C
Y:/0Tj>[09BV[@2CY:`0U:J]09BT[02EY:`0UJ>/0080UJB/00/0UZJ]09ZY/02KZK00WZbc0::a]`2S
/[P0Y;6f0:B`]@2V/[H0Y;6e0:Nc]0020:Rc/`030:Rd/`2Y]K80[KRd0080[;Rf00L0[[Vg0:nj^02]
^[L0[[fe0:jm/`2^_Jl0/Kn`0080/l2`00T0/[n^0;>o[P2c_Zh0]/2a0;Bo/02a_k00[K^]0=;Id@3U
j^D0M03ooolJooooocL0oooo00@0_<:m08ZBRP17CTL0>3dd0P0f>b`02`0a<bH0=CDZ038a:`0b<2l0
<S0`03@c<`13B480CeM>05MQE@1IHeL0FfEG0080F69E00/0E5eC05EOE@1HIET0EV=K059QF`1EIE`0
>TE001XO7`0J7aX061dE01PN500201XP4P0<01`R4P0N91<08BDF02@Y600N8Q<051D=01<A3P0A40l0
3`h>018@400S91l05A<C0P0_<bh02`2[b9h0Z<FP06YlJP17DTT0AU15024S800N7a/05QHC01PH4`0C
4Pl04Q0>0080518A00/0N8a]09F]RP2;X880Q9Qo06]jK01WMVP0I79Q069`G01LIeH0EF5=055NAP02
04eH@00<04MB>P15CcP0@d/f03m7<P0m@bl0>Sl[03Tl:`0i>b`0=cXZ03@g:`0c=RX0<SDY0P0c=bX0
2`0a=BP0;c@Y02lf:@0/=BL0:C<T02dg9P0[=B@0;3DT02dh900]>240;3LO0080:c@N00/0:c<O02Xb
800Z<R40:C4Q02Xd9@0[=2D0:cDT02Tb800[=200:S8L02Tb7@0202Tb6`0602/b6P0W;QP09b/G02H/
6P0V;1d092XK3oooool000gooooo00H0MXJ<08bOX@29WJ@0QIVT08BGX`26Vj@208RKX`0;08fOYP2>
X:P0Sj2Y08jOY`2AXZT0TZ>[09:TZ`2CYJ/0TjBZ09JV[@2IYjh00P2IZ:l209NW[P80VZR_00L0VjV_
09f/[`2Q[jh0Xjn^0:Nc/`2V/[D0Y[6d0080Y[:a00`0Yk>_0:Vc/02/]k@0[KRg0:Vd/`2Z][H0ZkRf
0:^i]02[^[80ZkV`0;2o/P2`_k020;2m[@0;0;2m[02c_jd0/l2]0;Fn[02d_j`0]L6_0;C0/02a_Zd0
[kfZ09NTT@2n`;X00P3LgMY`0?oooa[ooooo>P3oool03P2RXj40Q8Qo08B8O`1MHeL0Bdi60410?@0m
>cT0=S<a02h[:00Y9R<0;2XU0414=`19CT40FF1>0P1JHe402`1JIE<0C5I905IRD01>FDP0BUM804QG
B01=GD`0>4@g02D/8@0O9QP07B4D008061`>00H06A/>01TJ3@0M7A80824H01lP5`0H6A8201@C3@04
01@C400B40l05QDD01`L6`807AdO00/0Hg5P07^?N02adjX0JGeU03<i;00V:Qd07QlE01HE3@0B3P/0
510>01@@4002010>3P0;03Hm<`2E/Hh0R9n208JLP@1jSGD0E5mC05YVE@1PKE/0KG]X07f?N@20U7/0
0P1mSgH0301gQfd0J7AL061WD`1KH540EU]A04mDBP17CT<0?T@h03Y0=@0i?3@0=STa03Di<080=c/^
00/0<cP[038h:@0a>2P0;cLY02de:@0/<bP0;SDY02`c9`0Z<bD0;CHS02df7`0202Xa6P0;02hd7@0[
<A`0:S0N02T`7`0X<1l0:34R02H^7`0X<1l09R`K02P^6`0V:aT00P0W;1X01P0V:Q/092TI024W600T
;1h08b/P024Y7Poooooo000=ooooo`0607b>T023V9T0QibQ08NKY024Uj<0Q9NT0P24UZ<02`2;VjL0
SYj[08jO[02=WjT0S9nX08nSZ`2=XJP0T:BX096TZ02DYZX0UJR[00<0UZVZ00X0V:^[09RZ[02HZ:/0
W:Z^09f/[P2O/:`0Xk:^0:Ba[@2W];00ZKFa0P2Z][40302Y][40ZKF_0:Rd[`2Z]k<0Z;Bc0:Vf]P2Y
][D0Z[Nc0:bi]02_^kD0[[^a0;2n/@80/[na00/0/Kj_0;:n[P2c_j`0]L2/0;Bn[02f`:l0]Kn`0;G0
[`2f`:h0];f/0:^dX`020:N`WP030;g3]`3;c/P0oooo06d0oooo6_oooolm0?ooo`0;0>S[iP2l_kX0
IfUR05UJE00g<380=Bl^02hY:00X9280:RPR030`9`0i?2h00P17C3X02`16CCX0=CX^03Po<00b>RX0
;3DU030i:00kAS40@Tdd02/a800]<B4092PI00807b4E00L06AX@01PH3`0M7AD08R<L020R700F5Q<0
4aD@00804aH@00<051@@01hO6`0P8R400P0S9R<02`0R9R@0<CPc06MhI01UMV40?TLi01hO5`0U9AX0
4`h;014<2P0?20/03PH<00803`/A00/0Ae18086HP@28X8T0OiIo08JLP01iRg80JgMS05]RE@1MIUP0
RYb208JHOP0208ZLP00<09:SQ@25UGP0GVEE06AZGP1/M6T0KGM/06QcJ01RKEl0FfEH05=MDP19DTX0
ADa70P10Acl02`0nAS/0?D@h03]3=@0h@3@0<SXa02lc;00^<bX0;C8W02``8`0/<1h0;C8M0080;S0K
00/0<C8L034d7@0^<al09b`K01lW5P0J81<05ad@01TO4P0K8A@07R<E02@Y6@0202P/700602LZ7@0T
9a/09BPM028X7@0P9ah08BTO3oooool000gooooo00H0PIFA08VKVP2;WZ80R9^S08BFXP25Uj8208NJ
X`0;08ZKXP2<W:<0S9fU08fNYP2=WjH0SJ6X08jSZ02?XZD0T:BV09:UZ@2AYJL00P2@YJH02P2CYjL0
UJNW09NXZ@2JZ:/0WJ^/09fZZ`2O[:`0XZj_0:>_/02T[jl30:Nb[`0<0:Ve/@2Z][40Z[F`0:Vd/@2Z
^;@0Z;Fd0:Zh]02Y][00[;Vb0:nj/P2^^Jl0/;ba0`2c_k802P2c_k40]Kn`0;Bo[@2e_Zd0]l6_0;S3
/@2f`[00]l:^0;K0Z`2f_Z`20;Fm[0050;BnZP2c_JP0[;RR0;k7]`2TXJ<0J`3ooolJoooood00oooo
00P0fMWH09jJW00j=3@0>cLc03Ld;P0d<RX0=C@X03@e9P80<30Q00/0;RhN02/Y700U9AT0828E028V
5P0U:AP0<3DP03Ll9P0a=B<0;2lP02@V700201hO6@0<01/L600J71L07b0M02@U8P0N8Ad06ahI01LI
5@0H6a@061/B01@G400D5A408R@M0P0/<BH02`0d>Rd0=clb04=<?018DT00@d/j01dN5`0Q8a`06aTG
01LB500D3Q@04@/C00803`/C00/0>3Tj06ekKP1aQ7@0O99k08:GO029W7l0RYao082AN01lRg<0OHme
08:EN@0208FFN`0<08BDNP2CYHX0Q9=o05ELE`1HGeP0DEIA07B0KP25UGd0GVMM05URF`1JIEh0HFeT
0P1SL6H02`1TLFH0HFmQ05iYF@1IHU80CeI804E:?`0i>S80=3D/03@f:@0a=2<0;BlN0080<34N00/0
<S8O02l`7`0/;b008RDH01TL400?4`P02@`400H80P092`D02@`501LL3`0201dS5006028W600T9aT0
92HL02@W7@0P91/07R<I3oooool000gooooo00H0PIFA08VKVP2;WZ80R9^S08BFXP25Uj8208NJX`0;
08ZKXP2<W:<0S9fU08fNYP2=WjH0SJ6X08jSZ02?XZD0T:BV09:UZ@2AYJL00P2@YJH02P2CYjL0UJNW
09NXZ@2JZ:/0WJ^/09fZZ`2O[:`0XZj_0:>_/02T[jl30:Nb[`0<0:Ve/@2Z][40Z[F`0:Vd/@2Z^;@0
Z;Fd0:Zh]02Y][00[;Vb0:nj/P2^^Jl0/;ba0`2c_k802P2c_k40]Kn`0;Bo[@2e_Zd0]l6_0;S3/@2f
`[00]l:^0;K0Z`2f_Z`20;Fm[0050;BnZP2c_JP0[;RR0;k7]`2TXJ<0J`3ooolJoooood00oooo00P0
fMWH09jJW00j=3@0>cLc03Ld;P0d<RX0=C@X03@e9P80<30Q00/0;RhN02/Y700U9AT0828E028V5P0U
:AP0<3DP03Ll9P0a=B<0;2lP02@V700201hO6@0<01/L600J71L07b0M02@U8P0N8Ad06ahI01LI5@0H
6a@061/B01@G400D5A408R@M0P0/<BH02`0d>Rd0=clb04=<?018DT00@d/j01dN5`0Q8a`06aTG01LB
500D3Q@04@/C00803`/C00/0>3Tj06ekKP1aQ7@0O99k08:GO029W7l0RYao082AN01lRg<0OHme08:E
N@0208FFN`0<08BDNP2CYHX0Q9=o05ELE`1HGeP0DEIA07B0KP25UGd0GVMM05URF`1JIEh0HFeT0P1S
L6H02`1TLFH0HFmQ05iYF@1IHU80CeI804E:?`0i>S80=3D/03@f:@0a=2<0;BlN0080<34N00/0<S8O
02l`7`0/;b008RDH01TL400?4`P02@`400H80P092`D02@`501LL3`0201dS5006028W600T9aT092HL
02@W7@0P91/07R<I3oooool000gooooo00H0MXR608JKVP28WJ40QibS08NJY026VJH208RLZ00;08VM
YP2;WZH0S9nU08bOY@2;WZD0RYnV08fRYP2?XjD0TZFW096UZ02BZ:`00P2@YjP02`2DZZT0UJRV09VY
Z02KZjT0Wjj/0:6][P2R[Zh0Y[2b0:Ra/P2U[[00ZK>b0080ZK>`00`0ZkFb0:Zd/02[]K80ZkFb0:fh
]@2]^K@0ZkNa0:fj/P2^^K80[[Zb0:ni/02a_;820;:m/P060;>o/`2e_[<0];n`0;Jo[`2f_jd0^<:^
0P2g`Jh00`2f`:l0]L2^0;[4/@020;W2[P080;W2[@2j`jd0^/B/0;g:[@1mOg<0BD=30:RWX`3RiMiX
0?oooa[ooooo@`3oool01@2VYZ80S96104e@@019CC/0A4Le0080?cl_00/0<S0S02l]8P0Z:Ah0:2LK
02HX600W:QT0;c4P03/m;00i>bd0<C4X02PX8P02028S7P0<01dN6P0N81`09BLT02P[9`0U9b808RHP
01hQ700K7AX06ahG018D3P0A4@d051<>0P0I6a802`0W;Al0=3/Y04MB>P15CcL0=chZ02`b8P0U:1d0
824K01dM6@0L6a/06APH00806QXJ00/061TI02T]:@10B3d0C5E805eVE02J[Hd0TjB909>UR@2BY8L0
Sj2308fOPP0208bNP`0<08VIPP28VH@0RI^607V9N@1^NVd0IFiR06=]G`2P]YL0SZ>905]VG01KIed0
E5iF0P1CG5@02`1^OVd0N8Yf07b?N01mT7P0NH]c06ajIP1SKU`0GVMF05ELB`1=DT40B4dk0080A4Ld
00/0?Cl/03Dh:P0`=BX0:2`S01PK4P0=4@T02@`500D70@051`800`D100840@0200T;1@0600hA1P0F
6@/07R4C02<W5`0S:AT09BdM3oooool000gooooo00H0M8R6082EU`26VZ40R9fW08RKZ029W:X208RJ
Z@0;08VMZP2;WZX0RYjW08fQZ02@XZT0Sj6Y096SZ`2AY:X0TJBX09>WZP2FZJh00P2DYjd02`2EZJh0
VJb_09Z[[P2LZjh0WZ^^09j][`2Q[[00Y;6b0:Nb/P2U/;40YK6b0080Z;Jd00`0ZKFb0:^g]02/][L0
[;Nh0:fh^@2_^kP0/;^g0;6m]P2a_;L0/[^f0;6j]@2c_[L20;>o]`0;0;Bn]@2c_k<0]L6c0;K1/02h
`Jh0^L6]0;g5/@2k`[80^l:d0;_3]P2k`[D00P2m`kH02`2naK@0_LJa0;c6[@2nbZ`0]l>T07f1K`1N
FUD0/KbQ09RNS03DfLh0j>_U06D0oooo6_oooom60?ooo`0?0;o4^P2HWXl0FEa<05ULC013@c@0@T@b
03/n:`0l?bX0=cXS03Hi8P0e=bH0?3/]03hl<00h=bd0;BdU00809RHO0P0O7aT02P0S91h0:2TR02/^
:00^<BX0:blZ020S8`0K7A/04A8@00lB3P0>4@d2018E3`0;01HJ4`0U:Qd0:2lO02X`7`0]<R009RXI
024R5@0N7QP06aTI01lO800K6ah00P0k@cd02`0h?SX0?dQ004E?A@19DTH0@4<l069XG02JZi80R9N3
09:SR`29VH80T:690080SZ6900`0S9n908fQR`2<X8X0QY^508FHP020TgT0O8mf07Z=L`1oTgP0Nhig
07Z=M@1`PV`206emJP0;06alJ`1cQG80MhQf07Z<N01kSWP0O8eg07^=MP1nSgH0OHad07N3L@1aOFd0
0P1]NVX02@1ULV<0FfMK04]FB`0W;BT07R<M01LJ500;30L01`P300@50P0200830@<00@<100D010@1
01HH2@0Q9A8092TE02DZ6@0?ooooo`003Oooool01P1aQ8D0PYFK08FIX`26VZH0Q9NU08FIY@80QIRU
00/0QYZU08RMYP2;X:P0SJ6W08bOY`2<WZT0SZ:[08nUZ`2;X:H0SJ>V096VZ@0209FY[P0;09JZ/@2G
ZK<0UjVb09^[/P2LZk00VjZ_09j]/@2M[K00Wjfa0:2]/P2S/;<00P2V/k@0302V];@0Z;Fg0:Nc]`2X
/[H0ZkFh0:bf^P2/]KP0[[Rg0:be]02_][D0/;Re0;6l^@80/;bh00/0/knh0;:m]@2c_[D0]Kjb0;Jo
/`2g_k80^/2a0;[0]02l`[P0^/:i0;W1]`020;W2]00;0;W3]02ka;80^/B/0;S3Z@2h`ZX0]KjY0:nd
X`2d^ZL0][f[0;FoZP2b_JH00P34c;X00`2`/:h0oooo0?ooo`1P0?oooa[oooooB03oool20>7SgP0;
0:2OWP1OHEH0KgMQ071iH01KHD`0DEI304M;?015AcX0@d<g03Ld;00a;bL00P0[:R40300V9Ah0820I
020P6@0T9A`09bLP02/]9@0/;bP08bDR01hN7@0G5aL051@D018E4`804QHC00/05a`G01`R6P0S:al0
:2lP02Ta7`0Q9QH07R0D01`J5P0J61L061HI020P9@0203i4A00;06MgJ`1TMfT0IGQX06UjI@1MJEP0
ADM20<3I]01gQWH0MhQh05]WG@1OJUh00P1lSgT03025Uh00RIb408bQRP28WHL0S:>905ESE`1UMV80
PYEh07R;L01hRW@0O95k082FP080P9N000/0OiIm07N;M01gR7D0MHAe07J3MP1cPWH0M8Ae07F6L`1h
QW<0MhAc07R5LP0207N5L`0707N5M01gQW<0Nhig03Y1?@0C5AP03@h=00820P0400420@800@<100H0
0`H100/=0`0@4`D061`;02@Y5@0W:aP?ooooo`003Oooool01P1iRH`0PI>M082CX@20Tj80PIFR08FH
X`80QIVR00/0Q9RQ08NKY029WJD0Rj2X08ZOZ02;WjT0RinW08ZPZ02;X:P0S9nV092RZ@0209FW[P0;
09BU/02EY[80UjJb09RU[`2JZK40W:^b09bZ/@2LZ[80WJ^c0:2^]02S[[<00P2T[[<0302T[k@0ZkBh
0:Zc]`2Y/[L0Z[>i0:bc^`2/];T0[KNh0:ff]P2_][@0[kJc0;:j]P80/[^g00/0/kbf0;>m]P2d_k@0
/kjb0;:m/02d_[00]Kj`0;Jo/P2i`[H0^<:f0;O4]P020;G2]@0;0;G2/P2f`jl0]l>^0;W4[P2j`jd0
_<>^0;[1Z`2k`Jd0^L2/0;_3[@2ma:/00P2j`jT0102//Id0ZJfJ0<76]@3]knQO0?oooa[oooooC03o
ool02@3WjN@0`<Nc09jVS`2:TG`0MgaY05MGC01BD4D0AT8g03Tf;00203<c:@0<02X[8P0V9al0:2PN
02X/8@0Z;2<0:2XQ028S7P0N7a/06QTI01XI6P0D5AL05aXI0P0M8Q`02`0S:R009B`Q02/a9@0/<RH0
;SHX02/a800U:A/092DN020Q700N7A`06QTM0080DEiD00/0YlNR07J=L`1EIU<0EF=>0417>`16C480
R9^10763L01eRgD0H75P05]ZF00207:4K00<07nCNP23V7l0QY^408RLQP2=Y8X0@4M304aDC02T_IT0
?D0l05aWGP2H[iH0L89c0P1/P7402`1cRGL0NHaj07F5MP1bP7@0M85h079nN@1dPWX0M8=g07B4M01d
PW40M89_0080KgaX00/0Kg]W06ikI@1/NV@0<cHb00l<4@070`H01@<400<20P020P<00@4200420@02
00840@0600T;0`0J70l07R4B028W5`0S:QL092XG3oooool000gooooo00H0NhZ@086DWP24V:@0PiRS
08:FXP23UZ4208BGXP0708JIY026VJH0QiZV08^MZ`2:W:T0RijX08jQZ@0208bPZ00?08jQZ@2@XjX0
TjB/09>T[02DYjd0UJB^09JT/@2JZ;@0VZNe09bZ]P2OZk@0Wjbe0:2/]`2S/;T0Y:ng0080Y[:f00`0
Y[6d0:Rb/`2X/K<0Z;6d0:bf]`2^]kT0/;Vi0;2i^02`^KL0/;Rc0;6i/`2d_KD20;Bm]0040;Fm]@2d
_K<0];fb0;>m[`80];n_00D0];j^0;Fn/02f_k00];j`0;K1/P020;S4]00;0;S3/`2jaK<0^LBc0;[3
/P2i`jd0^/>/0;g6[02oaZd0_lJ/0;k5[02naJT00P2naZT01`2oajT0_<>X0;_2YP2k`jD0^/>S0=gS
dP3^l>L0G03ooolJooooodl0oooo00H0fn3?0<35[@2AUG/0Q8Qb05EDB016AcH203m2;`0<03Lm:`0`
=2H0<34T02l^8@0/;B00:2TN028R6`0O81X071hH01XK600I6aP07AlL0P0S9R402`0]<RL0;S<W030f
:@0`=2X0<3@X030e:00^<RH0;C4V02LY800K71D06AXC00805QPA00/0?TTf05EUBP0h?bl0>Cl_02hc
:00/<BL0:c0X02DZ8`1bRFX0I7ML06AeG00206ioI`0<07F6K`1gRW<0NHeh07b@O@20UX40Jg]/07:2
KP2EZh`0?40o04YAC`2P^Yl0Rj2:0P1XMfX02`24V880MhIf04A6AP1GGEX0NXAm075lN01/NG<0Kgic
0761L@1bP6l0MHE^0080Kh1X00/0KGaU06A`F`1>F4P0;c@]01<B4`0>30d02`P:00L41P071@D00`82
00<40P0200T;1`06010C3@0R9QT0:2hM02T`800Z<R40:S<Q3oooool000gooooo00H0MXN<082DVP23
Uih0Q9ZP08>GX026VJ@208FGX`0;08FGYP26VJH0RI^W08VHY@2<W:X0S9fZ08jOZ02?XZT0TJBZ08nQ
Z@2@XJX00P2@XJh02`2DY;00V:J`09NT/@2HYK<0VjNe09bZ]P2LZk@0W:Zc09j]]P2P[kL0X:fd0080
XJnb00`0Y;6b0:Na/@2Y/[40ZkBd0:bf]P2/];H0[KNg0:ff]P2^^KH0[[Vd0:nk/P2`_;420;:n/@0;
0;>m/`2b_;80/[fc0;>n/`2b_;40^<:d0;S2/`2h`K<0^L:c0;W3/02ia;400P2ja;802`2laK@0^l>d
0;c6]`2ka;H0_<Fd0;S2[P2j`jd0_LF/0;o7Z`2ob:X0`<NX0080`LRW00T0_/FV0;o7Z02oajH0`<RU
0;k8X`2kaZ40^/JN0;K1VP3Lhlh0FP3ooolJoooooe80oooo00<0eM_809BNN`1AD3X00P1GFD00301?
DC`0BD/j04I6=`10?c80>CL]030^9@0W9ah08bDL024S6P0N8AT07R0H028S6`80:2`Q00/0<CDX03Li
:`0i>bh0=SP/03Lh;@0c=2X0;c0V02`]900_<RT09bTQ01hP6@0201/M5`0;01LH500G6A<07AhG01`L
5P0K71L082<M028V7`0J7QT0>dHf05a/D01UMET00P26WGP0301[OF80EF9>04I@A@1FHe/0HgE[0767
M`1bQgD0N8ii06YmL01YO700NY5m09B^TP80RJ2500/0RIb406I_H`0X8bh0;Rdh096VTP1CG5`0@DE:
06=aI`1eRG@0Ef=F051IC002065_F@0;06MgH01TM5d0C5Y802L]9`0I71X04A0@00X82P081PP01`D5
00D40`030P800P0M8aL01P0Y<240:c8Q02`c8@0[<B<0:2`Q02L/80oooooo000=ooooo`060721R01n
TYP0PiJN08FGW`24UYh0QIRP0P26Uj402`27V:80QYRR08JGX028VJ80S9bU08bKY`2=W:X0Sin[08nO
Z02@XJX0U::/00<0UJ>^00X0UZ>^09^W/@2KYk<0VZJb09ZW/`2LZK<0W:Zb09^Y/P2LZK<0WZbc0P2R
[k@0302T/;<0Y[2a0:Rb/02[/k80[;Jf0:be^02/]KL0[;Fh0:ff]`2]^;D0/;^d0;2k/`80/;^b00/0
];fc0;Bm]02d_;D0][fe0;Ro]@2i_[@0^l6e0;_0]P2i_kD0^/:d0;S0[`020;[2[`0;0;g3/`2ma;D0
^/6d0;k5]P2na[<0_LJ`0;c6[P2nbJd0_/V[0;g7YP2ob:@00P31b:D02`2naJD0`LNX0;o6YP30aJD0
`LNU0;k8X`2laZ80^lJQ0;c7X02lb9l0`<N]0080d=;3EP3ooolJoooooe@0oooo00l0gn3I0;Zi[P2j
^Jh0T9=h09BLN`1oQ6P0GEa;04A0>00l>c80;RlU02X^8@0X;1l09bXO02PY7@0Y:1h00P0[;2@02`0e
=b`0?T4b0454=P0m@3D0=cXb030c:`0/;RP0:2XU02@V8P0V:R808RHM00807b<I00/06AdD01hP600J
6a@05QH@01/L500O8AP08RDM01lR7@0H71L092XQ02/c:00204=A?00<04AB>`14DC/0<3DX02dc9P0]
<RX0AeA605MXE01TMf00Df=A04YHC01aQg00LhUc0P1hSWL02`1lTG`0Lh9c02h]=P0d>Ch0MH]i07bC
OP12C4L0JWYX07:4KP0oASd05Q<F0080<C@^00/0KWmW04iJBP0e?SH0<3T`01`P700H71P03@l=00L9
1`072@D01@P200H80`0202Xe8@06041@=@0oC3@0<S`Y02`e900X;R009RTO3oooool000gooooo00H0
LhB<082BVP23Uj00QINQ08BFX024UZ<208>FXP0;08NKY027Vj80Qi^Q08bNY@2=WjL0SYjY08jLZ02@
Wjd0Tj>_09FR[P2FY:l00P2GY:l02`2FY:h0VJJ^09ZX[P2JZ;40W:Ze09^Y]@2MZK@0WJ^e0:2^]`2N
[K@0WJ^a0080XJna00`0X[:`0:Fc/02Z][80ZK>`0:fe/`2[/k@0[KJh0:jg^`2^^K/0[kZk0;2k^P2`
^kL20;:n^00;0;Bn]P2d_;<0];bc0;Jo^02j`k/0^[ng0;g3^@2j_kL0^[nd0;W0/`2j`k<00P2j`[40
2`2oa[@0_lFd0;k3]031akD0`LRb0;o7[P30b;00_lR_0;k8Z`2najP0`<ZW0080`L^W00/0_LNU0;o8
Z02najL0_/JW0<39Z@30bJH0_LNR0<7<Y@31bjD0_lVT0;k7XP020;g7XP030;W3X03>eK`0ko;Y05<0
oooo6_oooomH0?ooo`090>obj@38dKP0Vj:604Do>`1?CdD0@T@j03e0<`0j?bl0>d0_0080?3h`0P0i
>Rl02`0l@3<0BDln04eD@P0m@SP0>Shg03Ll=@0^<Rd0:Rd[02P[:00Z;RP0:BdU00809BTQ00/08RLM
02@W7P0O8AX061PB024T600T:1`09bXP028T700N8A/06QdH01PK5P02024W7@0<02L[800X:R009RTO
02@W700R9QX09BTM02T`8`1YOeh0C5Y203Dk;00Z;RH0D5]:0P1CGU402`1LJEl0MHMh07V?OP1IJF40
GW5R06UlJ@1]PFX0L89/06ioK@1AFU@0;2db0080CeI>00/0Ef1E05QSE`11BD406alO01`Q7@0E6Q<0
3Q4<00X<20072@D02@`700hB2P0201<I3@06041@=@19Fd00?4Pf03E0<`0[<bP08RTP3oooool000go
oooo00H0NXn>08JKW029WZ<0R9VT08FDX`26UZL208FFY`0;08JHY`27VjP0Qi^T08RKY02=WZP0SIj[
08jPZ`2=XJd0Sj:]092Q[@2CXjl00P2DY:d02`2CY:`0UjN^09VW[`2JYk00VjVc09n[]02NZ[80Wj^c
09n]/`2P[[@0XJna0080XK2a00/0Xk:d0:>c/P2U/k00Y[6_0:Zd/02^]k@0[kNf0:jg]`2_^;L0[kVg
0:jg]@030;2k]`0;0;2l]`2`^kH0/[^f0;Fm^02h`;/0][bh0;No^P2k`K/0^l:h0;W2]P2i`K@00P2j
`k<02`2ka;<0_/Fe0<37]`2la;80_LB`0<79/P30ak00_lN_0;_5Z`2kaJX0_lRZ0080_/VY00/0_<NX
0;g6Z02maJL0_/NX0<7:Z@31bjP0`L^V0<;<Z031bjH0`<ZV0;k7X`020<39Y@060;o8Y`2najL0_LJV
0;[5Y03Gg<`0i^SQD03ooolJoooooe/0oooo00P0cM3209VJS@2<Tg`0N7eX06U_FP1UJED0Gf9@05YM
C@80CU5400/0Addo04I8?014AcX0@4<h03`m=P0h>CH0=SPe03Dh=00f>3H0<C@b02hb;@0202lc;@0;
02db:`0[<2T08RDN01/K5`0L71P0828J02<V6`0P8Q/071hH01HH4`0Q8a`00P0`=BX0300^<RL0:BdS
020P6P0N7QL071hE01hT600L8AD0:2lN038k9`0e?BP0<3HS02P]7P808bDL00/08R@P030d;`1RLUl0
AU5803i8@@18DTP0GFaJ06IhIP1YO6d0JWa]06=aI@0206YhJP0;05ELEP16CDX0Cea?01/P7P0H7AX0
3Q8=00/>1`092`@02PX6018C3`0A4Pl00P0>3`l01P0D5aH061dI01lU7P0g@S@0<cda02P_9`oooooo
000=ooooo`0607f@TP24UYh0QiVS08NFY027TjL0RIJ/0P29VJh02`27VZ`0RIfY08RMY029W:<0RYjT
08ZNY`2<WjP0SJ6Y08jQZP2AXZ`0TJ:^0080TZ>]00/0TZB/09JX[`2GYZh0VZN_09ZW/@2IY[00WJZb
09j[/@2P[;80XJba09nZ[`020:6_/@0<0:Bb]02U/[@0Y;:d0:F`/P2X/[80ZkBe0:bd]P2]][H0[[Rf
0:bf]@2[]K@0[[Rf0P2a_;X02`2`^kT0/;^h0;6j]`2c_KX0/kbi0;Fm^@2f_[T0^/2i0;_2^@2j_kH0
^[jh0080^l2h00/0^l6h0;_2^02i`KL0^/:f0;_4/`2mak<0_LJa0;k8/@2nb:l0_/J]0;o7[P020;o6
[@0;0;o7[P2oajl0`LV`0<36[@2n`j/0`<JZ0<39ZP31c:P0`L^W0<39Z02nb:L00P2ob:T0202najX0
_lRZ0<38Z@2maJP0^lBW0;JoY02h`JH0g>7CCP3ooolJoooooeh0oooo00D0dMK90:J`TP28SWD0OH9Z
06EXE@0205QKC00;05=EA`1;Bd40B4Pm0492>010@3P0?C`e04eAA01=DdP0B4i40455?00g>S800P0b
=Rh02`0]<BT0;30Y02LZ9@0P8a`071dF024T6P0T:1`08bHK01hQ5`0J6a@09RPQ0080:bhV00`0:blU
02X/8`0W:2408B8L020R6P0K7QD06adC01@D2`0H60h071hB02<U5`0P8QD201TJ400;01HH4@0E5A40
>D4c05=QCP0P92809B`X02D[:`0_>C@0DV9D065cH01TMF800P1SLV<02`1OL680=3hj03U6>`0gA3D0
6R0I014E400B5Pl04Q<<018@300B40h04@h>00803@X<00H030T;00/92`0;2@`05aLG01dN700V:R@?
ooooo`003Oooool01P22TID0QYFP08VHZ027UjX0R9J/08JE[080Pi:Y00/0PiFY08NKZ@29WJP0RYjW
08bOZ@2=X:X0SZ6[08jR[02BXjd0TJ2[09BR[P0209BS/00;09JV/P2EYJh0VZR_09VW[@2KYjd0VJF^
09NT[@2LZK00WZ^a0:6//@2R[[<00P2Q[[40302S/K<0Xk2`0:B`/P2V[k80Yjnb0:Vb]02Z];@0Z[>c
0:jh]P2`^[/0[kRj0:jg^080[KNg00L0[[Vi0;6j^`2c_;`0]Kbl0;Fl_@2g_;d0^;fl0080^knm00/0
_<2l0;^o^P2l`K/0_<6k0;[0^P2la;`0_<Bj0;_4]`2i`k80^lFc0;c5/P020;g7/`080<38]P31b;D0
`<Jd0<36]02oa[@0_/Fb0<77/P33b;820<?7/0050<77[033bZd0`LNY0<;:[032bZh00P31bJl02`30
b:d0`<R/0;o6ZP31bJ`0`<N/0;g5ZP2k`ZP0^lBX0;S3YP38d;T0emg?04/0oooo6_oooomP0?ooo`03
0>[]i03>e<D0UJ230080LgMQ00/0Kg=M06=SEP1GEDh0CTe704Y:A012@S/0FVAA06QhG`1YNUh0I79F
03<e:00202`/8`0;02LV7`0R8Qd08b<Q02<S8@0R8b409RPS02HY8P0R9b807R8O020S8@0g?cH00P0h
?cD0300_<bX0;2hU02LY800X:1l0:RdS02DW7P0K71@05AD;014@1P0J6`d0820@01XI30804Q0800/0
3Pd800d<200J71D0EFA<02T`9`0X<2X07bDS01XP7P0G6aX0;3LZ03I1;P0202dc900;03Hn;P10C3X0
D61;04MD?`0=3PT05QPB01/N5`0H6aD06a`G01LF500A3Q400P0;1Pd01P0<1`h02`D;00d63@0=2140
3PXB01/L7@oooooo000=ooooo`0607j?U@24UJ40QYRW08BEZP23UJ`0Q9F[0P23UZX02`25V:T0QYbZ
08JLZ028VjP0RifZ08jO[02BXjl0TJ2]09:P[@2DXJd0UjBa0080VJBc00/0V:Fc09RV/`2HZ;00VZR_
09ZX[P2N[;40W:R`09^X[`2MZ[00X:fb0:2^/P0209n//P0<0:2]/`2S/;D0Y;2e0:Na]P2X/[D0Z[>g
0:^e]`2Z][D0[KRf0:fg]`2`^;X0/K^n0P2`^[`02`2_^[L0/Kbh0;Fl^`2g_K`0]k^k0;Zn_P2k_l40
_L730;c0``2l`<40_<300080_<2o00L0^[nl0;_2_@2j`[/0_LJj0;o8^@2naKH0_/Fe0080`<Jg00l0
_lFf0<36]`31b;P0`LRh0<79^@2ob;P0`<Rg0<78]P33b;@0aLVd0<?8/@35bZl0`/R]0<;9[`33bK40
0P33bk403033bk80`LR_0<79[@31bZd0`LV^0<79/030bJl0_/N/0;k9[@2laj/0^lNZ0;O3YP80a/ni
00<0k>oX0?ooo`3oool0A@3ooolJooooof<0oooo0P3Zk>D02`2e^jP0WjN>06a[H@1OGeP0F5Q@05=D
BP15ASd0AT/m059LAP15CSd0=3T]0080;S@X00H0:RhU02<T7`0Q8R008b<S02X]:P0[<2`202/`;@03
02<W9`0U:BX0BeM<0080@Ti400<0=T0g038j<00a=b`00P0_=2X01`0T9R006QXG014?3@0B4PT06AX>
01hO4@0M7a800P0F5`d02`0A40/030/900/:2@0G61<06A`H01PK600D61L04aPF01@J5`0L8a`072<G
00806R4B00/06Ah?01HJ3P0U:AX0:BdN01hP5P0T:1`08RHM024T6`0f?2d0:blT02HX8@02020O7@06
020L700L5aP0618E01<<4`0@2Q@04`lG3oooool000gooooo00H0NXfD08:EX@27VjT0QYRY08>DZ`22
TjX208BFZP0:08JHZ`26VJ`0R9^]08ZM[`2=WJl0SZ2`096R[`2BXJh0UJ6_09BO[`<0UZ:a00/0UZ>a
09VW/P2HYZl0VJN_09^X[`2N[;40W:Z`0:2]/P2NZ[40XZfd0:>_]P020:Ja]`0<0:>_]`2T[k/0YK2m
0:Fa^P2T[kL0Y[:h0:Nc^02Y][T0ZkRj0:bg^02_^KX0[KJj0P2`^Kh02`2`^K`0/K^l0;Bk_@2f^kh0
][Zm0;Nl_P2h_/40^ko20;g2`P2k`L00^l;00080^/6n00/0^/6l0;g3_02l`[T0_lJi0<;:^P2maKD0
_/Bc0;k5/`2ma;80_/Jd0;k4]P020<37^00;0<38^@31bKT0`LVf0;k6/`31ak<0aLRb0<G9[`34aj`0
a<R/0<G9/034b;400P35bK<03034bK80`lV`0<;9[P33bJd0a<V^0<?8[P33bJl0_/F^0;g4[@2oajh0
_/J/0;g6ZP80^lFZ00@0^/BX0;W3YP3KhM80k>oXA03ooolJooooofL0oooo00T0eM[>0::UVP1WIel0
IfUN059BBP1=CTH0B4To03m2>00h?C<00P0_<Rd02`0Y:bL09bTV028T8`0W:bP0;C8/034g;`0_=2`0
;S8Z02d^:P0];B`0=3Ld0080=3Te00`0<cTa038i<00a>Bh0<c``02lg;P0U:bD08R@R01`L6P0I6QH0
71lG01lT600K7a@201LL4@0;010C300A5@/03a4801<D3@0G6Q806AdH01DI5P0A5A404QH@01LM500G
71000P0E6Ph201HI3P0901<E300I6a<06AdE01`Q6@0I7AP06QdH02D[7`0d>bP0=3/U0080:B`I00H0
=3DQ03/j:@0_:b40;2TR02LU8P0N7A`?ooooo`003Oooool01P1jSI@0PYFQ08NKZ@26V:T0PiB[08:C
ZP80Q9JZ00X0QYR[08JI[028Vjd0RYf_08fM[`2>X;00TJ:_09:Q[P2EXJl0U9n_0`2FX[402`2FXk40
VJNb09RV[`2IYjl0VjR_09j//@2LZ[00X:fb09jZ/@2R[K@0Xjnf0080Y[6g00`0Xjng0:B_^`2U/;d0
YK6j0:B_]`2V/[P0Yk>h0:Vf^@2[^;X0[;Nh0:ni^P2]][X20;2i_P0;0;2i_02a^k`0];^m0;Jk_P2f
^[d0]kbn0;Rn`@2k_l80_L;20;_1`02k`/000P2j`Kh02`2j`K`0_L>l0;c2^@2oa[T0`/Zj0;g5]@2n
a;<0_/Fc0;g4/P2na[@0_/Bf0080`<Nh00/0`<Ri0<79^@31bKH0_/Jc0<77/`35b;80aLV_0<C7[034
b:`0aLV`0<C8/@020<G9/`0<0<C9/P33bK00`/V^0<?9[@34bJh0`lR^0<?9[`2naJh0_LB]0;o7[P2n
aZ`0_LJZ0P2kaJX0102ja:P0^L>V0=_QdP3/knQ40?oooa[oooooI`3oool02@3Ef/h0XZFJ06MWG`1W
JEh0DU9:04e>AP18BCl0?d8h03Pm<`0202lb;@0;02T[9`0W:BH08R@S02L[:00]<R`0<CL_02ld;00^
<RX0;BhZ02d];00d=c@00P0d>CD0300c>C40<ST`034i;P0c?300;cL^02D[9@0R928071`J01TJ5P0L
7aL07b@H01/O50805a`A00/041<<014E2`0?4@P04a@=01LJ4P0I7AP05ATF014E4@0B5Q005adD01LL
400201DJ3P805QT>00T04aD<01TK4`0I7AD0724I01TM600J7AP09B/O03@k:00d>bD00P0Y;1T01P0d
=B40>cXY02l[8@0/:B809bDR01hM70oooooo000=ooooo`0607f>T@21Ti/0QIRS08JGY`23U:H0R9RZ
0P28UjX02`29VJh0QIJ^08JG[P28VK00RYbb08bN[`2AXk00TZ>_09:P[P2DXK00U::b0080U:>a00/0
UJBb09NU/`2KZ;D0WJVf09f[]`2KZ;D0W:Zd0:2//P2Q[;80XZfc0:>^]0020:>^]P0<0:>]]`2R[;T0
Y:jm0:B__@2U/;`0Y[6l0:Re_@2W];`0ZKBm0:be_@2]]Kd0[[Jn0P2]]Kh02`2`^<40/KS00;>i_P2e
_;l0]Kc00;Ro`P2f_/80^<310;Bl_@2f`;l0^/?10080^L:o00/0^<2m0;g4_P2i_kT0^knh0;k4^02n
aKL0_lRh0<78]P2oaK@0`<Nf0;k4]P020;o6]`0;0<38^031b;X0`LRj0<;9]P34bK80a<V`0<G:[`35
bJd0a/^^0<?7[@35b;400P36b[D03035bKD0a/Vd0<G9/@34b:l0aLV_0<K9/@36b[<0`lRc0<;8]030
a[40`<R`0;o6[@80_/BY00H0_/NY0;k7Y`2jaZH0]/>V0:RbVP3GgM120?oooa[oooooJP3oool01P3<
dLD0PhYg06Y]H01QHeL0D55704U:@080>CTd00/0=3<`030^;P0Z:b/0:BTZ02X]:`0_<bl0<3@^02lc
;00a=2/0<S@[02/[9@0202TY900<02DX8P0W:R<0;C4W034h;00/<BP0:c0X02T^:00S9R809b`T02`d
:00S:b40728I0P0E6A802`0A50h03A0;00`?2P0D61805Q/D01XO6@0F6aD04QHA014F3`0F71805AT?
00804QH<00/041<;00hB2P0>4PX03A08010C2`0E5Q004a@?01`P600R9a/0:2hM02``6P0201dM2@06
03Hg7`0Q6a80=C8[02TU900_<b/0<SX_3oooool000gooooo00H0NXb?08:CV`23UJ40QIJV08FFY@27
UZH208VIY`0;08NGZ025UZX0QYV[08VL[P2:WJl0Rin]08bO[@2=X:d0Sj6^092P[P2AX;800P2AX;40
2`2AXK40V:Jd09ZW]@2IYKD0VZFf09ZU^02MZ[P0WZbf0:2/]@2Q[K@0X:ff0080X:jf00H0XZne0:>_
^02V/Kd0Y[2m0:Fa_P2U/Kl20:Jb_`040:Zc`02/]Kl0[kO00:ng`080/[W200/0/;O20;:j``2`^L00
/kg10;Fo`P2f_/80]Ko10;Jo`02h`Kl0][jl0;Bl^P020;Jn_00;0;Fn^`2h`Kd0^L6k0;_2^@2na;T0
_/>i0<36_@31a[h0_/>j0;o3^@2na;X00P2n`kT02`31ak/0`<Jj0<35^P33bKT0al^i0<C:/`32b;00
aLb_0<G:[036bZh0aLVa00<0aLRb00/0`/Jb0<K:]033ak80`lJb0<;6/@34ak40`lFb0<G9]P32a[<0
`/J`0<75[P020<36[0090;o6Z@30b:T0_LFY0;_4ZP2i`jT0]L2W0;>oZ035c[d0c=7803l0oooo6_oo
oom/0?ooo`040>[^i`2m_kT0OhIi06Y]I080BTM600/0BTQ503/g>00e<C80<bl_034];@0_:bd0<2h^
02d[:P0/:bL0;c0Z02`]9P0202LX8P0<02DV800R9Al08bHO028U7P0T9R0092XS02P_9P0U;2@09c0V
03Q5<@0U;Ql06b8G0P0C5a802`0A4Pl0418=010C3@0D5a006QhF01/O600J81H061hB01TP500M91H0
6AlB008061dA00/04AH>00lC3P0?5@l03A8;00P;100;3@H02``600d=1@0?3`L05AD;01dN4P0201XH
3`0604aC>`0A3@/0Ig5M05eZE@0@4Q007R@L3oooool000gooooo00H0N8ZB08>GX026VJL0Q9NW08FG
Z025UjH208JFYP0;08JHZ024UZX0QiZ/08RMZ`29WJ/0RIj/08ZN[02:W:X0RijZ08fN[02@X;400P2A
X;<02@2CX[H0UZ>f09RV]P2KZ;L0VJFe09^W]`2LZKL0W:^f09f[]P0209j]]`80X:jh00`0XZjh0:Jb
^P2W/[/0Y[6k0:F`^P2V/Kd0YK:m0:Nc_@2Y/kh0Z[:n0:ff`02^]kl20:jg_P090:jf_P2_^L00[[Rn
0:nh_`2`^L00/K[00;>k`02d^[h0]Kbo0080][jo0P2f_[h02`2f_Kd0^<2k0;W1^`2k`KX0^kni0;^o
^P2n`kd0_lBn0<36_P31b;h0`<Nn0080_/>m00/0_L>k0<36_02oaKT0_lFf0;g2/@30a[80`<Nb0<38
/033bJl0`lN_0<C7/@020<75/@0<0<?7/`31ak<0`/Vd0<?8/`31ak<0`/Jb0<C9]031a[<0a<Vf0<?6
]031a;40`/Fa0P30aK402`2naJd0_/F/0;g4ZP2najh0_<N]0;K1Z02e`:T0][nY0;FoZ02c_jH0_lNg
0080j^cW>`3ooolJooooofl0oooo00h0in[T09fPUP2MX9H0Nh5_05MHBP1BDT<0BdTk04@o=@0o>C<0
?cXc02hY:00^:RL0;BPU02/W90809R<P00`09RDQ02P/900U:b8082HL01lV700S:Ql08BTO028[7P0T
;Qd08blM02@^7@0N9AH201PO4P0;01LL400E6@h05AP>01TL4@0H71006alD01`Q5P0I7a@06b4H01dT
6@0M8aP00P0L8aP02`0B6a403A<=00lE3`0<4P`02Ph600T<10092PD020P400X81`091`D02PX50080
2@/300H03A0401HJ2`0K80l08bTE024W500I70h?ooooo`003Oooool0101oTiT0PiJP08JJYP25V:P2
08NJZ`80PiFX00/0QIV[08JJZP26VZT0QYVW08NKZ02:Wj`0S:2]08jR[`2?XZl0TJ>a096Q/P0209>Q
]@0;09FQ]`2EX[H0UZ>e09RU]@2LZ;X0VZNh09^Z]`2L[;H0WZff0::_]`2R[[H00P2S[kT0102T[kX0
YJnk0:Rc^`2Y];/20:Rd^`060:Rd_02W/[`0[;Fo0:bd_P2]][l0[;K30P2/]/802`2]]kl0[KNn0:ni
`02a^L80/[W00;6h_`2d^l00]K_00;Jl`@2f_/80];k10080];k000/0][g00;[2`P2j`<00^kno0;c1
_`2l`Kd0_L>m0;c3_02k`k`0^lBl0;W1_0020;k4`00;0;k4_P2m`kd0_<:l0;o4_02oaKP0_/Be0;g3
]@30a[H0`<Ja0<;:/`31b;400P30ak403032b;<0`lNc0<;7/`34bK@0a/Zf0<G9]P31a[@0`/Jd0<C8
]@34akH0`/Jd0<76]080_lFb00H0`LN`0;o6/02oaZl0_/J^0;k7[P2maZd30;_2Z`070;[2[02e_JT0
]KjZ0;FnZP2a_J@0e=W>0>KWh`0h0?oooa[oooooL`3oool02P34b;`0V9Z=06Y[G01GEDT0DTm204]8
?@14@SL0>cT_03<b:P0Z:2<202@R7P0<02<S7`0Q8b008RLQ024X7P0M91T06AlE01TO500Q:A/06R4B
01`R4@0O9a@07bDE0P0O91H02`0N8aL0728G01XP5`0I7QD05QTA01TL500K7aD07B<G01lV6@0N9QT0
72HH00806RDH00/0628E01DO400A6Pd03aD:00dC1`0<40D03A0700`=1@0;2PD020P400L9100200L:
0`0600L:0@0<3`804A@601PK2P0B4`D03@d33oooool000gooooo00H0NXbG08>FX@25VJP0QIR]08JH
[@26VZh208JJ[@0;08RM[025VZP0RIf[08VM[@29WJ/0Rj2/08jS[@2@Y;00Sj>_092S/@2CXk@00P2D
Y;L02`2DY;P0U:Bf09NW]P2GYkD0VZVh09b[^@2M[;L0Wjjh09n^]`2S/;P0Y[>j0080Y[2k00`0Y:jj
0:Na_02Y];d0ZKBk0:Zf_@2[]/00ZkO00:Zg_`2[^L00[;W00:fk`P2Z][l20:fia00;0:nja02^^/80
[kS00;:j``2c^L40];W00;Fk`P2f_<80^L350;Nma@2g_/D00P2i`/L02`2i`L@0_<C40;W2`02h`<00
^<2n0;[2_@2ka;d0^lBl0;_4^P2k`k`0_LBm0080_lO000/0`<G20<76`P31a/80`lS50;o4_`31akd0
`lZn0<;9_P31b;T0`lbj0<?;]P020<C<]@0<0<G=]P34c;D0`lZe0<;:]P32b;L0`lVj0<78^@32bKT0
`/Rh0<;9^@2oaKL0`LJg0P30a[H02033b;D0`lVe0<;8]@31b;H0`<Jc0<;8/P32b;40`LNa0P2oaZl0
202na:h0_LFa0;g5/@2k`k00]kn]0;BlZP2Z/il0dmW?=P3ooolJooooogH0oooo00L0_;jf06a]H01K
GDh0DEA404Y;?P0n?cL0=cLb0080=CD_00`0<S4/02`/:P0V:2L08bHU01lS8@0L8Ad06AhH01dS6P0J
81L06R0D020V6@0S:Qd2028X708082LM00T08RTO01lV6`0L8aL07bLG028[5`0S;1P09c0J024[5@0R
;1D00P0O:AD02`0O9aL072<D01`S4`0K8Q005Q`=01PL3@0D5P/04a<901@F300A4P`03@l9008030l8
00H0314700`@1P0<40L04QD:010A2@0<2PD?ooooo`003Oooool01P1hRYH0P9:R08BFZP24UZd0PiF^
08NJ/@80QIV/00/0QYRY08FHY`27VJP0S9j/08bNZ`2<WjX0SZ:[09:T/02AXk00Sin`08nO/P0208nP
/`05096S]02CY;<0UJJb09RX]02HYk800P2KZkH0102L[;D0Wjfe0:6_]`2R[kX20:J`^`0<0::/]`2U
/;T0Z;:k0:Vc^`2Z]K`0Z[Fm0:bf_`2/]/00ZkS10:bi_`2Z]k`0Z[Nm0P2]]kl02`2a^L40/[[30;Bk
a02e^/<0];[30;Fk``2g_<<0]k[20;Rka02f^/<0^;c400<0^/3300X0^l720;_0`02k`L00^l710;_2
`@2laL40_LG00;[2^P2oaK/0_L:i0P30aKd02`2oa;d0_l>m0;o3_`30aL40_lBo0<?7_P31a[`0`<Fj
0<78^P30akH0`LRe0080a<Vd00`0aLVf0<K;^@33b;P0`/Rh0<77^P31ak`0`LVm0<78_031b;X0`lZj
0<77^031akH20<?7/`080<C8/`35bKH0aLRg0<?7^033akL0a<Re0<;6/P31ak820<36/00;0;o4/@2n
a;<0_/Bc0;c2/@2k`K00^;j^0;Jl[P2e_Jd0Z;2P0;Rn/P36bL@0<`3ooolJooooogP0oooo00D0g]oL
0;Nj]01VIf<0Cdi<04Q9A@020494?00<03/l<`0b<B`0:bTY02DS9`0Q82<071dP01hQ8@0L8Ad05aXG
01<E4P0B5Q8051PC0P0F6aD02`0E6a<05a`D01TN5@0I7a@06b8F01PP400G7Pd06R4?01`T400K8`l0
6b8?00806Al=00/06B0>01TP3`0H7P`05ah;01XQ3P0J7`h06A/?01HF3@0E5Pd0418;00h@2`0200/>
300600`?300=4@`0310;00d?300>3P`02`X83oooool000gooooo00H0NH^F086BXP26UZP0QYJ]082A
ZP21TZX2082DYP0;08>FYP26VJD0RI^V08VIY`29VZP0RI^Y08ZMZ`2=WZ`0Sij]09>P/02?WK000P2@
Wk802`2@XK<0TjFd09FW/P2EYK00V:Nd09RW]`2GYkD0Vj^f09n]]`2P[KP0X:^g0080XJ^h00P0XJ^g
0:B_^02V/;T0Z;2j0:Va^P2X/K`0Yk6n0:Na_@80Z[Fo00l0ZkJo0:fh_`2^]kd0[[Nm0;6g_@2a^;`0
/kW10;Bj`P2c^L40];[20;Jk`P2g_L00^;g30;Jk`P2e^l000P2e^kh02`2g_Kl0^<2o0;S0_P2i`;l0
]kjm0;Nn_P2j`L40^[fn0;Zn_02k_k/0_<6k0080_L:k00/0_/>m0<35_`2o`kl0`L>n0<?5_`32aKd0
`L>k0<?6_@31a[/0`LNh0<;7]P020<;6/`0<0<?8]@33bKH0`<Nd0<78^02na;P0_/>j0;k3^@30b;T0
`LNi0;o5]`30akL0_lFe0P2oaK801@33b;80`lJ`0<;4/@32a[80`LJa0080`LF`00@0`<Fb0;c2/02m
`[40^Kj_0P2h_Jh02`2l`K40^/2a0;[0/P2i_[80^;f`0;Jj[02c^:X0/KNZ0:2VV@2d^jl0in[U0300
oooo6_oooomk0?ooo`0:0>3QgP2HW940LGUT075iI00n?3@0?3Tf038/<00W7bP08A/U01lK9080820U
00@07AhR01@E6@0?4AD03a4C0P0=3`h02`0;3@P041@<010E2`0=4`T03QD;00hD1`0B6PT051/801DN
2@0C6PD04QT200805ah500/06R0801HJ1`0C5PD041<3018E1`0C50T04Q@:014B3@0A51003@l=00X<
2`0200L81`0600/=2P0>4@d030h=00`?3@0>40`030/93oooool000gooooo00H0MHZB07jBW@22U:<0
Pi>W08:CZP1oT:T2082DZP0;07nDY`24UjH0Q9NW08NIZ`28VJ`0QiZ[08RLZ`2:VjX0S9bY08jN[@2?
WJh00P2AX;80102>W[40Sj2d09:S]@2BX;<209JT]@0509NU]02JZ;H0WJ^h09n[]`2PZ[P00P2QZ[T0
302RZkT0XZbg0::/]02V[KD0Z:nh0:Va^`2Y/kh0Z[C00:^d`@2/]<@0Z[;10:bd`P80[KC300<0/[S3
0;2g_`2c^L400P2c^L801P2d^/<0];W10;Fj`@2h_LD0^;c60;Jka080];S000/0];W10;Fk`@2f_<40
]Kc00;Fm`02f_;l0]k^n0;Zm`02l`<80^Kbm0;Zm_0020;bo_P0;0;k1_P2o`/40_ko10;no`02o_kl0
`/700<2o_`31`[l0`<:o0;k1_@30aKh00P33akd00`31ak`0`LJl0;k3^@020;k4^@070;k3^02o`kH0
`<Ff0<C6^033aKP0`LFf0;o3]0020;o5/`0;0;o5/P34ak<0`lBc0<73]031aKP0_/:e0;g3]@2k`K@0
^/2d0;k4]@2k`;800P2j_[402`2j_k40^knc0;_1]@2h_;80^;ba0;Jk[`2d^Zh0];^`0;6i/02^]Z/0
ZkBX0080Yk>R00<0d]O@0=OFf03oool0:`3ooolJooooogl0oooo00`0/;2^07=]M019@Th0;bLh02PP
<00R6bT081XT01`G800G51d05a@L01@E6P0@4aD200lC4@0;014E400A5Pl041D>00dC300:40T01`d6
014J3@0G8@d04ad801DM1P0D7@<00P0F7`D02`0H7`L051P501DG1P0B4`H04aD7010?1`0@40X04a<=
01<D3`0@4P`030l:00802`h800H02Ph8014E3`0<3Pd030h=00l@3`0?3``?ooooo`003Oooool01P1h
SY<0O9:K08:FX@22UJ@0P9:U082BZ080P9>Y00/0PiJ[08>FZP25UjX0R9V^08bM/P2;Vk40SIna08^K
[@2=Vjh0Sij`096N/00209:P/@0;09>Q]02EXkH0UJBg09NU]P2EXk@0UJBd09JS]02JYkP0WJZi09n/
^P2PZkX00P2PZ;/0302SZK/0Y:Zi0:F[^@2TZ[H0Z[2k0:bd_`2///40Zk;00:^c`P2]]L<0[KC20:fc
a@80/KK700/0[kG50;6fa02c^<<0];S30;Bga02d^<@0]KW30;Nj``2f^<40^Kg60;Jla@020;Fj``0;
0;Jla@2d^<80]k_30;RnaP2i`<P0][c40;Nm``2g_L40^[o20;c0``2k`<400P2l`;l02`2m_kd0_l2o
0<71`P30`<80`<330<;0`P32`L@0`L330<;1``31`L40_l300080`<?200`0`LC20<35`02m`[d0_/>m
0;k3^@31`kT0`<:g0<73]`33a;L0a<Jh0<?5]P32aKD20<?6]P060<;4]@33aKH0`lFe0<;3]`31`[X0
_L2k0P2m`[/00`2l`KP0^l6f0;_0/`020;c1]00;0;[0/P2j`;00^Kn_0;[0/P2i_[40^;fa0;Fj[`2d
^[00]KZa0;>i/02`]jd00P2^]j`0102^]jl0TYNG096IU@2LVJ8Z0?oooa[oooooPP3oool02@2CSY/0
=S4n03Ha=`0/92P08aXO01hG6`0M6AX06ALH01PI6P0201PI6@0;01HI5`0A51<051PF00h@400;3@d0
2`d<00dA300C6@d051/<01DN3@0A6`T00P0@6@H02`0C6PL05Qh:01DK2P0F70h061X?01HF2`0D50`0
4a<;01<C300D5@`03a8800803Q4800<03Q0700lB2`0A4`h00P0B4a400`0A4Pooooooooooo`0=oooo
o`003Oooool01P1eQi@0P9BP086EX`23UjL0Oi>S082BX`80P96U00/0PiFX08BDZP23U:/0QiJ^08VG
/029V:l0S9Z`08bL/@2<Vk00SYZ`092J/@0209:M/`0;09FQ]02GXkH0UZ6e09NS]P2GY;D0VJNe09ZV
]@2KYkL0VjNf09^U]P2MZ;T00P2MYKT0302RYk/0YJVm0:JY_02WZKh0ZJbo0:^^`02//<80[K730;2f
a02_]/<0[kG30;2faP80/[O700@0/;C40;6e``2a]L80/kO20P2d]l001@2e^<80];O00;Fi`02e^L40
][[10080];W100H0][_20;Vl``2g^L40^Kc30;Zna02j_L<20;Vk`P030;Vl_`2j_[l0_;nn0080_<6l
00/0_<6k0;k2^`2n`[X0_l2k0;jn^`2k^KL0`<2l0<70_P30_kd0_kjm0<30_P020<31`@0<0;o0_`2m
`;h0_L6l0;g1^P2n`kP0_<2d0<32]P32`[H0`L:f0<31]P30`kH0`<Be0P31`k<02`30`[40`<6`0;o0
[P2n_k00_l2c0;fo]@2j_[L0^/6h0;_2^02m`kL0^l6b0080^kna00/0^[n_0;Zo[@2j`:`0^l:^0;_0
[02k`:d0^Kj_0;Rl/02g^jl0]KZ/0;BhZ`020;:g[@070:ng[@2/]ZX0Z[BW096IS@1LG5P0QH=m09B>
T00W0?oooa[oooooQ03oool01`3?cLd0ViJF034W:00Z828091/N01hG6@0L5QP00P0L61P02`0K61P0
61@G01@@500E4QD04a0B00d:300B4a4061`G01TN5@0F71405QhA00805A`>00/05ah=01DL2`0E6`d0
5A/>01DJ3`0D6@d051H=018D3@0A4`h04aH>01@G300200lC1P0600/=0`0<30@03`l800h=200=3@P0
3Ph83oooool000gooooo00H0MHJB07^>WP1nT:<0OY2V07f?Y@1lSZ<207n@Y`0;082BZ022U:X0PiB]
08JG[`28Uk00R9Ja08fL]02<W;80SYfe08nM]@2AW[D00P2BW[H02`2BX;L0UJ:h09JR^02HXkX0UZ:i
09VT^@2JYkP0VZNg09RT]02KYkL0WJRi0080X:Vl00@0XJZn0:B[_`2VZ[l0Z:g20P2VZ/401P2X[<40
ZJk20:Z``P2Z/L80[;C40:jea080[kG500/0/;O70:nga02_]l80[kS20;6j``2b^/80/[W10;:h`@2b
^<00];_10;Bk`0020;>i`@0;0;Fla02g_<<0^;W30;Vj``2j^l@0^K[20;Zl``2h^/00^Kbo0;Zo`02j
`Kl00P2j`K/01@2j_kT0^l6j0;_1^@2m`kT0^l2j0080_L6l00@0_/>o0;c1_02m_k/0_L6m0P2n`/00
302m`l40_L?00;g3_P2j_kT0_<6j0;k4^P30a;X0`<:j0<71^`32a;d0_;ni0;k3^P80_L:g00/0`<Ff
0<74]@2o`[<0_/:d0;g0]P2n`[/0_/Bm0;[0^`2i`KP0^L:h0;Ro]P020;Vn]P0;0;Rk]02g^[40][Z`
0;Rm[`2h_Zl0]k^^0;Nl/@2g_K<0]K^a0;Bj[`2d^Jl00P2c^;402P2b^;40[kJ_0:bdZ`2]]jP0Z;:R
09:IR@0a9B/0>S4b09VEU@3;bLXT0?oooa[oooooQ`3oool0102GTY<0GeQH02DL700T7Ah2020K700;
01dH600J51D0618D01LD5`0F51@040l>00h?2`0C5Pd05a`@01XQ4`0L91@00P0L9A<00`0L8a405ah>
01HK3`0201DK3`0601@I3P0A5@d03Q4:010D3P0B5Q004AH;0P0@50T01P0?4`L0414600h@100>3P<0
4Q@8010D20oooooo000=ooooo`0607Z;V020TZ<0P9>Y082BZP1nSjT0O8fV0P21U:T02`21TjP0PYBX
08:CZP26UJd0QYB]08ZH[`2;V[00R9N]08bJ/@2?W;<0TIne00<0T9ne00P0T:2f09>R^02DXKT0U:6h
09BR^02FXKP0UjBg09RU]P80VjNh0P2JYKT0302LY[X0XJZm0::Z_02UZkd0YZc00:J/`P2W[<40YZ_0
0:R_`P2X/<80ZK720:^ca080[[G600/0[;?40:bda02/]<40[kW50;:kaP2b^l@0/KVo0;>j_`2d^/00
];_00;>j`0020;6j`00;0;:i_`2c^/<0];[30;Jka02g_<@0][_30;Rk``2i_L@0][c20;Bk_P2h`<00
0P2g_[`02`2f_K/0][fj0;Nn^`2g_k`0]kjl0;Vm_02j_kd0^[nn0;_1_P2k_kd0^l2m0080^l3000`0
_<;30;[1`P2j`kl0^<6l0;W0^`2j`;X0^l2k0;^n^`2o`;l0_Kk00;bo`P2k_l020;^o_@0;0;^o^P2j
_[P0^[jh0;^o^02k_k`0^l2l0;_2_P2k`[l0^l:n0;S1^P2h_[T00`2i_KP02P2i_[P0^;jg0;Nn]02g
_[@0]Kbb0;Bl/P2e_[H0];be0;:i/`2b^K820:je/@0<0:be/02[]:l0ZK>/0:RbZP2W/JP0ZKBW075b
K`1=BD/0>30c03D];P0a:2`0Ui>F0P39alTP0?oooa[oooooRP3oool03P2ETI<0FeEL05]EG00O6B80
8QdU02<O9P0K6B405ADJ010B4@0<3P`03Q4=018F3`0G7A@06R4F0P0N91L02`0L8AD05a`B01LL4`0E
6a@041D@00lB3@0@50h04AD?01@H4@0A5Pl03Q<:00803Q8900H03Q4900lB2P0?4`T04A@900h?1@08
2@8?ooooo`003Oooool01P1hR9T0OHjS07f>Z01oT:`0OXj[07b<Z`80OY2Y00/0PI>[082AZ@23TZT0
QiJ]08bJ/@2:V;00S9^a08bK/02=Vjl0SYba08nN]002092O]P0;09:Q]`2@X;D0Tj>g09FU^@2EXkT0
UJ:k09BP^P2EX;P0Uj:g09ZU^@2LZK/00P2IYKX0302HY;X0W:Nk09nY^`2QZKX0XjZn0:FZ`@2V[<@0
YZk60:B]a02V[/40YJk00:N_`0<0Z[;200X0ZkG30:^fa02]^<<0[;Bo0:ng`@2a^<00/kVo0;Fh_`2c
][l0/[No0P2a^L802`2`^L<0/[_50;6i`P2c^L<0/k[50;6ia@2b^<80];[20;Jka@2e_<@0][c30080
][k100/0][g00;Nn`@2j`L<0^L340;No`P2h_[l0^Kfn0;Vl_02j_k`0^knn0;Zn_@020;bm_0040;bn
_`2l`<40^Ko10;W1`080^<2m00H0^L2m0;Zn_P2j_Kl0^kjo0;c0`02j_Kh20;Zm_`0;0;Zm_@2k_kh0
^;bi0;^n^P2l_k`0^Kfl0;Rm_P2g_;d0^;fl0;Zn_02i_[P00P2h_;H02`2i_[D0][fc0;>l/@2d_[<0
]Knf0;:m]02b_;<0/Kbb0;6j/P2a^K@0];bg0080/KVc00`0[[N`0:bd[@2[/jl0Z[B_0:Vc[`2Y]:h0
Y:nX08fDS`1ACe80Ad=404A1@@0k=S/203<_=`0305aIHP2EUIT0oooo01d0oooo6_oooon=0?ooo`0;
0<K5b02OXZ80:2X`01lQ:@0J7B<051LI010B4@0>4Pl04AD@01DI4`0J7aX00P0O8ad02`0L7QP06ATC
01TJ4`0J7AP051LD01@G4`0D5a805AXA01DI4@0F6Q<04QD?00803a4<00H03a8=00lC3`0B5Q003Q4;
00P;1@061`8?ooooo`003Oooool01P1hR9T0OHjS07f>Z01oT:`0OXj[07b<Z`80OY2Y00/0PI>[082A
Z@23TZT0QiJ]08bJ/@2:V;00S9^a08bK/02=Vjl0SYba08nN]002092O]P0;09:Q]`2@X;D0Tj>g09FU
^@2EXkT0UJ:k09BP^P2EX;P0Uj:g09ZU^@2LZK/00P2IYKX0302HY;X0W:Nk09nY^`2QZKX0XjZn0:FZ
`@2V[<@0YZk60:B]a02V[/40YJk00:N_`0<0Z[;200X0ZkG30:^fa02]^<<0[;Bo0:ng`@2a^<00/kVo
0;Fh_`2c][l0/[No0P2a^L802`2`^L<0/[_50;6i`P2c^L<0/k[50;6ia@2b^<80];[20;Jka@2e_<@0
][c30080][k100/0][g00;Nn`@2j`L<0^L340;No`P2h_[l0^Kfn0;Vl_02j_k`0^knn0;Zn_@020;bm
_0040;bn_`2l`<40^Ko10;W1`080^<2m00H0^L2m0;Zn_P2j_Kl0^kjo0;c0`02j_Kh20;Zm_`0;0;Zm
_@2k_kh0^;bi0;^n^P2l_k`0^Kfl0;Rm_P2g_;d0^;fl0;Zn_02i_[P00P2h_;H02`2i_[D0][fc0;>l
/@2d_[<0]Knf0;:m]02b_;<0/Kbb0;6j/P2a^K@0];bg0080/KVc00`0[[N`0:bd[@2[/jl0Z[B_0:Vc
[`2Y]:h0Y:nX08fDS`1ACe80Ad=404A1@@0k=S/203<_=`0305aIHP2EUIT0oooo01d0oooo6_oooon=
0?ooo`0;0<K5b02OXZ80:2X`01lQ:@0J7B<051LI010B4@0>4Pl04AD@01DI4`0J7aX00P0O8ad02`0L
7QP06ATC01TJ4`0J7AP051LD01@G4`0D5a805AXA01DI4@0F6Q<04QD?00803a4<00H03a8=00lC3`0B
5Q003Q4;00P;1@061`8?ooooo`003Oooool0101dQ9/0NXVU07f>Z`1oSjh207n>[@80OXnY00/0OXjU
082AY@22TZD0QI>W08^I[P2:Ujh0QiJZ08^JZ`2@Wjl0TYj`08nK/@0208jL]@0;092N]`2@WkH0T9nd
09:P]02DX;H0UZ6i09FP^02GXKL0V::f09bV]`2IY;L00P2LY[X0302OZ;d0X:Zm09nX^P2SZK/0XZRk
0:F[_`2W[L<0Y:c30:B]`P2U[l<0Y:jo0:N``080Z;3000/0Z[?20:Zb`02[];l0[[K00:nf_`2b^<40
/KO00;:e_P2b/k`0];Fo0;Fh`@020;Bi`P0;0;:i``2c^L<0]K[40;Fha02e^LD0/kW50;6ia@2a]l00
/[S10;>i`P2d_<<00P2d^/802`2d^/00][g10;Fm`@2e_<00]KVm0;Nk^P2i_;T0^kbh0;bm^@2k_K`0
^kbk0080_;bk00`0^k^k0;Zm_P2k_l40^;bm0;Jl^@2g_[X0]kbk0;Vl_P2j_Kl0^l2o0;Zm_@2k_kl2
0;Rk^`0;0;Zk^`2k_[/0^Kfh0;Zn^02i_;L0^[bh0;Vj^@2i^kT0^Kbj0;Nj^02g^kH00P2f^[@02`2e
^[80/k^b0;6i/02b^[40/kbd0;>l/`2c_;40/kb`0;6j[P2a^Jh0/[R`0080/KV`00`0/;R`0:jf[P2[
/Z`0Z[6^0:Ra[@2X/J/0Yk:Y0:RcZP2HX9/0Ngb207b0P`1cN7X203Ph@`0502lb>00U:2d08bH[05QI
G@2?TI406`3ooolJoooooi00oooo00P0alS908n@TP0N8A`08RLL01/O5@0J6a805aP@01XK5@807A`H
00/07Q`H01dK600P81d07b0M01`N6`0K71P06A`G01<F4@0H71@05a/D01@H4`02010C4@0600`?3P0A
51<04QLD00hA3P082PL00P<23oooool000gooooo00H0M8BI07Z;Y01mSJP0Nh^Z07j=[01nSj`207f?
Z@0;07nAY`1nT:@0Oi6S08BEY026UJD0R9JY08RGZ028UZL0RYV/08^I[@29Uk000P2<V[<02`2>WK@0
Sinc096Q]02DXK@0U:2c09RQ]`2JXkX0VjFi09^U]P2JXkD0VZ:f0080VZ>i00`0WZVm09fX^`2NZK/0
X:Vk0:B[_02SZ[h0XZZo0:6Y`02RZ/80XJ[10:F]`@2U[/020:F_`00;0:Nb`@2W/;d0ZK>n0:be`02^
]l00/;S00;6g`02c]l00/kK00;Jh`@2d]/000`2c]l002P2c]l40]KS20;Nha02h^LD0];S40;>iaP2`
^<@0/K[40;6h`P2c_<<20;>k``0;0;Bl`P2d^kl0]Kg00;Jm`02g^[h0]kZl0;Rj_02j_Kh0^[bo0;Ri
_`2j^Kl00P2m_;l0302k^kd0^Kbm0;Rl_@2h_;`0]K^k0;Bj_02e_Kh0]K^n0;Jl`02g^l00^Kg00;Rm
_P80^Kbm00/0]k^l0;Jj^`2g^[T0^;bj0;Rk^02i^kP0^[Zi0;Vi^@2i^kT0][Ne0;Jh]@020;Fh]@04
0;Jk^02c^kH0/KRd0;:j]080/;Vb00D0/[^a0;2i[`2`^:d0/;J]0;6h/`020:ne]@0<0:jd/`2]];40
[;>`0:^c/02X/:h0Yk2_0:J_[02U[Z`0YJf]0:F]/02QZjh0W:ZY0P21TXl0200W:CT0:Blg02DY;`0P
92T07R<S020S6`2BTh`0b<W5603ooolJoooooi<0oooo00D0UiZA05UKD00Q8aD07b4E01`K5P0201`H
5P0;01hJ5`0P7Q/0820L020R7P0M81d07B0L01/O6`0H6aL06AhG01TO5`0E6A<00P0D61801P0@5100
30l=00`?300:30T01PL500830@oooooo000=ooooo`0607B6UP1jSJ<0O8fX07Z;Z@1mSZX0O8fX0P1m
SZP01`1mSJL0P96Z08:CZP24UZP0QINX08FFY`28UZT00P29Uj/03`28Uj/0RYR^08fJ/02=V[00Sifa
08jN/@2?W[00T9fa09BO]02GX[L0VZBh09VS]`2IX[P0W:Fj09fV_00209VS_00<09^V_02KY[/0VjNj
09nX^P2QZk/0XJZm0:2X_`2QZKl0Xj_20:J^``2U[<80Yjk30P2Z//H00`2[//D0[;?40:Za`P020:^b
`@060:je``2`]L80/KO10;6g`02`]l00[kNo0P2a^<002`2c]kl0/[Jn0;>i`@2e^L00];Ro0;:h`02b
]kl0/[Vo0:jf_@2^]kl0/;W00080/KVo00/0/[[00;>j_P2c^[`0]Kg00;Nn`@2g_<00][Zn0;Nk_`2f
^kl0];Ro0;Fg_P020;Ri_`0<0;Rk_P2g_;l0]Kbo0;Jl_P2e^kh0];Vm0;Jj_`2h^l00^Kbn0;Nk_@2h
^kh0][^m0P2d^[/02`2c^[/0/[Vi0;Bk^P2f_[`0^/2m0;Zm_02k_Kd0^[^j0;Rj^@2g^;L0];Jf0080
];Jg00/0];Rh0;>j^P2a^KP0/;^g0;2k]P2^^K@0[[Nc0:nh]02_][<0[kBa0;2g]P020:jc]@0<0:nf
]`2Z/[@0Z[:d0:Vb]02W/K<0Y[2b0:F_[P2U[Jd0XjZ/0:F^[P2P[:`0WZ^/0P2L[Z/02`1]N7h0D5MR
03PmB@0`=4009bXd02X^<@0d>SD0B55302PZ9@2EUIH0b<S901D0oooo6_oooonF0?ooo`0?09:CS`1I
F5L06aHJ01/F6P0M6A/0820M02<T7P0R9ah07bDN01hT7@0I7aT061dH01TN600J7aL06AlF00804aPB
00H03Q0<00P:20082PP01PH400D30P040`4?ooooo`003Oooool01P1fRYP0Ni2S07jAZ@1nSjT0O8fX
07f=Y`80P8nX00X0Pi6Z08BB[024Tjd0QIJ^08>EZP24UJP0QiFY08RF[@2:VJl0RYZ_0`29VZl02`2<
W;00SYjc08fL]02?W[D0T9nf09:O]@2EX[L0UjBi09JR^@2IY;`0V:Bl0080V:>l00`0VJFl09VU^P2K
YkX0WZVi0:2Z^P2QZ[/0X:Rj0:6Z_02SZl40YJc40:J/aP2U[<D20:J^a@0;0:R_a02Y/L@0ZK740:^c
a@2/]LD0Zk?30:fea02_]/<0[kK40:nga02^]kl00P2_]kd02`2a^;d0/KNl0;>i_`2b^<00/[No0;6g
_02_/k`0/KFn0;6g`02a^<40/;S10080/KW200/0/KS10;:i`@2c^l40/KVn0;:i_@2c^[h0/[Zo0;6h
_@2a^Kl0/[Zo0;Bj_`020;Jk`@0<0;Jk`P2f^l<0];[00;Bk`02e^[h0]k^o0;Ji_P2e^;`0]KVl0;Fk
_@2e^kh0][bo0P2c^KX02@2a^;L0/k^h0;Fk^P2g_;d0]k^l0;Rl_P2f_;l0];Zl0;Nl_0020;Fh^P80
];Rl00/0/KFj0;2g^P2a^;/0/;Ri0:jf]`2`^;P0/;Ri0;2f^02`][T0[kJg0:fe]0020:^c/P0<0:Zb
/@2Y/[80Yk2`0:N`/P2V/K80Yk>b0:Rc/P2T[jl0XJ^/0::^[02Q[J`0Wjf]0P2LZjX02`2JZ:L0V:JS
079jP01QIW80B4MM04Y:GP2CXid0Q92;055FF`1AFUL07AXS0080E4mG00<0SHZ?0?ooo`3oool0403o
oolJoooooiP0oooo0P35a<H02`2:R8`05A<G01DD4`0I6QD061`F01@G500E6AD05ALD01LI500E5a00
4aH<00803Q0800H020L400/:200>3@X02@L600P510081@<?ooooo`003Oooool01P1dQ9L0NhbS07j?
Z01mSjX0OHjZ07b;Z080PHjY00T0Phn[08B@[@23T:`0Pi6]086?ZP23T:T0QI>]08JC/@26UK800P28
VK@208VJ/P0;08fM/`2>W;D0S9Vf08nL^02?W;L0T9jf096O]P2DX;H0V:Bk09NS_P2HY;h00P2IYKh0
302KY[h0VZFk09^T^@2LYK`0WjRl0:6Y_02QZKl0XZVo0::/`P2QZL@0Xjc70:>/aP80Y:g400@0Xjc2
0:N`a02V[lD0Z[760P2W/<D01@2[/lL0[KC60:nfaP2_]l@0[[S10080[kVo00/0[KJk0:ng_`2^][l0
/;O00:nf_`2]]Kh0/;Fn0;6f`02b]l<0/[O10;6g`0020;>g_`0;0;:f_P2d]kl0];S00;:g_P2`^Kh0
/;Vm0;6i_`2a^;d0/KVm0;2i_02b^[h00P2f_L00302e^l00]K_20;Bi`02c^<00][W00;Bf_@2f]kh0
]KRm0;Jl_@2f^k`0]k^l0;Nj^`80]KVl00/0][bm0;Nm^`2f^kX0][Zl0;Jk_`2d^;d0]KZn0;Bi_02f
^[/0]KNk0;Fg_0020;Fh_@0;0;Bh_@2`];`0[[>k0:fd^P2^]kT0/;Vg0;:j]`2b^KL0/KNd0;2f]02/
];800P2W/:l0302Y/[40Z[>d0:Va]@2X/KD0ZK:e0:Zd]@2V/K<0Y:jb0::[[`2QZjh0XZfa0:6^/@80
Wjb_00/0WJR/09bW[02KY:/0V::X08jGWP2;U9X0SiVL09:NW02>ViP0Tj:F04a>D@0201H@7`0401/F
8`0H51d0D4eC08J5R0l0oooo6_oooonL0?ooo`090<?3a028QhP05A@C01TG5P0F5A<051@?01DF3@0F
5`d04a<;008030`700H02`X500`;1P0?3PP030X500T70`091`@?ooooo`003Oooool01P1/N940NhZU
07f<Z@1lS:X0O8^[07b<Z@80P8jZ00D0PHjY08:>ZP23SjX0PXjY08>?ZP0208FBZ`0408JC[@26U:h0
QiNb08NI/P80QYN_00/0R9Z`08bM/`2=WK<0Si^d092J/`2AVk@0TYbf09>M^@2EW[/0UYnn09NQ_P02
09VT_`0<09bV_`2KY[h0W:Fm09jX_02MY[T0XZVn0::X`02RZL40YJg50:>[a02RZ/@0Y:c50P2S[<@0
2`2U[/80YZk10:J]`@2Y[l@0Z:k30:V``P2[/l<0Zk?10:bd`02[/kh0[KFo0080[;Bm00/0[;Jn0:jg
_`2//kh0[;>n0:jd_`2`]Kl0/[O00;:g``2`]<<0/KO30;2g`P020;6f`00;0;:f_`2c]kh0][W00;2d
^`2a]Kd0];W00;Bh`02c^;h0/[Rm0;6f^`2c]kd00P2c^Kh00`2d^[h0/kRk0;>i_P020;6f_@070;>g
_@2c]Kd0]KJm0;Bf^P2e^;X0/kNi0;>g^`020;Bi_00;0;Bk_@2f_Kd0]Kfm0;Jk_@2f^K`0]KJl0;>e
_@2d][d0/kJl0;Fg_@2d][`00P2c][d02`2b]K/0/KFj0;:h^P2a^;T0[kNg0:jg/`2]][00[[J_0:je
[P2_];40[[Bb0080ZkBd00`0ZK:b0:Va/P2Z/[D0Z;2e0:R`]P2W[K@0Z:jd0:N^/`2U[K80XZZ`0::/
/`2OZ[4209fW[P0;09^U[02MYjh0WJF]09nW[P2KY:X0VJ>X09RQYP2GXJ@0UYnR08nKW027U8l00P1;
D5D01`0_;cL09BD[01dK8P0F4aX07QdP09ZJV@39b<T0303ooolJoooooil0oooo00H0U9FC05UHEP0N
7Q/05QH@01DD3P0E51<201<B4P0600h>3`0>3`h03a4=00lA2P081`<020H13oooool000gooooo00H0
L7jB07Z9X@1oSJT0Ohf/07b;Z`1kRZT207f=Y`06082@YP24TjL0PY2U08:AZ021SjP0PY6[0P24Tj`0
0`26UZh0QiN`08>C[P0208BE[`0;08JE[P26U:`0RYR^08bI[@2?VZh0SiV`092K/`2AW[L0TYff09FP
^02IX[`00P2HXK/0302IX[/0VZBh09ZT]@2LY[D0WJFg0:2W^P2PY[`0WZFm0:2X_`2RZKl0XJ[00:>/
`P80Xjg200/0Xjc00::Z_02W[[h0Yjbm0:Z`_`2X[[l0Z:nn0:Va_02Y/KT0[;>k0:Za^`020:^b_@0;
0:Za_02[/kh0[K6l0:fb_02_]Kh0[[Bn0;6f`@2`/l40[[;10:fa`02`]L400P2_]<001P2]/[h0[[Bm
0;2d_02c][d0/[Jn0;2c_@80/KFm00<0/KJm0;2d_@2c]kh00P2b]kd0302a]k`0/KJl0;2f^`2`]Kd0
[kBl0;:f_P2c]Kh0];Fm0;Bf^`2e]k`0/kJl0;>g^`80/[Nk00/0/[Rk0;6f^P2a]K/0/[Nm0;2d_02b
]K`0/[Fk0;6e^`2^];X0[K>h0:fb^0020:jd^P0;0:jb^P2]/kT0[KBg0:^c]02//k@0[[Nd0:be[`2]
]jh0Zk>_0:je/P2]];<00P2Z/k@0302W/K80Yk2a0:F^[`2W[k<0Z:bd0:JX]02WZK@0Yj^b0:JZ/P2W
ZkD0XjRd0:2X]080WZRc00/0WjR`09bU[@2LXj`0Vj>[09RQZ@2HX:T0Uj2X09ROZ02GWjP0Ti^S092M
W`0208^HUP0:08JDS01XLFh0=C<n03<a>P0Y9Rh0<c8e03Hg>00/;340TY:F0<S8bPT0oooo6_oooonR
0?ooo`0308j>SP1EEEH08B<S00806a/N00H05AHL00l@5P0;3@l02@/:00L910061P8?ooooo`003Ooo
ool01P1dPY00N8RL07b<Y@1mS:P0OXfY07Z:Y@80NhbS00/0P8jS082<X@1oS:80OH^Q07f=Y@1mSJH0
Oi2X086BZP23Tj`0QIJ_08FC[@0208JD[@0;08NF[@27U:/0R9F[08fH[P2?VK00SiVa08fG[`2=UZl0
T9Zb09BM]02GWkH00P2GW[D0302IXKL0UYjd09VR]02MYkH0W:Ff09ZS]`2KX[P0VjBi0:2X_02MY[X0
WjVl09nY_`80WjRn00T0Y:fo0:>/_@2UZkX0Yjnl0:N/_02V[;/0YJbi0:R^^P2Z/;T00P2//[X20:Za
^`0;0:R_^`2X[kd0ZJnl0:Z`_02[/K`0Zjnm0:Z^_@2[/Kl0ZZjk0:^^_@2]/Kh00P2]/[d00`2_/[l0
[k>o0:fb_0020:fb_0060:b`^P2]/[X0[k>j0:nb^02^/[T0[[>i0P2a][/0302`];`0/KBl0:na^P2]
/;T0/;Bj0:nd^P2`]K/0[k2h0:na^02`/KT0/[:j0;:c^@80[[>g00P0/;Jj0;2e^P2`];`0[K:k0:jc
_@2^];`0[K>i0:bc]`80Zk6f00h0Zk:g0:^b^02[/[P0[;2i0:jc^`2[/;L0[;>g0:fc]`2[/K@0Zk:c
0:bb/P2Z/K00ZJn^0:J][080Yjn_00`0Y[2_0:B^[P2SZjh0YJba0:FZ/@2VZK80YZRa0::T[@2SYZl0
XZJ_0:6V/02NY:l209jU[00309ZSZ02HX:P0V9nX0080UijW00H0UifV09JMY02DVj00T9RO08nGX02?
VIl208^FVP0;08^EV02;UIH0NhB707AoP01WL7@0GFIZ0413C@0c=4<0?T9=055JF`1ZKG000P29R8h6
0?oooa[oooooY03oool02@33`/D0RhZ>08^:SP0A41P020PA00@42`030`D00P<200@40`0?ooooo`00
3Oooool01P1[O8H0NH^J07b=X`1mSZH0NXZU07b=Y@80NX^R00/0NhbQ07b;X@20SZH0OhjW07f=Y`1l
S:L0OXnW082AZ022TZX0QI>]08FC[P0208JE[P0;08FE[028UZ`0RYN]08jJ/@2=Uk00SYVa08fG/@2>
VK<0SIRb08nK/`2DWkD00P2EWkH0302GWkL0Uj2f09BN]02DX;@0UJ6e09JP]P2HX[L0VZFj09^W^P2L
ZKX0W:Vk09nY_@80W:Jn00@0WZRo0::[`02SZkh0YJbm0P2W[Kh01@2UZk`0YZfl0:F/^P2V[;T0Yjjl
0080Z:no0P2W[kh0202W[[`0ZK2m0:R`_@2W[[`0YZfm0:V__`2Y/;l0Z[700`2[/[l01@2Y[Kh0Zjjm
0:Z]_02Z[kd0ZK2k0080Zjnj00@0[K6l0:jb_02^/k`0[;6j0P2]/kX00`2]/[/0[[>l0:fa^`020:jc
^P070:fb^@2^/kX0[K6l0:f`_02^/K/0/;:l0:fa^P020:^`^00;0:^a^@2]];`0/;Fo0:fc_@2]//00
[K>n0:V`^P2Y/KL0ZkBh0:bd^P2[/[/00P2Y/K/02`2Z/K/0Z[2i0:V_]P2Y[[D0ZZne0:ba^02[/KL0
ZJfc0:^`]02Y[[<0YJbb0080Y:bb00`0Yjnb0:J][`2T[:l0Y:Z`0::X/02SZK80XZRa0:2V/02QYk40
WjJa09^S[@2KXj`309^T[080V::Z00P0V:>Z09RSZ@2GWjL0UIfU09FOY@2CWJ80U9fP09:KWP80SiVL
00/0SiRL08bEV`2:U9X0Qi2F08B?U021SI80NHJ<07R4S01hQHh0NXR?06QeNP0202DX>P0303@m@P17
BE@0PhF:00<0oooo6_oooonX0?ooo`050<?3aP23Q8T01@L;00@51P030`<03oooool000gooooo00H0
K7b607B6U@1iS9d0O8jS07V:Y@1jRjL307^<Y`0:07^<YP1kS:D0O8bU07^<YP1lSJP0OHfW07nBZ020
TJP0Pi>Z08JE[080Q9F]00/0PiF/08FF[027UZ`0RIN^08ZE[P29UK00RIFa08ZG/`29U[@0S9Zd08jL
]@02092L]@0<096K^@2BWKT0Sibg092N^@2AWkL0T9jf09>P^02DX;X0UJ:m09JT_@2EY;/0VZNm0P2K
Y[h01@2KY[l0WJNn0:6[_`2QZKX0XjZm0080YJbo00@0Y:^n0:B[_@2U[;h0YZbo0P2TZkh02`2U[Kl0
YJjn0:B^_P2U[Kd0YZnn0:J^`02V[<40Z:k20:R_`P2X[l40Yjo10080Yjno00/0Z;2o0:Z`_`2/[kd0
ZZjj0:V_^@2Z[kX0[[:m0:fc_@2]/[h0[:no0:ba`P020:^b`P0<0:^b`@2[//00Z:nk0:R_^@2Z/K/0
ZK6j0:V`^@2Z/;`0ZJfm0:^a_`2///40Zk;00P2[/Kl02@2Y[k`0Yjjj0:Va^`2Y/;/0Z[6l0:bb_02Z
/K/0ZJnk0:V`^`020:Za_@80Z[6o00/0Yjjk0:R_^P2X[kP0YZfe0:R^]@2W[KH0ZJjg0:V`]`2Y/;P0
Yjfh0:FZ]@020:BZ]00<0:>Y/`2SZK80XjZa0:6W/P2SZKH0XjRg0:2X]P2PZKH0WjVe09^U/`2HX[00
VJB_0P2IXJd02`2GXJ`0UZ6/09BQZ@2CX:T0TifX09>LZP2BVjP0TYbV096MY@2@Vj80SYVN0080SYVL
00/0SiZN08fHW@2;UYX0QY:E08>@T`22T9<0PHnB07j;TP1mRY@0NhNB07Z9T@0206mmQ@0606j1P@0c
@4P04aXW00`B6@20PXD0`<316_oooon[0?ooo`030863Q011@DCooooo00kooooo000=ooooo`0606Yl
P`1hRYD0Nh^L07^;X01iRZD0N8RV0P1cPj@02`1cQJH0MHRW07V<Y`1iRj@0NhbU07^;Y`1mSJL0OXnV
07n@Y023Tj<0QIBT0080Q96U00/0Q9>[08:CZ`24U:`0QiJ]08RF[P29UK00RIFc08NC/`29UKD0RIJb
08ZH/P0208jJ]00<08nI]P2@VkT0SiZi092K^`2AWKX0T9fe096N]P2DX;T0Tj2j09:P^@2BXKT0UZBj
0P2KYkh02`2KY[d0WJNm0:2Y_@2RZ[d0XZVl0:>Y_02TZ[h0YJ[00:>X_`2TZL00YZ_10080XZRn00/0
YJW10:J/`@2U[<40Xjbo0:>]_02S[;h0Y:Zo0:BZ`02V[;l0YZbn0:J/_0020:N]_`0:0:J[_@2W[;`0
ZJfk0:R^^@2Y/;P0Z[6k0:R/^02Y[K`0ZZk10:b_a0<0Zjk300`0ZJc10:N[`02UZ[h0YZbk0:N^^`2Y
[k`0ZJfi0:R/^@2Z[KX0ZJ^k0:V/_P2Z[[d20:V]_00;0:N]^`2V[;T0Yjfj0:R_^`2W[[T0ZJnj0:R^
^`2TZkL0Yjji0:R^^P2W[[X00P2V[;T02`2UZkP0Yjjh0:J/]P2V[KH0Yjbe0:F[]@2SZKH0XZVf0::X
/`2UZkD0Y:Zf0080X:Jd00`0WjBc09nU[`2OYZh0WjJ^0:6V/`2QY[L0W:6e09fT]P2IXK80V:2_09bT
]02IX[8209NR/@0;09JR[`2DXJ/0Tj2X09>NY`2DW:T0TifY08nJY`2?Vj@0SibP08fJW02<VI/00P2>
V9h0102<Uj00RYJM08VEV`22SY<208>AU@0508B@U`22S9H0PXfE07n=T`1lRXh00P1jR8/01P1ePXD0
Nhb803M1A`0:31P020TA00H531[ooooo[@3oool?ooooo`003Oooool01P1[O8P0NHZH07b=W`1kRjD0
NXZZ07N8Z@80M8FV00/0M8NU07F8Y01fRJ<0NhbU07f<YP1lS:T0OXn[08:D[020TZH0PYBV08>CY@02
08>AY`0;08BE[@23U;00PiB`08FF[`25Tj`0R9F`08NB/`28U;H0QiJe08VH/P2=V[400P2BWKD0302>
U[40TIZg096K^@2AV[T0TYbh09:L]02CW[@0U9nd09>N/`2EX[D0UZ:f09NS]`80VjFi00/0W:Jk09^S
^@2NYk`0X:Zj0::Z^@2TZK/0XZNl0:>W_P2UZL40YJ[00:2W_@020:2X_@0;0::X_02UZ/00YJ[20:B[
`@2T[Kl0YZbn0:FZ_`2W[<00YZbm0:B[^`2W[[`00P2W[K`02`2W[;`0YZbj0:J[]`2V[KD0Yjjf0:J/
]`2W[KX0Z:fn0:R]`@2VZl00Yj_10080Z:c300P0YZ[10:J[`@2X[<00Yjbl0:V^_02Y[[X0Z:^i0:NY
^080ZJfi00D0ZZbl0:R[^P2X[;X0Z:bj0:R^^`020:J/^P80Yjfi00H0YZ^j0:R^^`2X[[X0Z:ji0:N]
]`2Y[[L20:R/^@0;0:R]^@2Y[KP0Z:fg0:V^]`2W[;D0YJ^f0::X]02RZ[@0X:Zd0:2X]02OYkD00`2O
Y[@02`2QYk@0WZBa09jS/02QY[<0WZ:e09nT^@2LXkL0VZ:c09ZQ/@2KXk80Vj>c0080Uin^00/0UJ2^
09BP[@2AW:X0Tij/09>NZ`2AWJ`0SI^Y08bKY@2;VZ40RYZO08ZHW@0208bHW`0;08RDWP27U9h0QiJM
08:@U@23Si<0QI2E08B>U`22RiL0PH^F07b9T01jQXX00P1kQhX01P1iPXH0NXB707N4Q00_<T@09BHh
020O;a[ooooo[@3oool?ooooo`003Oooool01P1ZNX/0NH^N07j?Y@1lRjH0NhZY07R7Z@80MhRX00/0
N8^W07Z?YP1mT:D0OHfV07j=Z01oSZT0P96[086BZP22TjP0PiFW08FEZP0208FBZ`0;08FC[P25U;40
PiBa08>E[`26UZh0R9J^08ZG/P29Uk80R9F`08^H/02?W;400P2@VZl0302AV:l0TYZc09:J]@2CVkL0
TIZd09JM]@2EWKD0UYje09FO]P2GXkL0Uj>c09^U/`80W:Ff00/0WZNk09jW_P2NYkd0WZNk0:6Y_02U
[L00Y:Rn0:BY`02UZKl0Y:Zo0:B/`0020:>/_`0;0:J]`02UZl40Y:W20:>Y`@2UZ/00YJZm0:BZ^`2W
[K`0Z:no0:J]_@2U[;`00P2W[;d02`2W[Kh0XjVk0:B[^P2TZkP0YZjh0:BZ]`2V[KT0Z:jn0:R_`@2V
Zl00YZ_10080YJW000`0Yjc10:R]a02W[<<0Z:g00:R]_@2Y[kh0Zjjo0:b^`02//<00Zjno0:Z]_@2[
[[/20:Z_^P0;0:V/^P2Y[K/0Yjbk0:N]^P2V[;X0Z:jn0:J/^`2V[KX0Yjfk0:^a_`2//;h00P2]/Kh0
2`2Z[[d0ZJjl0:V^^P2W[;H0YJ^e0:J]]`2T[KL0XZ^e0:6[]P2OZK@0W:Fb0080WJJc00`0WZRd09nX
]02OYk@0WZFb0:2X]@2LY;D0W:Bh09VQ]@2JXk@0VjFd09ZS/@2JX[8209RR]00;09BP/@2CX:l0Tin]
09:MZ`2CWj`0TYj]092L[02<W:P0RYZR08^KX02:VI/00P2=W9d02`2;VYh0RIZM08ZIVP26UID0QYBD
08NAU@26T9H0Qi:J08>>VP1nRiP0NhRE0080OHVC00H0OXR?07f5S01jPhX0M86706IcN`1QLG@Joooo
ojd0oooo3oooool000gooooo00H0J7N;07J9WP1kS:@0NHZT07b<Z01jRjP207N9YP0;07R;Y01fRJ<0
NX^U07f<YP1nSZH0OXjX07n?Z@20T:T0PHjV08FDZ026U:/00P25TZ`02`23Sj`0PY2/08>A[@26U[80
QiFc08NF/P29Uk<0R9Fb08bI/P2?W;<0SYZa0080SYVa00`0SiVc096J/`2AV[@0TYZe09BL]@2HWkL0
UYjg09BL]P2DW[D0UJ2d09JR/`2IYK@209^U]00;09bV^@2JY;/0VjJl09nX_@2MY[/0W:Bk09bT_02O
Ykh0X:Vo0:2Y`02PZ<000P2PZ<802`2PZ<@0XZ[50:6Ya@2RZ<<0XjW30:BZ`02TZkl0YZk00:B/_02U
Zk`0YZ^m0080YJ^o00/0YJc10::X`02QZKl0XZZn0:B/_02U[[`0Y:bi0:B]_02SZ[d0XjZo0:BZ_`02
0:F[_`0<0:J[_`2WZl80Z:c50:R/``2W[<00YJ_00:FZ`02XZl40ZJc20:R[`P2Y[<40Z:^m0P2WZ[`0
2`2UZ;d0YZZm0:FY_02W[;d0YJZl0:N]`02W[L40Yjg00:J/_P2VZkd0YZZo0080Yj^o00T0YJ^o0:F[
_P2SZKX0YJ^i0:F]^P2SZk/0Xjbk0:6Z^02PZKH00P2PZ;L209nX]P0<09nX]`2NYkD0W:Fc09bV/`2L
Y[@0VjFb09VT/@2GXk<0UJ6b09RR/`2GXK<0U9j`0`2GXk@02P2CX;80T9j^096M[@2?VjL0SIVV08jJ
Y`2=VZL0SIbV08^JXP2:VId208^KV`0;08VIW025UYX0QIFH08FDU`24TiH0Q92E08:>U@23SiP0PHjI
082>V@1nRiL00P1nRiD01P1oS9L0NhNB07R5S01fQ8X0LX:506YlNa[ooooo[@3oool?ooooo`003Ooo
ool01P1XMh/0MXVN07^<Y01iRZ@0O8bX07Z;Z080MhVV00/0N8^T07J9X`1jRjD0OHbV07j>YP1nSZP0
OhnY082@Z@21SZH0QIBX08JDZ`0208FB[00;08>?[022T:`0Pi6]08JF/P27UK<0QiJb08VG/`28UK80
S9Vb08nL/`2>V[400P2>VK40302?VK<0TIZc096J]02BV[D0U9be09RO]`2FW[L0U9bf09BN]@2EX;@0
UZ:c09VU]080VjFd00/0W:Ji09ZT^`2KY[`0WjRm09fV^`2LY;/0W:Bl09nW_P2PZKl0X:W00:2X`002
0:2X`P0;0:2Xa02RZ/D0XJW50::X``2SZL<0Y:[00:B[_`2V[/00Y:bl0:F[_02VZkd00P2UZkl02`2U
[<40XZS00:6Y_`2RZ[h0Y:bl0:F^_02T[;T0Y:fl0:>Z_@2SZ[l0Y:Zo0080YJ^o00`0YZ^o0:N[`P2X
[<D0Z:c30:N/`02UZl00YJ[00:R[`@2Y[<80Z:_20:V/`@2XZkd20:NZ_00;0:FX_@2VZ[d0YJVl0:N/
_@2UZ[`0Yjg00:N]`@2W[L00YZbn0:J[_@2VZ[l00P2WZkl02@2UZkl0YJ^n0:>Y^P2UZkT0YJfj0:>[
^`2S[;/0XJZh0:2Y]P020:2X]`80WjRf00`0WjRg09jW]@2LYK<0W:Jc09bV]02KYK80VJBa09NS/`2E
XK80V::c09NQ/`2DW[0309NS]00:09>P/P2@WZh0TIf]08nKY`2=VJH0SYZW08fJY`2=W:H0RiZR08ZI
W@80Ri^K00/0RIVL08FFVP25UIP0QIBG08BCUP24T9D0PXjE08>?V021SYT0P8jI07j;U`0207j;U@06
07n<U`1kQi80N8F<07J4RP1bPXD0JWak6_oooon]0?ooo`oooooo000=ooooo`06069aR@1eRJ40MX^V
07N:Y@1hRZL0NHZV0P1hRJH02`1gR:D0MHJU07R9YP1lRjP0Nh^V07b<YP20T:T0Q96Z08BAZ@26TjX0
RIJ]0080QI:Z00/0Q96Z08BBZP24TJX0Q96^08NC/`27U;<0R9Bd08RD/`29UK@0RiNe08ZE/P0208fG
/P0<08nH]02?U;80TIRe09:J]P2CW;P0Tibf09:L]P2AVkH0Tiff09>N]P2EX;H0UJ>e0P2DXk@02@2H
Y;T0Uj:j09RU_02JYKl0VjFl09bT^`2OYkl0WZO109fV`@0209jV`080XJW200/0WjO309jW``2NYl<0
X:O30:6Xa02OYl00Y:[10:F/`02TZkd0YJZl0:F[_@020::X_@0;0:BZ`P2TZL@0X:K309nW`P2RZ/00
Xj^o0::[_P2RZ[l0XZVn0:6X_P2RZ;l00P2VZl40302VZ/00Yj_10:FY``2UZ<<0YZ[40:BX``2TYl<0
YZW50:NZaP2UZ<H0YZ[60:BX``80YJS300/0YJW30:FZ``2RZ<40Xj[00:B/`02TZl00Y:_10:B]`P2U
[L80XZVn0:>Z_P020:BZ_@0;0:>Y_@2RZ;d0XZRm0:>[_@2SZ[`0XjVk0:>Z^`2RZK`0XJRi0:2U]`2Q
YkT00P2PYkT0302NY[P0WJFg09VR/`2JY;<0W:Fd09^T/`2HX[40Uj:a09RS/@2GX;40V:2c09NP/080
U9n^00/0U9j_096M[@2AWZh0TIn]08nLZP2<V:H0RiRU08bHY@2<V:<0RiNQ08^GX00208VEWP0;08ND
W@24TI`0Q9>M08BDV`23TYP0Pi2F086>UP21SiT0PHjI07f;UP1lRY@00P1kR9@01P1iQY80N8B>07F4
S01dPhT0LH2206j0OA[ooooo[@3oool?ooooo`003Oooool01P1XMh/0LXFO07F:Y`1hRZ`0MhZ/07N9
Z`80LhFW00/0M8FW07F7Y`1jS:P0NHZU07b<YP1nSZL0OHbV08:?Z024T:P0QI6Y08RC[P0208:=Z`0;
08B@Z`25TJ/0QI6[08BAZ`29U;00R9:a08ZA/P2:Tk<0R9>b08bF/`2>Uk<00P2AVK@0302BV;H0U9Vi
096F]`2BUkT0TYVi09:J]`2BVkH0TYbi09:L^02CWkP0TIfg09BQ]P80U:6e00/0U:2f09JQ^02GX[`0
V::n09JP^`2MY[l0WJBm09fT_P2LXl00WJG109^U`@0209fW`P0709jW`P2PYl40WjO009jV`02OYl40
WjJo0:6X_`030:>Y_P<0XZRm00/0XZRn0:>X_`2TZL80Y:S10:>X`02RZ<00XZRo0::X`02QY/40XZO3
0::W`@020:J[``070:BY`02SZ<00YJ[10:BX`02TZ<<0YZ[60:N[b0020:NZaP030:FZa@2UZL<0YJW3
0080Y:S300L0Yjc50:FY``2SYl<0XZW40:6Y``2SZl<0Xj[10080Y:_000l0XJRn0:>Z_@2TZk`0Y:^l
0:>Z_@2RZ;`0Y:Zo0:BZ_P2RZK`0XZJj0::W^`2RZ;/0XJJh09jT]P2OY[L00P2NXkD0302PY[L0W:Be
09^S]@2KXk@0VjBd09ZS]02HX[<0Uin`09RP[`2IXK40Uina09VR/`80Uj2`00/0UIj]09>L[02AW:d0
SiZ[096L[02BWJ/0Si^W08jKY`2;V:@0RiNT08bGY@0208^FX`0;08RBX026TZ40QY>P08FCW@26UI`0
QY6L08F@W@21S9h0OHRM07Z6VP1iQYL00P1hQiD01P1iR9<0N8RA07N8SP1dQXX0LhF406j1O1[ooooo
[@3oool?ooooo`003Oooool01P1UMHX0LXFM07>8Y01eRZP0M8JY0764Z080Kh:V00X0M8RZ07>7Z01e
R:P0MhZW07N9YP1hR:@0OHfW07f9Z021SJ/0PY2[0`24TJ`02`24TJ/0QY>[08NE[@27UJd0R9J/08RD
Z`29UJd0Qi:]08VE[`2:U:l0S9J_0080SYN`00`0SYNb096H]P2AVKP0T9Nh092I^@2?V;P0TIZf092J
]02AW;H0Tifi09:M^02CW[L209>N]00;09:M/`2DW[D0V:>j09RS_02GXKX0Uj2l09VR_P2HXKd0V::n
09ZU`P2KYl<00P2JY/802`2IY<00W:S009ZV_P2MYkl0W:Fm09nX_P2PZKd0X:Nk09jV^P2OY[`0XJRm
0080WjJl00/0XJNm0:2U_02QY[h0X:Bm0::X`02QZ;l0WjJm09nW_P2NY[l0WjK10:6Ya@020::Za@0<
0::Y`P2RZ/40XJW00:2X`02RZL00Xj[30:F[a@2SYl<0Y:W10::Y_`2RZL40XJK00P2PYKl02`2SYl00
XZO20:BY``2SZL<0XJW20:6Y`@2OZ<00XJRo0:6Z_P2QZKh0WjRk0080WjVk00/0WjJk0:2X_@2TZl00
Y:_10::Z_P2OY[/0WJFi09fV^02PYkP0WZFe09fV]@0209nX]`0<09fU^@2JXKL0VZ:f09ZR]@2IX[40
V:6`09JQ[`2FWjl0Uij_09RO/02EWK00UYn`0P2CVk002`2CWK40TYb_092K[02=V:P0S9RW08nJZP2=
V:L0SiVW08fHYP2:UZ@0RYBT0080Qi6Q00/0QHnO08FAW`24T9d0PY6J086@V@21SiP0PXjI08><W@22
SJ00O8ZM07R9V@0207N9UP0607J7T`1dQHd0M8J:07:5QP1_PX00KhAl6_oooon]0?ooo`oooooo000=
ooooo`0606UgS01_P9/0KhBQ0725X`1bQZH0M8NX0P1bQZL02`1aQZP0KX:U07:6Z01eRZT0MHNV07V;
Z01lS:P0O8^X082?Z@20SZP0PHjY0080OhbX0P1oSjP02@21TJX0PY:Z08:AZ@23TZT0QI>[08RD[@29
Tjl0RYBa08^F/@0208VC[P0908VC/02=U[<0T9Zf08nI^02=V;L0T9bh08nJ/`2AW;<0SYRb0080SYVg
00h0SIVd08nL]02?W;@0T9bd09>N]@2DWkH0UIng09NP^@2CW;P0U9bk09FL^P2EWkX0UZ2k09FP^`80
U:2l00P0Tj:m09FR_@2EX;X0U9nj09VS_`2GXKd0V:>j09bU^`80W:Bj00h0W:Fk09fV_@2MY[d0W:Bj
09bU^P2KXkT0WJBj09fU_02NYk`0W:Ji09fV^`2OYkl0WjK109jV`0<0WjS300/0XJW309jV`02PZ<00
WjNn09jU_`2OYKh0WZFl09jV_02MYK/0WjNn09jW_@0209bT^P0409jT_@2PYl00WZK009nW`080WJJo
00D0WJJm09bV^P2NYkT0X:Zj09jY^`0209fW^P0;09bS^02LYKP0WJFj09fU^@2NY[X0WZFj09bT]`2K
X[H0Vj>g09^S]P2KY;P00P2KYKP02`2IX[P0UZ2f09FN]02GWk@0UYna09JQ[`2DWjd0Tif]09BL[@2A
VZd0T9b]00<0SYVZ00/0SiZ/092L[`2>VZd0SYZ[08bGZ@2:U:H0RI6T08ZCY@29TZD0Qi:S08JAXP02
08FAXP0;086>W`20SIl0PI2P07n?WP1mSY/0OhnK082@W01nS9P0OH^H07V6U`1fQiH00P1hRYL01P1c
Q940LX>=0764R@1`Ph<0KX5o06UmMa[ooooo[@3oool?ooooo`003Oooool01P1VLi00JgfM06j4Y@1_
QJH0LHBV07J7Z@80M8FY00/0LhJ[07:7ZP1dRZX0MH^X07R<Z01hRjP0NXbX07^<Z01nSZT0Oi2Y082A
Z@0208:AZ@0;07j=Y`1oSZP0PI6Z086AZ`22Tj/0PI:Z08:AZ027U:d0R9Fa08ND/P28UK400`2<VK40
2`2<V;00SINc08jH^02<UkP0RiNh08fI^@2?V[L0T9bi08nL^`2=VkX0SIZg0080SYbe00/0Sife096M
]@2DW[L0U9fi09NO^`2FW[/0UIfj09FM^`2FW[/0Tibi09BQ_00209FR_@0309BQ_@2GX[h0VZG00080
V:6o00H0Uj2m09ZQ_@2IX;`0VZ:o09fU`@2NYl0209bV_P0;09ZU_02MYk`0WJNk09bT^@2MY[/0WZNn
09jX_02LY[T0WjNm09jV`P2OYl<00`2PZ<@02`2QZ<@0XJO40:6Xa02OZ<@0WjS30:2Y`P2PZL40WZVo
09bW_@2KYkl0WJW10080W:No00/0W:Fm09fT_@2MYL00VjC009jX`P2MZL40WZVo09jY_02OZk/0X:bi
0:6/^@020::[^@0:0:6[^P2QZ[`0X:Rm0:2X_P2QZKh0WjNl09fT^P2OYKX0WJBj09nX_P<0WZRl00`0
W:Fi09^U^P2JXkP0VZ>h09NQ]P2GX;H0UZ6f09FP]@2BW[80TIfb096N/@2AWjh209:N[`0;09:L[@2B
W;00T9Za08jI[P2=V:d0SYV^08bGZP2>VZ`0RiRY08RFYP27UZH00P26U:H02`23T:<0Q9:W08BAZ024
TjL0Oi2S07f=XP1lSZ40OHnN07f>W01iR9/0N8NL0080NX^M00H0MXNF07J9T`1dR8d0LXJ60766P@1`
QG/Jooooojd0oooo3oooool000gooooo00H0JWFD07F5Y`1fR:/0MHJZ07>3Y`1eQZT207N8[@0;07N7
[P1eQj/0LhNY07N:Z01kRjX0NXZY07f<ZP1nSjX0OhnY082@Y`22SjL00P24SjT00`26TJ`0QI6]08B?
[`0208B@/080QY>b00@0Qi>b08RB/P29TK00RYBa0P2:UK001P2<V;80T9^d08fG/`2?VKT0SiVl08fG
^P80S9Ff00@0T9Vk096K^`2?V[/0SIVh0P2@W;D02`2CW[D0U9bd09JM]P2HW[L0V9nf09NM]02HW[H0
Uibg09^P^@2GW;P0V9ni0080VZ>l00/0VZ:l09RN^`2JX;d0W:Bn09bS_02JXK/0W::k09bQ_@2LWkh0
WZ7009jS`@0209jS`00;09nU`P2NXl00X:Jn09fT^P2KXKL0WjJk0:6X_@2NY;X0X:Fk0::W_`2QYL80
0P2QY/@0302QYl@0XjS30:>X``2RZ<<0WjC209nV`P2OY/<0WJG109jV`02MY/00WJK209jX`P80W:Fo
00/0XJRm0:6W_02PYK`0WJ>m09fT_`2MXkh0WjNo0:2W_`2QYkh0WZJi09nW^0020:2U]`0:0:2V]`2P
YkT0X:Ri0:6X_02OY[`0X:Jk0:2U^P2MXKH0WJ6e09bQ]P<0WZ>h00`0W:6e09ZQ]@2IXK@0VJ2e09ZP
]@2IWkD0Uiff09FM]P2CW;D0Tifb09BN/@2DWJl209>K/00;096G[P2?UJ/0SiJ[08nG[02;TjT0S9>[
08^CY`2;UZL0RYFU08RDXP26TZ800P26TjD02`24Sj@0Q8nU08F@Z@20S:H0NhRQ07b;X@1kRil0NXZK
07R6V01hQ9L0NHJI0080MhFH00H0MH:C07N6T@1eQ8h0M8B80721P01ZO7LJooooojd0oooo3oooool0
00gooooo00D0IFf:071nW@1bPJD0L82T07B3Y`0307>1Z00;07J5Z@1gQZT0MhNY07N7Z01iQjT0NhZY
07b<Z@1lS:L0OXfV082=YP24TJX00P22SJP01026T:`0Q8j^08B?/@24TKD208:?]00508BA/`25Tk<0
QYBb08RD/@29Tk800P2;U;<0302<U;@0SIRf08bH]`2>V;T0T9Vj08bF]P2;U[L0SIRh096K^@2?VKH0
SIJc08nH]080SiVd00/0TYbe09>M]@2CW;@0U9fd09FM/`2FWK80VJ2d09NM]02IW[H0V9fe09RN]`02
09RN^00;09RN^@2JX;/0W:6n09^P_P2JX;X0Vj6k09fR_02NX[d0WZ6o09jR`02LXKl00P2KXKh00`2M
Xl00W:>n09bR^`0209jU^P0609jV^P2PYKP0XJJi0:6U^P2QXkX0WZ2i0P2OX[`0202PY;l0XZK00:2T
_P2QYL40XJC20:6T``2PXl80XJG30P2PY<003`2QY/00XJNn0::X_02RZ;`0XZRj09nS]`2NX[P0XJFl
0:2U_@2LX[`0WJFm0:2U_`2QY[h0WZ6i09nR^@020:2T^@0;09nQ]`2RY;T0XJBh09jR]`2MXkL0Vj6g
09fS^02MX[H0VIjb09^R]02KXKH00P2JX;H0302IX;D0VJ6f09RO]02HWk40VIn_09VL[`2JWk<0UIbc
09BK/@2CVk00T9N]09BK/080UI^a00/0TYJ]08jCZ@2@UZT0SYBW08jFZP2<TjP0R96T08VDX`27TYh0
QY6M08NCW`0208>=WP0;08F?X024SJ40Q8bT0869Y01mR:<0OXZQ086>X01lR9/0NhNJ07N3UP1ePI<0
0P1hQ9H01P1gPYD0MH6B07>0S`1aP8T0Kh6106UlMQ[ooooo[@3oool?ooooo`003Oooool01P1UKh/0
KgbK07>3Y01dQ:P0LX:V07B2YP80Lh:V00/0N8NZ07V9Z`1kRj`0NHZZ07V;Z01jRjH0O8fU07f=Y01o
SjH0P8fW08:>ZP0207n;Z@0;086=[@23SZl0Q8j`08:?/022T;80PI2`082A[P21TZd0Pi>]08JE[P27
U:h00P27U;00302:U;<0RIFc08VE/`2:UK80RiFa08nH]P2?V;L0SYVf096M^02@Vk<0T9Zc08jG/P80
T9Ze00/0T9Zd09:M]@2@W;<0TIbc08nI/P2DWK@0Uine09NM]P2FW;P0UYfi09NL^@0209VN^P0;09VM
^@2GW;T0VYnl09bR_P2LXkd0W:>k09bQ^@2KX;X0W:>n09^Q_@2JXK`00P2IX[X02`2KXkX0Vj>i09ZR
]P2KY[L0VZJf09ZT]02KX[80WjBe0:2U^@2PY;T0WZ>g0080XJJi00`0X:Bj0::V_P2RY[h0XJG00:6T
``2PY<80XZK40:2T`P2OXl40WZ>o09jV_@2LY;P209fT]P0809fT]`2MXkH0WJ>f09fT^P2MYKd0WJBm
09jU_02MXKP209nS^00809bO]P2OXKT0Wj6i09nR^@2OX[P0X:Bj09jT^@2LXkT209RN]@0409ZR]`2I
Wk@0VJ2c09VQ]@80VJ:g00`0UYjf09BL]02EW[<0Uj2c09NO/@2EWJl0UIf`09FL/`2BV[40T9V_08jE
ZP2@VJ`2092GZ`0;08nEZ@2=TjH0S9:W08R@Y028T:<0RI:S08N@XP27Tj@0QI>Q08BBWP23TI/00P20
SiX02`23TIl0P8fO08:=X021S:80Oh^Q07f9W`1mRId0NhNI07Z4U@1iPi<0MH2B0080MH6D00H0MX>G
0760T@1_Oh`0KX2706YmO`1WO7HJooooojd0oooo3oooool000gooooo00H0Hfn:06mmV`1dP:<0M86V
07>1YP1cP:@207J3Y00;07Z8Z01lRZ/0NXV[07V9ZP1hRZH0MXVU07V:Y@1kRj@0OhfU08:>Z@22SJd0
0P20S:d02`21SZd0P8bX08B@Z`25TZh0Pi6_086@[`21T:d0P96Z08:BZ@23TZP0Q96[0080QI2`00`0
R9>d08bH]P2=V;<0SYRa08jF/02@V;@0SiRg092K^P2>VKP0SYZf08fG/P2@V;42092G/00;09:H/P2@
V;40SIN`08nI/@2AVk<0TYVc09BL]`2FVkT0TiVh09FL^P2FWKX00P2HW[X02`2HW;/0Uibl09VN_02H
W[T0VJ2g09RO]@2KXKH0WJ>h09bQ^@2KXk/0VjBl0080Uing00/0V9ne09ZR]02KX[<0Vj>c09RR/P2I
Y;<0VZBc09ZS/`2MYKH0WjJi0:2W^`020:2V^00<09nU]@2OY;D0Wj:f0:6S^@2PY;`0X:Fm0:2V_P2M
X[/0W9nk09fR_@2LX[d0VJ2h0P2KXkL02`2LY;L0WJBh09jU^P2LXKX0VZ2k09bS^`2MYKT0Vj6f09jS
]@2OY;L0Wj>i0080W9nf00/0Vind09ZN/P2MX;@0WjBf09bR]02HW[<0Uife09NO]02HXK40Uij`09FL
/@0309JN]@80Tifc00T0Tiba09BL/@2AVJl0T9Va08fG[P2=UJT0S9JW08jHY`2>UZH00P2=UJH02`2>
UJD0S9:T08ZAX@2;U:<0R96Q08ZBX@2:TJ<0R92R08FAXP22T9d0P8nJ0080P8jI00/0PHnL086<W@22
Rj00P8VO07j8W`1lR:40OHVO07^6V@1iPY<0NX>E07N1UP0207AoUP0607>1V01^OY40L82<06YlPP1[
OWh0J7ag6_oooon]0?ooo`oooooo000=ooooo`06069]Q@1^NiP0LWjO07>0Y01aOJ<0Lh2T0P1fPj80
2`1ePZ<0N8FW07Z8ZP1iR:P0NHZW07R:Y`1iRjH0NHZU07^;Y@1mRjH0OhbX0080P8bZ00/0P8bY082<
Y@20SJ<0Q92V08B@Z025T:/0Pi:[08>BZP24TjT0QYBY08FDZ@0208JC[00<08JB[P28TZh0RiF^08ZC
Z`2=UZd0T9J`09:G]02@U[H0TINg092F]02?UK40TYRa0P2AV;402`2AUJh0TYR_09>I/P2BV[00SiJ/
09>H/02CV;40TiVd09BJ^P2BVK/0TiZi00<0U9^f00X0U9Zf09BI]`2FWKT0V:2h09RO]@2IWk<0VIjd
09VM]`2FV[P0Uijg0P2GWk@02`2HWk00VIn_09^O[`2JW[40VInb09VQ/P2GWZl0VJ6`09RO/02IX;D0
VJ2g0080V:2f00`0V:6b09^S/@2NY;40X:Fc09nS]@2OXkL0X:Fi09jS]`2LXKH0VZ2e09ZQ^02GW[@2
09JO]00:09NP]@2IW[D0WJ:i09jS^`2IWkL0VZ6i09ZP]`2HWk<0VZ2c09bQ/P<0WZ:f00/0W9nd09ZN
/P2IWK40W9nd09ZN/P2KWkD0V9nf09JM/`2FW:l0U9^]09FL[`0209>J/00<09BK/`2EW;80UIja09:K
[@2?UZX0T9R]092I[`2;UJ`0RY>V08bFY02?Uj<0T9JQ0P2>UJ402`2>UJ<0S9:R08bCX`2;TZ40R92N
08R?W@29Sih0RY:S08F>X@21S9h0OX^K0080OHZG00/0PHfJ0829VP22Rid0PhZN0827W`1lPih0Nh:N
07^3V`1jPIP0NGjG07QmV@0207InV00607=oUP1^OY00K7f706anP`1/P7h0JWeg6_oooon]0?ooo`oo
oooo000=ooooo`06069]R@1]NiT0LH2O07>0X@1bOZ<0Lh2T0P1ePjH01P1cP:@0MhBX07R6Z@1fPjL0
MhJX07Z:Z@80O8bZ00<0O8^Y07f<Z01oSjT00P20SZP02`1oS:H0PXjW08>=YP23SZL0PhjY08:=Z022
SZP0PHjX08:@ZP23TJT0QI>[0080QIB/00`0R9F^08RE[@2:UJ`0RiFZ08nG[@2?UZd0SiF/08jE[P2?
UZl0TIRa08nF/02>UK02092H/`0;092F/02AV[00TYZ_09:I/02CVK00TiVb09BI]02EV[H0U9Zj09BK
^`2EW;`00P2DVkX02`2BV[T0TiZi09:I]`2DW;H0Uijf09NM]02FVk<0VYjf09VM]P2EVkL0Uiji0080
V9ng00/0V9nd09ZO]@2LX;H0VYnc09ZQ/@2IXK00VJ2_09RN[P2FWZh0UYjb09FM]00209NQ]@0309JP
/`2KY;@0VZ6b0080WJ:e00L0WZ>h09jR^@2MX[P0WJBj09bS^@2KXKL0Vj6h0080Vj>h00/0VJ2g09RM
]@2HWKD0V9nf09RO]`2GWkL0VJ2h09NM]@2JX;H0Vj2e09^Q]P0209^Q]@0909^O]02LX;@0WIjd09bL
]@2KVkH0VYbf09VN]@2HW[00Uif^0080UIb/0P2EW:h209>J[P0:09:J[P2BVZl0TY^^08jGZ`2=UZX0
SINZ08^DY@2>UjD0SYBR08jCX080T9FS00/0RY2P08ZAW`2:U9l0S9FP08N?W026SIh0QX^O08R>X@26
SZ40Ph^P08>:X00208:9WP0;0828W020Qi`0PXJN0865WP1oQ9d0O8>M07b2WP1kPYd0N7jJ07QoV`1e
OYX00P1eOiT01P1cOi@0K7Z<06akRP1ZNh<0IgUm06IiN1[ooooo[@3oool?ooooo`003Oooool01P1U
KhP0KgfK0760W`1dPZ80M86Q07=oXP80M86T00/0M82U07J4Y`1fPjD0N8FW07f;Z`1kRZ/0OHb/07^:
ZP1lRj/0OHb[08:A[P02082=ZP0;082<Z`21SJX0Q8nZ08:>Z@21SZT0PHjZ08>?ZP23SjT0Pi2Y08FC
Z`24TJT00P26TZ/02027TZ`0R9>/08^E[@2=V:l0RiFZ08fHZ`2=UJT0S9B/0P2<Tjd03`2?Uk80SiFb
08nF/P2?U[80SIB^08jF[`2@UK00T9F_08nE[`2AUk<0TYRe092F]@2AUkH0TYRg09FK^`0309>K^`0:
09>J^P2DW;X0U9bh09NN]`2HWkH0Uijd09JM/P2FWK<0UIbd09FL]P80UIbg00H0V9ji09NM^02FVkD0
VIne09RO/`2GW[0209FL[@0309FO[`2DW;00V9nf0080VZ:h00`0VJ:h09VP]`2IWkD0W:6f09bP]@2K
WkL0W9nh09jR_@2NY;d0WZBl0:2U^P2MXK@209fQ/`0409^O/P2JWk@0VZ2f09VO]P80VJ2g00D0VZ2j
09VO^@2IW[L0W9nh09ZM]`0209ZM^00;09VK]P2JWK@0W9je09fM]@2KW;H0VYff09JK/02EW:d0UYf_
09FL[`2BVZ`00P2BVj`02@2BVZd0SiN[096I[@2=UJ/0SIJZ08jGZP2>V:/0SYN[08jFY`0208fCY00>
08bAXP2:T:80RY2R08bBY026Sil0R9:M08J?VP28T9h0QhjO08><WP23RYh0QXjQ08>;W`22RYl20868
WP0;07n6W`20QIl0P8BP0824X@1kPIl0NX6N07V1W@1fOi/0MGjH079lU@1cOIH00P1dOiH01P1bOY00
Kg^<06eiRP1ZN8L0J7R206AfNa[ooooo[@3oool?ooooo`003Oooool01@1SKHL0JgRF06imW@1`Oj40
Lh2T00<0LgnS00/0Lh2S07F2Y@1ePZ<0N8JU07b8Z@1mRjX0Nh^W07b;Y`1oSJT0OhbX08:?[002086?
[@0;07j=[P1oRj`0OXZY08B@[@23Sj`0QI6^08B@[P24T:`0QI2/08FB[P25Sj`00P26TJh03029UK40
Qi:^08RC[`27Tjd0R9J]08ZG[P2:U:d0S9F^08ZB[02;U:d0Ri>_08fE/@80S9>^00/0SiJ`092E/P2@
U[80T9Jb096G/P2CV;40U9Zb09FI]02CVK@0U9Ze09BI]`0209>H^00;09>H^@2DV[T0TiZg09FM^02H
WkP0UYbf09FK]@2CVK<0Uifd09JL]02GW[H00P2HW[P02`2HWKT0V9fe09^P]02JWK40V9bb09VM/`2G
W[80UYfa09NN/@2EW;40UYfc0080V9nf00`0VJ2i09ZP^@2IX;T0VYnh09^O]`2LWkL0Vinh09VM^02J
W[P0Vj2f09bO]02KWk8209bN/@0;09jQ]02MXKP0W9nh09bO^02IWKL0VYnh09bO^@2IW;H0VYjg09ZL
^@2JWKP00P2KW[L02`2IW;D0V9^c09VL/P2KWK<0UiZb09JJ/P2DVZl0UIb^09BJ/02DVk80TYV`0080
T9V`00`0T9V_09:J[@2AV:`0SiFZ08jD[02?UZh0S9:X08nEZP2@UJT0SI:X08Z?Y@2;TJH208V?Y00;
08N>X`26SZ<0QHjR08>;W`28SZ<0QXbQ08F;X@25RZ<0PhVR0867XP20Qj400P1nQIl02`1oPil0O82L
07f1WP1kOid0O8:N07UoVP1gOYL0MGbE07=kTP1`NHh0L7Z>0080LGV@00H0LW^@071iS`1]MX`0JWJ8
06MfPP1RLgXJooooojd0oooo3oooool000gooooo00D0Hff706]hUP1^OId0L7nQ07>0Y00307=oX`0;
07>0X`1ePZD0MH:S07R6Y@1lR:T0OH^Z07^;Y`1lRjL0OhfY07n<Z022Sj`00P21Sjd02`1nSJh0Oh^/
07j:Z@24T:d0Phn/08FA[P24T:h0Q92/08F@[025TZh0QHn/0080QY6^00`0RIFa08NB[P28Tjl0Qi>]
08RF[@2:Ujh0RYB]08bE[P2:TZ`0RiB]08^C[`2=UK4208bC[P0;08nF/02@UK80T9Jb092F/P2AUk80
TiRa09BJ/P2EVK@0TiVd09BJ]@2DVKL00P2CV;P02`2CV;T0U9Zi09>J]`2EWKP0V9nh09JL]P2EVkD0
TiVc09NM]02FW;@0Uijf0080V9jh00/0V9fi09RM]@2KX;@0VYfa09RL/P2IWK<0Uijb09JM/@2GW[40
UIba09JM/`0209RO]P0<09VP^@2JX;T0VJ2i09ZO^02KWkL0W9ng09^O^02IWKP0VYjh09^P]P2LWk@0
Vinb0P2LW[402`2NXK@0WJ6h09bO^02LWkP0VIfg09ZO^02LWkT0VIbf09ZN]`2JW;T0VYfh0080Vijg
00/0VIbe09RK/`2IW;80Vifc09NJ/P2FV[80U9Z_09FL[P2DV[00U9^b09:I/002092I/00<092I[`2B
VZd0TIR/08nEZP2>U:`0SiJ^08bBZ02?UJX0T9FY08fBZ02:SjD0Ri6V0P29Sj@02`27SZ<0QXjS08F>
XP23Ril0R8jS08J<X@25Rj40QHZS08>9XP21Qj80P8NQ0080OXFO00/0Oh>O07b0W01mPIh0NgnM07b2
WP1iOiX0MgjG07ElU@1cNi80L7V>071jSP02075iT006079kT01`NHl0KGJ<06YfR01WMX80HW=j6_oo
oon]0?ooo`oooooo000=ooooo`0606EbR`1]NYP0L7jO075nX`1cOjD0LWfT0P1bOJ<02`1cP:@0Mh>V
07R4Y01hQ:80NHFV07V7Z01jRJP0Nh^V07^<YP1oSjT0OhfX0080OXf/00L0Ohf_086?[`1oSZT0PY2X
08:>Y`23T:P0PhnZ0080Q8j/0100QI2^08F@Z`23SjT0PhnY08JA[@27TZh0QY2/08B?ZP27U:`0R9J]
08ZF[@2=UZl0SYN`08fF/02>VKD0RiB`0P2=Uk402`2<UZh0TIRa092D/@2BV;@0TIVb09BL/P2FW;40
UI^`09>G/02EVK@0TiRe0080TiVf00/0TYVf09>J]@2DW;D0U9Zc09JK]02EVk@0TYNc09>I]@2CV[@0
UI^e09JL]P0209FK]`0;09JK^02HW;D0VYje09RM/`2JW[@0Uibb09JM/`2DV[00Tib`09>M[`2FW[00
0P2FW[80302HWkD0Uije09NN]P2JWkH0Uibc09NL/P2JWKD0Vijg09VM]@2HWK<0Uib`09VN/@80VYnd
00/0WIne09^M]P2LWkP0VIbf09RM]@2KX;H0Vj2d09VL/@2IWK80VIbc09NJ/P0209RL/P0;09RM/P2G
W;40V9fc09RL/`2EVk<0U9Zc09:H/02CUZd0TiJ^09BH/@2?UK400P2<UJl0302<UJd0RiBX08jFZ@2>
U:P0T9F/08nD[P2=Tj`0Ri:Z08N?Y02<TjH0S92V08Z>YP80RhjX00/0Ri6Z08R=Z027SZL0Q8^S08>:
X@24Rj40Q8RR08F8Y023Qj@0PXRV07b4X@0207V1W00;07f4V`1mPYX0O86K07YoW01iP9/0Mh6K079l
U`1bOID0LgfE075kT`1`Ni000P1_N9001P1]MXh0JWB=06QdR`1WM8L0IGB1069aNA[ooooo[@3oool?
ooooo`003Oooool01P1SKhT0JgND075nW@1dP:D0M7fU07EnY@80M7bS00/0MWfS07V1Y01kPj@0NX:S
07b6Z01jQZH0NXRW07b;Z01mSJP0NhZV07j=Z00207f>Y`0;07j>Z020T:T0PHnW07n>X`1nSj80Q9>T
08F@Y029TZP0R96W08J?Z027Tj/00P25TJT01027TJP0RI:[08RAZ`27T:d208VB[`0608^D[`2?Uk80
SYJd08jG]@2<UK80S9Bb0P2=U[@02`2=U[<0S9J_08jF/@2>V;80SIR`096J/02CVk00TIR]09:I[@2C
V;00TiRb0080TiVd00/0TiZb09>H/02EV[80TiVb09BI/`2AU[00T9Ja092F]02@UK<0TIRd09>J]`02
09:J^00;09BJ]@2DV[<0UIbc09FL/P2FW;@0V9jf09FK]02DV[40UIj_09FO[P2FWjh00P2FW[40302F
W[@0U9bd09RO]P2GWKD0V9fc09NK[`2IW;<0Vijg09RL]02GWK<0UYfa09JL[P80V9fa00/0VIfb09RK
/P2IW;L0Ui^e09FJ/`2FW;00U9Z/09JL[@2GW:`0UY^^09BI/00209BI/@0;09>H/@2DV;40U9Zc09BH
]02CUk<0TIJa09:G/02CV;00TIF/096E[@2@UJd00P2>UJh0302;U:/0RiF[08bEZP2:TZH0Ri>Y08bB
ZP2;TJT0S9BZ08VAYP29TZ80RXnO08Z=X@80RXjU00/0R8bU08N<Y`23RjD0OhVN082;W@1oQiX0PHVM
0867W`1oQIl0OhRS07b5X00207V4W00;07V3V@1hP9H0NGnH07UnV@1gO9X0MGfL079kV@1`NIH0KWJB
06igT@1]M8l00P1ZLXl01P1ZLY00JG6=06=_R01ULXP0HW6105m_MA[ooooo[@3oool?ooooo`003Ooo
ool01P1VKhD0JG>B06mkV`1bOIl0MGnQ07MnXP80MWZS00/0MWZR07YoY@1hP:<0NX>T07f7Y01lR:<0
O8VS07j:X`1oS:@0OhfW082>Z002082>YP0;07n=Y021SZ@0OHVQ07n<XP1nS:80PY2T08:?X@26T:80
Q8fQ08N?Y`28Sj/00P29TJh0302:TZh0RY>]08VAZ`2:TJd0RXn^08jB]02;Sk80S96b08nE/`2<Tjd0
R92[08jD[`80SYFa00/0SIBb08VA[P28Tjh0QiB]08RE[02=VJ/0TIZ/08nFZ`2AUj`0TIN[096H[002
09:I[007096GZP2CVZ`0TiZ/09FH[@2BUZh0TYR_09BK/@0209>I[`0?09>I/02?UJl0T9Na092G/@2A
VK00TIN^096HZ`2BUjX0TYJY09>H[02CVJh0TiZ]09BK[02BVZP0U9bZ0080U9^/00`0UIZ_09BI/02E
V[40Ui^a09JI[`2GV[00UiV`09NJ/@2FV[00U9Z^09JL[02EVjP209FIZ00;09RK[`2HVk80V9Zc09NI
/02EV:d0UYZ]09FIZ`2FVZX0UIZZ09JIZP2DUJ/00P2DUZh00`2DUK00UYNc09FG/`0209>G/P0609BE
/02DUk00TYF^09:F[P2AUJd0SYBZ0P2=TjT0302>UJ`0SI>Z08V?Y@2;TJH0RHnU08ZAZ02:T:D0RY6S
08bCY02:TJ40RHnO08^=X080RhnR00/0R8^Q08J8Y026RZH0PXNQ0829W`1mQIX0OHBH07b3V01nQ9X0
OXBK07b2V@0207V0V@0;07MoV@1eO9H0MWbG07MnV01eNYP0LWVH071hU`1`N9H0KWFC06acTP1/M9@0
0P1XL8l01P1VKH/0IVn;06E`RP1SKHD0HFn005i]MQ[ooooo[@3oool?ooooo`003Oooool01P1YKH80
KgB@07AjV01eO9X0MgfM07MjW@80MgZQ00/0N7^T07]oYP1mPjD0OXRS07b7X@1kPj00OHJQ07b6X01l
Qj00OhbU082>YP0208:?Y00;08:>XP20S:<0PXbV08>=Y`1oRjH0Pi2X08JBYP28TJD0R92U08V>Z02<
T:h00P2=T[40302:T:h0RY:]08ZAZ`2:Sjd0SI:`092D]02>T[@0Rhn_08^A[`2;Tj`0SYB[08bAZP80
S96Y00/0RXn[08R=Z@24RjL0Q8fV08B<XP24RYl0R8bS08^=YP2<T:H0Ri6U08VAY00208bEY00608jF
Y02?UZ@0T9JV09:HZ02DVj`0T9NY0P2BVZ/209BKZ`0>09>I[@2DVk00U9^`092G[02AUjT0TiZZ09>G
Y`2DV:P0UIVZ09RM[@2EVJX0U9RX09JKZ@2FVjX209JJZ`0<09NJ[P2EUjd0UYZ`09BG[P2EVJl0UYR_
09RJ/02IVk80VYbb09JI[P2FVZ`0UYZY0P2FVJP02`2HVJX0UiN[09NH[P2FV:d0UiZ^09FHZ`2FVJX0
UYV[09JHZP2EV:/0TYBZ0080TiB/00<0U9J^09:C[02BU:h00P2EUk001P2BTjd0TiF^09:C[@2@TZT0
TIBY096CYP80T9>U00`0SI6U08bAY02;T:80S9:R08fCY027SZ40QhfR08V>X`29Sj<0R8fQ08N;W@28
S9d208^>W`0;08R8WP26Qj40Q8JS0825XP1nQ9l0OHFJ07f5U`1nQ9H0OX>G0825V@1mPIL00P1lOiT0
2`1kP9X0NGjI07QmUP1gNi@0M7RC07=hU@1aN9L0KGBG06YbU01/MI<0K7FA0080K7B?00H0J76:06Q`
RP1XKXP0IF^3061YO01OJgHJooooojd0oooo3oooool000gooooo00H0Jfj207IkT`1jPI/0NX2M07b0
WP1jOI`207YkWP0;07eoX`1mPJD0OH:T07n6X@21R9h0OhFL08:8X022RJ80P8VS07n;Y022Sj@00P22
T:802`24Sj40Q8jP08J>X`25S:H0PHRU086:Y024SZ<0Qi6R08V@XP2:SjD0SI2[0080Rhn^0P2;T:h0
2P2:Sj/0S96[08b@Z`2?TZh0SI6`08b@[@2;T:/0SYBY092FZ@2>TjH208fBY@0;08^?YP2:SZT0R8fY
08F<Y024RYh0Q8NK08J7W@25Pid0QH>O08:2W@1nPIT00P1oQYT02`1oQiD0PhVF08F:V028SY/0RY2N
08RAW`2<UJ80SiZV09:MZ02AVjL0U9^Y0080Ti^[00/0SiJY09:JZP2CVjL0Ti^U09FKYP2FVZT0Uib/
09JL[@2BUjP0UI^X09NLY`0209JJY`0<09JHZ@2GVJd0UYZ^09>I[@2AUj/0UIV]09NK[P2FV:/0UYJ]
09BE[02EV:/0UIVY0P2EV:T02`2HVZ/0V9RY09NGZ`2FUj/0UIR[09BFZ@2CUJL0UiZZ09NIZ`2GVZl0
TYF[0080TIBX00X0TYBW09:DZ02CUJP0UIFY09BDZP2BTZ/0UIJ]09>EZ02BUJD0TI>U0`2?TJ<0302<
T:40RY2P08bAX02<TYl0SY>P08jAX@2<SJ80RXbS08J9W`28SJ40Qh^O08R=W`80RXfM00/0RHZM08R8
W`26QZ40PXFQ07n4WP1kPiL0OHBE07f2U@1mPID0Oh:H07n1VP0207aoV@0;07YnUP1iOYD0NGbB07Yl
TP1iNi80MWRB07AgU01`M9@0Jg6B06YaS`1[M8/00P1YLhH01P1YKhD0JVj506IYP@1WJX<0IFUm05aR
L1[ooooo[@3oool?ooooo`003Oooool01P1[KX80MgbA07MmU@1hO9H0NG^F07]nV080NgfI00/0O7nL
07eoWP1oPil0P8FO0824VP21QY/0PHNN08B;XP22RZ40PXbQ08>?X@0208B?W@0;08F@W@24SId0R92R
08F=X@26SJ<0QXjR08Z@X@2;TZ80Ri2T08^@YP2<SjP00P2<SZP0302<T:T0RhnX08^@Z02:SjH0SI:W
08nCZ02=TJX0SI:/08jCZP2?UZT0SiFU096EY080Si6S00/0T9:V08nCZ02?TjP0SiBX08fAY@2>TJ@0
S8fQ08^;XP27Q9l0QXFM08:2V@020822U00607n1S`20PHh0P82?07ioT01lOY00N7f>0P1iOhl00`1i
P8l0PHRC08N=UP0208^BV`0;08fDW@2@VJ00TYZO09>KW`2BVZ40TiVU096GY@2CVjH0T9RS09>LYP2B
VZ800P2DVj40302FVj<0V9^V09BFY@2BUZD0U9RV09FJZ@2FV:T0V9VY09JGZ@2CU:L0TYFV09:FY@80
U9NU00/0U9NT09:DXP2FUJH0UYNX09>FY`2DUjP0UIVX09JJZ02DUZL0UYR[09BGZ`02096EY`08096D
YP2EV:L0TiFS09FEX`2BTZ80UIJU096BXP2AU9l2096DW@0?08jBW02<T9/0S92K08bAW@2:Sid0RY2K
08R>V02;TIL0SI6H08^>V@2:Rid0RHVP08N8W@29RYd0RhfM0080RHZI00/0RHRH08V8V`23PYT0PH6J
0864W01nPYP0Nh6D07b2TP1mPY80OX2D07n1U@0207anT`0;07QjSP1iO8l0N7Z>07MgR`1gMX/0MWJ=
079cS@1bM8h0KG6<06Q^Q`1XKh@00P1YL8<01P1ZKh40JVen06IWN`1UJ7X0I6Qg061WLA[ooooo[@3o
ool?ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`003Oooool01P0@4@T04148014A2P0A4@/0410>01<C4@805AHB00/05aPB01HG3`0F5`l0
61P@01LH400H6Q005a/@01@G3@0D5`h05AL>01HH3`0201PI3`0;01LI3P0E60h051P=01<F3@0A50d0
4aL?01<H400D61004aPA01DH4P0H6Q<00P0H6A<0300I6A<06AXB01TK4@0I6a806A`C01TM500I7A<0
6AhB01XO4`0I7Q806AdA01LJ4@805a/C00/06QhD01XN4`0H6a4061/@01TK4@0J71407AlC01`O4`0L
7AD071hG01/M5P0301`P6@0:01/O5`0J7QH06A`E01XN5@0H71@05a/C01PL4P0I714061/A01XL4P80
6QdC00/06ahE01/O600J7aP06alG01dP600K7QD06QdD01TL500H6Q@06ahG01`O5P0201`P500<01XN
4`0M81H06ahD01/O5@0L81H071lF01hP5P0M7a<071dC01dN5@0M7QH07AhE0P0M7QH00`0K7AH06QdE
01XM5P0201PK5@0601PK500I6a<06a`D01XK4`0I6a8061TA0P0H6Q402`0J71<05QLA01DF4@0E5Q00
5AH>01LG400G5a805ADA01@D3`0F5a805QHB00805A@@00`04A0;01<C2`0C50d04a@<01<E3@0E6@d0
4QL=010E300A50`03a8900hA200>40T200hA2@0;00h?1`0>3PL03a4;00hC400>4Q@03A0G00h>600?
31D03P`>00d>2`0:30T00P0<3P`0200<40h020/=00421@000080004100000@0000<00@050P0000H0
2@0000@0000300000`0000<0000200000@0200400`4100<0000Jooooo`0602lj6P0]>QX0:STL02Xh
8P0Z=bT0:SP/0P0[>2d02`0]>C40;3Pb02hg=P0`>CP0<3Ti034j>P0a>cP0<3/h034m>@0c?CT0<cdj
0080<S`i00/0<c`j03<m>`0c?CT0<S`j03<n?00d?Sd0=T4n03E0?@0e@Sh0=D4l03I4>`0203I3>P0<
03M4?00hASh0>DLo03]9@@0lBd80?D]203e;A00nCDH0?di7041?B010CTP0@4i90P11D4X02`11D4T0
@E18045@B@14DdX0A5=904ADBP14ED`0AUM=04AEB`14E4`0AUI>0080AeM>00/0AeQ>04UICP1:FTl0
Be]?04]LD01<GE40CEiA04aLCP1<GDl0CEe?04]MC`0404eND@0904]LC`1;G4h0BUY=04YJB`1;GDP0
@UDj01DP3P0@60L041H600802a0300@02@d200P<0P0830801`L00P071P0010030`000P<000420000
0P0200<400<00`<000X00`8000D20`050PH01P@600<21@020P@010@200H60@061@402@T30P0;2`D0
2`0>3PP03a49018C2`0D5@d05AH=01DG3@0D5Pd04a<=010@2P0>3@T02`/800<030`800/02@X600L8
0`0620<01PL100D70@031@000`<0008200010P000P<000<3000200D60@0;00L80P051`4010D000H6
0P0:2P@03a0800lA2@0?40X0414;00lA2`0?40/00P0=40X02`0?4`/02`h9004200010`000P<00043
00000P000@40004200000`0000<10080008500H0008900013@0101000P0<00D41`000@0?ooooo`00
3Oooool01P0i@3P0?DDm0419@@11Bd<0>D0m02<X:`806alP00/0724L01LK5@0F6a805a/?01TO400L
8A80720B01dQ4P0M81407B0B01`O4@0201dP4P0;01dQ4P0L8A80728C01XO4`0K81<0724D01XP4`0K
8QD0728G01hS600P8aX00P0O8aX0200P8aX082@H024U5`0P91L07B8E01dS5`0N9AP082PF0P0S:QT0
3`0S:1T08RDH028V6@0R9QT092PJ028W600Q9QL08RLH02@Z6@0U:QX09b`L02H[7@0V:R0092LO02@W
7P0202@Z800;02<Z7@0T;1`09BhL02H]6`0X;Q`09R`M02HZ7P0W:ad09R/L02D[6`0V;1/00P0W;1`0
2`0W;Ad09RdO02<[7@0S:QT09B`J02@[6P0V;1/09R/K02D[6P0Y;a`0:2hK0080:2dI00`0:2lK02T_
7@0U:QT09R/J02HZ6`0U:A/09b/L02X^7`0/<200:blP02`_8@0];b4202``8P0;02X_8P0W;1h09b`K
02L]6`0X;a`0:BlN02``7P0Z;ad0;30P02`^800Y:al00P0Z;B002`0Z;R809RTP02@V7@0S9QX08RDI
02<U6@0V9Q`09BHM028T700R91/08B<I00807R4F00`07b4E028U5P0Q91H08R@E028U5@0Q9AD07b8C
01dQ4P0M81407B4A01`P400L7a4201`P4`0;01/O4P0K7Q806alB01TO4@0I81407bTI00d@3@0<3P`0
30h;00/=2`0:30T00P0A5@h02@0C60l01`T500H70P0620<01@L300@60`061`@01PL500H81@0200D8
1@801@P400H01@L400D81@0520@01PT300H80`0820<Jooooo`06041=A@1EIeH0@U5703I0@@0b>480
=S]:0P0h?dX02`0k@Dd0>Ci=03a1D`0nA5D0?TIF0459F013C5X0AE1L04MBG@18DUd0B55L0080B59L
00H0BE9N04UCG`17DUl0Ae9O04IBG`18Df0204UDH00304]FHP1;EF00CUMO0080C5AM00`0CUMP04mI
HP1=F680CeYS055KH`1AFf@0DEYW059LJ@1DGF/0EEm/05EMJP1FGf`205QQKP0;05USKP1JI6`0FfE[
05aVK01MIfh0GVUa05iZLP1NJW00Gf]`05m[LP1PKG@00P1QKg@02`1SLGD0IgAg06QeN@1XMGP0IWEk
06IeO@1XN7d0J7Uj06UjN@1/NgX0K7]k0080K7]m00/0K7]n06elOP1^O7d0KWek071nN`1`OgP0L7mg
06ioLP1JJ5`0FFQJ05UWF@0205MSE`0<05EQE01EH5@0DEaA03Hj>00c=cD0<3@b02`a;00Y;RP0:BdX
02P/:@0X:bT09bTY0P0V9bL02`0U9bH092LU01<A5`0?31<03PdA00T:3@072@X01`T600P:100930D0
2Pd400802@`300L02Pd400T=1P0;3@H030h600`=1P0?4@T03a8:00803a<;01003a8<00hA3@0>4@`0
3Q4<00h@2P0<3PP02@`500T<0`0930402a0200dA100>4@H03Q8800hC2P0=4@X03A090P0>40T01@0>
3`P030h700T;100:2`D02`h500803Q4800@03A0700/>1P0930@020/40P0:3@D02`0930@01PP100H9
0P062@801PP300H8100930L020/600<50@011@400`D:00800`@D00H00P<F00@460081aL030P;00/8
0`061`4?ooooo`003Oooool01P2DZYH0VK6M09bfX02M^:00SjJ@0419B0804Q@J00/06AdL01<F500?
4Ph03Q89014E2P0E6P`05a`<01LL3@0H70`06Ah=01XO3P0201/O3@0:01/O3P0J7@l06QdA01/N4P0M
81D07R8G01dR5P0M8aP07B8H01dR6@<07B<I00`07R<I01lT600O9AH07bDF01dR5@0N91H07RDE01dU
4`0O9Q@08BHF028V5P0R9AD2024T5P0;028T5`0P8QD07R0C01lR5@0Q9AL082HH028W600T:A`09BTP
02<V7`0R9Qh00P0T:Al02`0S:A/09R/J02L]6@0W;1L0:2`H02/_7@0Y:ah0:2/M02X/7P0Y;Ad0:2`K
0080:2dK00/0:2`L02DZ6P0U:QX09R/K02P_700Z<A`09RhK02@[6P0U:QP09bdH02P]5`0202P^5`0<
02P]5`0W;1L092TE02@X5P0U:AT08bLH02DW6@0W:A`0:BXO02X]8@0/;R40;S4S0P0/<B802`0Z;b00
:2dM02T`7P0Y<Ad0;3<O02hd800^<b00;C4Q02hc8`0_=2D0;C4R0080;S4R00/0;S8T02h`900[;B80
:2XP02P/8@0Y;R40;2lR02`_900W:b009RTL02DX6`0202<U6@0<02DW6P0T:1T08bLG02@V5P0U9aL0
92LG02<W5P0T9QH08bDE02@W5`0S9QL082@F0P0Q9AL02`0O8aL07R8E020S5@0O8a<0724B01`Q4@0K
7a0061`>01DJ3`0E6A405APC00805AXC00/05Q/A01DI3@0D6@`051P=01<F300A50/051L>01LI400F
61404aHA018E4003018F4@0501<F4`0D6A805A/B01@I4@0C5a006_ooool01P0b>4X0=Ca>03@jC`0e
>E00=CUA03DiDP80=caB00/0>3eB03PmD`0i?UD0>3eF03U0E`0k@EP0>D1G03Y0E`0k@UP0?TEK03m6
G0020459G00;049:G012Bed0@DUM0418GP10BEh0@D]P04A<H013Bf00@TYO04E<G`16Bed00P16Beh0
3017CF80BTmU04Y?IP1:D6D0Be1T04aAIP1<DFP0CE9Z04aBJ@1=Df/0CE9[04iCJ@80CeAY00/0D5EZ
051FJ@1BFFT0DeYZ05AKK01EG6l0EUe`05IMK`1GGfl0F5m`05YRLP0305]UL`0:05mXMP1PJGP0H6Yh
05mZNP1NJG/0HFaj069^N@1TKgX0IFmj06I`N`<0IW5l00X0IW9l06QdO@1YM7d0JgIm06agN`1]NG/0
KWal071nOP1aP7l0LH1m0P1dPWd0301ePWh0Mh:007J2P01cOgl0Lh1o07:0O@1bPGX0Lh5h07B0M`1d
OgL0MH1i07AoNP80Lgij00/0L7af071oM00i?D006a/Q01/L7`0A51@03A4>00X=2@0:30@02@`300T<
0P0200P;0@0300H:00031P000`@0008010D000H010@000D60@051`4010D100H70`0720<300H50P0;
00L60`061`<01PP100H90@0?4`P05AX;01PM3P0J81007B<C01`R4`0J81800P0L7a802`0L7Q<061X@
01@E300A4@P03Pl700`=1P0;3@D02P/400L:0P062@001PP0008010H000<00`@00084000210000P03
1@001P051`802@`600X=1P082`800`D000<40P801@D400H01@H400d?1P0D5P/06AX=01HG2`0A4PX?
ooooo`003Oooool01P2G/9h0VkFT09njY@2M^:40VkFM069cI`806AdR00/05ATI01HJ5`0B5Q804aP@
01DJ3P0G7Ph06B0=01PO3P0H7Ph06R0?01`Q4@0201lR4@0:01hP400O8A<07alE01hP600N81T07b4J
01lR6P0N8a/06R0H01/Q60<072<I00`07RDH01dU5`0M9AD07B@C01lU500R9aH08RTF028Y5@0R:1D0
8bPG02@X5`0S9aH202<V5`0;02@W600S9aL08RDF028V5`0R9QP08RHI02<W6@0V:ah09RXP02<W7P0Q
9Q`00P0S:a`02`0U;AX0:2hG02X^5P0Y;1H0:bdI02l`7P0`;b00;2`O030`8P0^;b40;BlP0080;RlO
00/0:B`N02DW6`0U:1`09BTL02P_700Z=1h08b`H02@/600U;1L09bdG02L]5P0202L/5@0<02P]5`0Y
;QX09RXH02DX5`0U:1T09BLK02DV7@0W9al09bLP02PZ8P0[;R@0;C0T0P0[<B802`0Z<B009bhM02L_
6P0Z<AX0:c8K02dc700/<Q`0:S0M02/`7P0]<R40;C8R0080;C0R00/0;c4S030c900]<B80;30T02/_
900Z;b80:c0R02``8@0Z;Ql0:2dL02L[6`0202LY6P0602HY6@0U:QT09b`J02L[6P0W:QX09BLJ0P0T
9QP0100T9AT09BDK028S6P0Q8QT2028T6P0;01lT600N8aH07B8E01lU5P0N9AD07RDF01lU5`0M8QD0
61hB01LM4`0F6Q@00P0E6Q<02`0E6Q405AX?01PL3`0G6Pl05aL>01LH3`0I6A406AXC01PJ4`0F61D0
51LD00804aHC00H05QTE01DH500E6A<05a`D01HK4`0E610Jooooo`03038hB`0c>4l0<cQC0080<cUB
00h0=C]D03DkD`0e>e<0=SaD03HlD`0h?UD0>3mF03PnEP0k@eP0>3mD03U0E@0j@UD0?DEH03i6F`80
@4QK00/0@DYM049:G`12BUh0@dUN04=9G`13BUl0A4]P04A<H@15C680ATeR04M=HP0204Q<H`0<04Q=
I018CFD0BTmV04aAI`1>DFH0CE5U04mDI`1?E6P0CU=W04aDI`1>EFT0D5IZ0`1@EVT02P1BFVX0DEYY
05=JJ@1DFfX0EUe/05IMKP1GGVl0Eem_05UPL01JHW8205aUM@0;05eUM01OJ7D0GfQf065ZN01QJgT0
HVaj069/N@1TKWX0Ifmj06Q`N`1WL7/00P1VLG/02`1VL7T0JG=k06YdO@1YM7h0JWEn06]hOP1]NGd0
KG]l06ilO01_OGh0L7el0080LGml00H0LWmn079nOP1bOWh0LWmo07:0O`1dPWh207F2O00407F1N`1e
P7/0MH1k07N1OP80MGmn00/0M7mk07>2NP16CE00820Y020R9@0G6AX0418@00hA2P0<3PD020`200P<
0`0200T<0`0;00T=0P0520400`D000<400031@0010<000D400051@002@P000`;0`0;2P<00P081P80
3006104020L200L80P061`401@P100dA1P0D60X061`=01`P4@0N8a@07b<E01hR4`807R8A00/07B0@
01XL3P0F5`/04Q<:00d?200;30D02@/500T<1@0930@02@`200H:0@0200@7000600@500031@0010L0
00D80@041P4010H00P072P400`052@000P@00083000200<3000600@3000:2`004A4501@D2@0C4`T0
4A8;3oooool000gooooo00H0SjJD09^eX02P_JD0Wk^S09jkX024WHP203U5@00;01PL7@0I7QX04aTC
014E3P0C60l051X>01LM3`0J8A40728C01`P4`0O8aD00P0Q91L02`0R8aH08R<G024R6`0P8Q/07R0I
01dO600K7aL0728I01/Q600L91L072<F008072@E00`07BHE01hV500P9a@07bDC020W5@0S:AL08RHE
02<W5@0U:AP09BTI02DX6@0T9aP202@X6@0;02@Y6P0U:aX09BXH02DY6@0S9aP08RHH028W600S:1/0
8bPN020V7P0P9Qd00P0T;1d01P0W<1d0:S4J02/a6P0]<1/0;BlL02`]7@80;blQ00<0;S0Q02la900_
<2<00P0_<B802`0];b40:B/N02X/800X;1l09B/J02D^6@0U;AP092/F02H]5P0W;AL0:2hH0080:S0I
00`0:blK02T/700W:Q/09R/L02<Y6`0T9a`08bHL02PZ800X;240:BdR02/_8P0/<R8202X`800;02Ta
800Z<Ql0;3<N02le7P0`=Ql0;c@Q02`_800/<280:c0S02`b900^<RD00P0]<R@0200^=2@0;c<T02hc
8`0^<b<0;S<T02`b8P0]<b40;38O0P0]<Qh01P0]<B00:bhO02/^7`0Z;Al09b`M02L/7P80:2`O00D0
9BXN02HZ7@0W:Q`092LJ02<U6P02028T6@808bHI00/082DF01lV5P0P9QD08RPE024W4`0O91@07b<F
01dR5@0J81D061hE01HM4`0201HL4@0;01HM4@0H7Pl06Ah<01TL300I6Pd06AT?01/M4P0K7Q<06A`D
01XM5P0G6aD00P0F6QD01P0H7AH05a/D01HK4P0G7Q805Q/?01DH3A[ooooo00H0=CY<03DiD00d>E<0
=CYC03DkD@0f?58203PmD`0;03TnE@0i?UH0>T1F03U0E@0i?eH0>d9F03]1D`0j@E@0?DAE03m5E`0o
AUX00P10B5/01`10Aed0@TUN04=:GP14BUl0A4QP04=8H@13BF400P14Bf804016C6<0ADaT04M>I@17
CVD0AdeT04Q>H`19CV<0BdmT04e@I01>DVD0CeAV04iCIP1>E6H0CEAV04iFI`1?EFL2051EJ00;055F
JP1BF6/0DEUZ059JJP1CFfX0EEa[05MNK@1HGW00F5ia05UQLP1JHg800P1LI7<02`1MIG<0GfQd061Y
M01RJgH0HVag069/N01SKGT0IW1i06I_N@1WKgX0J71k0080Ig5k00/0IW1h06QaM`1ZM7P0JWAi06]f
N`1[Mgd0K7Qm06eiO01_Ng`0Lgin07AoP00207F0O`0<07>0O@1cP7`0Lh1n07>1O`1bPGh0M85m07F2
O@1dPW/0Mh=m07R3OP1hPgl0MH1n0P1eOgd02`1dOg`0Lh5j051HFP0P7b`07R0V01TK7@0C51@03Pl=
00`=2@092`H01`T400801`X300/020`200D900031P000P@00083000410001@D000@5000820002PT1
00X90`0200P7100<00D60P092PD02P/300X=0P0930402P`200h@1@0E5`T06Q`<01hP4@0O8Q<082@B
0P0O8Pl02`0N8Pl071l>01LH2`0B5@/03Q8:00/>1`092`D02@`500P;0`0930<02@`400802@d200/0
20X000H900062@001`T100H80@051`0020/000L:00031`000@<000<3000200@2000600@100071P00
3@d4014@1P0B4`P051D<3oooool000gooooo00H0GFUI07V;L`2=YHP0U:jB09ZgV02G]ID205mdGP0;
01XP700@51403a@>00`@2P0>4@/04AD=01DK3`0H7Q406AlC01XO500N8aL00P0P9AT00`0R9aX08RHH
024U6@03020S5`05020S5@0M8A@07R8D01lT5P0N8a@00P0N91<0300O9Q@08BLF02<X600T:AX082HH
028Y6P0R:AT08BLH02@Z6`0U:Q/09R/J02L/6`809b/J00/09BXI02DY600U:QP09BTI02<V5`0P9AH0
7bDG01lU6P0P9Qd082LO02<Z7`0202H/800;02H^7P0W;a/0:S4L02/a700]<Qh0;30O02da800/;ah0
;C4P02hc8`0_<b@00P0_<B402`0`<B00;RlN02d^7P0Z;1/0:BdK02L]6P0T:aL092/F02H/5`0X;QT0
:BlK0080:30K00`0:2lL02L]700W;Ah09R/M02D[6`0T:QT092PF02LZ6P0Z;1d0:R`N02/]7`0/;al2
02X_7`0;02/a8@0/<b40;C@R030g900a=bD0<3@V02lb:00_<bT0;34X02/`9P0[<B@00P0/<R<202`b
900902`c8P0]<b40;S<Q02/a7P0]<al0;cDN030d7`0`<R00;c4Q0080;C0R00`0:blS02T^8@0V:al0
9bdP02@[7@0S;1d092`J02D[600U:QT092LH02<U5`0R91H2028U5`0;024S5@0Q9A<08RHC024V4@0P
9100720A01hQ5P0K7aD06AdF01PO5P0G7Q800P0F71002`0D6Ph05A/<01@J2@0E6PT05AX:01DI2`0H
7A006AhB01TO4P0J81@06b4D00806AlD00H05ahC01LM400F70h05Q`<01LK3@0E60`Jooooo`0603@j
B`0d>4`0=CY@03HjD@0g>e00>Ce@0P0l?e<02`0l?eH0>cmG03TnEP0i?e@0>d1D03e2E00n@U@0?d=D
0496E`12AEX0@TIM0080A4YP1013BV001`13B680A4QQ04A:H@15Bf80A4]R04I<H`17CFD00P18CVH0
3015CFD0AdiT04Q=HP1:CV80C51T04iBIP1>DfH0CE=V04mEI@1?EFH0D5EW051EJ080DUMY00/0DeQZ
059HJP1BFFX0E5a/05AKK01EG6`0F5i_05QPLP1IH780FF5c05]SL`0205aTL`0;05eVM01NJ7@0GfUc
065[M01QK7@0HVef06A_N01TL7P0IG5i06IbN`1WLWX00`1XLgX02P1YLgP0JG=f06]dM`1/MWP0K7Mi
06ahN@1_NWP0L7]i079nO@1cOWd207B0OP80M85m00<0M8=m07:1O01bPW/00P1bPG/01@1dQ7`0MhAm
07R3OP1hPWh0MX1m0080MX5k00/0MH1i07B0N@1OJ6H09RHc01hP:00L828061/J014D4P0<3`d02P`9
00T<1@0200P;0@0500L:0005200010L000@700031@000P03100010041P0020T100T:0P0:30D200X<
1P0<00T<1P093@H02`d300dB0`0=4P802`d100X<0@0@50H05QX901/O3P0N8Pl07bDB0P0N8a40200M
8A0071l@01XM3`0F6a004QL<00lC2@0=3`L02`h50P0;3P@03@0:3P802a0200/@0P0<4@402@d100L;
0@082P801PP100@5000620001PT000<6000110000`010P001P010@000`@000T<100?4@H04A@7018E
2Poooooo000=ooooo`06028X700_=RP0@T`j05ASB@1[PEl0Pime0P1bRf@02`0T:Qh041<>018H3`0?
4Pd03A0<018F3`0E6a005Qd@01TO4P0K8Q@07B@F00807bDG00/08BHG024U5P0Q91L08B@G02<U6P0S
9a/092PK02<V600R91H08RDF020T5002024V500<028W5@0R9QL08RDH028U6P0Q9a`08BTK024X6P0R
:AX08bTK02@Z6P0U:a/09bdJ0P0Y;aX02`0X;AX09BTH02DX6@0U:1T092PJ02@Z6P0T:Q`08RTL02<[
7P0S:Qd08bXK008092`K00/09BdL02D_6P0V;QP0:C4I02X`6@0Z;aX0;30M02/a7P0/<Ql0;38Q02ld
9P02034d9P0;034b8P0a<R40;RhM02h_700[;a/0:BhK02D/600T;1P08b`H028Y600S:aX00P0T;1P0
300V;QX09bhL02L/700W;1`09b`K02H[6@0U:1L0:2XH02`^700[;A`0:b`M02`]7P80:RhO00/0:RlO
02/a800/<R00;S@Q030e8`0b=RL0<C@Y030e:P0^=2P0;C8U02/a8@0302`a8@0:02`b8`0^=R@0;cHS
02le8P0/<Ql0;C<P034e8@0b=1l0<S<P02l`7`80:bhM00`0:blN02P/6`0W;1/09bdK02D[6P0T:aX0
8b/H02<[5P0V;1H09b`I02DY600S9QL202<W5`0;02<V5P0R9QD08B@E01lS4P0M8A406b4A01dR500K
81D06AhD01LN4`0G71000P0G70l02`0C5`/05AT<01DI2`0C5`T04aH801DH2P0G70h061`?01LM3`0I
7a406R0C00806AlC00H05adA01HL3`0D6@/051L701@F200B50PJooooo`0603@kB@0f?D`0>3i?03Pm
D`0h?U<0>SmB0P0l?e402`0k?e@0>T1G03ToEP0k@ED0?49C03e4D`0oAE@0@DME04=:F@13BEh0@dIO
0080A4MR00/0ADUT04I<I@16Bf@0AD]S04I;H`17C6<0AdeT04Q?IP16CVD0AdiU04Q?IP0204Q@I`0<
04I?I`19DFL0BE5T04]AHP1>DV@0Ce9V04iCIP1?EFH0D5MW051FJ01AEVT0DeUZ0P1CFF/02`1DFF`0
DeY/05AJK01DFfd0EE]]05MNKP1HGfl0FF1`05QOL01IHG80G6=c00<0GFId00<0GVQe061[M01RK7@0
0P1QJg<01@1RKGD0I71h06A`N@1ULG/0IW9j0080JG=j00/0JgEl06aeN`1[MGP0JgIh06agN01]NGP0
K7Uf06ilMP1`OGT0LGim079oOP0207>0O@0<07:0O@1dPGd0MH=n07>2O@1ePgh0M8=n07B2OP1fQ7l0
Mh9n07R3OP1hPWd0MX5l0`1eP7/02P1gPW`0J79_02d^>P0T9Bl0828W01lP8@0I6aP04A8?00/=2007
208200D8000400L:00062P0010L000@70@800`D000D010H100D70@092P802P`400/?1@0200`@1@80
3A4800X0310700hC1P0>4`L0310600T<0`0=4@L04QL;01PN400K8A807RDC0P0O9AD02`0L8A<06alB
01/O4P0I7a405ad@01HL400C60`03a@800/@100;40D02Pl40080314400/03A8300/@0P0;3P<030d3
00P:00041@001@D000H700051`0010H00083000200020006000100000P001PP200`?1@0?4`P04QL;
3oooool000gooooo00H08RPL02lf:012C3X0E6=906^1G`23WgD207:;I00;02@Z7P0@4`h04QP?00lB
3@0=40`04QH?01DK400F7A006AlB01/R500M91H00P0O9AL02`0Q9QL08BDF024T5`0Q91L08bDJ02<W
6`0T:1/08bHH028T5P0R9AH082@D00808BHD00`08RLE028V5`0R9AP08RDJ024W700Q:A/08BPJ028Y
6P0S:A/092XJ02D[6`0W;AX202T_6P0;02P]6P0U:AP09BPI02DX6@0T:1X092XJ02@Z700R:A`08b/N
02<Z7@0S:Q/00P0T;1/02`0U;A`09BlJ02H^600Y<AT0:S0I02X_6P0/<1d0:c4N02`b7`0/<R40;c@V
0080<C@V00/0<C8R034b8@0^;Qd0;RlL02/_6`0Y;Q/09B`H02@/600S;1P08RTH02<[6P0202@/600<
02H^6P0W;Q`09b`L02L/700W;1/09R/I02DX5`0X:QP0;2hL02/]700[;1d0;2dN0P0Z;Ql02`0Z;al0
:c4P02`b800^=240<3DS038f9`0a=2T0<3DZ02hd:00]<RD0:c4Q00<0;34Q00X0;38S02hf900_=R<0
;cDR02`b7`0]<b00<CDQ038d7`0b<b00;c0O0P0[;Qd0300[;ah0:2`K02L/6`0W;A/09B/J02@[6P0S
:aP08b/F02H/5P0W;1T09BTH02<V5`808bLG00/08bHF028V5@0Q91D07b<B01dQ4@0K8A407B8D01/P
5@0I7Q@05ahC01LL400201LL3`0;01<G2`0E6@`05AT;01<G2@0C5PP05AP:01LL3P0H70l05ad?01TO
4@0J81<00P0I7a<01P0G7A405Q`?01@I2`0D5`L051H8018D21[ooooo00H0=3]903HmC00h?Tl0>3eC
03PnD`0j?e8203`oD@0;03/oE00j@5L0>CmF03]1E@0l@U<0?DAC03m5E011AeD0@dYI04=9GP13AUl0
0P14Af802`15BF@0ATaU04I;I015Bf<0AT]S04M<H`17CF@0B4mV04I>I@17CVD0B4mV0080B51W00`0
ATmW04UAI`19DF@0Be5R04iBI01?DVH0CU=V04mEIP1@EfL0D5IX055FJ@1CFFX205=IJ`0;05AIK01C
FV`0E5Y/05AKK@1EFfd0Eei^05QOK`1IH700F5m`05UQLP1LHg<00`1MIW@00`1NJ7D0H6]d069/M002
065[L`05069]M@1TL7P0I71i06EaN`1VLWX00P1YLgX02`1[MG`0K7Ek06]eN01[MWP0K7Mh06eiN01/
NGH0KWaf071mN@1aOWd0LWmn0080Lh1m00`0LX1m07B1O@1ePgh0Lh9m07F3OP1dPgh0M89n07J4O`1g
PWh0N8=n07R2O@1fPG`307F0N`0:07N2O01XLVl0;Bhj02@U;`0P8RL07b0Q01TK600A4Pl02`d800L8
0P801@P000@01`X000H:00041`0010L10P031@001@041P401@L100T:0P0:30@02`l5008031050P0=
4@P02P0<40L03Q<600hC1`0<40H02@`300dA1`0B5`/061h@01/Q4P0N9A<201lU5@0;01`Q4`0K7a80
6alB01TO4@0G7A005Q`@01<H300?50P02a0400/@1@0:3`@00P0<4@@02`0=4P<02a0200/>0`0<3@<0
20X000@500051@001PL000D700041P000P<00080008000H0004000020006208030l500lC200B5`/?
ooooo`003Oooool01P0D6@l06AhC01/P5@0K8AD0:2lN03a7;P80@Dld00/09R`L024V6@0L8AH05a`B
01<I3P0E6`l05Qd@01LN4@0I7a<072<E01hT5P02024V600;028V6@0R9aT08RDH028T6P0T9Q/09BLL
02DX6`0T:1X092HH02@U5P0P91800P0Q9A80300Q9A@08RDF02@W6@0S9a/092PO02@Z7`0R:1d08bXN
02D/800U;1l092XL02@[6P809bdJ00/0:BhJ02L[6@0W:QT0:BdM02T]800Y;200:BdO02P^7`0Y;Qh0
:2dK02L]600202H]5P0;02H^600U;AP09RdG02/a6P0/<A/0;2hK02h`7@0^<Ad0;C4N02dc8P0`=BD0
0P0`<b@02`0a<R@0;S0Q02d_7P0]<1h0:RhL02T^6P0X<1X09blL02H^6`0Q:AP07RHF00808BPH00<0
8bXJ02H[6`0W;1`00P0W:ad01`0V:Q/092LI02L[6@0Z;Q/0:blK02X^700[;ad00P0[;Qh02`0[<1d0
;34M02`a7P0/<Ql0;c@R038h9P0b=bP0<3HY030f:00]=2@0:c4O0080;38O00/0;S@Q02lg900^=R<0
;CDR02lf8`0_=B<0;S4R030b800b=240<S<Q030a7P0202l`700<02d_6P0Z;AT0:RhK02X_6`0Z;a`0
:BhL02P]700X;AX0:2hI02T^6`0Y;Qd0:BlM0P0T;1/02`0R:1P08bPG024U5@0O8A<07b8C01lS500N
8Q<07R4C01dP500J7a806Ql@008061h=00/061`;01PJ300H6@d05aP<01HG2`0F60X06A/=01XM3P0G
70h061d@01TO4P0201PM4P0601HJ400D5`h051H<018F2@0A4`L03Q046_ooool01P0d>dX0=C]=03Hl
C`0f?E00=SeA03ToDP80>T1B00/0>CmC03Y0E@0j@UP0?4AH03i5E`0oAeH0?dQF0418EP12BUT0A4]N
04=8GP0204A6H00704I8I@18C6T0B4aX04I;I@18C6@0B4eS04U?I`0204Q?J@0904Q@J019D6L0BU5X
04YAJ019DFP0BU5V04]AI01<DV@0Ce=U0080DEAX00D0DEEW055GJ01AEVP0DUUZ05=KK00205AKKP0;
05=IKP1CFVd0E5Y^05AKK`1EG6l0EUi`05MOKP1HGfh0FF1`05aRM01MHW@00P1NI7D02`1NIgH0GfUg
069[N@1RK7P0Hfeh06A`NP1SKWT0IG1k06EaN`1ULW`0Ig=m0080JGAn00/0KGIo06efO@1YM7/0JWIk
06aiNP1/NWT0KWai06imN@1_OW/0L7mm07:0OP0207N4P00407J2O`1gPh00NHB107N3P080NHB100H0
N8B007V4P01gPWl0NX>007Z3O`1hPGd207N1O00;07J2O01gQ7`0LG]e03/mA@0V9S0092DZ02@V9P0N
7ad05aPC014B300;3@H00P082`8200P<000900T=0`0;3PD020X400D70P041P<01@H300P:100:3@D0
2Pd40080314500`02`l500`?1P0=4PP03Q<:00lD2`0?4`X030l700/=1P0A5@/061hA01`R500O9AD2
020V5`0;01hT5P0M8QD07R8C01XP4`0F71004aT=010F2`0?5@T0314700/@1P0;4@L00P0=4PP02`0=
4@D02a0200/>0P0=3P802@/000H9000520001@L000@700041P000`@000800@8000H0004000410006
208030l500hB200@50X?ooooo`003Oooool01P0>4PX041@=018E3P0D5Pl05aXC01/Q5`807RDI00/0
7B<G01/P500J7a8061h?01LO3P0F70`05Qd=01PO4@0F710061lA01/R4`0201lU5@05028W5`0R9QL0
8BDG024U5`0T9aT00P0U:1X0100U:A/092LI02DY6@0V:aX202@Y600<028W5`0R9aP08bPJ02<X6`0T
:1h09RXO02HZ800V:al09b/O02DY7P0S:1`09R/L0P0X;A`02`0Z;ad0:BhL02P]700X:ah0:B`Q02T]
8@0X;200:BhO02X^7`0Z;Qh0:2dJ00809BXF00/09B/H02T^6`0Y;a/0;38L02hc7P0_<al0;c8O02h_
7P0^;al0<C<S038f9P02034d9@0;03<e9P0a<b@0;S4P02hb8@0]<b40;34O02/b7@0Z<Qd0:C4L02L_
6`0T;AX00P0U;AX0300W;A/09R/K02HZ6P0X;A`0:BhN02L/7P0T:Q/09BdK02P`6`0X;aX0:2lL02Xa
7`<0;34O00X0;30N02da7`0^<al0;S@O02hc800b=RD0<cPY038h:@0_=BD0;38Q0P0/<al01`0/=1h0
;3@P02lf8`0`>2H0<CLV030d900`<R800P0a<R40400_;b00;RlN038c7`0b<al0<30N02`_7@0[;Qh0
:RhM02``7P0Z;Q`0:BdL02X^7@0Y;Q/0:2dK02X_7P0Z;b0202H^7`0;02@[6`0R:AT08bPG028U5P0Q
91D08B<F024T5P0P8QD07R0D01dQ4`0M81<00P0M7a001`0M80l06ah=01PJ300H6@`061T=01PI300I
6`/00P0I70/02P0J7@l05aX>01DI3@0E6@d05QT>01LJ3`0D5``04AD800lB1@0?4@DJooooo`0603<k
C00e?500=SeA03DlD@0h?e80>3m@0P0h?e802`0i?e@0>T5G03]2FP0l@eX0?TEJ03i6F00mA5H0?dIG
0458F@11BE/0@TUN0080A4UR00/0AdYW04Q<J@18CFP0ATaW04M=IP18CVL0BE1W04Q?J@19D6T0BU1Y
04Y@I@0204aAI@0<04]AI01=DVD0C55U04eBI@1>DfH0CeAW055FJ01AEfL0D5MV055GI`1AF6T0DUQZ
0P1AF6/02`1CFV`0EE]/05EJK@1EFVh0EEa_05MOL01HH740FEm`05]QL@1MHW80GV9d0080GFAe00/0
GVMf061YN01RJgX0Hfej069/NP1SKW/0IG1k06IaO01UL7/0IG5k06McO00206]fO@0;06efOP1]MG`0
JW=l06]eO01/MW/0JgQj06ejN`1^Ng/0Kgak0760OP1bOgh00P1fPh001P1gQ840N8>107V3P@1iPh00
NH=o07Z4P080NX>000@0N8=o07Z3O`1jPgl0O8B00P1kQ7h02`1hPg`0MX9j07R4N@1<CTl0928/02HU
:@0S92<0828N01dN5`0E5A00414:008030l600/020/300T<0`0<3`L03Q4:00`>2@092`P01`P700H6
1P082@L02P`800X<1P0200X=1P0<00T<100:3@@03A4700hC2P0@5@`041<:00d>1P082P803A0601HL
3`0L8Q@082LG0P0P9aP02`0P9AP07R<G01dR500K8A<05ad@01<G300@5@X03Q<900`@1`0;3`H02Pl6
00802`l600/020`300X=0P0930002P/000L800051P0010H000D700041P000`@00083000300420005
000200031@002P`200d@1P0>4PT03oooool000gooooo00H02`l700hA2@0>40L04Q<:01DG3`0G71D2
01XO5P806AlE00D06b0E01XP4`0J8A<06R0B01PO400201HL3`0?01XQ3`0L8a007B<A01dS4@0O9A<0
7b@C024T500S9QH08R@F02<U5`0T9QL09BPJ02@X700U:ad092/N008092/M00P08b/L028Y700Q9a`0
8bTM02DY7P0V:Qd09b/N02DX6`809RXK00P09RTJ02X/700X;1d0:2`M02X_7`0Z;ad0:c4O02/`7`80
:RlO00<0:C0O02P_7P0X;Ah00P0Y;Qh202L^7@0:02P_7@0Z<1`0:BlM02X`7P0/<Al0;S8O02/^7@0[
;Qh0;S4Q030c90<0<SLW00/0<cLX034f:00`=BL0;c<U02dc8`0/<R40;3<N02Xd700[<a/0:C8J02Tb
6`0202/d7@0<02/b7@0[<1`0:BdL02X^700Z;Qd0:BhN02P_7@0X<Q`09c8I02H`5`0V<1P0:C8L0P0[
<Ql02`0]<b40;c<Q030e8P0_=240;C8O02db7P0`=200<SHS03Di9P0c>BH0<3HS0080;SDQ00/0;C@O
02lf7P0_=Qh0<CPR034g8`0`=R<0<3DR038f8`0`<R40;RhP02d]7`0302d^7P0;02`]7P0Z;Qh0:blO
02/_7`0[<200;34Q02/_8@0Y;Al0:RhP02/_8P0Y;R800P0X;b002P0X<1l08RTJ01lW5P0O9Q@07bDC
020U500R9aH08BDF024S5P0P8QD301dO4`0;01lQ4P0N8A407Ad>01dN400L7A806adB01TK3P0J70d0
6ad=01XL3P0H6`h00`0F6`h01@0G6`h04aL;010D2@0@50T04A@901[ooooo00<0=Ce>03HoD00f@500
0P0g?e003P0i@540>45C03Q1D`0i@5H0>d=J03]2F`0m@e/0?TEJ03m6F00oAeH0@DUI049:FP12BU`0
A4]N0P16C6802`18CFD0BDiU04M=I016CV@0AdmS04Q?H@19DF80BU9U04]CI`1=DfT0CE9X0080CU=W
00D0CU9V04mBIP1>DVH0CE=V04iEI`02051FJ005051FI`1AF6L0DEQW059IJ01BFV/00P1CFF/02`1E
Ff`0Eea]05QMKP1IGW40FEma05UQL`1KHg@0G6=d05iUM01OIW@0GVEe0080GFIe00/0GfMg065ZN01S
K7T0Hfah06=^N@1TL7T0IW5j06McN`1WLgX0Ig=k06UdO00206YfN`0;06YeN`1/MG/0KGIm06ifO@1]
Mgd0K7Qk06ekNP1aOWX0LX1k07F0OP1bOgl00P1cP7h02`1gPgl0N8>007Z5P@1jQ880Nh>107^3P01k
Ph40Nh>007^5P01jQ7l0NhEo00<0NXAn00/0NH=l07J1N@1hQ7/0E5YI02<O:00T8bL08B4R024R7`0P
8Q/06AXB018C300200lA2`0;00hA2`0<40T030l:00d@2`0=3`X030d800T:1P0820D02@P400X:1`0:
2`P00P0930L030082P@01`T200X>1P0?50X04QL=014E2`0>40H02`/100h@1@0F6`h06R4C01hU5@80
7bHG00/07R@F01dT5P0N91H0728E01PM4@0D60d041@:00dB200<40L02a0600X>1@0200P;0`0;00L9
0P0;3@@02@/000X<00082@001@H000@600051`001PT000@6000210000P020`001P010`00008000<4
00092P40310400`?1Poooooo000=ooooo`0600H90P072`802`h4014D2@0H6a4061`D0P0F6A<02`0F
6A806QhG01`O600K7a@0720D01/P4`0I7a8061h@01PO400I8@l072@A00807BDA00/07bPC01lW500O
9QD092TI02@X6@0U:1T09RPJ02L[700W:ah09b`P02@Z800202@[8@809RdR00X09B`Q02D/800U;1h0
9b`L02L/6`0U:AT09RTH02L[6P0W:QT0:R`K0P0[;Qd02`0[<1l0:blM02`a7P0^=200;C8P02X`7`0W
;Ql0:2lP02X_800Z<1l0:RlQ0080:BlP0P0Y<1h02@0W;ad0:C0N02X`7@0Y;ah0;34O02/`7`0[<200
;C8R030f9@02034g9P0;038h:00a>2P0<3HY034g:`0_=BL0:c8T02Xb800Y<Qh0:C8K02Tc6@0[=1T0
0P0]=A`0300^=Ah0;S@P02ld8@0]<1l0;2hO02/_7`0[<1h0:S4M02Ta6P0Y<aX0:34J02Xa7080;38O
00D0;c<R030e8`0a=R@0<CLT030f8@02030e7P0402ld7P0a=b40<3HP030e8@80<3DS00/0<3DQ030f
800^=1l0;cHO02hd800_=B80<CLS030f8P0`=280;S4Q02h_800302//7@0;02X/7@0Y;1d0:BdM02T]
7P0[;b00;34P02/_7P0Z;Ah0:B`P02T]8@0Z;b800P0Y;Ql0100X;Qd08BPH020Y5@0O:1<201hV4@05
024W500S:AL08bLF01lS500L81<00P0K81<02P0N8Q@07B0C01`N4P0L7Q<06ahD01XL4`0K7A807AlA
01`O3`0I6Pd301TK3@0601TK300I70`061/<01DI2`0C60/04AH;6_ooool01P0g@540=d1B03Q1E00h
@E<0>D5C03]4E@80?4AH00/0>dAJ03a3G00mA5d0?TMM03m7F`0oBEX0@DYJ0419F@12Be/0A4iM04I>
G`0204M=H00504Q>HP18CV40AdmQ04M@H@18DF400P19DV40101:DF<0CE9X04iBK01?Dfd204mDK00<
051DJP1@EFT0D5IY04mDJ01@EfT0DEQY051FIP1@EfD0DUUW059JJ01CFVX0EEe^0P1GGVl02`1HGVl0
Eee_05UPL01KHW80GF9c05aSM@1LIGH0GFEf05iVL`1OJG@0GVMe0080GfQe00H0H6Qh069[N01TKGT0
IG1j06EaN@1VLgP206MdN00306QeN01YMGX0JWEk0080JgEl00/0KGMn06egO@1^NGd0KgUn06mkO`1`
OGh0L7ij07:0N01cP7X0MH5m07B1OP0207J3O`0<07V5P01jQ800NhB107f7Q01nQhD0OHF307j5P`1m
QH80O8J107^5O`1kQWh0NXEm0P1kQWd02`1kQWh0NHAk07Z8OP1PJfD08b4[02<S:00S92H08B@R01lS
7@0K7QH05QP@00804a@>00/04A<=00lB300>40X03@l800h?200=3@D02@/400P800092P802PX400X:
1P0200T:1`0<00L91`0620D02@`800lD300B5`h04QH<00h@1P0:2@403`l501LI3@0K81807B@F0P0O
9QL02`0Q9aT082HI01lU6@0N9AP06R0E01DJ3`0@5@/03A4900/>1`0:3@D020/3008020X300D01`P2
00P:0P072@0020T000H7000200@6000400@7000520001PP000@600800`@000H00P<0000200051`00
30d200h@100<3PD?ooooo`003Oooool01P072P802@`300dA1@0B5`/061d@01TM4@805AL>00/04Q8<
01<F400A50h04QD=01@I3`0G7A406B0B01/R4P0K8Q006b<?01`T3`0201dV3`0;01dV4@0N9Q@07R@F
024V5`0T:AP092LH02DZ6P0Y;ad0:BlN02P^800V;2000P0T:b402P0U;2809RdS02L^8`0V;B409B`N
02H]7P0W;Ad0:2dL02T^6`0Y;QX202L[6@80:RlL00/0;34M02da7@0/<A`0;C8M02``7@0/;ah0:RhO
02T^800[<280:c0S02X^8P0202X_8P0;02/`8@0/<b80:c@Q02Xb8@0W<1d09RhL02Ta7@0Z<Ad0:c4M
02`c7P0_=R400P0a>2@02`0`>2H0;SLT034i9`0c>RT0<CTY02hh9P0/=b@0;3HR02`f7P0Z=1X0;3HJ
0080;3DK00`0;C@M02hd7P0^=1l0;S8P02d`800]<B40;C8R02`b8@0/<b00:c<N02Ta700Z<A`202dc
7P0;02ld800_=B80;cDR030f800a=ah0<3@K038e7@0a=Al0<CHP034g8@0a=R400P0a=b@02`0`=R80
;c<Q02hc800_=200;c@Q034f900b>2D0<CLT030f8`0^=280;30P0080:B`N00@0:B/O02X[800[;B00
:RhO0P0Z;al01P0[<1l0:RhO02X^7`0[;b40:2`O02L/7@809bhM00/09bdL02@/6P0T;AP08b`F01lX
4`0N9Q808RPE02@Y5`0S9aH08RLG024W5`0201dS500;01`R4`0K7a806AdA01PK400G6a405aXA01PK
4P0M8A@07AlD01TJ400G5``00P0J6P`01P0K70/06Q/:01TL2P0F6@X04aL8014D1a[ooooo00H0=ciB
03LoE@0h@5L0>D5G03U1E@0j@UH203Y2E`0;03a3FP0nA5d0?dEN0418G`10BF00@DYP04==H013CEl0
A4iN04M@H016Cf000P17CV002`18Cf40B59R04QAH@18DF40B59Q04]DI01<EFH0CEAW051EJP1?Df`0
CeA^0080CeA]00<0CeA/04mEJP1AEfX00P1@EVT01`1AF6X0DEY[05=KJ`1EGF/0E5a/05ELK@1GGfh0
0P1GGFh02`1HGFl0F5i`05UQLP1IHW80G6=d05eUMP1MIWL0GVMh05eVMP1MIW@0GVMe0080GfQe00/0
HVYg06A[NP1TK7X0I6ik06EaN`1VLGT0Ig=i06QeN01ZMWX0JWEk06]dN`0206efO00;06ifO@1_N7`0
KgUk079kO`1bOH00LGin07>0OP1ePGh0M89n07F1O`1gPX000P1hQ840301jQH40NXF007b6PP1mQh<0
OHJ407b5PP1mQH00OhN307n9P`1oR840OhV107n9P080OHQn00/0OHMm07R4N`1jQg`0K7Q_02h^=P0Y
:Rl0:Bh/028Y900J7aT05Q/D01<D3P02018C3@0;018B300A4@X040l900l>1P0?3`D02`/100P;0@06
2@0020/000P:0P0930D00P0:30H030092`L020X700/>2P0@5@`041@<00lC2@0?40H02PX100X90@0F
60T07B4B020V5`808BLH00/08RHI024V6P0O9AT07RDI01XP500C6@d03a<800`@1P0;3PD02Pd500X<
100200P:0`801`T300H010H000<500010`000P@0008500041P0200D7000900<500021@000PD00043
00020P001@D000/;0P0@4@H03a0700oooooo000=ooooo`0600H90`092`@02Pd400/?1@0=4PH04AD7
0P0D5`P02`0B5@T03A4900P;1@0930H03a@9018H300C60`05Q`>01XQ4@0L8a8072@B00807BDC00/0
7RHF01lV600P:1T08RPJ02<Y6P0R:AP09BdI02Pa6`0X<1/0:30L02P_7P0202@/7P0:02D]7`0U;B00
9R`P02P^8@0X;b40:C0Q02X`7`0[<Ql0:c4O02X_7@80:RlN0P0Z;ad02`0/<Ad0;C8M02ld7@0_=1d0
;S8L02la700/<1d0:2/L02P/7@0[;b00:c0Q00<0:c0T00X0:c4T02dc900/<b<0:S8P02P`7@0X<A`0
:C4K02/c6`0/=1`0;cHO0P0`=b802`0_=b80;CLR030i8`0b>b@0<C/V030k9P0`>RD0<C`V030j8P0^
>1l0<CXP0080<CTP00`0<CLP02le7P0`=Qh0<CDP034d8P0a=2@0<3<T02lc8`0_=B<0;SDP02`c7@0/
<a/202`b6`0;02da6`0`=Al0<3HP030f7@0a=A`0<CDJ03<f7@0e>B80<cPR030g8@0_=R400P0_=b40
2`0`=b40<3HQ02he800`=b40<CLR038h9@0a=b@0;cDR02lf8`0_=280;C8Q0080:RlQ00`0:B/Q02X/
8P0Z;280:RhR02/_8P0Z;b40:BhO02X_800[;b80:c0S02T^800V;1`202L^700;02D[600U:aD09B`E
02H]5`0U;1H08BHB024V500R9AD08BDF024V600P9aT00P0O9aT02`0O9QP07B<E01/P4`0J7A4071lB
01/O4P0L81<07b8F01hP5@0K7A406Q/?00806Q/=00H06Q`<01TJ2@0I6`X06A/:01LI2`0C5@PJoooo
o`0603LmE00h?eH0>d9I03Y2F@0j@UP0?4AF0P0j@ED02`0l@eP0@4EM0416G`10Af40@DUS04=<HP15
CV<0A4iR04E>H@16Cf40ATiQ0080B4mR00/0BU5T04UCI017D680B55R04UAHP19DF@0Be=V04iEJ01?
E6/0Ce=/04mCKP0204iDK@0<04mEKP1?EVd0D5IZ051GJ@1AEfT0DUU/05=KKP1DG6h0EUi_05IMKP1H
GG00FEib0P1HGG002`1IGG00FUib05YPM@1JHGD0G6Af05eUM`1MIWH0GfQf05mWMP1OIgD0GfUf0080
H6Uf00@0HVYh06A[O01TK7d0IVmn0P1WLGd01@1YLgd0JWEm06YfO@1ZMG`0K7Ek0080L7Mn00/0LGQo
071hO`1`NX00LGb2079mPP1cOH00M7n007N2P@1fPX40Mh:107V2PP0207Z4P`0307^5P`1jQ880O8J4
0080O8J400L0OHN407f6PP1nR8<0OhV3082:P`1oRX<0OhV10080OXQo00/0OXUn07^6O01hQ7/0MhAh
03Pj?P0W:2d0;34]024V800F6AD04A@@00hA300300h@2P0:00h@2@0=3`L02``300X<0P0:300020/0
00P<0P0;3P<02@`300X=10802P`400`020/300L90`0;30H03Q48010B1`0>40@030d200T800092040
5AP901`R4`0O9AP2020W6@07020V6@0O91P07R@G01hT5P0I7Q404QH;00dA1P0200/>100?00X=100:
30@01`X300L:0`062@801`T200<500010`000080000100010P000P<000<500041P000`@000800@<0
00H00@8000<300092@803@h5010A200@4PT?ooooo`003Oooool01P041@<01@L300@70@062@0020/1
00/@0P804QL600/04QP8010D1@0:3@802Pd400d@1P0<40H02`d500dA1`0C60`06AhA01`Q4`0201lV
5@0;024Y6@0Q:1X08RXK024Z6P0R:QT082PG028[5`0S;1L092dG02H_6@0W<A`00P0V;ad0300U;1`0
:2lO02X_800[<240;C8R02da8@0^<R40;S4Q02da800]<R00;S<R02hc8@80;34P00/0;3<P02he8@0_
=B40<3DQ02ld800^=200;C4P02`^7@0[;1d0:bhO02X]7`0202/_8@0;02da8P0]<R@0;C8U02dd900/
=B<0;3DR02/d8@0Z<al0:34K02Xc700Z=1h00P0/=Al02P0/=R00;cTR034k900`>b80<S/S03@l9@0e
?BD0<c/T03<j8`0b>B43038i8P0<038g8P0a=b80<STR034f8@0a=B00<cDQ038c8P0_<R80;S<R02le
8P0/<ah0:c4M0`0/<A/02P0`=Qd0;cHN030f7`0`=Qh0<SLN03@i800g?B@0=c/V038g900_=B0202he
7`0;02le7`0a=b40<CPQ030h8@0b>B80<3LQ02he7`0/<ad0:c8N02`b7`0^=B400P0]<b40300[;R00
:RdQ02`_8`0/;b<0;C0R02d`8@0Z;R00:RdP02/^800[<240:c0O02X_7P80:BlL00/09b`F02L/500U
:a<09b/F02P]6P0T9aL08BDG028V600Q9AL082HH01lV6002020X6@0;01lV600M8aD07B4C01lR5@0Q
91D07R0B01`P400O8a807R4B01`P4@0L81800P0J70l01P0H6Pd06Q`?01XL400J70l05aP>01<E2a[o
oooo00H0>D1B03Y1E@0k@UP0?D=J03i5F`0oAU`203m6F`0;03m6G011Aed0@DQP049:H`11BF<0@TYT
04A=I014CF80A4iQ04I?HP18DF800P19DV@02`1<DfD0Be9U04UAI@18DVD0BE9W04UCIP1<EFT0CeI]
051EK`1@E6l0D5E`0080DEMb00`0DUQc05=ILP1CFW00E5]]05=JK01CFf`0EEa^05MOL01HGfl0EUe_
05UOLP1KH7D205YPM00;05YQL`1LHG@0GF9f05eSM`1OIWP0GVIf05eVM@1OJGD0HF]f061ZMP1RK7P0
0P1SKGT02`1TK7X0Ifin06QaP@1XLX00Ig5n06QcOP1ZMGl0JgEn06afO`1^N7l0L7Z000<0LW^300X0
Lgj4079mQ01bOXD0LWf307IoPP1gP840N86207R2PP1iPX80NH>20P1kQH@02`1lQH@0O8F507b6Q@1n
R8L0OhZ707n:Q@1oRH@0OhZ4082:Q021Rh<0P8^200<0PXb300/0PH^107j8OP1lQgd0O8Um04E8B`0U
92/0:B`[02@W8P0I6aL04A8A00l?2`0200h>2@0;00l?2@0?40P03@h600X;10092`@020X200L90@09
2`<02`h500/>1P0;3PD00P092`@030072P802@/400/=1@0;3P@02`h200X=0@0:30402@X000`?0`0H
70d07B<D020W5`8082PI00/082LI01lT5`0P91H07bDF01/O4`0C5``03a8800/?1@0;3P@02P`300P:
0P0200H90`0300D70@0520000PD000<00P<00P010`000`0310001@H000@500020083000600410003
104030l5010D2P0B5``041@;3oooool000gooooo00H00`H600@71@041`4010L000<600072P0300/>
0@0:00`?0@0>4@804144010A1P0@4PP03Ph600`=1P0:30D03Q0801@I30806Ad<00/07R@A024W5@0R
:QL092`H02<[5`0Q:QL08BXH028[5`0U;QP09RlJ02H_700202L_700302L`700Y<A`0:c0L0080;C4O
00<0;C4P02ha8@0`<b<00`0a=B@03P0`=B<0;C<R02dc8P0/<b80;CDR02`e8@0]=B40;SDR030f8P0a
=B<0;c4O02`]6P0[;A/0;2dM0P0[;Ql02`0/<Al0;S<R02ld900^=RD0;3DT02Xd8P0[=240;3DR02/d
800Z=1l0;3HO00<0:cDN00X0;CHP02lh8@0a>R40<c/Q03Dm8`0e?2@0<cXR034h8@0c>B<0<SPR0P0d
>B@0300f>bL0=C/X03Dk9`0b=b@0<SHQ03<f8@0c=B80<C@Q02lc8P0^<b40:c4O02/a7@80:c<L00/0
:c8K02de7@0^=Qh0<CPP030g8@0b>B00<cXQ03<k8`0d>b@0=C`V038i8`0202hd7`0;02ld7`0a=b40
<cXT03<k900b>B80<3LQ02lg800^=Qd0;3<L02he7P0_=Ql00P0]<ad0300[<Ah0;C4Q02da8P0^<R@0
;S8R02la8P0/<280;2hS02d`8`0[<240:blO02T^70809b`H00/092/D02<[4P0S:A8092TD02P/6`0X
;1`09BTL02@X700S9QT082DI01dS600201hT600;01dS600L8QH06b4C01`R500M8a@0724B01XO3P0K
80h0720?01`Q400L81000P0J70l01P0F6@d061`@01LK4@0G6a805AP?014E31[ooooo00H0>d=B03a3
E@0nA5X0@4EL0455G`11AV020458G`0;0459GP11BUl0@d]O04=<HP13C6<0@daR049<G`13CEl0ADiO
04Q@H@1;Df@00P1<E6D02`1=E6H0C5=V04YCIP1;EFT0BUAZ04]EJ`1<EV`0CeQ_059IL01BFG80DUQ`
0080DUYa00`0DUUa05=JLP1EG780EEaa05ELL01FGVl0Eei`05UQLP1HH740Eei`05UQM01JHW<205UQ
L`0;05YSL`1MIG@0GVIe05mVMP1PIWL0GfQg05mYMP1PJWH0HVef069]M`1SKGL00P1TKg/02`1UKWd0
J71o06UaP`1YLX<0JWB306afPP1/Mh00KGMn06ihO`1`NH00L7^20080L7b300/0LWj407AnP`1dOX80
M7j307EnP`1hPH80NH:207Z3PP1jQ8<0NhB307b6Q00207f7Q@80OXR700X0OHR707n9R@1oRhP0P8^7
07n9Q@1oRXH0OhZ5082:Q@21Rh@0Phj60P24SXH02`23S8@0P8Z007f7O@20S7h0E5QG02LT;@0X:Rd0
9RTW01dO700E5A803`l;008030d700/03@h600h?1P0<30@02PT300X8100:2@@02@T200P:0P0:30@0
30h500/=1P0200X=1P0<00P;1@0:30H02P`600T:10072P<02@/300X=0`0:3@40418601TM400O8aL0
8BHH0P0S:1T02`0R9aT08BDH020S5P0O91D06b0B01DI3@0@50T03Q8700`@1P0;3@D02P`5008020X4
00<01@P200<5000110000P0210001P030`000080004300041P001@H000<500800`@000H00P<000<4
000>4@P051T=01DJ3P0B5Ph?ooooo`003Oooool01P0320D00`T300D90@052@000`L0008500800`H0
00/010H000H6000;2P404a8701PJ300G60`04Q8800d?1P0930<01`X200T=0`0200dB0`0;01@J1`0L
8Ph08BTD02D^6@0U;aX09S0M02L_800W<Al09c4N02H`7@0T;AP00P0S;AH0300V<1P0:34H02Xa6@0]
=1d0;S8N02ha800_<R<0<3<V030e:@0`=BP0<CLY030f:080;SDV00/0;CDT02hf8`0^>2<0<STU03<i
8`0b>2<0<CHS030c800^;ad0;c0M030a7`02034b8P0502lc8`0`=B@0<3DT030g9@0_=bD00P0/=R<0
100]=b<0;SPR02lh7`0`>Al202lg7P0602dd700]=1h0;S@O02he800a=b80<c/S0P0b>B800`0a>240
<cTQ038h800203@i8P0<03Ll9P0f>bL0=c`W03Dk9P0d>B80=STS03Dg900b=B80<CDS02hd8`0[<R00
:S4M0P0Z<A/02`0[<ad0:S@M02hi7`0`>Al0;cLN030h7P0a>1l0<3PP03@j8`0f?2H0<cXU0080<3HS
00@0;c@R02db800`=R@0=3`X0P0c>bL01@0c?2D0<CXS030h8@0a>Al0<STO0080;SDL00@0;C<M02hd
7`0_=240;c@T0P0_=2H01P0^<RD0;C4V02/_9@0[;R@0:RhQ02T^7@80:2lI00/09RhG02@[500U:Q@0
9R/G02T]6`0X;1`0:BdN02L[7@0U:A`092LL020S6P0301dP5`0301hR5P0N91H07R@F00807B@G00D0
7B<G01/Q4`0J81006b0A01dQ4P0201`P400601/O3`0I7@h05a`@01LK400E6@d041@96_ooool01P0k
@U<0?4=F03m6FP10Ae`0@DIM0457GP80@DUO00/0?dMO0458H013C640A4eR04A=H`16Cf80Ae5R04QA
G`1:DEl0CE=R04iDI@0204iDIP0904iEI`1=EVP0C5EW04aEJ01=EV/0CUM[04mHK01AFV`0Dea^0080
De]_0P1EG70205EKL00305EKK`1FFg00EEab0080EUeb00D0EUia05MOL@1IH780FF5b05YQL@0205YR
L@0;05]SLP1LIG@0GVEf061VMP1RIgP0HVQh06=[N@1RJgP0I6ih06E_NP1UKGX00P1VKWd02`1ZL7l0
Jg2106abQ01/LhH0KgJ706ieQ@1_N8<0KgV106iiOP1_NGl0LG^10080LWb200L0Lgj207IoP`1fOh80
MWn407IoQP1gPH@0N8640080NhF400X0OHN507n9Q`1oRHL0OhV707n:R@20RXT0OXV9082;S021SH/0
PXb90P23S8P01023SHT0PHb7086<QP21S8D208B?Q@0;08F>Q023S840OhQn086<O`1NHeh09b@^02PY
;P0T9bD06alJ01@G4@0@4`X00P0=40L01`0<3`H03A4700/>1@0;30@02@P300P70`082P<00P092`<0
0`0:30<02P`500X=1@0300X=1@0:00T<1P082`H01`X500P;0`0930<020X200`>1@0F6a007B8F024V
6@8092PI00/08bLI028U600P91H082DE01dR500I7Q005AT<00lD200<4@H02`h400/>1@0200X<1@0:
00L90`041P400`D000840003100010@000830003100010H000@700<00P@000H00P8000<30@0?4PT0
51P>01HJ4P0E6A<?ooooo`003Oooool01P042@@010T300H:0@072`401`X000D800800PD000/00`H0
00L800081P003`h201DD1P0E5PP04Q<600d>0P0;2`002`/100P9000200H7000;00`>0P0D5PT07B4C
02@X6`0Y;b40:S<W02Xd:@0[=RP0:3<S02Lc7`0U<1X00P0T;aH0300U<1@0:3<E02/d5`0/<QT0<3<M
034d8@0c=2D0<S@X030d;00^<b`0;SD/02de:`80;3DY00/0;SLW034j9P0a>RD0<SPS03Dj8@0d>200
=CPQ03Dg800e=R00=SPT03Dg9P0203@e:00;034c:00c=b/0<CHX030g9@0_>B@0;3HS02/d8@0/=B00
;cPQ03<k8@0b>Al00P0b>1l02`0d>B40=3PR03<f8P0b=R<0<CHT03<h9P0c>2@0=3/V03Dm9`0e?2D0
=CdS0080=3`R00`0=ChU03Ln9P0j@BP0>ClV03Lj900f>2@0=SLU03<e900a=2D0;S@U02Xc8`0Y<R03
02Tc7`0:02Td7@0/>1h0;c`M02lk6P0_>AT0<3PJ034i7@0d>b40=C`T03Dl9`80<STV00X0=3TZ038g
:P0_=2P0;cHX034h:@0d?2P0=3dW038m9P0a?2<0<3TP0`0`=ah0300`=al0<3HQ034e8P0`=2@0<3DW
02ld:@0`=BT0;S<Y02``9P0/<BH0:BhQ02P]7P80:30M00/0:30K02P`6@0Y;QP0:BhI02/_6`0/;Q/0
;2`K02/[700[;Ah0:B/N02@T6@02024Q5`0;01lP5P0O8QP07b<I01hT6P0O9A/08BLM024W7P0O9AX0
7BDG01dS5@0N8a<00P0L8@l01P0L8@h06b0>01XP3P0I7P`061/901<F1Q[ooooo00H0?4=C03e5EP0o
AeT0@DUL0458G013BUh20499G`0;0458H`12BF<0A4aS04I?H`15Cf<0Ae1S04YCH`1:Df80CE=R04mE
I@1?EVH00P1@EVP02`1?EfT0CeQY04iHJ@1?F6T0D5QZ055HJ`1BFF/0De]/05AKK@1DFfh0EEe_0080
EEa^00`0EUa^05MMK`1KGg40FUib05QNM01GGW@0EUib05ENL@1GGg00F61`05YRLP1LI7<205eUM00;
05iVM@1OIWL0HFMi069XM`1TJGT0I6Yj06I/N`1UK7/0IVik06I_N`1WKg`00P1YL7h02`1/LH00K7>3
06abP`1]MHD0LGR6071hQ01aNH@0LWV3079jP01bNh00M7b00080MGf200X0Mgj307QoQ01gOhD0N869
07R1RP1iPXT0Nh>907f6R01lQXD0OXN60`1oRHL03020RXP0PH^9082:RP23SHd0Q8j=08F>S024SHT0
Q8j808F>R@24SXT0Phf608>>Q080Q8n300/0Q8j308:<P@21RWl0PHan06Q`J00_;3@0;c0b02PZ:@0M
8Qh051TC014F2`0200lB2@0300`?1`0;3PL02Pd700<02`d800D02Pd500X=100:3@@02Pd400/>1@02
00/=1@0<00/>1P0;3`H02@d500P<1@072`<020`300T>0`0:3@<02`l5018F300J7Q407b@F0P0S9aP0
2`0T:1T08bLJ028V5`0R9aH08BHF01hR500H70l04aL:00hC1`0<40D02`h300802Pd300T02@`200T:
0@0620001@D000H500071P001@D000@300030`000P02100200420006000100041@804aL;01DK3P0G
71405AP@3oooool000gooooo00H01`/300P<100;3@@030l300`=0`0:2`4200P:000700T;00092P00
2@T000X;000:2P0030`100`<000200h=0@0?00`;0@0<2@802@D200T50P081@802PL501DE4P0Q8Qh0
9bXV02Ta:`0Y<b`0:CH[02Tg9`0X=b409c@L00809c@H00`0:CDF02Xe5@0]=AH0;C8H02la700b=B<0
<cHW03<e:@0`<bX0;c@]02de;P0]=bd202dg:P0;030j:@0b?2L0=C`V03Hl900g?2<0>3XQ03/l900j
>bH0>c/X03Xj:P0h>Bh00P0f=bh02`0d=Rl0<cP^03<j;@0b>bT0<C`W02lk900^>240<3TP03<l8@0g
?B80>3`R0080>chV00/0?3hY03Tj:@0h>BX0=cT/03Dh;00f>bd0=Sd/03Dm:@0g?bT0=d4X03Ho9@02
03@m8P0<03Dm8P0h?R<0>ChT03/o9`0j?BX0>C/[03Li:`0c=BT0<CDX02lf:00[=2D0:cDT0P0[=B<0
2`0Z=B00:C@L02Xe6@0/>1L0;SXG030j5@0b>aL0=SdO03Hl8P0f?2D0=clZ0080=cl]00/0=Sh^03@m
;P0b>bd0;cLX02df900_=b40<CXP03<m8@0c?1l0<CXN034h7P0203@i800<03Dh8`0d=b@0=3HV03<d
:00b=R/0<3D/02le;@0^=2/0:c4W02Xa9@0Y<B80:C4Q0P0Y<R002`0X<Ad0:C8L02/b6`0[;a/0;BhK
02h_7@0^;Ad0;bdP02h/8@0/:b40:2PO00809BHO00/08B@L01lR700O9Ad07bDL01lV700P:1d08BTN
01lW6P0N9QH07RDD01hV4P0201`T3P0601`T300M9@h07RD=01hT300M8@`06AX96_ooool01P0k@e<0
?DIF0419FP11B5/0@4MM0458GP80@TYQ00T0@TUS04=<I@15CVD0Ae1T04QBI019DVD0BU=U04aDIP1=
E6D00P1>EfL204mHJ@0;04mHJP1?FFX0CeYY055KJ@1CFfX0Dea[05AKK01EG6d0EUe^05IMK`1FGW00
0P1EFfl0301FG700Eee`05YOLP1JGg80FEic05UPMP1IHWD0FF=c05UQL01JHW00FfAb05eVM080GfMf
00/0HFYg065[N01QJWP0HV]h06=[N01UKGT0IVii06E^NP1VKg/0IW1l06MaO00206QaO00;06]cO`1^
M880K7B106egP@1`NH@0Lgb5079kP`1dNh80MGb107EnP01fOX000P1gOh402`1iPH@0NX6607V1R01h
PHT0NH6:07Z3RP1kQ8X0OHJ:07n8R021RXP0PH^90080PHb800`0PXb908>=RP23SH/0Phf;08F?S@26
Sh`0QXn;08NAR`27T8X0QXn908J>Q`25T8D208B?Q00;08>>PP25Sh<0Phf108:>P01bNg40=cHl03@f
>@0c=cH08R@S01PJ600C5Q400P0>4P/02`0<3`X02`d900P:200:30T02`h:00`?2@0:30D02@/200/=
0`0=3P<03@l300803@h400`02`d500X>1@093P@02Pl400/@100>50@03Q@5014G1`0@5@L041@701LJ
3@0M8Q@2024W600;028X600R9QP08BHF020U5@0Q:1P07bDG01/P4`0F6`l04A@:00dA1P0:3P800P08
30000`0930002`/100T90@0200L6000600P700061@0010<000<300020`000P800P010@001P000P00
0P@100dA1P0C6@/061d?01PL3@oooooo000=ooooo`0600X<1@0<3@D03a0600h@1P0:2`<01`P10P05
1`002`092P402``100X<0@092`001`P000P9000<30003Ph400d<100=2`<02`T300802@D300/02@@7
00P3200<2@h05ADH01dQ8@0T:bL09c8Z02Pd:00W=R@0:3LP02Le700202Te6P0<02/f6@0^>1P0;cHJ
02he7@0`=B00<SHT03<g:@0b=RX0<3H[038g;@0a>Rl0<3X]0P0_>RX00`0a?2L0<3/U03<l900203Y0
9`0603/n9P0l?BH0?CdZ03dm;@0h>Bd0>3X_0P0g>c002`0f>c80=S`a03@l;P0c?2/0=3dZ03@n:00c
?2D0=C`S03Lm8`0j?R@0?3dW0080?SdZ00/0?C`]03Xi;`0i>C40>3Xb03Dj<@0e>c00=Sh_03Do;00g
@RX0>D<X03Y29`0203Ln900<03Ll900h?2D0>S`W03/m:`0l?Rl0?3lb03Pm<@0c>Rh0<SX[034k:@0_
>BL0;SPT0P0/=R002`0/=Qd0:cDI02Tc5@0Z<Q<0:c<D02hg500a>QL0<cTL03<g7`0d>bD0=C`X0080
=3h[0P0c?Rd02@0b?R/0<C/V02li800^=aX0;SLG038k6@0a>AT0<cTL03Hi7`0203Li8`0<03Lg9@0e
=2L0<S4W02l`9`0]<BT0;SD]02Xb;00Z<RT0:C8V02Xc8`0Z<R40:S4P0P0]=B802`0]=240;38N02hb
7@0^;ad0<30O034`8@0a;b<0<BhU02dZ8`0[:R@0:2/V00809BTU00/08BLQ01dS7@0M91`072@J01lW
700O:1X082TJ020Y600O:1@07RLB01lX4@0201hW3P0601`S2P0M90T07R8:01lS300N8@d071`<6_oo
ool01P0lAE<0?TQF0419F@12BUh0@d]P04=<H080@daQ00/0A4eQ04A>HP16DF<0Ae9T04UDIP1:E6H0
BeIW04iGJ@1=EfT0CUQ[04iJJ`0204iJJP80CeYZ00T0D5Y[04mJJP1AFfX0DUaZ05=LJP1CGF/0EUi]
05MNKP1HGW000P1IGg4205UOLP0:05UPLP1IGg80F5ic05UPM`1JHWH0FV=d05YSL@1KHg00GFEa05iV
L`80H6Qf00<0HFYg069ZM`1RJgP00P1SJWT01P1UK7X0IVmk06I^O01WL7d0J75n06UcOP80JGAn00/0
KGEo06ieO`1/MGl0KGN1071jP`1cO8D0M7b507EmQ@1gOXD0N7n507R0Q00207Z2QP0;07^2Q`1lPhX0
Nh:;07Z2S01kPhd0O8B;07b5R@1oQhT0PHV908::R@23S8X00P23SHX03024Sh/0Q8j;08B>R`26T8d0
QXn=08J=R`26SX/0RI2=08V@S027Sh/0Qhn:08N@R@80QI6800/0QI2508JAQ024T8<0QI6107V5N00n
?d<0=STl03Dj>00O8R<06A/J018E4`0200hA3@0;00`>2`0;3@X02@X900X<2@0:3@T02`d600X<0`0:
3@803@h200h>0`0>3P800P0=3P401P0<30403@d200h@1@0A5@P04AL8010F1P8041D600@03a8400h?
0`0D5@X07b4D0P0S9aP02`0R9aP07bDF01hU500M91<082LE01lV5P0K8Q@06Ad@01@G2`0?4`P03103
00802`l100/02Ph000/=0@0:30402@X000T800092@001`P000D60003100010D000<4000200@30006
004200010`003@l601DH300H7Pl061/<3oooool000gooooo00H03Q8:00d@2P0<3`P02Pd500L91005
1`<200@60@0400L:0P0;3P<02Pd200P;008020X000D02P`100d>0`0=30<02PP200H40@0200@2000;
00P5100=2PX030X=00d<4@0C5AT06alQ028Y9`0U;bP09C8V02Hc8`0Y=B400P0[=b00300/=al0;cLM
02lf700_=Qh0;cDQ038e900g>B/0=CL]03<g;P0e>C00=3T`038j;@80<3/[00/0<3/W034m9@0c?RD0
=SlU03Lo9@0h?bD0>ChU03Pk9@0k?BT0>S`/03Xl;P0203Tl;P0;03Ll<00f?300=3X^03Dl;P0e?Bh0
=Ch]03Dn:P0e?2H0=C/S03Pk8`0j>bD00P0k>bL02`0k>BX0>cT]03Ti<00g>C<0<cLb03Dk<P0e?C40
=D0^03M3:`0i@bT0>T<W0080>40U00`0>3hV03Pm:00j?RX0?D0]03ho;`0n@340>d4b03Ln<@0e?Rl0
=3d/03<m:@0a>bD202dg800;02df700/<aT0:C0F02P_5P0Z<AH0:S0E02`c5@0]=1T0;cDM034g8@0b
>2D00P0b>BL02`0b>BT0=3`Z03<k9`0a>R@0;cPP02hg7P0`=a/0<3LJ030f6@0b>1`0=CTN0080=SPQ
00`0=SPT03Hg:00b<RL0;BlU02/`9P0X;RH0:2lW02T`9P0[<bH0;3@U02dd8P0/<Al202db800;02hc
8@0^<R00;S8N02l_700_;ah0;blO02l/7`0`;R80;RdT02`/9@0[;BL00P0W:bD02`0S:24082DM01lV
700M9AX07RDI01lW600N9QL07RHE01lW5P0P9QD082HC00807R@@00<06b0<01`R2`0N8Pd00P0N8@h0
0`0L7Pgoooooooooo`0Hooooo`0503i7D`10BEP0@D]J049;GP13Bel00`14CF002`14CV40AU1S04QB
I@18DfH0BUEX04aGJ@1=EfT0CEQY04iIK01?FV`0D5a/0080D5a[00/0D5YZ04mJJ`1AG6h0D5]^051K
K01BGFd0Dei]05APKP1FH6l0Ef1`05QOL00205QOL@0<05QOLP1JHW80FF5b05YQM01JH7D0Ff9g05]S
N01KHgL0G6Ae05eVM@1NIg@0H6Qe0P1PJWH02`1RJgL0HFYh06A]NP1UK7X0I6aj06=/NP1VKg/0Ig1l
06YbO@1[M7d0JgAl0080K7Ek00/0KWMl06igO@1^MWl0L7N2075iQ01cNhL0M7b607AnQ@1fOhL0MWj8
07MoR00207V1RP0507Z2R`1kPhd0Nh:=07^3S@1lQH`00P1mQh/01020RH`0PX^>08:<SP25SXl208B=
SP0<08B>S`26Shl0QY2@08NAT@26T900QY2A08J@S`28THl0R9:=08RCS@28Th`0R9>;0P27TX`02`26
ThT0QI6708>@Q@23TH@0O8em03/o@P0/;c<0:Rd[01`N700C5Q803Q4<008030l90P0:30L02@092`H0
20X500X=1@0:30<030h300h@0P0>3`803Ph200d<0P0200h>0@0600d=0P0?3P<04Q86014C2@0>4@L0
2`h30P092`40100;2`403Ph301LH300N81<2028U5P0;028U5`0P91H07b@F020T5@0R9QH082HG01/R
4`0I7a405Q`?014F2P0>4`H00P0<4@<02`0<3`8030l100X<0@0;3@402``000X<000:304020/100H9
000620001@L000800`@000H000800042000;30D04aD:01DH300E5`X?ooooo`003Oooool01P0=4Pd0
310<00X<2@082PH02P`800L:1`801@L300/01@P100L90@072@401PP100L90@082P402@/100P90008
20001`H000D4000200@2000;00P60`0E5@h061PE01XJ6`0M7B407b0V028V:P0T;2`09Rl]02Hb:`0W
<RT00P0Y<bD0300Z=280;3DP02de7`0]=1h0;cHP038g8`0e>2L0>3X[03Lh;@0e=bd0=3P^03<h;@80
=3/^00/0<C/[030k:00b?BP0=3lV03Ho9@0f?b@0=clT03Hm8`0i?RD0>ShX03Xn:`0203/o;P0;03Pn
;`0g?Bl0=cd`03Hl<@0e?C00=3ha03E0;`0c?RT0<c`T03Dl8P0g?2<00P0h>b802`0i>b@0>S/W03Xk
:P0i>bh0=cX_03Di;`0e>bh0=d0_03M2;P0iABd0?DP/0080?DLY00`0?4HY03a3:P0m@B/0?D4[03e0
;00n@2h0?T8`03]0<@0k@S80>44`03Do;P0c?2/202lg9@0;02`c7`0[<A`0:2hI02T_6P0Z<AX0:S0J
02/b6P0[<AX0;34L02hc7`0a=R400P0d>BD02`0e>BH0=CXW038h9@0a=b@0<CPT038j900b?B<0<S/P
030i700a>A`0<SPM0080=3TN00`0=CTP03Pj900f>2H0<c@U030c9`0]<2L0:bhU02/_9@0/<BD0;S@V
02le9@0/<b<202dc900;02`c8`0]<b40;C8O02da7P0^<Ad0<34N030^7P0^:ah0<2dP02h]8@0/:al0
0`0[;1l02P0W:Ql08bHL020T6`0O8aT07b@I01dT6@0L91P07bHI01lU600P9AL2020T5P0601hR4P0M
8Q407b<A01hR400M81006ad@6_ooool01P10AeD0@TYK04A=G`15CV00ADeQ04I>H@80ATmQ00/0AU1R
04QAI019E6D0BUEV04aFJ01>FFX0CeUZ055LK@1AG6h0DEa]055LJ`02051LJP0;055LJP1BG6X0Dei]
05=NL01CGg00EF5b05APL@1EH700Ef5a05QRLP1GGg<00P1IHGD00`1KI7@0FfAc05]TM00205]TM@06
05aUMP1MI7H0GFAg05aUM`1MIgP0H6Yh0`1RK7P02`1SK7T0Hfak06E^O@1VKW`0IFml06EaO@1WLW`0
JG=l06aeOP1]MGh0KWIn0080L7Mn00/0L7Uo079kPP1bNX@0LWZ307=jQ01cNhD0M7f707AnQP1fP8P0
N86907N0R@0207R2RP0507Z4R`1kQX/0NhJ;07^6R`1mR8`00P1nRX`01021S8h0Phj@08>=T026T982
08F?TP0<08J@T@28TI40R9:B08JATP26TY<0R9BC08NCT@27Thl0RIF>08ZFS029UHX0RYN;0P2:Uh`0
2`28UHX0QYB908BCR024U8H0P9620498B00S9BT082<S01DH5P0?4Pd03@l8008030h500/020X100P:
0P093@<02@/100X<0P0;3P803A0400hB1@0@4P@04Q86014B1P02014@1@0<00l?100?40H0410700l@
200<3PL02@/400L90P092`<030d4014B1`0G6@d07B4C0P0Q9QH02`0S9aP08RHG024U600Q9QL092TJ
02D[700P9aT07R@F01/R500H7a405A`>008051X<00/05AX;014E1`0>4`D03a8500hB100>4PH04AH9
00lD1`0>4`D03A8400T=0@0200D800060085000210002@/3018D1`0E60/05aP<3oooool000gooooo
00H03A8=00`@300:30T020X600X<20072PL200D70`0;00D80@072@401`T100H80@072@4020X100T;
0@082@0020P000L6000510000P040P002`081P<05AD>01PH5@0J6Q/07AdQ01lP9P0R9RX092`/02H_
;@0V<R/09c8Y0080:C<U00`0:S@R02`e800]=Al0;C@N02lf800b=b<0=CPW03Pj:`0g>2d0=CL]03@h
;P0c>2d203@k;P0;034k:`0`>bP0<SdX03@o9P0f?bD0=SlT03Lo900f?B<0>ChU03Xn:00j?R/00P0k
?bh02`0h?Rl0=cd_03Lm<00f?340=Cd`03@n<@0e@2l0<chY03<l900e?280=c`S0080>3/R00/0>C/T
03Xk9`0j>bX0>C/^03Lj;`0e>Bl0=C/^03M0;`0g@Rh0>DD]03e8;00203e7:@0<03a6:@0l@bX0?D4[
03e1:`0m@2`0?T0^03i2<00k@340>d8b03Q1<00e?bh0<c`[0P0_=bD02`0/<al0:c4L02P^6@0Y;aX0
:S4J02X`6P0[<QX0:c4J02`a700^<al0<CHQ0080=3TU00/0=CTV03Dj9`0b>2D0<CLT034h900b>R@0
<SdS038k800`>A`0<CTL038h7@0203@i7P0<03Di800h>R@0=SPV03<d9@0`<bL0;C0W02/^9@0[;bD0
;34U02hd9P0_=BD0;3<S0P0]<b@02`0/<b<0;C<Q02db7`0]<Ah0;S4M030a7P0`;Qh0;R/N030]800^
;B40;2/O00<0:b`O00X09bXO02<V700P91/07b<I01lT6@0M91T072@H01lV6@0O9AP082DG0P0P91H0
1P0N8Q807B8A01lS4@0N8Q007B0@01/M41[ooooo00H0@4ME049:F`14CEl0ADiP04E=H@16CV4204I?
H@0;04I@HP18DF@0BEAU04YEIP1<EVP0CUUZ04mIJP1AG6d0DEa^055LK@1AG6/00P1@G6X02`1AG6X0
DUaZ05=NK@1CGW00Dem`05EQLP1DH740EF1`05MQL@1HHW80Eemc0080FF5e00<0FfAd05]TL`1KI7@0
0P1KI7D01P1LIGH0GFAf05eTM`1LIGL0GFMh061ZN0<0HVah00/0Hfai06=/N`1UKWd0IVil06E_O01U
LGd0Ig9l06UcO01/MGh0KGEn06ifOP02071gOP0;071iO`1bNh80LWZ4079jP`1cNX@0Lg^507AmQ`1d
OXH0MX2807R1R@1gP8T00P1hPXX01@1jQ8/0NhJ;07^6R`1kQX/0OHR<0080OXZ<00@0PHb>08>>T023
SI00QY2B0P25Si803026T940R96A08RBTP26TI80QY:C08RDT`27Ti40Qi>?08VESP2:UX`0RIF:08ZG
R`80RYN<00/0R9F:08JDR@24ThP0Q9B6082APP12B4P08bDY020S8`0E61H03a8=00d?200200`>1@0;
00P:0@082P802@d300T;0@0:30802`h200d@100>4PD04184018B1P0A4PH00P0A40D0300?3`@03a06
010@1`0?40P030h700T;10072@802@/300`=100A4PL05aT=01dQ4`808BHF00/08bLH028V5`0Q9AP0
8BHG02@Y6P0U:a`082LI01hT5P0K8Q@061lA01DL3P0201@J300;01DJ2`0A5@L03Q<500lB1@0>4P@0
3Q86014F2@0?50L03Q<500dB10093@400P0520001P021@000P@000T;0`0B50L05AP;01LH30oooooo
000=ooooo`0600X>200:3@T020/700P:1@092`H01`T40P0520<02`072PD01`T400L80`092P@01`T2
00H900072@001@P000@600031@000`@000800P8000/00`<000P9100G6Q<0;S@Y03Dk<@0a=C40;30^
02X`;`0[<S40;cPc02`f<00202Pa:@0<02D^8`0U;Ql09BdL02H/6`0X;QX0:S0K02`b7@0_=240<CDW
03<f:P0e>2/0<cP/0P0e>bh02`0b>R/0<3TY030j9`0d?BL0<cXU03@l9@0d?2@0<c/R03@l8`0e?2D0
=SdX0080>3lY00/0=ShY03Dl:@0f?B/0=S`/03Lm;P0g?c00=Sl`03Dn;@0f?R/0=ShX03Hn9`0203@k
8`0;03Dk8P0f>b80=c`S03Pm9P0i?BP0>CdY03Hl:@0e?BT0>48/03]5:`0lABX00P0j@bX0300k@b/0
>T8/03U0:`0g?BT0>3hY03Xo:P0k@2/0>d4]03]2<00j@Bl0>T8`03Hn:`80<3LT00/0;3<P02/a7P0Y
<1h0:BlL02Xa7@0Z<1/0:c4L02T_6`0W;AT0:RlJ02`a700202ha7P0;02lc7P0^=1l0<3HP03<i8P0d
>bD0=3`V03Ho:00f@2P0<chS038l8@0`=ad00P0^=1`01P0`=Q`0=CXP03Hj8P0e=b80<cDT030c9@80
;BlS00@0:blR02/`900]<RD0:c8T0P0Y<B@02`0X<2<0:C4P02Xa7`0[<1h0;C8M02lb7@0_;Q/0;B/K
02/Y6P0/:QX0;RdJ0080:bPF00/0:bTG02TY6P0V:1/092HL028T700Q8a`082@M01hR700N8a`07B<K
01dS600201/Q5P0601`Q5P0M8QD07R<E020S5@0O8AD06adC6_ooool01P13BUT0A4aO04I>H`18D6H0
B4mU04UAI@80Ae5T00/0BE=V04]FI`1<F6H0CEUW051KJP1CG6`0Dee]05ANK`1CGFl0Dei^05=NK`02
05=NKP0905AOK`1EGVh0EEi^05IOL@1FHG<0EV1e05IPL`1HH7<0FF9c0080FV9d0P1LHgH0301MIGL0
FfAd05]TL`1MIW<0G6Ec05aUM01NIWH0GfIg05iVN@1NIg/0H6Yj069[N080Hfai00/0Hf]i06E[O@1W
KH00J6n106M`P@1XLH40JG:106adP01^MH00LGR1075gP@02075hP`0;07=jQ01dOHD0M7b507AkQ01f
O8D0MWb607InR@1fOXP0NH::07V4RP1hPhT00P1iQ8X02`1kQX/0OXV<07f:R`1mRX`0P8b?086<SP20
S8`0PXj>08B?S`25T8l0R9BA0080Qi:@00`0R9:@08VBT@28TY00Qi:B08RETP28UI40RYFA08ZET02;
UY00RYJ>08ZFS02;V8d208VGR`80RIJ900T0QiF908JFR026V8H0CeUC02HY:P0M81h051LD00lB300<
3PP00P0:30@010092`802`d400/>100<3`@200d>100500`?1@0>4@H041@8014B200B4`P00P0A4`P2
00hA1`0:00d?1P0;3@D02`h600X=1P0:3@D02`d400d@100@50L051P;01/P4P808BLF00/08bPG028X
5`0Q9QL08bPH02<Z6@0T;1X08bXI020W5`0M91H07B@E01dU500201hU500;01hT4`0H7@h051P9018F
200B5`X041H;01@I3P0E6`h05a`?01TN3`0A5@P00P0;30<01P061`0010@000L70@0A4`P05aP=01PJ
3Poooooo000=ooooo`0600H:0@072P8020/300X;1009208020P20P0;3@D0200>4@X0418;00l?2P0?
4@X03A0700/>0`092`401PT00P041P003P031@000P<00083000210000@<000L:1P0W<240<S`[03<j
;@0g?c<0=3/a034g;P0e?C40=Clc0P0T:R@0300M8a`06R0F01XO4`0K8A007R<A024V4P0R9Q<09BTD
02/`7@0^=2<0<SPX03Dk:P<0>D4]00X0=ClZ03Ho:00h@2P0=clW03To:00i?RT0>ClY03Pn:@0h?RX0
=chY0P0h?bT02`0h@2X0>3lZ03Po:P0g?bT0>3lZ03Y0;@0i?bl0>3h_03To<00j@2h0>T4/0080=S`V
00/0=S`T03Hm8`0h@B@0>44S03Q0900h?bD0>40W03Lo9`0h@BH0>D8V03]2:00203]2:`0403e3;P0l
@S40>T0`03Ll;080=S`Z00H0=clZ03U1:`0i?bX0>T4[03]3;@0h?bX203@j9P09030g8@0/<Ql0:S0O
02X`7@0[<Qd0;38N02`b7@0Z<1`0:2dK0080:RlL0P0[<1`02`0[<A`0:c8L02he7@0c>R00=3/R03Dk
900f?RL0=chY03Ho:@0e?bP0<c/T00<0<3LO00/0<CTP030g7`0_=B00<SPR034f8`0^<b40;S8Q02`a
7`0Z;ad0:blN02`b8@0202he9@0;02dc9@0/<R@0;C8T02/_8@0/<R00;S@P02hb7`0/;ad0:b/K02TY
6@0Z;1T00P0X:AD02`0V9a<092HD02DW5`0T9QP08R@I024S6P0Q91d08BDN028W7P0O9A`07B<J0080
6b4H00H07B8I01/Q5`0L8AL07R4H01lQ6@0M7QLJooooo`0604E<G@16CV40B59U04UCJ019DVP0BeEY
0P18DVD02`18DfH0C5QY04eJJP1?FfX0DUe]05ANK`1EGfl0EV1a05APLP1DHG40EF9a0080EF9b00/0
EF1b05IPM01GH7@0F65d05MQM01EH7D0Ef1e05YSMP1KI7H0G6Ae05eTM@0205iVMP0<05iWMP1LI7<0
G6Eb05]UL01MIW40GfQd05mXN01OIg/0GfQm061[OP1PK7`0HVek0P1SKWX02`1UKg`0IVio06Q`PP1Y
LH@0JG6206UbP@1[M880K7B206ieP`1`N8D0LGV50080LWV700<0LWV807EmR01eOHP00P1fOHP01P1i
Oh/0NGn>07N0SP1hPXd0NHF>07V6S080NHF<00/0NXN>07f:T@1mRi00OXfA082<T022SI40PXnA08:A
T`24TY<0QY:B08VFU00208ZET`0<08VET`2:UY<0RiNE08^FUP2;UYD0RYFE08bFU@2?VID0SiVC08jI
TP2=VY80S9Z@0P2=VXh208fJS00908^HRP28UhP0RY^8061[H@0/;S007b4R01LJ6@0A51803A4<0080
2`h700D02Pd400lA200?4P/041<<014C2P02010A2004010B200>4@L03Q47010B1`804A<800`03a88
00hA200>4@P030l600/>1P0;3PD02`h400dB100@50D04AH701PM3P0M8Q<2028W5P0;02<X5`0T:AL0
8bPH02@X5`0S:1H08bTG028Y5P0R:1H082HD01hV500O9aD00P0O:1D02`0O9aD07B<D01`Q4P0J7a40
61hA01LM3`0I7`l06b4A01hR4`0S9aL06Q/?00804Q8900H03@d500X80`071`<03@l801<F300F6Pl?
ooooo`003Oooool01P052P801PX100P;0@0:2`802PX100T:0P803A0800/04AD<01DI400E61005ATA
01HJ400C60/0310600P;0`0520401@L000D70@0200@5000;008400031@400`H100/@1P0D6@`07b@E
03]5;`0g?b/0<3HU03Lo;@0g@C000P0M8aX0300G71D041@?00hB2P0?4`P051L901TL2`0L7@h0824A
02T]6`0_=B80=3XX03Lo;080>D8]00/0>44/03Q1:P0j@bX0>d@Y03a4:00oA2X0@DD/0415;@0n@bd0
>d4[03Y0;00203]1;00;03a2;@0n@bl0?T@_03]3;00i@B/0>D4]03]1;`0m@Rl0?44`03e2;`0l@R`0
0P0k@2T02`0i?bP0>T4W03a5:@0lABT0>T@X03U2:00j@bT0>d<X03]4:00kABP0?dL[0080@DP^00/0
@TPb0457=00oAC@0?4<b03Xo;`0f?2X0=chZ03Po:P0g?bL0>T4Y03U1:`0303Y1;P0603Hm:P0_=bD0
;S@S02`c8P0[<al0;3<N0P0`=R000`0]<al0;34N02`a700202`b6`0;02`b700[<A/0:c8L02`c7P0]
=1h0;cLP034i8`0b>RD0=3dW03E0:00g@2P00P0c?2@0300b>R80<CPS034g8`0`=b<0<3PS034h8`0a
>B@0;SHS02de8@0^=B00;C<N02dc7`80;cHU00/0<CPV02dd8`0/<R40:S0Q02`a8@0/<R00;34N02`c
7P0]<al0:blN02X_700202P]600;02L/5`0W:aL09b/I02H[6`0U:AX08bLJ028W7@0S:1d08RTM01lV
6P0N9AT00P0N9AL201dT5P0401lV600P9AT082@I01hP5a[ooooo00H0ATeQ04QAI@19E6T0BEEY04UC
J019EFP204UFJ00;04YFJ@1;EfT0CU][055MKP1BGFl0E5ma05IQL@1FHW80EF9b05ESL@1FHg800P1E
Hg000`1EHW80EV9e05ERM@0205IRM00605EQL`1GHW@0F6Ad05YTL`1KIG<0G6Id0P1LIW<0301LIg40
FVE_05aXL01LIg00GfUc061ZMP1OJGP0GVQi05mZO01QK7l0I6mo06E_OP80IG1o00/0IG1n06E^O`1W
LH80J7>506UbQ01[M8@0K7F606ifQ`1_MhP0KgR906mjR@02071kR@0;071kR01bOHP0LWf907EnRP1g
P8/0Mgn<07N0S`1hPY40Mh>A07V5TP1iQY000P1jR9002`1jQi00O8RA07j;TP1oSI80P8bB086>T`22
T9@0PI6E08>BU@25Ti@0QiBD0080R9FF00@0RIJF08^HUP2:UiH0RYJF0P2<V9L01P2<UiD0SIRD08fI
TP2>VY80SIZB08fLT@80S9Z>00/0S9Z<08bKS@2<VX/0RYR808^JR01^Nfh0<C@g02HX:P0L82405QPI
018C4`0200lA300;00d?1`0F6@l06A`D01HI500B5A0041<;00lB2@0>4@P03A0700d@1P0@4`H00P0A
4`H0300@4`L03Q8700hB200=4PH02`l400/@0`0<4@<04AL601@J2@0D6@T05QX;01XN3`807R8B00/0
82DE024W5`0Q:1L08BPF028X5P0T:AL08RTH024X5@0P9Q@082HE01lV5@0201hV4`0;01lW4`0N9Q@0
8RXG028Y5P0N9A@07RHB01hU4@0N8a0082DD02P]700R9AL00P0K71801P0C50`03Pd800T;200;3@T0
3Q<:010E2Poooooo000=ooooo`0400D81@072PH020`400L90P801PP10P072@@02`0:3@P03a<<018G
3`0E6Q<05adD01DK4@0?50X02Ph400H90004204010H100800`D100@00@D100440@042@8020d30P0:
3P801@0F6``07R8C020T5@0c>RL0?DPc0080;3HW00`08BPM01DH4`0A4`l040l;010@2P0B4``05AH>
01hP5@0W:a`0<3HS03@j:00h?b`203Y3;`0;03U2;@0h@2/0>D4[03Y2:`0lA2X0?dD/0457;`0oAS00
?48/03a1;@0l@Rl00P0m@c002`0oAC40@4Lb03i5<00nAS40?DDa03a5<P0mAS40?dD`03m3;`10A300
?D4^0080?44^00P0>d4^03a3;`0kA2d0?4L^03e7;`0mARh0?DH[03a6:@80?TLZ00l0?dP]0458<011
B300@TLd0498=P12BCL0@TTh03m5=00l@bl0>T0]03Ln:P0e?BT0=clZ03U0:`0k@bl00P0nAS802`0k
@c40=Sd]034i:P0_=bX0;cLW030i9@0_>2D0<3PR02hg7`0^=Ad0;C<K0080;SDK00@0;38J02/a6@0/
<A/0;34L0P0[<1d01@0/=200;cPS034l9P0a?RL0<clX0080<chX00`0<cdV03<n9@0a>bD0;cPR02hf
800_=b40<CTR034i8`0_=R80;SDR02dc800/<B0202hc8@0;02le8P0/<b40;34Q02hc900/<B80:blO
02X_7P0Y<1h0:c4O02/c7P0[<Q`00P0Z;aT02`0Y;QP0:2dG02L/5`0V:aP09RXK02@X700S:1d08RPM
024Y7@0P:A/082PJ00807bHG00H07RHE01hU5P0O9QL082LG024X600P91LJooooo`0304A=HP16D6H0
Ae9X0080BEEX00h0BUIX04YFJ@1:EVT0BUMY04YHJ@1=FF/0DEe^05=OK`1DH740EF5`05IRL@1EHG00
EF9a05MTLP80EfEa00<0F6Ec05MTM@1GI7H00P1FHgD01P1GHg@0F6=c05USM01JIGD0FVEf05YUM@80
FFEd00`0FFIb05QWK`1JJ700GFQb05mYM@1OJ7H0GVQh05iZN`1NJW`0H6]m069]O01SKW`206I^P00;
06I_P01VKX00J76306YbQ@1ZLH@0JW>406afQP1]MXH0KWN706miRP1_NX/00P1`NhX02`1`NhL0LGj7
079nR01dOXX0MX2<07J0S@1gP8l0N86A07R4T`1iQY@0NHJC0080NhNB00/0OHVB07j9T01nRI00P8^B
08:=T`21Si@0PY:E08>CU@24U9@0QYBC08NDT`0208REU00;08^GUP2<V9P0RYJG08bHUP2;V9D0S9ZF
08bJU@2<VI<0S9ZB08bJT02=VXl00`2<VXh02`2>W900Sif>08nKS02<VHT0SI^:07V6NP0m@DD0<3<g
02<W:@0M82806A/L008051HD00/05QPB04MB?P0U:b804A@B014E4P0>4P`030l800/=1P0<3@H03@h5
00lA1P0200h@1P0<00hA1`0=4@L0310700/?10093P802Q0100lF1P0D6`X05ad<01LL300C5PT051H:
0P0J70l02`0N8a@07bHG01lV5`0O9QH082HG028X6@0S:AT08BPF020W5@0P9Q@08BLF008082HG00/0
82LD01lW4`0S:aH092`H028Z5`0P:1H07bLC01hV4@0N91809RdK02H[6`02020U5`0601/N4P0D5P`0
3Q4:00hB2P0<4PP02@d43oooool000gooooo00H02`h>00T<2`0:3@T01`X400@60@0310020084000;
00H80`0:30L03A4;010D3P0B5`l04aL@00hC2P0:3P@01`/000@700041@400P0310402`0210400`D3
00L91@082`@01PT100D70@061`4020/300/>1@0E6Pl08b`L00808BXK00`07RDH01dQ500M81@06Q`B
01LI4P0G61<05QL@01/M5@0R9ad0:c0U030f:@0e?Bd203U1<00703Q0;P0g?b/0=clZ03U0:`0i@B/0
>T4]03a4;P0203i7<00503e4;P0nAC00@4Pc0418<`0oAc400P10BC<02011BC<0@T/d0418<`0oB380
?TH_03m5;P11Ac00?T<_0P0m@c002`0nA380?4<b03e4<00nAc00@4Xb03m9<@0mB2d0?TT/03i::`0n
B2`0?DH^0080?dL_00`0@DTd0458=P15BCT0A4Th04A:=`11B3@0@4Pf03e5=@0h@300=ch]03Lo;00i
@2`203a3;P0;03i5;`0k@Rd0>Cl]03Po;P0g?Rd0=Sd[038j:00`>2D0<3XT02lh8@0_=ah00P0_=Qd0
2`0]<a`0;C@L02hd7@0_<ah0;S8O02`a7P0/<Qd0;3@P02li900_>bD0;c/V0080<SlX00`0<ChX034m
9@0b>b@0;STR02hg800/=Al0;SHQ02hh8`0`>2@0<3LT02dc800/<1h202hb7`0;02la7`0_<B00;c8Q
02d`800^<R<0;C4S02/`8P0Z<2@0:C0R02Ta8@0/<R000P0/<Qh02`0[<A`0:BlI02T_600X;AL09b`K
02DY6`0U:Qd092TL028W6`0R:1/08bTM00808bLJ00H082DG01hT5P0M91D07B@D01hU5P0M8aHJoooo
o`0604A=H@17D6H0B5=Y04UDJ@1;EVX0C5IY0P1;EVP02P1<EfP0CEQX04mIJ@1CGF`0EF1_05EQL@1D
HG00EVAb05MULP1FHg4305ISLP0;05MTM@1GHgH0Ef=f05MRMP1FHWH0F6Af05UTMP1HHgH0FVAi05]T
NP1JI7X00P1JIGX0301IIGT0FFIg05UVM01KIWL0GFMg05eWN01NJ7X0H6Yl05mZO01OJg`0H6el06=_
OP80IFj100/0Ig6306Q`P`1YLH<0JG:106UbP01ZM880JgF406efQ@1_N8L0L7V;071jS@02071kS00;
079mR`1cPHT0MH>;07J2S01eP8h0MX6?07J2T@1hQ9<0N8FD07Z7U01kR9@00P1kQi802`1oRi40P8^?
07n;S`21SI40Q8nC08BAT`25Ti<0QiBE08NDT`29UID0RIFF0080RIJF00`0S9RH08jIV`2=VIX0SYZH
08fIU`2=ViL0SYbG08jLU02?W9<0T9fC096MT@2@W942092MTP0;09:OTP2AWHl0TIf@08jLS`2<Vh`0
PY2304]?DP0h>d00;2lc02L[;00U:2L00P0L7ah02`0I71T0BUQ3028Z8@0A5A404aLC010D3`0=4@X0
30h900`=1P0<3P@03A0500<03A4600/0310500d@1`0;3PH02Pd500X>0`0B60X05ad?01TN400E6`d0
3a@8014D2P0201LK400801`Q5@0O9AP082DI028W6@0Q9QP08RLI02<X6@0R:1L2024X5P0>028X5P0P
9QL082HG020V5P0O9AD08bXI02D]700R:Q/07bLH01hV5P0O:1@07RHA028Y500R:AL201lW5P0601hV
5@0I81404aL<010C2@0=4@L02@d43oooool000gooooo00H04aLL00lD600<4A<020/<00H81`041`@2
00<50P0;00H80`0>4PP041@800dB1P0=4@D03a8900d@200;3PH02Ph400P;0P072@800P061`802`05
1@401PH400P91@0720800`@000<300051@801PL200P:10092`@03A4800803a@;00`041@;018E2`0B
5PX051P;01dR500S:1X08RPI024W6P0S:Qh09blT02`d:00`>RX203@m;00;03Dn:`0e?bX0=d0Z03Ho
:@0f?BX0=cl[03Y3;P0lARl0?4P`03e8<010BS800P11BS802`10BC00@DXb04=;=015C3D0A4`e0458
<`10B3<0@DTa045:<P12BS80@DL`0080@4H`00P0?TDa03e5<@0nAS00?dTa041:<@12CC@0@D`c03i9
<080?d/a00l0@DXb045:<`11BS<0?dXc045;<`12BC<0A4Xd04=9<P13B340@DLb0456=00oA3<0?D<a
03Y2;@0i@2X00`0m@RT02P0n@bX0?d@^0497<P0oA340>cl_03Hl;00b>RT0=3dY03@m9`0c>R<2030h
800;02lf7`0`=al0<3HO030e800^<b00;S@P02`b7`0]<b80;3<S02`e8`0]=R<00P0/=b<0300]>2<0
;STQ034l8`0c?R<0<c`S038j8P0`>280;cLR030h900b>2D0;c@R02/`7P<0;C4O00X0;S4P02d`800[
;Qh0:bdO02d`800/<240;34T02/^8`0/<2@0:S4R0P0X;ah02P0Y<1d0:2hK02P]6P0Y;Q`0:BhM02L[
700U:A/092LK02<V6`0Q9AX3024U6@0601hS5`0M8QH07R@F01`S5@0L8QD06R4D6_ooool01P19Ceh0
Be9T04aEJP1<EV`0BeE[04]EJP80C5IY00/0C5MW04eHI@1AFfP0EEi/05QRL01FHW40EF9a05ITL`1H
IWD0EfIc05ISLP0205ISL`0;05QTM@1IIGD0F6Ee05MSMP1GHWL0Ef=i05QTNP1HIGX0FVAj05]TN`1K
I7`00P1KI7d0301LIGd0G6Ml05eXNP1NJG`0GVUk05iYNP1NJW/0H6Ym05mYO@1RK7l0HVj106=_PP80
I72300/0IW6406MbQ01XLh<0J7>006]fP01]Mh80KWR506miQP1_NXP0LGb<075mSP0207=nSP0;07=o
S@1dPH/0MX><07N3S@1hPi40N8:C07N1U01hQYD0NHND07V7TP1kRI800P1lRY802`1nS940P8jA082=
T@21SY80Q8nC08B@T`24TI<0QY:D08VEU@2:UYL0RiNI0080S9VK00`0SIVL08jIV`2<VIX0SYZJ08nL
VP2@WIX0T9jI092NUP2AWY<0TYjA09:NT02AWY0309>OTP0:09:NTP2AWi80T9f@08nLSP2:UhP0F5eM
03Xj@@0f=S`0;Blb02``<0809RXY00/06QhL020U7`0P9Qd072<I01HJ4P0A5@`03Q<;00dA2`0<3`L0
2Pd300/?0`0200`@100<00`A1@0;40@03A4600`@1P0:30D02@/400dA1`0D60`061`@01PL4@0C5Pd0
41<<0P0F6Q402`0K8AD07bDG024V6@0Q:1T082LH01lV5`0P9aL08BPG020W5P0S:AP09BXH00808bTH
00/08BHG01hT5`0R:A/09RhN02</6`0O:1P07bLG020W5`0P9aH092/G028Y5`02020W5`06024W600K
8A<04AH;00lC1P0=40<02Pd23oooool000gooooo0P0I82H0100H7BD051PP010C6@0<41<200T<3P0;
00`?3P0@51003@l900X<100<3`D03Q4700lB200@4PT03Pl600`=100;2P<00P0:2@<02`0:2@D02PP6
00X92@051@D00`<200810@020P401`P500/>200>4@T030l700802@`500`02Pd600/?1P082`<02@d4
00lD2@0J8A808b`J02Xd800^=b@0<3/X038m;00a>b/2030i9`0;034j9`0b?2P0<CXV038i9@0c>bL0
=3dY03I0:`0g@R/0=d@[03U6;@0mBC000P0oB3002`12Bc<0A4df04A<=`15C3T0A4/g04E<=`14CSL0
ADhf04E?=P16CCD0A4`e0080A4/f00/0@DTd03m8<P0mAc00@4/`045;<@12CC@0@D`d03e:<P0mBc80
?DX`03i9;`0203m;<00<03i<;`0nBRd0?dT]0458<010ARh0@dP`04=8<P13AS80@THb0497<`0oARl0
?TH]0P0nABT02`0k@2@0?D8V0456:`13B2l0@dLa0414<@0nA340?48`03]2;P0h@2T0=CdU0080=3/T
00/0<cTS030e8@0a=R80;c<P02ld800^=1l0;38N02/`800/<R80;cDU02hf900202dg900<02hh9@0^
>B<0;c/Q038n8P0e?b80=ShS03@k8P0`=b40;S@Q02le900`=RD0;S<Q0P0/<Al202`a7@0902`a7P0]
<Al0;2dN02`^7`0]<240;BlS02`_8`0]<b<0:c8R0080:2lP00/0:C0N02X_700Y;A`0:RdM02P[700V
:A`092PJ02@W6@0S9a`07b@J01hT6@0201hT6P0401hT6`0L8QT072<H01TO4`806R0C6_ooool01P1:
DU/0CEAP04mGJ01=EV/0C5I]04]FK080BUEY00/0BeMX04aHI`1@FfT0DEe[05AOK@1EHG00E61a05IR
M@1GIGT0EfEj05ITN@0205MUN080F6Eg00T0F6Eh05QTM`1IIGP0FF=i05USNP1II7P0FfEf05aVMP1L
IWT00P1LIG/0101MIWd0GFIl05mWO01OJ7/2061YNP06065ZN`1QJGd0HV]o06=]P@1RKH80Hfn30P1T
Kh<02`1UL8<0Ig:206UcP`1ZM840K7J006iiPP1_NX80L7^4075lQ`1bO8/0Lgf=0080M7j>00/0M7f>
07F0S@1fP8h0Mh6?07Z3T`1kQ9H0NHBF07V6UP1kR9D0NhRD07b9U00207n<U@0;08:>UP23SiD0PhjE
08:>U025T9H0QI6E08BAU027TiH0R9FG08ZGV02;V9T00P2=VIX0302<V9/0S9VI08bHV02>VYT0SibJ
096NVP2BWiX0TIjI096MU@2BW980TYjB09>OTP80U:2C0P2CX9@02@2AWi40Sif?08nMSP2?W8`0HfMS
03Xf?`0i=cl0<30e02d_<P0202`_;@0:020T8`0L7ad071lK01dR6P0I7A@05AP@010C2`0@4PT03Q06
00/?0`<0310300`02a0300X>0`0<40H02`l600T<100:3@@03a8801@I300H6`l06QdA01LJ400A4`d2
01DH400;01hR5P0S:1X08bPI02<Y6@0Q:1P07bLE01lX5P0P:AH08BPE028Y600Q:1P00P0P9aL02`0O
9QL07bDG028Y6`0U;1`08BXI01lW5P0O9A@07bDF01lT5@0O8QD07R8D00807R<D00H082DF01XQ4P0@
5@X03a@600dA0`082P4?ooooo`003Oooool01P0S:Rl08bX^024X:`0O9BP07B<V01PN80805ATK00/0
51PH014C4`0;30`02PX900`?2@0>4`T03a<900lB2@0=3`H02@`400X<100200/;100;00`=1P0?3P/0
3`h?00`=3@0720T010@500<4100;3P/041@@010D3P0<40X00P0;3PL0300930H02`h700L:10062@80
20/300X=100C60`08RTH02hf8P0d?BL0>D8]03Q0;P80=Sh]00/0=Cd[03<k:P0c>RX0;cHW02dd9`0[
<RL0:cDW02hi:00a?BX0=T8/03Y6;`0203e7<00;045:<`13BSH0@dXh04=;>P14C3X0ADlj04E@>016
DCP0AE0g04E>=P14CSH00P15CcL02`14CCD0@d/c0459<@10BS00@DX`04=<=012BcD0@4Xe045;<`0n
BRl0?D/]0080?dd^0P10CBl02P0oBRh0@DX`0457<013Ac<0@dLd0454<`10AC<0@4Hc03i5;`10B2h2
03m8;00;03i5:011ART0@TLZ0496:`11ABd0@DD`03m3<P11AC<0@DLb03e5;@0j@RX00P0h@2L02`0g
?BH0=3TT02le8@0/<Al0;C8P02ld800]<Ad0;34N02`a7`0^=B<0;cLU0080;SLV0P0^>BL02P0^>B@0
;SXR034l8P0d?R<0=CdS038i8`0_=B80;C<Q02le900_=2<202hd8P0902hd8@0]<b00;34O02/`7`0Z
;B00:R`O02X]800/;R80;34Q0080:c4P0P0Y;Qd02P0Y;a`0:c4K02/`6`0Y;1X09bXK02HZ7@0S9QX0
8B@H020U6P0O9AX301lV700601hU6P0L8aL06b8D01XQ4P0K81406Qh>6_ooool01P15CUP0BU9N04iG
I`1>EVX0C5IZ04aGJ`80BeMZ00/0CEYZ04iIJP1?FF/0D5Y/05=NK`1DHG40E61a05EQM`1FHWX0EfAm
05MUO00205QUN`0;05MSNP1FHgT0EfAj05QUN01IIGP0FVEh05]TN@1KHgP0G6Ee05]VM@1LIWL00P1L
IWT0201LIgX0GVMk05iWN`1PJG`0HV]k069[O01RJWh0HFYo0P1TKH803`1SKX<0I72406MbQ@1WLXD0
J7:506UcP`1[MH<0JgF206agP@1]N840K7N106mjQ@1bO8X0M7b=07AmT00207EnTP0;07J0TP1hPI<0
N82C07V2U@1lQ9L0O8BH07^4U`1lQiL0O8NF07f8UP1nR9H00P20RYL02`22S9H0PXfE08>?UP24T9L0
QY6G08NCUP27U9L0RIFH08VFV02:UiP0S9RI0080SY^K00`0SIZJ08fIV@2>VY/0SYbK08jLV@2?W9T0
T9fI09:MV@2CWYP0UInG09BOU`2DXIH209>PU@0;09:PUP2BWi@0TIjB092OT02@WXd0T9n;075jKP13
@dD0?cm3034`=P0/;S400P0[;R/02`0R9B807QlL020R7P0S:2007bDK01TO500D5P`04A8800l@1P0<
3P@030l30080310300`02a0300`@100<40P0310800d@200?4PT04AD;01@H3@0F6@h05QT=01@G300A
4`X201HG3@0;028V600U:A/092TJ02<X6@0Q:1P082PG020X5P0Q:QL08BTF028Z5`0P:1L00P0N9QH0
2P0N9QL07bHH020X6P0Q:A/07bLH01dS4`0J8A006Al?01PM3`0G6`l301DH3@805AX>00@04QH<00hB
200;3`@01`/13oooool000gooooo00H08bT^02H/<00T:b`08RTX02<Y9`0T:RL2024W9P0;020V9P0I
7Al04aHH00lA4P0>4@l041@>014F2`0@50P03A4500X>0P0930<00P0<3PD02`0>4@H03Q4900h@300=
3`d03@l>00T92@072@L03Q8=01@G4P0A5Pl0310;008020/400`01@L100H80@072@801`T200L:0P06
20402`l601<G300L7a<08B@G02LZ7P0d>b/203a4<`0;03e7=00kA3<0=d0a038k;P0[<bT09B`S024X
7P0M8a/08b/O02di9`0d?b/00P0jABh02`10BS80@dde04=<=P11BCH0@DXg0419=P11BSH0@d`g04E?
>015CcT0Ae8l0080B5<j00/0AU0f04A<<`14C3<0A4`b04=:<015CC@0A4de04A==`14CSL0@T`e045<
<P02045<<00<049<;`12CBl0@DT_04=8<013Ac<0@dLf04A8>013AcP0@dPh0498=P11BC@0@T`b0P13
CC802`13C300A4`^04A;;015BBd0@DD/03e2;@0m@S80?D@d03e5<@0lABh0?4D]0080?4@[00/0>40X
03Hm9P0b>2<0<3DS02hb8@0]<B00;S8P02lc8@0_<b80;cDT034i9`0202hh9P0<02`g9@0_>RL0;cXW
02li900]>280<3/R03@m900c>b@0<cPT03<h9P0_=BD0;S@T0P0`=RD01@0a=bH0<3HT02dc8@0[<200
:RlR0080:2dQ00@0:S0S02`b8P0/<R00:c0O0P0Y;Q`02`0Z<A/0:c<K02/b6P0Y;AP0:BXJ02LY7@0T
9Q/092HL02<V700O8aX082HL00808BHL00H07RDI01dT5`0N8a@07B8A01dQ400K7PdJooooo`0604I?
F@19Df00CEQW051KJ`1@FV`0CUU/0P1;Ef/02`1>FFd0Ce]^059ML01BGW00Df1`059PL01CHG40E69c
05ERM01FI7L0EfEh0080EVEh00/0EfEh05QUM`1HIWP0FFIi05QUN01JIGX0GFIl05iVO@1MIGX0GFIi
05eVN00205mXN00<05mYN@1PJg/0H6Uk061YO@1RJWh0Hfao06=/P01PJX40Hff406E_Q@1ULHL0Ig:7
0P1YLhH02`1ZLhD0JW>406egQ@1]MhD0KGR606miR01_NHX0L7Z<07=lSP1dOI40MGjD0080MWnD00P0
MGnD07IoT`1hPI<0NX:D07^3UP1lQID0OHFG07n8V080P8VJ00h0PHZH086<V021S9P0PhfH08F>V025
T9T0QY2I08JAV@28U9T0RIJK08ZFV02:UiT0RiRI08fJV`80SifM0P2>WId02P2>W9d0SYfM092NW02@
WYX0TInJ09>OW02DWi/0UJ2J09FPV02DXIP209:PV00;09:PU`2@X9D0T9nC092PT@2AX8d0Tj>=07V5
MP19C4/0ATU7034b=00[;Rh00P0[<2X02`0U:b@08BDM02HZ800W;B8082HK01LK4@0B5@X04187010A
1P0?4@L03A4600803Q<500`03A8400dB1@0>4`P03A4:00lC2`0B5P`04QH;01<G2`0B5P/04QL:014F
2P0@50T2018E2@0;01hQ4@0R9aL09BTI02@Z6@0U:QT092XI028Z6@0T:aX08RTH02@Z5P0T:AL00P0Q
9aL02`0O9AP07RDH01`T5`0K8QD06R4C01LM400D6P`04QP:014E2@0?4`T03Q4800803A0800H03A88
00lD2@0A50/04A<:00d@1`082`<?ooooo`003Oooool01P0X;C00:Bhb02H[;P0T:BT08bPW02H[:@80
9R/Z0P0T:R`02@0P9RP0724R01LL6`0F6aD04QL=00dA1P0;3P802`l300/>100200`@1@0;00lB1`0?
4@P030d800T;1`0:2`X02``:00d?2P0A50d051P?018G300@50X00P0;40@030072P001PT000L90@08
2@<020/400P;1@082@H02`d:010C400D5Q<05APE024U7P80=3d_00/0?4Hd041;=`11C3T0>48a02`d
9P0V;B007R@J01LK5@0E6A<07B<J02H]8@02030j:P0;03Q4;`0oBS<0@4/c03m8<P0oB3<0?dLc0418
<`11B3D0@dXh04E<>P15CSX00P14CcP01014CcH0@Thd04=>=013CS8204A=<00504I><`16CC@0A4`d
045:=011Bc@00P12C3<02011Bc40@4Xa045;<P14Bc@0AD/f04A9=`14B3H0ADTh0P16BcX03015C3P0
@d/f049;=@12BcD0@d`d04A><P13C2l0@TT^0455;00l@BX0>cl/03To;P80>T4`00h0?4@a03]3;`0k
@bl0>40]03U1;P0h@2`0=C/Y034f900^<b40;cDQ02lf800_=B40;S@R030g9080;cLU00/0;SPT030k
9@0_?2<0<3`S02dh7`0]=al0;cTQ038k8`0c>RD0<SPU030e900302dc8@0;02lf8P0a=b@0<CLT030e
8`0]=240;C8Q02X`800Z<240:c4Q02`c800Z;a`00P0Y;Q/02`0Z<1d0:c4N02X^700Z;A`0:bhN02T/
7`0V:1h092LN024T6`0P8aX082@I00807b8H00H07b8G01`Q4`0N8Q@07b<C01lR4`0M814Jooooo`06
04MBGP19EF80C5QX04iIJP1?Ff`0CUY]0P1=F6h02`1=FFl0CUY`055MLP1@G780D5a`055NL01BHG80
DF1`05ARL@1EHg80EVAc0080F6Ie00L0FFMd05YWM01JIW@0FfMg05YVM`1JIWT0FfIk0080GFIl0100
GFMl05aWO01LIg`0G6Ml05iZO01OJg`0HF]m065ZO@1QJWh0IFj106A]P`1SK8D0I6f506E_QP1VLXL0
J7:70P1XLXD01P1[M8D0KGN706mhR01_MhP0KgR9075iR`80LGZ=00<0LW^?07AmT@1fOi800P1fP9<0
2`1eOY80Mh2A07R2T01jQ940OHFC07j6U@1nQYH0PHVH086:V@22RYX0PhZI0080Q8bI00/0Q8jI08N@
VP28SiX0RI6L08RBW028Tid0RIBL08^EVP2;UiX0S9VK08jMW`0208jNW`0<08jNWP2=WYd0SIfM08jN
WP2BX9l0Tj6N09>PW@2BWi`0TinL09BPW@2DX9/0Tj2H0P2AWiL02`2CXIT0TZ:G092QTP2AXY40T:6?
09:RT01oSGh0DEEC04eBCP0b<cD0:R`/0080:B`Z00/09b/V02<W800Q9Qh092TP028V7`0M7aP061T@
01@G300B4`T04Q<8010B1P0200`A100<00/@0`0<4@@03A4600d@200>4@T03a8:00lB2@0?4`T04QH<
01@I3@0B5`/041@90P0B5@T02`0K7Pl08RHF02@X600U:QP09R`G02@[5P0T:aL09bdI02@[600R:1H0
8RLE008082@E00/07B0C01TM4P0F71005A/?01DJ3P0C60/041@9010D2P0?4PX03A4900/?2@0200/?
200600/>1`0<3`L03A4800hA200=40L02@`43oooool000gooooo00H09b`Z02X^;00Z;Bd0:B/[02PZ
:00W:RL202P/:@0;02P/;P0V:S009b/a02L/;`0V:b/08BLS01PL5`0@50h03Q0:00l@2P0?3`/00P0=
30X200h=300900L61`030`@010D500@5100930H04QL<01PM3`0G7@h04AH:0080310300`02@`100T<
0P082P802P`500d?200;3@P02P/700T9200<2`/04A0A01@C4P0F5Q<201`M600;02LZ8@0c>2/0?D@d
03Hm;`0W;B4082HI01HI3`0G6Q405aXC01PN5@0O9A/00P0W<2<02`0^>BH0=D4[03Q5;00jARd0?TP_
03m9<P10BC<0@4Pe0417=P11BCL0@D/g0080@4df00/0@Dlf04=@=P14CcD0A4la04A@<014Cbl0ADl`
04A=<@14CC80@DXb041:<P0203m:<P0<03m;<P0oBc40@4Xb049;=014C3H0AD/f04E:=`15BST0ATXj
04M;>`17C3/0@TTe0P12BS@02`12Bc80@T``045;;P11BBd0@TT^03m4;@0l@2`0>Cd]03Pm;`0j@340
>d8a0080>T8b00/0>D8`03U1;P0g@2/0=d4Y03@l9@0b>B40<cXQ02lf7`0]=1l0;C@Q02df900202lg
900302hh900_>b<0;SXO0080;c/O00L0;STO02lj800a>b40<c`T034h8`0a=b@0;S@R0080;SDQ00/0
;SDO034g8@0e>R@0=C/T038h900_=B40:c4O02P_7@0X;Q`0:BlL02X`6P0202X_6`0;02T^700Y;1h0
:bhO02X]7`0Z;R009bXO02DW7@0S9A`08RDL024S6P0P8QL00P0O8QH01P0O8QD07R4C01dQ4P0O8a<0
7b<E01`Q51[ooooo00H0B5=P04]GI01=FVX0CUY/04iJK@1>Ffh204iLL00;04iJL01?Fg00D5aa051L
L@1AG700D5a_059PL@1BGg00E69a05MTLP1HIG<00P1JIgD01@1IIW@0FFIc05aWM01MJ7H0G6Mg0080
FVIi00@0FVIj05]VN`1NJ7`0GVQm0P1NJ7`0301NJW`0GV]l05m[O01RJg`0Hfam06E_P@1TKX80I6n4
06A^Q@1TL8H0I76706EbQ`80J7>600/0JW>606afR01_MhT0L7N9071iRP1aNHX0L7V:075kS01cOHh0
MGn@07J1T@0207N1T@0;07J0T@1gP940N8:A07b4T`1mQI<0OXJD07n8U@20RYH0P8VE08:;U`24S9T0
0P23RiT02`25SIT0QXnI08J?V029TY/0RI>L08RCV`29U9X0RiJK08fHW@2>VIh0SY^O0080SI^N00`0
SYbN08jMW@2AWih0TYnN09>PWP2EX9l0U:2M09>OV`2CWi`0U:2N09BQWP2BWiX2096OV00;09:QV@2A
XIP0TJ6F096QU02@Wi80TJ6A082=P@1@E580E5eD038f=00V:BP00P0U9bD02@0T9bD08bHT02@X9@0X
;bP0:c0X02<V7P0I6a@051D?010@200200l@1@803@h400`02`h200`A0`0=4@@03Q8700`?2P0:30T0
2`d900d@2`0A5@l04aP@018G3`0>4`/200hC2@0;01LK3P0O91D08bPH02DZ600U;1H08b/D02@[5@0S
;1L08BTG01hV5P0O9QH00P0O8aD02`0J71005AP=01<G300C60/04AH900hB1P0=40H03Q89010D3@0<
3``02Pd900802Pd700H02P`500X=1@0930@02@`300X>10082`<?ooooo`003Oooool01P0P9b<09B`T
02X_9P0]<2P0;RlY02`]:@80;Bl/00/0;2h^02X[<00/;SD0;c8h034f>@0[<C00724P01PJ6@0E51D0
4a0C014?4`0200d;4@0;00/940071Ph01@@;00<31`041@D00`D300D70@0B60P06R0?01LL300B5@P0
0P0<3`D030092`802P`400X=1`0?4@/04Q@<010A300>3`/030`:00d<300C4A405aDD01HD4`8051<B
00/061PD01/K5`0R91d092LO01dR6@0F6A80414:018D300K7a@08BPK02@[7P0202<[7@0702@]7@0V
<Ah0:SHQ030k9P0g@b/0?DP`041<=002045;=P07049==`12CSH0@e4f04=A=P13DSD0Ae@g04MB=`02
04IA=@0504IA<`16D3@0A4hc049=<@13CC<00`13CcD03012CS@0@Ddd045;<`11Bc<0@ddf04A==`17
CCP0B4hh04U>>@1:CSX0BU0k04]B?080BDlj00X0Adhg04A<<`13C380@d/c04A<=012BS<0@TPb0456
<`0oA340?TDb0`0oBC<02`0mAS40?4D`03U4;@0iAbd0>4D[03M29`0f@2@0<S`P030i800`>B40;cLR
0080<CXU00`0<S/V038l9P0b?2<0<C`S034l900a>R<0=3`U03Dn9P0f?RP0=C`W03Dl:00a>2D2030f
8`0;030g800`=al0=CXR03Hl8`0e?2@0<c/S02lg800/=1h0:S8L02Tb700Z<A`00P0[<Ad02`0Z;a`0
:BhL02`a7`0[<200;38Q02T^7`0U:A/09BTL02HZ7`0U:1d092PL00808bLL00H08BHJ024V6@0P9aP0
82LG01lV5`0P9ALJooooo`0604MCG@1:EV40C5UX04iJK01>FVd0CEY^0P1=Ffl02`1>Fg00CeYa051L
L@1BGG40DUe_05=OK`1CHG00Df1_05ESK`1HIW80F6Id0080FFIe00/0F6Ef05YUM`1LIWT0G6Ii05]V
N@1JIg/0FfMl05UVN`1JIWX0GFQk05mXO@02061YOP0<069/P01SKX80I6n206A^P01UKX40I6n206=_
PP1RL880Hg2406AaQ01TL8@0IW:40P1XLh@02`1ZM8@0KWJ606mgR01bNX/0LW^;071jR`1`NX`0LWf=
07=mSP1gOi00NH6@0080NH6?00/0N86@07Z3TP1kQ9<0OHJD07j7U@1oR9D0P8VE086:UP21RYD0PH^E
08>=V00208B>V@0;08J@V`26T9X0QY2I08NAV@28TYX0R9BK08ZFV`2;Ui`0S9NM08jIW`2>VIh00P2>
VYl0302@W9l0T9fO09>PX02DXJ00U:2N09FPW@2FXYd0UZ>N09JRWP2FXYl0UJ:O09:OW080Tj2J00/0
U::J09FSV@2FXiP0U:>F09:RU02CXY80RIV604a@B`1>ET`0>Chi02PZ:P0202DW9P0;02/^:`0W:RT0
9b/Z02/b;00[<BP08bLO01/M600E5a40414:00d?1`0>40L00P0<3`@0300;3`@0310400`@100<40H0
2`h800X=2@0:3@P03Q@;01@J3`0D6a404QT?00hD2P803A<900/05A/?01`S5@0Q:AT08b/I02<[5P0T
:aD09B`F02@/5`0S:aP08BTH020X5`0201`R4`0;01LL400D6@d041D;010E2P0?50P03A4800`?1P0=
4@L03Q<900`?2@0:3@H00P0830@01P072P4020/100H:00052P001``000L;00oooooo000=ooooo`06
01LN7P0J8A`07R@K028U700V:240:B/U0P0]<B/02`0^<Bh0;S4a02hb=00^=3L0<SXk034i>00W;Bd0
82DU01lQ900I6B4051@N00804A4L00/03a0K00X:5@061A000`<;00421@010`<00`D100dA1P0F70h0
61d?01HG3@02014B2P0<00h>200=3@T03Pl<01<D4P0G6AD05aXG018F500>41003Q0A018C4`0E5AH0
4a4C0P0A3a402`0B4Q404A4?01<D400G6A805AT?014C2P0?40L02`/201HI300U:aX09R`N00807B<I
00/06AlF01HL4`0H7Q<072@F02@]700/=R80=40Z03U4;@0lB2l0?TX_045?<@0204=B<`0;04A@<`16
DCH0Ae4h04I?=`18DSP0Ae8g04EA=@15DCH0A50e049>=013CSD00P14CSH03013CCD0@ddd04=<=012
BcD0@T/f04A;=`16C3P0Ad/h04Q<>@19CCP0Bdhi051D?`80DEE000@0CE4l04Y?>P18CST0AT`h0P14
BcL01@13Bc@0@d/c0458<010B300@DTa0080@DTb00T0@DLb0417<@0mARl0?4L`03]6;`0hA2/0=T8W
03A08P0a?B000P0`>Al2030j8@0<038l8`0d?bD0=3dV03<l9P0a?2H0<S/U03@k9`0e>RH0=SdY03Lo
:P0f?RX0=3hZ0P0c?BL02`0c?2<0;SDN02`b700`=Qd0<3LN030h7`0`>1h0;CDL02/b6@0Y<1P0:2dG
00809b`I00/0:2`K02T]7@0[<1l0:RlP02T_800Z;b009bdM02<Z6P0T:A/08bPJ024V6002028V6@06
024V6P0P:1/07bPJ024Y6`0P9aT082DG6_ooool01P17De`0BEIP04aII@1=FVX0CUY/04iJKP80CEY^
00/0CUYa04iJL`1?Fg@0DEac055LL@1CH740EF9b05=OK`1DH6l0EV=a05QUL`0205QUM00;05MTM@1H
I7L0FVEj05aUN`1KIWX0FVEk05]VO01JIW/0FVEj05eVN`1NIgd00P1QJWl00`1SJh00IFf206E]P@02
06A]P00706E_PP1UKh<0Hfn306=_PP1TLX80I76106McP@0206UdPP0;06]fPP1`NXD0LWZ707=jR@1b
Nh/0L7Z<075lS`1bOI00Lgj@07EoT01gP8l00P1hPHh02`1jQ900OHJB07j5TP1lQ980OXNE0829UP21
RiL0PH^F086<UP22S9L0PhbI0080Q8jJ00/0Q8nK08F?V`26TI`0Qi6L08NBV`29U9/0RiNM08fHW@2?
VYd0TIbO096KWP0209>MX00909>MXP2BWJ80TYjS09>OY02EWj40UZ2Q09BOX02EXJ00UJ:P0080Uj>P
00h0U:6M09FQW02EXI`0UZ6K09JRV@2GXiH0UZ>D09BRTP2CXI00TZ>=05MLEP0g>CX0?44n030c<P80
:2X[00/0:bh[02T/:P0T9bL092TV020U8@0I7QX05APD01@H500?4`l03Q4;00hA2@0200dA1`0<00d@
1P0<40D03A4700`@1P0<40L0310800/@200=4`P04AP;01<K3@0B6@/03a@80P0<40L02`0H7Q407bLG
028Z6@0T;1X09B`J02H/6@0W;AT092/G02@/600R:aL07RLC00806R8@00/05Qd?01@J3@0?50T03108
00/@1`0<40P0310700`@1P0=4@H02`h500X=100200P;0P0600D800062@0010L0008700021P000@@0
3oooool000gooooo00H05ahN01XQ700N91/08RDL02HX8@0Y:bD202da:`0;02ha;P0^<C40;S8d02hd
=`0b>S/0<CTh02L];@0P9BD07b4T01TI8@0D51h00P0A4A`02`0?41/02PXE00H540030`/00@850043
0`031@403A4601HL3P0H7@l05QL=00804A8:00`03Ph800d=2@0>3``04a@B01LI5@0G6QL04QHD00h@
400>41404Q<C01DE5P0C4A<2014?4@0;018B4@0A4@l04a@@01LI4P0E6@l04A<:00l@1`0;2`805QT<
02D[6P0V;1h00P0M8aT02`0I7aH05Q`C01PN4`0L91H092dL02`f8P0d@2X0>D@]03a8;`0nBRl0@Dla
0080@e8c00/0A50c04IA=P17DCP0ATlg04QB>017DSL0AE4e04EA=P14D3D0@Thd04=>=@0204A>=P0<
04===@13CC@0@d`d049;=@12BcH0A4/g04I<>017BcP0B4`i04U=>01;CST0D5@o0P1AED00101=DC`0
BTlj04Q>>@16C3P204A;=`0504=;=013Bc<0@DP`0418<011BC400P11BC802@11Ac80@4La03e6;`0l
Ac00>dH_03Q4:`0f@RL0=40R034m8002030i7`80<3XQ00`0<S`S03@o9@0d?BH0<c`V034l9P0b>bD0
=3/W03Dj9P0f?BT0=clZ03Hn:P0d?RX203<m9`0;03<l8`0^=Ah0;38L030f7@0`=ah0<3PO030h7P0]
=A`0:c8I02T`600X;AL00P0W;1T02`0X;1/0:BdM02/`7`0Z;b00:BlP02X_800W;Ad08bXJ02@Y6`0S
:1X08BHH00808RHI00H08BHJ020X6`0O:1X08BTK020W6@0P9ALJooooo`0604MCG019EV00C5UU04eJ
JP1>FV`0CUY^0P1=FVh02`1>FW40CUYc04mKM01AG7<0DEaa05=PL@1EHW80Dem_05APK`1FHg40F6Ec
0080F6Ed00/0EfAe05QTM`1JIGX0G6Ek05]VNP1JIG/0FfIl05YVN`1JIGX0GFIk05iWO@02065ZO`03
06=[P01UKH80IFf10080I6f000L0IFn206E_P`1SKh<0Hfn206AbPP1TLH40Ig>10080JGB200/0JgJ2
071jQ@1bNXL0LgZ9079kR`1`NX`0LGb?079mT01cOY00MGn@07N0S`0207R1SP0;07Z4T01mQY80OXFB
07b4TP1nQiD0P8VF086;U`21RiH0PHbF08:<U`23S9T00P24SYX02`24Si/0QHnK08JAW027TI`0Qi:K
08VDV`2;Uid0SIRM08nJW@2AW9l0TI^N0080TifP00T0TifR09:MXP2BWZ<0TinT09FOX@2FX:40U9nP
09FQX02EXZ000P2GXj003P2DXId0UJ6L09FQW02FXI/0UZ:I09NSUP2FXi@0U::B09>QT02BXhd0EeaF
03Li>P0l@Ch0<3<b0P0X:R/02`0[;R/0:B`Z02@W9`0T:BH082DQ01TN6P0E61@051PD00lC3`0>4@/0
3Q4900803A4700`03A0600`@1@0=4@L0310600`@1`0<40P02a0800dC200A60/04a/=018I2`0?50P2
00`@1`0;01PN4@0O9aL08RXI02@/6P0U;1X09R`I02L]6@0T:aL092`H028[5`0N9a<00P0J8Q002`0F
7@l051X=00lD2@0<40P02a0700`@200<40L0310600dA1P0;3PD02Pd4008020/200H01@P000H90004
1`000PL000860001100?ooooo`003Oooool01P0K82806QhN01LL600G6a@06QdG020R7080:2/S00/0
;2lX02lc;P0`=S<0;SDd02dd=P0`>3P0;SLe02P_;P0W;Bh09BX_02@Y;`0202@V<@0;028T;`0L7RP0
51DP00h>60082A4010H;00<51P0;3`X051P>01HJ400B5@d00P0B4``0200B4@d04Q4>01@C4@0J6aL0
7B4L020U8P0O9B<0728O0P0J7ah03`0E61X03a4D00d=4@0=3A403@d>00`>300=3`/041<=010D300>
4@P030l500X<0P0J8100:C8N02Tc7`0201lW6@0;01TO500D60l04QH<018F300E6@l061d@01hT5@0T
;1X0;3HP03A09@0lB2/00P11CC002`15D3<0AU4e04M@=`17DSP0B5<f04MB=@15Dc@0AU@g04ME>@16
DSP0AE4h0080ADlh00D0A4hg04E>=`16CCH0B4lg04Y@>00204Q>>P0504I<>017C3T0B4dj04Y?>`1>
DS`00P1>DSX02`1>DCX0C54j04]A>`1:CcT0ADhh04E?>013CC@0@ddc045;<010Ac00@DL`0080@DLb
00/0@TPd0498=@0oAS@0?THd03]4<@0h@B`0=d8Y03Do8`0a?1d0<CXM034j7`02034k800<038m8`0f
@2D0=3hT038l900a?2@0<S/U03@k9`0e>RT0=C/[03Hn;00d>bT0=C`X0P0e?RP02`0e?BL0<CTT02de
7`0[=1`0:cDL02Xc6`0/=A`0;CHL02/b6P0Y;aP0:RhI0080:c4N00/0:RhN02T^7`0Y;b009bdO02T_
7`0Y<1l09blN02D]6P0S:aP082TE01lW5002024X5P0602<Y600O9aL07B@F01lU6@0O9AP07R@E6_oo
ool01P16DE`0BEEP04aIIP1<FFX0CUY]04iJKP80CEY^00/0CU]`04mKL@1AGG<0DUec055LL@1BGW40
E5ma05AOL01DH6h0EV=_05ISL00205MTLP0705QULP1HI7@0FVEi05aVN`1LIG/0G6Aj05aUN00205eV
N00705iWN@1QJG`0HFYm065ZO@1QJG`0HVam06=]O@0206=/O00706A]O@1TKWh0IFn106E`P`1ULH<0
IG:006QeP00206UeP@0806agPP1_NX<0LWj707AmR@1cO8/0LGb;079mS@1dP8l207F0T00807N1T01g
PHh0Mh6>07Z3S`1mQI40OhJD0826U@21QiH308:;V080PXbG00X0PhfI08B>V@24SYT0QHnI08J@VP27
TI/0R9:M08RCW02;UI`0SINK0P2AVYd01@2AVYl0TifQ09>OX`2CWj<0U9nT00<0U9jT00L0UIjS09NP
X`2FWj80UYnR09NRXP2GXZ00UZ:N00<0Uj>L00/0Uj>K09JRV02GXiD0UJ:C09BRTP2CXI00UJFA06M`
J@0a<3H0?44o03Dg=P0202`];00;02/^:`0Z;B/0:B/[02P[:P0N8B8061`M01@F500C5A004A@<00hC
2@0>4`L00P0=4P@02`0=4080310200`?0P0<3`<0310500dB1`0<4@P02a0700`B1`0>4`P03Q8700<0
310500/06B0B024Y6@0R:aX09BhL02H]700V;1/092TI028Y600R:QH082TD01`T4@0201TP400;01HM
400E70h041H<00`A200:3`H0314800/@1`0;3`@02`l300X=0`072P800P0620401P041`001@P000@7
00031`000@D0000300oooooo000=ooooo`0601lR8P0M820061`K01HJ5`0F6Q@06AdE0P0L7QD02`0O
8AT08bDP02PZ9`0[;b`0;3@b034j>00a>SH0:c@`02/b<00/<c<0;S<d0080<3<g00/0<3<i02ha>@0[
;SL08bL`01PL9@0@4a/02`dB00/>400@51005AXA01DI4@0201<E3P07018C3@0C4`d05QL@01XK5@0J
71P07B4N020W900202D/9`0302L^:00P9R805ATH0080414C00/03`h@00d<3P0>3@h0414@00lC400?
4Pl03A0<00`@2@0A5`/061l?01XR400201/R4@0;01TP3`0F6`h04aH:018E2P0C5@/04Q@:018E2`0C
5``06b8A028Y500/<a/00P0i@RL02`0oB2`0@dda04I@<`18DC@0B58c04MC=P17DSL0Ae<h04UE>P19
E3X0B5@k0080Ae<k00L0AU8i04E?=`14CCD0B50h04UA>P18D3/0Adhk0080Addh00<0B4hi04U?>@1<
DSX00P1<D3P01P1;D3P0C58k04aC?01;DS/0AU0h04A?=P80@dhd00<0AU4f04A?=P13C3@00P13Bc@0
2`13BcD0@dTd0457=@10B3@0?4@a03]2;P0kA2`0>48W03Do8P0d?B00=ChP0080=3hQ00`0=3dQ03Dm
8P0f?R<0=ShT03Dn9P0d>bH0<SPU03Dl:00d>RL0=3/X03@l:00e?2P203Dl9`0;03@k9P0b>bD0<C/T
02lj8P0^>R00;CPO02`e7P0^=Qh0;C<O02`b7`0Y;Qd00P0[<2002`0[<280:BlQ02P_800X;ah09bdM
02H]6`0W;aX08b`G02</5P0S;AH08b`F00808b/F00H08RXF020X5@0O9aD08BTG02<Z600O9AHJoooo
o`0604IAG019Df80C5MX04]GK01=FG00CeYa0P1>FW002`1?G780D5ec059NLP1BGG40Deia05EOL`1G
Hg@0EV5b05EOL01GHW40F6=b0080Ef=b0P1HIG<02@1KIWH0FfIi05aVN@1MIWX0GVMh05mXM`1PJGP0
GfQi065ZO002069ZO@0<065ZO@1SK7h0I6in06A_O@1TKWd0IVmn06M`O`1XLH00Ig6306QbQ01YLh80
JWF10P1/Mh<0101^N8@0L7Z607=mR01dOXP207EnR@0507J0SP1fOi00N86@07R1S`1hPY000P1hPi40
1`1jQI80O8FD07f6UP1oR9P0PHRI08>9VP23RYT00P24S9T03`25SIT0QXjK08N?W027Si`0R96M08NB
W@28TY`0RIBM08VDW02;UiX0SYVJ096LW02AVid0TIZO09:MXP02096MX`0<09>OY02EX:D0UJ2T09JO
X`2FX:<0V:6R09NQX@2GXIl0Uj:O09NSWP2HY9d0V:BL0`2GY9/02P2FY9T0UZ>H09JSU`2FXiH0U:>D
09FVU@1]N6l0<C<h03a2@00h?3X2030b<@0;034d<P0_<S00;c@`02ld<00L7b006adM01HH5@0A4@`0
414800d@1@0<4@<00P0;4040300<3`403A0300`?100<3`H030l800dB2`0>4P`03A8:00`A1`0<40L0
3A4600dB1@804AH800/07B@B02<[600U;A`09BdM02D]7P0T;1h08RXL02<[6`0R:QP07RHC01XR3`02
01HM3P0;01@K3P0C6Ph04QT>00lF3@0=4PT03A<900`A1`0;3P@02Pd400/=10082P800P051P001P03
1@001PL000@700031P000PD0004300oooooo000=ooooo`0601PM700N8B0071`N01LH6P0G61H061XF
0P0H6A@02`0I6QD06ATF01TH5`0K71X082DQ02P`:P0]=Rl0;SL^02lh<@0]=C40;C<a0080;c<d00/0
<3<h034c?00a=Cl0;cDn02/b>@0S:S007B8W01LM7`0G7AT061hG01DJ500201<G400<018F3P0E60l0
5a/B01HI400A50h04QD@01LL5`0Q9Ql0:BlU02hd:P0^=B/092XT0P0L7a`02`0H6AT04a4D00h>4P0@
3a<03a4C010C4`0A51<04ALB018I400F7@l05al<00<05ah;00X05AX901<G200A5@H04AD6010D1@0?
50D041@601DI2P0E60P06Qd:0P0Y;QL02`0g?280@4P[04I@<P19DSD0BE<f04MC>017DcL0AU<h04QE
>P19ECX0BEDl00<0Ae<l00/0AE4i04A>>015CSX0Ae4m04UC?@17DSX0ADhf04I>=@17CSD0B4hf04Q=
=P0204Y>=`0604U>=`1:Cc/0B4ll04QA?@16D3X0A4hf0P13CSD00`13CCD0@ddd04===00204A>=P0;
04I>>013BSD0@dPe04A:=P10Ac<0>d<`03Y2;P0i@R`0=ClX03E09P0g@R@00P0f@280300f?b<0=clS
03U19@0h@2@0=chV03Hl9P0c>BD0<CPU02le8`0`=RD0<c/X03@k9`80<cXV00/0<3PT034i8`0b>R<0
<c/S038j8P0c>b40;cHN02dd6`0^<ah0;S<R02db8@0202`a8P0;02`a900/<R@0;38R02/a7`0W;1/0
9B/H02L^6@0U;AP09BhI02@]6@0T;1P00P0U;1T01P0S:aP08BTF020X5@0N9Q807RHD01lT5A[ooooo
00H0BE=O04]FIP1<EfX0C5Q]04iJL01@G742051KLP80DEad00T0DEed059MM01DGG@0EEif05MPMP1F
HGD0F65e05URM@1HHW<00P1JHgD02`1JI7D0FVEf05YVM`1JIWL0G6Mh05iXN@1OJ7P0H6Yi065[NP1P
JW/0HFYn0080HF]n00`0HFao06E_P@1TKWl0IVmo06M`P@1YLX80JG6006QbP`1YLX@0JG>406YdQ01]
MXL206miR@0;075jR01aNXL0Lgf:07EoRP1eOhP0Mh6;07R0S`1iOi40NX6B07^2T@1kPi400P1kQ940
2`1lQI<0OXJE07n8V@20RIT0PhZJ08B:W024Ri`0Q8bL08B<V`25S9/0R8nN0080RI2O00/0RY6P08ZC
X02<U:00RiFM08bGW@2=UiX0SYVJ09:LV`2CWIh0UIjP09BNXP0209:MX@0<09BPXP2FXJ<0Uj:S09VS
XP2HXZ80V::Q09RRX02GXYh0V:>N09VTWP2IY:00VZBP0P2IY9d02`2IY9h0VJBL09NSVP2GXYT0Uj>G
09NUU02HZ9D0MX9g03Tk@@11B4H0?44n0080=SXg00/0>Clh03Dj<`0^<R/0<cP`01hO7@0L7AT05aPC
014C300?4PT03Q4600`@0`0200`@0P0<00dA100=4@H03A4800hB300>4Pd03A4<00hB300?50/03Q88
00dA1`0>4`H03Q<50P0B5`L02`0L91408b/G02P`7@0X<1l09bhP02D/800U;B008R/M024Y6P0N9AH0
6R4B00805A`>00/04QT<018H300C6Ph04AP=00hD2P0<4@P0310700X=100930@02P`400P90P0200H7
0@0600H5000610000`@00085000110000@<03oooool000gooooo00H06b0O02T]:00U9RD07adP01XI
7@0I61`201PF6@0;01LF600E4a@04a8A014C4@0C5a8061hG01hU6`0W;b40;SHX030g;00a=Rh00P0_
<bl02`0_<S80<C<h03@f?P0d>Cl0<SPo02lg?00[=3H09Bl_020X9`0K8R005Q/J00805QXH00`05aXF
01HJ5@0F6Q@051PB00hA300=3`/041<>01/O5`0R9Q`09RXN02/^8P0]<RP202da:P0;02T^:@0T9bH0
7AlS01LI7`0B5AX04A@H01DI600J81X06R4H01XQ5@0G7`l00P0H7`d02`0G7@`04aT8018G200?50H0
3Q<500hA0`0@5@D04aL701DG2@0B4`L04Q8500806AP700/08R4>02`]6@0k@B/0A4dd04MA=`19EC/0
BUHj04UF>019EcL0Ae@f04MC>00204QC>@0<04UE>`17DCX0AU0k04E>?017DC`0Ae8l04QC>P15D3@0
A4ha04E><P16CC<0AT`c0P17Bc<02`16Bc@0Ad`h04M>>`14C3X0A4dh04A>=P14CcD0@ddc045:<P12
Bc<0@T/b0080@TTc00/0A4/d04A:<`14BC@0AD/g04=:=`0oAcL0?4<e03U1<P0f@2h0=3l[03A0:@02
03<n9@0<03<n8P0f?b80=d0T03Dn8`0d>b<0=C/U03<h9@0a=bD0;S@U02db900]<b@0;SHS0P0`>2@0
2`0a>2<0<3PR02lh8@0`=b00<3LO02lf7P0]=1`0;38J02da7@0/<1l0:blP0080:blR00/0;30S02`a
8@0/<B00;34P02T_7`0V:a/09B/J02@[600R:QL08bXG02H[6P0202H]6`0602H^700T:aX08BLG01hU
5@0N91<07B8A6_ooool01P19EUl0C5UT04eIJ@1?FVh0CUU_04mJL080D5Y`00/0DEab059LLP1DGW<0
EF1e05ANM@1DGGH0EUig05MNM`1IHGL0FF=f05MRM00205QRM00;05QRM@1HHgD0FFEg05UUN01LIgT0
GFMi05mYN01PJWT0GfUj061ZN`1PJWd00P1QK7h01P1RK7l0IFj206I_P@1WL840J72306UaQ080JG:4
00@0J7:206YdP`1/MX@0KgV70P1`NXL02@1aNhT0LWb9079mR`1bOH/0Lgj:07F0S01gOhd0NX2@07b2
T00207f4T@80OXJB00P0OHJA0829U@20RIP0PHZH0869V@22RIX0PHZL08>=WP80PhbN00`0QXjN08V@
W@29T9d0RY:M08^CW02<UId0SIFL08jGW02?VI`0T9VL09>LWP2DWIl209FNW`80U9fN00`0UYnP09JP
X02GXZ80Uj:R09NRX@2HXZ00V:>P09VTX@2IY:00VJBN09ZTW`2JY9h209VSW00;09ZTV`2LYi`0VZBI
09RRU`2HXiH0V:FB09NWT@23TH40?d=604A:B00j?cd00P0c=c802`0d>S80=3X`02d`:00^<RT07AhI
01/L5P0F5a404A<:00hA1`0>4@D031040080310300`02a0400/>1@0<3`P03A0<00h@300<3@X03@l:
00hA2@0>4`T03A4500/@0P0;3P4200`@0`0;01hV4@0S:aH09blJ02L_700U;Qh092dO02H^800S:ad0
8BTL01hW6@0I81<00P0D71001`0B6@d03aD;00lE300=4`/03A<:00/?1P082`<00P082P400`072@40
1@H000H7000200H7000500H6000310000@@0004300000P003oooool000gooooo00H0Df=G04UEB`0e
?3H0<CHb02`^;P0X:B/2028Q900;01hL7`0K6QX061TD01@G400B5Pl04aP@01DI400L7a<08R@G02X[
8P0`<b`00P0a=2h02`0`<c40<cHh03Lj?P0g>d40=ce403<k@@0a>Sh0;SLi02Ta<P0S:R/08BLX0080
8BDW00`07b4R01`O7P0H6A/04a@G00h>4P0;2`h0418B01`P6`0L81X061/C01PJ4P0O8QX202DZ8P0;
02T^:@0[<Rh0:S4^024W9P0I7ah061hL01/Q700K8QX072@J01XP5P0G71000`0I7Pl02P0F60/04Q@9
010B200@4@T03Pl8010A200C50X05AD<01DF300D50T201LE1P0;01/I200L6`X0:B`I03To:011B300
B50d04aD>01=EST0BeLj04]G>`19EC/00P19E3/03018E3X0BEDk04UD>P17DSX0B54h04Q@>018D3L0
AThd04E==016CcD0ADhe04I>=@80AD`c0P16C3@02@17CCD0A4Xd04=9=014C3@0@d/e04A;=@14C3D0
A4/d04A:<`0204A:=@0;04A;=@16CS@0AD`d04E;=@14BCH0@TPg03m5>00l@SD0>D4b03Hn;P0b>bX0
0P0`>bH02P0a?B@0<ShS03<m8`0b?2<0<CXT03<k9@0c>B@0;SDQ02hd800_=R8202dc8080;cDR00/0
<CPT034h8`0`>2@0<3PT02lg8`0]=B00:c<N02/d7P0/=1h0:c8N02X_7@0202/^7P0;02`^800/;b00
:RlN02X_7`0Z<200:2lP02D/7@0R:QX08BTH028Y5`0U:aX00P0T:Q/01P0R:Q/08bXK028X6P0R:1T0
8BPG01hS41[ooooo00H0BUQL04iKH`1@G6/0D5]^051JL01@FW82055LL`0;05=MLP1CGW00EUm`05IO
L@1FGg80EF1d05EPM@1FGgL0F69i05MSN@1FHWP00P1EHGD02`1GHWL0Ef=g05QUN@1HI7X0FfMl05eY
O01MJGP0GV]i05i[N`1MJW/0GV]l0080HVin00H0HVeo06A]P01WL880J76306M`P`1XLH<206UbQ@04
06YdQ@1[MH<0KGN206miPP80KgZ400/0LG^7075lQ`1aOHT0LGf:079nRP1cOX`0MX2?07V1T@1kPi40
O8BB07b4T@0207f6S`0;07b7SP1nRI40P8VF082:V@20Ri`0PH^M082:W@22Rih0Q8fO08F>W`26T9d0
0P28TYX02`2;UIX0S9FI08^FV@2;UIP0SYRL08nJW02>V9X0T9^M096MWP2BWYh0TijM0080U9jM00`0
UYnO09FPW`2FXJ80UZ:R09JRX@2GXZ00V:>P09^VX@2KYj40VjJP09ZUW`2JYId209VUV`0;09RSV02I
Y9P0VJBG09RTUP2GXiH0V:BD09NVTP2;VXP0B4]<0415A00h?C/00P0]<2d02`0Z;BH0:blV02T[8`0/
;bD07b4J01XL500E60l04A<:00lB1`0?4@@03Q440080310500`02`h500X=1P0;3PT03@l<00h@3@0>
40/03a0<00hB2`0@5@/041D700hD1@0>4P@200`?0`0601`S3`0S:QH09R/H02L^6P0V;Qd09RhO0P0U
;Ql00`0R;1d07RHH01PO500201<J400:014H300@5P`03A8900`@1`0<40H02@h400P<0P082`002@`0
00P:00@01PP000D01PP100@6000310000@<00041000?ooooo`003Oooool01P1aQWd0LXIl06EgK`1N
KFD0Ef9M04aDDP80ADa:00/0>T4o02P/:@0S:2008RLM028V7@0T:1h092HL028R6@0O7QP08b0P02/Z
:`0202XZ:`0;02XZ;00a<S<0=CTj03Lk@@0i@4@0>45503@m@P0_>3/0;3Dh02/b=00/=3<00P0_>3@0
300]<c80:Rh`02@U;00J6B<04a0K010=5`0E4a/06adP01HJ700A4a<03@h<00hA3P804aHC00/06QhJ
024W8`0U;2L08bXT01lW800S;2<092hT020Z800N9Q/06B0D01LM400201TN400;01XN400I6P`051D9
01<C2P0D50/0410800l?200@3`T04A4:01<C300D50d00P0Q8aD02`0X;1X0:BlK02`d7P0d?2<0>T4U
0457:P16C340Be8h04eD>`1=ESl0BeE10080BEE000`0BEHn04QD>`19DcP0BeDh04eE>@1<DcT0CE8i
04Y>>019CCP0B4hi04I>>018D3L204Q?=@0;04Q?=016CS80A4/`04A:<@15BS80B4he04M==`18CSX0
Addj04I;>015BSP00P13BSP02`11BCH0@T`c04=<<P14C380A4Xb04=8<`12AcD0@4De03m4=00l@C40
=c`]0080<SXZ00`0<SdX034m900a?280<C`Q038k8@0d?B80=3/R038i800a>200<cXR03<i8`0b=b82
030f8P0;030e8P0`=R<0<3LU02lh9`0^>2H0;SPT02dg900]=b<0;3LR02/e8@0Z<Qh00P0/<Al02`0[
;Ad0;2lP02da8@0/<2<0;30T02/`900X;b<08b/P02<[7P0S:Q/092/K00809B`M00H08RPK01lW6@0Q
9aX08BPH020X5P0N9Q8Jooooo`0604YHG@1=FV<0Ce]Z051KK`1@FW80D5]d0P1AFg@02`1BGG80E5m`
05EPK`1FHFl0EF1_05APL@1EHG80EV9f05EPM`1EHWT0EF9g0080EF9e00P0EVAf05UVN@1JIW/0FfMm
05]XO@1MJW/0G6Yg05i/N080GVYi00L0Gf]j069`O01RL7`0HW5m06AaO@1XLh00J7>20080J7:400H0
J76506UdQP1YMHD0JGB306ehP`1`NH@2071iQP0;071kQ`1bOXT0LWj807=oR@1ePH`0MWn=07V1TP1k
PY@0OHBC07f6U01mQI<00P1mQY8207f7T@0907n9U@1oRIL0Oh^J086<W021S9d0PhbM08B=W@27Sil0
RI:O0080RI>O00/0RiBM08^EW02<UY/0RiJL08bHW@2=VIh0SIVM08jKW@2AWil0TInP09>QX00209BQ
W`0<09FRX02EXJ80Tj2R09FRX`2FY:80V:FR09VVXP2JYZ80VjNQ09^UX@2LYj<0W:RQ0P2KYYh02`2J
YI`0VZJJ09ZVV@2JYiP0Uj>F09RSU@2HY9@0UJBA05=GEP0i>Sh0>Cdm0080:bd]00/09BTT02HZ8P0S
9R008bHO020S700L7aL061/B01DH3`0F5`d05AL;01<E2@0200hB1`0<00`@1`0<40P030l:00hA3@0?
4`d041<=014C3@0B5Pl04QL?014F2`0@5@T04AD80P0A50D02`0D5`L07B0@020U4`0T:QL09blK02L_
7@0W;ah09BlN02@^7@0Q:a/072@F008061lB00/051X?010F2`0=40L030l600`@1P0=4@H02`l400/>
0`0;3`<02Pd200L90@0200D70@0600D60@072P<01`X200D7000310000P803oooool000gooooo00H0
OY:908>FSP25V980PiF@086BS`1jRHP207N7Q00;0720OP1IIfP0DEeM05EQG@1JIeh0FVIJ04Q?B00d
=cH0=SPk03<d>`0/;3<00P0R8BL02`0N72408R0S02PX:P0`<S@0=3Pi03Hm?@0f?d00<CTl02/c>00]
=CP0<CXk0080=Chn00`0=Slo03Q0@@0g>Sl0;c4j02DV<`0P82d0824[01hP9`0D5A`0418E00h>3`0=
3@`200l?3P0;014A3`0C51405a/G01XO6`0T;2D0:38Y02Td:@0V<BL08BXO01`S5`0J8A<00P0J8180
2`0J7a806A`?01HF300F5P`05AL<01<C2@0B4PT04Q8;01<C300@3`/040l>0080<3HZ00/0BUQ304eN
AP1;G480AU@j045<<@0nAb`0?dL]04=:<@16CCH0Ae0j04YC?P0204YE?P0<04YF?@1:E3/0BU<i04]C
>@1=E3X0D5Ln04mF?@1>Dc/0C50j04Y@>@1;DCX0BU4i0P19D3H02`19D3@0B4hd04M==017C3@0B4`c
04U==@18CCL0B4di04U>>`16C3P0A4Xe0080A4`f00/0A4df04===013CC<0A4hd04A==015C3@0AT`d
04E:=@15BC@0@DDb03e2<00203Y0;`0603Ho:`0d?RP0<c`T03<l8`0d?2<0=3`T0P0e?BD0100c?2@0
<c/U03<i9@0c>RH2034i9@0;02hf8`0]=B80;3DS02`f8`0]>2@0;SLT02dg9@0]>2H0;SPW02dg9`0]
=RL00P0[<R@02`0Z;R40:RlR02``8`0/;b<0:RhS02P^8`0V;2<09B/R02D[8@0T:Qh092/M008092XL
00H08RLJ024U6@0P9QP08BPH020W5`0O91DJooooo`0604]IH@1=Ff@0D5aZ055LKP1BG780DUed0P1A
Fg<02`1BGG<0DUeb05APL@1EHg40EF9a05ESLP1EI780EfEe05MSMP1HIGP0EVAe0080EVAb00/0EfEc
05UVM01KJ7L0G6Uk05iYO@1PJgh0H6al061]NP1PK7P0HVaj06A_O00206EbOP0<06McOP1WM7l0Ig>1
06McP`1XLh<0J7>406QbQ01ZM8@0JWB506]dQ@1^N8L0LW^90P1cNhT02`1dOHT0M7n;07=nR`1eP8/0
N8:<07R1S@1jPHl0O8>B07b4TP1mQI<0O8FC0080OHJE00/0OHNE07b7U01oR9H0OhVF082;V023SI`0
Q8jL08>=VP26T9`0R92N08^CXP0208bDY00;08bEX`2<UZ40S9NO08fHX@2<V9l0SYZO08nKWP2@W9h0
TYnO09>QX02EXZ400P2EXZ00302EXj40UZ>S09NRX`2GY:@0V:FS09RUX@2JYj40VZJP09^WX02KYZ00
W:NP09bXX080W:RN00D0WJRM09fXV`2LYiX0VjNI09VUUP0209VTUP0409NTT`1HFUX0?Ce203Tl?@80
;C0a00/0:2/Z02HZ:00T:2@07b<N01lT6`0O9QX07B<G01/P5@0M81<06Qd>01DH2`02010D2@0<00hB
200=4@P02`l700`@2P0?4Pd04AD@01<G4@0C5`l04AH<00lD2P0>4PL031430P0<40802`0<3@40720@
028W5P0U:QP09blI02P`6P0W<1X09S0K02H_7@0U;Qd082PH00806b4C00L05adB014F300>4PT03A47
00dB1`0>4`P03Q8700803Q4700X02`h500L90P0620401PP100D60@0620801`X300D70@0210000@80
3oooool000gooooo00H0PYJ<08JHT@2:ViP0RYZL08ZJWP28Uid208JGVP0;08JGV024UIP0Oi2D07nB
TP22Ui<0PYN>07V;PP1/Ng@0Kgig05aWI@0/;SP00P0K6B@02P0J6Al05A<I01HD6@0M7Ah09RPV02lc
<00d>CP0=Chl038k?00i@d8303m:B@0<03a6B00kA4P0>T5703PoAP0e?4D0<SU302he?`0T:C@06A`W
01<D7P0@41H04A4C0P0A4A402`0?3Pd03Pd<00l?300A50l08bXR02H^9P0Y<BL0:C8W02@/8`0Q:B00
7RHK0080728I00/06b0H01XO5`0H71@05a/B01DH3`0D5``05AH<01PI3`0G5Q005QH@01lP600202X[
8`0;04I>?P1AGdX0DfE<05=TBP1@HDD0BEPn04EC=`13CS<0@dhb04A?=017D3L00P1<E3/0301;Dc`0
Be<k04eF>`1=Ec`0BeDl04aG?P1>Ecd0CEHk04eF>@1=E3P0CE<h04aB>P80C54j00D0Be0k04]@?01:
D3`0B4hj04M=>00204M==@0304I<=@17CCL0Adde00<0Addd00/0ADdf04A==`13CCH0ADlg04E>=`14
BcH0@d/e04=:<`13BC40@DPa03m7<@0203m6<00<03a3;@0j@B`0=CdX03<j9`0b>RH0<c`Y03@m:P0b
?2X0<C`Y030k9`0`>bH0<C/W0P0a?2L02`0`?2H0;cXU02li9@0_>2@0;cTT02hf8`0]=RD0<SXZ034j
;00`>2h0<3T]0080;CDX00@0;38U02X`8`0Z<2<0:S0R0P0Y<2801@0X;R00:BhQ02X^8@0Y;2409RXN
008092TJ00H08B@G020T600P91T08bHJ02@W6`0P8aTJooooo`0604YFI01=FFP0D5a]055LKP1AFg40
Deed0P1CGGD0101EH7P0E5mg05=NM@1DHG<205ESLP0505IUL`1IIgH0FFIg05QUM`1HIGD00P1IIWD0
2`1JIgD0FVQf05]YM`1LJGX0GVYn061ZO`1PK7h0HFem069^N`1TKgd0IW5o0080IW5n00`0IW9o06Mb
P@1VLH80IW6206QcPP1YMH80JWF306]gQ01/MXH0KGJ706igR@1aNX/207=kR`0;07ElR`1dOH`0M7j=
07F1S@1gPX/0N8:;07V2S01jPhh0NhF@07^4T@1lQI<00P1mR9D00`1nR9D0OhNF0869V@0208:;VP06
08B=W024SY`0QHnK08NAW028TId0RY:N0P2;U:002`2;UJ40S9JQ08bHX@2=VJ40SIRQ08nJXP2@W:40
TIfO09>OW`2EXJ40UZ6R0080Uj:S00`0Uj>T09RTY02IYJ@0VZNU09ZWY02IYZ80VZNO09^XWP2KZIl0
W:RP09jYW`2NZYd209jZV`0409bYV@2KYiT0VZRI09VWV080VZNG00D0VZJF09ZWU@1QHf00>cTo03Tg
>P0202`[;@0;02HV9`0S92H09BXY01dQ7`0T:R409bdQ020V6P0M8QH071lC01PJ3@0E5`/00P0B50T0
300A4`T03Q0700`>1P0<3`P03A4:010D3P0A5Pl04AH=00hB200;3`H020`200L:0@801`T000/02PX1
01hR400T:AH09bdH02L^600X<1P0:34I02H`6@0W<A/09c0L02<[6@0201lU5@0;01XO4@0B5``041@:
00lD2@0>4`P03A8600dA1P0<40H03A0600/=10092`<00P072@801P051`0010H100@600031@000P<0
004300oooooo000=ooooo`06082DSP26VY@0RY^J08^LWP2<WJ40S9bS0P2:VYl02`2:VY`0RY^L08^M
W@2:Wih0Rj6M08ZRV@2;XiH0RZ6B08bQTP1nT8@0?T=800806QTT00/071/Q01LE6P0D4AD04a4C01LF
5P0M7ad08RDR02`c;P0b>cH0>dDo041<A00203m:A00<03i7AP0mADL0>d=803Q0B00h@4L0>T=<03Y3
B`0g@4P0<3I002<W<@0M82P05ALM0P0B4QL02`0@3a<03`d@00l>3P0D5Q@09B/T028Y8P0P9b009B/R
02L^8P0T:b008RPN00807bDM00/07R@N01lT7`0O9Ah07B<K01/P5`0J7aD06AhC01XM4`0I6A4061PB
02<S6`0202<S6P0;03m3=01FHT`0D5m903i;>P13DSh0BEY104eO@@1:G3/0AeLe04MD<`15D3400P17
D3@204U@>00:04QA>019ECX0B5Hj04YG>`1=FSd0BeLk04YE>P1<ECX0C5@j04aB>`80Be0k00/0Be0n
04]A?`1:D3h0B4lo04M??P16CcX0ATlg04I>=P17CcH0ATld04M=<P0204M<=00;04I;=@16BcP0A4/h
04A<>P13BcT0@d`j049;=`11BC<0@TP`0459<012Bc000P13BC003012Ac00?dD`03a3<00i?bl0=3/[
034j:P0_>BX0;STZ02lj:@0_>bH0<3`T030l8`80<SdS00/0<S`T038k9@0b>B@0<CLT030g8`0`=R<0
;cHT02dc8P0/=2D0<3PZ02hh:@0202hg:00;02df900[<R40:2lN02L^7P0Y<Al0:C8O02/b7`0Z;ad0
;BlO02`_8@0X;Al00P0U:A`01P0Q91L0828G020R6P0S9Qd08RDM020Q71[ooooo00H0BUEW04eHJ`1A
G700DUeb059LM01BGG@205AOM@0;05EPM`1DH7H0EF1g05IRMP1GI7@0EVEe05MUMP1HIWH0FFIg05UW
M`1KJ7P00P1KJGP02`1KJ7P0G6Uj05eZO01MJW`0Gf]m069]OP1SKWl0Hff006I_P@1WLH00JG>10080
J7>100`0J7:206QbP`1YLh@0JgF506]eQP1ZMHD0JgN506iiQP1]MhL0KWV906mjR`1`NXd2079kS00;
07EnS@1dOhh0MX6@07J2T@1fPY00N8BA07R5T@1iQI00NXFA07Z7TP1lRI800P1mRi802`1oS9D0PXfG
08:<V@24SIX0PhbJ08B=V`24SI`0QHnM08RAW`2:U:40RiBP0080RYBN00/0RiJP08jGXP2>V:40SIVP
08nJX@2AVj<0TYfS09>OXP2FXJ80V:>S09ZTY@0209RRY@0<09VSY@2JYJH0W:RU09^XY02MZZD0W:VT
09^XX@2JYj00W:RR09nYX`2NZ:00WZVO0P2NZid00`2MZYX0WJ^J09^YV@0209VWV00609ZXV02IYYH0
W:ZH07N1MP0j>3`0=c@g0P0/:R`02`0V92H08b<U02lc<@0U:2P09BLT02DX8`0N7a/08RDN02<V7@0N
8AH06A/?008051D:00@04Q<900lA200=3`L030l70`0=4PP01@0>4`T03a8900dA200930<01PP10080
1PL000P02``301dR400U:aL0:BlL02/a7@0[<Q`0:c<M02Pa70809RlJ00h092`I020V5`0P9QL0728D
01TN4P0D6@h04AH;010E2P0@5@T04AD900hB1`0=40H030l500`=10802`h400@020X300L:0P062040
10H00P03100?ooooo`003Oooool01P1oUHd0QifF08ZOW02;Wil0SJ2R08fOXP80S9nO00/0SJ2M08bN
V`2<Wi`0SJ6L08bRV`2<Y9X0SJFH092WV02AZ9D0SjFB06alL@0202hb=@0;028T9P0P820061LH01DC
500D4Q8051<A01PH5@0L7QX07R<N02P_:00`>3000P0g?CH0300k@C`0?D=203i5A`0nATT0?dM:0417
C00oAT`0?TI=03m8CP0lADX0=cm202``=08092DZ00/07alU01XH800D4QX07QhQ02<W9P0J7Qh05a/H
01/Q6P0R:Ad08RPL020U6@0201lU6`0;024W7P0Q:1h082LL024X6`0P:1/082PJ01lU5`0L7a@06ATB
01HE4`0H61D00P0I6AH02`15D3h0GVmE04AA?`0]=BX0;3@X02/d9@0nBc80C5lm051R?P1AHSl0C5/k
0080Ae<h00`0Ae0h04QA>`17DCd0ADlj04=@>P14DSX0BULm04]G?P1:ESh0BeDo04]C>`1:DCX204M?
>@0;04Q@>`19DSd0BE4m04QA?P17Cch0ADhm04I@?016D3X0Ae4h04I?=@16CS@00P17CcD204I==@09
04I==`15CCT0A4/i04E=>P13BcT0@DTe045:<`11BC40@d/a0080@dXa00`0@TP_0457<011B380?TDa
03U0;P0d?B/0<3TY030i:P0_>2L0<3XU030k8P0`>R02030i7`0;034h8@0`>280;cHR02lg8P0^=R40
<3PS02lg8`0]=B80:cDQ02hf8`0^=R@00P0_=bH02`0_=bD0;C<P02db800Z<1d09bhL02D^700U;Qd0
:2hM02X_7P0[<1l0:BhO00809BXM00H082DI01hS5`0P91L08RHK020T6`0O8Q`Jooooo`0604]HJP1?
Ffh0DUid05=OM01CGWD0DEec0P1AGG402`1CH780E61b05IRM01HIGD0EfAf05MUN01FHgH0EfEf05QW
M`1HIgP0FfQj0080FFMh00/0FVQh05aYNP1LJG`0GV]m061]O@1QKG`0I6mn06E`P01VL840IW6006Ia
O`0206QbP@0506UcQ01YLX@0JG>506YdQP1ZMHH00P1[MHL01@1/MXT0KWV:06miRP1`NHd0LW^?0080
Lgb>00/0MGj>07AoS`1cOhl0MH2A07J2T`1hQ9<0N8FC07R5TP1jQY80O8VC07b9TP0207b:TP80P8fD
00P0P8^F08>=V@23SIX0PhfM08J@W`27T9h0R9:P08VDX0<0RYFO00@0S9NQ08fHX@2?V:00T9VP0P2B
W:801@2CW:80UIjT09JPX`2GXJ80V::S0080V:>S0P2JYJ@02P2MZ:H0W:RT09bXY02MZJH0W:RU09^W
Y@2MZJH0WZVU09jZX`2NZZ4209n[X00309jZWP2NZi`0W:VJ00<0VjRJ00D0VJVG09VYV025U8@0?Cm0
038b=@0202d^;P0;02PW9`0R8b80:R`Z02X];00T92H08B<T01lP8@11BSd0<3H[01lQ600L7a<00P0F
60`0300C50P04A<800lB200<40D03A4500dB1`0=40P03A4900lC2P0<40P020/300H80@801@L000D0
2`h501dT4P0S:QH09blI02Tb700202Xd700402Pa6`0T;AL08RXE01lV5080728C00/07B8C01`Q500K
7a8061dA01@H3@0B5P/04aD:014D200@50P03a8800d@1@0200X>0P0600X>0`0;3PD02`l500P:0P06
1P401@D13oooool000gooooo00@0Q9^A08VPV02:XY`0Rj:N0P2;X9h208^PW00;08ZOVP2;WiT0SJ2J
08fQV@2?XiX0T:FK092VV`2BZ9/0TZNI09BYV@28W8`00P1MJf<02`0h?cd0<3@b020Q8`0L6ah06ALI
01HE5@0G5Q@061TC01HG4P0I6QD07AlI00809BLQ00`0=3H_03/n>00oA3l0@TQ404=:B@15CTh0A4i@
045;CP0oBT`0?dY:0417B@10ATL203e1A00;03Tl@00a<CT0:2La02TZ<00T9BX051@K010A5`0B5AD0
51PD01DI5@0I7QL00P0L8AT02`0N91X07RDI01dT5`0P9QL08BTH02<Z6@0R9QP07b8G01hN600L71X0
7R0O00807B4P00/092XV02hg;@0U;2@09RXR02<W7`0L7aL06b0E02`f9016ES/0DfM905MZC00205AU
BP0<04iL@`19ECl0@Tdk03a6=P0jASH0?DTh049>>`16Dcl0B5E104YG@P19ED00B5Dl0P19ECX02`1<
ESX0BU@g04UB=`1:DSP0B4lk04I>?017D3d0Ae4j04MC>P15CcD0A4lc0080ATld00/0AThc04E>=015
C3@0Adde04I<=P15BcL0AD`h04A<=`14CCH0@T/d045:<`02045;<P0<049:<010B2h0@4P_03m7<00n
AS40?DDa03Y1;`0e?2d0<cTZ038i9`0`=bH0<CTV0P0c>bD0200b>R@0<3PT02/d8@0[=240:c<P02hf
8@0]=B40;SDR0P0]=2403P0^=B80;cDS02le8`0_=R<0<3LR02lf8@0]=1l0:c8O02T`7`0W;b00:30P
02T`800Y<B009RhM0P0U;1`01P0Q:1X07bDH024W5`0Q9QH08BDG01lS61[ooooo00H0C5UW04mKK@1B
Gg<0DUic059OM@1BGW82059NL@0;055NK`1BGfl0E65`05ERL@1EI7<0EFAf05ITMP1FIWL0EFEi05QW
NP1HIGX00P1IIWX02`1KJGT0G6Uj05aYO01OJgh0Gf]k069^O01TL7d0IG5n06A_OP1VLGl0J7:10080
J7>000`0JWF106]eP`1ZM8<0JWB506UdQ01ZMHD0JgJ606agR01^N8X0KWR906igR@1`NH`2079lS@05
079mS`1cOhl0M82@07J2T@1gPi800P1gPi<00`1iQY<0NhND07j9U00307j9U00;086;UP20RiH0Oh^H
086;VP22Ri/0Q8fM08N?W`29T9h0R92M08RAW`29TYl00P2<UJ802`2<UZ40SINR08jGX@2@Uj80TIVR
09>KX@2CVj00U9bR09NNY@2FWj@0V:6S00<0Uj:R00/0VJBT09bVYP2MYjL0WJRV09fXY`2NZJP0W:RW
09bWYP2NZJD0WZVT09nYX`020:2[XP0;09nZX02NZYh0WJVL09bWV`2LZ9`0VjVL09NVU`2GZ9L0RYV8
03m1@@0_<3400P0^;bl02`0Z:bX09RPU02LY9@0Z;BT08R@S01dQ800b>C80>T@g02/b9@0M81D06QdA
008051H:00`04Q<7018D200@5@P03A8500`A1P0<40L02a0800`@200<40L02Pd500H90@082@4200H8
000;00X>100L8a407bLD02@^6@0W<A`0:38K02Tb6P0Y<AX09RhG024W400N8`l00P0K7`l02`0M8180
82<E01hQ500M81<071lC01XL400F5``04a<9018C2@0F6@`05AX:00804AH600H04aP801@J2`0B5`T0
3A8600X<10051P4?ooooo`003Oooool01P21V8l0QinE08RPV028X9T0QijH08VPV080R9jG00/0R9bD
08ZOUP2>XYT0T:>K096UW@2BYYd0TZFK09>TV`2EYI`0UZNM09>UV`0208VKT@0907V:P01GHUl0>3a0
02h`=@0T92X08R4S01dL6P0K6QH061PE00805QDB0P0E4a40300M6QD09B<M02l`:P0i?CH0@4I0049;
A`15Cd`0@4];03e8B@0nBDX0@4U;04=9C080A4U<00/0@dQ<04=6B`11@d/0?3m802`^>@0N7RX051HP
00l@600>3QD03PlC010B4P0201DI5@0;01XO6@0N8Q/07B<I01hT600Q:1T092XK02@X6`0T9Qd09RPR
02PY:@0X:R`00P0Q9BL02`0I72005aTL01LI700M7ad07R0K01/L6@0H6aL05a/G024X7P0b?Bd0?T`g
0080CEi400`0EfU=059RBP0f@C40:S<V02H_8`0X<B@0;3DX03M3<@0nBcD0AE8k04MD?@18E3d204UE
>`0;04]I>P1:ESL0BE@e04UC=@17D3L0B54i04Q@>@15CcH0AU0h04I@=`16D3D00P15Cc@02`14CS<0
ADld04E><`16C340A4P`04A:<P17C3H0AT`f04M>=@16CSD0ADde0080A4/d00`0@d/c03m8<00nARl0
?DD_03m7<@10B380?TH`03Y2;P0i@2h0=S`Z03@i:@0c>2P203@j:@0;03<j:@0b>bT0;CLV02Xc8`0[
<R00:c8N02`b7@0]<ah0;3<N02/c7P0]=1l00P0`>2402`0`=b00;cLP02he800]=B80:c@S02P_8P0U
;2008b`O02L`800V;ah08b/J008092`K00H08b/J01dT5@0M91D082DD024U500P8a@Jooooo`0604eH
IP1?FVd0DUmd05=PMP1DHGH0EF9e0P1DHG8205=QK`0905ASK`1EHg40EF=d05ETMP1FIGP0EfIi05MV
N01IIgP0FVMh0080FVQi00/0G6Yi05eZN@1NJg`0H6am065]N`1RKW`0HVmk06=_O01SKgd0IG5o06Ma
PP0206UdP`0<06]fPP1ZMX<0JWB306]eQ01ZMH@0IgB306YgQP1[N8P0KGV906mjRP1`NX/0KgV;0P1a
O8l02`1cOY40LgnA07F1T@1ePY40Mh>B07R5T`1hQ9<0NHBC07b6U01nQiD0OhVF0080PHZH00/0PHZI
082:V@1oRYX0P8VK086:W024S9`0QhjM08R?W@29TId0Ri:N08^CWP0208fEW`0;08jFX02?Uj40T9RR
09:JXP2AVJ40U9bP09BNX02FWj80Uj2S09NQX`2HXJ@00P2HXj<0302HY:D0W:NX09bVY`2LYZL0WJNW
09jYZ02NZJL0WJRU09fXYP2NZJ<0WjRS09nWXP80XJVQ00/0XJZP0:2ZX@2OZ9h0WZRL09fYW02LZi/0
UjRG09NZU`2>Wh`0ADY603Lk=`0203Lk=@0;030c;`0Z;2L09bXT02da:@0R91l07AhJ03Y2<`0lAC<0
=3`X028V5@0K70d00P0E50T02`0A4@L04A@900hB1`0=4@D0314500/A1`0;3`H02`h600X>1@082P<0
1`L100<020P000/01`P101TM300R:AH09RhL02Pa7P0X<A`0:c@L02/c6`0W;QT092TD028V4P0201hQ
400;01lR4`0S9QL09BPJ02@Y6@0U:aX08bHG01lP500I6@l05QL=020T5@0U:AP00P0Q9AD01P0Q9Q80
7RDA01dS400G7@`03a<600H90@oooooo000=ooooo`0608>HT026WID0QijG08JOV@26WIL0QifE0P29
WYH02`2:WYL0S:2I08fQW02=XI`0Sj>K096TW02CYI`0U:BM09NWW`2FYYl0UJFM0080U:FK00/0TjFJ
08JHSP1_OGL0D5UH03Di?00a=380:B/U024R7@0L7AT06AXF01LE500201HB4@0<01HA3`0G4A006aLD
02PT800e=S00>3hi03i6@P11C4L0@Te:045<B`12CD`0A4a<0P14BdX02`14BDT0ADU;04M8C`15AU40
@D=>03PkA`0[;cT061XV01@D7`0A4AT03a0E00804A8E00/05QTI01/O7@0M8Qh07R@M024W7P0S:Al0
92PN02@U7P0_<R/0=SXe03Hj>P0202T/<00;01lO9@0H61l05ADJ01LH6`0J71/06AdI01TO6@0J81X0
5Q`F01TP5P0N9aP00P0T;a`0300nCC@0B5Tn02hi9P0R:Q/072<F01PO4`0F70l092`L038k9`0nAc00
AE0h04QB?080B58m00/0BEDl04YF>`1:EST0BE@h04MC=P19DcH0BU4f04M>=016CCD0Adlg04E>=`02
04=<=P0;049<=P13CCL0@d`e049;<@10B2h0@DP^0498;`13B2h0ADXa04I;<`16BcD00P16BSP01P14
BCP0@DLf03i5=00lA3<0?4@`03a5;P<0?DD^00<0?D8/03/n:`0h>RX00P0f>2X02@0d>2`0<SP[02de
9`0/=2@0:c8Q02Xb7P0Z<a`0;3DM02Xd6P0202Pa60<0:c@K00X0;CDO02dd8@0/<b@0:c<X02H]9@0R
:B408RTP02<Z800S:b0092dN0P0T;A`01P0S:aP082PE024Y500S:18082@@01hQ3Q[ooooo00H0CEQW
04mJKP1CGW@0E61g05ARM`1EHWD205=PLP0;05=QK`1CHFh0E6=_05ETLP1DHW<0EVAe05UWN01JJ7X0
FFMh05UWMP1KJGH00P1LJGD02`1MJWL0GVYg05eZN01NJWT0H6ai065^N@1QKWX0Hfmk06EaO01WLWh0
J7>10080J7:300H0JGB506YeQP1YMHH0JWF606UfQ`1XMXP206YhR@0406ejRP1^NXT0KgZ:071jR`80
L7^>00/0LWf?07=oT01dP8l0MX:A07R3U01iQI@0NHNE07V4U01lQiH0OXZG07n:U`02082:V@0;086<
V`20Ri`0Oh^L082;W021Ri`0Q8bM08N>W`27Sil0R92N08V@W@2<Til00P2=UIh02`2?Uil0T9RQ096I
XP2BVZ80TIVQ09BLY02EWZD0U9nU09FPY@2FXZ@0VJBV0080V:>V00`0VJBW09ZVY`2LYjH0WJRW09jW
Z02OZJT0WZZX09fXY@2NZJD0WjVT0:2ZY02OZJ<20:2YX`0;0:6[XP2QZZ<0WjRQ09nYX02NZId0W:ZK
09VZVP2GZ9L0U:JA059HDP0e=cL00P0g>SH02`0^;b`092DR01hO700a=B/0:RhS020R6@0R9AX0@ddd
04MC=@0N80l07Ah?008061L<00<051@;01<D2P0A4`T00P0>4PD01@0<4@H02`d500X=1@0:30@020T2
008020H00P081`402`061P0061`?02<Y5`0X;a`0:C8N02Tc7@0Z<QX0:C8I02D^5P0R:QD08BTD0080
7R<C00/08BDE02DZ6@0X;Ad0:S0O02/b7`0/<Ql0:BdM02DY6P0Q9AT0:30P030h900202hd8@0602T`
6`0X;AP09R/F024W500F6P`01`P13oooool000gooooo00H0PiR@08JMU@27WYL0QYnI08JMU`27WID2
08VNUP0;08ZNU`2<X9T0SJ6L08fQW02?Xi/0TJBL09>UW02DY9d0UjNO09JVW`2EYId00P2DYI/02`2C
YIX0QYR>06mmM`1@FEP0=CTl034d<P0Y:bD08B8M01`M6@0I6QH05aDD00805Q8A00`05Q4?01LA400K
5a@0:2@P03Df<00h?ST0?TI2045<A`12CDX0@Da;049=C014C4`204A;BP0;04A9B@15BD/0AdQ?04E6
D@11@dh0>3]702/_>@0H6RH051@O014A6@0?41D00P0A4QD02`0F6AT06alM01dR7P0N91d08BLN02<Y
7`0T:1h092DN02lb:`0f>SD0=SXj0080:B``00/07alU01PH7`0E5AX05aPK01XL6`0I7AT06AlI01XP
6P0F71H06B0F01hW600202@_700<03i==018FCh0;STV028Z6`0L8aH061lC01HL3`0T;1`0<S/W03i7
<015D3P0B58l0P18DSd02`19EC`0BUHk04YF>@19E3P0Ae<f04UC=P1:DCH0Adhd04I==@17CcL0ADhg
0080@d`f00/0@T`f04===`13C3D0@T/a0418;P11B2h0@TP_04=8;P15BS40AT/c04I;=@0204I:>006
04A9>011AcH0?TDd03a4<`0lA300?4D^0`0mABh00`0m@R`0>ch[03Pj:P0203Hh:P0903@h;00b>2/0
;CDW02`d900[<R40:S8N02Xc700/=Ad0:S@J0080:34H0`0[=1/02P0]=Al0;C@Q02`c900[<bP09RdU
028Y8@0R:B008bXP02<[800T;Ah202@]700602<[600P:1D08BTD02<X4P0P91007R4>6_ooool01P1=
F6L0CeY^05=NM01DH7L0E69g05ERM@80Df1b00/0Df5_05=QKP1DHfl0EFAb05ARL`1FI7D0FFMh05YX
NP1IIgP0FFMf05]YMP0205aYM@0;05eZM`1NJWL0GFYh05iZN@1PK7T0HFii065^NP1SKg/0IG5l06Mb
OP1XLh400P1XLX<01P1YM8D0JWF606UeQP1ZMHH0JGJ706QfR080JWR900@0KGZ:06ijR@1_NXX0L7Z;
0P1`Nhh02`1bOHl0Lgn@07B0S`1fPY40N8>D07V5U01iQiD0NHBD07b7UP1nRYL0OhZG0080P8ZI00/0
PHbK082;W01oRi`0P8^L086;W024S9d0QhjO08N?W`28T9h0RI2M08bCW`0208fEWP0;08nGW`2@V:40
TIVR09:JXP2AVJ40U9bT09FNY@2DWjD0UJ2U09JRY02IY:H00P2HXjH0302IY:L0VZJW09bWYP2MZ:L0
WZNX09nYZ@2NZZP0WJRU09jYY@2OZJ@0X:ZT09nYX`80X:VS00/0XJ^R0:6ZX`2OZ:40WjVP09jYW@2L
ZY/0VJZJ09NXU`2DYY40DUQB03Dg=`0203Lj=P0;02h_;00T9B807QlL034e:`0Z;R<0828I028U6P13
CC@0Ae<e01hP3`0M7Pl00P0H5``00`0D50/04a@:014C2@0200hB1@0500`A1P0;3@D02Pd500X<1008
2@800P081P0200P70@0;00H6000H70l08bTG02P_700Y<Qh0:C<M02Xb6P0Y<QT09BhF028Z5@0Q:A@0
0P0N8a<02`0Q9AD09BXI02P]7@0Z<1l0:c8O02`b7`0Y;Ad09BTJ024U6@0X<200<3PT0080;S@Q00H0
:C0K02P]600V:aH08BLD01HJ3007204?ooooo`003Oooool01P21Th/0QibC08ZPV@29X9/0R9jK08JK
VP80QYbJ00T0RIjM08bPWP2>X9l0Sj:P08nRWP2AXih0U:FO09FTWP2FYIh00P2FYYl209NXWP0;09FW
WP2FZYl0TZJK08:CR01XMVh0F6=J04YDB00/<R/09R`U01dP700I6AP00P0G5AD0300H4a<05a8A01PB
4P0J5A@081dJ02HV8`0/;bd0=3Xf03Y1?@10BD@0Ae1;04QAC080B51;00/0ATa:04I9BP14AD`0A4E=
04=6C`14BU@0@TQA03Y0AP0X;3@08RD[01/N900201<D6`0;018D700K7b@082HX020W9P0R:BH08RXT
024X8`0Q9B00:B`V03Pm=P0nA3h00P0k@Cd02`0`=3<0:Rd]01lP8`0L7B006ahP01TL700G6aT05APF
010E400D6A406R4D008061l?00`07B@E02H_7@0S:a/06B0C01PN4@0I81<06AlC01dT5`0Y<B00=ClX
03a7;P10BS82049<=@0804QB>@1:ESX0BeHi04]F>@19DcL0C5Dg04]C=P19CcD204Q?=P0>04I>=`15
CcP0ADlh04E?>@16D3T0ATli04M>=`14C3@0?TD_03a2:`0m@RX0?T<[0456;`12Ac4204A8=00<04E;
=`14BSL0@4Lg03m6=`0mACD0>d<`03]3;`0k@S00>d8_03i5;`0l@B`0>Sh/0P0j?Rh02`0h>bh0<cT]
038h;00c>B/0<3LV02de8P0^=B40;cPR02lg7`0]=Ql0:c<N0080:c8O00/0:S4N02Xa7`0[<R40:c@T
02/d9P0Y<RH09blT02D]8P0T;2008b/M02H^7@0202D^700602D^6@0T;AL09bhE02H/4`0S:1008BD?
6_ooool01P1;F6D0CUY[059NLP1CH7@0E61e05AQM080Dema00/0DUm_059RK`1BHW40EVAd05IUM`1G
IGT0FFMk05YXNP1JIgX0FfQi05]WMP0205aXM@0;05iXM`1PJWT0Gfak05i/N`1OKG/0HFmk065`N`1S
L7`0Ig9o06UcP@1XLh400P1WLX@01P1XLXD0J7>606QcQ`1YMHP0JGJ:06YgS080KGV=00@0KWZ>071l
S@1`O8`0L7b<0P1aOHd02P1aOXh0Lgn?07B0S`1fPI00NH:A07Z3TP1jQY<0NXFD07b6UP1nR9L307n;
V00;082:V`21Ri`0PHbK08:=V`24SI`0QHjN08B>W`25Sj00Qi6Q08VBX@2<UJ800P2>UZ402`2?UZ40
TIRS09:JX`2CVj80Ti^S09BMY@2EWJH0U9jV09FPZ02GXjP0UjBX0080UjBY00/0Uj>Z09VUZ02KYZP0
WJRX09nZZ@2QZj/0X:ZY0:2ZZ02QZJD0X:VT0:2ZYP030:2ZY`0;0:6[Y@2QZj@0WjZR09nZX@2NZih0
WZ^K09^ZV@2IZIL0VJ^G061YHP0e=cX00P0c=SP02`0X:2T0824N01PF5@0Y;B<0<CHX02db8`0R91P0
>D0[059P@00P8QD07AhB00806AP@00`051D=01@D300B4`X04187010C1P0>4PL03Q4700d?1@0:2`<0
2PX300`:0`0=30<200`;100;00P90P0G6`d08bPE02T_6P0[<A`0:S4K02L_600U;aH08BXA01`U400I
8@h00P0J8A002`0P9aH09B`K02X_7`0/<b40;SHR034i900^=R40;3@O02he8@0a>RH0>40/0080=SdX
00H0;SDO02X_6P0X;1P09b/H01dQ4@0@4@H?ooooo`003Oooool01P23UH/0RinF08bSW@28Wi`0QIfM
08JMW`80QYbN00/0QifO08ZOW`2<X:00Sj:Q096TX`2BYJ<0U:JR09FXX02EZ9l0UZNN09RXX@0209RY
XP0;09RZX`2GZj80UJZP09FZW`2AYYX0RIf@07Z=OP1OKf80BE9:03@g=@0/;Bh00P0U9BL0300N6ad0
7AXK01lN7P0O7Qd07ahL01dM6P0N7Q`08B8P02PZ9`0f?3H0@4Lo04M>AP80C5==00/0CE=A04Y>D@17
BU40A4QB0416D015CUD0A4iC04E@D@13CD/0?dM503To@@0202`_=`0;020Q;@0W:cD09R`d01hU:P0L
8b@06b@Q01`S7`0L8Q`06adJ024S800^<Bh00P0g?CP203]3?00903Hm=`0^=34092XY01dQ8P0G71`0
4QDE00hA3`0A5A005Q/C00805adB00D06QlD024X6`0U;1h08BPK01`T5P0201`S5`0502D]7`0a>bT0
=d8/03]6;P0nB2d00P10BB`02`15CC40B4lb04Q?<P1:DC@0C58g04aC>@1;DSP0BE4h04QB>018DSL0
BE@g0080B5<g00/0Ae0g04YA>P1;DC`0C50l04Y>>`16BcT0@dPg0457<`0oAS00@4L`03i7;`0203e6
;`0<03m8<00oB340?dLa03m7<`0oAS<0>d8a03a4<`0nASD0>D8`03Y3;`0i@Rl0=d0^0P0i@Bl02`0i
@300=cl^03M0;P0i@Bd0=clZ03@l9`0f?BT0=C`Y03<i9P0b>BL0<3PX0080;CDX00/0:C8U02Pa900X
<B@0:34R02Pb8P0Z=2<0:C<S02Tb8@0Z<b00:C0N02T^700202T_700602P^6`0X;AT0:2dG02L/5P0V
:QH09BPF6_ooool01P1=FVD0D5eZ059PKP1DHG40EF1d05IQM@80EF5c00/0E65a05ITLP1GIW@0F6Eg
05QVN@1HIWX0FVMi05YXNP1LJGX0FfQi05]WN00205eXN00;05mXN`1QJW`0HF]m065[O@1QKGl0Hfmo
069`OP1ULH00Ig6106QcPP1WLh800P1WM8@0301WLhD0J7:706UbR@1YM8X0JGB;06afS@1^Mhh0KWR>
071jS`1`NXd0L7^<075lS080LWj>00H0M7n?07F1T01fPY00Mh>@07V2S`1kQHl207j7T@0307j7T`1n
QiD0PHZG0080PXZI00D0Ph^K08B<VP26Si/0QXjL08J?W@0308J@W`0308RBXP29Tj@0S9FV0080SYJV
00/0SiJU092HX`2AVJ80TYZQ09>LXP2DWJ<0UIfT09FNY@2FWjL0Uj:Y09RUZ00209RTY`0609ZVZ@2M
ZJX0WJRW09jZY`2OZjP0X:^X0P2PZZD0102QZZ<0XJ^S0:2ZX`2PZZD20:6[YP0;0::/Y@2PZj<0WZZQ
09jZW`2NZih0WZbL09b[VP2JZYP0VZ^H06UcK00g>3h00P0`<SD02`0R92@07R0M01LH4`0O8QL09bXM
02hd8`0U:A/0Ae0i08fVN@0d>bX04Q8<008061TB00`04a<<014@2@0@40L04Q88014C1`0A50L051H9
01@F200A4`P04A8801HH2`0I7@h201HI2`03018D1P0O8a409b`G0080:S0I00H09R/E028X4`0O:140
6b8=01PO300G7@/201hT4P0602L^6`0Y<200:c8Q02dd8P0`=b@0<CTT0P0_=R400`0b>B<0=3TU03Hm
:00203@k9`0602le800Z<1`09b/I02T]6@0W:aP071l?3oooool000gooooo00H0QibB08fSV`2<Y:00
S:>S08ZRYP2:XJD208VOXP0;08NMW`29WYl0Rj6Q08nSXP2AY:80TZFR09:VX@2DYj00U:NN09NYW`2I
ZZ800P2JZZD02`2I[:L0V:bV09N[Y@2G[:@0UjfU09N]Y02F[:00TjRI07Z:P01/NG00IgA[0080AD]=
00`0<S@l03Lk?`0m@D<0<C<f02`^;`0Y:bX09bTU02HX8P0W:B<0:bhW030b;@0h>S@20453?@0;04Y<
B01=Cdl0CU9E04]CEP15CU80@Ta>045<C013CT/0BEA@04YCDP1:DE@00P17CU@02`0nA4`0>T5902L]
>00L8R`051/Q01<J700D6QP04aLE014@4P0C4A@06QLI0080;B`Y00/0>cli03a2>`0nACd0?4Dm03Hn
>@0]=3@09B`]01/Q8@0A5A@03a<@010C4002018F400<01hU6P0U;1l0:C0Q02L^7`0S;1/08b/K020W
5`0R:1T09BTJ02X_7@0]<Ql0=3TS0P0h?RD0200nA2X0ADX_04M<<P17CC80BDhc04Y@=P1:DCP0BE4h
0P17D3L03P18DcL0B58g04QB=`17D3H0B4li04Y@?@1<DT00Be4n04Q>?014BcP0@TTe045:<`11Bc<0
?dXc0P0mB3<01@0mB340?4H_03a6;P0mARl0?DD_0080>D8^00D0>d<`03Q1;`0f@2d0=3h/03Do;@02
03I0;@0;03Do;00c?R/0=Cl/03Ho:`0e?bX0=3dZ03Dn:`0g@2d0=cl/03Hl;00c>bd00P0`>B`02`0_
>B`0;CHZ02Xc9`0X<B<09BhO02H_7P0X<Ah0:S@O02Xd7P0Y<Q`0:C0I0080:BhI0P0V:aT0100V:aP0
92PF02HX600V:AXJooooo`0604YHHP1>G6L0DUm^05APL`1FHGL0EV5h0P1EH7H02`1DH7@0EV9c05QU
M01IIGD0FFIf05YWNP1KJ7`0FfUl05aZN`1NJWP0GFUh0080GFQj00/0GfUn061YOP1RJh00HFZ0069]
P`1SKX<0I6n306A`PP1ULH40Ig>106IdP`0206IdQ00606MdQP1WLhL0JGB906]eR`1[MH`0K7F<0P1^
Mh`0101_N8d0KgZ=071kS01aNh/2075lS00;07AnSP1eP940MH:A07F0T01gPY00NHBA07Z4T@1lQY80
OHNE07n9U`20RYP00P22RiX01@23RiX0Q8fK08F>V`24SI/0Q8jL0080Q92P00@0Q92O08NCX@2:U:<0
SIJV0P2=UJH02`2?UjH0TIVV096JY@2?VZ<0TIfT09:NY02DWj@0U9nU09FNYP2EX:H0UZ:V0080V:BV
00@0VZJX09^WZ@2LZ:P0WZZW0P2N[:L01P2N[:H0WjbT0:6]Y02P[:<0WjbR0:2[X`80XjbU00/0Y:fU
0:6/Y02O[:<0Wj^Q09n/X02O[9l0WZ^N09bZW02M[9/0MX5g03Ph?@0203<f=@0;02L[:00P91h07AlG
01`L4P0M7a<0=clZ03m9<P1<FCh0UK6104AA>P0@4@X00P0K7Q80300E5@X04A84018B100C4`D04Q<6
01@F2@0E5`X06A/<01TK3P0H6@h08RPF02@/60808BTE00/082HB02L]6@0Z<A`0:2lJ02@Z500N90h0
6b4=01dT3`0N9A407bD@028W4`0202L/6@0;02/_7@0/<B00;38R02lf9@0b>2H0<CTU030g8`0`=R<0
<SPT03@i9P0h?RT00P0f?BT01P0a=bD0;C<R02T_7P0W;a`0:2hK02@X5`oooooo000=ooooo`0608NN
UP2<Xi`0Rj:O08bSXP2;XJ@0RZ2T0P29WZ@02`29WZ<0RYnQ08bQXP2=Xj80SjBR092VX@2BZ:00U:VP
09:VW`2EZ:80V:ZT0080VJZV0P2H[:T02@2I[JX0V:bZ09R/Z@2J[ZX0VZnY09Z_Y@2J[Z80RY^A07F2
O00206E_KP0<05UPI01bO7L0N8Al06I^K01PJVH0Ef9I0458@00f>S80=3D^034`:`0`;B`0=34_0P0e
<c402`0j>CP0?clo04M:BP1<De80C5MD04YFD019EDd0BEA=04aFDP1=EEH0C59H0080C55K00/0C5AM
04UDF`0oBU80=D1802@^=@0P:2/05a/N01@D600B3aD05a4E01XD5@0203Dc:`0;03Xi<P0c<Rl0<C0`
038d<P0i?SX0?DE003]6@00b?SP0624M014G4`0?4`l00P0>40/0300L8aL08BLI02<Y6@0W;AT0:2lK
02P`7@0Z<1`09bdJ028V5P0Q8aD07AlA01hP4P809BLH00/0=S/W04UB=`19DSL0BU@i04YC=`19DCH0
ATde04I<=@16CCH0ATdg04I@>00204A>=`0;04E@=`17DC/0Ae4m04QC?@18DS`0AU0i04A>=`13CCD0
@T`d045<=012CSD00P10C3@0300oBc80?DX`03a8;`0kARd0?DH]03e5;P0k@bd0>T<_03Y2<00h@C00
=d0^03Q2;`80>4<_00/0=T8]03A0:P0c?bT0=3lY03@n:00c?BT0=ClZ03Ho:@0g?bX0=Sd[03Dk:`02
03<j:`06038k;00_>2X0;CHY02`e9P0X<R80:34P0P0Z=2000`0Y<Qh0:S4M02X`700202/a700602T^
6P0V;1L092/E02DZ5P0U:QL09R/J6_ooool01P1<F6D0Cea[059OL@1DGgH0E5mg05EOM`80E5if00/0
EEmf05MRMP1HI7L0F6Ag05UUN01JIWX0G6Ul05eYO@1MJW`0GV]k05aYN@0205aXNP0;05iYOP1OJGh0
H6Yo069/P@1SKX80Hfj306=_Q01SKh<0Hg6206AaP@1ULh800P1WMHD0301WMHP0IW>606MdQ`1YMHT0
KGN:06ihRP1]Mh/0KWN=06mhSP1`NXd0LGb=079mS080LWj;00/0M82=07J1T01fPY80MH6A07J2S`1h
Q900NHFC07Z5U@1lQiP0OHRH07n:V@0207n:VP0;086;V`23SY`0PhfL08>>W022SYd0PXnN08>@W`24
TJ40QY>S08VEY02;UJD00P2=UZD02`2?V:D0SiVT08nIX`2=VJ<0T9bT096NY02CWj@0U:2U09BPYP2E
XJL0UZ6X0080Uj>Z00`0VjJ]09bV[@2LZ:T0WJRX09j[Z@2N[:T0WJ^W09j[Y`2Q[:D0XJbS0:6/XP2R
[J<20:B^Y00;0:B^X`2S[J@0XJbV0:2[Y@2OZj<0WjZR0:2ZX02NZIh0WZbN07f7OP0m?4800P0h>CX0
2`0X:BP08R@O01hP600L7A407b0C04]G?01CH4<0DUm308FOLP16DSP05aT<00807Qh@00`06AP801DE
100G5`H0824@02LY6P0K71806adC02<W6@0S:QX082LF02H^6P0Y<A/202Pa6P0;02Xb7@0[=1d0:S<N
02P`6`0R:A@072<>01hV400S;1D09RlG02Xb6P0/<a`00P0]<b002`0]<R00;C8Q02le9P0b>2X0<cTY
03Dl:@0c>BL0<3HT038g9@0h?R/0?TD`0080>T8/00H0=C`Y02le9P0Z<2809bdN02H/6`0U:AX?oooo
o`003Oooool01P24VY<0RJ2I08^QW@29WYh0QibO08NMX0<0RInR00X0RInP08^QX02=Y:@0SjJV096Y
YP2BZZD0U:^S09FYY02GZZP0UZVX0P2FZZP02`2HZZT0VJ^Y09V/Z@2J[J/0W:n/09j`Z`2O/JX0W[2W
09nbYP29VY00HVaZ0080HVYZ00`0Lgei09:PU@2FYIT0V:RL09ZZW@2EYiL0Lh1g05QQG01CFeD0CE9<
059FC@15A3h203Tg=00;03Dd<P0f=3@0?3Xk0493A015BTT0B51;04eGC01AG4l0DUeC051HE@1<DeH0
0P1:D5P02`1?EEh0D5QQ04aFH01:EEh0A51E03e8B`0b>S`0:B``028P900N61`09B0P0080@D0i00/0
;bXZ02DQ900Q72407ATN02<S900]<Bl0=3hg03Q4>@0[>2`05QlG01<I3`0200dB200<010E2`0C60`0
51P;01PM3@0N91@08BPH02<Y6@0O9QL0724F02H[7`0U:Qh08BDK0P0O8AP02`0_=2H0EF=605]XB`1K
J4/0Ef=9055JA019DCh0AT`j04=:=`13BSH0@4Le0080?dLd00/0@4Tf049;>015Cc/0AU4k04QB>`16
D3/0A4hh049<=@10C3@0?d`c045?=002041?<`0<045=<@10C340?dX`03m9;P0oAbl0@4La03e3<00l
@S<0>T8d03Q1<P0h@S00>D@a0P0f@Rd02`0f@B`0=T8[03I2:@0g@BL0=clW03Dm9`0d>bH0<STU03@k
9`0d>bP0<c/Y0080<S`Y00/0<S`X02lh9P0]=RD0;3DU02Tc8P0Y<R009c0N02P`7P0Z<1h0:RdM02X]
6`0202X^700602P/6`0U:QL08RHF02DY6@0U:QT09BXJ6_ooool01P1>FFT0D5a]05=PL`1CGgD0E5me
059MM080E5ie00/0EF1f05IRM`1HIGP0EfAh05UUN@1KIW/0G6Ql05aYO@1NJWl0GV]n05aYO00205]W
O00805eXO@1NJGh0H6]o065/P01SKh40I6n106=`PP1TLX@206EcP`0<06EbPP1VLh<0IW>306QdQ@1W
MHD0IgB406QcQP1/MhT0KgZ;06miS01_NHh0L7Z=0P1aNhd3079nS@0;07B0S`1fPY00N8BB07R3TP1h
Phl0NHFA07Z7U@1lQiH0OXRI07j9V`20RY/00`21Ri/02P22SI/0PXfL08>>W`23T9l0Pi2N08FAW`27
Tj<0R9BU08ZDY@2<UZH2092HZ00;092IYP2AVZH0TIZV09:MYP2AWZ<0TZ2Q09>PX`2DX:<0UJ6T09NS
Y`2HXjT00P2IXjX0302KYJd0WZN_09jX[02OZZX0X:^Z0:2[Z@2OZZP0X:^X0:6/Y@2QZj<0XZbS0:>/
X`80XZbS00/0XZbR0:>]XP2R[:@0XZbV0:6ZY02QZZ80XJ^Q09nZW`2P[J00PXV1040nAP0203Ph?00;
02d];@0Q8R407QlK01XJ4`0Z;Al0FFM805=P@P1;ES/0HgA@04mI>P12Ab/00P0b<Q`0300X9Q808Ah=
03Hh901DG4<0CeQ201lP600P8QT0:c0S02/b8P0Z<R00:S4N02`c7P80;3@O00/0;CHP02/e7P0Z<Qd0
;CHO02de7@0Y<1T0:C4J02Xc700[<a`0;SHN02he800202hd8P0;02db8@0^=280<3HU03<i:00d>bT0
=chZ03Hl:00f>bL0=C/V03i7<010BS800P0h@R/01P0c?BP0;3DS02H]7P0T:Q`092PK028U60oooooo
000=ooooo`0608FGU02:WYd0SJ2S08^NY029W:<0RIfR0P2:Wj402`2;X:00S:2O08jQX@2?XZH0Sj>X
096VZP2AZ:T0TJNV09BXY`2H[:/0Uj^/0080Uj^[00/0VJ^[09b]Z`2L[:X0WZj]0:2`[`2P/Jh0X;2/
0:2aZ`2Q/j`0UJFO07AoO`0206igM`0<08>?RP2M[:40WZbR0:>`Y`2V]:X0YkFZ0:6]YP2DWiX0Qi2=
08:<QP2=VhX0I6aO0P1;D4H02`15B400@40k03ll>P0m>SX0?3Xl03hn?@13Ad40BU1704mHC@1@FU40
CeQC0080CUEF00/0DeML05=GG@1>DU/0CE=M04aFG@1<F5`0BeQH04IBD00m@d80<C4d03@b<`020410
>`0;02LS9P0P7B806aPO01DB6@0C4QH05AHH01XN700P9Ql08RXP01TS6@0E71400P0F7@l0300D6Pd0
4aP<01<H300D5`/05AP=01LK400H71405AT?010C3@0F6a@07R<J028W70808bLL00/0:c4S03i6=01E
GdP0G6Q@069`F01PL5P0F6EA04eEA011ASH0=SX/03<f:00203Dh:@0;03Pk;00l@300?dDc04=;=`16
CSX0A4hl049>?@0oBcP0?ddf03m><`0oCS000P10CRl03011CBh0@4`^0459;P12BRl0@DLa0415<`0m
A3@0?4<e03]4=`0g@S@0=D0_03E3;@80=D8[00/0=D8Z03I2:00h@bT0>D8Y03Ln:00g?2X0=3TY030g
9`0_=bH0<3PW02hi:00202dh9P0;02hj9@0_>R<0;SPQ02hg7`0[=1d0:c<L02Xa6`0Z<1`0:blM02//
700];Qd00P0];Ad01P0[:ah0:2TK02LY6`0W:Qd09R/M02@X7A[ooooo00H0CUQZ051LL01BGg@0DUic
05=NM01CGGD205ANM`0;05IQN@1EHGL0Ef=h05QTN@1HIGT0FFEj05]WO01LJ7/0FVMj05aYN`1MJg`0
0P1MJW`02P1MJWd0GVYn05iZO`1MJWh0HFj006=_P01TL800I7:106EbP@1VLh<306MdP`0<06QcP`1W
MH@0JGF606]fR01]MhT0KWR906mhRP1`NH/0L7Z:071kR`1aO8d0LWf>0P1cOY002`1cOY40MX6D07N2
T`1iQI80N8B@07Z6T@1kQiD0OHNE07n8U`20RYX0PHZL00<0Ph^N00L0PX^M08>=WP23SIl0Q92Q08BA
X026Tj40RIFS0080RiFV00h0SYNX092GZ02@UjP0TYVX09:JY`2BVZD0TibT09BOX`2DXJ40UJ:Q09NS
XP2IY:D0V::U09VSZ080VjFZ00D0W:J[09fV[@2NZ:d0Wj^[0:6[Z@020::[Z@050::[Z02Q[:L0X:^U
0:2[Y@2QZj@00P2S[:H02`2R[:D0XjbT0::/Y02S[:@0XJZQ09nZX02OZZ40WJZO09fZV`2=V8/0AdQ<
0080>3Tm00/0;S0a02<U900L7A/05QHC03Hm;01FIDP0E69604eJ?`13CCD0BeDj06=`C00205eTA00<
05EH?00m>BX0PXi^08RIN@1;DT<0;BlV02LX7`0^<RD0;c@U02le900/<b<0:c<S0P0/=B@02`0_>BD0
;cXU02hh8`0`>R40<3TP02dd7@0/<Q/0;C@M02dd700/<a`0;C@N0080;C<P0P0]<R402@0^=2<0<CPV
03<i:00d>bP0=SdY03Hm:00f?2L0@DTb03i7<00203Dn:006038l9P0Z<b0092`K02@Y6`0U:1d08R@K
3oooool000gooooo00H0QYNH08^LX02<WZL0RifX08ZLY`2;WJH208bNYP0;08jPY02>XJ<0Sj6T092R
YP2@XjL0SjBW092VY`2?YZL0TZJW09JZ[02EZjh00P2FZZ`02`2H[:/0Vjj[09^]ZP2M[:/0Wjj^0:2`
[`2R/[00X[>]0:Bd[@2Q/J/0VZVT0080UJ:M00`0UjFM0:6aYP2S/JT0YkB]0:Re[`2Y]:l0ZkF`0:Vb
[P2Y/jd0Yk6Y0:FcY@2EY94208JBO@0;06Q_H@1QIUT0GV1F05AEC@1<CDL0@T8l03i0=`0n?cL0@TDl
04M<@`1<DD/00P1?EE802`1CFET0EEYL059IG01@Ee/0C5EH04YFE`1;FET0CeaI05=NF@1AEe@0CE1A
0080ADM900/09B8^020O;00J6RH05A<N018A6P0@4QL03a<C00lE400?5Pl04AT@018J400201LP400<
01`T4P0K8Q406Ad?01PK3P0G6Ph061/?01DE2`0A4@P03Pd700l>2P0C4`l05QH@0P0F5a802`0M7aT0
:B`U03Lm<P18DT@0DV1?05UZEP1PLe/0GFiE04]F@@0g>RX0:2LK00809R<I00/0:BDL02d[8@0b<2H0
>3X/03m5<`11BSL0@D`i03e:=@0lBS40?D`]041>:`02041=:`0<041;:P0nB2L0?TDW03m5:`10AC00
?D<b03]3<`0i@3<0=d0c03I0<P0e@300=40[0P0d@BP02`0d@2D0>48V03U19`0i@2P0>CdX03Pj:00g
>b`0=3X]038i;00_>2`0;3HZ0080:C<V00/0:SDT02`g8P0/>200;STN02`h700/=a`0;3HK02/c6`0]
<Q`0;C0N02h_7`0202d^7P0602d/800Z:R00:B/R02P[8`0T:2008B@M6_ooool01P1<EfP0D5a^05=N
L`1BGG@0E5if05IMM`80EUih00/0Ef1i05QRN01HI7L0F6Eg05UUMP1IIWL0G6Uj05eZN@1LJWP0GF]i
05aZN@0205aYNP0;05i[O@1NJgh0GV]o05m/P@1PK840HFj2069^P@1TL880IW6306MaP`1WLXD00P1X
M8H0301WLhD0J7F706UfRP1[MhX0KGR:06egRP1^N8X0L7Z:071jR`1`NXd0LWb@079mT@80MH2C00/0
MWnB07R1T`1iPi80NHF@07V4SP1jQI00NhFD07j7U`1nR9T0PH^M086:W00208:;W@0;08>=WP24SIh0
PhfN08F>W`25Sj00QI6Q08JDX`27U:<0RIFS08^GYP2?V:L00P2@VJH02`2BVZL0U9^W09BMYP2EWjH0
U9nU09BPX@2EXZ40Uj:R09VTY@2IXjH0VZBX0080W:JZ00@0WJN/09fW[@2PZ:h0X:V/0P2QZj`01P2Q
ZjX0XJbZ0:6/ZP2O[:P0Wj^V0:6]Y`80XZbX00/0XZ^X0:>[Z@2R[:L0XJbU0:2/X`2O[:40WZZP09fZ
WP2N[9/0Tj6?04i?D00203Xj?@0;02h`<@0O82405aTH014B4@0c>bd0Df1705=QB01>GD@0AU<l05MU
BP1ZNe/00P1`OUd0302<Vg<0G5m:0;C:WP28V7/0@TLl03a1=00g>R`0=cTZ03Hj:@0e?2X0=3`Z030i
9`80;CLV00/0;STW02dh9P0^>2@0<C/U030j8`0^=R00;38K02dd700[<Q/0:RlK02dc7`0302hc8@0:
02db8P0^=BD0<3LW03<l:P0e?R/0=Sh[03Ho:P0f?RP0?TL^03a5;@80=CdW00H0<CXU02Tc7`0T;1/0
8bTI02@X6`0T9Q`?ooooo`003Oooool01P23UiL0QYZN08ZNY@2<WZT0RibX08ZKY@80Ri^S00/0S9fS
08jOY02@XJH0SZ2U08nSY@2AY:H0TJFW092UY`2AYJH0Uj^[09V][P0209Z][@0;09V/[@2I[Jd0VZb[
09b][02N[Zd0Wjn^0:6a[`2P/Jd0X[>/0:Bd[02S/ZX00P2R/:P0302P[jL0Xk:Y0:FbZ`2W]:h0ZKF`
0:bf/P2^^KD0[KNc0:fh/P2[]Zh0ZKJZ0:^iY`80Z;JQ00/0WjZG09ZUT`2CWH`0RI:307MoK`1NI5@0
BTln03m2=00i>c00=cP`03Lh<P0203/m>P0;04I9B01>E5<0DUYJ059LF`1@FeX0C5QG04YFE@1=F5P0
E5iK05UPG@1JGeh00P1HG6002`18C5@0?45<02T]>P0N8Rd061/V01<G7P0@5AP02a8@00T>2P0>50/0
620A00807RLC00`08bdG02D^600S:QD082DC01dQ4@0J7Pd05QP8018A1@0A3PD04Pl901HC3@0I5Q42
01LD4`0;01DB5@0F4aL071XK02HY9`0e?CH0AeA505EVCP16ESl0AUDk04EA=`0k@2d00P0m@3002`0g
=Bd0;b/Y02hZ9P0a<2P0=SX^03To<P0lAC<0>dD`03]6;00jA2P0?4LW0080?4HX00`0>T8W03Y09P0j
@2L0>ClY03Po:`0g?Rd0=cl`03Ho<@0d?C00<c`]03Dm:`0g?RT203Q0:00;03Q19`0j@RP0>d8Z03Y1
:P0j@2/0>Ch[03Hk:P0e>b/0=3`/030h;00/=2L00P0[=2H02`0Z<RD0:S<S02/d8`0[=R80;3LQ02dh
8@0[=Al0:S@O02`d7`0[<Ah0:BdL0080:BdM00H0:2`N02L[7`0W:b00:2`Q02H[7`0S9a/Jooooo`06
04aII`1@G6d0Deme05=PM`1EHGP0EV1h0P1FH7H02`1GH7D0FFAe05YWMP1HIWD0FFMf05]XM`1LJgP0
GFaj05a/NP1LK7T0FfYh0080G6Yi00/0Gfen061/O`1OJh00H6b1061/PP1QKHD0HFf406A`Q01ULH@0
IW6406IbQP0206IcQ`80J7F600X0JGF706agR`1^N8d0KWR=06iiS01`NX`0LG^>075kT01cO9<0M7jD
0P1fPI@02`1gPI<0N8>B07Z5T`1jQI40NhJA07^5TP1nQiL0OXNJ07f8V`1nRY`0PH^K0080PX^L00/0
PhbN08F>X026Sj40QhnQ08J?XP25Sj<0QI6S08JCY028UJ@0RIJT08jIY`02096JYP0;09:KY02CW:D0
U9nX09FPZ@2EX:P0U:6V09BQY02EXJ@0V:>V09^UZ@2LYZ`00P2MYjd0302OZZh0X:Z^0::Y[P2QZJ`0
XZZ/0::[Z`2Q[:/0XJfZ0:6]Z@2R[ZP0XJfX0:6^Z080XJfX00/0XJbX0::[Y`2S[JH0XZfT0:>^X`2R
[J00XJbO09n]W`2O[Yd0V:NC055DD`0203De>00;02l_<00U9RD07b4P01PG600_<b/0CUU6059NBP1@
FdL0@d`k05=OB@1YN5`00P1YMU/0302Q^900QYEj0;gH[@1bOfL0BE0n0498=@0g>RT0=3DU03<e9@0e
>BL0=3`X02lg9080;3HT00H0;CLV02dg9@0_>2@0<C/V038l9`0_>2<202dc800302T_700W;A/0:S0O
0080;C@Q00/0;cHS02he900a>2P0<cXY03Do:P0f@2/0=3lZ03I0:P0e@2T0?TT]03M09@02038k8@06
02df7P0Y<Q`09bhJ02L]6@0V:aT09bXL3oooool000gooooo00H0OYFG08BKW@29Wj<0RYjV08RLY@29
Vj<208^KX@0;08^LX`2<WJ<0SInU08jPYP2@XZD0TJ>U096TY`2BYZX0TJJX09FXZ@2FZJX00P2I[:`0
2`2I[:h0VZb_09V/[P2L[Zl0WZnb0:2`]02O[k<0X:na0:6a/02T/k00Y;:_0080YK>^0P2U/jl02P2V
/jh0YkF^0:Vg/@2Z][<0[;Rd0:bi]02/^K<0ZkV`0:ZiZ`2/_:X20:flZP0;0:fkZ@2]^ZT0[[ZY0:Zf
Y`2KYYT0TZ2=06M`H@10A3`0=CPb02lc;00[;BL00P0Z:RD02`0];2P0?3dh04I:A01>EE00DUYG05=M
FP1AG5X0D5]J05ANG01GHE`0F5mJ0080FV1M00/0Ff5P05QPH01:DE@0?TI:034i?P0O9B/05A/O00hD
500:3`/03Q@;01TQ4@0201lY500<02Td7@0^>B40:cDL028Z500M8@h061X9014C100?4@<04105018A
200J6@l07QdB0P0N71<02`0V91/0:2HM028O6`0V9B@0<C<^03Tn=P16Ccl0<3HY01`Q5`0R:A/0:c@S
0080BULm00@0H6a@05iWD01FG4T0Ad/m0P0o@cL01@10ACL0?dDe03a2<@0l@R`0>d<X0080>d@X00`0
>D4W03Ln9P0g?bH0=C`V03@k9@0d>bH0=C`Y03Hl;00e>bd0<SPY03<i:00f>RT203Pl;00;03Lm;@0f
?B`0=cl/03Hn;@0f?R`0=ShZ03Dn9`0d?BL0=3`V030h900]=2<00P0/<b<02`0[<B80:c8S02Xa900Y
<BD0:C4V02Tc9P0Z=2@0:c@R02Xc800Y<Ah0:BlM0080:2lL00H0:2hI02H/600W;1T0:BhL02P/6@0W
:aPJooooo`0604aHI`1@GFd0Df5d05=PM`1EHGT0E61g0P1EH7D02`1FHGL0F6Ei05UWNP1HIgT0FVQj
05YXM`1KJGL0Ff]g05]ZNP1KJgX0FfYj0080FfUi00X0GFYk05m/O@1OK7l0Gf]o05iYP01QK8@0HFb5
06=`Q`1TLHH0IW>60`1ULhD0301WM8<0IgF206UeP`1[MXL0KWN906ehR@1^Nh`0Kgb=071lSP1bO8l0
LgfA07EoU080MX6B00/0MX:A07R4TP1iQI40NHJA07^8T@1kR9<0OHRG07n9VP1oRI/0P8ZM08:;W@02
08>;WP0;08>;X026SZ80QXnR08J?XP26TJ<0QI2R08FBXP26UJ<0R9NS08VHXP2<VJ<00P2@VjD02`2A
W:<0TifT09BNY`2EWjT0UZ6Y09JRY`2EXZH0UJ:W09JSZ02IYZ/0VjN]0080W:R^00@0WJZ^09nZ[@2N
Z:X0WZVY0P2QZZX01P2R[:X0Y:j[0:B_Z`2T[Z/0Xjj[0::]Z@80XJfY00/0XZjX0:>]YP2U[ZD0Y:nS
0:>]XP2S[Ih0XjjO0:6/W`2O[Ih0VjZK05UMGP0202l/=`0;034_=00X9b/08B4S01`K7@0^;b/0Dea<
05QQD@17C480<34[03`o<`1WLeT00P1NJ5<0302M/Hd0[<:M0:[2V`1II4h0>3h/03@h9@0U9AL09BDH
02X/7`0^<R<0;C8S02X_8080:2hP00/0:S8R02`e8P0`>B<0<S`T038k9@0_=b<0;CDR02/c800X<1h0
9blN02Pa7`0202/d800;02df8P0^=R<0<CPU03Dl:@0f?BX0=Sd[03Dm:P0d?2P0<cdX03]5;@0d?bL0
0P0`>R801P0/=A`0:38J02H^600U;1H09BXF02HZ6@oooooo000=ooooo`06082FU`25W9l0RZ2U08ZO
Z028WJH0QibS0P2:Vj<02`2<W:H0SIjW08bMYP2?X:P0TJ>Z096SZ@2AXj/0TjF[09:UZP2CY:X0U:B[
0080UJJ/00/0UjR^09ZZ/02KZk80WZfd0:2`]P2R/KL0XJne0:6^]02R[k@0Xk6d0:Jb/`020:Nd/`80
Z;Bc00X0Z;Ba0:Vd/02Z][80[KRf0:fj]`2]^KH0[;Vd0:bk/@2/^jd0[kf/0P2`_Zd02`2`_Jd0/;f^
0;2m[P2b_K00[k^_0:^j[02BX9@0HVaV04M?BP0j@3P0<CH]0080;BlT00/0:RXO02/Y8@0a;bX0>c/g
03m1?`17C4T0D5UC05EPF@1JIUh0FVEL05IOEP0205INEP0;05EME`1FGUT0EV5L05EPG@1>FeT0@e1=
02`d=00C5aP04ADB01<H3`0J8A<00P0N9QD0300S;1L09c0K02Pa6`0U:aH07R8@01HG2P0@3`L03Pd8
00h?200@40/08bHL01lP608071`E00/0EV5606elFP0d>2d0?D@k0458?P0b>340:RhY028S7P0H6A<0
4Q4=00h>2002020S6@0;06j0H@2;XGd0Q9Qh06ekI`1EH5@0EEmD051HC01<DdD0Adho04=:=`0oB300
0P0nB2d0300nB2`0?4DZ03]4:P0h@2H0=ShV03Dk9P0e>RH0=c/Y03Hk:P0b=bP0<CHW038f:080<cHZ
00/0<CLZ034h:`0b>Rd0<3T[02hg:00_>BH0;c/T02lj8P0_>B40;CLN02`e7`0202`d800;02`c800Z
<B00:C4Q02P`8`0W<2D0:38V02Td900Y<b40:C@P02Td7P0X<ad00P0X<QX01P0Y<AP0:2lF02L]5P0W
;1P09R/H02L[6A[ooooo00H0CU]W055NK01DHG40E61d05EPMP1EGgL205=NM@0;05IQN@1HIG/0FFIl
05YWO01JJ7X0FFMf05]XMP1LJWP0FfUj05aYO01NJgd00P1MJG`02P1LJG`0GFYn05m/P01NJgl0GV^0
05m[PP1PK880HVn306A`Q@1WLhD306McQ00<06MdP`1YMH@0JGB206]eP`1]MhL0KGR806ijS01_OHh0
LGf?075mS@1aOHl0M7nB0P1fPY802`1gPi40N8F@07R5S`1iQhl0NhRA07j8U01nR9D0OhRF07n9V@20
RI`0PHVM0080PX^O00/0PhbP08J?XP27T:80QY2R08JBXP25TJ40QI>O08NFX028Uj40RYRR08^IX`02
08jJY@0308nJY@2BVjH0U9fX0080U9nX00D0UJ6Y09JRZ`2FXj`0V:F/09VV[00309^X[@0709bY[02M
ZZd0WJRZ09jZZ@2PZjP0XJ^W0:B]Z@020:F^ZP030:F^[02T[Z`0Xjj[0080Xjn/00/0XJjX0:6]Y02S
[Z<0XjnS0:B^X`2R[J40XjfQ0:6]W`2O[Yd0WJfL05eRH@02030]>00;02d/<`0S8BP081dQ020O800e
>380GfYG0761J013Acl0<2l]030`;@1NJE<00P1JHdl0301gQFL0SZ9l086EL@1>FT80=Sd[02X_7P0O
8QD07AlE02<U6`0V:Ah0:2`O02L[7@809BTM00/09b`N02Xa7`0]=B00;cLO02`b7@0Y;ah0:c8P02Xc
800W<1h09blN02H`7@0202Pb7P0;02/f800]>240<3PP038i8P0c>BD0=3/W03Dl9`0a>2@0<3LT03Y2
:`0d?BP00P0]=R801P0Z<Qh0:30K02H]6@0S:QL092TG02H[6Poooooo000=ooooo`0607jAU@27W9l0
RinU08VLYP26VjD0QibT0P29Vj802P2<WZ@0SInW08fNYP2?X:L0TJ6Y09>SZ`2BXj/0TZB[09:SZP2C
Xj/309FSZ`0;09BT[02FYJd0VJN^09^Y/02N[;<0X:nd0:6_/`2S[[80Xk2c0:B_/`2T/;<00P2U/K40
302V/K00Yk>`0:Zf/P2/]kH0ZkJd0:Zf]02/^;H0ZkNd0:bj/`2[^k40[Kb_0:jm[P80/;f^00/0/;f/
0;:n[02b_J`0/kf]0;>n[P2b_Zl0[kf^0:2^W`2:V8P0HVaQ0455?P0203]0=00:03Pk;P0h>Bd0=3@]
03<a;`0a;Rh0;bh^03Df<`11ACh0CUI:05END@<0FF=E00/0EV1C059LD@1GHeH0EV=G055OEP1AHEL0
AeI<02D]:@0M91d06AhG01PM4`0201LL400<01TN3`0J7`l07B0B020T5P0O8aD05QL>01<B3@0A40d0
3`h=00l=3@0I6AL05aHD0P0N7ah02`1oTgL0Y/:N09B_T01OL5l0?DDk02/_9`0K71L05QHB01DD3`0C
4@l04A0>00803P`<00/0Ae5109B]R029Wh00R9b10721K`1RLF<0HG1O06=aG@1RKed0GV]I05e[E@02
05QVCP0<051MA@1<ET00B54l04A;>011ASD0?D8a03Xn;P0h?2d0=cX[03<e:P0b=BX0<C@X0P0b=RT0
2`0`=BP0;S<W02hd9`0/=2H0:C8T02Xd900Z=2<0:S<S02/e8`0/=b40;3HO00<0:C8L00@0:C4M02T`
7P0W<1l0:34Q0P0X<R80100X<Al0:34M02P`6P0W;aX202L^6@0602P^6@0V;1P092TF02@Z6@0T:Q`0
8RTK6_ooool01P1>FfP0DEi]05APL@1DGg80E5md05IQM`80EEmh00/0Ef9l05UUO`1IIWd0FFIk05YX
NP1LJGT0G6Yh05e[N@1LJGX0G6Um05eZOP0205eYO@0;05aYO01MJWd0GVao05eZOP1MJgh0GV]o065^
P@1SKh80IW2506M`QP1YLXH00P1ZMHH0201[MHL0K7J806afQ`1/MXH0KGN806mjR`1_NXd0L7^>0`1b
OXl03P1dPI00MH:A07F2T@1fPi40MhBA07R4T01jQi00NhR@07f9T@1mR980OhRD07n8U@20RIP0OhZJ
0P21Ri`02`24SId0Q8jO08F?X026T:00Qi6Q08NBX@26U:00QiFP08ZGX`2>VjH0Si^X0080T9^[00/0
T9^Z09>N[02DWZ/0U9nY09BPZ02FXZX0UZB[09JSZ`2HYJ/0VJNZ09VWZ`0209bZ[00<09bZZ`2NZZ/0
Wj^[09j[Z@2O[:L0XJfU0:B^Z02U[ZP0Y:jW0:F_Z@2U[ZT0Y:j[0P2T[Z`02`2S[Z/0XjjW0:>^Y02T
[j@0XZnR0:6^XP2Q[Z40X:jP09j^W@2M[Y/0Ifm[0080?T5600/0<34g02@T:@0R828071XK03Lk<`1F
HTl0HG1J05EPC`10AC/0=cXc05IQCP0205aXDP0<05AOB@1HID/0EfI:04mL@@0g?bd0:C0Q024V6P0M
8AD08B@G02@X6P0W;1`09BXK0P0Q91H02`0R9AL092XJ02L]700U;1/082@H02H]800X<240:C4P02Pb
7`0X<A`0:34K0080:C8K00D0;3HN02hg7@0_=a`0;cHL02lf7P02038j8`0402dc800a>2@0>D4Z03@l
9P80<3LS00H0;3<P02/b7P0Z<1h09bdL02D[6P0W;Qh?ooooo`003Oooool01P1fR8d0Q9RJ08NKXP25
V:80PYFR08BGXP80Q9RQ00X0RIbT08fNY`2>WjP0SIjW08jOY`2@XJT0Sj6Y096SZ@2AXjP0TjFZ0`2G
Yj`02`2EYZd0UJN/09RX[@2HYjd0VZR]09^Z[@2N[J`0XJn/0:Ba[`2V/[80Y[6c0080Y[:a00`0Y[>^
0:Rc[P2Y/jl0ZkJd0:Rd/P2W/k<0ZKJe0:Vg/`2Y^;80Z[R`0:fk/02^_Jl20:nm[P0;0:nkZ`2`_:/0
/[j[0;:mZ`2c_J/0];n]0;>o[`2b_Zh0/Kj/0:FaW`22RG`00P1bN6`02`1aMf/0H6EK04M9A012@Sh0
=S<b030[:P0Z9R<09R@O034b:@0o@cH0C5920080E5]900/0Ef5>04YBA01<ETH0B5=2049??P10CSh0
AUE3049??@0Z=2D082HI01lT5@0201XM3`0<01LI300G60`06QX@01hO5P0N7aP061PB018B300A4P/0
4Q4=018@3P0F5A<06aXJ0P0K6a`02`0k@C/0GFeM09:^SP1mUGP0>T@e02P/7`0N7Q@05aD=010=200?
2`T040/<00803P/=00/09BTU07bDN02>YhX0PiYo082EN`1SLEl0F6AC05UTD`1SKUh0OHih08>GO@02
08>FO00<086BMP1ePfP0I6eG065WEP1NI5T0FF1F051HCP16Cd<0@4Lk03a2>00i?CD0=c/c0P0e>S00
2`0d>Bd0<SPZ038i:@0_>2T0;SHY02Xa9`0/<RP0:c8V02T`8`0Z<R00;3<M0080:S4J00P0;38J02`b
6`0[<Ad0:2lM02D]6`0T;1d08b/L02<[6`8092XI00T09BXI02H[6P0V:aX09RTJ02<W6@0Q9QP08BTK
024X7@0P:1d06_ooool0101=FfL0DUi^05=OM01CGWH205AOM`80EF1j00/0Ef9m05YUP01JIH00FVIl
05aYO01MJW/0G6Uk05eZN`1LJGT0GFYm05aXOP0205e[OP0;05e/OP1LK7`0GFek05i^NP1OKgd0HG21
06=bPP1SLH<0I76406IaQ@1WLHD00P1YLhH0301[MXL0JgF706egR@1/MhP0KWR:06mjR`1_NXd0L7^>
079mSP1cOhl0Lh2>07B2S@80MX>@00/0MX>A07N4TP1hQ980NXRC07^9T`1mRi80OHVD07n9U@21RiD0
PXbH08:=V@0208:<V`0;08>=V`25SY/0QI2L08JAW028Til0R9>N08RDWP2:UZ40S9RT08jIY`2?VJP0
0P2AVZ/02`2AVj/0TIf[09>NZ`2BWZP0U:2Y09BQZ02EXjP0UZBX09RUZ@2KZ:X0W:V/0080WJV/00/0
WZV]0:2Z[@2QZZl0XJ^]0:6[ZP2T[ZT0YJnY0:F^Z@2U[ZL0YJjV0:F_Z0040:J`ZP0:0:F_Y`2T[j<0
Y;2S0:B`X@2R[il0XJfN0:2^W`2M[9l0WJjM07V5O080ADY=00/0=SXm02`^;P0W:2D08R4M034b:P17
C3l0BU95051LB`14CSl0>D4c05MVC@02061_E00<04eI@@1;Ecl0B5<k04E>=`0e>bX0;C8T02DX7@0O
8QP08RDI02@Y700R:1X07bDF0P0M8A<02`0P9AH08bTI02DZ700U:ad06A`D02@X700W;Ah09blN02Tb
7P0[=1h0;3@M0080;CDM00/0;SDN02lf7`0`=b00;SDO030g7`0`=R40;S@P02/`7P0`=R40>40X03<j
8@0202lg7`0602/c7`0Z<Al0:30N02T^7@0W;Ah0:c4S3oooool000gooooo00H0O8n?08:EU@26VYd0
QiZR08BFXP23UJ8208>EX@0;08RIX`2;VjH0S9fX08bMY`2;WJH0S:2X08bPY`2=XJH0Sj:U096SY`2B
YJP00P2CYZP02`2DYjL0UJNW09JXZ@2FYjX0VZV/09^ZZ`2M[:/0X:n/0::_[02T/:d0Y[:^0080Yk>_
00`0Z;B_0:Rd[P2W/Zh0Z;B`0:Nd/P2V/[80Yk>c0:Nd/@2Y][40[KVc0:fi/@2^^k020;6n/00;0;2m
/02a_Jh0/[j/0;>mZP2c_J/0/kf]0;Bo[`2d_jh0];n]0;BnZ`2`^JL00P2[/j802`2Y/Z00W:FE07b0
MP1cN6`0?3Dg03H`;`0`:RX0:RHT02PU800];B@0<c@W0080>ch^00/0?T@a038e9`0_=2H0:c4R02L_
7`0Y<1l0<S/W03]5;@0`=R<0:RhN02DX6@0201hP5@0301TJ4@0F5`l06Q/D0080824K00L061TE01<E
4@0C5Pl04aH?018C3P0H6QH07R0M00809BTS00/09BTT02/a:`1=FT/0FFQF04YFA@0R9Ad07AdE01TF
4@0A3@`03PT<00d52`0200`73P0;03Dh=P1cQW<0PiZ507fEO`23VGl0PIAi07B2J`1WLV00HFYJ07^;
M023UGX00P26Ug`0302<WH00S9j006ehI01KHEL0HVQO06A]I01YLfP0JGEU065[G@1IHeP0DEYB04eF
D080BU=;00/0Ae1604A<@@11BC`0?D@h03Po=@0b=bl0;c8Z02``9P0[;b<0:blN02X_6`0202`_6`0;
02h`6P0^<A/0;C0L02DZ6@0N91@05Q`?018G2`0A5P/051T=01HJ3`0N8Q@00`0U:AX01@0T9aX092HK
028V700O91`07RDK01[ooooo00@0C5YY055ML01CGgL0EEmk101EH7/02`1GH7`0FV=n05YUO@1MJ7d0
G6Uk05iZO01NJg`0GVYm05eZO@1NJgh0GVYo00<0GVb000X0GFao05e^OP1MKW`0GVmm061`O`1SLH40
HFn0069`PP1TLH<0IW:50P1XLXH0301ZMHL0K7N806]gR@1/MhT0KgV:06mjR`1`Nhd0LWf>07=nSP1d
P8h0MH6=07J3S`80Mh>B00/0Mh>C07N2T`1hQ9@0NXNE07b8U@1oRiL0P8^G0829UP20RYD0PH^G08:=
VP0208:=W00;08>>W024SY/0Q8jK08JBW@28Til0R9:O08VDX02<UZ<0SiVW08nIZ02@VJT00P2AVJX0
2`2AVZX0TIbZ09:NZ@2BWjL0U::Y09FRZ@2FXjX0UjFY09VVY`2MZ:X0WZV/0080X:Z_00X0X:V`0::Z
/@2S[;80Y:fb0:>[[P2T[J`0YJfY0:J]Z02X[jH0YjnV0P2V/:L20:J`YP0;0:NaY@2U/J80YK6Q0:B`
W`2V/Il0YK2N0:B^WP2Q[Yh0WjfN09f]W@22T8<00P18C4d02`0i>c`0;c4`02X[:00X9b80:BPR03Ph
;`19CSl0B59003m8>00g?bh0E6=70080I7IE00`0Cea004YF>`19DcP0@dTa03Hi9`0_<B80:2XN024S
6@0Q9AX092/O028Z7P0O9aX201lV600;028Z6P0T:aX08RXI028X6@0F6Pl06QdA020R500R9aH09bhK
02Xb7@0/=1d00P0^=Qh02`0_=b00<CPS03<i9@0_=R<0<3HS02hd8P0]<R00:RlN034g900lA2`0<cXR
0080;cLN00H0:c<M02Tb7P0X;ah0:BhN02X_800]<b<?ooooo`003Oooool01P1mTH`0QIRE08VLWP27
VZ40Q9NQ08BFX@80QIRR00/0QiVQ08ZKXP2;W:<0RibT08^NY02;X:H0S:6V08fQY02>XZ@0T:>V08nT
Y`0208nTY@0;096UY@2BYJD0UZRW09VXZ@2KZJX0WJZZ09jZZ`2PZjh0XZf_0:>][P2U/:h00P2V/Jh0
302X/jl0Z;B`0:Vd[`2Y/jl0ZKJb0:Ve/`2X]K40ZKF_0:^g/02]^;00[KN^0:jj[`80/;b_00/0/Kf`
0;>n/02c_Jl0];j^0;Bn[@2e_jd0]/6^0;G1[P2e`Jd0]KnZ0;FoZ`020;BmZP0;0;>mZP2d_jT0/KbV
0:VeWP1SHU`0>c@f040l>00m?3<0>ST^03Lg:P0g>2P00P0b<b<02`0/;1d0:RPL02DT6@0P8AD082<D
02<U5@0[;a`0=CTU03Dh9P0/;b809RPN00807b0J00`06a`H01XK5`0N81`08R@Q020R7P0K7QX05aXF
01LI500H6a<051H>014C3@0I6QD202DY7P0;02dc9P0f?Rl0A4dk04QC?P12C3P09RXO020R6P0M7AT0
61DE01DA500C3A<00P0A3A<02`0Q7b<0CUI?05i]H01`Pfh0NHac08VLOP2;WH00QiQn08:CN@20TGL0
PYEi0080QIMk00`0Q9Ak08ZKPP2;VhD0IW1V05aUG@1DFU@0HV]N08^MP`1fPg40EEiG05EOF@1KIUl2
05eZH@0;06AbIP1YN6L0IgES06AaGP1LIUD0D5M904E8?P0l?S@0>3/_03Dh:00a<b800P0a<R002`0b
<Qh0<34O02`^800U:A`06A`@00lB20082`<010L000H80P05208030l600805AT=00H06b0B020S5@0Q
91L08RDJ024U6P0O91PJooooo`0604eJJ`1AGW80Deif05AONP1DH7`0EF5m0P1EHG/00`1FHWX0FF=j
05YTN`0205eXO@0605eYO01MJGX0GFUk05eZO@1NJWl0G6Un0P1MJX002`1OK880GF^005e[P01MJgl0
GFam05m^O@1RLGl0HG1n06=bO`1ULh00IW>20080JGF600`0JWF806]hR@1[N8T0K7Z:06ijS01`Nhd0
LGb?079nSP1bOhd0Lgn;07>0R`1cPHd207F3TP0;07N3T`1gPi@0N8BE07^7UP1mR9H0P8ZF0829UP20
R9D0PHRF0829V@23S9`00`22SI`02P24SYl0QHnP08JAX026TZ00Qi:P08ZDX`2=V:L0SiZY08nIZ@2@
VZP2092JYP0;092JY@2BWJH0TYjV09>PYP2EXjH0UJ>W09NSZP2IYJ/0VZFZ09bWZ`2OZJd00P2QZZl0
302QZK00X:V`0::Z/02SZk00Xj^_0:>/[02U[:T0YZjY0:R^Y`2W[ZH0Yk2W0:N_Z@80YZjW00/0Yk6V
0:JbY02V/J80Y;2P0:FaX@2V/J80YJnQ0:>^X02P[9d0WZfL08^GRP0204Q:CP0;03Lf>`0b<C80;Rd/
02`/:P0/;2L0<S@[04eF@`1:E400?4Dc03<j:`18Dch00P1YNU/0301AGD<0BE<j04UA>015Bc80>ShW
030d7`0Y:QX08b@G024S5`0R9QX08bPK02@Y7@8092TL00/08bXK02H/6`0R9aL0720B01HH3@0B50X0
5AH<01TL3P0X;AX0;34O02hd8002030g8`0;038i9@0b>BL0=3/W03Dl:00b>2@0;c@R02hc8@0Z;ah0
<CLT03]3;@0c>bD00P0_>2401P0[=1d0:c<O02/b800Y;al09bhM02Xa7`oooooo000=ooooo`0607fA
S025V9D0RIbN08NJX@24Uj40Q9JQ0P25V:802`27VJ40RY^R08^LX`2;W:@0RijT08^PYP2<XJH0SJ6T
08jRY02@XjH0SjBW0080SjBU00/0TJFU09:UY@2FZ:L0VJRY09^YZP2MZZX0WZZ[0:2[[P2R[Jl0Xjf^
0:F`[P020:Ja[P0<0:Rc[`2X];00ZKB_0:Vc[`2Y][80ZKFc0:Re/@2Y]Jl0ZkN`0:fh/02]]jh0[[Z_
0P2`_:l02`2a_K00/kj`0;>m[`2d_Zh0];j]0;Fo[@2f`Jh0]L6^0;G1[@2e_jX0]Kn[0080];fZ00/0
/kfZ0;BoZ@2a_:H0ZKFN06=RG00k=3H0@3`h03dl<`0j>Bh0=cLZ03Lh:002038c8`0;02`/7@0Z:1`0
9B@I020Q5@0P8a@08bDE02/_700e>BD0=CPV02`_8P0V:1h00P0O81X0300K71P06Q/G01hP700R9240
828N01/N6P0G6QH05aTD01PK4`0D5Ph04A<=01TJ5@809BTN00/0;C<V03Hn;`14CC/0B5<n049<>00V
:Ql0828J01dM6@0H5AD05A4D01<=4`02014=4`0;024O8`1>ETl0GVeP0723KP1iS7<0RIan08^MP027
V7h0PY=i082AM`22UGT00P25Ug/03024U7/0RY^208^KQ@1VL6H0G6EM05AJE01RJeh0Rif307J3L@1E
GUL0EEmI05]VG`80GFYQ00/0I79V06UhI`1WMF<0I75N05aVE@1@EdT0ADPn03`n=00h>bl0=CPX034c
8P02034b800;038b7P0`<Al0;2hP02DY700I71003a8800P;0`041`001PP200D80P0<3`H00P0E6@d0
1P0K818082<E024T5`0R9AX08BDJ01lT61[ooooo00H0CEY[055NLP1CGWH0E5mj05APO01EHGd205EQ
N`0305IRNP1IHgX0FVAk0080GFQm00H0GFUl05eYNP1MJG/0GFYm05iZO`1LJGh205eZP00;05m/PP1M
Jh00GF^005e[O`1MK7d0Gfim069aO`1QL7h0Hg9o06EcP01VLh800P1YMHH0301ZMHP0JgR906]hR@1/
NXX0KWZ<071kS@1aO8l0LWj>079oS@1cOh/0Lh2;07>1S@80MH>B00/0Mh>C07N3U01hQ9D0NhNF07f8
UP20RYH0P8VF0828U@21R9H0P8VI08><W00308:=W00:08B>W`25Sj00QY6P08JBX027TZ00RYBS08fH
Y`2?VZT0SiVY092JZ080T9ZV00/0T9ZU09:MYP2BWZH0Tj2V09FSYP2EXjL0Uj>Z09VUZ`2JYJX0W:N[
09nY[@020:6Z[`0<0:6Y/02PZK00XZZ`0:>[/02SZjl0Xjb/0:F/Z@2V[ZT0Z:jW0:N^YP2W/:L0YjnY
0P2V[ZL02`2W/JH0Y[:T0:JaXP2T/:00YK6Q0:JaXP2U[j40XjjP0:2/W@2N[I`0RiN:0080B4Y>00/0
=cHk038a<P0^;B`0;2`Z02`/9`0b=2/0CEI304YD@00lAC<0<cX[04QC?P0206UjF`0<055M@`19DcX0
BE4h04E;<P0j?RL0<3@O02TZ6P0S91L08B<G028V6P0S:1/092TM0P0T:A`02`0S:Q/09R`K028W5`0L
81805QP=018D2P0E5P`06A`>02P]6P0/<Al0;S@P0080<3LS00/0<STU038i9`0d>bL0=C`X038h900_
=280;S<Q02X_7P0a=b@0>d<]03<k9@0202lh8@0602/d7@0[<al0:c8P02T_7`0W;Qd0:S4O3oooool0
00gooooo00H0MHR607nDT`25VYh0QY^R08JIY026VJH208NJY`0;08NKYP29W:H0RijU08ZMY02;WZD0
RYjU08^OYP2=XJD0T:>U096UZ02AYZX00P2@YJP02`2BZ:T0U:NW09JWYP2IZJP0W:^Z09n/[02Q[Jh0
Y:n`0:J_/02U[Zl0YJn`0080Yk:`0P2Y/k002P2Z/k40Z[Bc0:^g]02/^;@0ZkNb0:fj/P2]^K80[KVa
0:jh/02`^k420;:m/`0;0;:m/P2c_[40/kj`0;Bn[P2d_Z/0][n[0;S1[@2g`:d0]/2^0;G0[`2h`[40
0P2i`[002`2i`Jh0^L:/0;W3Z`2lbJ`0WZN@05]HDP1:Ad80NH5[06]aG@1DFDP0DUM40080@dDe00/0
=cHX034a8`0];Al0:R/M02PY6@0X:QP0;2hM03Pi:@0j>Rd0<S<Y02XZ8`0202<T7P0301dN6@0L7AP0
8R@P00809RTT00L09BPR024U800L7a`06QdH018D3`0?40`0414<00805AL?00/0720E02/a8@0j@Rd0
>d@^03Hn:@0[<B0092LJ01lP600L71P06aXJ01XJ6P0201dO7@0;01dP7P0U:BD0=Sdd04=;?`18CT80
OXac09NYS02?XHL0TZB8092QQ@2>X8@00P2=WhD0302:Vh@0R9V408RKQP21Th00MHAc06ijJ@1YMF@0
R9Z008nUR@1[NVX0HFmQ05]XF`80EEmE00/0HVmR07F7M01iS7H0O8mg07^>MP1cPfd0K7]V06UeH@1T
KEX0F61>05=JB@0204iD@P0;04I<>@0l@C80=S``02P^9@0L8QP04AD=00X=1P06204010H000430000
0@000P031@401P072P<03@l501PJ3@0Q91@08RLF02<Z6A[ooooo00H0CUU^059MM01CGgP0E5ii05IQ
O@1EGgd205AON`0;05IRN`1HIG`0FVIm05YVO01KIgd0FfQl05YWO01LJ7`0G6Um05iYP01MJ8000`1M
JX402P1LJX00GV^105m/P@1PKH00H6io069`OP1SLWd0IGAn06EdO@1VLgl206UdP`0:06]fQ`1/MXT0
JgJ906ahRP1^NXd0LGZ@079lT@1dOI00MGn@07B0SP80MH6=0P1ePHl02`1gPi<0N8BG07R3UP1lQYP0
OXNI07n8V020R9T0P8VH0869V021RYX0Ph^K0080PhbK00/0Q8jL08B>W`26T:40QY6Q08NBX@27Tj00
RIBS08bGYP2=V:T0SYRZ08nJZ003092KYP0:09:MY`2BWJD0TinV09>QYP2EXZL0UZ:W09VSY`2JY:T0
WJJ/09nV[@80X:N^00P0WjN`09nX/02PZK00XZZ`0:>[/02SZjl0Y:b]0:B/Z`80YZf[00l0Yjj[0:N]
Z`2V[JT0YZfY0:B^YP2T[Z@0Y:nS0:>^X@2U[j80YJnS0:B^X`2S[J80XZfO0:2]WP2<V8`00P19BU00
2`0l?D40>S/k03Ph=00b<Bd0;R`X038c;01BFdP0DUe804=<>@0d>b/0@T`g0080JG]J00`0Dem404YC
>`17CcH0AD/c0497;`0g>RL0;blO02XZ700X9a`0:2XN02HW7@0T9Qh202<U7@0;020S6@0O8QL07B4D
01PK3P0C5PX03a<700d?1P0?4PL09blJ02`c7P0`=R800P0b>2D02`0c>BH0<SPW038i9`0b>BH0<3HS
02hd8@0]<R00:c0N02dd8P0a?2H0;CLQ0080:cDN00H0:38L02Pa700Z<Ah0:BlO02H[7@0Z<R0?oooo
o`003Oooool01P1cQhD0OI:C08BHW`26VZ@0QYVV08JIY`80QYRW00/0QYVW08RLZ029WJL0RYnV08fP
Y`2=WjP0Sj:Z092TZP2>XZL0T:FX09BWZ`0209BW[@0409>W[02FZJl0UjZ^09ZZ[P80VjZ]00<0WZf_
0:2_/02R[k400P2S[k420:Jc/`0<0:Ne/P2X]K80ZKBe0:Zd]P2[][P0[;Ng0:ji]`2_^[D0[[Ve0;2i
]@2`^;@0/;^f0P2a_KH02`2b_KD0/Kfb0;:n/P2e`;00]/2_0;No[P2j`Jl0^l6a0;[0/`2j`[H0^L6e
0080^l6d00/0_<Bd0;_4/02ja:`0_<N[0;W6Z02LY8d0MGAZ09nVTP2Y/I`0WJNB09FPR@0207MnJP0;
04U9?@14ASH0@dLd04=7<@0o@b/0?40X03Pk:00k>bd0?C``03Th;@0];BD00P0W9al0300Q8AX07QhG
020P6P0T91d0:2XS02`_9`0/<2T08bDT01dN7@0B4a803a0>00d@3@803a8=00/04aLA01dS6@0T:ad0
9bdM02T`7@0U:QP0828D01`L5P0I61L06aXK01/J7@02030e=00;04A=A`13CTH0CUa@051KCP1<DdL0
CE1909>SRP2:VH@0Q9>0082@N`20SgX00P29W8@02@29W8D0RYf708^OR@27W8D0QIV107f@M`1gRW80
NH]b07b@M@0207^?MP0707N:L`1cQW00LhI`07>5L01cQG40M8Ic07N8MP0207R9MP0507R9M@1jRg@0
O8]c07V6L`1dP7000P1aOVh02P1^O6`0IgAV05aZG00f?cP0720M01LK5P092PH010D1008300010P03
0001000600020002100030h301XM300R9a<09BXG6_ooool01P1>FFd0DEYb05=NN01DGW/0EUml05IQ
O@80Ef9m00<0F6=m05UUO@1KJ7d00P1KJ7d01P1KIgd0FVMm05aXOP1MJWl0GVV005aVP080G6Mo00/0
FfQn05aZO`1NJgl0Gff105m/P@1OK7l0HFio069`O@1SLG`0Hg5m06IbP@0206QbQ@0<06YcQ`1ZLhP0
K7F:06igR`1`NHd0LGZ@07AlT@1dOI00MGj@07J0T@1ePI00MX:@0P1ePY402`1gPi@0N8>H07V3V01j
Q9P0NhFI07j7VP21RYd0P8ZM082:W022S9`0PXbM0080PhbM00H0PhfN08B>X025Sj00QY2Q08N@XP27
TJ@208VDY@0308ZEYP2<UjP0S9JY0080SIRY00/0Si^X08nKYP2@WJH0Tj2W09BPZ02FXJT0Uj6Y09ZS
Z@2LY:/0WZF/09nW[`0209nX[`070:2W[`2QZ;40XZV`0::Y/02RZk40Xj^`0:>/[P020:B/[P030:F]
[P2U[:d0YJb[0080YJfZ00/0Y:fX0:B/Y`2T[ZD0Y:jT0:F_X`2V/:@0XjfS0::/XP2QZj00X:bO096N
TP0204e>E00;0494B013Ad<0?3lh030`:P0];2D0<30Y04eCA01<Dd80?TDf02ld:00lA3400P1^PUd0
301FIDL0Ae4h04QB>@16CSD0AD/d04=7<P0l?B`0=cP[038c:P0`<2X0:RXT02@T8080824L00/07R4I
01hQ5`0M8AD061/?01<G2`0@50L03Q4600X<100Q:1P0;cPS02lh8P02034i9080<3TU00T0<3TT02hf
8`0^=R40;SHO02dc7`0Z;ah0;3@R02lj9@0[=Al00P0Y<a`01P0Z<a`0:c4L02/a7P0[;ah0:2/L02T^
7Poooooo000=ooooo`0607:4Q@1mT9D0PYFP08>FY022UZ<0PiJS0P24Uj<02`24Uj80QIZS08RNY@2:
WjD0RYjU08VMYP2:WjP0S::X08ZOYP2:WjD0SZ>W0080TZF[00H0U:N_09BW/@2FYk40UjR`09VX[P2J
ZJl209^Z[`0309bZ/02N[;40X:ba0080Xjna00`0Y;:c0:Nc]@2W/[D0Y[6d0:Rb]P2Y/[P0ZkBh0:bf
]P2[];@0[;>c0:je/`2_^KD20:ni]`0;0;6l]P2a_;D0/[fd0;>m/P2c_K00];f`0;Jn/02h_[80^/2f
0;W2^02h`KL00P2g`;@02`2f`K<0]l>`0;O2[02g`JT0]/6Y0;K0ZP2c^:H0/[RV0;JmZ`2f_Z/0]L2Y
0080[[VQ00/0N7Y`06e_I01lPfl0PHYa079iH`1KHDl0DUM704Q;?@14A3T0?CXa038`9`0202d/8`0<
02LV7P0Q81X0820H02<T6`0V9Ql0:2XR02T[900R92007AdL01PG600D4aD04A@C0P0B5a<02`0G7AL0
6b4J024Y7@0W;R00:C4P02D[6P0O8Q@06a`E01/I5`0H5AL071XO0080=cdn00/0MHQg06f2L01QM6@0
I7IR05YWE01:CdH0V:^@08jRR`1aPg<0I7=U055KDP020761K@0<08:EO@24V800RIj608RMQ`2:XHP0
GfmP04QCB@25VW`0LX=Z06mnJ`1kSGT0OI5l0P1jT7/02`1jT7X0Mh]e07J9M@1eQ7@0M89e07:0M@1b
PGD0Lh=c07B3L@1dPW40MH9`0080M85^00L0M85_07B2K`1hRW<0Ce]@018B5`0;2``00@4100<00000
0`000@001P0210002@/2018D1P0G6PX07b@A02<X51[ooooo00H0CEUZ051JL01EGgL0EV1j05EONP1G
Hgd205QSOP0905UTO`1IIGl0FVEn05]WO01MJ7d0FfQl05eXOP1MJ7l0GFR00080GVV10P1MJ8000`1M
JGl0GVZ005i[P002061]P006065]P@1RKh40I76106IcPP1VLH<0Ig:50P1YLhT0301ZMHX0JWB906ef
S01_N8h0L7V@079kT@1dO980Lgb@07AmT@1eOi<0MH6C07J1T`80Mh:D00/0N8>F07V4V01jQIT0NXJI
07Z5V01lQiX0P8ZM086:W@20RIh0PHZN08>;W`0208><W`0;08B=X025SZ00QHjO08NAX@28TJ80R9:T
08ZDYP2:UJD0RiNW08bHZ02<UjX00P2=V:X02`2?VZX0T9fY09:NZ02DWZL0UZ6Z09VRZ`2IXZX0VjF[
09bTZ`2NYZ`0X:R_0080X:V`00L0X:Vb0:2Z]02QZ[<0X:Va0:2[/@2QZk00XZ^_0080YJf_00<0YJf^
0:J][@2V[J`00P2U[Z/02`2U[ZT0YJjX0:B^YP2U/:L0YJnU0:F_Y02T[J@0XjfS0::/X`2PZj40UZ:H
0080DU=H00/0?3a30452@@0m?CP0<S4Z02l^9@0b<2L0BU1004U>?P0o@cD0<cH[03Xo<@020721G`0<
05UWC015CSX0BU@n04QA>`16CSP0Bdlj04M8=`15ACL0?She03Th<P0c<bh0:RTW0P0U9R802`0P8aX0
7B0D01XK400F5Pd04aD;014D2@0?4PP02@`401dU5P0_>BD0;cPU0080<3TV00/0;SLU02dh900]>2<0
;CPS02`f8@0]=b00:c<O02Xa7`0Z<b00;3HR02Xd7`0202Td7P0602/d7`0[<ah0:c4L02T^700[;Qd0
;C8P3oooool000gooooo00H0NHV>07jAV@20Tj00Oi>P082DX@21U:0308>GX00508BHX@26VZ<0RIfV
08RMY`29WJH00`2:WZH03`2;WZH0SJ2V096SZ`2AXj/0TZB]09>T[`2EXk00UZB_09RW/02JZK40VjVa
09bY/@2LZK80WZbc0::]/`020:>^/P0<0:>]/P2W/;D0ZK6e0:R`]@2Y/[H0ZkBi0:bd^02/]KL0[KFe
0:fe/`2^]K80/;Rd0P2a^[D02`2b^[D0/[^d0;:l/P2b_;00/Kb^0;:l[P2c_Jh0/kb_0;Fn/P2e_k<0
]<6c0080]<6b00/0/l2a0;G2[`2f`Zh0^<:^0;S2[02i`J/0^l6[0;_2Z`2i`:X0^/6Z0;c3Z@020;_3
Z00;0;BkXP2^/id0[K>L0;2iW`2[]9T0W:>:08fCN`1YJUX0G5Y>04]8?@0m>bl00P0e=BT0300]<2@0
9RXP02LW7P0Y:Ql0:R/Q02DX7@0P8Q/07AdI01XJ5`0H5aL05ADF01HH5`806alK00/092TP02L]8@0Y
<2<0:c4U02`b9P0[<B809R/M02DX7P0R8ad07A`I01PH6002030f<@0;07^BMP28Y800DV9=04eJAP0o
B3T0>Chd06AaGP1OKEd0JWmY06UmI`1JJUH00P1ZNf@0301jSG@0OY9j08:FO`24V880RIn6065_H@10
AD40V[6?055ICP12B4H0SjB=07nDP080IWQ[00/0LHEd07Z>N`1]Nfd0K7Q]075lM01bOGP0LH1i07:1
MP1bPW<0Lh5a07B2K`02071nJ@0;06ijI@1ZMf40HFeJ03m5?@0D4QD02@D800D310030@800P420040
0@000@000P010`001P051`805QP=020S500R9aL08bXI02@/61[ooooo00H0CEQY051KL01DGgD0EV1g
05MQN@1II7`205YSOP0;05YTP01KIH40FVB005]WO`1LJ7d0FfQk05aYO01MJGl0GFR0061ZPP1PJX<0
0`1OJ8802P1PJH<0H6Z2061[P01QKH40HVf1065^P@1SL8<0IW:606QcQP1YLhL206YdRP0<06afR`1/
MH/0K7F<06igT01_NI80LG^C07=mT`1dOY<0MH2C07B0TP1eP980Mh>C0P1hPi<02`1iPY<0NX>D07^4
U`1nQYP0OXRH07n8V@21RY/0PHZM0869WP21RYl0PX^O0080PhbO00/0Q8fO08F?X028T:40RI6Q08VA
XP2:TjD0RY>T08^DYP2<UjP0SINZ08jHZ`0208jIZ`0;08nIZP2BWJ`0U9j[09BNZ@2FWjX0V:6Z09VQ
ZP2IXj/0VZBZ09bVZ`2OZ:h00P2OZ:l0302NZK40WZRb09jZ/P2OZ[40WjZ_0:6/[`2R[:h0Y:f/0:B]
Z`2U[Z/0Yjf[0:R^ZP80YjnY00<0YZnW0:N`Y@2V[j<00P2U[j@20:J_Y@040:B^Y02R[:80X:ZQ09^X
W080HFEU00/0?Se30411@P0n?SX0=SD`03<a:`0c<BX0B4/l04]A@011ACL0<C<Y03Hj:`0206emF`0<
06IeEP15BcX0BU4o04Q@?P15C3X0DEI105eSB`1EFDD0C4dn0492=`12AC/0:BPV0P0V9b802`0Q8a`0
71hD01TI3@0F5PT04a@9018D2P0@4PP03Q0601LJ300X;a`0:C0K0080:C0N00/09RdM02D]7@0X<B00
;3LS02Xe8P0X<Ah0:34M02Tb700Y<ad0;CPN02dh7@0202/d700602/c7@0[<Qd0:S0M02T_7P0[;al0
;S<Q3oooool000gooooo00H0NXV?07nBVP21UJ00PYNQ086EX@22UZ4208>GXP0;08BGX`24Uj@0QYRU
08VJY`29VjP0RYbX08bNZ02=X:P0S9nW08fPY`2>XJP00P2@XJ/02`2CYJd0U:B]09BR[`2GYK40VJJc
09ZX]02LZK<0WJZc09j[]@2P[KH0XJff0080XZnd00`0Y;2b0:J`/@2W/;40Yk2c0:Zc]@2[];H0[KJg
0:jg]`2^]kD0[[Nc0:jh/@2a^[820;:l/@050;:k/`2b^k80/[bb0;:l[`2a_:h00P2c_Zh0102d_Jl0
]Kn_0;Bo[P2e`:l20;O2/P0;0;S3/`2h`[40^L>c0;W2/P2h`Zh0^<:/0;[2Z`2la:/0_LF[0;k6ZP2m
a:P00P2ma:H02`2naZH0_<BV0;_3YP2ka:@0^/>R0;[5X@2d_YX0XZV:09>IOP1aM5l0BDPg0080A4Lb
00`0?48_03Dj:P0c=2L0<C4T02l^8P0Z:Ql092@K01lP6@0L7QL06Q`F01TK5P0L7QT2024T7P0;02da
9`0_<bL0<3DX034d:@0`<bP0<3@X02ha9@0/<2D0:bhT01hO5`0I6Q800P0F61002`0T:Ad0>TDb034h
:@0^<RD0:2`R02L[8P0W;2@082DN04iMB@1[Of40HW=H0080LhIZ00`0LH=Z0721J`1]OV/0LHEd07N<
N`1cQgD0KX1]08RNP`1NJUl0@TU:08ZPR`2BZi8207V<NP0;07b?N`1oTGd0?Cm004=5B01ePGP0KgUe
05mXIP1XMVh0KWe^06imK01]OFP00P1/O6D02`1[Nf@0IgIO055LBP0f?S<06A/I00d<3@0;20X020D7
00H410030P800P41008020X600H051L@01lS600W;1`0:BlP02P_800Y<20Jooooo`0604eFJ@1@FFl0
Deed05IOMP1HH7L0FV=j0P1JHg`01`1JHgl0FVB005YUP@1KIX00FfMn05YWN`1LJG`00P1MJ7h01P1O
JH00H6V105iVO`1NIWl0GfN0069ZP@80HFZ000L0HFf206=^P@1TL880I72306IaQ@1XLXD0JG:60080
JW>800L0K7>906edR@1]M8X0KWN=06miS`1bO980MGjD0080MGjE00<0MGnE07EoU01fP9@00P1gPY<0
2`1hPi@0NH>C07Z4T`1lQI@0OHJE0828UP20R9T0OhRJ0829W@1oRih0OhZM0080OhZK00/0PHfL08B>
W@26Sih0R92N08RAW`28TJ00RI>Q08^EY02<UJL0S9JW08jHZ00208nJZ@0;092KZ@2BW:X0TifZ09FN
Z@2FWZT0Uj2Y09RRZ@2IXjX0VjF[09bVZ`2NYj`00P2NZ:d0302NZ:l0W:R`09bY/02MZjl0Wj^/0:2[
ZP2Q[:X0Y:fZ0:F^ZP2U[JT0Z:jZ0:V`Z@80Z:nW00/0YZjU0:J_X`2V[Yl0YZjP0:N_X`2W[j@0Yk2T
0:F_X`2S[J80XJbQ0:2^X00206Q]K00;03Tg@010@480>SXh03ho>P12A3`0Ad/o04]@@@1:Cd00@DLh
03<g;00b=bX00P1VMeL0301`PF00A4Xi04M>?P16CCh0@DHh05AKAP29VWH0JW9J06=ZEP1PJ5H0CE=8
02/[:@809bTU00H0824K01PI4@0C4`X04A06010?1@0@40H2018C2@0301@F2@0S:1@08bPB00808BDB
00/07B4@01hS4`0V;1/0:S8O02D]700O9AH08RTH02H_700Y<Q`0;CPN02dg7@0202hf700602dd700]
<a`0:S0K02X_7@0/<B40;C<R3oooool000gooooo00H0M8J:07fAU@21UI/0PiNN08:FWP23UZ0208BF
X@0;08>EX`25UZ<0QYNS08NGXP2:VJH0Ri^W08bLY`2=WjP0SZ6W08jPY`2?WjP00P2@X:/02`2AXJd0
UJ>]09JT[`2GYK40VJFb09ZW/`2KZK80VZRa09bZ/`2MZk@0WJ^c0080Wjb`00H0XZna0:B_/02W/:h0
ZK:a0:^c]02Z/kD20:^e]@040:bf]02/]k<0[[Va0:nj/080[k^_00/0/Kba0;6k/@2a^k80/K^a0;:l
/@2e_K80^<2b0;S0/`2h`;80^<6`0;S2[`020;W2[`0;0;[3/@2j`[<0^L:c0;[3]02k`k<0^L>_0;S1
Z`2ka:/0_LJZ0;k6Z02naZH00P2oajD02`2ma:@0_LBU0;g4Y@2naZ@0_/FR0;_6X@2jaIh0]l:K0;G1
VP2X]8d0Kg5G0080GV1800`0Fee605MJA@1BE440ATDg03hl<@0c<BP0:BTP02@V700R91X07b4I01hO
5`0P8QT202@W7@0;02lb9P0e=bX0>3X]03Pj;@0f=b`0<S<Y02d^9@0Y:R80:R`S02P[8P0P8Q/00P0L
7QL02`0E5a805AHA01XK500I6A<061TD01/N600P8a`071lJ02@Y8017E3h0D5i60080LhQV00`0JGaN
05QWC`0lACP0@de404iKE01UN6X0Jh1^06n4K`1ZOVd0HWEX07:8MP24WH<208NOQ00;08FJP@1`OFd0
;R/c02/Y=01^OW<0LX9f03a1A@1EH5X0M8Mb05YWF@0j@3T00P1<ETH02`1UMEd0HG1J04YFA@0`>Bl0
720M018C4P092@X01PD600D410040`400P8000805a`B00H0:c@R02`e8`0]=B<0:c4Q02L/800U:AhJ
ooooo`06051IJ@1DG6h0Eemf05MPMP1IHWT0FFAj0P1IIGX02@1JIWd0FfMn05]XOP1MJ7l0GFQn05]W
O01LIg`0G6Mm05eXO@0205eYOP80GVUo00/0HF^0065[O`1SKH00HVj106=`PP1SKh40Ig>306QbP`1X
LH@0J7:606UbQP0206YdQ`0<06]eR01_MXP0L7N8079jRP1bNhd0M7b@07MmU01gOIH0MGfG07AnUP1e
OiD0Mh2E0P1hPYH02`1hPiH0N8BD07R4T`1iQ9@0O8JE07n9UP21RIX0P8VK082:W01oRY`0OhZM0080
P8^L00/0PHbK08>>W024SY/0Qi2L08VBW@29TYh0RiFP08fFXP2>UZ<0SiNU096JZ00209:LZ00;09>M
Z02DWZP0UIjX09FMY`2EWZH0Uj2V09ZSY`2IXjL0WJJZ09fWZ`2NZJ`00P2OZJ`0302NZJd0WZV^09fZ
[P2NZZ`0Wj^Z0:2[Z02S[JT0YJf[0:N^[02X[Z/0Z:jY0:R_Y`80YjnU0P2U[Z<02@2V[j80YZnQ0:J_
XP2Y/:@0Z:nS0:F^XP2T[Z<0XJbR0:6_X`0206]`LP0;03Dc?P0o?cl0=cHc055EAP1CF4H0GVA?05YP
B`1?E4<0CEA303a2=@0i@3<00P1PL5H0301[O5l0BU=104UB@011AcT0=SX^04iFA02G[8P0Rian08NE
NP26U7X0F5mB02TX:0809RPS00/07R0H01XL4P0E5P/04A8600l>100@3`D051<901HG300H6Pd07B8@
01hT3P0201/R3@0;01TO3@0I7@d09R/I02he8P0O8aL051H>020V600U;A`0:S<O02lg8@0_=Qh00P0`
=R001P0a=b40;cDP02`b7P0/<Ql0;C<S030g9Poooooo000=ooooo`0606n0R01iS9<0P9BL08>FWP23
UIh0Q9FO0P24UJ002`25Uj40QIRP08BGW`27VJ00RYZS08^JYP2<VZL0SYfZ08jNZ@2@WZT0Tj6[00<0
UJ:]00X0UZ>]09RT[P2HY[00V:Fa09VW/P2JZ;80VZNa09^Y/P2KZK40VjZa0P2O[[40302R[k80Y:n`
0:Ja[`2X/[00Z[>c0:^c]@2[];H0ZkBh0:bf]`2/][H0[[Ve0:nj]080[kZa00/0/K^a0;>k/P2c^k80
]Kbd0;Nn]@2h_[@0^Knd0;Zo]@2h_K<0^;nc0;S0[`020;S0[P0;0;_1/@2l`[<0^l6c0;c2]02naK80
_LJ_0;_4[@2laj`0_<RZ0;_6YP2maZ<00P30b:@02`2naJ<0_/JV0;k5YP2na:D0_lJT0;g6XP2kaJ00
_<NQ0;_6X02laj00[kRD0080WZ>500`0Vj630::ZR@2GX800M7MQ04E1>P0o?CD0<c<Z02`_8`0Y;R00
:BdP02X[7`0[:b0202//8`0;038c:P0o@S<0@dLh03i3=`0g>S80<CH]02`_:@0X:RH092HR02@X8@0S
9ah00P0P8aX02`0K7aD071lF01`M5P0F5A006Q/B020R5`0S9Q`08B<M01/M6@0J7aP08bPO0080<CX[
00`0=d4_03Q1;`0`=RP0:RlR02L[8@0d?C00AE91069fG@1EIE00@Ti105=SD`1[OVT207:7L@0;07B9
MP1fQgP0DEYG03m8B@1MKV<0O9=l05IUE`1SLf40LH=]04mIC@0L6Qd00P0Y:RP02`1OK5T0E61@03U2
>@0Z<R`07b@P01PK5`0?4Pl020X800D8100520801PT2008061lA00H0?dlc04AD>@0hA2l0;CHV02P_
8P0T:1hJooooo`0604iHJ@1CGVl0FF9h05YSN`1IHg/0F6Ak0P1GHgX01`1IIG/0FfIk05]VO01NJ7h0
GfUo05eXO@1KIg`00P1LIg`03P1MJ7`0GfYn05eXOP1MJ7h0GVUo05mZO`1PJWl0HFf0065^P01RKX00
IG6206QbP`1XLX@0JG:70`1ZM8H0201ZM8D0KGN806mhR@1aNXX0LW^=07AlS`1eO980MWjE0P1eOYL0
3`1fOiH0NH6G07V1V01iPIP0NX6G07V1UP1kQ9D0OXNI07n9V@1oR9T0PHVL0828W@1oQid0P8RM086:
W`0208><X00;08:;WP22S9l0PhfN08J?W@28TIh0RY:O08^DW`2=UZ00SYNQ092HXP2BVJ@00P2CVjH0
2`2DVjP0U9fW09BLZ02DVjP0UIfX09NPZ@2IXjP0VZ>W09fVZ@2NYZX0WZRY0080WjZ[00`0WjV[09jY
Z`2MZZX0WJZX09nZZP2QZj/0XZ^[0:>[ZP2U[:/0YZf[0:R]Z@2Y/:L20:R`YP<0YZnT00P0YZnS0:Na
X`2X/:80YjnS0:F]X`2S[J<0X:^S0:2^Y080LgYj00/0?Si703i0@@0f>3H0DEU904mE@`1RJU40HFUA
055GA@1BFdT0@DXk03]3=@0205YXC`0<06UjG01?FD<0C5E00415=00c=2T0D5I4096TP`2=Wh40TJ:4
09V[S01/Mf<08QhO0P0T8b002`0P8QT06Q/A01DE2`0B4PL04@l6014@1P0H6`/071l>01hQ4@0N9180
7B@B00806R4A00X05ad?01HI3`0b>BT0?DDb01DG4P092PP07R@H02df8`0`=b80<STR0`0`=Ql01P0b
=R80;c@R02db8P0]<b80;S@S02lf9@oooooo000=ooooo`0607F7S01oTYP0PiNO08BGX023U:00PYBQ
0P22U:802`24Uj<0QIZS08FIX028Vj80RifU08fMZ02>W:P0SYj[08nP[@2BXJh0U::^0080UJ:]00/0
U:>/09JT[02HYJd0VJN_09ZX/`2KZ;@0VjRc09bY/`2N[;D0WZfd09b[/00209j][`0<0:6`/02S/Zl0
Y[B`0:Na[P2Z/jl0Zk>b0:bd]@2]]KP0[KNh0:ji^02^^;P0[kVf0P2_^kD02`2a_;D0/KZc0;:j/`2d
_;H0]kni0;Rm]`2i_kL0^[nh0;Zo]@2i`;<0^<2b0080^L6`00/0_LBb0;g4/`2m`k<0_/>b0;o5/02n
ajh0_lJ^0;k7[P2laZX0^lJX0;k7YP020;o:YP0;0;c6Y@2laZH0_LFV0;g5Y@2ob:L0_lRV0;g7XP2o
bJ@0`<ZT0;o9X`2nb:800P2naj80302kaJ40_<FT0;[5X`2Z]9@0LG9R059@AP1CEDT0Bdm104E:>@14
BCL0@dHf04=5=P80?d8e00/0?D4e04A9>P19Ccl0@DLj03Pl=00g>cD0<3@`02`_;00Y;2/0:RhY02T]
9P0202L[8`0;02@X800T:1h08R@L01TI4`0K71D08B<J02@W7@0Q91`07AlJ01PK5P0G6AD00P0Q9Qd0
300W:b409RTO02<U7@0P8QT07b8G024V6@0S:1`0B5Hn051OA00h@Bh0;c@W03Ln<@80@4Pl00/0Ae58
05aZG`1cQgH0GViS05ATF@1OLF00IgUT06anJ@1]OF`0GfaQ0457A@0204U?B`0;05eVF`1=Ddd0HFmN
01/O7`0K81d04AH@00`@2P072PD01@P400T;1P0=40X00P0?4`/01P0X<b80>dXd03Q5<`0f@C<0;cP]
02@/8Q[ooooo00@0C5Q[055ML@1EHGH0EF1i0P1GHW`205QRNP0;05USNP1JI7X0FfAk05]TO01KIg`0
FVMk05aYN`1MJG/0G6Qj05aYNP1MJG`00P1MIgd02`1PJWl0HF]o05mZO`1PKH40HFf1069^P@1TKh<0
IG6406MbQ01XLXH0JGB60080JWB600`0JWB706efR`1_Mh`0L7R=075kS`1bO940LgfC07AoU@1eOiL0
MgjH07QnV01jP9T207Z0V00;07V0UP1iP9@0O8:F07n4U`20QIT0P8JJ0828V`20Qi/0OhJK0827W020
RIh00P21Rj402`21S:40PhbQ08B=X@25SIh0R92N08RBX02:Tj00S9BP08^EX@2<UJ40SiJS0080TIVU
00/0TYZV09>KZ02AVJP0TYZY09BMZ@2FWZT0UinY09NOZ02HXJP0VJ>W09^UZ00209bWZ00<09fXZ@2N
Z:X0WJRY09fXY`2NZJT0XJV[0:6ZZ`2RZj`0Xj^/0:B/Z`2V[JX0Z:jY0P2V[jD02`2V/:D0YJnT0:B^
X`2U/:@0Y:nS0:F^X@2U[Z<0YZjS0:B]X`2Q[:40X:jR0080OhR200/0AdQ=0495A@0j?SX0@4Dl04M>
?`1HH4/0J7AJ04mFA@1CFTP0ADdm03U0<@02055NAP0<06YmFP1EHdL0CUU004YB>`0j?Rl0C59108jQ
P02:Vgh0S9b109JVR@21SgD0;RdY0P0U8Ql02`0R8Q`071`F01LF3P0C4PT04A47018B1P0H6`/06b4>
01`Q400O9A<07R@D00807B<D00/06A`?01<D300Z;R@0?TLh01XM6P0;3@`061hD030j9@0^=b40<cXS
034g7`02030f8006034g8`0^=2<0;C8S02hc9@0a=bD0<SPU3oooool000gooooo00H0NXj>08>GV@26
VIl0QYRR08BCXP25U:H208FEZ00;08FGZ025VJL0QYZT08FIXP29Vj@0RibW08^MZ02<WjX0SJ2[08jO
ZP2@XJd00P2BXZ`01`2@XZT0TjF[09JV[@2IYZh0VJN`09^X/P2MZK400P2MZ[40102O[;80Wjb`09n^
[`2O[Zl20::`/P0:0:>b/@2T/:l0Yk:_0:Zd/P2]]K@0[KFf0:fg]P2/]k@0[;Jd0:fg]080[kVf00/0
[kZf0:ji]02_^KD0/[^f0;Fm^02d^kL0]Kfh0;Vo^@2j`KL0^;ne0;Ro]0020;W0/`0;0;W1/P2k`k@0
_L>e0;_2/`2k`k00_LJ`0;k6/02maZh0_<F/0;_4Z@2laZT00P2majT02`2laZT0_<BY0;c5Z02maJL0
_/JX0;o8Y`2obJH0`L^V0;o:Y@2nb:@0_LNS0080_LNT00`0_LJU0;g6YP2maJD0^lJU0;2kV`2EVX80
Uin608fEO01gOFL0KgAN06IYEP1PHU02055DAP0;04Y>@@15B3`0@dDh03m1=@0k?3@0>CTe03Pi=@0g
>SD0>3Xg03@g=00_<Rh00P0_<bd02`0]<R/0:c0Y02DY8P0K7AP06AXE01dP600Q91X08B<J01`N5P0G
6A807AlH0080:blV00`0;C8W02T]8P0Q8Q`07QlH01/L5@0I7Q@06alD01`P4`0X;Qd0;38O02`b800V
:Q/2020R600;01dO6@0Q9200AE1304aHB`0d?3P0=Shh04MCA`1GIeP0HWET06MjJP1UMFL00P1XMfT0
2`1RKV@0<SHh04QDBP0T:bD07bDO00dA3@0<40T02P`500X:100?3`/03a0=00803@d<00H03Pl?014D
4P0D61D0:30V034i;P0W;RHJooooo`0604]GJP1?Fg40E61g05AOM`1GHWX0F6=l0P1HHgT02`1II7P0
FVIi05aWN`1LIg`0FfIj05YWN@1LJ7/0GVYk05eYN@1NJW/0GVYl0080GFQn00/0GfUm061[O`1OJWl0
HFf1061]P@1QKX40I6n306I`Q01WL8@0Ig:506UcQ`0206YdR00906YcR@1/M8/0LGN>07=jS`1dO940
M7jB07F0T`1fP9D0MWnG0080MgnH00X0N82H07R1U`1hPIL0NH6F07^3U@1mPiD0Oh>E07f1U01nQ9P0
OhJJ0P1oQi/03`1oRId0OhZN07j:W`1nRYl0Oh^N086=X023SJ00QHfP08J?X028TJ40R9:R08^DY02;
UJD0RYFU08bFY@0208jGYP07096JZ02BVjT0TIZX09:KY`2BWJL0U9fY09NPZ`0209RQ[00@09NPZP2J
Xj/0VjF[09^UZ`2LYZ`0WJR]09fY[02MZ:X0WZV/0:6Z[P2RZjh0XZZ_0:B//02U[K40Y:b_0:F/Z`80
YJjX00D0YZnV0:J`Y@2T[j<0YK6T0:>^X`030:B^X`030:B]X`2Q[:80XJnT0080RiJ>00/0AdQ=03m0
@@0i>cP0?d8k04]AA@1=DdH0JgUR04]BA@1?EdT0Ae1103Hl<@0204]GA00<06f1G`1HIdX0CEU004]G
?P14CST0B50n08^MN`2<WGl0RYYm08jMPP2?WH80CE160P0X9B@02`0U92807ahL01TI500E50l051@=
01DF300J7Pl0724C01dR4`0P9AD08BHF00807b8D00/06QX>01HE300N7aL0;C4X03i7>@0?4A403a<?
02Tb8@0]=B80<3HS02le8P0202he8@0602lf8`0_=240;S8P034d8`0d>2L0=CXX3oooool000gooooo
00H0OY2C08BFW026Uj80QYJU08JCYP26TjT208JEZ`0;08FFZP26VZP0QibT08RLXP29WJ<0RYfU08ZN
YP2<X:P0SZ6Z08jOZP2@X:d00P2AXZd02`2AXj/0TjF/09JV[@2HYJd0V:F^09RT[P2HYJh0W:V`09jZ
/02OZk00WjZ_0080Wj^_00`0XZnb0:>`/P2S/;<0Xjja0:F_/02X/K80Z[:d0:Zc/`2/][@0[;Je0:^e
]@2[]K@20:jh]P80[[Vg00T0[kVg0;6j^02b^kT0/kZh0;Bl^02h_KP0^/2i0;Vn]`2i_KL00P2i_[L2
0;W0]`090;S0]P2h`K@0^L:a0;[4/02ka;00_<N`0;_6[P2laZh0_/J^00<0_/B^00X0_lJ_0<37[`31
aZh0_/>/0;o4Z`2oaZT0`<VX0;o9YP2ob:L0_/NX0P2najT0302laJP0_/JX0;o7Z@2naZP0_<FX0;S0
Y02g`:@0]KjR0:ffVP2JXXH0R8me07IkI080Fee=00/0F5Y:051AA@1;Bd40ADDl0451>@0n?3H0C513
05QQD01AFT/0C5A603Tm<P02030b:P0;02/]9P0X:R@09bTT024S7P0L7AP07b4I02<V6`0Q9Q/07R0H
01XK5P0T9Ql00P0Z;RH0300/;bH0:R`R02DW7`0R8a`0828J01hQ600K7A<051@;01<C2@0H6@d07b0B
01hN4P805aL>00/04a@=014A300S9Qd0EVI?02lg;P0T:RD08BLW02<[:@0f@CX0DV9A05e^F@0205MT
E00;05MUEP13D4D0?Ta003m=?00N91`03A4<014E3`0B4``04Q8=01<A3`0@3@d00P0<20/01P0:1`X0
2@H900X62P0>3A005ADF020S81[ooooo00H0CUU/051KLP1BGWL0DEef05=NM`1DH7H205EQM@0605MS
M01HIG@0FfMh05eYO01KIW/0FVMk0`1KJ7`01@1MJGd0GVYn05eZOP1MJWh0GV]o0080Gf^000P0H6b1
065]PP1PKH80Hfn206E`P`1VKh@0IW2406QaQ`<0JW>700/0KGN:06miRP1`NHX0LW^<07=mS@1dOXh0
MGjA07J0U01eP9H0MGnF07F0U`0207N2V@0:07V2V01gPIH0NX:E07b3UP1kPID0Nh:F07f4V01mQIP0
OXRJ07n9W@<0P8^Q00/0OhbP082=X021SJ00PhfO08J@X@27TJ80Qi2R08RBY@29U:L0R9BV08ZEYP02
08^GYP0;08fHYP2?VZD0Si^S092KY02AWJH0TYjX09FPZP2FX:/0Uj6/09RQ[02IXZd00P2IY:h0302J
YZl0W:N`09bX/02MZ:l0WJR^09jY[@2QZZd0XZ^^0:B[/02SZk00Y:b_0:>/Z`80Y:bX00/0Y:fW0:>_
Y`2R[jD0XZnS0::]XP2S[J<0Y:jT0:>]XP2R[J80X:^R0:2]X`0208nLT`0;04Y:D@0n?T@0>CXm04M=
A`1JHeD0D5I<06QeHP19DDP0C5I;04E?A00e?3D00P15D480301YOF00FFU?04aH@P1<Ed80Ae4o04M@
@01oT780RYan08RGO@29V7l0RIN106UcI080?T4l00/09RLW024R900N7al06AXI01PH500J71<07B0E
024S600R91P092LI02DW6@02020R5@0;01/I3`0J6100DEa403m7>01IIE004A8A018D4@0U:al0:S4Q
02`b8@0]<R000P0^<b40100]<b40;c@Q02ld7`0c=b<203Hi9`oooooo000=ooooo`06082@U025U9d0
QIFT08FFZ025UJX0Q9B[0P21TZT01P22U:P0Q9RW08NLY`27VjD0RIfW08^NZ@80SJ2[00<0T:6[096P
Z`2CXJd00P2DXZl02`2DY;40UJB_09NV[P2HYZ`0VJF/09VV[@2GY:`0VZN^09bY[`2NZ[00X:ba0080
Wjba00`0X:fa0:6^/02R[k40Y:nb0:F^/@2W/;<0Z;:c0:Vc/`2/][@0[KNf0:jh^P2^]kT20:fg^00:
0:fg]`2_^KP0/[^k0;>j^P2d^[/0][^l0;Nl_02i_Kd0^kjn0;Zn_0<0^[nk00X0^Kni0;[1^`2j`kX0
^/>g0;[3]02ja;<0^lBc0;g5/`2ma[<0_/Jd0`2oa[D0102naK@0_LFb0;o5/P30ak420<;6/0050<35
[@32b:d0`<JY0<78Z`31bJd00P31bJh03030b:h0_lN/0;k6ZP2oajX0_/J[0;k5Z`2la:T0^lBX0;W4
Y`2e`J<0[[ZM0:B`T`80RI1g00/0OH=[071bH01OGE<0DTm:04i=A`17B3l0Bdm205aYD`1VMe/0Hg=F
03Xo;P0202d_900;02PX800R8Qd0824N028R800S8b809RPT02HY900S:B@07R<Q01dQ800g@3L00P0m
Ac`0300a=bl0;34W02T[8P0X:R00:RdS02HY800L7AH04a<<010@1P0F5`X07Ad>01/K30804Q4900/0
3@`700X91@0?3`/0=d0a02/c:@0Q9b806b4O01LN700D6AP07RHN02Tc8`0202D/700;02L^7P0`>BP0
?dXh04MD?@0L7aH05AL@024U6`0I6aD07b4J01dM6@0D4Q<00P0?2a001P0=20l03@H=00d6300<1@h0
30H@01@B5a[ooooo00H0CUY/051MLP1CGgL0Demg05=PM`1EHWH205ARL`0;05ISL`1GI7@0FFIf05UV
N01IIWT0FVIj05]XO01JIg/0FVQi05YWM`1LJGT00P1LJG`02`1NJGh0GfYo05m[O`1OJh00Gf^105i[
P01QKX40HVn206=`PP1ULHD0IW6600<0JG>700/0K7N906mjR`1`NX/0LWf=075lS@1bOHh0Lgn?07F0
TP1ePI<0MH6D07F0T`0207N0U@0;07N0UP1iPIH0NX:G07V2U`1jPYL0NX>G07Z4UP1lQYP0OXNJ07n9
W@21RYh00P21RZ002`20Rj40P8bR086=X`22SJ80Q92R08F@XP26TJ80Qi:T08RBY028TjD0RYBV0080
RiJU00/0S9NT08nIY02AVj<0TYfS09>NY02BWJH0U9jX09JPZ@2FXJT0V::[09RR[00209VS[@0<09^W
/02LYk40W:N`09fX[P2MYj`0WZR[0:2ZZ`2QZjX0Y:^/0:B[[@2T[:d0Y:b[0P2S[:T01@2S[:L0XZbW
0:6]YP2P[J@0XJfS0080XjjT00@0XZfR0:6]XP2NZZ40W:VN0P2>Vi002`1=D5@0@dE:0414A@1=E4d0
HfeN059HCP1KIEP0C5A;04]DB014CD40=C/c0080Ae5100`0HG5F05a[D@1?FdD0CEM404UA@P19D4<0
P8md08VJOP28UWh0RIN008BAO@25Tgd2079mJP0;020N8@0O72406aTM01HD5`0E4a<06AXE01dP5P0P
8QL08R@H02LZ6`0Z;1h00P0R8QH02`0L6A406AHA06=`E`1WMeh0Ae54010@4`0E61P0;cP]02lh;00_
>2P0;3@R0080;C@Q00H0;3@Q02dc8@0]=240<3HR03<i9@0f>RL?ooooo`003Oooool0101lSY@0PiFN
08FGY@23UJP208:CZP80PiFY00/0PiJX08BIZ026VZP0Qi^Y08VKZ@2<WJ`0Sj2]08nN[02AWj`0TZ2/
09FQ[`0209JR/@0;09FR/@2FY;40UZF_09NV[@2IYjd0VjZ_09^X[P2LZ:l0VjR_09j[/@2O[;400`2O
[;802`2P[K@0XZnf0:B_]@2T[k@0Z;6e0:Rc]P2X];@0Z[Je0:bf]P2^]kP0[kRk0080[[Rj00/0[kVh
0:nj]`2b^[T0]K^j0;Jk^P2g^k/0^Kbn0;^o`@2l`<80^l300;^o_`020;Zo_P080;Vn^`2j`;/0^L2j
0;_3^02ob;P0_<Bd0;c3/P2m`k<20;g4]00>0;g4]@30a[L0`<Jg0;o7]`2nb;L0_/Nf0;k6]030a[<0
`lRc0<;6/033ajh0`LN[0<78[@32b:l20<;9/00<0<;9/@30ajh0_lN/0<38Z`30b:`0`<N^0;o6[@2m
aJ/0_LJ/0;c6Z`2jaJT0^LFW0P2d_j<02`2]]Y/0YZnE08^@O@1/KF<0F5MA05EEC@19BT80@TDk04U>
?`15C3`0=CX^0080;S@Y00/0:2`S02@V800O8Ah0828P02LZ9`0[;bX0:c0[02X_:`0V:BP092LX03]4
?@0204=>A00<03Dn=P0c>c80<3L]02le:`0^=2X09BPR01`M6P0B4A00410:01DF3@0K7A0071h@0P0G
6@h02`0@40X03@`700`;1`0A40`05QTC01HJ5P0D61H04ADC014F4P0G7QH06B0E00805ah@00/05ad>
01HJ3@0J71408RDH01`O5@0M8QL08BHL01/N5P0^=2L0<CHX02/_8`0202DW7P0602HT7`0V8ah07aTI
01TC5P0D3aD04@dE6_ooool01P1:F6X0CE]`051NM01AGgH0DUmg05ARM`80EF=e00H0EVAe05MUM01H
IGD0FFIf05YWM`1KJ7P205]XN@0305aZN@1JIgL0FfMh0080GFUm00/0H6V0065[Q01PJh80HFb3065]
P@1OK7l0HFio069`P@1TLH<0IG:506QcR00206afR`0306efR`1^N8d0LWb@0080LgfA00L0LGbA079m
TP1dOi80MX6C07J2TP1fPY<0N8:F00<0Mh6E00X0N8:H07Z3V`1jPi/0NhBK07^7V`1lQYX0OhVL0828
V`20RYh0P8ZM0P20Rj002`20Rj40PHbS08:=YP22SjH0Pi2U08>?X`23Sj40QY6R08RCY02;UZP0SINW
0080SIJU00/0SYRV092HY@2BVZH0Ti^T09>MY02DWZD0UYnU09NPY`2GXJL0V::W09RRZ00209ZTZ`0<
09^V[P2KYZl0VjJ_09bV[P2MYjh0WZR^09jX[@2OZJd0XZ^]0:B/[@2S[:`0XZb[0P2S[JX02`2R[JT0
XZfX0::]Z@2Q[JT0XjnZ0:6]YP2Q[JD0Wj^T09fYX02KZ9h0VJNK0080SI^@00/0EeaN04E8CP1:DE80
HFaP05aUE`1AEdX0DUU;04aDA`18DD@0?dHj03<h;P0203i6=P0<06AdE`1QLEH0DUi804aF@`18Cd00
ADTn07Z8L02=Wh80RIR008^JP`26Tgl0S9^30P25U7d02`0T8R<06aHK01dJ700G51H0510A01@B400I
6A<08B<H034d900g>RT0<cHW008092HJ00/071dC01LD3`1DG4P0OY1_05EPC`0L7Ah051DI038l=00c
?C80;CLY02Tc8P0202Xc8@0602Xb800Z<b00:C4O02/c8@0_>2@0<cXW3oooool000gooooo00H0NXfC
086EW@23UZ@0QIRX08>DZ022TjP208BEZ@0;08FGZP24UZ/0QIR/08RJ[P2:Vjl0S9f_08nP[P2AXJh0
TYn]09>O[P2DX:l00P2EXK402`2EX[00UZB`09NU/02HYJl0VJN_09^Y/02KZJl0WZ^`09jZ/02PZk80
XJfc0080Xjnf00`0XZff0::]^@2S[[/0Xjjj0:>^]`2T/KP0YK:h0:Jd^02X][P0Z[Fh0:be^@2/]KX2
0:fe^`0;0:ng_@2_]k/0/KVl0;Bj_@2e^K`0]KZm0;Jl`02h_/00^Kjo0;Vo_`2i`;l00P2h`;d02`2h
_k/0_<:k0;_0^02l`[L0_lJg0;g5]@2ma;@0_/Fb0;c4/@2maK80_L>d0080_/Be00/0_lNg0;o7^02o
akL0_/Jc0<36/@33ak00`lN]0<?6Z`33aj/0`lN]0<;7[`020<C8/P0<0<?8/P33b;40`/R^0<76Z`33
b:`0`lR]0<;7[P2oaJl0_LB]0;g5[@2maJ/0_<FZ0P2j`jT02`2j`jP0^L>V0;G0X`2T[YD0Oh=e07Ei
JP1QHeL0DU=;04i?A@14AS`0>che0080<cH_00/0:bdY02TY9`0S9B@09BLV02/_:`0^=2d0;cD/02db
:P0^<2T0;RhZ02l`;@0202lb;`0<02hc;@0^<b/0;cD[034i;@0^=R`0:2hW02<V8`0N7ad06adH01hQ
6P0O91X06b4E0P0F6a402`0@4`d03Q4900d@200A4P/05APA01PL5P0E6AD03a<@00lC3P0C61005AX@
00804aP<00/04aH;018D2`0@4PT04Q@<01@H400H71D05a/E01PK5P0N8aT0;3<R030g800202P]5P06
02//5`0b<1l0<2dQ02XV7`0/;2H0:2XT6_ooool01P18EVP0BeU/04mNL@1@GG@0DEed05=OMP80EF=f
00/0EfEg05QUM@1IIWD0FVIg05aXN01JIWT0FfMj05]WN`1KJ7`0FFIj05UVN`0205aXOP0;05mYP@1O
JX80H6^3065]P`1QKX00HFin069_OP1SLGl0IG:306QcQP1ZMXT00P1/Mhd01P1_N8l0L7V@075jT01c
O940LWfA07=nTP80M82D00@0M82C07F0T`1fPID0N8>G0P1gPIH02`1gPYT0N8>J07V3V`1iPi/0NXFK
07^6W01lQi/0OXRL07n7W020RIh0OhZO0080OhZQ00@0Oh^R086<X`21SJD0PHjU0P24T:H01@23SjD0
QY6T08RBY@2:UJL0S9JW0080SINW00/0T9RX092HZ@2AVZT0TY^W09:LY@2DWZH0UZ2V09JPY`2FX:H0
VJ>X09VSZ@0209ZT[00409^T[@2KYJl0VjF^09bW[P80WJN_00H0WZR_09nY[`2RZk00XZ^]0:>/Z`2T
[Z/20:>]ZP0;0::/ZP2R[JX0XJbY0::]ZP2T/:`0XZj[0::^ZP2PZZL0WjZT09fYX@2LZZ000P2FY9X0
2`1VK6`0ADM<04a?C@28Ugd0FEm@05AIBP1JHU80C5A803m6?P0d>3@0:RdZ0080=CXa00X0Hg=H06Ad
E`1FHTX0D5U404]B@@13B3/0Lh1W09:UQ02;W800SIj30P29V7l208^KP00;034a;P0K5aX08b4N01/I
5`0@3@d03@T:010=300d>2X0FfM<061/D`1:DT400P0X:b@02`0T9Ql08R8O05YTDP1jRg00KWeV038g
<@0D4aH0?4Lk038j<00Y<BH09RhP00809RhO00H09blN02Tb7P0X<ah0:S<O02hf8@0b>2@?ooooo`00
3Oooool01P1jSI<0PIFM08>FY025V:P0PiBX08:CZ080Q9FY00/0QINZ08BFZ`25V:`0R9Z^08ZK[`2<
WJl0Sj2^096Q[P2BWjd0Tin^09BP[`0209FQ/@0;09FR/02FY;00UjF`09RU[`2IYjl0VjV`09^Y[`2N
Zk00WZZ`0:2[/P2Q[K<00P2S[kH0302R[KH0XZfi0:>^^`2S[[X0Xjjg0:Ba^02U/[P0Y[Bh0:Rf^02Z
]KP0[;Fi0:be^P80[KFk00/0[kNm0:ng^`2a^K`0];Zm0;Fi_02e^[d0][c00;Rn`02i_[l0^Kno0;W0
_`020;S0_@0;0;Ro^`2l`[/0^l2h0;c2]`2oa[L0_LFe0;g4]02naK80_<Ba0;g5/P2m`k@00P2na;D0
2`2oakL0_lNh0;o7]`2na[<0`<Ja0<?7/033ajd0`lJ[0<?7Z`33ajd0`/N_0080a<Rb00`0`lRb0<?8
/@32b:h0`LJ[0<?8[033b:d0`/N^0;o5[`2ma:d0_LF]0;g5Z`2laJX20;[3Z@0;0;[3Z02i`jH0]L2S
0:B^U@1oPgD0MGUZ065SE`1BDd/0CTm504A6?00k?SD00P0c=Rl02`0[;BT0:BTW02<U900U9bH0:bl[
02hd;@0_=B`0;C8Z02h`:@0^;RX0;c0]0080;c8_00`0;S<]02hc:`0_=B/0<CT]02hf;00X;RL08bHS
01hO7@0K7AP07R4J01lT6P0K8AD201HK4@0;010C3@0>4@T03A08014B2`0E614061`F01DI5@0?4a00
3a<>01<H400E6Q000P0C60`02`0C5P/04Q@;010B2@0B50`051P@01PL5@0G6aD061/F01hS6@0/<b80
<3LP0080:2dF00H0:b`G038`7`0`;B40:RHO02`/9P0X:R@Jooooo`0604QFJ01;FF`0Ceia051MM01A
GG@0Demf0P1EHgH02`1GIGL0F6Ee05UVM@1JIWL0G6Qh05YVN@1KIgX0FfMk05]XO01IIWX0FFIk0080
G6Qn00/0GfV105mZPP1PJh<0HFf3065^P01QKWh0HVmn06=aO`1ULX<0J7>606YfR@0206agS@0606mh
S`1`NI00LGZ@07=lT@1bOI40LgjB0P1dP9@0101dP9<0MH2C07J1U@1hPiL207N1UP0;07N2V@1hPiX0
NH>K07V3V`1jQI/0NhJL07b7V`1nR9`0OhNL0829WP1oRYl00P1oRZ40101oRj80PHbS086=Y@21SZD2
08B@YP0508>?Y@26TJ@0R9:U08ZEY`2<UZL00P2=UjL02`2@V:P0T9RY096JZ@2BVjL0TYbU09BNYP2F
X:H0UZ2W09JPYP2IXjP0VJ>Y0080VZB/00@0VjB]09^U[`2KYJh0W:N^0P2MYjl01P2NZ:l0WjV_0::[
/02RZjd0Xjb[0:B^Z`80XjfZ00/0XZbZ0::]ZP2Q[:T0XZfZ0:B`[02R[Z/0XZjZ0:2ZY`2OZZ@0WJVQ
09bZX00209JTVP0;06I/K015Ad`0C4m=08RGO@1IGe00E5U:05YRDP1<E4P0?dHn03@h=00Z;BX00P0e
>S402P1SLeP0I7AG05IRBP1@FD@0Be9104=8>`1cP6L0TZF408^LP02=WX<208VHO`80Ri^000/0<C4^
01/G6P0S8Ah06aTG010=3@0=2@X040d<03@h:P1KId`0H6aC04YB@@0202P[900;02@V7`0R8Ql0FVAB
07Z;L01^OFH0<SLa01@C5P0lAc/0<SX`02Ta9P0V;R000P0V;Ql01P0W;ah0:C8N02Pc7P0Z<al0;SHQ
038h90oooooo000=ooooo`0607b>T021TiP0PYFO08BEY022Tj@0QIFV0P27UZP02`27UjX0QIF[08BE
[025Ujd0R9V_08VL[P2=X:d0Sj6]08nO[@2@Wjd0TJ2`0080TZ2`00/0TZ2_09FS/P2IYK<0VZJe09bW
]P2JYkH0VZRd09fZ/P2OZk40XJ^b0:6//`020:6]]00<0::/]@2QZkH0XZbj0:>/^`2S[[/0Y;2l0:Fa
_02U/K/0Yk:l0:Zd_@2[];`0[;Bm0P2^]Kh02`2^]Kl0[kNo0;6h_`2c^kl0];bn0;Fm`02f_L40][jo
0;Fm_@2d_K`0]/2m0080][nm00/0][jl0;W1_@2h_kT0^Kjg0;c2]P2l`kH0_LFg0;o5]`2m`k@0_/Be
0;c2]@020;c3]@0;0;o6^030a[T0`<Ji0<77]`33bK<0`lR`0<?8[`34bJd0a<R/0<?7Z`33ajh00P34
b;401@34b;80`lJb0<C7/032aZh0`lN_0080`lN`00D0`/Ja0<;6/P30aK40_lJ_0;o5[0020;k3Z@0;
0;g5Z02maZH0^/FV0;O2Y@2`^j00Z[BK09ZSS@20QWD0L7AU05MID01AE4X00P0n?ST02`0g=S<0<S0a
02`[;00Y:2T0:BXZ02`^;00]<2d0;C0[02h`:@0a<bX0:b`T00809bPQ0P0T9Ql02P0W:b80:c0V02T^
9@0X;BD09b`U02DY8`0T:B80;SLY02H_8`0L91T201DI4P0;010B3P0<3`X02`h9010C3P0E6A<061dG
01LL5@0C61404QL?01HL4@0E6a000P0C5``02`0?4`X03Q4:00dB2P0<3`L02`l7010B2`0?40/05QTA
01/N500P9AH09b/H00807Qh=00H0@4@Z024L4`0h=Bh0A4Ln02<T8@0Z<BPJooooo`0604UEJ01;F6/0
Ce]a051MM01@G7D0DUig0P1DH7H02`1EHgH0EV=e05QUN01KIG/0G6Ek05UTO01JIGh0FfIn05aXO`1K
J7d0FfMm0080G6Qo00/0GFR005iZP01NJWl0GV^005m]P01QKWl0HVmm069`O`1TLX<0J7F706]jR`02
06ahR`0<06eiS01_NXd0L7^?071kS`1bOI00Lgn@07B0TP1cOY<0LgjD07AoU01eOiD0MX2F0P1fP9L0
1@1fPIP0MH2H07N1V@1hPiP0N8BH0080NXFJ00@0NhJJ07^5V@1mQih0OHVQ0P1mRJ80101lRJ40OX^Q
07n<XP21SZ@208B@YP0508>>YP24SjH0QY2V08NAY@2:UJL00P2=UjT02`2=UjP0SYRY092JZP2@VZT0
T9^X096LZ02CWZT0TijZ09>NZ@2EX:/0V::/0080VJ>^00`0V::^09ZT/02HXjl0VZFa09^V[`2MYjl0
WjV`0:2Y[`2RZJl0XZ^]0:>]Z`2T[ZX20:>]ZP0;0:>/ZP2R[:X0XZbZ0:6/ZP2Q[J/0XZj]0:>^Z`2Q
ZjP0XJ^V0:2[Y@2NZZD00P2KZZ@02`1[LWD0BD]A04E7AP1IH540CeA704]@A01OJEP0DU]?04A;A00j
@3d0;C4`0080<3Ha00`0EfMA05m^D`1FHTX0De]704eC@`11ASX0J7EO096UQ029VWd0SIb208bIP@2;
V80208nNQ00;0410>@0M5aP09B8O01/H5@0=2PP02@L500/92@15CSh0Q9Yh07jBM01fQfd00P0j?c/0
2`13BTD0CUI?06AbH@1cQ6d0Kh1Y04UBA@0K7A/0BEE3038g;@0[<RH09bdP00809B`N00H092dN02D_
7@0V<A`0:S<N02he800`=B4?ooooo`003Oooool00`1hRhl0P9:I08:CX00208>EY00>08BEY026UZD0
QYJU08JGY`24UJL0Q9NZ08NJZ`29W:`0R9b/08VNZ`2:WJX0S9j[08fN[02?X:l208nO/00;092P/@2D
X[<0UjFc09VU]@2HXk@0V:>e09ZW]P2LZ[D0WJZc09j[/`2NZkD00P2N[;D01P2P[KD0XZjf0:B_^P2U
/;/0Y:nk0:B`_@80YK6m00@0Yk:m0:Vb_@2/];h0[KFn0P2_]kl01@2_][l0/;S10:jg_`2_^Kl0/[_0
0080/kc000@0];bn0;Fm_P2d_K`0];bj0P2e_K/02`2d_K/0][nk0;O0^@2h`;P0^l:g0;g2^02n`k/0
`<Fm0;o4_02m`[T0_/Bj0080_L:i00/0_/>i0;o4^@2n`kP0_lFf0<;7]@32b;<0`<N_0<;9[P33bJ`0
`lR/0<C7[`020<;6/00<0<?7/@31aK40`lRb0<;6/P31a[80`<Fa0<;5/032a[40`lJd0<;5/`31a;00
`<B^0P2oaJ`02`2ma:X0_/JY0;c4Y`2k`jT0^L>Y0;G0Y`2c_jL0/KbU0:2ZUP2>UXD0OXAf0080Gf1H
00D0DU1;04=1?P0k>3D0>3@`03D`;P02034];00402dZ:@0Y9b@0:bXU02/[9@809bLQ00<092@O02<U
7`0R9ah00P0P8a`01`0S:2009BdT02<[8@0S;240;c/Y02Td8`0K8aL00P0D6Q401@0A5@h0418=010B
2`0B5Ph05a/B00806AhD00@061dB01LN4P0K8QD06AlC0P0H7Q802`0B5`l03A8<00dB3@0<40/01`/4
00P;10092P@02PT400/9100>3@H051D;008051<:00H0;C4P01XI400f>Rh0G6YA01LJ4`0J7aHJoooo
o`0404IBI`19EV`0CEYb04mJM080DEeg0P1CGgL0201DH7P0EV9h05MRN@1II7X0FV=k05URO@1II7h0
FFEm0P1IIG`03P1KIgd0FfMo05]WO`1LIh40GVV205aYP01MJWl0GV]n05i[O@1PKGd0HFmn06EcPP1X
MXD0JWR70P1ZNHT0201/NHX0KgZ;071kSP1`O900LGbA079mS`1bOXl0LWf@0P1bO9800`1dOY80MGnD
07EoU@0207EoU@0:07F0U`1fP9P0Mh6H07R2V@1iQ9T0NHFI07V5V01jQIP0NhJJ07b7W080OHNM00D0
OHVM07j;W`1nRih0Oh^P08:>X`02086>Y00408:?X`25TJ@0Qi>T08ZDY`80RiFY00X0RYFX08bHZ@2>
VZX0SiZZ08jIZ@2?VZT0TIfZ096MZ@2AWJX0TYn[0`2DX:d0302DXJd0Uj>^09RT[`2JYK00VZF_09bV
[P2NZK00WjN^09nW[02QZJd0XJZ[0::/Z@80XjfZ00/0XZ^Y0:6ZZP2QZZX0XJ^Z09n[Z@2OZZX0XJ^Z
0::[Z@2PZZL0WjVV09fXY@0209f[Y00;06eeM`14Adh0@dM703i3?P12Acl0@DLo06ajI`1CGU@0BE5<
04=;AP0b=cD00P0a>3<03017DT80Dem:051JA`1?EDH0BDm403m2>`1XMV<0T:B708RHP02<Vh@0S9V4
08^HPP80Sij500/0@44k01dH700U8R4071/H01<C3`0>3`/03Pl<02T_9@1XNE`0Nhe]08>DM00205mX
F00;06]fIP1aOVh0LH1^075oK@1aPFd0HFiL03m6?@1@FdX0=3``02/b9P0W;Al00P0S:Q`01P0S:a`0
9RlM02H_700X<Ad0;CDP034h90oooooo000=ooooo`0607V<T`21UIh0Q9NT08>FY@24UjP0Q9JV0P23
UJD02`24UJL0PiJX08FHZ@26VJP0QibY08RLZP29WJ/0RIbZ08ZLZP2<WZ`0SYn_0080T9ja00@0TZ2d
09>P]02FXk@0UjFd0P2HYKD01@2JYkD0VjVd09^Z]02MZkD0WZ^e0080WZ^f00`0XJfh0:>`^@2T/;T0
YK2i0:B_^02T/;X0Xjnj0:F`^P2X/[`0Z;6l0:^c_@2]]/020:be_P070:be_02/][d0[;Jl0:jg_P2_
]kh0[kRm0;6i_P020;>i_@80];bn0P2e_Kd02`2d^k`0][jl0;Ro^`2i_kX0^[jj0;Zn^@2k`;/0_<:k
0;g3_02naKd0_LFl0080_<:l00T0_L:k0;c2^P2m`kT0_L>f0;_1/@2m`k00_LBa0;k5/@30aZh00P31
aZh20<34[`0<0<35/@2oaK80`<Ja0<76/@31ak80`LFa0<76/P30aK80`/Jd0<?6/`30`jl0_l:`0P2o
`k401`2m`jd0_<>[0;_3Z@2la:`0^lJ/0;O2Z02e_jP00P2f_jP03`2e`:L0[;NP09fUTP2MYI80SYN2
06mcH@1IFd/0De9204M3>012?CD0@3/d03Lc;@0`;BL0;BXV02TU8P0202@Q7P0<028Q7@0T9b408bPQ
020V700N91T07BDI01hU6P0Q:Q`08BXJ01lY5`0Q:QP07B@D0P0I7a402`0G7A005AX>01@I3P0G6Q00
5aX?01TL4P0J7Q@061hD01TO5@0L8aP072<G00806R8G00/051hC00hF3@0=50`0318;00X?1P082`@0
20T400P80`071`<01`D300H70P0200H80@0600L9000>4PD05QX:01hT400N8`l061/;6_ooool01017
EfT0BU]^04iNL`1AGG@2055MM@80Demf00/0E5mh05APNP1EHG/0EV5i05MRN@1HHgT0FFEj05QUN`1K
Igd0G6Mo05aXO`0205]WO`0;05aXP@1NJH<0GFZ105i[O`1PKH00H6b0065]P01RL840IG>106UhQ01/
NhH00P1]NhP02P1]NXX0KgZ;075kSP1aOI00LWb@075lT@1bOI40LWjA079lTP1cOY<407EoU00;07N1
UP1iPiP0N8:I07N1V01gPYT0N8FK07Z6VP1iQYP0NXJG07b8V@1lR9X00P1mRI/02`1nRid0OX^N07n<
WP1oS9l0PHfP082=X@21SZ80PhnS08BAXP27Tj@0RIBU0080RYFV00/0RiJW08bHZ@2<VJP0SIZW08fI
YP2=VZL0SYZW092LY`2AWZP0TZ2X09BQZP0209BPZ`0<09FQ[02FXJ`0V::^09VS[P2JY:h0W:J^09fW
[P2NZ:l0X:V^0:2Z[02QZZ/0XZ^Z0P2SZjX0102SZj/0Xjb^0::[[P2QZjd20:2/Z`050:6[Z`2PZZT0
WjZW09jZY@2LZ:000P2N[:402`1fOgh0@D9;03a0@`0h?C/0?dHo04UAA`21U7T0GVYJ04M@AP15CD@0
<SHb0080<cP`00`0A4`n04]CA01?EdL0D5M804aAA@0l?ST0I6iO09BWRP2:VX00SIf308^KP`2:VH42
096RQP0504Q;@`0H4QD081hL01XJ600F5Q@00P0B50l0100F5a409RXN059LA022UG42075oIP0;07J3
K@1hQg40MhIa07F3K`1eQ700KgiZ06=`H01SLUh0>D0e02H[8@0V;Qh00P0S:aX01P0T;1T0:34L02Tb
7@0/=R00<3PT03<i9Poooooo000=ooooo`0607fAV022UYl0Q9RT08BGY`25UjX0QIRZ0P23UZP02`24
UjT0Q9VX08JJZ026VJL0QYZW08RMZP2:Wj`0S:6]08fP[@2?XZl0T:2`0080TZ2c00/0Tj6f09>Q]@2D
X[@0UJ>c09VW]`2JYkP0VZRf09b[]P2M[;D0X:jf0::_]P020::]]`060::]^02S[KT0Y[6j0:Rc^P2W
/kX0Z;>l0P2W/[/0102Y];d0Z[Bm0:^f_P2Z];l20:Ze`@0:0:^f`02/][h0[KNo0;2h`02a^<00/KNo
0;:i_`2d^L00]K_10;Fl`@<0/kg000/0];bo0;S0`@2h_kl0^;fn0;Vo_@2i_k`0^/6k0;_2^`2j`[X0
^L:j0;W1^P020;_1_@0;0;k4_P2m`kd0_<:m0;k3_@2n`kT0_L>f0;g3]@2oaKL0_lJd0<38/`30b;40
0P2oak001P31b;80`LNb0<76/@32ak<0`lRd0<C8]@80`<Fd00@0`/Jd0<;7]@30a;<0`<Fd0P2oa;<0
1P30aK00_lF`0;o7/02naZl0_LJ^0;c4[080^l:[00<0^l6Z0;[2ZP2g_jX00P2g_j`02`2c_ZP0Yk6K
096HQ@20QG<0IVII05MEB@1?C400AdHi03hm<P0g=Rd0;B/U0080:2HQ00`09BDQ028S800Q920082HO
01`S6P0I7aD05adC01/S5`0J8A<061h?01hT4`0O9AH201lT5`0;01hS5`0L8aP06b8H01TO5P0F6a80
5a/A01XP500L8aD07bHG01hV5P0M9aH00P0K9AD02`0I8Q@05QlA01<M3P0A60/03aD700`A1@0=3`H0
30d400/;100:2PD01`T400801PT200H01PT100P<000<40804QH6014C1@0;2P4Jooooo`0604UGJP1;
Ffh0CUib04mMLP1@G740DEeb0P1DH7H02P1EHGP0EV9j05EQN@1FHWP0EF5f05QTM`1HIWX0FFEk05YU
O01MIgh305iXP00;05iXPP1PJX<0H6b405m[PP1OJgl0H6b1069^PP1TLH<0J7F406aiQ01^O8D00P1_
O8P00`1_Nh/0L7^<075lSP02075lS`07075lT@1bOI<0L7fD079mU@1cOI@0LgjC07AoU00207F1UP0;
07J0U@1gPYH0N8>H07V3V@1hPYT0NHBK07R4V`1kR9/0NXJI07Z6VP1lR9/00P1mRY`02`1nRid0Oh^M
082=WP21SIh0PXjN08:>X022SJ40PhnS08>@XP24TJ80QiBT0080RYNT00/0S9RU08ZGY02;V:@0S9ZS
08fKY02?VjH0Si^W092LZ02AWJP0TZ2W09BRZ@0209FRZ`0309JQ[02GXJ`0VJ:]0080VJ>_00L0WJJ`
09fV[P2OYjh0X:V/0:2Z[02PZj/0XJ^/0080XZ^]00D0XZf/0:B/[@2RZjh0Xjb_0::/[@020::/[004
09n[Z@2OZjP0WjZV09fXX`80WZbQ00/0PHf504A7C00k@480=CLg03Xm>01@F4/0OHab06QdH018D4D0
ATi3034e<00202h_:P0<04E:?01=E4<0DEU7059JB@1?EDL0@48j05iVE`2EZ8T0RYZ008fMQ@2;Vh@0
RYV20P2CYXT01@1HHE405Q4A01hL5`0H5Q<05ADC00804a@A00@051@A01XJ500e>b`0KWiO0P1GHD`0
2`1/NF00LX1W07>0J@1dPF/0N8I`07J6L@1^Of/0KWmZ03Y1>00Y;R@0:c8S00809bhL00H09bhJ02Tb
7@0[<al0;cHR03@i9@0c>BH?ooooo`003Oooool01P1iRiD0Oi:N08>FY@24Uj/0PiF/08FI[P80QIV/
00/0QIZZ08BHY`26VZT0RIb[08RLZP2:WZ/0S:2Z08nS[P2?XZh0SZ2_092P/P02096R]00:09:S]@2C
Xk@0U:Fd09JV]02HYk@0VZVf09^Z]P2M[;H0WZfe0:2^]P<0Y;2i00`0Xjfi0:B_^P2W/[/0Z;>j0:Rd
^`2Y]Kd0Z[Fn0:^f_`2Z][l0ZkRo0:^i_`2Y][d20:Zf`00;0:ji``2^^L80[[O00;2h`@2b^L40/kRo
0;>i`02e^/40]kg30;Jla02e^l@00P2h_lD02`2h`L@0^/;20;W1_`2h_kl0^;nn0;S0_@2j`kd0^lBm
0;W2^P2j`kX0_<:k0080_/Fn00/0_/Bo0;o4`02oa<00`LG30;o4`02oaK`0`/Rm0<77_030akT0`<Rh
0<7:]P020<?:]00<0<C;]@34bkH0`/Ve0<78]@31akH0`LNh0<37^030akT0`<Nh0<78^02oaKH0_lFe
0P30a[D02`31a[<0`lRe0<;7]@30a[D0`LJe0<76/P31a[00`LJa0;o5[`2naJd0_LB^0080_LB`00/0
^l:_0;W0[@2e_:X0[kRV0:6YU`25RWX0JFeN05aPD01@DTH0@d@m03Xj=@0203Lh<P0<03@d;P0_;b/0
:2TW02@U9@0P8b806b0N01TM6@0K81T06AlH01LM500J81D07RDI0P0P9QX02`0M91X07B<J01hU6`0N
9QX072@G01dU5P0O9aD08BXE02</5`0Q:QD082TC00807RHB00L07BDD01`S500K8Q806R4>01PN3@0H
70d05AT<00804a@:00<04A8:00d?2@0;3`P00P0;3`P01@0<40P02`l700hB200?40T030/501[ooooo
00H0BEAV04aIJP1=Ffh0C5U]051LL01CGW<205AOMP0;05APN01FHGT0EV9i05IRN01FHGL0F6Ai05UU
N`1JIW`0FfIl05eWO`1MIh000P1MIWl02`1MIX00GVR2061ZP`1NJH40GVZ0061]P@1RKh80IW>106ei
P`1_NX<0L7Z30080L7Z600`0LG^;079lS`1aO940LWfB07=nT`1bOI<0LgnE079nU@1cOYL0LWbE079m
U@1eOYL207J0U`0307EoU@1eOi<0MX2C0080Mh6E00H0NH>H07V4W01kQI`0NhJK07Z5V`1mQYh207f8
W@0;07j:W01oRid0P8bL08:=W023Si`0PXfK08>=W024Sih0Pi2P08BAXP27U:@00P2:UZ@02`2:UZ<0
RiRR08bHX`2<VJ<0SIZS08jJY02@W:D0T9bV092LY`2@WJH0TInW0080U:6Y00X0UZ2Y09NQZP2IXJ/0
VJ:/09^S[@2MYJl0WZJ_09fV[P2MYjd0WjV/102NZZT00`2OZjP0WjZW0:6[Y`020::[Z0060:>/Z02S
[:L0XZfV0:2/Y@2NZZ@0WJRR0P2N[J802`26Th/0AdY?0455A@0f=cL0>3Tf059HC01XM5l0HF]I05EN
C`11Acl0;c8_0080;2dY00`0@4<f04eC@@1BFDD0DeY704iDA016BS`0FV5?09JWQ`2<Vh40SI^508^K
QP2:VX@208jQQ`0;05]TE@0I5AH08B0K01hK600L6QP05A@B018A3P0B4Ph05QD?03Hl:P1<Ech00P0e
>2X02`0k?S40JgMO06ikI@1aOfP0N8Q`07V;L01cQV`0L85W03Dk<00/<BH0;34T00809bdO00H09R`L
02T`7P0Z<Ah0;38P030f900c>2L?ooooo`003Oooool01P1gRID0OY2N08:DY`23U:`0PI:/08BE[@80
PYJY00/0PiJW08>GY@26V:H0RIZX08ZLZ@29VjP0RifX08nQ[@2@XJh0SYj^08fM/00208jN/@0;08nQ
/P2AXk40TZB`09FU/@2FYK00V:Rc09RY]02IZ[@0W:^d09n]]@2P[;L00P2R[KP00`2Q[;H0Xjfg0:J`
^@020:Ra^P070:Vc^`2X/[`0ZK>m0:Ve_`2Z][d0ZKJk0:Ve^P020:bf_00;0:jg_P2`^;l0/[W10;>i
`@2b^L40/kS00;Fj`@2f^L00]k[10;Fh`@2f^L400P2g_L400`2h_/00^Ko00;Vo_P020;Vo_P060;W0
_P2j`[l0^/6m0;[0^P2k`KT0_<6h0P2m`[T01P2m`[/0_L6k0;g1_02o`[h0_l>m0<74_080`<Bj00<0
`<Ji0;o5]P2oa[<00P31ak803033a[@0`lRf0<;7]P30a[L0_lFh0;k4^P2oaK/0_lNj0;o6^02oa[L0
`<Jg0;o5]@80_lFb00/0`LJa0<?7/P33a[@0`LBd0<75]031a[80`LF`0<35/02na:l0_/>^0;c1[P02
0;_1/00;0;[1/02i_jl0^;j^0;Jm[P2f_Jd0[kFW0:>ZW02@UX/0NWef069TG`1DEDl00P19BT40300n
?cD0=3<^02`Z:@0U8BD081dR01/J7`0M7b407B4O01PL6P0A51803a8@00lC40804AD@00/041D>018F
3`0D6A004aT>01DK4@0D6`d04aX:01@K2@0F7P/05ah:01HM2P0201HL200;01HL2@0F70/051X801<H
1`0F7@X05a`<01HI300D5@/04a@<00l@2P0<3PX00P0930T00`0930X02`l;00/>2P0200/=2`0300X:
1ooooooooooo01Sooooo00H0Ae5W04UEJ@1<FF`0Ce]^055KL@1DGWH305=NNP0:05=ONP1DHGT0EF9h
05ISN@1GI7X0F6Ek05UVO01JIgd0GFR005aWO`80G6Eo00/0FfEo05eVP01OJ840GVR105aXP@1PK840
Hg2206QePP1_NhD0L7^6071jQ`02075kR@0<075kR`1cOHl0LWbA07=nTP1dOi<0LWjB07=nT`1bOI<0
LWbD07=lU@1cOIH0M7jF0P1dOiD02`1dOY@0MWnD07F0TP1gPY@0Mh:C07N2U01hQ9P0N8>I07Z3U`1m
QIX0OHFL0080OHJL00H0OHRL07j9V`1oRYX0PHfK08>>V`25SY`208F?WP0308J@W`25Sj40R9:R0080
RYFR00<0RYJQ08^GX@2<Uj800P2=V:801P2=VJ<0SibS092LX`2BWZ@0TIjU096OY@80TZ2V00`0UJ6W
09NPYP2HX:L0V:6W09ZSZP2LY:/0W:F/09^T[02LYZ`0WJR/09jYZ@2NZZT209jZZP0;09nZZP2PZjP0
X:^W0:6[Y02PZZ80XJ^S0::[X`2Q[:80X:^Q09fYW`2KZ9h00P2N[J402`29UHd0B4Y@0494A`0f=CL0
>3Xi05QRE@1IHU@0FVAC05ANC`1=ETT0>Cdi0080<3<_00`0?T@g04]D@P1AFDH0DEQ504]@?P16BS/0
DUU808nRP@2=WH00S9b408fMQP2<WXH208nRR00;05aUE`0I5AP08AlM01dK6@0J6QL051@A010B3@0A
4P`04Q8;03@k:@1=FCd00P0_<B402`0L61<0J7=L07B3J`1_Of/0MXQa07V<LP1fRVd0LhMX03Hm<00Y
;BD0:BdS00809bXQ00H09RXN02P]7P0Z<1d0;34M02ld800a=R@?ooooo`003Oooool01P1fRI@0OY2M
08:CX`24U:T0PI:Z07j?Z080Oi:W00/0P9BU08>FY025V:D0QiVV08NHY`26V:P0QiZX08ZLZ@2<W:X0
T9j]08jL[@0208jM/00;08fN/@2@XK80TjBb09>S/02EY;40UZFe09FU]02HZ;@0WJ^f09j[]P2NZKL0
0P2OZ;L0302PZKH0XJ^f0::]]@2U[KL0Yjjg0:N`^P2W/K`0Y[2l0:Rb_@2Y/kh0ZKBn0:^e_P80[;Bm
00/0[kJm0;6g_02a]kh0/[W00;:h`02c^L40];W10;Bi_P2g_<40][[20;Bi`0020;>i_P0;0;Bj_P2f
_;l0][fm0;Jm_P2f_Kd0]Kbl0;Nl_P2h_;h0^Kfl0;Zm^P2i_[T00P2k`;/02`2l`K`0_/:m0;k1_P2o
`;d0`<6m0<32_@2o`K/0`<>l0;o3^P2n`kP0`LJg00<0`LFd00@0`LJe0;o5]02naKD0_/Bf0P2l`[P0
1@2naKL0`LJh0;o4]P2oa;H0_/Bd0080_L>a00/0_lF`0<75[`30`Zl0_l:`0<35/P2o`k40_l>`0;k2
/@2k`K00^l2`0;Zo[`020;Rm[@0;0;Vm[P2i_Zl0^Kjb0;Rl/@2f^jh0]KV/0;>gZP2a]jX0Z:nS09nW
V@2CVh/00P25SW/0301HFTh0?CTh03Lb=@0[8bd08a/X01dH900N6b@07Q`T01/L800E5Q/0418G00hA
4`8030l>00/02Pd900hB2P0@50/0318900`C2@0;4PL03QH801<L2@0C70L04a/4014H0@0201@L0`0;
01PO1P0E6PH04aD400lA0P0@4P@04A86010A200@40/03a4=00h@3@0:30X00P072@H01P082PL03A0<
00/>300:30/030h<00`<2A[ooooo00H0BUAV04eGJP1?FVh0CeYa051KL`1AG7D2059MN00405AON`1D
HG/0Demi05EQNP80EV=k00D0EfAk05QUN`1IIG`0FfMn05]VOP0205]VP00;05]UPP1MIh<0GVR305eX
P`1MJH80HFf406EaQ@1YMHD0KWV7079mRP1aO8X00P1aNh/01@1`Nh`0LGf>075mS`1cOY80LWfC00<0
LGfB00@0LGfC07=nU@1cOYH0MH2F0P1ePIH02`1ePID0MH6C07J1TP1gPi<0N8BD07R3U@1iPiT0NH>K
07^3V`1nQY/0OHFJ0080OXJK00/0OhNK07n9W020S9`0PHjK086>VP23Si`0Q8nN08J?X027T:80Qi2Q
08RBX@0208ZCW`0;08ZFX02;Uj00RiNO08^GW`2<VJ00SI^Q08fLX02>W:40T9jS096OY@2BX:P00P2A
WjL0302EXZP0Uj:W09RRY`2IXZP0VJ>Z09ZTZ`2KYJ`0W:N]09bXZ`2LZJX0WJZ[09jZZP80WZVX00/0
X:^Y0::[Z02RZjD0XJbT0:2/Y02P[J@0WZ^T09j[X`2O[:80WJZP09f[WP0209f]W`0;08fKT01:CE80
@4A703Lh>P0g=cP0D5I<04iDB@1EGU00C5I804aGB@15CT<00P0e>c@03010AcX0BE=104eG@`1?F4@0
Be500454>011A3T0Rien08bNP@2:Vh40Rib408JIPP80RYj400/0HFaL01dJ7P0R82007AdL01XJ5`0G
5a<05QHA01@E3P0D5Ph09b/N05e[B`0203i2;P0;02@R701VLed0M8E^06inKP1dQG@0NHae07Z=L`1h
Rfl0?dHl02T]9`0`<RP00P0];R@01P0Z;240:RhN02/`7@0]<ah0<3HQ03<g8`oooooo000=ooooo`06
07B:T@1jSiP0Oi:O086BY020TJL0OXnX0P1nTJT0101nTJH0PIFU08>FYP25UjX208NI[00508NJZ`29
VZX0RYZY08bLZ`2=W:d00P2?WZl0102>Wk40SYnc096Q]@2AXK<209BQ/`0509FS]02HYKD0VjVg09jZ
]`2NZKH00P2OZ;L0302PZKP0X:Vf0:6Z]02SZk<0YZjf0:R`^P2X/K`0Z;6m0:Zb`02Z/l80ZK710:Zb
`@80[;;200<0[kG20:ne`02a]kl00P2b^<401P2c^<80/[S10;>h`02f^/80]k_40;Bj``80/kS000/0
/[S00;:g_`2d^Kl0];[00;Fl`@2d^kl0]KZn0;Jk_`2i_/40^;fn0;Rl_0020;Vl_0050;bn_02m_kh0
_ko00;jm`02o_[l00P30_l001030`<00`<6o0;k0_@2n`Kd20<33_@080<35_@2oaK`0_L:j0;g2^P2l
`[L0_/>g0;g0]@2n`[D20<;5]`0:0<33]@2o`[@0_/>c0;k3/`2n`k80`/Fc0<;4]030`kD0_l>f0;g1
]P80^l6e00<0^[nd0;[0]02j`;800P2i_[402`2h_K00^Kfa0;Zo/`2g_K80]kba0;Jk/02c^:h0/[V_
0;:i/02_]jd0[KFZ0080Z;>U00`0VZ:G06QVK01CCeX0>31202PP<P0V7b`08A/U01dG7`0G4aX05a<I
01@D600A51H2010C4P0;014D4@0?50l03a<>00dB3@093PT01P`600XA200C70`04Q`8018L1P0B6`<0
0P0B70<00`0D70D051X5018F1@02018D1`06014A1P0?3`P04A4:018B300@4P/030h80P0:3@H01P0:
30H03A4;00d@300<3P`03Pl>00l?3A[ooooo00H0B55S04aEJ01@FVl0D5]b055KM@1AG7L2059LN00;
05ANNP1DGgX0EF5l05IRN`1FHg/0EVAk05QTN`1IIG`0FFIl05]WOP1KIgd00P1JIGl02`1KIX80GFN3
05mXQ01OJH@0H6Z406=^QP1WLXH0JWB706mjRP1cOX`0Lgn<0080Lgj<00X0LWf=075mS@1`OHl0LGfA
07=nTP1bOY80L7f@06mlT01aOi80LWjC0P1dOiD207=oT`0:07F2T`1ePI80MH6B07J2TP1gPiD0NH>I
07Z3W01jPih0OH>N07n6W@<0P8NL00P0P8VL082:W020RY`0P8bK082>V`22Si`0Q8nK08B>V`80Qi2N
00h0R9:N08ZEX02:UJ00RiJQ08bHXP2;V:00RYNM08bIW@2=W:00SY^Q08nKX`2?W:D0TIjW09:OZ@80
TInX00@0Tj6Y09BRZ@2HY:X0VJB[0P2HXj/01P2IY:`0VjJ]09bXZ`2LZ:T0WZZZ09jYZ080WZVW00/0
X:^V0:6[X`2R[:<0XZbS0::]X`2Q[J@0WjbS09j[XP2MZj40WZ^P09f[W@0209f/W00;09:QU01<CU80
?T5603Hh?@0a<C<0CeE:04Y?A@19CTD0ATi204]FB017DT<00P0d>c00300j@cD0B5<n04YE?P1;ESd0
Adhi03/m<00c=2/0P95d08fPPP2:Vh40RYb508FHP`80R9b500/0JgYY01lO8`0T8b<08B0N01hN600K
6a@06QXC01LI4@0I6Q<082@J02le9`0202lb:00;0418>P1aPfP0MHM^0762KP1dQG40NHae07b>MP1m
SgD0B51502/]:00d=bd00P0_<BH01P0[;B80:B`N02P]7@0/<B00;c@S034g9@oooooo000=ooooo`06
07J<T`1lTYX0OiBO086DXP1oTJ<0Oi6T0P1nT:D02`21TjP0PiFY08:DZ025UJ/0RIV_08ZI/02;Vk00
RYZ]08ZH[02<VZh0Sib_0080T9f_00/0TYnb09>Q]02EX[D0UJ>e09BR/`2DX[80UJ>c09NT]02JYkH0
W:Vg09fX^00209jW^@0<0:2V^P2RZ;T0Y:Vi0:>X]`2W[;T0Zk2n0:^a`02Z/L00Zk;00:fd`@2//l40
[K?40P2_]LH0102_]<@0[[?20;6e`@2c]l820;>f`@050;>g`@2d^<40]KO00;Jj`P2e^/800P2c^L40
2`2d^/80]KW20;Fi`@2f^l<0^;k50;Nla02f^/80][[00;Rm`02j_/00^kno0080^kjm00/0^knk0;bn
_02o`;h0_kjn0;jn_`2n_;h0`;o00<2n`@30_/00`;no0;jo_`020;o0_`090;o1`02o`[l0_<6l0;c1
^`2l`KT0_L2f0;o0]P30`KH0`L:e0080`L>e00d0`LBe0<74/`31a;<0`<>b0<;3/`30`[40_l2b0;o0
]P2m_kP0^[jg0;_1^@2k`;L0^[ne00<0^[na00/0^Kj`0;Rn[P2h_Z`0^Kj^0;Rn[`2h_Jh0][Z^0;>h
[@2d^K00/[R^0:nfZ`020:jeZ`0<0:ff[@2RZZ@0V:6J065RJ00c;S/0>cHk034Y:`0W7R808QTM01hH
6P0I5AP061LH0P0H61T02`0G61L04Q<C018D500@4Q8030`=00/;2`0=40d04QL?01@J3P0D6`d04Q/;
00803aP700/041P601@L200C6PT05AX<01DI3@0E5``04Q<:018B2P0A4@X04Q<;010B2@0200d@1P06
00`?1@0=3`L03a0;010@3@0?40h03a0=6_ooool01P19DF@0Be=W04iHK01?FG00D5Yc055KMP80DE]g
00/0Deej05IQO01FHWd0EV9m05ERN`1FHW`0F6Al05UVO01JIWd0FVEl05]XO@0205aXOP0;05iYP01P
JH40H6R006=[Q01TK8D0I6j506MbQP1XLhL0KGR:079nS@1fPXl00P1hQ900301fPHl0M82@07AoTP1c
Oi40LgnB07=mTP1`Ni40LWbB07=oT`1bOi80LWjB07B0U080LgnB00/0MH2B07B0T@1eP980Mh>D07J2
U01gPYL0N8:I07Z3V`1lQ9d0OXJN07n8WP0207n8W@0807n9W@21Ril0PHbO086=W`20SIl0PHjM08B@
W@25T9d208NAW`0>08RBX029U:80RIBR08ZFX`2;Uj@0RiRS08bHXP2<VJ00SY^R08nKX`2@VjD0TIbX
09:NZP2CWj/209>PZ`0<09FP[02EXJ/0Uj>/09RT[02JY:`0VZF[09VTZP2JYJ/0W:R[09fYZ@2OZZT0
X:^X0P2R[:L02`2RZjH0XZ^S0:2[X@2R[:00XjjQ0:6]X@2Q[J80XZfR0:2[X@2PZj80X:bP0080Wj^L
00/0VZRH05EGF@11@TH0>ci0038b=019CT@0CU=604U>@`18CT<0CeY;04=<?`02034f;00<03Dk;P1A
GTD0CUY104eF?P18CST0?T4c030_:P1hQVh0Sj6508ZKP`2=WXP0RIZ50P2;WHL02`1oSg`0:BT]028P
8P0Q7ad08B0H01hM4`0I6@h051D<01HG3P0P91P08B@J00807b0J00/08B<N06amHP1fRFd0LH5Z07R8
L01mSG@0OY1f08BEN01FGTh0;c0Y03Pj<@02038f;P0602da:@0Z;B@09b`O02`a8@0_=BD0<SLX3ooo
ool000gooooo00H0M8NC07fAW@1nTJ00P9BU07jAY01mSj4207j@X`0;082BYP21TjP0PY>Y08BD[027
UZl0QiF_08ZH[`2;V[40Ri^`08fJ/02?V[400P2AW;802`2BW[<0UJ6e09JQ]@2EXKD0UJ:d09RU]P2H
Y;@0VZJe09VU]02IY;@0VjJg0080WJJi00`0WjJj0::W^`2UZ;`0YZVm0:NZ_P2XZkh0ZJg00:^_`P2/
/L80[KC10:fd`P2^]<<20:nda00;0:jda02_]L<0[[C10;2e`@2a][l0/[Jo0;>g_`2b]Kl0/[Jn0;Bh
`02d^L000P2b^<00102d^L40][[10;Ni`@2g^L420;Rk`@050;Nj`02g^L00]kZn0;Rl_P2j_[d00P2j
_[X02`2j_kT0_<2j0;c0^@2m_kT0_;ji0;Vi]P2n_[X0_[nk0;jn^`2m_K/0_[nm0080_/2n00`0_Knn
0;bo_@2l`;/0^kni0;_0]`2l`;@0_/6e0;o0]030`;H0`<6g0;k1]P2m`[@20;o2/`070;o2/@2o`Jl0
_Kn]0;bn[P2m_[40_;je0;Zo]`020;W0]`0?0;[1]@2j`;<0^Kja0;Vn/@2h_:l0]kb]0;Rm[02h_j`0
^Kn[0;VnZ`2g_Jd0]kb_0;Jj[P2d^Z`0/kNZ0080/[N/00`0[kF/0:feZ`2[]:P0X:ZM07b0MP1/KF80
<bT[034W:00/8B<09AdN01lG6@0L5QL201/G5`0;01/G5P0H51@05A0B01@@4P0C3a403@/<00h>3@0D
5Q405adC01LM4@0G7Q400P0F7@h02`0G7Pd05Qd<01<I2`0D6Pd051T>01<H300B5@`03a8;00lA300A
50d04QD;00803a<700H02`h300/;0P0<30@03@d500`=1P0>40PJooooo`0604MAI@19DfP0C5Q[04iI
K@1?FW00D5Yc0P1AFgH02P1BG7P0Deei05EPN`1FHG`0EF5k05IRN`1HI7/0F6Ek05UUNP1IIWX305YW
NP0;05]WO01MJ7d0GVUm069/PP1SKH<0I72306IcQ@1VLh@0JGF6071nS01fQI000P1hQi<0301gQ980
MH>B07B0TP1cOi<0LWjD07=mU@1aOI@0LGbC075oU01`OY<0L7jB079nTP80LWjA0`1eP940201gPi40
N8FB07R4U01hPiH0NXFI07f6V`1jQ9/0NhJN0P1jQ9d02`1kQYd0OXVP082:W`20RZ00PHZP08><X@24
SZ00Q8nP08J?X025T9h0QI6O0080QY:P00/0Qi>Q08RDX@2:UZ<0S9RU08fJY02=VjD0SibV092MYP2A
WJP0TYfZ09:NZ`0209>OZ`0<09FP[@2FX:`0UJ2/09RS[P2JY:h0VZF^09ZU[02JYZ`0W:R[09fYZ@2P
ZZP0XJ^X0P2RZZP02`2RZjP0XZ^U0:6[X`2QZj<0X:bR09n/X`2Q[:@0XZfU0:2/Y02OZj@0Wj^S0080
W:ZN00/0W:bL05iRH@14ADT0ADI603He=`0o@C`0Ad]004aBA01=ETL0DUe=04]FB00203Hn=00<03Lo
<@1JJDd0EfE:051KA01=E400ATXl03Hg<`1`O6X0U:N>08ZIQ02<VhL0RIR60P2<VhP02`25Th00;2Xa
024N8`0S8Ql0820G01dN4P0K6`h04a@:01<E2`0O8QL08BHL00808bTN00/05ADA05i/E01fR6/0KGiV
07R8K`1nSg@0PI9g086CMP1CFT/0=3D_03Xm=00203Hk<006030e:@0[<2<0:RhP02hb8@0c=bH0<cHV
3oooool000gooooo00H0MHJC07Z<W01mSj80OHnU07b=Y01kS:8207f?Y@0;07nAY`20TZP0PI:Z08BD
[026UJd0QiF_08ZI/@29V:l0RiZb08jL]02?WK@00`2@WK@02P2BWkH0U:6g09FQ^@2DX;L0UZ6g09NS
]P2HY;H0Uj>c09VU]@2JYkL209fX^P0<09jW_02QZKd0XjRm0:F[_`2UZKl0YJW00:FZ`02VZl00Z:g0
0:V_`@2Z//80Zk;20P2/]<@02`2]]<@0[[G30:be`@2^]l40/;W30;2i`@2`^<00/KS00;6g_`2b^Kh0
/[Vm0080/[Vo00/0/kW10;Bj`P2e^<40][W20;Rj``2g^L80^;[10;Rj`02g^[l0]kbn0;Ro_P020;S0
^`0;0;Nn^02h_[T0^;jh0;Vo]`2i_kP0^[jj0;^o^`2j`;`0^l2m0;^n^P2k_kX00P2k`Kh0302l`L40
^l6o0;[1_02i_kT0^Knh0;_1^@2l`[T0_L2i0;o0^P2o`;`0_;jj0;^o^P80^l2h00/0_L:f0;k1]02m
`;@0_<6d0;^o]@2l`;T0_<:k0;W0^`2h`;T0]l2g0;Jn]P020;Nl]@0;0;Nk]02f^K80][Za0;Jj[`2g
_:l0][^^0;Fi[`2d^k40];Za0;:i[`2b]jh00P2a]Zl0302_]K00[KB^0:^bZ`2Z]:P0ZK>T0:2YV@1C
CDd0>2la03<[;00^9BH09ahO02DM7P808QXM00/07QLJ01XE5`0I4aH05a@I01HC5@0@3`l030d;00lB
2`0C60d05adA01XQ4`0201`S4`0;01/Q4@0G7@d051X=01@J3`0B60h04AH<010D300=4@X03a@<014E
3`0?50X00P0?4`P01P0>4@H03Q0500h@1@0>3`@03Q0400lA1A[ooooo00H0ATmU04UCJP1<F6h0CEU_
04iIL@1@FW<2055LM@0;05=MM`1CGWL0EF1i05MTN`1FHWX0EfAk05UUN`1HIGX0F6Ai05UVNP1JIgX0
0P1KIgX02`1JIg/0G6Ql05iYOP1PJX40I6n606EbQP1VM8<0IWB106MeP`1/NhL0LH:=0080M8FA00`0
M8BA07>1T01bOhl0LGf@075lT`1bOYD0LWjF071mU@1bOiH0LWnE079nU@1cOi@207=oT`0;07F1TP1f
PY40MhBA07N4T@1iQY40N8B@07R3T@1jQID0O8JH07^6VP1kR9d00P1kQYh0101lR:40OXVR07j9X@1o
RZ4208><Y00508B=Y026Sj@0QXnS08JAX@26TZ000P27Tj402P28UJ<0RYJS08^GY02;V:@0S9VV08ZH
YP2:VJD0SI^U08nMY`2AWJT3096NZ`0<09:NZ`2CWj/0UJ6]09JR[P2HY;00VZF`09ZV/02LYk00W:J]
09bWZ`2OZJ/0WZRZ0P2OZJT02`2PZZT0XZ^X0:>/Z@2RZjX0XJbY0:2/Z@2Q[:T0X:bX09n[Z02PZjT0
WZZV0080VZRQ00/0Vj^O06E/JP11@TL0@TE303@d=00n@C`0AD]204eFBP1AG4h0Dem@04iKC00203e:
?00<03Y6=@1JK500FFQ<05=PAP1<ET00@TLj03Xk=`1ePfl0UJR=08^KQP2;VXP0R9J50P2;VXH02`24
Th00;R/b020K8`0S8B407QhG01XJ400H6@d051H;01TK400W;240;cL/0080;SDZ00/0:BhU05aZE01c
QF`0KWmX07B5K@1kS7<0Oi1g082CN01?F4`0=CTb03Y1=@0203Dk;@06030f9P0]<R80:c0O02ld8P0c
=RD0<cLU3oooool000gooooo00<0N8VF07b>WP1nTJH00P1mSjP03P1kS:L0OY2W07j@Y`20TZL0P9:V
082AY`24U:/0QYB/08NE[02:VJl0R9N]08VH[@2<V[00SYfc0P2?W[@02`2>W[@0Sijd096P]P2BX;L0
TYng09>P^02CWkL0U:2f09FR]@2IYKH0VZJg0080V:>h00H0Uj>g09bV^P2PZK/0XJVk0:>Z_@2TZKl2
0:BZ`0040:F/`02V[L00YZo00:R``P80Zk?300/0Z[;30:^b`P2Z/l40[;G10:jg``2`^<80[kRn0;6h
_@2b^;h0/[Vo0;6h_@030;2h_P80/KW100P0/[W20;Bj``2c^L<0];W10;Jj`P2e^/80/kVo0;Fl_`80
]Kfm00<0]Kbk0;Fk^P2f_K`00P2f_[d01P2f_;/0]kfk0;Rm_02i_kd0^Kjl0;Zn_@80^Kjm00X0^[o0
0;Zo`@2h_kh0^<2l0;No^P2h_kX0^;fi0;Vm^P2l_Kd0^kbn0P2j_Kl20;Vm_@040;Vm^P2i_KP0^;bg
0;Vl]`80^Kfj00D0^;nl0;Vo_P2j`;d0^;nj0;Jm^0020;Nk]P0;0;Rl]P2g_;D0][ff0;Fl/`2e_K<0
];bb0;>k/P2c_;<0/[^c0;6i/`2a^;800P2^]K00302[/jl0Z[:^0:Ra[02X/Z/0Y[2Y0:NbZ02?UHh0
IFAU03`e>`0j<S<0=Bh_02lX;0809b0X00/081/T02DR:@0X9R/06QTR01DF7@0?4A<02`d=00/=2`0>
4P`051PA01PN5P0201/Q5`0;01/P5P0G6a405QXA01HJ500@5A003Q8=00lC3@0@50d04AH?018F3`0?
4`/00P0=4@P200d@2@0400hB2@0>4PP030h400L80A[ooooo00H0Ae5V04UDJP1;EVd0CEM`04mJL`1A
G7H2059LM`0705=MN01DGWT0EEmi05IPN01FHGT0EV5j05MRO00205QTOP0?05QUO@1IIW`0FVMl05YW
O01JIG`0G6Mo05iYP@1OJh<0I6n706EbR01VM8L0IWB606MeQP1XMXL0JgZ90080KWj<00`0L7n?079o
T01bOi40LWjB079lT`1aO9@0LWfD075lU@1cOYH0M7fG079lUP1cOYH207=oU@0;07B0U@1ePI<0N8FC
07V5T`1hQ9<0MhBB07N3TP1hQ9@0NHFF07^7V@1kR9`00P1lR9d0101lR9h0NhNO07b6X01nRJ42086;
X`0508><Y026SjD0QXnS08N@X028Tj000P29Tj402P29U:40R9BQ08VEX`29UJ80RYJQ08ZFXP2;Uj@0
SYVU092JYP2BWJP309>MZ@0<09:MZ@2CWjT0UZ6Z09JPZ`2GX:h0V::_09VS/@2KYK80WJJ`09jX/02O
ZJl0WZR]0P2NZJ/02`2PZZX0XZ^[0::/[02R[:/0X:bZ0:2/Z02OZZL0WZVV09jZY`2NZjL0W:VT0080
VJNO00/0W:fO075kL`0l?T00?D4m02la;`13BD00BeA904aFB`1EHe@0Cee?03m:?P0203E0=00<038k
;`1IJe00FV]>059PAP1;Ed00=cd`03<e;`1fQVd0UJ^<08ZJQ@2;VHP0RYN70P2;VXP02`23TH00<c8f
01/F7@0O71l06aXH01/I500J6A<05aP@01`N500]<bH0A4lm0080=Slb00/0BUM7061`G01^P6T0LH=[
07>5K`1fR7@0NXaf07^>M`1BGU40=cde03U0<`0203@l;P06030f9P0^=280;38R02dc8P0b>2H0<CLU
3oooool000gooooo00H0MXJI07Z;X01lSJL0OHjZ07f=Z`1kRZX207b=Z00;07j?Z01nSjL0PI2W08BB
Z@2:Ujh0RYN_08VG[P2;VZl0SI^_08jL[`2>Vk000P2>W;<02P2@WkH0Sine08nP]02BXKH0U::h09BQ
^@2CWkP0Tijg09FP]@2HXkL309ZU^@0<09RT^@2KY[/0WJNj0:2W^@2QZ;/0XZNn0:J[`P2T[<@0Xj_2
0:>/`02S[;h0YJjn0P2W[kl02`2X/<00ZK;00:Vd`@2[]/40[;Bn0:fd_P2`][h0/[No0;:f_02b]Kd0
/[Jn0080/KO000/0/;O20;2h``2`^L80/KO20;:h``2`]l<0/;K10;6h`02d^L80/k[30;Bj`P020;Bk
`00;0;Bl_`2e_<00][k10;Jn`P2e_<00][bm0;Nl^`2h^kT0^Kbi0;Vm^`2i_;/00P2j_;X0302k_;`0
^[jn0;Vn`02g_[l0][jl0;Jn^P2g_K/0^Kfl0;Vl_@2i_Kh0^[fm0;Vm_@80^;^m00/0^;^k0;Zm_02h
^kT0^;bg0;Zm^@2i_;X0]k^j0;Jj^`2g^k/0^;bj0;Nk]`020;Nk]0060;Nk/`2d^k40/[^`0;:k/@2c
_;<0/[bd0P2a^k400`2`^:l0/;Ra0;6i/`020;6i/@0<0:jg[`2]]:`0Z[6/0:Vb[@2X/Zd0Yk6/0:J`
Z@2KYId0Kg9a051=D@1=Bdd0B4E90P0e<CX02`0X9Bl0:R/a02/]<P0N82L06ahT01PK700C5Q@041@@
014D3`0D5a405a/E00807AlI00/071dI01TI500I6A<06QdH01HI5P0E61<051LB01@H3`0D6A005ATA
018E400200hA300600`?2`0?4Pl04AD@00dA30082`H010D16_ooool01P19DfL0BUI[04aHKP1>Efl0
CeUb059MMP80E5ih00X0Deai05EMN`1FGgX0F61i05MQN@1HH7T0Ef1j05URO@1HHWd0F6An0`1IIGl0
2`1KIX40GFN305iXQ@1OJXH0HVj906AaRP1XMH`0J7J<06UfS@1YMX/0JgR;0080KW^=00P0L7b?075n
TP1`OI80LGfA075lT01aNi80LWbC07=lUP<0M7fI00h0LgfI07AmU`1dOIL0MWnG07J0UP1eP9@0Mh:E
07J1U@1gPiH0N8BF07V4U`1iQIL0NXJI07^8V`80O8RM0P1nRYl02@1nRJ00OhZR07n:X@20Rj40PXfQ
08>?X025Sj00Qi6N08RAWP0208VDX00;08VDX@28Tj00RIBQ08ZFXP2;UZ40S9JR08jHXP2?VZ<0TI^T
09BMY@2DW:H00P2EWJL0302EWZX0U9j[09BPZP2EX:/0V::]09VQ[P2JY;00VjBb09^T/02NZ;40WjV`
09jZ[P80WZZ/00/0WjV[0:6[Z`2PZZX0X:ZX0:2[Z@2R[ZT0X:fV09n/Y@2OZj@0Wj^S09fZX@0209^Z
W@0;09b]W01cOW<0>cdn03e2?P0`<C00@dPn04iHBP1AG4d0Df1@0459?`0c>S400P0X;bP0300W;RH0
FFYA05]_D`19FD<0BEI0034f:P0];bP0L7eW09FYR`2:VH<0SI^808fIR080S9^900/0Q9B303Hg>P0H
4aX081dN01hL600O7AL071/F01HF4P0H6140;c@W05m]E00205UUD@0;04YDA`1HIEL0LHE_0763KP1b
Q6l0LH9_06j0K01bQfh0Df1>03Dj<00h?S000P0e>bh01P0a=bT0;cDU02hd900^=B@0<STV034h90oo
oooo000=ooooo`0607J6V@1jRj00O8fW07f>ZP1mSJ/0NhZZ0P1lSJP02`1nSjP0OXnW086@Y`24TZT0
RYN^08ZG[`29Ujh0RiZ_08fK[`2>W:l0SY^`0080SYbc00X0T9nf08nO]@2?X;@0TZ6f09BR^02DXKT0
Tinh09>N]`2EX;D0V:>g0`2JYKT0302HY;T0VjJk09fW^P2PYkT0XJRk0::W_P2VZl80Y:c40:>[`P2S
[<00Xjbn0:F^_P80Yjno00/0Z;300:Vb`02Y]<40ZkK10:bd_P2]];h0/;Jn0;:g_`2b][`0/[Fm0;:f
_P020;6g`00;0;2g`P2`^<<0/;W20;6g`P2b^<<0/;O30;2f`@2a^<00];W20;>j``2d^/800P2d^l00
2`2d_;l0]Kc00;Jn`@2f_/80]Kc00;Jl_@2g_;/0^;^i0;Vl^@2i_K/0^Kbk0080^[bj00`0^kbl0;Zn
_P2i_/00]kjo0;Jn_02f_[X0]kfk0;Vm_02i_;d0^Kfn0;Zm_@2i_Kd20;Rk_@0;0;Rk^`2j_K`0^;^i
0;Rl]`2j_KT0^Kbj0;Nk^P2f^[/0]k^k0;Rl^P2g^kL00P2g^k@01P2g^k<0];^a0;:k/02b^k40/kbc
0;:l]080/K^a00<0/;R_0;2h/@2a^K<00P2a^K40302^]jl0[KB/0:Za[02Y/Zd0Z;:]0:Na[02V/:T0
VjFM06mbL@1@CE40CD]=04Q5B@80=C4j00/0:2D_02X[<@0[;C807R0W01/N900H6a`04aHD010D400A
50l051LA01LK5@0201dO6@0;01`M6@0I6A@06ATC01XM600F6AH05APC01@G4P0D60l051T@01DI4@0B
5A000P0>4@`01P0<3`/03a8?014E400=4@`020/600@50A[ooooo00H0BE=W04YFJ`1<F6h0CUM_04mI
LP1BGGH205ANN00:05=LN@1EGG/0EUmj05QPN@1GHGT0F61i05MPNP1IHWd0F69m05QTOP<0FFEo00/0
FfJ105eWP`1NJ8D0GfZ6069^R@1TLHX0J7F<06QfS01YMXd0JGJ;06]hR`0206ikS@08071lS`1aOY80
L7fB075mT@1aO900LG^B079lT`1cO9H307AmV@0>07=mV@1dOIL0M7fG07IoU`1fP9H0MH2D07N2U@1f
PID0Mh>F07R4UP1iQ9L0NHFG07Z6V@1kR9/207b8W@80OXZO00T0OXVP07n:XP1oRZ40P8^Q08:=X@23
Sj00QHnP08NAWP28TIh00P29U:002`29U:40R9>P08VDX@2:UZ80RiJQ08bFXP2>V:80SiZS096KY02D
WJD0U9bV0080UIfW00`0UIjZ09BNZ`2DX:X0UJ2[09RR[@2IXJh0VZB`09^T/P2KY;00WZRa09nY/02N
ZZh209jZ[00;09nYZ`2QZj/0X:ZZ0:2ZZ02PZjT0XZjY0:2]YP2O[:D0Wj^T09n[X`2MZZ400P2KZYd0
2`2L[I`0Lgic03/m?P0m@Sh0<34`04=8?P1>F4X0DEa=05=PD011BCl0<cXa0080:2lX00`09bhV05UZ
D@1KKe<0BEU304UF@00a=RX0;BlX071mI`2EZH/0RYV308fKR02=VHP208bKR@0;08BDP`0f=cX061<J
020M7P0N71P07adG01`K5P0F5Q8061PA02ld9`1OKE@00P1IIE402`1:E4L0F6EG0765K`1aPfh0LXA_
0762K`1^P6`0LXM^05=PCP0e>S00>3h`0080=C/^00H0<CLY02le9@0^=2@0;SDT038i9P0a>2@?oooo
o`003Oooool01P1bPYT0MhNQ07b<Z01lS:/0OHb[07f=Z`80OHjX00/0O8fT07f>X`20T:80Pi6S08NE
Z@29UZ`0QYBX08NFY`2;Vj/0SY^]08bI[`0208bI/P0;08fL]@2>WK@0Sijb096N/`2CWk@0UJ2f09FO
]`2EWkH0Uj6e09VS]02HXKD00P2IXkL0202MYk`0WZRl09fW^@2PZ;X0XJNi0::X^`2TZ[l0Xj_10P2R
Zl403`2R[;h0YJjn0:J__`2V[kl0Z;700:R`_P2Y/[d0[;Bn0:fe_P2_][l0/;Jo0;6d_P2a/k`0/[>m
0;Be_`020;:f`00;0;6g`02b]l40/kW20;Bh``2e]l@0/kO40;2ha@2_]/40/;O00;6g`02b^l<00P2b
^L402@2b^L00/k_00;Bk_`2d^kl0];Rl0;Fh^P2g^[P0^KZh0;Zk^@020;Zj^`80^k^k00`0^[Zj0;Vj
_02i_;l0][Zl0;Bi^02d^kP0][bk0;Jk_02g^kh0^;fo0;Rl_@2i_Kd20;Rj^`0;0;Ni^@2h^kT0^;Zg
0;Rk]`2h^kH0^;Zf0;Ri]`2h^KP0^;Zi0;Jh]P2f^KD00P2e^;<0102d^K<0/[Vb0;2h/02a^;020;6i
/@050;6j[`2a^Jh0/;R]0:ng[02`]Zd00P2`][00302^]K00[KF]0:Za[02Y/:d0Yk2/0:J_ZP2V/:X0
Yk6Z0:2YY02<T9@0RHjB08>;S080EeeR00/0<3<k02DZ;P0R9RX07b4V01dO8P0M81`092PL01dP500J
6a405aP?01PH4P0201XH500;01`J5P0M6QL07A`I01hO700K7AX06Q`H01TK5`0E61<05APA01LL500C
5a400P0A51001P0=3`h03A4@00lC4@0=40d01`T600420A[ooooo00H0Ae5X04QEK@1<FW40CEY_04iJ
L01?FW42051KL`0;05=MM`1DGWP0Deef05EOMP1FHGL0Ef9h05MQN01IHg/0FFAl05UUO@1JIX400P1I
IH002`1KIH40G6N405iXQP1PJhP0Hfj:06AaR`1WM8d0JGJ?06UfSP1YMXd0JgN<0080KGZ=00`0Kg^>
06mmT@1_O980L7bA071lS`1bOY80LWfC079mU@1cOIT0LWbH07=mV01dOiP207=mU`0;07EnUP1gP9D0
M7jD07EoU01eP9@0Mh:E07R6V01hQIP0NhJK07b7W@1mR9h00P1kR9h00`1nRYl0OhbO07j;WP0207n;
X006082<W`20SYl0PHjO08B?W`26T9h0R96O0P28TZ0208VEX00908VEXP2;V:@0S9ZU08bIY02=VZ<0
SibS092LX`2BWJ<0TijU0080U9nX00`0U9j[09>O[02DXJd0UJ6^09NR[`2HXjl0VJF_09ZS/02JY;00
WJR`09fX[P2MZZd209jZ[P0;0:6[[`2QZZh0XJZ/0:2ZZP2OZjT0X:bY0:2]Z02O[JH0X:bU09n/X`2N
Zj400P2KZid02`2K[9X0M81d03m4@`12Ad<0=STg0417?P1?FT`0D5a>05=OD@10BCl0>40e0080<CT^
00`0;C@Y04eKA@1FId`0AU8n04QE@00c>B`0;c4Z06eiI@2BXhP0RIR108fMQ`2?WXX208jMR@0;08FF
PP0g>C/06QLM028P8@0L6aT06aXF01TI5@0E5Q806QhG02Ta901`QFD00P1[OV802`1WN6<0ADi707^A
N@1bR7<0HWAR03m;@P11CT<0Jh5U05MVCP0a=bX0>3h^0080=S/[00H0<cPX034g9@0a=b@0<cTV03@l
9`0b>bH?ooooo`003Oooool01P1cQ9L0N8VP07Z;YP1jRZP0Nh^Z07b=ZP80O8fX00/0O8jV07j>Y@1n
Sj<0PI:S08BEY025UJH0QYFW08FDYP28UZT0RIR/08RF[P0208ZH/@0;08bJ/@2=WK40SYja096O/P2C
W[80UInd09RQ]`2JY;P0VJ>f09ZR]@2JX[L00P2IXKP0202JYK/0VjNj09^V^@2NY[X0XJVj0::Y_02Q
Z;h0X:Ro0P2QZL003`2SZl00Y:bo0:F^`02U[/00Yk300:J`_@2W/Kd0Z[:n0:bd_P2]]Kl0[kFn0;6f
_`2a]Kh0/[Jo0;6e_P020;6f_`0:0;:e_`2b][l0/[K00;Fg`P2f^<80/kO20;:h``2_]l40[kO00:nf
`0<0/;W000L0/[[00;:j_P2c^[d0];bn0;Fk_`2f^Kd0][Vk0080^;Zm0100][Rm0;Ng_@2i^Kd0^KVm
0;Vi_02h^[/0][^l0;Jk^`2d^KX0/kVk0;>j_02d^kd0]KZm0;Fj_P2g^kh0]k^m0P2f^k/02`2e^K/0
/kRj0;Bh^02e^[P0]k^i0;Rk^02h^[P0^;Rg0;Ri^02e][D0]KJd0080];Fd00/0];Rf0;:j]P2`]k@0
/;Rb0:ni/P2^^;40[kRa0:jg[`2_]Zh0[[B]0:nf/@020:jd]00<0:fc]02[/k80Z[:`0:Va/02W/:l0
YJj^0:F^[02T[:/0Xj^[0:B/[P2QZjh0WJZ[0P2AXj002`1<E5d09RXg02T^=P0S:2h07b<V01hS7P0S
9a/09BPK02@W6@0P8QH071dG00806aLF00/071PF01lN6P0O81`07b4L01dQ7@0M8A/06QhJ01LL600G
71H06AhG01HK500201<H4@0600lB3P0:3@/02Pd900P:1`041@<00@816_ooool01P15DfP0AUE[04QH
KP19FFl0BeY^04eJL080Ceab00/0DEed055NM@1BGW@0Df1d05APM01EHGD0EV9h05MSNP1GI7`0F6En
05YWP@0205QVP@0705YVP@1JIh40G6R205iYQ01RKhT0I7::06EcR`0206MeS00@06IcRP1ZMh/0K7V;
06aiR`1^O8d0KG^>071mT@1aOI<0KgfC07:0U@1bOY@0L7fD071mUP1`O9H0L7fE075mU080LWjD00/0
LgfD07F0U01ePID0LgnC07=oT01ePi<0MXFG07N5V01hQYX0NXNM07b9W`0207^7W`0;07Z7WP1nRYl0
OX^M07j;W@1nRih0OX^O07n=W`20SIh0PhjO08J@X025T:000P25TZ002`26U:40QYFQ08NFX`29V:@0
RIVT08^JY@2<VZD0SI^S092KY02@W:@0TIjV0080TInX00`0TZ2/09:P[@2CXJh0U::`09BQ[`2FXjh0
V:F^09VU[P2KYjh0VjR^09ZX[@2JZ:`209bXZ`0609jZ[@2OZZh0X:^]09n[Z`2OZjX0WZ^Y0P2NZjP0
0`2MZjL0W:^T09b[X@0209RXW`0;09Z/WP1kRH00A4Y<03m4A@0i?3h0>d4o04I?A`1;F4d0EF=D04]G
B@0lAc/00P0g?cD0300d>2h0>3l`045;=`0j@S00?dPf03Pn<@0_<2/0H6UI09:TR028UX80S9b908jO
SP80SIn<00/0QiV703Tm?`0D41T07A`N01LE5P0E51805AHA018D400U:R80;cL[05i`EP0206n5I`0;
06=dG`15CTL0NXii07J<MP1IJE/05QXM01XN7@0lASH0BE@o03@i:`0g?2h00P0f>b/01P0d>RP0<SLU
03@j9@0f>bL0=SdX03@k:0oooooo000=ooooo`0607B7UP1hS9l0NhbV07Z;Y`1kS:P0NhbW0P1lSJH0
2`1mSJL0OhjX086BZ@22U:P0PiFW08BEYP25U:L0QiFY08RFZ`27UZT0R9J[0080RYR]00/0S9Z_08fL
/02=W:l0SYb`096M/P2CWkD0Uj:g09NQ]P2GXKL0V::h09^T^P0209NQ^P0<09RS^P2IY;X0VZFi09bW
^02NZ;T0X:Vk09jV^`2PZ;`0XJVo0:B[`@2UZl80Y:_10P2W[/<02`2Y/<@0ZK330:Va`P2Y/L40Z[70
0:bc`P2]]<40[kC00;2e_`2_][l0[[Fm0080[[Jm00/0/;Jm0;6e_@2a][h0/kNo0;:f_P2a][`0/;Fl
0;2f_02^]K`0[KJn0:jg_`030:nh_`060;2g_@2b^[`0/[^m0;Bk_P2e^kl0];Vm0P2d^Kh0402b]kh0
/kJm0;Fg_P2e]kh0][Vn0;Jj_P2d^[h0];^m0;Bj_@2d^Kh0];Rl0;Fi_@2g^[d0][Vl0;Fi_@2e^K`2
0;:h^P0;0;6h^02a^;L0/[Vi0;Fk^P2g_K/0^;fl0;Rk_02g^[X0]kVi0;Fg]`2c]KD00P2b]KH02`2b
][L0/;Ni0;2h^02_^;H0[kVf0:jh]02^][<0[[Fc0:ne]02^];80[[Fb0080[;>c00`0[;>d0:Va/P2W
[k40Y[2a0:F_/P2T[k40Y:j^0:>/[02QZZ/0Xjb/0:2/ZP2MZZX209^ZZ@0;08NFU`1YLgT0BU1J03Tm
B@0];cd0:bhh04Q?C@1II5P0=CTf02`^;@0Q8B<00P0J5Q/02`0H4aP071/J01hO6P0O8Q/0728J01XP
6@0H7QP05Q/G01LK5P0G71@05Q/B00804QH?00H02`h:00P91`0820H01PD400@20@040@0Jooooo`06
04QFIP19EfX0BeU`04YHL@1<FG80C5Yc0P1>Fg800`1@G7@0D5if059NM@02059NL`0605=NL`1EHGH0
EV9i05MTO01GI7d0FFEo0P1IIH002`1HIGl0FFIn05UWO@1LJGl0H6j406=aQP1SLXL0IGB906MeR`1X
MX/0JWN;0080JgN<0P1]Nhh02P1`OI40LGjC071nU01_OI<0L7jB06imT01^O940KgfB075nT`1aOY82
0760TP0;07:0T`1dPI@0Lh2E07:0U01bP980M8BD07J5U@1gQYT0MhJK07R5W01hQY/00P1kQid01@1j
Qid0O8RN07f9W`1lRIh0OH^N0080OHZM00@0OhbM086>W@23Sil0PhnP0P24TJ4208BCX@0908FEXP27
Uj<0RIRT08ZJY`2=VZP0SY^V092KYP2?VjL0TIfZ0080T9j[00X0TIj]092P[P2@X:h0TZ6^09>R[@2C
Xjd0Tj>/09JT[02HYjd0VJR]0P2JZJd209b[[@0;09bY[02NZJd0WjZ]09jZZ`2NZZP0WZ^X09jZY`2M
ZjL0VjZW09ZZY@2JZZ@00P2HZ:402`2JZj40NXJ204]?E00l@4H0ADa:04I=A`10Ad40D5a@05ERD`18
DT@0=S`c0080<cL_00`0;c<Y02/`900[<240:c0O034f9@0h?Bd0<C<Z069/F@2@XXD0QiF108ZIQ`2:
W8X208VLR`0;08:DQ@0a=3T05Q<L01XI7@0E51@0518?01DC3@0C4Ph09b/R030c:@1OK5D00P1gRVh0
2`1XMf<0Hg1S0720L@1gRgT0DV1D00h@5@0F5aX04Q4A02DX800_=2H0<SHY0080<cTY00H0<STW038h
9P0d>RH0=S`Y03Ll;00e>B/?ooooo`003Oooool01P1eRIL0NXnP07b?YP1mSjT0O8bW07^;YP80OXfV
00/0PXnY08>@Z`22T:/0PY>/086AZ@22TZL0Q9:X08JD[027UZh0R9R`08RI/00208NH[`0;08ZJ/02<
W;80S9Zb08fK]02>WKD0Sifd09:O]@2DXKH0UJ:h09JR^P2GXk/00P2FX[/0302HY;/0V:Bi09RT^02K
YkP0WZRi09nY^P2OZ;T0WjRj0:6Z_P2QZ/80Xj[40:B[a@80Y:_300P0YJg20:N_``2W[/80ZK330:Va
a02Y/L<0Z[?30:bc``80[[G300`0[KJo0:ff_02]][`0[[Jk0:nf^`2_][d0/KNn0;2f_P2_][/0[[>k
0:nc_02`]Kh20:nf_`<0/;K000X0/;Jo0;6h_`2`^;h0[kNk0;2h_02_]k`0[kJl0:ng_02_^;d0/KVn
0P2d^[l0302d^L00]K[20;>i`02b^Kl0];Vn0;Fh_@2d]k`0];Nk0;Bh^P2d^[/0];Vl0;Fj_080/[Rj
00/0/KNh0;:h]`2d^[P0];Zj0;Fi_02f^[`0];Vl0;>i^`2e^KX0]KRj0;>g^@020;>g^`0;0;6e^P2_
];T0[kBi0:je^02/]KL0[[Jg0:nh^02_]KL0[kFf0:je]@2[/k<00P2Y/K402@2X/Jl0Yk2`0:N`/@2U
[k00Y[2b0:Nb/P2V/K40Y:n_0:2[[0020:2[Z`0>09n][@2LZj/0W:^[09^XZ02IYZD0Qi:E07InQP1N
HG40EeU[08B?T@2:Ui<0JgAe06QcKP0f=cX201D>6P0;01PC7@0D4QP04Q0C01@C4P0E5Q8051DB01<F
4`0C510051D@01@F3P0B5@X00P0>3`L01P071`<02@L500`;1`0:20H01`D300L40a[ooooo00H0Ae5S
04UDJ@1;EW00C5Mc04aFL`1;EW4204eIL`0;04mKM@1@G7D0DUef05=OMP1CGWD0DUid05=OMP1DGgL0
E65j05ESO01HI7h00P1II8002`1HI7l0FFIo05UWOP1KJgl0Gff2065`PP1TLhD0I7>606MeR01XMXX0
JGN;0080JWN;00`0KW^>075oT@1cP9<0Lh2E071nU01^OI<0KWfA06elS`1^O8l0L7b@075lT01aOI42
07>0T`0;07:1T`1aP980LX2D07>0U@1dPID0MX>E07N5UP1hQIT0NHFL07R3V`1hQ9T00P1jQiX02`1l
R9`0OHVM07j:WP1nRIh0OHVN07n;WP20SIh0P8fM086?W`22T:00PY2Q0080Pi6R00/0PY6Q08>CX@25
U:80QIBR08NEX`2:V:H0SI^V08jLYP2?VjH0T9bX08nLZP0208nM[00<08nN[P2>W[00Sin`092O[P2D
Xjh0UJB/09JS[02EXj`0V:J]09VX[@2LZJh0WJV]0P2NZZd209fY[00909fX[02NZJ`0WZVY09jZY`2M
ZZL0WJZX09bZY`2JZJD0VJVS0080UjRP00/0VZ^R07^6P`19C5<0@4A80416A00m@c`0<SH_04QB@`1J
Ie<0Dei<03Y0=`02038g<00<02lc:`0^<bH0:S0P02H[6P0Z;A/0=cTW03@d:P1PJEL0UZV;08ZJPP2<
WHL0Rib70P28VHD02`23UH80=3Pi01DC6P0K6Q`061LG01LG500G5Q805A@@020Q6@0X:Al0HFeC0080
MXMZ00/0KgiV07>2K01bPVh0NXeh05QTF@0A4AT04@hD00l:3@0P7QP0;c8U034d9002038f900603@j
9P0d>BH0=3XV03Dl9`0f?B/0=S`^3oooool000gooooo00H0LH2E07V:X@1kS:H0O8fX07^<Z01jRZL2
07j<Z00;082=Z@21SJ/0PXjZ08:?Z`21SZT0PHjX08>@ZP24TZh0Q9>`08FF/P26Uk<00P27V;002`2:
V[00S9bc08^I/`2=V[H0SYZe08nK]@2@W;D0TYfe09FP^@2FXK`0UZ6m0080V:>m00`0VJBm09VT^`2I
XkT0VZBj09fV^P2OYk/0X:Rm0:6X_`2RZ/40WjS20:2Xa02QZl@20:6[``0;0::[`@2U[L80YJk30:N_
a02W[/@0YZk30:Vaa02[//@0[KC40:bd`@2]]/000P2]][h0202/]K/0[[Jm0:bd_@2]]Kh0[;Bm0:fc
_@2_];d0/;Fo0P2`]L003P2`]Kl0/KJn0;6f_P2a]Kd0/[Fm0;>g_P2a]Kd0[kJl0:ng_02`^;h0/;Nm
0;2g^`2_^;/0/KRk0P2c^[d0302c^Kd0];Vo0;>h_`2b]kl0/kNo0;>e_02c];`0/kFk0;>g^P2d^KX0
]KVj0;Fh^P80];Nj00/0];Vl0;Fl^P2e^[P0]KZj0;Fi_02c]k/0/kNl0;>g^`2d]kX0/kJj0;>d^P02
0;Bf_00;0;6e^P2`];/0[kBk0:fd^@2/]KL0[[Je0;2h]02`]k<0/;Ja0:jd/@2//k400`2X/Jl00`2X
/K40Z;6d0:N_/`020:R`]0060:F_/P2T[K40XZZ_0:2Y[@2PZjl0Wj^_0P2NZZh209^VZ`0909ZTZ`2J
Y:X0U9bS08nHWP2AVYh0TYfM096MV`2BX9T0L7Ud0080924]00/07ATV01PD7`0E4aX03``B01<A4`0M
71X06ALF01HF4@0D5@`05AD<018B2`0200h=2@0600X91P0:2PH03@d800`<1P071@4020D16_ooool0
1016Cf@0BE9Y04]EK`1<EG8404eFL`0;051JMP1?FgH0DEef05=NMP1CGgH0Deif059MM`1CGgT0E65k
05=QN`1HI7l00P1HIGl02`1IIWl0FFJ005UVP01KJ800GV^0061]O`1RL880IG>506IdQ@1WMHD0J7J7
0080L7n>00T0NhZH07j=W@1lRY`0MX>I071mUP1`OID0KWfC06elTP1_O9400P1aO940101cOI80LgnC
07=oT`1cOi8207>0T@0807B0U01ePI@0Mh6E07N2U@1gPiD0N8BG07V4V01iQIT207Z6VP0;07^7W01l
R9d0O8RO07f8W`1oRYh0Oh^N082<W020SId0PXjP08>>X@24Sj400P25TJ8308FBXP0808JDX`28UZ<0
RiNS08fIX`2=Vj@0SY^U08nLY`2AWJX2092M[00<08nM[P2?WK40T9na09:P[`2EXZh0UJ>_09JT[`2G
YJh0V:F^09ZW[@2LZ:d0WZR/0P2OZJ/01P2NZJT0WZZX09jYZ@2NZ:/0WZRZ09fYZ@80WZZY00<0WJZY
09bZYP2JZZ@00P2HZ:002`2IZYl0QI>:04E8C@10ADH0=3Ph02hb<00T9B<0>d8g05m]E`1IIE00BeI6
0080?dHj00T0>3db03<h;00^=2H0;C8S04mH?`11A3@0=cPa05=ICP2DYh`00P2:W8D03P2;W8H0R9R2
08RHPP27UX40ADQ501HB6P0P7b007AhK01`N6@0J6aL05aLC01HF400T9aX0Ef980P1kSV/02`1`PFD0
M8A[07J5K@1gQg40MHAa03Hi>@0L6Qd07a`L028P6P0`<B<0<C<R0080<cLT00H0<cPU03@j9P0e>bL0
=C`X03Pn;00g?2d?ooooo`003Oooool01P1]NY40NHRP07^:Y`1kRZT0NhZZ07Z:Z080O8^W00/0OhbW
082=Y`22SZP0PHfW086=Z022SjT0Q92Z08BAZ`25TZ`0QYF`08BF[`0208>E[00;08FG[@28VJl0RiZ`
08bI/02>V;00SiVb092J]02@VkH0TYfh09>N^P2FX;`00P2GXKd0202IXkd0VZFl09VS^P2LYKT0W:Bg
09nW^`2PY[d0WjFm0P2RZ/403`2QZL80XZ_30::/``2R[<<0Xjc10::[_P2TZkh0YZg00:R^`@2X[/00
ZK300:Vb_`2Z/[d0Z[:k0:^c_0030:Zc_00:0:bd_@2[/[d0Zk6l0:bc_@2^/kh0[kFo0;2e`@2_/l80
[k?10:ne`@80[kBo00D0[kBm0;2d_@2b][h0/[Bk0;2c^`020;6f_P040;:f_@2`][`0[kBj0;:f_080
/KJl00`0/[Rl0;6g^P2a][/0[kFk0:nd^`2`];/0/[Bl0;>e_02d]KX0];Jj0;6e^02b]kT20;:g^P0;
0;:i^`2c^K/0/kZk0;Bi_02c][/0/kFk0;:d^`2b]K`0/;Bj0;6e^`2a];/00P2a]K`02`2_/kX0[kBi
0:ne^02^]KH0[KFe0:be/`2/]Jl0[;B]0:^c[02]]:l0[K>a0080Z[:b00`0Yk2a0:J_/02W[k40Yjnb
0:J]/`2UZk<0YZ^b0:N//P2UZk40XZV`0:6Y/@2OZ;4209jX[`0;09ZT[02LYJ`0W:>[09fT[02JXjX0
V::X09NPYP2GX:D0UYjT096KWP2<V9H00P1YLg<02`1?E5H0=3Hj028P9`0J5al06ADK02`/:`0X9RH0
8R8P01LH500E51005A@B008051@D00H0410B00d?400<3Pd030l:00P910061@0Jooooo`0604Q@H`1:
DfT0BeE_04aEL@1=EWD0CeQg0P1?F7D02`1?FgH0DEag055LMP1CGGH0Deig05=NN01CH7X0EF5m05IQ
OP1GHWl0F6F00080EfB000/0F6Io05UVO`1GI7h0FVN105aXP01PK840H6f106=`Q01ULXH0IWB606aj
S@0207V:V`0;08:DX`26UjL0P8jS07R4W@1aOYP0L7bD06mlT@1]Ni00KW^@06ikS`1_O9000`1cOY80
2`1cOi40M82C07B0T`1eP9@0M82D07J1U@1fPYD0Mh>E07V5U`1iQIP0NhRK0080NhNL00/0NhRL07b8
W01lR9l0OHRQ07f:XP1nRj40OX^N082=W`21SJ00Q8nQ08B?X`0208F?X`0;08JAXP28Tj80R9>Q08VD
X02:UZ40S9ZS08fIXP2<VJ<0SI^T08nLYP2AWJT00P2@W:/0302?Vj`0TIf_09:O/02DXJl0UJ6]09JS
[@2GY:d0V:F]09VV[@2JYjd0W:RZ09bXZ@80WZVZ00/0WjZW09jZY@2NZZL0WjZZ09nZ[02NZZ`0WZ^/
09f[ZP2MZjP0W:^U09b[Y00209Z[XP0;09Z[W`2?X980Ad]?03/o@00_<C80:Rd]02@U9P0d>C@0GVaI
05QUDP1GI5800P1>FTT0300mACL0=C/^02hc9`0/<2H0K7]N04=8>P0j?3H0C51808jOQP2>WhP0S9f7
08jPR@80RY^300/0RIZ0055FCP0K5A`08b4S01dL700L6aX061TG01LG5@0G61<08RDK051LA@0207nD
L@0;07:3J01dQF`0MXI_07F6L01eR740KGeX05EQD@1IIU40BEA103@h:P0k?R/00P0h>bT01P0a=BD0
<SLV03<j:@0d?2X0=cl]03Ln;Poooooo000=ooooo`060760T@1hQid0O8^U07j<Z@1lRZX0NHRW0P1k
RjH02`1nSZ@0PI2T086>X`1oSJ<0OXfU07j=Y`20T:T0PI6Z08>CZ`25U:d0Pi>]0080Pi:/00/0Q9B/
08BBZP27UJ/0RiN/08bGZ`2>V:h0SYR`08jJ/`2@Vk<0TYfe09JO^00209NO^00<09NP^02GXKH0V::d
09^U]02KY;D0WJFg09fT^@2MY;/0WZJl09nV_@2NY[d0XJVo0P2QZ[l02`2RZ[h0XJVk0:BZ^P2V[;X0
Yjfl0:N]_@2U[;/0Yjjj0:R_^02Z/KT0Z[2i0080ZK2k00/0Z:nj0:R__02Z/;/0ZZnj0:bb_02]/kd0
[K:n0:fa_P2/[kh0Zjnn0:f`_P020:fa_P030:fb_@2^/[`0[K:k0080[k>k0P2^/[/0102_/kX0/;Bj
0:jb^P2_/k/20;2e_0080;2f^`2_];X0[[>j0:jc^`2^/kX0[k>j0;6d^`2a/[T20;:c^@80/KBi0P2`
];P02`2`]KT0[kFi0:nc^P2_/kX0[[>k0:nc^P2_];T0[k>i0:^a]`2//[L0Zk2f0080Zk6g00/0Zk2g
0:ba^@2Z/KH0ZK6d0:Za/`2[/k80Zk>_0:^d[@2Z/Zd0Z[6^0:Za[`020:Ra/@070:J`/02T[[00Y:b^
0:F//02VZk80YZRc0:FW/P020:BW[`030:BX/@2RYk80WjFb0080WJF`00/0W:F]09ZSZ`2JXJX0VJ2X
09NOY`2FWZL0UYfV09FMY@2DW:@0TIZR08nIW`0208^GV@0;08RETP1jQH40E5ML0412BP0j>d80=cLm
03/m?`0Y:C409BH]02@U:P0T9bP00P0H61`01P0D51X030hD00P93P0720P010H300@50A[ooooo00H0
A4iM04M@I01:DV/0BU=_04aEM01>EWH204iHMP0;04iIM`1@FgP0D5]h051LN01AGGP0D5ai055LN@1D
H7/0E5ml05MRO`1II8000`1HIGl02P1HIWl0F6In05]XP@1MJH<0GVZ305m/Q01SL8L0I72806I`R@1_
OI<207b<X080P96T00X0O8^P07N3VP1dP9P0LWfD075lT01_Nhh0KWZ>06ajSP1/NXl0Kgb@0P1aOI00
2`1bOI40LWjB07=oU@1eP9L0MX6H07F1U`1gPiL0MX:G07J1U`1fPYP0N8BI0080NHFL00@0NHJM07^8
WP1lR9h0O8VO0P1mRJ401@1oRil0OhfP082=X022SYl0PhfP0080QI2S0P27T:D02@27TJ<0R9>Q08RC
X029UZ80RYNR08^GX@2<V:80SY^T08nKYP0208jJY`0:08nKZP2?Vj/0TIf]09>O[@2CWjX0TYnY09>Q
Z@2DXjX0V:J[09VWZP80VJNY0P2KZJT02`2MZJL0WJVV09bYYP2NZjP0Wj^Z09fYZ@2KZZT0Vj^X09ZZ
YP2JZZ80VZZQ0080VJVN00/0VJ^L092ST`1>EeH0?D91034d<P0/;B`0:b/[03@g<P1KJ5H0F6ED05IR
DP02059NC00<04E??`0h@340;cHX02``900d>2X0<c@Y03Dd;P19Bd@0T::8096RR`2>WhT0T::;0P2;
WHH02`2;W8<0G6AG01XD6P0T8B807Q/L01XI600G5QD05aLD01XI5P0Q81/0ATdm0080Q9Uf00/0M8I/
07B6L01dQG<0M8Ab07>5K`1eRFl0MHU^07J9K01ULe/0>Cd`03m3<@0203Pk:`0602lc9@0^<bD0<CLX
03<k:00f?bX0=3/X3oooool000gooooo00H0L82=07N7V01iRZ00Nh^U07^;YP1jRZ@207V:X@0907b;
X01mRj00OX^Q07f:X@1kRj<0Nh^T07f>YP1oT:P0P96Y0080Pi:/0P25TZ`02`26U:`0QI>Z08NDZ`2;
Ujd0SIN^08fG[`2;UJh0S9F^08fG[`2@V[80U9fd0080UYfd00`0Uije09NO]02FW[80V::c09RS]02H
XKD0V:6f09ZS^@2LYKX0WJJi09bW^@2NZ;`209fW_00;0:2X_@2RZ[d0XjZk0:F/^`2V[;`0YJ^j0:>Z
^02V[;T0Yjfg0:R_^02Y[kP00P2X[[T02`2W[[X0YZfk0:N]^`2X[[X0ZJnk0:R^^P2X[K/0ZJjm0:V]
^`2Y[[`0Zk2m0080[;2l00/0[:nl0:b`_@2[/;/0Zk2k0:^`^P2Z[[P0ZZnh0:fa^@2]/;P0[K6g0:ba
]`020:jc^0040:nc^P2^/[X0[[6j0:b`^080[[6i00H0[k>j0:f`^02][[L0[[2h0;2a^P2`/KP20:fa
]P090:fc]`2^];T0[kBk0:fa^`2[/;/0[K:l0:Za^02Z/KH0ZK2d0080Z[6f0P2Y/;L02`2Y[kP0Zk2h
0:Z_]P2Z[kD0Zk6e0:Z`]02Y/;<0ZZna0:V^/02W[Zh0YJb/0080Y:b]00`0YZn_0:B][@2RZjd0XjZ_
0::X[`2SZ:l0Y:N_0:6T[@2QYJd0X:F^09jT[P2LXZ`209bSZ`0;09^SZ@2FX:L0UinX09JNYP2GWZH0
UYbU09FLX`2CVj00T9RN08nHWP2?V9d00P2;UIX02`2;U9P0RiFG08B>T01jQ8P0Lgj106M`MP1KI6X0
@49A04aBGP1JIFT0BU9D00805QDR00H05aLP00X;50041@d00P<600420@020P4Jooooo`0504A?G@17
DF<0BUEZ04]EL01=EgD00`1<EgD02`1;EgD0C5Ug04iKN@1>FgP0Ceeh04iLM`1AGGP0DUii05AONP1E
HG/0EfAm0080EVAk00/0EF=l05IUOP1GIGl0F6N205YXP`1KJ8<0GVZ4069^Q`1SKhP0IG2:06]fT@02
07F1VP0907R6WP1hQid0M8>H07:0U@1aOI@0L7^B06mkT@1_Ni80KGZA0080KGZ@00<0KWZ@071lT@1`
O9400P1bOI<02@1cOi@0M7nF07AoV01eP9P0MH2G07B0V01ePIT0MhBK07R4V`0207R5V`0;07R7WP1j
RJ00NhVP07Z9X@1kRJ00O8ZO07j<W@1oSId0P8fN08:?W`24Sj000P26T:@02`27T:H0QI2W08F@YP26
TjH0Qi>T08NDY028UjD0RINU08VHY02;VjD0S9ZW0080S9ZX00`0S9ZY08jJZP2@Vj/0TYj/09:OZ`2B
X:X0T:6Y096RZP2CXjT0UJJX09NVZ@2IYjX209^YZP0;09bYZ02KZ:H0W:RW09jZY`2N[:T0W:^Y09ZZ
Y`2KZjL0Vj^U09VYXP2IZIl00P2GZI`02`2GZIT0TjNF05MQG`15C4`0=CTj030b<@0f>CD0?44j05MS
D`1GIE@0EV=A0080DEa;00`0B5A303U3=P0/=2T0;34V02/^900Y:B40:2DQ03ln>@2HZHh0VZbC08nO
R`2>X8/208bORP0;08fNRP1[MVP07AXO028S8P0L71/071`H01TJ4`0I6Q405aD?01lN5`12B3P00P29
WW`02`1dQVh0LhAb07:2MP1cQ7L0LXEb07:9K`1bRF`0MH]/05e[E@10ASX0?dHi0080>3ha00H0<cT/
030e:P0a=bX0=C`/03Lo:`0e?2X?ooooo`003Oooool01P1[O8H0M8JC07V:WP1kS:<0NHZT07Z:Y080
NHZS00/0NHZQ07Z:X@1lS:<0OHbU07b<YP1kRjH0O8bU07j@YP1oT:P0PY6Y08>B[00208>C[00;08>D
Z`25U:/0QYBZ08ZF[@2;UZh0S9N_08ZE/02;U[40RiNa08bH/P2@W;@00P2BW;@0102CW;D0UIfe096K
]02AWK@209:N]00609BO]@2FXKP0Uj>i09VV^P2JYkX0VjNj0P2KYK`02`2KYKd0WJNn0:2Y_@2QZK/0
Y:Zl0:J[_@2TZ[`0Y:Zk0:B[^P2TZ[T0YJ^k0080YJfm00T0YJfn0:F]_@2T[;`0YJfk0:J^_02U[K`0
YJ^l0:N]_P2W[[h00P2X[kl20:R`_@070:R^_@2X[K`0Z:bj0:R]^`2X[[T0ZJfh0:Z^^@020:b`^`0@
0:ba^`2[/;X0Zk6k0:^a^`2//K`0[;:k0:^_^@2[/;P0Z[6h0:Z`]`2[/KL0Zk2j0:Z^^`2[[k/0[;2k
0:b_^P80ZJjh00/0Z:jh0:V`^P2//[`0[;6l0:^`_02//[d0Z:ni0:N_]`2Y/KL0Z[:i0:Zb^`020:V`
^`0;0:R_^P2X[[P0Yjjf0:N]]02X[K@0ZJje0:Z`]`2X[[@0ZJjc0:N]]02UZk<00P2RZK40302TZk40
Y:^_0:>Z[`2RZ:l0XJN_0:6W/@2PYk40WjJ`09nW/02MY;00VJ6]09RQZP80V:2Z00/0V::Y09JQZ@2F
XJT0UJ2Y09FPZ02EWJL0Ti^T09>LY02AVj80TI^O092JW@0208jHV`0;08jGVP2<UIX0RI>I08J@U@23
SY80PHfA07b9S`1iQH`0NHJ?07Z7T01bP8L00P13BUT01P0oBU006b4/00L;5`062Q000`D700820a[o
oooo00D0@diP04MAIP19E6`0BeA`04]FM00304UFL`0;04aIM01<FGD0CEUf04aIMP1=FgH0Ceaf051L
M`1BG7T0Deij05AQNP1DHW/00P1EHW/02`1DH7X0EF=l05ETO`1GIX40FFN205]WPP1MJH<0GV^4061]
QP1RKXP0IG2:0080JGJ=00`0KW^B06mmT`1^OI<0KG^C06ejT@1^Ni<0K7VB06]hT`1ZMY80JgN@06ei
T@1^NY4206eiT@0606ijTP1`Ni<0LGfD075nU@1bOYL0LgjH0P1dOiT00`1ePIT0MX:J07N4VP0207N4
V@0307R6V`1jRIl0NXVQ0080NHVO00H0NXZM07b:W01lRi/0O8ZL082<WP23Sj0208B?XP80Q96U00D0
Pi6T08FCY@26U:D0QiBT08NEY@0208VGYP0@08^IY`2<VJL0RiVX08^IZ02=VJT0SiZ[092KZ`2CWJd0
UIn]09FQ[@2DXZ/0Tj:[09:QZ@2EY:/0UjJ/09VV[@80VZN/0P2LZ:/02@2NZ:X0WjVX09fZYP2LZZH0
VZZU09ZYYP2IZ:<0VZVS09ZZX@0209RXW@0;09JWV@2DYiH0FVEQ04I=C00`<SH0;c8b03]1?010B440
FFEF05UVEP1GI5@00P1AG4d0301?Fd/0ADm302da;00`<bh0;2dX02LT8@0S71h0>3@c09f]T@2R]9T0
TZ6<092PS080Sij:00/0SYn:06ahJ@0M72008b<S01dN6P0M7QL06AXA01LG3`0F50l08b8J04aB@@02
08nUP00;07>7KP1`QG40Kh=h06YoM`1gTX40FG1O05mfH@1[PFT0F6EF03m8@00nAC/00P0g?S<01P0b
>Bd0<3L/030e:`0d>Rd0=cd]03<k:@oooooo000=ooooo`0606]kP`1bPi00MhVJ07Z;W`1iRZ<0N8VT
0P1hRJH02`1gR:D0N8VV07V:Y@1jRj@0NXZT07Z;YP1kRjD0OHnV07j?YP21TJH0Q9>X0080Q9>Y00/0
PY>Z08:DZP24UJ/0QiF/08VE[@27Tjh0QY>`08ND/@28UK<0RIJb08^I/P0208fI/`0<08jI]P2?V[L0
SIZf08jK]`2?WKP0SYbe092M]P2BW[P0Tj2j09>Q^`2BXKT0UZBj0P2IYK`02`2JY[d0VZFm09nY_@2O
Z;X0X:Nk0:>X_02TZ[d0XjRm0:>Y_@2SZ[d0YJ^n0080XjZm00/0XjVn0:B/_P2S[;h0Xj^m0:B/_02S
[;d0XjZn0:BZ_`2W[L40YZbo0:F/_P020:F]_P0;0:F/_@2W[[d0ZZjl0:V]^@2X[KP0Z:ji0:Z^^P2[
/;/0Zk2m0:^^_`2[[l000P2Z/<40302Z/<00Z:no0:N]^`2V[KT0Yjji0:R_^@2W[[L0Z:jj0:R]_02X
[Kd0ZJjo0:Z`_`80ZJnm00/0Yjjk0:J]^@2V[KT0Yjji0:N^^P2Y[kX0Z:jj0:N]^@2W[[X0Yjnk0:R^
^`020:N^^`070:J/^P2W[[T0YZbf0:F/]@2V[;@0YJ^d0:F[]@020:J/]@0@0:F[]@2TZ[D0XZRc0::X
/`2QYk80XJN`0:6W[`2PY[00X:Jc0:6W]P2NYKD0WZJe09fV]02JY;80V:6`09RR[`80Uj6^00D0UYn/
09BPZP2CX:P0TYjW09:LYP02096JY`04092JY@2?Vj<0SYZP08fIW@80S9NK00/0S9NL08^FV`29UIX0
QY6D08>?T`21Si80P8jB07j;T@1mRI<0NhRB07Z8T00207B2R@060720P`1FIfP092hg00T>60031`d0
0@866_ooool01P12CV<0AE1W04IBK01:E700BUAc04QBL`80Ae9c00D0B5=c04QDL`1;EW@0CEUd04iJ
M@0204mJM@0404mJM`1AG7T0Demk05=PN`80E61j00/0Demi05EQN`1FHWh0EfF005UVP01KIh40FfJ0
05aXP@1NJX<0H6b4069_Q@0206AbQ`0<06MeR@1YMh/0JWV>06]jT@1[NI80K7RE06YeU01YMI@0JgJE
06]fTP1[MY00K7N?0P1]N900201_NI80LGZC075kT`1cOID0LgnD079nUP1bP9P0Lh2G0P1ePIL03P1f
PIP0MX6I07J1V@1fPYX0N8BL07R5V`1iQYX0NXNK07^7V`1lR9/0OHZK07f:W01nRil0PHfQ0P21SZ40
2`22Sj<0Pi2S08>@X`23T:40Q9:R08FCX`26Tj<0RIJV08ZGY`2:UZP0RYNX0080RiRY00/0S9VY08fI
Z@2?VZX0Tif[09FNZP2DX:T0TinX09BQZ`2EXJh0Uj>_09NT[P0309VU[P0;09ZU[02KYZ`0WJN[09fW
Z02LYjD0VjRT09^XY@2JYZ@0VjNS09^YX@2JZ9h00P2HYi`02`2FYYT0TZBD05AMF`0j?T40;S0d02d`
<00i?cP0?THl05aZF01JIUH0F69C0080DU]?00`0CeM<04mGB`0o@c`0=SLd02/X:00V82808aXO03Lb
<`2P/9@0Y;FJ09>SS@2@X8d208jNR@0;08fOQ`1WLfD061LL020Q8@0L7Q/06A/E01PI400G60l05QH?
01hP5`14CSd00P1nUG802`1ZP6@0JX1W0767LP1HJ600LHQh06UnK00oBd@0JgiZ05=PE00mA3h0?4<j
0080=Cdb00H0<ST_03<j;P0c>Bd0=CX]03Hl;@0d>RP?ooooo`003Oooool01P1YNh80MHNA07V:VP1i
RYh0NHVT07J6Y@80Lh:S00/0LH>S07:5Y01eR:@0MhZS07V:X`1iRJD0NhbW07f?Y`1nSj@0P96R08:B
XP0208>AY00;086@Y`21TZ/0PI:[08BCZ`26U:`0QiB^08NC/@25T[80QY>d08NE/@29U[000P2<V;<0
1`2=Uk<0SiVg08nI^02?V[T0T9^i092K]02@W;<00P2BW[H2096O]`0>09>Q^02HY;X0V:Bj09ZU^`2J
Y;X0WJJk0:2Y_02QZ;X0XJNi0::X^`2SZ;d0XjRo0::W_P2SZ;h20:6W_@040:6W_P2TZL00Xj[00::Z
_`80XZ^l00D0XjVn0:BY_`2TZ[d0XjZl0:J[^`020:J/_00;0:BZ^`2UZ[/0YZ^i0:N]]`2W[KH0Z:jh
0:N[^02WZkX0Yjbo0:V]`@2YZl400P2YZl80202WZ/00YJVo0:BY_@2UZ[/0YJ^j0:N]^P2WZkP0YZVg
0P2WZ[P0202WZ[/0Z:^k0:N[^`2WZk/0YJ^j0:BZ^@2UZkP0YZfh0P2V[;P01@2W[;T0YJZg0:F[]`2V
ZkL0YZbg0080YJ^g00/0Y:Zf0:F[]P2VZkD0YJ^e0:JZ]02TZK@0XJNd0:6X]02OYk80XZRb0::X]002
09jU/P0<09jT/@2NY;00WJ>]09fS[@2OYK00X:Bd09bQ]02JXK@0V9nb09NN[`2IXK00V:2a0P2FWjl0
2`2EXJh0Tin[096NZ02BWJL0TY^X096KZ02>VJH0S9RS08fJW`2;V9/0RYRJ0080RiJL00/0RYFM08RC
W028UI/0PXjD086=TP21Si<0PXjE082;U@20RY@0OHZA07^9S@0207V6R@0607J1Q@1hQXD0FVMX01HI
9`0<3AL02@LB6_ooool01P10C6D0@TmX04EAK@18Dg00BU=c04YCM080BE=d00/0B5Ac04QDL@1:E6l0
BeI^04eIL01?Fg00CUU`051KM01@FgL0DEai059NNP0205=ONP0;05AONP1FHW`0Ef=m05QTO`1IIH00
FVB105]VP`1MJ8<0GVV3065]Q@1RKX@00P1RKhD0301TLXP0IWB906IdR`1WMXh0J7B@06QdT@1YMI80
JWFC06afU01]Mi<0JgJB06]gT@80KWRA00/0KWR@071jT@1aNi80LWfD079mT`1bOY@0LWjE07=oU@1f
PYL0Mh>G07V2U`0207^4V`0407V3W@1gPY/0Mh:J07Z5VP80O8NJ00D0O8JJ07n9W01oRYd0OhZN086;
X002082;X080PXjQ00T0Pi2Q08B@X024TZ00Q9:P08FBX@28U:<0RYJU08VFY`29UZP00P2;V:X01@2;
VJX0S9ZZ092KZ`2AW:/0TibZ0080TifY00D0UZ2[09NQ[@2HXZd0VJ>]09ZT[@0209bU[@0;09^T[02K
YZX0VjJY09ZVY`2JZ:D0VjRT09ZWY02IYJ80VZNQ09ZVW`2IYI`00P2HYY/02`2FYYT0TJ6C059HF00`
<ST0=3Li02lb<@0a=2d0@DPj05i[E01IHdl0DUU:0080BTe400`0BTa405AHCP19BT@0?chm03Hc=@0d
;S40<2T]04<o?`2FY8d0WjjF09FUT02@X8h208bMRP0;08ZNR01WMFL06QXP024S900I6QX06AXD01PG
3`0H5`h05aP>02<W6P0`>B/00P16Dd002`1LKUH0IWaP05U/E01HJU<0HgIN096[R01FI5D0Df1D051O
DP0/<Rh0=S/c0080=S``00H0=CX_03Dk<00g?C00>3d_03Ll;`0c>B/?ooooo`003Oooool01P1/OHX0
MHNF07^<WP1kRZ<0NHVX07N7Z080LhFV00/0M8NU07B8X`1gRZ80N8ZS07^;Y@1lS:L0O8fY082BZP20
TZL0P9:T086BY@0208:@YP0;08>BZ`23Tjh0PI:^08:C[@23TZ/0QYB]08JC/@26Tk<0QYBb08NF/02;
VK000P2@V[40302?Uk00T9Rc08nI]@2?VKH0T9Ze096K/`2CW;80Tifb09>M/`2DX;@0U:6d09FQ]080
V:>f00/0VjBi09ZS^@2KY;X0WJNi09nX^02RZK/0XZNk0:6V_@2TYkl0XjRn0:6X_@020:2X_00;0:6X
^`2SZKh0Y:S00:>Z`02SZ[h0Y:^n0:>X_02UZ[d0YZbm0:>[^P2U[;/00`2UZkX02P2TZKP0XjVf0:BZ
]02T[;@0Y:^e0:F[]`2VZk/0YZ^n0:FZ_`2UZKl20:JZ`@0<0:FZ`02TZL00YJ[00:JZ_@2VZk/0Z:fj
0:R[^@2WZKT0Z:^j0:V/^@2Y[;X0Z:Zi0P2X[;T01@2W[;T0YZ^h0:FZ^02UZkL0YZbh0080YJ^i00@0
YZbh0:N]^02W[KL0Z:fg0P2X[KP20:R/^0080:R[]P2W[;D0YZ^d0:BZ]02RZ;@0X:Vc09nY]02NYk<3
09fU/P0909fV/`2NY[<0WJB`09fR/02OYK40WJ>d09bR]P2KX[H0VJ6c0080VJ6`00h0VJ6a09NP[`2G
X:l0U9n]09:O[02@VjX0T9bZ096MZ`2@W:/0SIZZ08ZJY@29VJ00RIVO08RGW080RYRM00/0RIFM08ND
W026UI/0PY6E08:?TP24Si<0Q8jE08:;UP21RiH0OHRB07V6S@0207Z6RP0607V3R01iPXH0N8B605AL
IP0g>d/0;c926_ooool01P11Bf@0@deX04QBK@1:E700BUAc04YCL`80BUAb00/0BeIb04]EL01;EFl0
BeI_04aHKP1?FVl0CeY`055LM01@G7D0D5]f04mKM`02051KMP0;059MM`1CGWT0EV5j05MRO@1IHh40
FV>305aVQ@1NJ8D0GVZ4061/Q@1RKXH00P1RKXL0301SL8T0Hg6:06AaS01ULhh0IW:?06MeT@1XMI40
JGFB06YfTP1/Mi<0JgNC06ajT`80JgRA00/0JWN@06eiT@1^NI80L7bC06mkT`1`OID0LWjG075nU@1d
OiL0MX2H07R2V00207^3VP0;07^3W01hPYd0N8>K07V5V@1kQIT0O8JI07f6VP1oR9`0OhZN082;WP22
Ril00P22S9l02`24SZ80PhnS08FAX`24TJ00Q9>N08FDX024Til0QI>N08NEX@27UJ@0RINW0080RYNX
00`0RYNZ08bHZ`2?VZd0TI^]09:L[@2BWJ`0Tin]09BO[@2GX:d0Uj6[09VRZ`2KY:`209^TZP0;09bU
Z@2JYJL0VZFW09ZVY`2KZ:H0VZRV09^XYP2JYjD0VZJS09ZWXP2IYj000P2GYYd02`2EYIX0UZNI05aR
HP0a<CH0=SXg038d<00a<BT0@4@f05eVCP1FGTX0ADPn0080>CPg00`0B4Q705eQF`1QIUh0C4e<04M8
B015A480AD=004e=BP28U800V:J@09JUT@2@X8h208RJR00;08RKR01/O6h06a/P020Q8@0M7AT071dE
01PF3@0G5@/05A@:02<W600^=BD00P0d?Bd02`0oC3T0Cem702Xd9`0_?2`09S0U08BPN`1bRFX09B/T
04EB@P0I6aT0:2/S0080;C4W00H0<3@Z03@h;P0g?2l0>3h^03Lo;P0b>BT?ooooo`003Oooool01P1Y
NH/0M8FH07^<XP1jRj@0NXVW07V7Z080MXJV00/0MXVU07R<Y01kSJ@0NhbU07f<YP1mSJL0OXjY07n?
Z@20T:L0PI:U08BDZ00208>@Z@0608>AZ`23TZd0PY:^08>D[`24U:h0QYF^0P28UK000`28U:l0RYN_
08fI[`0208jH[P0<08jG[`2@V;40TIRc096I]@2AVK<0U9^c09FL]02DW;@0U9fd09FP]@2EXK80V:>b
0P2KY;D02`2LY;P0W:Fl09bU_02MYKX0WZNk0:6Y_@2QYk`0XJNm0::X_P2RZKh0XJVn0080XJZn00X0
XZZo0:>Z`@2SZ<40XZO00:>X_`2SZKd0XjRj0:F[^`2U[;`0Y:^k0`2TZ[/0102UZkd0XZVk0:6X^@2S
Z[P30:B[]`040:F/^`2U[;h0Y:^o0:BZ`080Y:Ro00`0YJZo0:FZ`@2VZl<0YZ_00:J[_@2W[;d0Z:bn
0:V/_`2Z[L00ZZfo0:V/_@2Y[;X20:V/^@070:R[^@2WZkX0YJZi0:FZ^@2UZkT0YJbm0:J[_0020:F[
^P0?0:N]_02Z[[h0ZZfm0:Z]_@2X[;d0Yjbl0:J[^@2UZ[H0Y:Ze0:BZ]P2SZkL0XJZe09nY]02NYk<0
WJFc0080W:Fb00`0WJNc09jW/`2MY[<0W:Bb09fV/`2KY;<0VZ>d09RP]02GXK80VJ>b09VR/@2GX;02
09NP/P0;09FQ/P2BWjl0T9f]092LZP2AW:T0T9bY08nJZP2<VjP0RYZT08VIW`28V9/00P2;VY/02`2:
VY`0R9VK08NHV@25UID0QI>D08FAU024SY@0Q8nG08:=V01oRiP0NhVE0080O8RC00H0OHVA07b5S@1i
PhX0MX:806aiP01TM7PJooooo`06045:H@13CFL0ATm/04QAKP18DG00B59`0P19DW002`19DVh0B59_
04YDL@1<EG80BeEa04aGL01=F700CeYc04mJM@1@FgP0CeYh0080D5]h00/0DEah059MM`1DH7T0EV5k
05QSOP1IHh40FVB405]VQ@1MJ8<0GVV2061/Q002061/Q@0<065^Q`1SL8X0Hfn>06AbT01TLI40IG:B
06IbT@1VLY80IgBC06UdU01ZMI@0JgND0P1[Mi<02`1[MY80K7RC06eiU01^NYH0KGZF06ikU`1_OIP0
LWnH07AoV01dOYP0M7nI0080Mh:J00X0Mh2I07IoV@1fPIT0Mh>H07V4V01jQYP0NhJJ07f6V`1nR9`0
OhZM0`22Rid01022S9h0PhfP08>>X@22T9l208>BW@0508BCW@24Til0Q9>R08FDX`27UZH00P28UZL0
302:UjT0S9N[08jI[02>VJd0SiZ]096L[@2BWZd0Tin^09BP[@2EX:/0Uj:Z09VTZP80VZFY00/0VjFX
09ZTYP2KYZL0VZJV09ZVY@2JZ:H0VJRW09RVYP2HYJD0UjBS09JTXP0209JUW`0;09FTVP2HZ9T0IVmZ
03@c>@0m@3d0>C/f03De;`0m?cH0Eem<05MNCP1<DDH00P0k?ST0301HHEH0HFaR08:CP@1PJF00FEmH
04A5A01;BdP0BdY907j7N@2AWh`0TJ2?092PS`80R9N700/0QYN40760L00N7b@08B8R01dL6@0L71D0
61P?01@C2`0C4P/07b8F02de9@0203Q3<@0;034l;00P9a`06b8H01XQ5P0?50`0H7IE06EkF00E6Q80
;SLZ01@F4P0O8AT00P0W:R401P0]<BL0=3L/03Pl;P0e>b`0=3X[02lf9`oooooo000=ooooo`0606Ed
R@1aPiT0MhVR07N9X`1hRJD0NHZU0P1fR:D02`1fR:@0M8NR07N8X`1kRZD0Nh^T07b<YP1mSZL0OhnX
082=YP23TJL0QY>Z0080Q96Z00X0PXjZ086>Z@21SjX0Q9:^08FC/@26U;40QiFb08ND/P29U[40S9Ra
0`2<Uk00302<U[40SiNa08nH/P2AVK@0TYVd09BL]02DWKH0TY^e09:K/`2CW[<0U:2b09FQ/P80Uj:b
00/0VZBf09RS^@2IY;X0VjFk09^U^P2JY;T0Vj>k09fV_P2NYkh0WJJn09jU_`0209nV`00;09jV`P2P
Yl<0WjS30:2V`P2OY/40XJNo0:>Z_P2T[;l0Xj^k0:BZ^P2TZ[/00P2SZ[d02`2TZ/00XZS109nV_`2O
Ykh0X:Vl0::[^`2RZkT0XZ^k0::Y_02QZ;d0XJNm0080XjRm00`0YJVn0:FY_`2VZ/<0YJW20:FZ`02T
ZL00XjS00:FY`02VZ/40YJS10:JY`@2VZKh20:FX_@0;0:BW_@2TZ;d0XjRl0:>Y_02TZK/0Y:Zn0:F[
_`2TZkl0Y:bn0:>Y_@2TZKd00P2UZKh02`2SZK`0XjVm0::X^P2SZKT0Y:^j0:>Z^P2QZKT0X:Vh09nW
]@2OY[D0X:Ng0080WZJf00`0WZNf09bU]@2JX[80VZBa09ZT/P2IXk40Uj>`09FQ/02EXK40UZ2a09JO
/@2DWJl209BN/00609JQ/P2BWjl0T9f]092MZ`2?VZP0S9NT0P2;Uj@00`2;V:@0RIRQ08RGW@0208VG
V`0:08NFVP24TiT0PY:G08:BUP22TID0PXnD086=T`21SIH0P8fG07j;U@<0O8ZD00H0O8VD07Z6T@1f
Ph`0MH>90761Q@1/OWdJooooo`06045:G`13C6D0ADiZ04M@K@18DVl0B55`0P19Dg802`19DW00B55^
04]DLP1<E7<0C5Ec04]EM01<EW<0CUQe04iIM@1@FGL0CeUg0080D5Yh00/0DE]i059LN@1BGGL0E5ii
05IQN`1GHWd0FF>305YTQ@1JI8<0G6N205iYP`02061[Q@0<065]QP1RKXP0Hfn;06=_S@1SKi00Hfj@
06=^T@1TL9<0IG:E06IbU@1XLiD0Ig>D0P1YM9D02`1[MYD0K7VD06aiU@1]NID0KWZC06mkU@1`O9L0
LWfG07AnUP1dOYP0MGjJ0080MGnJ00@0Mh:K07J1V`1ePIT0Mh>K0P1gPiT01@1hQ9/0NhJL07b7WP1m
RIl0OhVO0080PHZM00/0PhfO086<WP21SIl0PY2P08:@WP21T9d0PY6L08>BX024TZ80QYFV08JDZ002
08REZ@0<08VDZP2;UZ/0RYJZ08^G[02=VJd0Si^/096LZ`2BWZ`0TYj[09>OZP2DXJP0UZ>X0P2GXjH0
2`2HXZD0VZBW09VTYP2JYJH0VJFV09ZXZ02IYjT0UjFW09FSY@2EXj<0U:>Q0080UJBP00/0U:BK09RY
VP1[M6l0=cLn0412@@0j?3T0<S@a04E:@01BFD`0EEe?04mIC0020417?`0<05=ND@1SKf40Q9J0086@
O01lQGD0?S/n04Q5A`0m>400Mgmf09:OS`2;V8T0U:>A0P2=W8X02`29V8D0NHMg020O9P0N7B4071/J
01PH4`0E5@h051D=01HG3`0U:Q`09R`N008092/N00/08RPL01TO5P0F71@05Q`A018G300[=R<0>4D_
018H400L8QX051PC01<F400202D[7`0602lf9`0c>bX0=ch/03Hn:`0c>RT0;S<T3oooool000gooooo
00H0IGB90763V@1gRJ80MhVS07R9Y@1iRZD207J8Y@0;07J8Y01dQj80MhRS07^:Y@1kRj@0O8bV07f>
Y`1oSjP0P8fV08>AY`26TjX00P24TJX02P22SZX0PHjY086?ZP24TZh0QI>a08JD/@27UK80QiBb08VF
/@2<V;4308bG/00<08bF/@2?Uk40SiRb096I]02BVK@0U9bd09BM]P2BVkD0TY^c09>N/`2DX;80UJ6b
0P2GX[802`2JY;H0V:>i09VT^P2KYK/0VjFj09ZT^@2KXk/0WJJn09jW_P2MY[h0WZFo0080WjK000/0
WZK20:2W``2OZ<<0X:K209nV`@2QYkl0XjZn0:B/_`2SZk/0Y:Zj0:BZ^`020:>Z_@0;0:BZ`02RZ<40
WjJo09nW_P2PZK`0XZ^k0::[^@2RZk/0XZVl0:6X_@2QYkd00P2SZ;d0302UZKh0YJVo0:JZ``2UZL80
YJ[00:BY`02SZ<00YJW00:JZ`@2UZ<40YZW10:JY_P80YJRm00/0Y:Nm0:BX_@2SZ;`0XjVl0:BY^`2T
Z[h0YJ^o0:B[_`2T[;h0XjVm0:BY_@020:FY_P0;0:>Y_02SZKd0XZRj0:>Y^@2TZkX0XjZj0:6Y^@2P
ZKP0WjNe09nV]@2PYkL00P2NY[H0302NYkH0W:Fe09ZR/P2JY;40VZBb09VS/@2GXk00UJ6`09FQ/@2F
X;40UYna09BM[`80U9j`00H0UZ6b09:O[`2@WJd0T9f[08nJZ02<Uj@208^GY00308^HY029V:40R9NM
0080RINK00X0QiJJ08BCV@22TYL0PY:F08:AU@22Si@0PHfC086=UP20SIL0OX^E0`1lRY@01P1lRI@0
NXJA07J3S01ePhT0LH6506anOA[ooooo00H0@DYO04=<I@15CVX0Ae1]04QBK`18DG0204UCLP0;04UB
L018DFh0BeAb04aDL`1<EG<0BeEd04aFL`1>F7D0CUUe051IM`1?FGL00P1@FWP02`1AFgT0DUai059M
M`1DGWT0EV5k05MRO@1IHh<0FVB505YTP`1LIh80GVV30080H6^500`0HFf6069^R01SKh/0Hfn=06=_
T01SKY00HfjA06A`T`1ULYD0IW:E06QcU@1WLi@206UdU@0;06]fU@1/NI@0K7VE06eiU@1^NY<0Kg^E
071lU`1bOIL0M7jF07AnV01eOYX00P1eOiX0101gPY/0MX6K07F1V@1gPi/207N3V@0507R4V`1kQY`0
O8NN07f9W`1oRIl00P21RYd02`23SIl0PHbN086=W`22T:00PY2N086@W@22TI`0Pi:P08BBXP26UJH0
QYBX0080R9FY00`0RIBZ08^FZ`2:UZX0RiN/08fI[@2?Vj`0TIb[09:N[02BWZ/0TinZ09BQZ02FXjP2
09NSYP0;09RRY@2JY:L0VJBV09ZUYP2IYJH0VZRX09VWZ@2GYJL0UJ>U09FSX`2DXj400P2EY:002`2D
Y9/0V:VJ06]dK`0g=ch0@49103Xl>@0b=340ADY0059IC01EGDl0CeU<0080@4Lo00`0DeiA06=_H@24
UX00PI1l07b5M@0n>ch0B4E703dh@01gOgH0TYn?08^HR@2DXi4208fLRP0;08VHQ@1iQgL081lV01hM
8@0L6aX061PC01DE3P0D5@d05QL?02DZ700V;1h00P0T:ah02`0R:1`06AlF01HL500F71404QL<02/f
8`0hABl04QP@01`R6P0D61<04aH@00809B/O00H0;cHW03<k:P0g?R`0=Sh[03<j:@0^<b@?ooooo`00
3Oooool01P1SLXT0Kh:J07B9X`1fRZL0MXVW07N9YP80MXNU00/0MHFT07B5Y01fQjD0NHVU07Z9Y@1k
RjD0OHfV08:@Z023T:L0Q96W08NDZ`0208FAZP80Pi2Y00T0PY2X08:?Z`25TK00QY6b08NB/`27TK80
Qi:a08ZE]02:U;800P2<U[40302>U[<0T9Fd092F]02AUkD0TYVg09:J]@2AV[D0T9Ze096K]@2BWKD0
TYfd09>Q]080Tj6c00/0UZ>f09FQ^02FX[/0Uj>m09RR^`2JY;/0W:Bl09fT_P2LY<00VjBn09bT_P02
09fV_`0909jV`@2MY/40WJG109jV`P2OY/80WjK00:6W_P2SZKh0XZZm0080XjRk0P2QYk`02`2RZ;h0
XjS20:6V`P2PY/40XJRo0:6Y_`2QZKh0XJRm0:6W_P2PYkh0X:Jn0080Y:W000`0Y:Vo0:FY_`2TZ<40
Y:O10:>W`P2TZ<<0XjK20:BW``2VZLD0Y:O40:BXa02TYl<20:>W`P050:BY``2TZL80XZO10:2W`02Q
ZL000P2RZ/00102RZl40Xj_00:6X_@2QZK`20::X_0050:6X^`2QY[`0XJNk0::X^`2RZK/00P2RYkX0
102RZ;/0X:Jh09nT]`2OYKL209nT]`0<09jU]`2LYKH0VJ:c09VR/P2KXk<0VZ:b09RQ/@2FX:l0UZ6_
09JO/02FWk40UYn`0P2EWZh01P2CWJd0TIb/08nL[02?W:/0SYbZ08fHY`80RiNT00<0RYJR08ZEX@2:
UJ000P29U9l02`27TYd0QI6M08>BW@24Ti`0Pi:I08:@U`21SYH0OhbH07j<V@1lRIH0NXND0080NXNC
00H0N8FB07N4S`1dPh`0Lh:90762Q01]OgdJooooo`06045:G@14CF80ATmY04UBKP18DVl0B51`0P1:
Dg<01P1;E7@0BE5a04YCLP1;Dg<0Be9b04]DM0<0CEIe00l0CUQf04iHM`1?FGL0CeUg051KM`1BGWT0
DEeh05=NNP1EHGd0EV6005QSP`1HI8D0FVB405aVP`1OJH@00P1PJH@0301PJX@0HFb7069^R@1RKH/0
HVf=069_S`1SKi00HVn@06=aT@1ULi80IW>B06IbTP80JGBD00/0JgJD06YeU01[MY@0KGVC06ijT@1`
NY80LG^D079kT`1cOI<0M7jE07InU`0207MoV00407N1V@1fPIX0M82J07N2V`80N8>J00D0N8:I07V3
VP1lQY`0OhNN0868W`0208>:W`0;08F=W`22S9l0PHbO08>>X024TJ40QI>R08FBX@25TJ80Qi:S08RD
Y@29UZH00P29UZL03029UZP0RiNZ08^FZP2;Uj/0SYV]08nK[@2@Vj/0TIf/09:N[02BWZX0Tj6Y09FQ
Z@80Uj:V00T0Uj6U09RRY`2HXjL0VJBW09RTYP2IYZH0VJNX09NTYP2FY:<00P2FY:8209JUX@0;09JU
W@2HZ9`0Lgef03`m@P11AD@0>Shm03<g=@0i?ST0ATi205=NC015CD800P0b=S@0301@F540HfeS08JE
P@2=WHL0VZZA04]:BP0m>3h0=C0j06edK`2@X900QiB708nOSP80T:6=00/0RYb707V9M`0O7b@06APK
01LF5P0C4Pl04A0:014A200D5@X082DG024W600201lS5`0;01hQ5P0I7Q<05a`C01@J4@0B5`h04QH?
014E400C61805ATC018F4@0@50h00P0P9aX01P0]=R@0<CXW03@n:P0c?BP0<c`V02lg8`oooooo000=
ooooo`0606MgR`1`PYX0LXJR07F8Z01eR:X0LhJY0`1aPjH02P1dQZL0MhVX07R:Y@1iRZD0Nh^T07b<
Y@1nRjD0PHjW08>@Z@25TJ/208:>ZP0;086>Z@23SjT0Q96Z08BAZP27U:d0Qi:]08R@[`28T;00Qi6`
08VC/02<UK400P2>Uk40302@Uk<0TINf092F]P2@UKH0TINh092H]P2?V;D0T9Vf096K]P2AWKL0T9bg
09:N]@80TYjc00/0TYfc09:N]@2FXKT0UZ:l09FO^P2IX[`0Vj>l09^R_02IX;h0VjC009ZT`00209ZU
`@0709bV`02MY[l0WJJn09fV_P2MYKh0WZJn09nV_@020:6W_00?0:6V_02QYk`0XJNl0:6W_02PY[`0
XJJm0::W_`2QY[l0XZJo0:6V_`2OYKh0WjJn09nT_P2OYL00WjG10080XZW200`0XZS00::W_`2RZ;l0
XZNo0::W`02SZ<<0YJW60:FXa@2TZ<@0XjS20:>W`@2SZ<820:>W`@0;0:>W`P2TZ<80XZO10:6W`P2O
Yl80XJW20:6Y`02RZ[l0XZVn0:6X_@2QZ;/00P2RZK/02P2QZ;/0XJNl0:>Y_@2SZ[h0XZRl0:2U^@2O
YKT0WjJi09nU]`2NXk@309fT]@0<09fS]@2JX[@0VJ6d09ZQ/`2JX[80V:6a09JP/@2EWZl0UYf]09NN
[P2FWZl0UYna0P2FW[002`2DWJd0TY^/092KZ`2>V:X0SYVY08nKZP2>VJL0SIVV08bHY@29UJ80RYFS
0080RIBR00/0Qi6O08F@W`24TIh0Pi6K08BBVP23T9T0PhjJ086;W01nRYh0NXJK07N5UP0207N6U@06
07N7T`1fQY00MHJ=07>5R@1aPh<0Kh9m6_ooool01P10BE/0@deR04I@J@18DFh0Ae5^04QAK`80BE9b
00/0BeAd04YCLP19DW80BeAc04YBLP1;Dg80C5Ed04eFM@1=EgH0C5Mf04aHM`0204iIM`0;051MN@1C
GWX0DUej05=NO01EH7l0F6:305QRQ@1HHh<0FF>105YUPP1NJ8<00P1PJHD02@1QJHH0H6^806=]RP1R
KH/0H6b;061]R`1QKX`0Hg6?06AbT@0206MdTP0>06McTP1ZMI<0JWFC06]eTP1]Mi@0KGNC06miT@1_
NY40L7Z@075kT01bO940M7nC07AoU01fOiH307N1V@0607N2V`1fPIX0MX6H07N3U`1iPiL0NhBH0P1l
Q9P02`1nQYX0PHVL08B;WP24Rih0QHbP08><W`23S:00PXbQ08:<X024Sj40QY6S0080Qi:T0100Qi:S
08RDX`28UJ<0R9FS08NEX`29UjL0RYVX08bIZ`2>VJd0SiZ^08nK[02@WJ`0TYjZ09>NZ@2EWjX0Uj6[
0P2FXJP02`2GXZT0Uj6X09NSY`2HY:P0V:FX09VVY`2GYJD0UZBT09RUY02HXj<0Uj>R0080V:BQ00/0
UjBM09RWW01kQWl0>CQ10453A@0m@3l0=cTj03<f=`0m@Sd0DUe>04]DB00203Pk>00<051FC`1TJf80
Q920092PS@2T^9l0HfYS03Tg?@0j>Cl0I6eU096SS`26UH@0Rib90P2<X8/02P28WHL0Nhil028U:P0C
51T061TI01HF4`0D4`h04a8;018C2P0G6@h301XO4P0;01/P4`0I7A405aXA01@H4@0B61804QHC00lB
4`0B5AD051PF01<G500B5Pl00P0O9QP01P0Z<al0;cLU038l:@0a?BT0<SdW030j8`oooooo000=oooo
o`0606EeR@1_PIP0L8BO07:7Y01bQZH0LH>V0P1^PJ@02`1`Q:L0LHBU07:5Y@1cQZD0MHNU07J7Y01k
RZH0NhRV07j;Z020SZT0PXnZ0080PXjY0P22T:T02@23TJX0Q9:[08FCZP25TZP0QY:Z08JA[027Tjd0
R9:^08ZD[P0208ZD[@0<08^D[`2=UK80SiNe08jG]P2>UkL0SYRf08jH/`2?VK80SYRb08nJ]P2@VkL0
T9^d0P2@W;<02`2@Vk80TYbd09BO]`2EX;P0UYnh09FM^02FW[/0UYnk09FO^`2GXKh0VJC00080Uj>o
00/0UJ:n09NS_@2GX[/0Uj>k09VT_02KYKd0W:Fk09bT^@2LXkP0W:>i09jU^P0209fT^P80WZBj00T0
WZBk09jR^`2NY;d0WjJm09fU^P2MYK/0WZJm09jU_`2OYl800P2OZ<<0302PZ<40WjS009jW_P2NYkh0
WjNo0:2W`02QYl40X:G00:2V_P2PYkd0X:No09nU_`80WZ>l00/0X:Fn0:6V`02PY/40XJS009nW_`2O
Z;l0WJJm09fV_02OZ;`0X:Rl09fV^P0209bV^@0;09fU^P2MYKT0WjNl0:2X_@2OYk/0WZFj09bS^02K
XkH0WJFf09bS]02KXk<00P2LYKH0302KXkL0V:2f09NO]02GX;<0Uj2`09JP[@2DWZ`0UIj]09BL[@2E
W:h0Ti^]096J[080TIZ]00@0SiV^092K[@2>VZ/0S9RX0P2;UZH01@2:UJD0RiFU08ZEY@28Tj<0Qi:R
0080QY2Q00/0PXfN08:=W@22SY`0P8jJ07j>U`1oSIL0P8fG082;V@1oRi`0NhNJ07N7U`0207J8U@06
07B5T@1bPhd0LH>90723Q01]PGl0K81j6_ooool01P0nB5h0@4aR04=?J015CfX0Ae1/04M@K`80B55`
0P18DW402@19Dg80BUAc04]DM01:Dg<0C5Ee04]DM@1<EGH0C5If04aHM`0204iJN00;04iKN@1@FgT0
DEaj059MO01DGgh0Ef:105QSPP1HI880F6>105UTP@1LIh<00P1OJH@0301OJHH0H6^905mZR@1PK8T0
H6b8061]R`1QKh`0Hg6>06=`T01VLi80J7BA06IcTP80IW:A00H0JGFA06YfT@1[Mhl0KGR?06mhS`1`
NY82075kT`03079mU01cOYH0LgfF0080MGnJ00/0MH6L07F0V`1fPIT0Mh>H07N3UP1gPYD0NXBE07^5
UP1kQIL0O8JJ07n9W002082:W@0;08>;W`22RYl0PhfQ08>>X@22SIl0Q8fO08F?X@25T:80Qi6T08NC
Y029U:<00P29UJ<03027U:80R9JT08ZIY`2;VJX0S9R/08jJ[P2>VZ/0Si^[09:MZP2EWZX0UYn[09NP
Z`80UJ2Y00/0UZ>Z09JSZ02GY:H0UZ>V09NUYP2HYjH0UZFT09JTX`2IYJ<0V:>Q09JQW`0209NRW@0;
09JQVP2IYYX0N81k03Pc?`10?T@0@D9404=6A@0n@3l0>cll05AODP1BG4l00P19CdL0301=DTX0HV]O
08>BP02;VhT0V:^E07b8NP10@DD0?3e306=]I`2J[iT0QiZ808VMR`80R9f;00/0RYj;086DP`0X;3<0
51DM01TL7P0I6QT05QLB01<C3@0A4@/051H>01PL4P0201PM4P0;01/O4`0N8QD07AlF01`M5`0K7AX0
6QdN01XK8@0I6B4061XO01DG600@50h00P0P:1T01P0[=200<CTU03<l:@0c?BX0<S`Z038j9`oooooo
000=ooooo`0606MeS01ZNiH0KH6O06f4XP1_Q:@0LhJW0P1bQJL02`1aQJL0KX>U0724YP1cR:P0M8RV
07J9YP1iRjL0NXZV07f<YP1nSJL0OhfW0080OXbV0P1nSJH02@1oSjP0P92Y082@Z021TJP0PI6W08JC
ZP27TZd0R9>_08RD/00308RD[P0;08^E/02=Uk<0SIRf08^E]@2=V;H0SIZe08jJ/`2=VK80S9Rf08bG
]P2;UkD00P2<VK802`2=Vk80T9bc09>M]02CWKH0UIjh09>L^02AV[T0Ti^i09>L^02CWKP0Tijj0080
Tj2k00/0TJ2k09>Q_02EXK/0U9jj09FP_02EWk`0UZ2j09VR^P2KXkX0Vj>k09^T^`0209ZT^`80VZ>i
00P0VZ>h09ZR^02KXkX0W:Fk09bV^@2LYKT0W:Jl09fU_`<0WJG000`0WZO209jV`P2NY/40WZK009fU
_P2MYKl0WJBn09fU_02LYK`0W:Fj09bV_02LY[d209^T^`0;09^S^`2MY;d0WJBn09fU_`2LYKl0W:Fn
09ZU_02KYKX0W:Nh09nY^@2NZKT00P2MZ;T02`2LYKP0W:Bg09bT^@2MYKT0WJJi09fU^@2KXkL0VZ6e
09VQ]P2KXkL0VZBh0080VZFh00`0VJ>h09NP]@2EW[@0UYjd09FO/P2EWk00Tij^09:M[@2BW:`0T9Z/
08nJ[02=VJT208jJZP0;08jIZP2@VZd0SYV]08fHZ`2;UjT0RiFW08RBY029TZD0RI>U08JBX`25TJ80
0P24TJ801020SIh0P8fO082>X@20Sj0207b=W00507f=W01mS9X0O8^H07V6UP1fQIH00P1gR9L01P1d
QI<0LH:>0723R@1_Ph<0KX:006]oNA[ooooo00H0?TQO041<I@12CVP0A4mX04A>J@15Cf`204I?KP0;
04IAK`17DG00BE5a04QAL019DW80BU=c04YBL`1;Dg@0CEMg04eHM`1=FGL00P1>FWP0201=FGP0CUUi
051JN@1BG7d0Def005IOP@1HHX80Ef>20P1GHh403`1JIX<0G6N405aWQ01MJHD0Gf^905mZR`1OJXX0
GVZ9061]RP1QKXX0HFj;069]S01SKhh0IG6>06EaT00206A`T00906UdTP1YMI40JWJ?06afSP1^Mhl0
KgZB06mjU@1^NIH0KWZE0080LWjH0P1dOi/02@1eP9d0MH6K07F0V@1fPIL0Mh>G07R2U`1iPiP0NX>H
07^5V`0207b8WP80OHVO0P1oRj002@21SJ00PHbN082<WP21S9h0PhbN08F?X025Sj40QY6S08NBX`02
08FBXP0<08FCX`26UJD0R9JU08VHYP2;VJT0SiZ[096K[02AVZ/0Tib/09FM[@2GWjd0UinZ0P2EX:P0
2P2EXZP0U::V09>RX`2CXj80U:BR09JTX`2EY:<0UJBR09NUX`2GY:8309JRX00;09FQW02IYi`0KG=`
03D^>P0m>400@D1504Y>C@11AT@0>Cdj055LC`1@FTh00P1AFDh0301;CdP0G6=J08BBP02:VHD0Ri^4
08VHPP15ADL0<2dh06A^J`2J/9d0QYV:08^MS080QYN700/0RY^8082AO`0T92`06QTP01dN7P0I6AL0
5ADB018B3P0C4Pd061XB01`N500201`M5@0;02/a8P0X;Al082<G02LW800W9BD0@TE4038d>@0W9bd0
9RPY01PI6@0C50l00P0T:QX01P0Z<Qh0;SHS038j9@0c>bL0<cdX030i90oooooo000=ooooo`0606Md
T01/O9`0KX:T06n5YP1`PjD0LXBW0P1dQZX0101cQJX0LHJZ07:7Z@1dRJH207N:Y`0507V:Y`1kS:P0
O8fX07j?Z01oSjL00P21SjL02`1oSJL0OXbW07n>Z@21Sj/0PI6[086BZ`21T:T0QI:/08JB[`26TK00
Qi:_00<0RIJ_00/0RiJ_08^F/@2=U[D0S9Jh08ZE]`2:U[L0S9Rf08jI^02>VkX0S9Vi08^H]P0208^I
/`0;08jL]02@Vk<0Tibe09>L]P2FW[P0UIbh09BL^02EVkT0UIbi09>K]`2DW[X00P2EXK/02`2DX;/0
U9nk09RR_P2IX[h0V:2m09NP^`2IX;/0V9nk09VO_02LX/00WJC00080W:Bn00/0VjBm09bU_02LY[/0
Vj>i09^S^02LYK/0WJNl09^T^02LYKX0WZFo09jU`P0209jV`P0:09nW``2PYl<0X:K209nU`P2NYL80
WZK209jW`@2NYl00WJNn09^V_@80VZJo0P2KY[l02`2KYK`0WJBl09bS_@2JX[h0VjFo09^V_`2LY[d0
WJNl09jX^`2MZ;P0WjZg0080X:Zg00/0WjRg09nX^02NYkX0WjNk09nW_02NY[/0WJFi09fS^02LX[P0
W:Bj09fU^P0209bV^@0<09^S]`2HXKH0VJ6f09RQ]P2GWkD0UIjd09BM]@2CW[D0TYbc092L/@2@WK00
T9f]0P2AW:h02`2AVZd0T9V]08jH[P2=Uj`0RiFZ08^FZ`2;UZX0S9NY08^GZ027UJD0QYBT0080QI>U
00/0Pi2S08:?Y022T:L0PY2V07j>XP1kRj40Nh^O07^<W01jRiT0N8NH07N5VP0207R7V`0607F5UP1e
QY80M8J=07:5Q`1`Q840KH9j6_ooool01P10BF40@D]U049=J@13CV`0@diZ04A>J`80A4e[00D0A4e/
04M@KP17D6l0ATm^04M?KP0204UAL@0404YCLP1;Dg80C5Ed04aFM@80CEMe00/0CUQg04mHN01@FGP0
DEYk055JO@1DGH00Ef2105IRP@1HHgl0Ef=n05UUP00205YUP00;05]VPP1LIXH0GVR805mZR@1OJHT0
Gf^9065/R@1RKXX0Hfn;06A_S01TL8h00`1TKhh02`1WLHl0J7:>06YdS`1/MHl0KGJ?06miT@1^NY<0
Kg^D06mlU@1aOID0LWbF0080M7jI00/0M7jK07AnW01dOi/0M7nH07N1U`1iPYT0NX>I07V3V@1jPi/0
NhJN07b7W`0207b9X@0;07j:XP1oRj80OhbP07n;WP1oSIh0P8bN08:<WP24SYl0QHnQ08J@XP26TJ80
0P25TZ403026Tj<0QiFU08NEY@28UZH0RYJV08fHZP2@VJ`0TIZZ09:KZP2DW:/0UIf[09JNZ080UIjW
00<0UJ2X09>QY@2CXJ<00P2DXj<01P2EXj80U:>R09>RX@2EXZ80UJ:Q09NRXP80UZ:Q00/0U:2M09RV
W@1bNGH0;BHd04A1A`14@dT0A4M;03Xn@P0g?3`0C5M=04eIC@02051JD00<04=7A01[MFP0T:6;07R4
M@27UX40Pi9m0451@`0Y9380HVUW09R/VP2:Vh/0SIj<0P29UhD01P2<VhL0SIj602TW:`0N6a`071/G
01LF4@8051@>00<05AD>01/M4`0O8QP00P0I6A@02`10BCL0>T8d02hb:P1HHE80?3lm05URF`0n@TD0
:BX_02T[:P0D51@06A`D0080:2dM00H0:BlL02/b7`0_=R@0<STV03<l9`0^>BD?ooooo`003Oooool0
101XLi40Lh6Q07B4Y`1cQ:L207:2YP80MHBZ00/0M8>Z07B5ZP1cQZP0MHNV07R8Z01iR:P0NXVX07b<
Z01nSJL0OhfV086>YP0208:=Y`0;08B?ZP24SZ`0Phj^08>?/022S[00Pi2a08FA/@25T[40QI6a08R@
/029T[000P29Tk00302;UK00SYRc08fG/`2<UkH0SYNj08bF^02:U;D0RY>d08fF]`2?VKT0SYVi08fI
]`80SYVd00/0TIbc09:L/`2CVk<0UIbd09JM]02FW;80UYfc09NM]@2IW[H0UYbf09JL]`0209RP^@0;
09VP^P2GW[X0VIjk09ZP_02IX;X0VJ2i09ZO^@2LX;/0Vijm09bO_@2MX;h00`2LXKl02P2LX[l0WZBm
09fS^@2KXKL0WJBh09nV^`2NY;T0Wj>i0:2T^`2PXkh209nS`00:09nU`@2QY/40XJG00:6U`02OXl00
WjC109jT`@2MXl00WJBn09bS_P80WJG00P2MY[h02`2OY[/0X:Bi09jS^@2MX[/0W::l09^Q_02LY;`0
WjJn09nU_@2NYKX0WZBg0080WZ>f00/0Wj>f0:2U]`2NYKL0WjFi09jT^P2MXkT0WJ>h09bQ]@2LX;<0
Vinc09^P]@0209fR]P0409^P]02IX;<0Uijb09NN/P80V9jb00H0Uibc09FL]02CVk<0TY^`09:J[`2C
Vjh209>J[`0;092F[02?UJ/0SYBY08jEZ@2<U:T0Ri>Y08V@Y@29Tj@0R9:Q08JAW`25TJ000P24T:40
2`23SZ80PhfR08>=YP20RjD0NhRQ07^9X01kRYh0NHNJ07R6V01fPiH0MX:F0080MX>F00H0MH6C07F2
T01dPXd0LX:906n0P@1ZO7PJooooo`060458G`10B680@T]X049;J`12C6/0@D][0P12C6/204A=K080
ADi^00L0Adm^04I?KP18D6h0BE9]04UBK`1:Dg40C5Ac0080C5Ab00/0CEEd04iFM`1@F7L0CeYg051K
N01CGG/0E5mm05EQO@1EHG/0Ef9j05QSO00205UTO@0<05UTP01KIX<0GVV5061YQ@1QJHL0H6Z7069/
R01RK8T0HVf9065]R`1SKhh0I72>0P1ULXl02`1WLXl0J7>?06YdS`1ZM8h0JgF>06egSP1^N8l0KWV@
071jTP1`O9@0L7bF0080LGbG00/0LWfH079lV01cOIX0M82I07IoV@1hPIP0NH:G07R2U`1iPYP0NH>I
07^6V`0207f9WP0;07j:W`1nRZ00OX^N07f:W@1oS9d0P8fN086=W`22SZ40PhjP08F@X026TZ000P27
TZ80302:UJ@0RYFU08VCY02:U:D0RiFV08jGZP2?UZX0T9VY09>LZ@2CW:P0U9fX09JOZ080UZ2W00@0
UZ6W09FRY@2FXjD0UZ>T0P2FXZ<01@2EXZ<0UJ6S09FQX`2EXJ<0UZ6R0080UJ6O00/0UJ6K09JTW01o
R8@0:bPe06M_J@1<CU40BTe>03i2A@0`<cP0CeQB04mHD@0204mGDP0<03e1@P1VLVH0W[JI079oL@25
UH40MX=d03/k@@0a;c/0Ff5R086AQP26UXP0SYj;0P29Uh802`27UWl0SIj302l^;00O71X07adF01/K
400H6@h05aP=01LI3P0K7A406alD00805ATB00/08RLO04eHA`1JIUH0KWeZ06A]H`1^NFd0G6EM04Q>
B00f?3L06a`L024S7@0202HZ7`0602T_800]<R<0;c@U03<i9`0e?BT0<3TV3oooool000gooooo00H0
I6f:06YgUP1`Oj40KgnS07:1Y@1bPJH207:0Y@0;07F4Z01fQJP0MXNX07J6Z01hQjP0NXVW07^:YP1k
RjD0OHfU07j;Y@21SZL00P20S:L01022SJT0Q8f]08:=[`21S[42086>/P05086?/022TK00Pi:`08FB
[`27T[000P29T[401P2:Tk80RYBc08ZD]02;U[H0SIJg08fF]P80RiJf00@0SYVg08nJ]@2=U[80S9Ja
0P2>Uk802`2@V[<0TI^d096K/`2BW;80TIZa09>K/@2FW[80UYbc09JK]02FVkD0UYbf00<0Uifg00X0
Uijh09ZP^`2JXKd0VZ2j09ZQ^P2KX;T0W:2k09bP_P2LXKh0VZ2m0P2JXK`0102JXKd0Vj:m09ZP^@2K
X[P209bT^00509fS]P2OY;L0WjBh09nR^02MX;P00P2LX;P01P2NX[/0X:Fm0:2T_@2PY;l0Wj;009nR
`@80Wj?100@0Wj>o09jS_@2OY;h0WZFl0P2OYKP01@2PY[P0WZ>f09bQ]P2NX[T0WZFl0080Vj:k00@0
WJ>k09nS^`2NX[T0WInf0P2NXKP01@2NX;L0Wj6g09nR]`2NX[L0Vj:f0080VJ2f00@0Vj6f09RN/P2I
X;80VInd0P2HWkD0302GWk@0UYjd09JN/`2GWk40Uij^09NL[@2GW;00UI^a09:J/02AVJl0SiJ/092G
[080TYV^00/0T9FZ08fCZ02=U:P0Ri6V08^BYP2:TJH0QhnS08NAXP26TYl0QI2K08FAW@0208:=W00;
08:=W@22SIl0PX^P0828XP1mR:80O8NO07f:W@1kR9X0NXFH07N2U@1dP9400P1ePI<01P1fPY@0M82A
071nS@1^OXT0KGj106QkMa[ooooo00H0@DQN049;H`13C6L0@T]Y049:J`12BV`204A=K`0604A=KP14
C6d0ADi^04I?K017Cf`0B55]0P17D6/00`19DVd0BE9_04aEL`0204eFM@0;04eFMP1>EWP0D5Qk04mI
N@1@G7T0DUej05EPO@1EGg/0EEmj05QRN`1HHg/00P1IHgd0101KI800FfF105eUPP1OIh<2065XQ@06
069ZQ01QJX@0HF^5069/Q`1TKXX0I6n<0P1ULHd02`1ULXd0IW><06QdS01YMH`0JGF906afR`1^N8d0
KgV@071iTP1aNi@0LG^F00<0L7bG00X0LGbH079lV@1dOiX0MH2I07J1V01eP9H0NH:G07^2V01kPiT0
O8FJ0P1mR9`207n:W@0907j:W01nRYd0Oh^N086<WP22SJ00PhnR08B?X025T:00Qi:R0080RI>S00`0
RIBR08RCX@29U:80RIBR08bFYP2>UZT0SYJZ092JZP2BW:P0TYbV09BMYP2FX:L209JQYP0409FQY@2F
XJH0UZ:U09JRY@80V:>V00D0Uj>V09NRY@2GXZ<0UZ:R09JRX@0209FQW@0;09BPV@2FY9T0QY6902l/
>01@E5@0CE5@04mED@0n@d80;Bld051ID`1>EU800P1>EU003015BdP0D5UC09B/T@24V880RIj607R8
N01FGE`0@45;05mVJ`1VKW40QIB:08nPSP80RY^400/0QYAk07j>LP0Z:RD06aPE01hL5@0I6@l061T>
01PJ3P0H6`d06Qd?01`O4P0201`O5@0;018B3@1:DT40NhYa06mjJ@1cOg00MX=e071oK`1XMfH0@4Lo
02@V900Z;BH00P0[;b<01P0[<B80;C<S02ld900`=RH0=3XX034g9`oooooo000=ooooo`0606=^RP1/
NIH0LH2P07>2Y@1cPJD0LH2T0P1bPJ@02`1eQ:L0N8NY07V9Z`1hRJX0MXRW07N9Y01iRZ<0NX^R07f=
Y01oS:H0P8bY0080OhZY00/0OhZ[086;[022SJd0PHf^086?/020SZl0Ohj/07n@Z`20TJ/0Pi:[08BA
Z`0208FA[P0;08NB/@28U;80RIFb08ZE/@2:Tjh0S9Fb08fG]@2>VKH0SIVf08jJ/`2=VK400`2=Uk40
202?V;80SiVb08jI/@2>V[40SYRa096J/P2DW;@0UIbf0P2DVkL03P2EVkL0Uibi09NL^@2GW;T0UYZh
09NL^P2IWk/0VJ2j09VQ^@2JX;L0VYng09ZP^P2JXK`0VJ6k0P2GWkP02`2GX;L0VZ:g09RQ]02IXk@0
V:>c09RS/P2HX;00Vj:b09fS]P2NY;L0WZ>g0080WZ>f00`0WjBg09nS^@2PY;/0X:>l0:2S_`2NXkl0
WjC009jR`02MXKh0WJ:n09fS_02JX[L209^R]00;09^S]@2LX[D0W::f09^Q]P2KX[/0Vj>k09bS^P2K
X;L0W:6e09fQ]P2LWkH00P2LW[H02`2MX;H0W9ne09fQ]P2MXkL0Vj:g09RN]02FW;<0UYjd09NO/P2G
Wk40Uijc0080UYne00`0UIfe09>K/`2CW;80U9fb09BM/02CVjh0Ti^_096I/02?Ujh0SYN/08bEZ@2=
UZT208nFZ@0;08fDY`2<TZ@0RY2T08R@X`26Sj40Qi2R08J?X@25Sj40Q96Q08>AW@20SiX00P1oSYT0
2`20SY/0P8fM082;WP20RZ00OHRO07b8WP1lR9d0NXJH07V3U01hPY<0MH2A0080LgnB00H0Lh6E071o
T@1^OX`0K7f506YlO`1WNWLJooooo`0604=9HP14BVH0@dYY049:JP12BFX0@dU[0P13BFd01@14Bf`0
A4Y[04A;JP15CVX0AdmZ0080ATeY00@0B51Z04UBK01:Dfh0C5=`0P1=E7@02`1<E7@0BeAe04mGN@1@
FG/0D5]m055KO01CGGd0E5im05ANO01FHGd0F69l0080FV=l00`0G6=n05eTP01NI840GVB1061XPP1Q
JX@0HFZ3061ZP@1RJh80I6f506I^Q`1VL8T206A`R`0;06EbS01ULXX0IW>:06MeR01XM8H0JWF706]e
R@1]MX`0KgR>06mjT01`NY400P1aNi802`1`O9@0LWbE07=lU`1dOYP0MGnG07AoU@1dOi@0Mh6D07Z2
UP1lPiP0O8BI0080OHFI00/0OHJI07j8V`1oRY`0OXNL082:W`22RZ00PX^P08B<X024SYl0QhnO08N@
W`0208NBX00<08RBX028TZ40R9>S08ZDY@2;UJH0S9FW08jFZ02?VJT0TIVX09>KY@2FWZ@0UIjR0P2E
Wj40202EWZ40U9jR09FQY@2EXJD0Uj>V09RRY@2GXZD0UJ6T0P2FXj803P2EXZ00Tj2M09>PW@2CX9X0
TZ6G08bKSP0j>D00@TA605]SG019DD`0>Sll02HY:P1=Edd0CEE=0P1>ETh0301<DTT0GfUK096VR`1f
QWH0Oi1o08:CP`1kRG`0G61Q04a;E@1_M7D0O8B008fKS@80RYZ600/0QYEn07f>M00X:BH071/I01`L
5`0G6A005aT>01LK3`0E6P`061/<02HZ5`0202X/7P0;01LD400o@CL0Ohme06egJ@1bOW00M8=d0721
L01YNVH0?4Dl01`O700[<2L00P0/<RL01P0/<bD0;3@T02de9@0^=bL0<3PY02lg:@oooooo000=oooo
o`06065]R01ZMi@0LGfN079nX`1aOZ<0LGnS0P1dPJ802`1gQJ@0N8NW07V6Z@1hQjT0MhVV07F8Y01g
RJD0N8RS07^;X`1oS:H0Oh^Y0080Oh^[00/0OX^Z07n:Y`21SZL0Pi2Z08>@Z`21Sj`0P8n/07n@Z@20
T:P0PY2V08>@Z00208B@[00<08F@/027Tk80RiJa08^E[P2=UJh0SiJa08nG]@2?V;P0SYNg08jH]P2<
U[40SYN`0P2>UJh02`2?UZl0T9N`08nG[`2>V:l0SYN_096H/02BVK<0TiVe09>H]`2BVKT0TiZi0080
UIbh00/0UIZg09BI^02FVkT0UYbh09JN]`2FW[@0V:2d09ZP]@2JWkH0VJ2i09VQ^P0209NO]P0609JN
/`2HX;40VJ2`09ZP/@2HX;40V:6b0P2HXK400`2IXK80Vj>f09fT^@0209bS]P0<09bS/`2LX[80WJ:c
09nR]@2OXkP0WZ>i09jT^P2MX[X0Vini09ZO^@2JX;X0Uijg0P2HX;H02`2JXKH0VZ:f09bR^02LXKT0
VIni09ZQ^@2JX[P0VZ6d09ZP/`2MXK@0WJ6f0080W9ne00/0VYfc09RM/@2IWK40WJ6c09^P/P2HWK80
UI^c09JM/`2EWZl0UIb]09FK[`0209>J/@0<09BL/`2CW;80TYba09:K[`2AVJh0T9R^08nG[`2<UZh0
RY>X08ZDY@2;UJ<0SIJT0`2<U:<02P2;TZ80RI2Q08VAX027T9l0R92O08V@X027Sj40Q8nQ082=W@1o
SIT207f;U`0;07n=V@1oRiX0P8ZM0828WP1nQih0O8JP07Z5WP1iQ9T0N8:D07R0U01gOiH00P1dOIH0
1P1bOYH0KWfA06anR`1[O8<0JGam06QlMa[ooooo00H0@dIO04E8I@15BFT0A4UZ04E:K015BF`204A8
J`0;04A9J`14BVT0A4YX04E<J015C6T0ATeZ04E=J`16CVd0BE9^04]DK`1<Dfh00P1<Dfl02`1<EG00
BeAa04aCL`1?EWL0D5Yk055KO01CG7d0E5in05IPO@1FHG`0Ef9k0080FF9j00`0Ff9k05eSO@1OI7l0
GF>005iUP@1RJX@0HV^4065[P`1SK8@0I6f606E^R01WKhT206M`RP0;06Q`R`1XLX`0J7>;06YdR@1Z
MHL0JgF706]dR@1/MH/0KgR<06miS@1^Mh`00P1_N8h02`1`NY00LG^A079kTP1eOYD0MWjF07MoUP1g
OiD0N86D07^3U@1lQ9@0Nh>E00<0OHFG00P0OXJI07n7V`20R9h0PHVQ0828X@21RZ80PX^P08>=WP80
QXnN0P28T9l03029TJ00RY:S08^CY@2=UJP0SYFY08fDZP2>UZT0T9RY096IY`2DVjH0UYfT09JNXP80
UYnR00X0UInQ09BNX@2DWj<0UZ6U09FPY`2EWjD0UJ2U09BPYP2EXZH0UJ:T0`2DXJ402`2AWid0SifG
096QU@16B4/0@4A507>1LP1;DTd0?44n02LY:`1;ED/0C5I<0080CEM<00`0Ade4051EBP1nSGH0MhEb
07^8MP27UX<0Pi6007V1M@0n>D40I6IV07ImN02;UhX208RFQP0;08FEP@1kSGL0<3@_01TI600N7aX0
5aTC01@F3`0E6@l04aL=014E2P0g@bT00P1=FCd02`0F5100CUA707Z8L`1/N6/0LGia07>2M01aPg<0
JG]X049=@@0]=Bd0<C/_0080;SH[00H0;3<W02`e9P0/=RD0;STW02hi:00]=bL?ooooo`003Oooool0
1P1PJhD0JGJB06mlW01bOZ40L7bR075nX`80M86R00/0Lh6R07F3Y@1hQZP0MhFV07N7YP1hRJH0N8ZV
07V9Y@1jRZD0NhZS07f:Y@0207j;Y`0;07j;Z01nRj@0Oh^R086=Y022SJH0PhfX08:?Z@21SjP0P8nW
08>BZ024TZP00P24TZX02`25TZ`0QY6/08VC[029TjX0RiBZ08fD[02?UK00SYBb08nE/`2>UK80SI>_
00<0SiJ_00T0SiF^092F[@2AV:l0TYV_092G[@2AUZh0TYN_09:G/P2CV;L00P2AV;T209>I]`0;09:J
]@2BVKH0TYRe09BJ]P2FWKH0UYfd09JL/P2HW;<0V9be09FI]P2EVkH00P2FWK@02`2GW[40Uif^09VM
[`2IWJl0V9j`09NN[`2FWZh0Uij^09JN[P2GW[80UYfd0080UYje00`0UZ2b09RR/02KX[00WJ:a09jR
]02MX[D0WZ:g09bQ]P2KX;D0VInd09RO]@2FW;@209FM/`0;09JN]02GWK@0VIfe09ZO]`2HW[D0V9jg
09RO]P2FW[<0Uijb09VO/@2JWk<00P2LXK@02`2JW[<0VIfb09VL/02JWK80VIba09VM/`2GWKD0UYfb
09FK[P2BVJ/0U9Z]0080TiV]00`0TYV`09>J/02BVjl0TIZ]08nFZP2>UZX0SYJ/08^DZ`29TZD0RYBS
08fDXP2>U:0208nDX00;08bBX@2;TZ00Ri:Q08ZAW`28T9d0QHfJ08J=W029Sj00QHfP082:W@1oRY/0
0P1mRIP02`1oRYP0OhRI0828VP21R9`0OhFM07b2W@1iP9`0NH6K07QoV01gOIH0MWbG0080MGbG00H0
LWfE06ilT01ZNhP0JWb306UlOP1XNgPJooooo`0604=6H014B6D0ADUW04E9I`16BFP0ATQY0P17BVT0
2`16BVT0ADYX04E:J@15BfX0AD][04A<J`15CF`0ATe^04U@L@19DG00BU9_0080BU=^00/0BeE^04aF
KP1=EW00CUMd051IN01AFWX0De]m05EOO`1EH7d0E5mk05IPN`0205UQN`0605QON@1JHGX0GF=l05iR
O`1OI840H6F30P1PIhD0101QJH@0I6b606A[Q`1UK8L206I^R00406M^R`1XKh/0J72906UbR@80JG:8
00D0JW>906]dRP1/MXT0KWV<06iiR`0206egRP0;06miR`1aNhd0LW^>07AlS`1fOI40MgnB07MnTP1i
PI<0NX:B07^5T`1jQ9800P1kQ9D02`1kQ9L0OHFI07n7W020Qj00PHRR0868X`21RJ40PHZP086:W@23
S9d0QXnM0080R92M00`0Qi2O08RAX@29TJ80S9BT08jGY`2?UjT0SiJX092FY`2AV:H0TYVV09BKY02E
WJ@209FNY@0;09BNX`2CWJ40TifQ09FPY02EWjH0U9nU09BPY`2DXJP0Tj2X09:PYP2BWj800P2BWil0
2`2?WI/0SY^G09:RV@1PIfL0;2Tf06MaJ01CFe@0@4I102d_;`1>F4`0CEM;0080BE5700`0?3lj0454
?@1KHe@0MH9[08BDN@2:Vh80QYEo08>?O@0j=ch0FeeN07R0NP25THH208BAQ00;08BEQ01gR7H0<CDd
01/K700O81d06Q/G01DG4P0B5@d04A@<00h@2`0e@2`00P1;F3l02`0B40/0ADXl07F2K01]N6/0Kga`
07:1M01bPg<0L89_04IAA`0^=Bh0<SX/0080;CDU00<0;38S02hd900]=2<00`0^=b@?ooooo`003Ooo
ool01P1SKXT0JgRE071oW@1aP:00LWnQ075nXP80Lh2T00/0LGjR07B1Y@1fQJL0MH>V07J5Y`1hR:P0
NXZY07^:Z@1jRJT0Nh^W07n?Z00207n=Y`0;07n;YP20S:H0PHbU086<Y@21S:L0P8bW086=Y`20SJL0
PHnX08:@Z023TJT00P24TZX01@26Tj`0Qi>/08VDZ`29TjT0S9F[0080SIFZ00D0S9>[08fD[@2=UJh0
SYJ`08fD[`0208jE/@0308fE[`2>Ujh0SiR^0080T9J^00H0TIN`096G/`2AUk@0TYNg09:I^@2CV[X2
09>J^@0709:J^@2AV;P0TIRf096J]@2EWKD0UYfd09JL/P0209NL/`0?09BJ]02EVkL0UIbf09FL]P2F
W[D0Uife09RM]@2IWK<0VIna09RO[`2GWjh0UIb/09BL[02DWJl0U9bb0080UYnd00`0UInc09RQ/`2I
X;80VZ2c09bO/`2LX;H0WJ2g09bP^02LXkX0Vj:i09^Q]`2KX;H209^Q]@0;09VP]@2GWK<0Uibc09NM
]02GW[D0Uijf09RO]`2FWKH0Uije09ZO]@2HWK@00P2JWkD02`2IWK@0VYfc09bM/`2KVk@0Vi^e09VK
]P2GW;@0UYb^09FL[@2CVZ/0Ti^[0080Ti^/00`0TYV/092G[02@V:`0SiN/08nH[02=UjT0S9JY08^F
Z@2;U:D0S9>S08fCXP2<TIl208fBX@0;08ZAX@27Sih0Qi:M08RAW027Si/0QHbL08B;W@25S9l0QXfP
08::W`22RYh00P20R9d02`1oQi`0OhFK0824W@20Pid0OH:M07^1W01jP9d0NH2L07MnV@1eOIT0M7fI
0080M7jH00H0LWfC06aiR`1ZN8P0JGZ506IhO`1TMgTJooooo`060455G`12AV80A4MT04I8IP16B6P0
ATQZ0P16BFX204E9J@0404A:J@13BfT0@d]X04=;J@80A4aZ00<0ATi/04UAK`1:DW400P1:DW402`1:
E700C5I`04aFL01=EW40CeMd051GM@1AFGT0Deam05AMO@1DGW/0EEmk0080FF5l00`0FF1j05YRN@1L
HWX0GF5l05mSO`1OI840GfF2061WP`1SJh80Hf^106EZP`1WJhH206Q[Q`0306M/RP1WKHT0Ifj80080
Ig2900H0JG::06YcRP1YLX/0J76:06YdR`1YM8P206YdQP0;06egQ`1]MhH0KWR7079kR`1eOHd0MWn?
07R0T@1iPI40NH:@07V4TP1hPi800P1iPi<02`1kQID0OXJG07n7VP1oQYd0OhJN07n7W`21Rj40PH^O
08:;WP24SIh0QHjM00<0Qi2M00/0R96O08RAX02:Tj40SIFS08nGY02@UZ@0TYNV09:IYP2BVJD0TYZS
09BMY00209>OX`07096NX@2AWZ00TIjO09>OX@2EX:80UInR09JQY@0209>PX`0?09>OX`2CWj40TYjN
09:NWP2AWI`0TIjI09>RVP1_MgH0:BDc04E9B012B4<0=c/g03Pk=P1=EDT0C5A70080CEI900`0@TPo
03Pl=P0o@c/0IG1L08RHOP2BXh/0RIJ308F@PP10?4H0KGA`07V3O026TXP208FBQ@0;08FDQ@1iQgL0
;2d_01`L7P0O7ah06AXF01@F400A50/0418900l>2@0nAC@00P1FHd/02`0A3`l0<38^07:1K@1[NFX0
KG]^0721LP1aPg80L89_05MVE@0b>2h0:BdQ0080:c0O00H0;38O02dc800^=240;CDR02`e8`0/=28?
ooooo`003Oooool01P1SKHP0JGND06elV`1`Oil0LWnO079oX@80LWnR00X0LGjR07>0Y01dPJ<0MX>T
07^9Z01kRJT0NhZY07Z9Z01jRJT0O8ZY0`1oSJ/01@1nRZX0Oh^Z086<Z@22SJX0P8bY0080PHjZ00@0
PXjY08>?Z@23T:X0PhnY0P25TJ/03026TZ/0QY6[08RC[02:UJd0RIBZ08ZEZ@2:U:T0RY>Z08ZBZ`2:
TJ`0Ri>^08fD/080S9B_00/0S9>]08fD[P2=Tjl0SY>^08fD[P2?UK00TINc092F]02@UK<0TIJe09:H
]`0209:I^@0;096H^@2AVKT0TYVh09:J]`2DW;H0UYfd09FL/`2CV[00UI^a09BK/P2DW;@00P2EW;H0
2`2FW;P0UY^f09JK]02GW;<0Uifa09JL/02DVjd0U9^/09BM[P2BVjl0U9bb0080V:2f00`0V:2g09NO
]`2GW[D0VIne09ZO]@2IW[D0VYjg09^O^@2KX;/0Vj6i09fR^02MXK@309^O/@0309ZN/`2IW[D0VIje
0080Uife00@0V9jh09RM^02HWKH0VIfg0`2IW;L02`2HV[D0V9Zc09RJ/P2JW;80VIZc09NJ]02EVK00
TiZ[09BK[@2CVjl0TIV]00<0T9V/0P2?Uj/02@2=UJX0Ri>X08fEZP2=UZX0SIFY08fEY`2=TZ@0Ri6S
08Z?XP0208V>X@0;08R?X@25SYl0QHnL08B>VP25SY`0QHfM08>;W@22RYd0PhZO0869WP20R9h00P20
Qih02`1nQ9d0OH>M07f2WP1mPYh0Nh2N07UoW01gOY/0MGfI07=lU@1`NY40L7^B0080LWbB00H0LG^?
071jS01/MhT0JWJ706IfPP1SMG/Jooooo`0603i5G010AUh0ADUR04M8IP17B6P0ATMX0P14AVP02`14
AfP0A4QX0498I@12BV@0@T]U04=<I@14CVH0A4eV04=<IP16CfT0Adm/0080B51_00T0B51^04]CL01<
E700C5Ia04iGL`1?F7D0D5Yh059LN`1DG7`00P1DGW`205MPO@0<05URO01JHW/0G6=k05eTO01MI7d0
GVEo061WP@1QIh40HV^1065YOP1RJGl0Ifb20P1XJh<02`1XJhD0J6f806I]R01VKXT0IVn:06E`R@1W
LXX0Ig6:06I^Q`1WKhD0IVj30080I6b100/0IFf106M_PP1UKX40Ig6206]dQ01]MHH0KgR8075kR01a
O8L0M82:07N3SP0207V5T@0907^7U01mR9H0OhVI07n8V@1oRIX0OhZJ086<VP22SIT0PhfJ0080QHjM
0P25Si`03027TId0RY:P08^BX@2<Tj<0S9>U08jDYP2@UZD0T9NT09:IY@2CVZD0Ti^T09:LX@80T9fO
00/0T9jP096NW`2@WYl0Tj2O09FQW`2EX:00UJ6R09BPXP2DX:<0TinQ09>OW`02096NW@0;08nMVP2>
W9L0TJ6H06efM00/:3H0=C@g02d];P0S8R@0C5A5055KB@1?EdH00P1>ET@0300oACH0>Chb03Dg<01G
GU40XkVJ09:RSP2;VHP0R9B404M4B@23S800QHn408ZER080R9B600/0Q9:007j<M`0a<Rl05aHG01hO
6`0J6QD05QL>01@D2P0B4PT03P`5049:=P0205UUCP0;01HB4`0f>SL0IgIY06AcJ01WN6`0JWe^06b0
KP1XO6L0EFEA02he:@0Q9QT00P0Y;ah202`a7`0402/c800]=R80;3DS02Xc8Poooooo000=ooooo`06
06=^Q`1XMI80K7^J06mmX01aOj<0LWjS0P1`OJ402`1aOZ80M86T07B1XP1fPj80NHJV07Z8Z01iRJH0
NHVT07^:Y@1nS:L0OhbY0080OXf[00X0OH^]07j<[01mRZP0P8bY086=ZP23Sj/0Phj[08:>Z`23SZ/0
Pi2/0`24Sj/02026TJh0QY:^08JA[@25T:/0QY>[08RF[028U:`0RiB]0P2:Tj`03`2;U:l0Ri>`08^C
[@2;Tjd0S9B^08nE/02?U;40T9Fb08nE/@2AUjl0TYR`09>H/@2CUk40TiRc09:H]@0209:G]P0;096F
]P2BV;H0TiZf09BK]@2FWKH0UIbe09>I]02BV;80U9Zb09BK/P2EVk@00P2EVkD02`2EVkL0UY^d09VM
/P2IW;40V9^`09NK/02FW;40U9^_09FL/02CVjl0U9^`0080UYfc00@0Uije09NN]P2HW[L0VIjf0P2I
WKD01P2IWKH0VI^f09RL]@2HWK<0V9fa09VM/080VIf_00L0W9nc09bO]P2KW[L0VYff09RL]P2IWKH0
VYjg0080V9bd00l0V9^e09RJ]P2IW;@0VIbd09RL/`2GVk80Ui^a09RK/@2FV[40U9R`09:I[P2BV:`0
TiR^09>H/02AUk000P2>UZh02P2>Ujd0SYN[08jFZP2?UJT0SI>Z08jD[@2<TZX0S96X08bBYP2<TJH2
08V>Y080R8jT00/0R8fT08J=X`25S:80PXZP08>:X024RZ40Q8RP08>7X@22R:80P8JR07j4X00207b3
W@0;07f2W@1lP9/0NgnK07YmV`1iOi/0N7nI07ElUP1dNi@0LW^B071iSP1_NHd00P1`N8h01P1_Mhh0
KWN=06YeR`1YM8L0IWB1065bNQ[ooooo00H0?DAM03m6H013B6D0ADQW04E7J015AVP304=6I`040498
IP12BFD0@TUT04=:I080A4eU00@0A4eV04E=I`16CfT0BE5]0P1:DFl02@1;D700C59b04iEM01=EG@0
CEEe04iHN01@FGX0D5Uk059JO00205AMO080EEel00`0F61n05UQO@1JHW`0FV=k05aVO01MIGd0GfIo
061WP@1QIh40HFR006=ZPP1UKH<206E/Q00;06I/Q01WKXL0Iff:06M^S01UKhd0IG2<06MaR`1XLXT0
IW2706M`QP1VKX@00P1UKH402`1VK840IVb3069ZPP1RJh40I6b106=]O`1SJgh0IFio06IaO`1XM800
K7R30080Kg^800/0Lh2=07F2T@1iQY<0NXRD07b9U@1mRYD0OhbE07n=T`20SI@0PhnI08B>VP0208B>
V00<08NAW@29TZ00RY6P08Z@X02;TJ@0SI:V08fBY02?U:@0TYNT09BJY02CVZD0TY^R0P2AW9l02`2A
W9h0TIfN09:NW`2DXJ00UJ6P09BOX02DWj80TijS09:NY@2AWZ80T9fN0080T9jN00/0SijL08ZJUP2>
X9H0LWmh02l]=P0d<S<0;B/[01lL701GGdd0FVE@051IA@0204aD@@0<034c:@0b=2X0>Sdb0495>`2J
[Xh0UjZB092OS`2<VXX0DE9A08bGQP2CWY00SIR<0P2:V8P02`24UH40PYEj03m6>@0E51807b0I01dM
5@0M71<06AT?01LF3@0A3PP0?D8b0080HFeF00/081dO04aCC@1VM6/0HG1[05maJP1OLFH0HGAS065d
G`0d?S@0:S8X02L_8P0202P_7`0602Xa800/<R40;C@Q02`d8P0[<b80:C8R3oooool000gooooo00H0
Hfj706QeTP1/NiX0KgfP075oX`1bOZ<2071mX@0;075nXP1dPJ@0M86R07J3XP1iQZH0NXRX07V9YP1i
RJ@0NhZU07j<Y`1oS:T00P1nSJ/02P1mRjd0OXb/07f:Z020S:T0PHfZ08>?Z`23SZ/0PXj[08>>Z`23
T:`308B?Z`0808JA[P26TZh0QY6]08F@Z`26Tj/0R9J/08RD[02;U:d208ZC[00?08^D[`2;Tk00Ri>]
08^C[@2<U:h0SiF`08nD/@2@UK80SiFa096G[`2BV;00TiRa09>G/@2CV;<0TYRe0080TYNf00/0TIJf
09:H]P2CV[H0U9^e09JM]P2EW;D0TiVd09:H/P2DV[80U9^b09FK]00209FK]@0;09FK]`2FVk@0VIfb
09VL/@2HVk00Ui^`09JL/@2DVjl0UIb`09>K[`2DVk000P2FWK<0102GW[D0Uijf09RN]`2IW[H209VM
]@0609VM]P2IVkH0V9be09RM/`2HWK40VIf`0P2IWJl01`2LWk<0W9nf09^N]`2JWKH0V9bf09VM]P2J
W[L00P2HW;@03`2HVkD0V9Zf09VL]02IW;@0V9bc09NK/P2GVk40V9^a09JJ/@2DV;00TYV^09:H[02C
V:h0TiR`096G/00208jF[P0:08jG[@2>Uj/0SYJZ08nEZ@2=TjX0SYB]08bBZP2<TJP0S9:V08bAYP80
RHjT0P28SZ@02`28SJ@0QXfS08F<XP22RZ00PhZP08B:X@24R:00PhNQ08:8XP20QZ80OXBP0080O8>M
00/0OH:M07b0V`1kOi/0NWfK07UoV`1hOiT0MGbF07AkU01bNi80L7V>06miS@02071hSP0606mgSP1^
Mhd0JWF;06UdQ`1VM840HG9j6_ooool01P0mA5d0?dIP04=8I@15B6L0ADMX04E6J0<0@dIW00@0@TQV
0499I@12BF@0@dYT0P14CFD01014CFH0ADeW04I?J@19DFd204YAK`0904]@L01<DW80CUEd04eEM01=
EGD0CUQh051INP1@FG/0DUYl0080E5el0P1EGG`0301HH7h0FF5m05YRO01JHg/0G6Il05eUO@1OIWl0
H6N1065WP@1QJ800HfZ206E]P`80IFb400/0IVb406M^Q`1WKHX0Ifj<06E_S@1UL8`0Ig6;06QbR@1V
L8L0Ig2606I^Q00206E]P@0;06I/P@1VK8<0HVZ2069[P@1TK840Hfeo06=[OP1UKWl0IW5o06QdP01/
N8<00P1_NhP02`1cP8d0MH:A07V6T`1jR9@0O8VE07f:U@1oS9D0OhfC082=U023SiT0Q8jJ0080Q8jH
00`0Qi6M08VBX02:TJ00RY2P08^AY02=TZH0SI:T08nDY02BUj@0U9ZT09>JY@2BVj82096LW`0;096L
WP2AWIh0TYjO09BQX02EXJ00U9nP09BOXP2CWZ<0TYjU096NXP2@WIh00P2@WYh02`2?WY`0RYZF08jP
UP1bOgP0;bdf03@b<`0]:b/07a`L05MOC@1JIE00D5U50080C5A100`0<C<Y038d:P0j?C80@TDk09Z^
SP2GZY80T9n?08bJRP1ADU40S9N609>NT02=V8`208ZHR00;08BEP@22UGX0?dHi01DD4P0O81T07AdE
01dL4`0I6@l05aH=014>200m@S800P1QKEH02`0P7Al0C5==06IdJ`1QL6/0Gg5Z05maIP1QM6<0HGAO
03@n=00Z<RP09blR0080:2lO00H0:S4P02`b8@0]=240;3@R02/c8P0Y<R8?ooooo`003Oooool01P1S
KhT0JGFB06ekV`1_O:00LGfS079mY080LG^R00/0LGfR07F0X`1gPZ<0Mh6Q07V5Y01hQJH0N8NV07Z9
Y@1jRZD0O8bV07f<Y`0207f<Z@0807f<Z`1nSJ`0OhfY07n>YP20SZ@0PY2U08:?Y`23SZX208B>Z`0?
08B@ZP23SZP0PhjX08B?Z@26T:`0QHnZ08>>Z024TJX0QY>[08VE[02<UJh0S9F_08^D[`2<U[80RY>`
0080RiB`00/0RiF^08fE[P2>U:l0SiJa08nG/@2BV[00Ti^_09>J[P2BUjd0TiR`096G/P0209:H]00;
096H]02AUk80TYVb09:I/P2CVK40TiVb096F/P2AU[<0T9Jc096H/`2DV[D00P2CV[H02`2DV[L0UIZd
09NL/`2FVk80V9bc09NL/`2DV[80TiZ`09:K[P2BW:d0U9f^0080U9b_00`0UIfc09FL]02EW;@0Uife
09JK/`2EV[00UiZa09VK]02HVk@0Uibb09JK[`2GW:l209RM/P0;09ZM/`2IW;@0VYbf09RK]@2FVk<0
Uibb09RM/P2HW:l0Uib_09NK/@2EVK400P2EVK002`2EV[00UY^`09FJ/@2FV[80U9Vb09:G/@2AUk00
TIJ]092DZ`2AUJd0SiF_0080S9B^00`0RiB[08ZCZ@2;U:P0Ri>V08fCZ02=Tj`0S96[08^BZP26SjD0
R92S08Z?X`28SJ<208V<Y@0;08R=Y`27S:L0QHbV08::X@20RIl0PXVM08:9W`22Qj40PHJQ07n6X`1l
Q:400P1gP9/02`1iPIT0NX6G07YoV@1iOYT0MgfI07IoVP1bO9L0L7ZD071jT`1_NI80KgV?0080KGJ>
00H0JgB>06UbS01ULHX0IG:706AcP@1PLGPJooooo`0603i3G@10AV80@TUV04=9I`14B6P0A4MX0P13
AVL02P13AfL0@TMV04=7IP14B6H0A4UV04A;I`14C6L0ADeX04I=J`16CVd304Q@KP0:04Y@K`1:DG40
C5=c04eCL`1>DgD0DEMi059HN@1CFWX0E5]k05IMN`<0Eeil00`0F5mn05MOO@1GH7`0FF9k05]TN`1L
I7`0GVEn05mVO`1PIX40H6J2069XP`1TJh@206A/Q@0706A/QP1VKHL0J6j:06M]S01VKHd0Ifn=06U`
S@0306YbS00>06abR`1/LXT0K7:906abR@1/LHX0JW2:06M`R@1VKHL0I6b506=ZP@1TK840IFf2069[
P01SJh0206=/P00;06I_P@1XLH80K7F406mhQ@1aNhH0M7n907F2R`1hQXd0NhR>07n<T@21SI<00P24
SY@03027TIT0RI6M08ZBWP2:TId0Ri:O08bDX`2=U:80SYBQ096GXP2AV:40TYVP09>KW`80TIZK00/0
TI^L09:KW02BW9d0U9fO09JMX@2EW:40U9fR09BNXP2BWZ40TInQ092OW`02092NW@0;08nMVP2<ViH0
SInE07f<PP0o@T@0=cLd02l]:00U8Ah0G69?05]SD01?EDD00P1:DT40300h?S40=C/]03e4=@0g>C40
NhUb09^^T`2@X900S9^>06UaKP20S880OXV4086>R080S9j@00/0Q9N5086DO00m@cL05Q@A020O6@0M
71L07Q`G01/J500H5Q005Q<?0496>00206ajHP0;04E;A01PJeh0I75U06=aI`13C4/0<cTk04YHC01W
Nf40<CX_02L_900Z<bD00P0Y<2401P0Y<1h0:S8P02/c8`0/<b80;3<Q02T`7`oooooo000=ooooo`06
06=^QP1WLhl0KG^J075nX@1cOZ<0M7fS0P1dNj80201cNZ40MgjR07R0XP1hP:80NhFV07V6Y@1iQZ@0
NhVU0`1lRjH207b<Y@0;07f=Y@1oSZL0OhbU07j<XP1lS:00PI2Q08:?X@25Sj<0QXjT08F=Y@25T:P0
0P25T:T03026SjT0Qi2Y08J?Z@26SjX0R92]08VA[`28T:h0S9>_08fD/P2<UK80RY>`08^C/@80S9Ba
00/0S9Fb08^D[`2;UJl0RiF_08^F[@2>V:d0T9V]092G[02@UZ/0TIN]096G[`0209:G/00;096H[`2A
Ujd0TiV_09:G/02AUZl0T9F_092E/02@UK40SiBa08nE/@2@Uk<00P2@Uk@02`2AV;<0TYRa09:I/02C
VJl0TiR_09FJ/@2DV[40TYR_09>J[@2CW:`0U9f/0080U9b^00`0U9ba09>J/P2DVk<0UY^c09FJ/@2F
VJh0UYV_09VL]02GV[80U9Z`09FK[`2DVZ/209FJ[00;09NK[`2GV[00UiZd09FH/`2CV;00U9Z_09BI
Z`2DVZX0UI^Z09BIZ`2CUjd00P2BUZh02`2BUZl0TiJ`09>G/@2BUk80TIJb092D/@2AUJl0TIF^096E
[@2@U:`0SYB[0080S9>[00`0Ri>Z08ZCZ@2:TZP0RI2U08R?YP2:TJP0RI2W08ZAY`28TJ@0R92Q08V?
WP28S9h208V=X@0;08N;X`25RJ@0PXVT07n8WP1mR9`0OHJJ07j5VP1nQI/0OH>L07f5W`1kPih00P1h
PY/02`1gPIP0MGjE07IlUP1gO9P0MG^H07=jV@1`NIP0KWRE06eeTP1[Lhl0K7>?0080JG2>00H0Ifn=
06I^S01SKhT0HVn7065`PP1NKWHJooooo`0603]1FP0nAEl0@4MQ03m5H@11AF<0@dIU0P11AF@02`11
AfD0@TIU04A7IP15AfL0ATQX04E9J015BfT0A4YY04A:J`15C6h0ATe]0080ADe[00/0ATi[04M>K@19
Cfh0C51`04iBL`1?Dg@0D5Ae059GN01CFGT0E5Yi05EKN@0205IMN@0<05MNN@1IGgX0FF1k05YQN`1K
HWX0G6=k05iTO@1NHgh0H6B106=VQ01SIX<0HfF30P1TIh@02`1TJ8D0IVZ706Q/R@1ZKH/0JFb;06Q^
S01XL8`0JG2<06YaR`1ZL8X0KG:;0080KgF=00/0L7J=075fS@1`Mhh0KgJ>06ifS`1]MXh0K7F;06]c
R@1[LhP0JW2706]aQP0206U_PP0;06M^O`1WKWd0J6em06Y_O`1ZKh00Jg2106Y`P@1ZLX00K7J006ii
P@1eOXH00P1iPXT0301oQhd0PhZB08F<U027SiD0R92I08bCW@2=U9d0SIBL08nGWP2@V9h0TIVN096J
V`80TIZH00/0TY^K09:KW02CVih0UIbN09NMX02FWJ40U9bP09>MWP2BWYd0Tj2N09:OW@0209:NW@0;
092LV@2>W9D0TInD07j9O`17AdX0>CLh02`U9@15@ST0OhQ^05MJCP1AET/00P1>EDP03014Bcd0?dLg
0415>011A3/0LWaX09JUS02BXHl0RYN;08>>Q`22ShP0GVI[06ilM`80SJ:?00/0Oi9o082CN`0m@ST0
6aLF024P700L6QP06APE01PF4`0E4a0061HD04M=?`0206UhHP0;061]G01VMF<0IWAS06UiI`0g>c`0
6QXU02P^<@1EIeD0<Sda02L_9@0Z<bL00P0Z<B@01P0Y<B80:C8R02/d900[<b40:S8O02Xa7@oooooo
000=ooooo`0606I^Q01XLHd0K7JF071iV`1cO9d0MGbO0P1eNJ402`1eN:40N7bS07MnXP1hPZ40NXFR
07Z5X@1jQJ00NhNP07b8X@1mRZ@0OXbV0080P8fU00/0OXbR07j;XP1mRJ40OXZR07f;XP20SZ<0PXnR
08B?X024SJ40QHfU08N>Z@0208V@[@0<08VA[P29TZ`0R96Z08R?Z`29SZd0SI6b08b@/P2:S[00S96`
08^B[028T:T0Ri6[0P2<TZd02`2;TJl0Qhj/08F>ZP24T:T0QY:Y08RBYP2=UJP0SYBY08nEZP2>UJP0
SYJY0080SiNZ0P2@UjT02@2AUjT0TYJZ09:G[02@UZ`0TIN]09:I[@2AV:`0TYR]092E[@0208nF[`0;
08nF[P2?UZ/0T9JZ092EZ02@U:L0TYJY09>HZ`2CVJ`0TiVZ09:IY`2CVjP00P2CVZX0302DVJ`0TiN]
09BG[P2EVJl0U9N^09FG[P2FV:h0UYV`09JH[`2DV:d0U9ZZ09>IYP80TiNV00/0UYV/09NI[`2EV:l0
UIV_09FH[@2DV:/0U9NY09BHZ@2DVJT0U9NX09:DZ002096CZ`0;09:D[`2DUK00TiF`09:E/02CU[00
TI>^09:D[P2ATjd0TI>/092CZ`2=TZP00P2<TZH0102<TjT0Ri:X08R>Y029Sj<308R>X`0508R?X@2:
TJ80RHnP08N=WP28S9d00P29SIl02`28RYl0QHRR08>6X`21QZ80OXFN07b3V@1jPYH0O8>F07f2U`1l
PiP0O86G0080NGnG00/0MgjH07ElU@1eNiD0MWbF07=iU@1aMiD0KgJE06ifU@1/M980K7>B06]cTP02
06UaT00606E]RP1UKHT0IFj8069/Q01OJgl0GFag6_ooool01@0l@EX0?D=M0416H010AEl0@DIP00<0
@TMQ00/0@4IR0416H`11AfD0A4MX04E8J@13AVT0@dQ[04A;K015CFh0ATi_04A<KP0204A<K00;04E=
J`16CF/0BU1^04aAL01=DW40CE9b04eBL`1?E7H0DEIf059HM`1DFWP00P1GGGP0101GGWL0F5ig05UN
N01JH7X205aSO00605eROP1MHH00H6>3065TQ@1SIXD0I6N50P1TJ8<00`1SIh<0IVV606MZQP0206U/
QP0606U]Q`1YKhP0J72906M`R@1XL8T0JW6:0P1[LX/02`1]M8`0L7N<075hS01bN8l0LGR@06mhS`1`
NHl0LW^?07AmS`1eOHh0Mgj?0080Mgj>00/0M7b:079jQP1aN8@0LWN6075dQ`1^LHL0JVj406Q]PP1W
KX00IVim06Y`O`0206ecP@0;06meP`1bMhD0MWZ807UnS01lPhl0P8RB08>;T`26SY<0RI>G08^FV02>
VIX00`2@Vi/02`2CW9d0TIZK09>KW02EWI`0UYjK09JNW02CWI`0TYfK09:LV`2AWI/0TYbK0080TibK
00/0TY^K096KU`2AWI<0QY660490AP0g=3T0;BP]06AZF`2T]Y80C4e204]?A00204]@A@0<04E<?`11
B3T0?T4d0451=P1ZL5h0TIf509FRS`2=V8/0RYF;07b5PP1GFV80IW5`0P29W8`02`1mSgl0OI1n03m6
@`0E4aP07alP01XJ6P0G5aH05aHD01HD4`0F4a@0BE120080KWiW00/0I75P06QgI@1[NFL0L7i/0498
A@0H5b<0>D9202`d<`0X<B/0:34W02Pa9P0202Ta9P0602Pa9@0Y<b@0;CDS02`e8@0Z<Al0:BlM3ooo
ool000gooooo00H0JFf106ebS01cNID0MGbJ07MmW01gNY/207IiWP0;07MjX@1jOJ@0Nh2T07b4X@1l
QYl0Nh>M07b4W`1lQZ00O8JO07b9XP1oS:D00P21SZ@02`20SJ00P8^P08:<Y022RjD0P8ZU082<YP23
SjD0QY2S08N?XP27SJD0RXjZ0080Rhn^00`0RHn^08V@[029SjX0RHjZ08^?[@2>T[00SI6a08Z>[P29
Sj`0RY6[08bBZ@2;TJL208^@Y`0;08V>Y`28SJP0QH^V08>:Y022Rj00PXRL08>7W@27RJ80R8ZR08N;
X@25Rj000P26SZ002`28TIl0RI6N08bCX@2>UJ@0TINX08jEYP2?UjL0TIZY09:JZ@2CVjX0TiZ[0080
TiV^00/0T9J[08nFZ02AV:P0TYNU09>GY@2DV:L0UY^[09BIZP2CUZL0U9RV09FIY`0209BHZ00<09JH
[02DUj`0U9R^09>G[@2BUZ`0U9N]09JH[P2GVJl0V9V_09FG[@2DUjX0UIVY0P2DUjL01`2FV:P0UYNY
09FFZP2EUj`0UIR/09BGZP2DUZP00P2EUjT03`2DUjX0TI>Y092BZ@2@TZT0TYBZ096BZP2@TZX0TiF]
09BE[P2ATZ`0TYB]09:CZ`2@TZP0Si>V08nBY00208nAY00608b?X`2:Sj80RHnQ08^@X02<TJ40RHjQ
0`27S:400`26Rj00QHZN08J:W00208V<W@0;08R9W026QYl0QHFQ0865XP1nPil0Nh>H07b4UP1mPiD0
O86D07j2U`1lP9L00P1kOYL02`1iOIL0N7fG07QlU@1gNY80MGVB07=gT`1aMYD0KG>E06U`TP1ZLY40
JgB>0080JW>;00H0Ig2806M^Q`1WK8H0IFZ3065XO@1MIgDJooooo`0603e1FP10@eh0@TIQ0496H@11
AV00@TMO0P12Af002P12Af40@dMR04=6I@13AVH0A4IW04=7J012AfT0@dMZ04A;K016CVd304E<J`0;
04I<K@17CFh0BU1`04YAL@1<DW80CU9b051DM01AEWD0DUMe05=GM01EFWD00P1FG7L0301EFgL0EE]e
05MMMP1JH7T0Ff5i05eSN`1MHW`0GV5o061RP`1PHX80HVB306EXQ@80IFR200/0IFQo06QZP@1XJX<0
JVb406]]Q@1[KhP0JVj706U^QP1XKXL0JG2706Y`Q`0206aaR@0;06idS01_MH`0L7F;079gS@1cNHl0
LgR>07AjT01eNi40MW^B07QoTP1iP9800P1hOi002`1gOXl0NH2?07^3S`1mPXl0O7n?07]nT@1hO8l0
MGZ>07=gRP1aMXP0L7B70080KW:700`0KW>706eaQP1^LHH0L7>607=fQ`1fNXX0MWb907UoR@1lPhX0
OhN<08><T028T9<208ZBU00;08ZCT`2=UYD0T9RG09>KV@2EW9X0UYjK09BLV@2DWYT0U9fI09>MVP2B
W9X00P2AVYT02`2AVY/0TY^I09:NU026THD0A456038^=00b;c40Mh=[08>AL`1@E4D0B4e10080BTm4
00`0@dPm03Lj;`0e=RX0=C8W05UIB02GXXL0SIB608jES@2<U8d0O85o079gM01TJFX208VIR`0;07j?
P@1lSgl0?dI401HD6`0O7b406a/K01XJ6@0I6AH05A<A01@B4@1@FTL00P1_OV802`1MIe@0FF9C05aV
EP1/N6D0CEE;01TH7@19DdT07R4R024V8`0V;RD09c0U0080:30S00H0:30Q02P`7`0/=200;C@P02`a
7`0Z;Qd?ooooo`003Oooool01P1YK800LgJ=07MmU`1hOYX0NGfJ07UlVP80NG^K00/0NgbN07aoX@1l
P:80OXBP07n5W01oQ9X0OhFL08:8X@20R:40OhVR07n=X@02086>X00;08:>W`23SIh0Q8fQ08B<X`21
R:<0P8VR08><X@26Sj40R8nQ08V>X`2:SZP00P2;SZ/0302:SZ/0RHj[08V>Z@29SZP0RXnX08fAZ`2=
TJd0S92]08Z@ZP2<TjP0SYBV08jCY@80SI6S00/0RhnT08Z>Y`29SJL0QXbT08F;X024RI`0QHJK08F4
W023PId0PH6L07eoV00207f1UP0;07j3T`1oQ980PHFD08>7UP24RIP0PXZH08B=V`27TIh0RIBP08fF
X@2?UZ800P2@V:D02`2@UjH0T9RV096IY02BVZ<0TYVS09>HYP2EV:P0U9^Z09:HY`2BVJH0U9ZU0080
U9RT00H0UINU09FHZ02DUj/0TYR[096FZ@2BUjX209FHZ`0409FFZP2CU:X0TYBY09:EY`80TiJW00/0
UINX09FFYP2DU:H0UYJZ09>EZ02BUJL0TYFV09BGZ02EUjP0UYN[09>FZ`02092BY`0;092CY@2AU:L0
TYBV09>DYP2CTZH0TY:X09>CZ@2ATjH0TI>R092CX@2>T:000P2<SYh0302<Sil0RHjN08V?WP2:Si`0
S96L08b@W02;SIh0RX^P08J8W`26RIl0QXZM08N;W@80R8^K00/0QhRJ08N7W024Pi`0P86N07j2W@1k
PIL0NX6C07^1T`1kP980OH2E07j0V00207anU`0;07QkT`1hO980Mg^@07QiSP1gNHl0MGJ?07=dT01`
LY00Jg2@06Q^S01XLHP00P1XLHD01P1XKX<0JFf206EXO`1TIgl0I6Ql05eRLA[ooooo00H0?d9G0413
F@11A5d0@TAP0495H014Ael304=6GP0:04=7H012AF80@TAS0456H`11Af80@TQS04=9I@14BFH0AD]X
04M;J080Ade[00/0BDi^04Y>L01:Cg40BTmb04a@LP1=DG40Ce=`051EK`1BEW00DeM`05AJL@0205IL
LP0<05EKL`1FFg<0EUad05QNMP1JH7L0G61i05eQNP1NHW`0Gf9n065RO`1RHX40IFJ30P1UJ8802`1W
JWl0JFf006M[O`1XK840JFb306]]Q01ZKH@0Jfj506]_QP1[KXD0K6n50080KW6700/0Kg>:06mdRP1_
M8X0LGJ;075gS01cMh`0MWZ>07MjT01gNi40N7f@07Z0T00207Z0SP0;07UoSP1jP8h0Nh:>07f3S@1m
PXl0OX>A07j4T`1oQYD0OhBD07n3U@1oQIH00P1nPiD0301kPI@0N7jA07MlS`1gNX/0N7^:07IjR@1f
NXP0MGV507MkQ@1hO8<0O7j507j1Q`80OX>800L0P8J908B;S@26SHl0R8n@08jEU@2@UiD0TYVF0080
U9bG00l0U9fI09:LV`2AVYX0TIZJ092HU`2AVIH0TYbC08ZCQP12?T<0;bP^04mAB01YLEh0DE=704i>
AP19BT<00P1;CdD03018CD40>cha03Pj:`0n?Bd0DU5009RQP`2@UXH0VZ6F09>ITP25RH<0MGMd06a^
JP80Sif;00/0PI1o07b=NP0g?3X05aHH020P7@0L71T06Q/G01TK5@0C51005QLC05ERBP0205eZD00;
03Lk;P0c=Rd0CE=306E`F@1?ETD081lL03@h;P0M7Q/08BLP02<Z8@0V;R800P0W;b800`0W;b40:2lO
02/a800202dc8@0302/`7_oooooooooo00gooooo000=ooooo`0606Y]P01cN8`0MWbC07MkU@1hNY@0
NG^F0P1jO9P02`1kOIX0NgjL07f1W@1oQ9h0Oh>J07n4V@20QI`0PXVP0869X021RZ00P8bO0080PXfM
00<0Q8jL08:<W025SIh00P24S:401P24Rj40QhjP08V@X029Sj80RHnT08Z=YP80RhfW0P2:SZP02P29
SZL0R8fV08Z?YP2>TZL0S92W08bAZ`2<TJT0SIBX08jDY02?U:<208jAXP0;08f@X`2>TJH0SI:V08jB
YP2<TJ@0S8nR08^<X029RJ00QX>N08B2W@21PIT00P1nOi<02`1mOhl0OX2=07ioS@1lOHh0Ngf?07Ql
S@1gOHh0N7n?07MoSP1nQY40QH^E0080RHnI00/0SI>M08jGWP2AVYh0TIZM092HWP2AV:<0T9JT09:I
Y@2@V:<0T9VS09:IXP0209>IX00<09BHX02FVJ@0U9FU096DY02BUZD0TiNW09BGZ02FV:P0U9FW09>C
Y`2ATjD0T9BS0P2BUJ@02`2BUZ<0TI>Q09:CX`2EUJL0TYBV09:FYP2CUjH0U9RV09>EYP2DUJT0U9N[
0080T9>V00/0Si>U09>FY@2CUJ<0Ti>R09:AX@2CTj<0TI:R092BW`2@Ti`0Si:K08fAV`0208^>VP0<
08^@W028SY`0RHnK08N>U`29SiH0Ri2G08Z>U`29RY/0QhRM08J6W@26Qi/0RH^L0P27RIP02`27R9L0
R8NI08>2U`1oOiP0Oh:J07f1U`1jP9<0NX2A07b0T@1lOi80OX2D0080O7jB00/0MgV=07MjSP1gNHd0
MWJ;07EdRP1eMH`0LW:;071aS01]LH`0J6b706I^Q00206M_PP0606Q^P01YK7d0I6Ik06AVNP1SIgL0
GfEa6_ooool01@0o@5@0?d5F0413FP12AEd0A4IN00<0@dEL00L0@dIL0455G@12AEl0@TEQ0458HP0o
AV00@TQQ0080A4YR00D0AD]T04I:I@16BVL0ATYW04Q=J`0204Y?KP0804Y>KP1;Cfl0C55`04eBK@1>
E6h0D5E_055GK`1CFVh205ELK@0<05ELK`1FG740Eeac05MLM01HGWH0F5ig05aPN@1MH7P0Gf9k065S
OP1SHgl0IFF10P1TIX002`1UIgh0If]n06I[O01VJgd0I6Um06IZOP1YJh40JVf306Y^Q01YK8<0K6n3
0080KW2600/0Kg68071dRP1_LhP0KgB:075eRP1cNHX0M7R;07IiSP1gNhl0N7b>07Z0S`0207^1S`0;
07YoS@1kP8d0O82=07b1SP1mPY00OXBB07f4T`1mQI<0OhJE0827UP23RiX00P24S9X03024RiX0Ph^I
08B;V023QiH0PHFC07j3T01kP8`0NGf807UmQP1iO8@0Ngf307]mPP80O7j300/0OH6607n4R020QHP0
PHN908F;S028SH`0Ri2?08jDT`2@V9H0TiZH09>MVP0209:LV@0;08nHU02>V980SiV>08bGQP11?T40
:1dT06]`GP1eOVP0FeiA04Y8A01:BTD00P1=DTP0301:DD@0A4Tk0414=012AC80C4dk08jHN@2CW8H0
[;ZU09fWV@2:THD0Oh=i06]]I@80RYN100/0Pi5k07V9L`0h?CP0518D01hN6@0J6QD05aXD01DI4`0B
5Q005a`C03M2;P02049==`0;02ld9@0Z;240BU4n06MfF@1AG4D071dH02<V7@0R9ah08bTP02DZ800V
;B000P0W;R401P0W;B80:C0R02`b8`0^=280;38P02X_7@oooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {299, 0}} -> {-0.0508884, -0.0375078, \
0.00526762, 0.00526762}, {{9.625, 190.438}, {291.875, 156.25}} -> {-12.9439, \
-9.62807, 0.929149, 0.929149}, {{208.5, 389.312}, {291.875, 156.25}} -> \
{-197.728, -9.62807, 0.929149, 0.929149}, {{9.625, 190.438}, {142.688, \
7.0625}} -> {-12.9439, -148.245, 0.929149, 0.929149}, {{208.5, 389.312}, \
{142.688, 7.0625}} -> {-197.728, -148.245, 0.929149, 0.929149}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Compute one-dimensional pdfs and corresponding error on 1d color \
channels\
\>", "Subsection"],

Cell[BoxData[{
    \(\(p1r = ComputePDF1D[d1, Red];\)\), "\[IndentingNewLine]", 
    \(\(p1g = ComputePDF1D[d1, Green];\)\), "\[IndentingNewLine]", 
    \(\(\(p1b = ComputePDF1D[d1, Blue];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(p2r = ComputePDF1D[d2, Red];\)\), "\[IndentingNewLine]", 
    \(\(p2g = ComputePDF1D[d2, Green];\)\), "\[IndentingNewLine]", 
    \(\(p2b = ComputePDF1D[d2, Blue];\)\)}], "Input"],

Cell[BoxData[{
    \(\(pl1 = 
        ShowTwoGaussianPDFs1D[p1r, \ p2r, {0, 255}, x, 
          FrameTicks \[Rule] None, nS];\)\), "\[IndentingNewLine]", 
    \(\(pl2 = 
        ShowTwoGaussianPDFs1D[p1g, \ p2g, {0, 255}, x, 
          FrameTicks \[Rule] None, nS];\)\), "\[IndentingNewLine]", 
    \(\(pl3 = 
        ShowTwoGaussianPDFs1D[p1b, \ p2b, {0, 255}, x, 
          FrameTicks \[Rule] None, nS];\)\)}], "Input"],

Cell[BoxData[{
    \(\(errors = {ExpectedError1D[p1r, p2r, x], ExpectedError1D[p1g, p2g, x], 
          ExpectedError1D[p1b, p2b, x]};\)\), "\[IndentingNewLine]", 
    \(\(pl4 = 
        BarChart[errors, \ Frame \[Rule] True, \ 
          BarStyle \[Rule] {Red, Green, Blue}, 
          FrameTicks \[Rule] {None, Automatic, None, Automatic}, 
          GridLines \[Rule] {None, Automatic}, nS];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show one-dimensional pdfs", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{pl1, pl2}, {pl3, pl4}}], 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00373483 0.0147151 26.3545 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
1 0 0 r
.01 w
.02381 .15635 m
.06244 .24121 L
.08255 .28767 L
.10458 .33472 L
.11448 .35317 L
.12507 .37028 L
.13499 .38343 L
.14415 .39275 L
.14911 .39658 L
.15437 .39968 L
.15709 .40088 L
.15964 .40175 L
.16108 .40214 L
.16244 .40243 L
.1632 .40257 L
.16402 .40269 L
.16471 .40277 L
.16546 .40283 L
.16617 .40288 L
.16682 .4029 L
.16811 .4029 L
.16928 .40285 L
.17051 .40273 L
.17115 .40265 L
.17184 .40254 L
.17308 .40231 L
.1759 .40156 L
.17851 .4006 L
.18097 .39946 L
.1856 .39671 L
.19019 .39323 L
.19525 .38852 L
.20551 .37639 L
.22393 .34689 L
.26413 .26058 L
.30282 .17327 L
.32247 .13469 L
.34396 .09942 L
.36448 .07295 L
.38358 .05432 L
.3941 .04625 L
.40404 .0399 L
.42263 .03083 L
.43235 .0273 L
.44264 .02431 L
.45228 .02208 L
.46109 .02046 L
.47053 .01908 L
.48067 .01793 L
.49006 .01712 L
Mistroke
.49898 .01652 L
.50859 .01603 L
.51883 .01565 L
.52848 .01538 L
.53723 .0152 L
.54728 .01505 L
.55651 .01495 L
.56665 .01488 L
.57175 .01485 L
.57734 .01482 L
.5826 .0148 L
.58758 .01478 L
.59689 .01476 L
.60211 .01475 L
.60692 .01475 L
.61217 .01474 L
.61782 .01473 L
.62286 .01473 L
.62747 .01473 L
.63652 .01472 L
.64133 .01472 L
.64657 .01472 L
.65201 .01472 L
.65714 .01472 L
.66209 .01472 L
.66744 .01472 L
.67189 .01472 L
.67679 .01472 L
.68209 .01472 L
.6877 .01472 L
.6929 .01472 L
.69775 .01472 L
.70275 .01472 L
.70819 .01472 L
.71332 .01472 L
.71808 .01472 L
.72235 .01472 L
.72707 .01472 L
.732 .01472 L
.73663 .01472 L
.74131 .01472 L
.74644 .01472 L
.7518 .01472 L
.75679 .01472 L
.76147 .01472 L
.76573 .01472 L
.77064 .01472 L
.77528 .01472 L
.7799 .01472 L
.78499 .01472 L
Mistroke
.7903 .01472 L
.79527 .01472 L
.79992 .01472 L
.80416 .01472 L
.80906 .01472 L
.81372 .01472 L
.81875 .01472 L
.82331 .01472 L
.82858 .01472 L
.83354 .01472 L
.83814 .01472 L
.84238 .01472 L
.84702 .01472 L
.85193 .01472 L
.85689 .01472 L
.86142 .01472 L
.86664 .01472 L
.87158 .01472 L
.87615 .01472 L
.88037 .01472 L
.885 .01472 L
.88992 .01472 L
.89482 .01472 L
.8993 .01472 L
.90423 .01472 L
.9067 .01472 L
.90941 .01472 L
.91399 .01472 L
.91888 .01472 L
.9235 .01472 L
.92769 .01472 L
.93255 .01472 L
.93499 .01472 L
.93768 .01472 L
.94244 .01472 L
.94689 .01472 L
.94958 .01472 L
.95214 .01472 L
.95692 .01472 L
.9596 .01472 L
.96208 .01472 L
.96497 .01472 L
.96769 .01472 L
.97215 .01472 L
.97619 .01472 L
Mfstroke
0 0 1 r
.02381 .01472 m
.02605 .01472 L
.02846 .01472 L
.03072 .01472 L
.03279 .01472 L
.03521 .01472 L
.03658 .01472 L
.03784 .01472 L
.04016 .01472 L
.04262 .01472 L
.04496 .01472 L
.04749 .01472 L
.04987 .01472 L
.05205 .01472 L
.0546 .01472 L
.05604 .01472 L
.05738 .01472 L
.05983 .01472 L
.06244 .01472 L
.06383 .01472 L
.06529 .01472 L
.06791 .01472 L
.06937 .01472 L
.07073 .01472 L
.07232 .01472 L
.07382 .01472 L
.07653 .01472 L
.079 .01472 L
.08165 .01472 L
.08315 .01472 L
.08454 .01472 L
.08693 .01472 L
.08916 .01472 L
.09161 .01472 L
.09426 .01472 L
.09688 .01472 L
.09964 .01472 L
.102 .01472 L
.10458 .01472 L
.10712 .01472 L
.10986 .01472 L
.11246 .01472 L
.11485 .01472 L
.11701 .01472 L
.11939 .01472 L
.12187 .01472 L
.12419 .01472 L
.1269 .01472 L
.12947 .01472 L
.13178 .01472 L
Mistroke
.13429 .01472 L
.13702 .01472 L
.13992 .01472 L
.14266 .01472 L
.14514 .01472 L
.14747 .01472 L
.15003 .01472 L
.1527 .01472 L
.15519 .01472 L
.15753 .01472 L
.15965 .01472 L
.1621 .01472 L
.16443 .01472 L
.16694 .01472 L
.16962 .01472 L
.1719 .01472 L
.17441 .01472 L
.17711 .01472 L
.18001 .01472 L
.18275 .01472 L
.18526 .01472 L
.18775 .01472 L
.19001 .01472 L
.19263 .01472 L
.19509 .01472 L
.19737 .01472 L
.19947 .01472 L
.20178 .01472 L
.20422 .01472 L
.20668 .01472 L
.20932 .01472 L
.21182 .01472 L
.21409 .01472 L
.21676 .01472 L
.21966 .01472 L
.2224 .01472 L
.22494 .01472 L
.22735 .01472 L
.22956 .01472 L
.23199 .01472 L
.23455 .01472 L
.23886 .01472 L
.2413 .01472 L
.24358 .01472 L
.24626 .01472 L
.24879 .01472 L
.25353 .01472 L
.25618 .01472 L
.25863 .01472 L
.26132 .01472 L
Mistroke
.26417 .01472 L
.26669 .01472 L
.26909 .01472 L
.27359 .01472 L
.2761 .01472 L
.27843 .01472 L
.28116 .01472 L
.28372 .01472 L
.28595 .01472 L
.28837 .01472 L
.29258 .01472 L
.29497 .01472 L
.2975 .01472 L
.30202 .01472 L
.30457 .01472 L
.30699 .01472 L
.31151 .01472 L
.31404 .01472 L
.31638 .01472 L
.31911 .01472 L
.32168 .01472 L
.32591 .01472 L
.33057 .01472 L
.33512 .01472 L
.34002 .01472 L
.34242 .01472 L
.34498 .01472 L
.3496 .01472 L
.35242 .01472 L
.35509 .01472 L
.36007 .01472 L
.36534 .01473 L
.3702 .01473 L
.37553 .01474 L
.37822 .01474 L
.38118 .01475 L
.3864 .01476 L
.39135 .01478 L
.39579 .0148 L
.40064 .01483 L
.40589 .01487 L
.41148 .01493 L
.41676 .01501 L
.42154 .0151 L
.42643 .01523 L
.4316 .0154 L
.43601 .01559 L
.44084 .01584 L
.44605 .0162 L
.45162 .01669 L
Mistroke
.45689 .01728 L
.46167 .01796 L
.4665 .0188 L
.47162 .01991 L
.48081 .02257 L
.48592 .02452 L
.4907 .02672 L
.49591 .0296 L
.50159 .0334 L
.51197 .04249 L
.52183 .0543 L
.53143 .06946 L
.54035 .08732 L
.56086 .14463 L
.57947 .21762 L
.61952 .42169 L
.63789 .51112 L
.64832 .55195 L
.65342 .56815 L
.65806 .58047 L
.663 .5908 L
.66527 .59454 L
.66768 .5978 L
.6689 .59917 L
.67024 .60046 L
.67148 .60143 L
.67262 .60215 L
.67395 .60277 L
.67465 .60301 L
.67539 .60318 L
.67663 .60332 L
.67734 .6033 L
.67799 .60323 L
.67931 .60292 L
.68005 .60264 L
.68073 .60232 L
.68199 .60156 L
.68332 .60054 L
.68563 .59822 L
.68817 .59488 L
.69379 .58461 L
.69905 .57157 L
.70945 .537 L
.71933 .49524 L
.73786 .40206 L
.7761 .20929 L
.7958 .13475 L
.80681 .10294 L
.81678 .07991 L
.82683 .06172 L
Mistroke
.83606 .04882 L
.84619 .03818 L
.85179 .03361 L
.85689 .03013 L
.86639 .02511 L
.87161 .02301 L
.87656 .02138 L
.88535 .01917 L
.89031 .01823 L
.8949 .01753 L
.89954 .01695 L
.90455 .01645 L
.90887 .0161 L
.91359 .0158 L
.91884 .01553 L
.92435 .01532 L
.92946 .01517 L
.93421 .01506 L
.93927 .01497 L
.94475 .0149 L
.94993 .01485 L
.95469 .01482 L
.959 .01479 L
.96373 .01477 L
.96867 .01476 L
.97329 .01475 L
.97619 .01474 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.125 0.3125 0.0147151 0.158881 [
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09416 -18 -4.5 ]
[-0.0125 .09416 0 4.5 ]
[-0.0125 .1736 -6 -4.5 ]
[-0.0125 .1736 0 4.5 ]
[-0.0125 .25304 -18 -4.5 ]
[-0.0125 .25304 0 4.5 ]
[-0.0125 .33248 -6 -4.5 ]
[-0.0125 .33248 0 4.5 ]
[-0.0125 .41192 -18 -4.5 ]
[-0.0125 .41192 0 4.5 ]
[-0.0125 .49136 -6 -4.5 ]
[-0.0125 .49136 0 4.5 ]
[-0.0125 .5708 -18 -4.5 ]
[-0.0125 .5708 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .09416 m
1 .09416 L
s
0 .1736 m
1 .1736 L
s
0 .25304 m
1 .25304 L
s
0 .33248 m
1 .33248 L
s
0 .41192 m
1 .41192 L
s
0 .49136 m
1 .49136 L
s
0 .5708 m
1 .5708 L
s
0 g
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09416 m
.00625 .09416 L
s
[(0.5)] -0.0125 .09416 1 0 Mshowa
0 .1736 m
.00625 .1736 L
s
[(1)] -0.0125 .1736 1 0 Mshowa
0 .25304 m
.00625 .25304 L
s
[(1.5)] -0.0125 .25304 1 0 Mshowa
0 .33248 m
.00625 .33248 L
s
[(2)] -0.0125 .33248 1 0 Mshowa
0 .41192 m
.00625 .41192 L
s
[(2.5)] -0.0125 .41192 1 0 Mshowa
0 .49136 m
.00625 .49136 L
s
[(3)] -0.0125 .49136 1 0 Mshowa
0 .5708 m
.00625 .5708 L
s
[(3.5)] -0.0125 .5708 1 0 Mshowa
.125 Mabswid
0 .0306 m
.00375 .0306 L
s
0 .04649 m
.00375 .04649 L
s
0 .06238 m
.00375 .06238 L
s
0 .07827 m
.00375 .07827 L
s
0 .11004 m
.00375 .11004 L
s
0 .12593 m
.00375 .12593 L
s
0 .14182 m
.00375 .14182 L
s
0 .15771 m
.00375 .15771 L
s
0 .18948 m
.00375 .18948 L
s
0 .20537 m
.00375 .20537 L
s
0 .22126 m
.00375 .22126 L
s
0 .23715 m
.00375 .23715 L
s
0 .26893 m
.00375 .26893 L
s
0 .28481 m
.00375 .28481 L
s
0 .3007 m
.00375 .3007 L
s
0 .31659 m
.00375 .31659 L
s
0 .34837 m
.00375 .34837 L
s
0 .36425 m
.00375 .36425 L
s
0 .38014 m
.00375 .38014 L
s
0 .39603 m
.00375 .39603 L
s
0 .42781 m
.00375 .42781 L
s
0 .44369 m
.00375 .44369 L
s
0 .45958 m
.00375 .45958 L
s
0 .47547 m
.00375 .47547 L
s
0 .50725 m
.00375 .50725 L
s
0 .52314 m
.00375 .52314 L
s
0 .53902 m
.00375 .53902 L
s
0 .55491 m
.00375 .55491 L
s
0 .58669 m
.00375 .58669 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09416 m
1 .09416 L
s
.99375 .1736 m
1 .1736 L
s
.99375 .25304 m
1 .25304 L
s
.99375 .33248 m
1 .33248 L
s
.99375 .41192 m
1 .41192 L
s
.99375 .49136 m
1 .49136 L
s
.99375 .5708 m
1 .5708 L
s
.125 Mabswid
.99625 .0306 m
1 .0306 L
s
.99625 .04649 m
1 .04649 L
s
.99625 .06238 m
1 .06238 L
s
.99625 .07827 m
1 .07827 L
s
.99625 .11004 m
1 .11004 L
s
.99625 .12593 m
1 .12593 L
s
.99625 .14182 m
1 .14182 L
s
.99625 .15771 m
1 .15771 L
s
.99625 .18948 m
1 .18948 L
s
.99625 .20537 m
1 .20537 L
s
.99625 .22126 m
1 .22126 L
s
.99625 .23715 m
1 .23715 L
s
.99625 .26893 m
1 .26893 L
s
.99625 .28481 m
1 .28481 L
s
.99625 .3007 m
1 .3007 L
s
.99625 .31659 m
1 .31659 L
s
.99625 .34837 m
1 .34837 L
s
.99625 .36425 m
1 .36425 L
s
.99625 .38014 m
1 .38014 L
s
.99625 .39603 m
1 .39603 L
s
.99625 .42781 m
1 .42781 L
s
.99625 .44369 m
1 .44369 L
s
.99625 .45958 m
1 .45958 L
s
.99625 .47547 m
1 .47547 L
s
.99625 .50725 m
1 .50725 L
s
.99625 .52314 m
1 .52314 L
s
.99625 .53902 m
1 .53902 L
s
.99625 .55491 m
1 .55491 L
s
.99625 .58669 m
1 .58669 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.0625 .01472 m
.0625 .60332 L
.3125 .60332 L
.3125 .01472 L
F
0 g
.5 Mabswid
.0625 .01472 m
.0625 .60332 L
.3125 .60332 L
.3125 .01472 L
.0625 .01472 L
s
0 1 0 r
.375 .01472 m
.375 .55318 L
.625 .55318 L
.625 .01472 L
F
0 g
.375 .01472 m
.375 .55318 L
.625 .55318 L
.625 .01472 L
.375 .01472 L
s
0 0 1 r
.6875 .01472 m
.6875 .05213 L
.9375 .05213 L
.9375 .01472 L
F
0 g
.6875 .01472 m
.6875 .05213 L
.9375 .05213 L
.9375 .01472 L
.6875 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00373483 0.0147151 36.1337 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
1 0 0 r
.01 w
.02381 .13493 m
.06244 .23072 L
.10458 .36129 L
.12507 .42434 L
.14415 .47602 L
.16254 .51483 L
.16783 .52347 L
.17284 .53047 L
.17768 .53612 L
.18221 .54037 L
.18682 .54365 L
.18927 .54495 L
.1919 .546 L
.19322 .54639 L
.19391 .54656 L
.19466 .54671 L
.19537 .54683 L
.19601 .54692 L
.19727 .54703 L
.19849 .54705 L
.1998 .547 L
.20104 .54686 L
.20218 .54666 L
.20325 .54641 L
.20439 .54608 L
.20646 .54532 L
.20891 .54412 L
.21115 .54276 L
.21601 .53894 L
.22062 .53422 L
.23028 .52107 L
.24053 .50257 L
.25895 .45939 L
.2967 .34626 L
.33691 .22279 L
.37559 .1292 L
.39563 .09403 L
.41673 .06637 L
.42628 .05665 L
.43647 .04796 L
.45484 .03603 L
.46508 .03112 L
.47619 .02692 L
.48667 .02385 L
.49634 .02164 L
.50603 .01991 L
.5151 .01865 L
.52505 .01759 L
.53574 .01675 L
.54587 .01616 L
Mistroke
.55692 .01571 L
.56735 .0154 L
.57702 .01519 L
.58211 .01511 L
.58761 .01504 L
.59246 .01498 L
.59758 .01493 L
.60728 .01486 L
.6162 .01482 L
.62117 .0148 L
.6257 .01479 L
.63058 .01477 L
.63588 .01476 L
.64078 .01475 L
.64531 .01475 L
.65422 .01474 L
.65887 .01473 L
.66388 .01473 L
.67293 .01472 L
.67817 .01472 L
.68369 .01472 L
.68885 .01472 L
.69354 .01472 L
.69814 .01472 L
.70311 .01472 L
.70837 .01472 L
.71332 .01472 L
.71798 .01472 L
.72289 .01472 L
.7317 .01472 L
.73665 .01472 L
.74117 .01472 L
.74638 .01472 L
.75132 .01472 L
.75587 .01472 L
.76009 .01472 L
.76472 .01472 L
.76964 .01472 L
.77452 .01472 L
.779 .01472 L
.78391 .01472 L
.78909 .01472 L
.79361 .01472 L
.79781 .01472 L
.80243 .01472 L
.80736 .01472 L
.81268 .01472 L
.81759 .01472 L
.82297 .01472 L
.82868 .01472 L
Mistroke
.83363 .01472 L
.83827 .01472 L
.84336 .01472 L
.84883 .01472 L
.85407 .01472 L
.85894 .01472 L
.86428 .01472 L
.86702 .01472 L
.86998 .01472 L
.87541 .01472 L
.88052 .01472 L
.88549 .01472 L
.89007 .01472 L
.89478 .01472 L
.89982 .01472 L
.90457 .01472 L
.90891 .01472 L
.914 .01472 L
.91687 .01472 L
.91953 .01472 L
.9244 .01472 L
.92692 .01472 L
.92958 .01472 L
.93447 .01472 L
.93896 .01472 L
.94379 .01472 L
.94652 .01472 L
.94906 .01472 L
.9537 .01472 L
.95791 .01472 L
.96277 .01472 L
.96735 .01472 L
.97195 .01472 L
.97619 .01472 L
Mfstroke
0 0 1 r
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.04262 .01472 L
.04795 .01472 L
.053 .01472 L
.05753 .01472 L
.06244 .01472 L
.06751 .01472 L
.07308 .01472 L
.0789 .01472 L
.08435 .01472 L
.08944 .01472 L
.0941 .01472 L
.09947 .01472 L
.10458 .01472 L
.10961 .01472 L
.11417 .01472 L
.11943 .01472 L
.12439 .01472 L
.12899 .01472 L
.13322 .01472 L
.13786 .01472 L
.14277 .01472 L
.14773 .01472 L
.15225 .01472 L
.15747 .01472 L
.16241 .01472 L
.17119 .01473 L
.17615 .01473 L
.18074 .01473 L
.18538 .01474 L
.19037 .01474 L
.19941 .01476 L
.20464 .01477 L
.21016 .01478 L
.21532 .0148 L
.22001 .01482 L
.22956 .01488 L
.2348 .01492 L
.23975 .01497 L
.24857 .01508 L
.25354 .01517 L
.25812 .01526 L
.26781 .01553 L
.27688 .01587 L
.28683 .0164 L
.29242 .01679 L
.29752 .01722 L
Mistroke
.30739 .01827 L
.31655 .01959 L
.32659 .02152 L
.33728 .02429 L
.3476 .02787 L
.35874 .03298 L
.36925 .03928 L
.37892 .0466 L
.39778 .06608 L
.40848 .08077 L
.41846 .0972 L
.43885 .1399 L
.45742 .18999 L
.49732 .32896 L
.5357 .47518 L
.55551 .53823 L
.56551 .5634 L
.57088 .57464 L
.57653 .58459 L
.58137 .5915 L
.58392 .59453 L
.58665 .59728 L
.58917 .59936 L
.59145 .60088 L
.59256 .60148 L
.59375 .60204 L
.5948 .60244 L
.59592 .60279 L
.59722 .60309 L
.59843 .60325 L
.59918 .60331 L
.59988 .60332 L
.6012 .60325 L
.60187 .60317 L
.60259 .60304 L
.60387 .60273 L
.60525 .60227 L
.60678 .6016 L
.60926 .60017 L
.61194 .59815 L
.61679 .59325 L
.62174 .58662 L
.62634 .57904 L
.6368 .55705 L
.65789 .49578 L
.69691 .3497 L
.7168 .27443 L
.73837 .20151 L
.75739 .14813 L
.77832 .10233 L
Mistroke
.79817 .07074 L
.80904 .05771 L
.81921 .04785 L
.8296 .03978 L
.83947 .03372 L
.84919 .02902 L
.858 .02566 L
.8676 .02281 L
.87782 .02052 L
.88729 .01893 L
.89621 .0178 L
.90599 .01688 L
.91631 .01619 L
.92512 .01577 L
.93478 .01543 L
.94003 .0153 L
.945 .01519 L
.95431 .01504 L
.95952 .01497 L
.96433 .01492 L
.97523 .01484 L
.97619 .01484 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00373483 0.0147151 33.9506 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
1 0 0 r
.01 w
.02381 .11071 m
.06244 .18214 L
.10458 .28193 L
.14415 .37793 L
.16408 .41858 L
.18221 .44715 L
.19227 .45868 L
.19689 .46283 L
.20178 .46642 L
.20426 .46791 L
.207 .46929 L
.20952 .47032 L
.21182 .47106 L
.21312 .47138 L
.21453 .47167 L
.21531 .4718 L
.21602 .47189 L
.21671 .47197 L
.21745 .47203 L
.21813 .47206 L
.21887 .47208 L
.21957 .47209 L
.22021 .47207 L
.22143 .472 L
.22272 .47186 L
.22394 .47168 L
.22526 .47141 L
.22767 .47076 L
.23002 .46992 L
.23219 .46896 L
.23712 .46615 L
.24235 .46221 L
.25107 .45354 L
.26069 .44108 L
.28004 .40797 L
.30089 .36301 L
.34203 .26169 L
.38166 .17033 L
.41976 .10313 L
.43937 .07783 L
.46033 .05723 L
.47057 .04931 L
.48167 .04212 L
.49127 .03694 L
.50182 .03221 L
.5217 .02559 L
.53257 .02299 L
.54274 .02106 L
.55315 .01951 L
.56303 .01837 L
Mistroke
.5719 .01755 L
.58157 .01685 L
.59191 .01628 L
.60128 .01589 L
.61209 .01555 L
.62226 .01531 L
.63205 .01515 L
.64238 .01502 L
.6512 .01494 L
.66087 .01487 L
.6711 .01482 L
.68041 .01479 L
.68557 .01478 L
.69117 .01477 L
.69642 .01476 L
.70134 .01475 L
.71077 .01474 L
.71577 .01473 L
.72116 .01473 L
.7265 .01473 L
.73213 .01472 L
.7374 .01472 L
.74218 .01472 L
.75175 .01472 L
.757 .01472 L
.76196 .01472 L
.77078 .01472 L
.77576 .01472 L
.78034 .01472 L
.78503 .01472 L
.79006 .01472 L
.79914 .01472 L
.80468 .01472 L
.80994 .01472 L
.81462 .01472 L
.81979 .01472 L
.82443 .01472 L
.82943 .01472 L
.83471 .01472 L
.83968 .01472 L
.84435 .01472 L
.84928 .01472 L
.85381 .01472 L
.85809 .01472 L
.86308 .01472 L
.86762 .01472 L
.87251 .01472 L
.87781 .01472 L
.88244 .01472 L
.88736 .01472 L
Mistroke
.89155 .01472 L
.89617 .01472 L
.90137 .01472 L
.90631 .01472 L
.91075 .01472 L
.91559 .01472 L
.92083 .01472 L
.92642 .01472 L
.9317 .01472 L
.93647 .01472 L
.94131 .01472 L
.94642 .01472 L
.95077 .01472 L
.95556 .01472 L
.96071 .01472 L
.96623 .01472 L
.97144 .01472 L
.97619 .01472 L
Mfstroke
0 0 1 r
.02381 .01472 m
.02605 .01472 L
.02846 .01472 L
.03279 .01472 L
.03543 .01472 L
.03793 .01472 L
.04262 .01472 L
.04502 .01472 L
.04756 .01472 L
.05212 .01472 L
.05466 .01472 L
.05704 .01472 L
.06244 .01472 L
.06504 .01472 L
.06788 .01472 L
.07038 .01472 L
.07305 .01472 L
.07568 .01472 L
.07807 .01472 L
.08274 .01472 L
.08556 .01472 L
.08814 .01472 L
.09093 .01472 L
.09399 .01472 L
.09914 .01472 L
.10195 .01472 L
.10458 .01472 L
.10959 .01472 L
.11241 .01472 L
.11503 .01472 L
.11983 .01472 L
.12493 .01472 L
.12948 .01472 L
.13375 .01472 L
.13844 .01472 L
.14349 .01472 L
.14845 .01472 L
.15306 .01472 L
.15812 .01472 L
.16353 .01472 L
.16922 .01472 L
.17458 .01472 L
.1794 .01472 L
.18463 .01472 L
.18952 .01472 L
.19409 .01472 L
.19911 .01472 L
.2045 .01472 L
.21014 .01472 L
.2155 .01472 L
Mistroke
.22031 .01472 L
.22555 .01472 L
.23088 .01472 L
.23589 .01473 L
.24039 .01473 L
.24526 .01473 L
.25058 .01474 L
.2562 .01475 L
.26099 .01476 L
.26624 .01477 L
.2715 .01479 L
.27648 .01481 L
.28579 .01486 L
.29101 .01491 L
.29582 .01495 L
.30107 .01502 L
.30672 .01511 L
.31176 .0152 L
.31637 .01531 L
.32542 .01559 L
.33023 .01579 L
.33547 .01605 L
.34091 .01637 L
.34604 .01674 L
.35634 .01773 L
.36569 .01898 L
.37576 .02084 L
.38665 .02363 L
.39614 .02691 L
.40657 .03168 L
.41745 .0383 L
.42762 .04633 L
.43806 .05681 L
.44795 .06919 L
.4665 .09994 L
.48638 .14548 L
.5048 .20004 L
.54403 .34898 L
.58175 .49892 L
.60107 .55805 L
.60637 .57055 L
.61194 .5817 L
.61717 .59015 L
.62192 .59607 L
.62427 .59836 L
.62682 .60036 L
.62799 .60111 L
.62923 .60178 L
.63039 .6023 L
.63145 .60268 L
Mistroke
.63266 .60301 L
.63395 .60323 L
.63516 .60332 L
.6363 .60329 L
.63694 .60323 L
.63762 .60314 L
.63885 .60286 L
.6396 .60264 L
.64031 .60238 L
.64164 .6018 L
.64387 .60051 L
.64623 .59871 L
.65046 .59442 L
.65501 .58829 L
.66 .57981 L
.67021 .5571 L
.67952 .53082 L
.70044 .45696 L
.74031 .29436 L
.77866 .16159 L
.79845 .11217 L
.80856 .09213 L
.81946 .0742 L
.82963 .06057 L
.83894 .0504 L
.84779 .04253 L
.85723 .03579 L
.86704 .03031 L
.87617 .02637 L
.88702 .02283 L
.89687 .02048 L
.90686 .01873 L
.91607 .01756 L
.92618 .01664 L
.93127 .01629 L
.93687 .01597 L
.94196 .01573 L
.94678 .01555 L
.95583 .01528 L
.96089 .01517 L
.96558 .01508 L
.97619 .01494 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`002Ooooonf00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool0coooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Ooo
ool00`00003oooooooooo`02ooooodoo003o1?oooom:ool0013o003o0oooool00`00003ooooooooo
o`3?ooooo`002Oooool00`00003oooooooooo`1>ooooo`?oo`001?l00?m6ooooo`Co003o4oooool0
0`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`1;ooooo`?oo`001oooool2o`00
od;ooooo00<0003oo`00ooooool05_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003o
ooooooooo`18ooooo`?oo`003?ooool2o`00ockooooo00?o003o0000ooooool06?ooool00`00003o
ooooooooo`3?ooooo`002Oooool00`00003oooooooooo`16ooooo`;oo`004Oooool00ol00?oooooo
ooooo`0jooooo`03o`00oooooooooooo01Wooooo00<00000ooooooooool07Oooool2o`000;3ooooo
0009ooooo`0300000?oooooooooo04Kooooo00?oo`00ooooooooool04Oooool00ol00?oooooooooo
o`0hooooo`030000oooooooooooo01[ooooo00<00000ooooooooool07?ooool01?l0003ooooooooo
ool00003oooooj8000002_ooool000Wooooo00<00000ooooooooool0A?ooool2ool001Gooooo00?o
003oooooooooool0=_ooool00`000?ooooooooooo`0Kooooo`0300000?oooooooooo01cooooo00Co
0000oooooooooooo00000oooool00`00003oooooooooo`2Nooooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo04;ooooo0_oo000Hooooo`03o`00oooooooooooo03Gooooo00<0
003oooooooooool06oooool00`00003oooooooooo`0Looooo`04o`000?ooooooooooo`0000?ooooo
XP00000:ooooo`002Oooool00`00003oooooooooo`11ooooo`03ool00?oooooooooo01Sooooo00?o
003oooooooooool0=?ooool00`000?ooooooooooo`0Looooo`0300000?oooooooooo01cooooo00Co
0000oooooooooooo00000oooool00`00003oooooooooo`07ooooo`030000003o0000o`0002D0o`00
00<00000ooooooooool01oooool00`0000000?l0003o000U003o000300000?oooooooooo00Oooooo
00<000000000o`000?l09@000?l00`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo043ooooo00?oo`00ooooooooool06_ooool00ol00?oooooooooo
o`0cooooo`03o`00oooooooooooo01cooooo00<00000ooooooooool07?ooool01?l0003ooooooooo
ool00003ooooo`0300000?l0003ooooo00Oooooo00<000000?l0003o00009@3o00000`00003ooooo
ooooo`07ooooo`0300000000o`000?l002D00?l000<00000ooooooooool01oooool00`000000003o
0000o`0U0000o`0300000?oooooooooo00Oooooo00?o000000000?ooool02Oooool000Wooooo00<0
0000ooooooooool0?oooool00ooo003oooooooooo`0Kooooo`03o`00oooooooooooo03;ooooo00?o
003oooooooooool07Oooool00`00003oooooooooo`0Mooooo`;o00001?ooool00`00003ooooooooo
o`07ooooo`030000003o0000o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0003o
000U003o000300000?oooooooooo00Oooooo00<000000000o`000?l09@000?l00`00003ooooooooo
o`08ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo03oooooo00?oo`00
ooooooooool06oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo01gooooo00<00000
ooooooooool08oooool00`00003oooooooooo`07ooooo`030000003o0000o`0002D0o`0000<00000
ooooooooool01oooool00`0000000?l0003o000U003o000300000?oooooooooo00Oooooo00<00000
0000o`000?l09@000?l00`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo03kooooo00?oo`00ooooooooool07Oooool00ol00?ooooooooooo`0`oooo
o`03o`00oooooooooooo01kooooo00<00000ooooooooool08oooool00`00003o0000ooooo`07oooo
o`030000003o0000o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0003o000U003o
000300000?oooooooooo00Oooooo00<000000000o`000?l09@000?l00`00003oooooooooo`07oooo
o`03o`000000003ooooo00Wooooo0009ooooo`0300000?oooooooooo03gooooo00?oo`00oooooooo
ool07oooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo01kooooo00<00000oooooooo
ool08oooool00`00003oooooooooo`07ooooo`030000003o0000o`0002D0o`0000<00000oooooooo
ool01oooool00`0000000?l0003o000U003o000300000?oooooooooo00Oooooo:@00000:ooooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo03cooooo00?oo`00ooooooooool0
8?ooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo01oooooo00<00000ooooooooool0
8oooool00`00003oooooooooo`07ooooo`030000003o0000o`0002D0o`0000<00000ooooooooool0
1oooool00`0000000?l0003o000U003o000300000?oooooooooo03[ooooo00<00000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool0>oooool00ooo003oooooooooo`0Rooooo`03o`00oooo
oooooooo02gooooo00?o003oooooooooool07oooool00`00003oooooooooo`0Sooooo`0300000?l0
003ooooo00Oooooo00<000000?l0003o00009@3o00000`00003oooooooooo`07ooooo`0300000000
o`000?l002D00?l000<00000ooooooooool0>Oooool00ol000000000ooooo`09ooooo`002Oooool0
0`00003oooooooooo`0kooooo`03ool00?oooooooooo02;ooooo00?o003oooooooooool0;?ooool0
0ol00?ooooooooooo`0Pooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool01oooool0
0`000000o`000?l0000U0?l0000300000?oooooooooo00Oooooo00<00000003o0000o`009@00o`00
0`00003oooooooooo`0jooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
03[ooooo00?oo`00ooooooooool08oooool00ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo
023ooooo00<00000ooooooooool04Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Cooooo00<00000o`000?ooool01oooool00`000000o`000?l0000U0?l0000300000?oooooooooo
00Oooooo00<00000003o0000o`009@00o`000`00003oooooooooo`0iooooo`03o`000000003ooooo
00Wooooo0009ooooo`0300000?oooooooooo03[ooooo00?oo`00ooooooooool09?ooool00ol00?oo
ooooooooo`0Zooooo`03o`00oooooooooooo027ooooo00<00000ooooooooool04?ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00`00003oooooooooo`07
ooooo`030000003o0000o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0003o000U
003o000300000?oooooooooo03[ooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooo
ooooool0>Oooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo02[ooooo00?o003ooooo
ooooool08Oooool00`00003oooooooooo`0@ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000
oooooooooooooooo00000009ooooo`030000003o0000o`0002D0o`0000<00000ooooooooool01ooo
ool00`0000000?l0003o000U003o000300000?oooooooooo03[ooooo00<00000ooooooooool02?oo
ool000Wooooo00<00000ooooooooool0>Oooool00ooo003oooooooooo`0Vooooo`03o`00oooooooo
oooo02Wooooo00?o003oooooooooool08Oooool00`00003oooooooooo`0@ooooo`04o`000?oooooo
ooooo`0000_ooooo00Ko0000oooooooooooooooo00000?l000080000O`030000003o0000o`0002D0
o`0000<000000000O`0007l01`0007l00`0000000?l0003o000U003o00030000000007l0001o03P0
001o0`00000:ooooo`002Oooool00`00003oooooooooo`0iooooo`03ool00?oooooooooo02Kooooo
00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0Rooooo`0300000?oooooooooo013ooooo
00Co0000oooooooooooo00001oooool4o`0000Cooooo00<00000ooooooooool01oooool00`000000
o`000?l0000U0?l0000300000?oooooooooo00Oooooo00<00000003o0000o`009@00o`000`00003o
ooooooooo`0jooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo03Sooooo
00?oo`00ooooooooool09oooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo02;ooooo
00<00000ooooooooool04?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Go
oooo00<00000o`000?ooool01oooool00`000000o`000?l0000U0?l0000300000?oooooooooo00Oo
oooo00<00000003o0000o`009@00o`000`00003oooooooooo`0iooooo`03o`000000003ooooo00Wo
oooo0009ooooo`0300000?oooooooooo03Sooooo00?oo`00ooooooooool0:?ooool00ol00?oooooo
ooooo`0Wooooo`03o`00oooooooooooo02;ooooo00<00000ooooooooool04Oooool2o`0000Sooooo
1Ol00003ooooo`0300000?oooooooooo00Oooooo00<000000?l0003o00009@3o00000`00003ooooo
ooooo`07ooooo`0300000000o`000?l002D00?l000<00000ooooooooool0>_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`0gooooo`03ool00?oooooooooo02Wooooo00?o
003oooooooooool09oooool00ol00?ooooooooooo`0Rooooo`0300000?oooooooooo02?ooooo00<0
0000ooooooooool01oooool00`000000o`000?l0000U0?l0000300000?oooooooooo00Oooooo00<0
0000003o0000o`009@00o`000`00003oooooooooo`0jooooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo00;ooooo00?oo`00ooooooooool0<_ooool00ooo003oooooooooo`0Y
ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool08oooool00`00003oooooooooo`0S
ooooo`0300000?l0003ooooo00Oooooo00<000000?l0003o00009@3o00000`00003oooooooooo`07
ooooo`0300000000o`000?l002D00?l000<00000ooooooooool0>Oooool00ol000000000ooooo`09
ooooo`002Oooool00`00003oooooooooo`02ooooo`03ool00?oooooooooo037ooooo00?oo`00oooo
ooooool0:oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02?ooooo00<00000oooo
ooooool08oooool00`00003oooooooooo`07ooooo`030000003o0000o`0002D0o`0000<00000oooo
ooooool01oooool00`0000000?l0003o000U003o000300000?oooooooooo03[ooooo00<00000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool00oooool00ooo003oooooooooo`0_ooooo`03
ool00?oooooooooo02cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Sooooo`03
00000?oooooooooo02?ooooo00<00000o`000?ooool01oooool00`000000o`000?l0000U0?l00003
00000?oooooooooo00Oooooo00<00000003o0000o`009@00o`000`00003oooooooooo`0iooooo`03
o`000000003ooooo00Wooooo0009ooooo`0300000?oooooooooo00?ooooo00?oo`00ooooooooool0
;oooool00ooo003oooooooooo`0/ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0
9?ooool00`00003oooooooooo`0Sooooo`0300000?oooooooooo00Oooooo00<000000?l0003o0000
9@3o00000`00003oooooooooo`07ooooo`0300000000o`000?l002D00?l000<00000ooooooooool0
>_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`04ooooo`03ool00?oo
oooooooo02gooooo00?oo`00ooooooooool0;Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooo
oooooooo02Cooooo00<00000ooooooooool08oooool00`00003oooooooooo`07ooooo`030000003o
0000o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0003o000U003o000300000?oo
oooooooo03[ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool01?ooool0
0ooo003oooooooooo`0]ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool09?ooool0
0ol00?ooooooooooo`0Tooooo`0300000?oooooooooo01cooooo0ol00004ooooo`0300000?l0003o
oooo00Oooooo00<000000?l0003o00009@3o00000`00003oooooooooo`07ooooo`0300000000o`00
0?l002D00?l000<00000ooooooooool0>Oooool00ol000000000ooooo`09ooooo`002Oooool00`00
003oooooooooo`04ooooo`03ool00?oooooooooo02cooooo00?oo`00ooooooooool0;oooool00ol0
0?ooooooooooo`0Rooooo`03o`00oooooooooooo02Gooooo00<00000ooooooooool07Oooool00ol0
003oooooooooo`03ooooo`0300000?oooooooooo00Oooooo00<000000?l0003o00009@3o00000`00
003oooooooooo`07ooooo`0300000000o`000?l002D00?l000<00000ooooooooool0>_ooool00`00
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`05ooooo`03ool00?oooooooooo02_o
oooo00?oo`00ooooooooool0;oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02Go
oooo00<00000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`0300000?l00000001o00L0
001o00<000000?l0003o00009@3o00000`000000001o0000O`070000O`0300000000o`000?l002D0
0?l000<000000000O`0007l0>00007l3000000[ooooo0009ooooo`0300000?oooooooooo00Gooooo
00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`0`ooooo`03o`00oooooooooooo02;ooooo
00?o003oooooooooool09Oooool00`00003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo
00<00000ooooooooool01oooool00`000000o`000?l0000U0?l0000300000?oooooooooo00Oooooo
00<00000003o0000o`009@00o`000`00003oooooooooo`0jooooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo00Kooooo00?oo`00ooooooooool0:Oooool00ooo003ooooooooo
o`0`ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool09_ooool00`00003ooooooooo
o`0Mooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool01oooool00`000000o`000?l0
000U0?l0000300000?oooooooooo00Oooooo00<00000003o0000o`009@00o`000`00003ooooooooo
o`0jooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo00Kooooo00?oo`00
ooooooooool0:?ooool00ooo003oooooooooo`0aooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool09_ooool00`00003oooooooooo`0Looooo`;o00001Oooool00`00003o0000ooooo`07
ooooo`030000003o0000o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0003o000U
003o000300000?oooooooooo03Wooooo00?o000000000?ooool02Oooool000Wooooo00<00000oooo
ooooool01oooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo03;ooooo00?o003ooooo
ooooool08?ooool00ol00?ooooooooooo`0Vooooo`0300000?oooooooooo01gooooo00?o0000oooo
ooooool00oooool00`00003oooooooooo`07ooooo`030000003o0000o`0002D0o`0000<00000oooo
ooooool01oooool00`0000000?l0003o000U003o000300000?oooooooooo03[ooooo00<00000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool01oooool00ooo003oooooooooo`0Vooooo`03
ool00?oooooooooo03?ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Vooooo`03
00000?oooooooooo02?ooooo00<00000o`000?ooool01oooool00`000000o`000?l0000U0?l00003
00000?oooooooooo00Oooooo00<00000003o0000o`009@00o`000`00003oooooooooo`0iooooo`03
o`000000003ooooo00Wooooo0009ooooo`0300000?oooooooooo00Oooooo00?oo`00ooooooooool0
9_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0
9_ooool00`00003oooooooooo`0Sooooo`0300000?oooooooooo00Oooooo00<000000?l0003o0000
9@3o00000`00003oooooooooo`07ooooo`0300000000o`000?l002D00?l000<00000ooooooooool0
>_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`08ooooo`03ool00?oo
oooooooo02Gooooo00?oo`00ooooooooool0<oooool00ol00?ooooooooooo`0Oooooo`03o`00oooo
oooooooo02Oooooo00<00000ooooooooool08oooool00`00003oooooooooo`07ooooo`030000003o
0000o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0003o000U003o000300000?oo
oooooooo03[ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool02?ooool0
0ooo003oooooooooo`0Tooooo`03ool00?oooooooooo03Cooooo00?o003oooooooooool07oooool0
0ol00?ooooooooooo`0Wooooo`0300000?oooooooooo02?ooooo00<00000o`000?ooool01oooool0
0`000000o`000?l0000U0?l0000300000?oooooooooo00Oooooo00<00000003o0000o`009@00o`00
0`00003oooooooooo`0iooooo`03o`000000003ooooo00Wooooo0009ooooo`0300000?oooooooooo
00Wooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`0eooooo`03o`00oooooooooooo
01kooooo00?o003oooooooooool09oooool00`00003oooooooooo`0Sooooo`0300000?oooooooooo
00Oooooo00<000000?l0003o00009@3o00000`00003oooooooooo`07ooooo`0300000000o`000?l0
02D00?l000<00000ooooooooool0>_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`09ooooo`03ool00?oooooooooo02;ooooo00?oo`00ooooooooool0=_ooool00ol00?oo
ooooooooo`0Nooooo`03o`00oooooooooooo02Oooooo00<00000ooooooooool08oooool00`00003o
ooooooooo`07ooooo`030000003o0000o`0002D0o`0000<00000ooooooooool01oooool00`000000
0?l0003o000U003o000300000?oooooooooo03[ooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool02_ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo03Kooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`0Wooooo`0300000?oooooooooo013ooooo
0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`0300000?l0003ooooo00Oooooo
00<000000?l0003o00009@3o00000`00003oooooooooo`07ooooo`0300000000o`000?l002D00?l0
00<00000ooooooooool0>Oooool00ol000000000ooooo`09ooooo`002Oooool00`00003ooooooooo
o`0:ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool0=oooool00ol00?oooooooooo
o`0Nooooo`03o`00oooooooooooo02Oooooo00<00000ooooooooool04Oooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool000000oooool00`00003oooooooooo`07ooooo`030000
003o0000o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0003o000U003o00030000
0?oooooooooo03[ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool02_oo
ool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo03Oooooo00?o003oooooooooool07Ooo
ool00ol00?ooooooooooo`0Xooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool02ooo
ool01_l0003oooooooooooooool00000o`0000P0001o00<000000?l0003o00009@3o00000`000000
001o0000O`070000O`0300000000o`000?l002D00?l000<000000000O`0007l0>00007l3000000[o
oooo0009ooooo`0300000?oooooooooo00_ooooo00?oo`00ooooooooool07_ooool00ooo003ooooo
ooooo`0iooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0:?ooool00`00003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooo00000009ooooo`03
0000003o0000o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0003o000U003o0003
00000?oooooooooo03[ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
2oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo03Wooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Xooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool0
1oooool4o`0000Cooooo00<00000ooooooooool01oooool00`000000o`000?l0000U0?l000030000
0?oooooooooo00Oooooo00<00000003o0000o`009@00o`000`00003oooooooooo`0jooooo`030000
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo00_ooooo00?oo`00ooooooooool07Ooo
ool00ooo003oooooooooo`0jooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0:?oo
ool00`00003oooooooooo`0@ooooo`;o00002Oooool00ol0003oooooooooo`05ooooo`0300000?l0
003ooooo00Oooooo00<000000?l0003o00009@3o00000`00003oooooooooo`07ooooo`0300000000
o`000?l002D00?l000<00000ooooooooool0>Oooool00ol000000000ooooo`09ooooo`002Oooool0
0`00003oooooooooo`0<ooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool0>_ooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02Sooooo00<00000ooooooooool04Oooool0
0ol0003oooooooooo`07ooooo`Go00000oooool00`00003oooooooooo`07ooooo`030000003o0000
o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0003o000U003o000300000?oooooo
oooo03[ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool03?ooool00ooo
003oooooooooo`0Looooo`03ool00?oooooooooo03[ooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`0Xooooo`0300000?oooooooooo02?ooooo00<00000o`000?ooool01oooool00`00
0000o`000?l0000U0?l0000300000?oooooooooo00Oooooo00<00000003o0000o`009@00o`000`00
003oooooooooo`0iooooo`03o`000000003ooooo00Wooooo0009ooooo`0300000?oooooooooo00go
oooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`0looooo`03o`00oooooooooooo01[o
oooo00?o003oooooooooool0:Oooool00`00003oooooooooo`0Sooooo`0300000?oooooooooo00Oo
oooo00<000000?l0003o00009@3o00000`00003oooooooooo`07ooooo`0300000000o`000?l002D0
0?l000<00000ooooooooool0>_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`0=ooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool0??ooool00ol00?oooooo
ooooo`0Jooooo`03o`00oooooooooooo02Wooooo00<00000ooooooooool08oooool00`00003ooooo
ooooo`07ooooo`030000003o0000o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0
003o000U003o000300000?oooooooooo03[ooooo00<00000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool03_ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo03gooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`0Yooooo`0300000?oooooooooo02?ooooo00<0
0000o`000?ooool01oooool00`000000o`000?l0000U0?l0000300000?oooooooooo00Oooooo00<0
0000003o0000o`009@00o`000`00003oooooooooo`0iooooo`03o`000000003ooooo00Wooooo0009
ooooo`0300000?oooooooooo00kooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0m
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0:Oooool00`00003oooooooooo`0S
ooooo`0300000?oooooooooo00Oooooo00<000000?l0003o00009@3o00000`00003oooooooooo`07
ooooo`0300000000o`000?l002D00?l000<00000ooooooooool0>_ooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`0>ooooo`03ool00?oooooooooo01Oooooo00?oo`00oooo
ooooool0?_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo02Wooooo00<00000oooo
ooooool06oooool5o`0000?ooooo00<00000o`000?ooool01oooool00`000000o`000?l0000U0?l0
000300000?oooooooooo00Oooooo00<00000003o0000o`009@00o`000`00003oooooooooo`0ioooo
o`03o`000000003ooooo00Wooooo0009ooooo`0300000?oooooooooo00oooooo00?oo`00oooooooo
ool05_ooool00ooo003oooooooooo`0oooooo`03o`00oooooooooooo01Sooooo00?o003ooooooooo
ool0:_ooool00`00003oooooooooo`0Looooo`04o`000?ooooooooooo`0000?ooooo00<00000oooo
ooooool01oooool00`000000o`000?l0000U0?l0000300000?oooooooooo00Oooooo00<00000003o
0000o`009@00o`000`00003oooooooooo`0jooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo00oooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0oooooo`03
o`00oooooooooooo01Sooooo00?o003oooooooooool0:_ooool00`00003oooooooooo`0Mooooo`03
o`000?oooooooooo00?ooooo00<00000ooooooooool01oooool00`000000o`000?l0000U0?l00003
00000?oooooooooo00Oooooo00<00000003o0000o`009@00o`000`00003oooooooooo`0jooooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo013ooooo00?oo`00ooooooooool0
5?ooool00ooo003oooooooooo`10ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
:_ooool00`00003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00<00000o`00000007l0
1`0007l00`000000o`000?l0000U0?l000030000000007l0001o00L0001o00<00000003o0000o`00
9@00o`000`000000001o0000O`0h0000O`<000002_ooool000Wooooo00<00000ooooooooool04?oo
ool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo043ooooo00?o003oooooooooool06?oo
ool00ol00?ooooooooooo`0Zooooo`0300000?oooooooooo01_ooooo00Go0000oooooooooooooooo
o`000003ooooo`0300000?oooooooooo00Oooooo00<000000?l0003o00009@3o00000`00003ooooo
ooooo`07ooooo`0300000000o`000?l002D00?l000<00000ooooooooool0>_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`0Aooooo`03ool00?oooooooooo01;ooooo00?o
o`00ooooooooool0@Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo02[ooooo00<0
0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000?ooooo00<00000o`000?ooool0
1oooool00`000000o`000?l0000U0?l0000300000?oooooooooo00Oooooo00<00000003o0000o`00
9@00o`000`00003oooooooooo`0iooooo`03o`000000003ooooo00Wooooo0009ooooo`0300000?oo
oooooooo01;ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`12ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool0:_ooool00`00003oooooooooo`0Looooo`?o00001?oo
ool00`00003oooooooooo`07ooooo`030000003o0000o`0002D0o`0000<00000ooooooooool01ooo
ool00`0000000?l0003o000U003o000300000?oooooooooo03[ooooo00<00000ooooooooool02?oo
ool000Wooooo00<00000ooooooooool04_ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooo
oooo04?ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0[ooooo`0300000?oooooo
oooo02?ooooo00<00000ooooooooool01oooool00`000000o`000?l0000U0?l0000300000?oooooo
oooo00Oooooo00<00000003o0000o`009@00o`000`00003oooooooooo`0jooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo01?ooooo00?oo`00ooooooooool03_ooool00ooo
003oooooooooo`14ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0:oooool00`00
003oooooooooo`0Sooooo`0300000?l0003ooooo00Oooooo00<000000?l0003o00009@3o00000`00
003oooooooooo`07ooooo`0300000000o`000?l002D00?l000<00000ooooooooool0>Oooool00ol0
00000000ooooo`09ooooo`002Oooool00`00003oooooooooo`0Dooooo`03ool00?oooooooooo00go
oooo00?oo`00ooooooooool0A?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo02_o
oooo00<00000ooooooooool08oooool00`00003oooooooooo`07ooooo`030000003o0000o`0002D0
o`0000<00000ooooooooool01oooool00`0000000?l0003o000U003o000300000?oooooooooo03[o
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool05Oooool00ooo003ooooo
ooooo`0;ooooo`03ool00?oooooooooo04Gooooo00?o003oooooooooool05_ooool00ol00?oooooo
ooooo`0[ooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool01oooool00`000000o`00
0?l0000U0?l0000300000?oooooooooo00Oooooo00<00000003o0000o`009@00o`000`00003ooooo
ooooo`0jooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Kooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`17ooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool0:oooool00`00003oooooooooo`0Sooooo`0300000?l0003ooooo00Oooooo00<0
00000?l0003o00009@3o00000`00003oooooooooo`07ooooo`0300000000o`000?l002D00?l000<0
0000ooooooooool0>Oooool00ol000000000ooooo`09ooooo`002Oooool00`00003oooooooooo`0F
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0B?ooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo02_ooooo00<00000ooooooooool08oooool00`00003oooooooooo`07
ooooo`030000003o0000o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0003o000U
003o000300000?oooooooooo03[ooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooo
ooooool05oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo04Wooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0/ooooo`0300000?oooooooooo00oooooo1Ol00003oooo
o`03o`000?oooooooooo00;ooooo0ol00004ooooo`0300000?l0003ooooo00Oooooo00<000000?l0
003o00009@3o00000`00003oooooooooo`07ooooo`0300000000o`000?l002D00?l000<00000oooo
ooooool0>Oooool00ol000000000ooooo`09ooooo`002Oooool00`00003oooooooooo`0Hooooo`;o
o`001?ooool2ool004cooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0/ooooo`03
00000?oooooooooo013ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000?ooooo00<00000ooooooooool01oooool00`000000o`000?l0000U0?l0000300000?oooooo
oooo00Oooooo00<00000003o0000o`009@00o`000`00003oooooooooo`0jooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo01[ooooo1Ooo001=ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool0;?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo
00_ooooo00Go0000oooooooooooooooo00000009ooooo`030000003o0000o`0002D0o`0000<00000
ooooooooool01oooool00`0000000?l0003o000U003o000300000?oooooooooo03[ooooo00<00000
ooooooooool02?ooool000Wooooo00<00000ooooooooool0KOooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo02cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0:oooo
o`06o`000?ooooooooooooooo`00003o0000200007l00`000000o`000?l0000U0?l0000300000000
07l0001o00L0001o00<00000003o0000o`009@00o`000`000000001o0000O`0h0000O`<000002_oo
ool000Wooooo00<00000ooooooooool0KOooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo02cooooo00<00000ooooooooool03oooool01Ol0003ooooooooooooooooo000000Oooooo1?l0
0004ooooo`0300000?oooooooooo00Oooooo00<000000?l0003o00009@3o00000`00003ooooooooo
o`07ooooo`0300000000o`000?l002D00?l000<00000ooooooooool0>_ooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`1]ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool0;Oooool00`00003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`05ooooo`0300000?l0003ooooo00Oooooo00<000000?l0003o00009@3o
00000`00003oooooooooo`07ooooo`0300000000o`000?l002D00?l000<00000ooooooooool0>Ooo
ool00ol000000000ooooo`09ooooo`002Oooool00`00003oooooooooo`1]ooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool0;Oooool00`00003oooooooooo`0@ooooo`?o00002?ooool5
o`0000?ooooo00<00000ooooooooool01oooool00`000000o`000?l0000U0?l0000300000?oooooo
oooo00Oooooo00<00000003o0000o`009@00o`000`00003oooooooooo`0jooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo06gooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0]ooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool01oooool00`00
0000o`000?l0000U0?l0000300000?oooooooooo00Oooooo00<00000003o0000o`009@00o`000`00
003oooooooooo`0jooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo06go
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0]ooooo`0300000?oooooooooo02?o
oooo00<00000o`000?ooool01oooool00`000000o`000?l0000U0?l0000300000?oooooooooo00Oo
oooo00<00000003o0000o`009@00o`000`00003oooooooooo`0iooooo`03o`000000003ooooo00Wo
oooo0009ooooo`0300000?oooooooooo06kooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`0^ooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool01oooool00`000000o`00
0?l0000U0?l0000300000?oooooooooo00Oooooo00<00000003o0000o`009@00o`000`00003ooooo
ooooo`0jooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo06kooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`0^ooooo`0300000?oooooooooo02?ooooo00<0
0000o`000?ooool01oooool00`000000o`000?l0000U0?l0000300000?oooooooooo00Oooooo00<0
0000003o0000o`009@00o`000`00003oooooooooo`0iooooo`03o`000000003ooooo00Wooooo0009
ooooo`0300000?oooooooooo06kooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0^
ooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool01oooool00`000000o`000?l0000U
0?l0000300000?oooooooooo00Oooooo00<00000003o0000o`009@00o`000`00003oooooooooo`0j
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo06kooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`0^ooooo`0300000?oooooooooo02?ooooo00<00000oooo
ooooool01oooool00`000000o`000?l0000U0?l0000300000?oooooooooo00Oooooo00<00000003o
0000o`009@00o`000`00003oooooooooo`0jooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo06kooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0^ooooo`03
00000?oooooooooo01cooooo0ol00004ooooo`0300000?l0003ooooo00Oooooo00<000000?l0003o
00009@3o00000`00003oooooooooo`07ooooo`0300000000o`000?l002D00?l000<00000oooooooo
ool0>Oooool00ol000000000ooooo`09ooooo`002Oooool00`00003oooooooooo`1_ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool0;oooool00`00003oooooooooo`0Kooooo`05o`00
0?ooooooooooooooool000000oooool00`00003oooooooooo`07ooooo`030000003o0000o`0002D0
o`0000<00000ooooooooool01oooool00`0000000?l0003o000U003o000300000?oooooooooo03[o
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0Koooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo02oooooo00<00000ooooooooool07oooool01_l0003ooooo
ooooooooool00000o`0000P0001o00<000000?l0003o00009@3o00000`000000001o0000O`070000
O`0300000000o`000?l002D00?l000<000000000O`0007l0>00007l3000000[ooooo0009ooooo`03
00000?oooooooooo06oooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0_ooooo`03
00000?oooooooooo01gooooo0_l00004ooooo`0300000?oooooooooo00Oooooo00<000000?l0003o
00009@3o00000`00003oooooooooo`07ooooo`0300000000o`000?l002D00?l000<00000oooooooo
ool0>_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1_ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool0;oooool00`00003oooooooooo`0Oooooo`05o`00
0?ooooooooooooooo`0000002Oooool00`000000o`000?l0000U0?l0000300000?oooooooooo00Oo
oooo00<00000003o0000o`009@00o`000`00003oooooooooo`0jooooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo06oooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`0`ooooo`0300000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`000003ooooo`03
00000?l0003ooooo00Oooooo00<000000?l0003o00009@3o00000`00003oooooooooo`07ooooo`03
00000000o`000?l002D00?l000<00000ooooooooool0>Oooool00ol000000000ooooo`09ooooo`00
2Oooool00`00003oooooooooo`1`ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
<?ooool00`00003oooooooooo`0Looooo`?o00001?ooool00`00003oooooooooo`07ooooo`030000
003o0000o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0003o000U003o00030000
0?oooooooooo03[ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0L?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo033ooooo00<00000ooooooooool08ooo
ool00`00003o0000ooooo`07ooooo`030000003o0000o`0002D0o`0000<00000ooooooooool01ooo
ool00`0000000?l0003o000U003o000300000?oooooooooo03Wooooo00?o000000000?ooool02Ooo
ool000Wooooo00<00000ooooooooool0L?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo033ooooo00<00000ooooooooool08oooool00`00003oooooooooo`07ooooo`030000003o0000
o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0003o000U003o000300000?oooooo
oooo03[ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0L?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo037ooooo00<00000ooooooooool08oooool00`00
003oooooooooo`07ooooo`030000003o0000o`0002D0o`0000<00000ooooooooool01oooool00`00
00000?l0003o000U003o000300000?oooooooooo03[ooooo00<00000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0L?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo037o
oooo00<00000ooooooooool08oooool00`00003o0000ooooo`07ooooo`030000003o0000o`0002D0
o`0000<00000ooooooooool01oooool00`0000000?l0003o000U003o000300000?oooooooooo03Wo
oooo00?o000000000?ooool02Oooool000Wooooo00<00000ooooooooool0LOooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo037ooooo00<00000ooooooooool08oooool00`00003ooooo
ooooo`07ooooo`030000003o0000o`0002D0o`0000<00000ooooooooool01oooool00`0000000?l0
003o000U003o000300000?oooooooooo03[ooooo00<00000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0LOooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo03;ooooo00<0
0000ooooooooool08oooool00`00003oooooooooo`07ooooo`030000003o0000o`0002D0o`0000<0
0000ooooooooool01ooooolY000003cooooo00<00000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0LOooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo03;ooooo00<00000
ooooooooool04?ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00<00000
o`000?ooool01oooool00`000000o`000?l0000U0?l0000300000?oooooooooo06_ooooo00?o0000
00000?ooool02Oooool000Wooooo00<00000ooooooooool0LOooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo03;ooooo00<00000ooooooooool03oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`0300000?oooooooooo00Oooooo00<0
00000?l0003o00009@3o00000`00003oooooooooo`1/ooooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo07;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0b
ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool01_l0003ooooooooooooo
ool00000o`0000P0001o00<000000?l0003o00009@3o00000`000000001o0000O`1Z0000O`<00000
2_ooool000Wooooo00<00000ooooooooool0L_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo03;ooooo00<00000ooooooooool04Oooool2o`0000cooooo00Go0000oooooooooooooooo
00000009ooooo`030000003o0000o`0002D0o`0000<00000ooooooooool0K?ooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`1booooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool0<oooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo1?l0
0004ooooo`0300000?oooooooooo00Oooooo00<000000?l0003o00009@3o00000`00003ooooooooo
o`1/ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo07?ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0cooooo`0300000?oooooooooo00oooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Gooooo00<00000o`000?ooool01ooo
ool00`000000o`000?l0000U0?l0000300000?oooooooooo06_ooooo00?o000000000?ooool02Ooo
ool000Wooooo00<00000ooooooooool0Loooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo03?ooooo00<00000ooooooooool04?ooool3o`0000Sooooo1Ol00003ooooo`0300000?oooooo
oooo00Oooooo00<000000?l0003o00009@3o00000`00003oooooooooo`1/ooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo07?ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0cooooo`0300000?oooooooooo02?ooooo00<00000o`000?ooool01ooooolY0000
06gooooo00?o000000000?ooool02Oooool000Wooooo00<00000ooooooooool0M?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo03Cooooo00<00000ooooooooool08oooool00`00003o
ooooooooo`2Nooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo07Cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0dooooo`0300000?oooooooooo02?ooooo
00<00000ooooooooool0W_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`1eooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0=?ooool00`00003ooooooooo
o`0Soooooj8000002_ooool000Wooooo00<00000ooooooooool0MOooool2o`00o`;ooooo0_l00?lg
ooooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo07Kooooo1?l00?lhoooo
o`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool0coooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Ooo
oonf00000=7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo0009oooookH000004Ooooonf000000[ooooo0009ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo00;ooooo
=Ol00?lSooooodCoo`001@000?l00ol00?l0003o0000o`02o`00o`80003o00?o003o0000o`000?l0
0_l00?l3ooooo`0300000?oooooooooo00oooooo00@00000oooooooooooooooo?_l00?lSooooocko
o`0000@0003oo`00o`000?l0003o1?l00?l20000o`04o`00o`000?l0003o0000o`Cooooo00<00000
ooooooooool02?ooool000Wooooo00<00000ooooooooool0=oooool5o`00oaSooooo1_oo000ooooo
o`<0003o00?o003o0000ooooool04oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
03oooooo1_l00?lGooooo`Koo`00>_ooool40000oa;ooooo00<00000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0??ooool2o`00oaCooooo0_oo0012ooooo`030000ool00?l0003o01Wo
oooo00<00000ooooooooool03oooool00`00003oooooooooo`15ooooo`03o`00oooooooooooo01;o
oooo0_oo000oooooo`030000oooooooooooo01Cooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0?_ooool2o`00oa3ooooo0_oo0012ooooo`80003o7?ooool00`00003ooooo
ooooo`0?ooooo`0300000?oooooooooo04Kooooo0_l00?l?ooooo`?oo`00?oooool00`000?oo003o
ooooo`0Fooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo043ooooo00?o
003oooooooooool02oooool2ool004?ooooo00<0003oooooooooool07?ooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo04Sooooo0_l00?l;ooooo`;oo`00@?ooool20000oaWooooo00<0
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0@Oooool00ol00?ooooooooooo`09
ooooo`03ool00?oooooooooo04;ooooo00<0003oooooooooool07Oooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo04[ooooo00?o003oooooooooool01_ooool2ool0043ooooo0P000?lK
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo04;ooooo00?o003ooooo
ooooool01_ooool2ool004Cooooo00<0003oooooooooool07_ooool00`00003oooooooooo`0?oooo
o`0300000?oooooooooo04_ooooo00?o003oooooooooool00oooool2ool0047ooooo00<0003ooooo
ooooool06oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`13ooooo`03
o`00oooooooooooo00Cooooo00?oo`00ooooooooool0@oooool00`000?ooooooooooo`0Oooooo`03
00000?oooooooooo00oooooo00<00000ooooooooool0C?ooool01Ol00?ooooooooooooooooooo`00
04?ooooo00<0003oooooooooool06oooool00`00003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`14ooooo`03o`00oooooooooooo00?ooooo00?oo`00ooooooooool0@_ooool00`000?oo
ooooooooo`0Pooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0C?ooool01?l00?oo
oooooooooooo0013ooooo`030000oooooooooooo01cooooo00<00000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0AOooool01Ol00?ooooooooooooooooooo`0004Cooooo00<0003ooooo
ooooool08Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo04gooooo00?o003oool0
0?ooool0@_ooool00`000?ooooooooooo`0Mooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo04Gooooo00Go003oooooooooooooooooool00013ooooo`030000oooooooooooo
02;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`1=ooooo`03ool00?l00?oooooo
047ooooo00<0003oooooooooool07_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`16ooooo`03o`00ooooooooo`0004Cooooo00<0003oooooooooool08_ooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo04cooooo00?oo`00ooooool00?l0@_ooool00`000?oo
ooooooooo`0Nooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo04Oooooo
00?o003oooooooooool0@_ooool00`000?ooooooooooo`0Sooooo`0300000?oooooooooo00oooooo
00<00000ooooooooool0C?ooool01?oo003oooooooooool00?m0ooooo`030000oooooooooooo01oo
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0A_ooool00ooo003o003o
ooooo`13ooooo`030000oooooooooooo02?ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`1;ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool0?Oooool00`000?oooooo
ooooo`0Oooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo04Gooooo00Co
o`00oooooooooooo003o@_ooool00`000?ooooooooooo`0Tooooo`0300000?oooooooooo00oooooo
00<00000ooooooooool0B_ooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo03cooooo
00<0003oooooooooool08?ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`15ooooo`05ool00?ooooooooooooooool00?l0@Oooool00`000?ooooooooooo`0Tooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool0B_ooool00ooo003oooooooooo`04ooooo`03o`00
oooooooooooo03_ooooo00<0003oooooooooool08?ooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`14ooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool0?_oo
ool00`000?ooooooooooo`0Uooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0BOoo
ool00ooo003oooooooooo`05ooooo`03o`00oooooooooooo03[ooooo00<0003oooooooooool08Ooo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`13ooooo`03ool00?oooooo
oooo00Cooooo00?o003oooooooooool0?Oooool00ol00?ooooooooooo`0Uooooo`0300000?oooooo
oooo00oooooo00D00000ooooooooooooooooool00017ooooo`03ool00?oooooooooo00Kooooo00?o
003oooooooooool0>?ooool00`000?ooooooooooo`0Rooooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo04?ooooo00?oo`00ooooooooool01?ooool00ol00?ooooooooooo`0l
ooooo`03o`00oooooooooooo02Kooooo00<00000ooooooooool03oooool01@00003ooooooooooooo
ooooo`0004Kooooo00?oo`00ooooooooool01oooool00ol00?ooooooooooo`0hooooo`030000oooo
oooooooo02;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0@_ooool0
0ooo003oooooooooo`06ooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool09_ooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo00;ooooo00?oo`00ooooooooool0@oooool0
0ooo003oooooooooo`08ooooo`03o`00oooooooooooo03Kooooo00<0003oooooooooool08oooool0
0`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`11ooooo`03ool00?oooooooooo
00Sooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0Wooooo`0300000?oooooooooo
00oooooo00<00000ooooooooool00_ooool00ooo003oooooooooo`12ooooo`03ool00?oooooooooo
00Wooooo00?o003oooooooooool0=_ooool00`000?ooooooooooo`0Sooooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo00;ooooo00?oo`00ooooooooool0??ooool00ooo003o
ooooooooo`08ooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool09oooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo00?ooooo00?oo`00ooooooooool0@?ooool00ooo003o
ooooooooo`0;ooooo`03o`00oooooooooooo03Gooooo00<0003oooooooooool08oooool00`00003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`02ooooo`03ool00?oooooooooo03_ooooo
00?oo`00ooooooooool02_ooool00ol00?ooooooooooo`0gooooo`03o`00oooooooooooo02Sooooo
00<00000ooooooooool03oooool00`00003oooooooooo`03ooooo`03ool00?oooooooooo043ooooo
00?oo`00ooooooooool02oooool00ol00?ooooooooooo`0dooooo`030000oooooooooooo02Cooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool00oooool00ooo003ooooooooo
o`0jooooo`03ool00?oooooooooo00[ooooo00?o003oooooooooool0=oooool00ol00?oooooooooo
o`0Xooooo`0300000?oooooooooo00oooooo00<00000ooooooooool01?ooool00ooo003ooooooooo
o`0nooooo`03ool00?oooooooooo00gooooo00?o003oooooooooool0<oooool00`000?oooooooooo
o`0Tooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo00?ooooo00?oo`00
ooooooooool0>_ooool00ooo003oooooooooo`0;ooooo`03o`00oooooooooooo03Gooooo00?o003o
ooooooooool0:Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo00Gooooo00?oo`00
ooooooooool0?Oooool00ooo003oooooooooo`0=ooooo`03o`00oooooooooooo03?ooooo00<0003o
ooooooooool09?ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`03oooo
o`03ool00?oooooooooo03Wooooo00?oo`00ooooooooool03?ooool00ol00?ooooooooooo`0eoooo
o`03o`00oooooooooooo02Wooooo00<00000ooooooooool03oooool00`00003oooooooooo`05oooo
o`03ool00?oooooooooo03cooooo00?oo`00ooooooooool03_ooool00ol00?ooooooooooo`0boooo
o`030000oooooooooooo02Gooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooooooo
ool01?ooool00ooo003oooooooooo`0hooooo`03ool00?oooooooooo00cooooo00?o003ooooooooo
ool0=?ooool00ol00?ooooooooooo`0Zooooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool01_ooool00ooo003oooooooooo`0jooooo`03ool00?oooooooooo013ooooo00?o003ooooooooo
ool0<Oooool00`000?ooooooooooo`0Uooooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo00Cooooo00?oo`00ooooooooool0=oooool00ooo003oooooooooo`0>ooooo`03o`00
oooooooooooo03?ooooo00?o003oooooooooool0:_ooool00`00003oooooooooo`0?ooooo`030000
0?oooooooooo00Kooooo00?oo`00ooooooooool0>_ooool00ooo003oooooooooo`0@ooooo`03o`00
oooooooooooo037ooooo00<0003oooooooooool09Oooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`05ooooo`03ool00?oooooooooo03Kooooo00?oo`00ooooooooool03_oo
ool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo02[ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`07ooooo`03ool00?oooooooooo03Sooooo00?oo`00ooooooooool04Ooo
ool00ol00?ooooooooooo`0aooooo`030000oooooooooooo02Gooooo00<00000ooooooooool02?oo
ool000Wooooo00<00000ooooooooool01Oooool00ooo003oooooooooo`0eooooo`03ool00?oooooo
oooo00oooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`0[ooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool01oooool00ooo003oooooooooo`0hooooo`03ool00?oooooo
oooo01;ooooo00?o003oooooooooool0;oooool00`000?ooooooooooo`0Vooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo00Gooooo00?oo`00ooooooooool0=Oooool00ooo
003oooooooooo`0@ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0:oooool00`00
003oooooooooo`0?ooooo`0300000?oooooooooo00Sooooo00?oo`00ooooooooool0=_ooool00ooo
003oooooooooo`0Cooooo`03o`00oooooooooooo02oooooo00<0003oooooooooool09_ooool00`00
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`06ooooo`03ool00?oooooooooo03Co
oooo00?oo`00ooooooooool04?ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo02_o
oooo00<00000ooooooooool03oooool00`00003oooooooooo`08ooooo`03ool00?oooooooooo03Ko
oooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`0_ooooo`030000oooooooooooo02Ko
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool01_ooool00ooo003ooooo
ooooo`0cooooo`03ool00?oooooooooo017ooooo00?o003oooooooooool0<?ooool00ol00?oooooo
ooooo`0/ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool02Oooool00ooo003ooooo
ooooo`0dooooo`03ool00?oooooooooo01Gooooo00?o003oooooooooool0;Oooool00`000?oooooo
ooooo`0Wooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo00Kooooo00?o
o`00ooooooooool0<oooool00ooo003oooooooooo`0Aooooo`03o`00oooooooooooo033ooooo00?o
003oooooooooool0;?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo00Wooooo00?o
o`00ooooooooool0=?ooool00ooo003oooooooooo`0Eooooo`03o`00oooooooooooo02gooooo00<0
003oooooooooool09oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`07
ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`0_
ooooo`03o`00oooooooooooo02cooooo00<00000ooooooooool03oooool00`00003oooooooooo`0:
ooooo`03ool00?oooooooooo03?ooooo00?oo`00ooooooooool05Oooool00ol00?ooooooooooo`0]
ooooo`030000oooooooooooo02Oooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooo
ooooool01oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo01?ooooo00?o003ooooo
ooooool0;oooool00ol00?ooooooooooo`0/ooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool02_ooool00ooo003oooooooooo`0booooo`03ool00?oooooooooo01Kooooo00?o003ooooo
ooooool0;Oooool00`000?ooooooooooo`0Wooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo00Sooooo00?oo`00ooooooooool0<?ooool00ooo003oooooooooo`0Cooooo`03
o`00oooooooooooo02kooooo00?o003oooooooooool0;Oooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo00[ooooo00?oo`00ooooooooool0<_ooool00ooo003oooooooooo`0Gooooo`03
o`00oooooooooooo02_ooooo00<0003oooooooooool0:?ooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`08ooooo`03ool00?oooooooooo02oooooo00?oo`00ooooooooool0
5Oooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo02gooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`0;ooooo`03ool00?oooooooooo033ooooo00?oo`00ooooooooool0
6?ooool00ol00?ooooooooooo`0[ooooo`030000oooooooooooo02Sooooo00<00000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool02?ooool00ooo003oooooooooo`0_ooooo`03ool00?oo
oooooooo01Gooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0]ooooo`0300000?oo
oooooooo00oooooo00<00000ooooooooool02oooool00ooo003oooooooooo`0`ooooo`03ool00?oo
oooooooo01Sooooo00?o003oooooooooool0:oooool00`000?ooooooooooo`0Xooooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo00Wooooo00?oo`00ooooooooool0;_ooool0
0ooo003oooooooooo`0Eooooo`03o`00oooooooooooo02cooooo00?o003oooooooooool0;_ooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo00cooooo00?oo`00ooooooooool0;_ooool0
0ooo003oooooooooo`0Iooooo`03o`00oooooooooooo02[ooooo00<0003oooooooooool0:Oooool0
0`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`09ooooo`03ool00?oooooooooo
02gooooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo
02kooooo00<00000ooooooooool03oooool00`00003oooooooooo`0<ooooo`03ool00?oooooooooo
02kooooo00?oo`00ooooooooool06_ooool00ol00?ooooooooooo`0Yooooo`030000oooooooooooo
02Wooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool02Oooool00ooo003o
ooooooooo`0]ooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool0:oooool00ol00?oo
ooooooooo`0^ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool03Oooool00ooo003o
ooooooooo`0]ooooo`03ool00?oooooooooo01[ooooo00?o003oooooooooool0:Oooool00`000?oo
ooooooooo`0Yooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo00[ooooo
00?oo`00ooooooooool0;?ooool00ooo003oooooooooo`0Gooooo`03o`00oooooooooooo02_ooooo
00?o003oooooooooool0;_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo00gooooo
00?oo`00ooooooooool0;?ooool00ooo003oooooooooo`0Kooooo`03o`00oooooooooooo02Sooooo
00<0003oooooooooool0:_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`0:ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool06?ooool00ol00?oooooooooo
o`0Zooooo`03o`00oooooooooooo02oooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`0>ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool06oooool00ol00?oooooooooo
o`0Xooooo`030000oooooooooooo02[ooooo00<00000ooooooooool02?ooool000Wooooo00<00000
ooooooooool02_ooool00ooo003oooooooooo`0[ooooo`03ool00?oooooooooo01Wooooo00?o003o
ooooooooool0:Oooool00ol00?ooooooooooo`0_ooooo`0300000?oooooooooo00oooooo00<00000
ooooooooool03_ooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo01gooooo00?o003o
ooooooooool09oooool00`000?ooooooooooo`0Zooooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo00_ooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`0Ioooo
o`03o`00oooooooooooo02Wooooo00?o003oooooooooool0;oooool00`00003oooooooooo`0?oooo
o`0300000?oooooooooo00kooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`0Moooo
o`03o`00oooooooooooo02Oooooo00<0003oooooooooool0:_ooool00`00003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`0;ooooo`03ool00?oooooooooo02Wooooo00?oo`00oooooooo
ool06_ooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo033ooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`0?ooooo`03ool00?oooooooooo02Sooooo00?oo`00oooooooo
ool07_ooool00ol00?ooooooooooo`0Vooooo`030000oooooooooooo02_ooooo00<00000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool02oooool00ooo003oooooooooo`0Yooooo`03ool0
0?oooooooooo01[ooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0`ooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool03oooool00ooo003oooooooooo`0Xooooo`03ool0
0?oooooooooo01oooooo00?o003oooooooooool09Oooool00`000?ooooooooooo`0[ooooo`030000
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo00cooooo00?oo`00ooooooooool0:?oo
ool00ooo003oooooooooo`0Kooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool0<?oo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo013ooooo00?oo`00ooooooooool09ooo
ool00ooo003oooooooooo`0Oooooo`03o`00oooooooooooo02Gooooo00<0003oooooooooool0:ooo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0<ooooo`03ool00?oooooo
oooo02Oooooo00?oo`00ooooooooool07?ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooo
oooo033ooooo00<00000ooooooooool03oooool00`00003oooooooooo`0@ooooo`03ool00?oooooo
oooo02Kooooo00?oo`00ooooooooool08?ooool00ol00?ooooooooooo`0Tooooo`030000oooooooo
oooo02cooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool03?ooool00ooo
003oooooooooo`0Wooooo`03ool00?oooooooooo01cooooo00?o003oooooooooool09_ooool00ol0
0?ooooooooooo`0aooooo`0300000?oooooooooo00oooooo00<00000ooooooooool04Oooool00ooo
003oooooooooo`0Uooooo`03ool00?oooooooooo023ooooo00?o003oooooooooool09?ooool00`00
0?ooooooooooo`0/ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo00go
oooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`0Looooo`03o`00oooooooooooo02Ko
oooo00?o003oooooooooool0<Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo017o
oooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`0Rooooo`03o`00oooooooooooo02?o
oooo00<0003oooooooooool0;?ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`0=ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool07Oooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo037ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`0Aooooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool08_ooool00ol00?oooooo
ooooo`0Sooooo`030000oooooooooooo02cooooo00<00000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool03Oooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo01kooooo00?o
003oooooooooool09?ooool00ol00?ooooooooooo`0booooo`0300000?oooooooooo00oooooo00<0
0000ooooooooool04_ooool00ooo003oooooooooo`0Rooooo`03ool00?oooooooooo02?ooooo00?o
003oooooooooool08_ooool00`000?ooooooooooo`0]ooooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo00gooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`0N
ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0<_ooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo01;ooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`0S
ooooo`03o`00oooooooooooo02;ooooo00<0003oooooooooool0;Oooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`0>ooooo`03ool00?oooooooooo02Cooooo00?oo`00oooo
ooooool07oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo03;ooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`0Cooooo`03ool00?oooooooooo027ooooo00?oo`00oooo
ooooool09?ooool00ol00?ooooooooooo`0Qooooo`030000oooooooooooo02gooooo00<00000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool03_ooool00ooo003oooooooooo`0Sooooo`03
ool00?oooooooooo023ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0cooooo`03
00000?oooooooooo00oooooo00<00000ooooooooool04oooool00ooo003oooooooooo`0Pooooo`03
ool00?oooooooooo02Gooooo00?o003oooooooooool08Oooool00`000?ooooooooooo`0]ooooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo00kooooo00?oo`00ooooooooool0
8oooool00ooo003oooooooooo`0Pooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0
<oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Cooooo00?oo`00ooooooooool0
7oooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo023ooooo00<0003oooooooooool0
;_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0?ooooo`03ool00?oo
oooooooo02;ooooo00?oo`00ooooooooool08?ooool00ol00?ooooooooooo`0Rooooo`03o`00oooo
oooooooo03?ooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Dooooo`03ool00?oo
oooooooo01kooooo00?oo`00ooooooooool09_ooool00ol00?ooooooooooo`0Pooooo`030000oooo
oooooooo02kooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool03oooool0
0ooo003oooooooooo`0Qooooo`03ool00?oooooooooo02;ooooo00?o003oooooooooool08?ooool0
0ol00?ooooooooooo`0dooooo`0300000?oooooooooo00oooooo00<00000ooooooooool05?ooool0
0ooo003oooooooooo`0Nooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool07oooool0
0`000?ooooooooooo`0^ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
00oooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0Rooooo`03o`00oooooooooooo
023ooooo00?o003oooooooooool0=?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
01Gooooo00?oo`00ooooooooool07?ooool00ooo003oooooooooo`0Xooooo`03o`00oooooooooooo
01kooooo00<0003oooooooooool0;oooool00`00003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`0@ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool08_ooool00ol00?oo
ooooooooo`0Pooooo`03o`00oooooooooooo03Cooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`0Eooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool0:?ooool00ol00?oo
ooooooooo`0Nooooo`030000oooooooooooo02oooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool04?ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo02?ooooo
00?o003oooooooooool08?ooool00ol00?ooooooooooo`0dooooo`0300000?oooooooooo00oooooo
00<00000ooooooooool05_ooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo02Sooooo
00?o003oooooooooool07_ooool00`000?ooooooooooo`0_ooooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo013ooooo00?oo`00ooooooooool07oooool00ooo003ooooooooo
o`0Tooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool0=Oooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo01Kooooo00?oo`00ooooooooool06_ooool00ooo003ooooooooo
o`0Zooooo`03o`00oooooooooooo01gooooo00<0003oooooooooool0;oooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`0Aooooo`03ool00?oooooooooo01kooooo00?oo`00
ooooooooool09?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo03Gooooo00<00000
ooooooooool03oooool00`00003oooooooooo`0Fooooo`03ool00?oooooooooo01[ooooo00?oo`00
ooooooooool0:_ooool00ol00?ooooooooooo`0Looooo`030000oooooooooooo033ooooo00<00000
ooooooooool02?ooool000Wooooo00<00000ooooooooool04Oooool00ooo003oooooooooo`0Moooo
o`03ool00?oooooooooo02Gooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0eoooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool05oooool00ooo003oooooooooo`0Hoooo
o`03ool00?oooooooooo02_ooooo00?o003oooooooooool07?ooool00`000?ooooooooooo`0`oooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo017ooooo00?oo`00oooooooo
ool07Oooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo01kooooo00?o003ooooooooo
ool0=Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Oooooo00?oo`00oooooooo
ool06?ooool00ooo003oooooooooo`0[ooooo`03o`00oooooooooooo01cooooo00<0003ooooooooo
ool0<?ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Booooo`03ool0
0?oooooooooo01cooooo00?oo`00ooooooooool09_ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo03Kooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Hooooo`03ool0
0?oooooooooo01Oooooo00?oo`00ooooooooool0;?ooool00ol00?ooooooooooo`0Kooooo`030000
oooooooooooo033ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool04_oo
ool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0fooooo`0300000?oooooooooo00oooooo00<00000ooooooooool06?oo
ool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool06_oo
ool00`000?ooooooooooo`0aooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo01;ooooo00?oo`00ooooooooool06oooool00ooo003oooooooooo`0Wooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool0=_ooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo01Wooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0]ooooo`03o`00oooooooo
oooo01[ooooo00<0003oooooooooool0<Oooool00`00003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`0Cooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool0:?ooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo03Kooooo00<00000ooooooooool03oooool00`00
003oooooooooo`0Iooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`0Jooooo`030000oooooooooooo037ooooo00<00000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool04oooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo02Wo
oooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0gooooo`0300000?oooooooooo00oo
oooo00<00000ooooooooool06_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo02oo
oooo00?o003oooooooooool06Oooool00`000?ooooooooooo`0aooooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo01?ooooo00?oo`00ooooooooool06Oooool00ooo003ooooo
ooooo`0Yooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0=oooool00`00003ooooo
ooooo`0?ooooo`0300000?oooooooooo01[ooooo00?oo`00ooooooooool04oooool00ooo003ooooo
ooooo`0_ooooo`03o`00oooooooooooo01Sooooo00<0003oooooooooool0<_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`0Dooooo`03ool00?oooooooooo01Sooooo00?o
o`00ooooooooool0:Oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo03Oooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`0Kooooo`03ool00?oooooooooo017ooooo00?o
o`00ooooooooool0<?ooool00ol00?ooooooooooo`0Hooooo`030000oooooooooooo03;ooooo00<0
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool05?ooool00ooo003oooooooooo`0G
ooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0h
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool06oooool00ooo003oooooooooo`0@
ooooo`03ool00?oooooooooo03;ooooo00?o003oooooooooool05oooool00`000?ooooooooooo`0b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Cooooo00?oo`00oooo
ooooool05oooool00ooo003oooooooooo`0[ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool0>?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01cooooo00?oo`00oooo
ooooool03oooool00ooo003oooooooooo`0booooo`03o`00oooooooooooo01Kooooo00<0003ooooo
ooooool0<oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Eooooo`03
ool00?oooooooooo01Kooooo00?oo`00ooooooooool0:oooool00ol00?ooooooooooo`0Hooooo`03
o`00oooooooooooo03Sooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Mooooo`03
ool00?oooooooooo00gooooo00?oo`00ooooooooool0<oooool00ol00?ooooooooooo`0Fooooo`03
0000oooooooooooo03?ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
5Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo02cooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`0hooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0
7Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo03Cooooo00?o003oooooooooool0
5_ooool00`000?ooooooooooo`0cooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0]ooooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool0>Oooool00`00003oooooooooo`0?ooooo`0300000?oo
oooooooo01kooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0fooooo`03o`00oooo
oooooooo01Gooooo00<0003oooooooooool0<oooool00`00003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`0Fooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0;Oooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo03Wooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`0Oooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0=oooool0
0ol00?ooooooooooo`0Dooooo`030000oooooooooooo03Cooooo00<00000ooooooooool02?ooool0
00Wooooo00<00000ooooooooool05_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo
02kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0iooooo`0300000?oooooooooo
00oooooo00<00000ooooooooool08?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
03Sooooo00?o003oooooooooool05?ooool00`000?ooooooooooo`0dooooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo01Kooooo00?oo`00ooooooooool04oooool00ooo003o
ooooooooo`0^ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0>Oooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo027ooooo0_oo0005ooooo`03ool00?oooooooooo03Wo
oooo00?o003oooooooooool05?ooool00`000?ooooooooooo`0dooooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo01Oooooo00?oo`00ooooooooool04Oooool00ooo003ooooo
ooooo`0`ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0>_ooool00`00003ooooo
ooooo`0?ooooo`0300000?oooooooooo02;ooooo1_oo000mooooo`03o`00oooooooooooo01?ooooo
00<0003oooooooooool0=?ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`0Gooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0<?ooool00ol00?oooooooooo
o`0Dooooo`03o`00oooooooooooo03[ooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`1Uooooo`03o`00oooooooooooo01;ooooo00<0003oooooooooool0=Oooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`0Gooooo`03ool00?oooooooooo017ooooo00?oo`00
ooooooooool0<?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo03[ooooo00<00000
ooooooooool03oooool00`00003oooooooooo`1Uooooo`03o`00oooooooooooo01;ooooo00<0003o
ooooooooool0=Oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Hoooo
o`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0<_ooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo03[ooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Uoooo
o`03o`00oooooooooooo01;ooooo00<0003oooooooooool0=Oooool00`00003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`0Hooooo`03ool00?oooooooooo00oooooo00?oo`00oooooooo
ool0<_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo03_ooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`1Vooooo`03o`00oooooooooooo017ooooo00<0003ooooooooo
ool0=Oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Iooooo`03ool0
0?oooooooooo00kooooo00?oo`00ooooooooool0<_ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo03_ooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Vooooo`03o`00
oooooooooooo013ooooo00<0003oooooooooool0=_ooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`0Jooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0=?oo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo03_ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`1Vooooo`03o`00oooooooooooo013ooooo00<0003oooooooooool0=_oo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Jooooo`03ool00?oooooo
oooo00cooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo03cooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Wooooo`03o`00oooooooo
oooo00oooooo00<0003oooooooooool0=_ooool00`00003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`0Kooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0=Oooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo03cooooo00<00000ooooooooool03oooool00`00
003oooooooooo`1Wooooo`03o`00oooooooooooo00oooooo00<0003oooooooooool0=_ooool00`00
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Kooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool0=oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo03co
oooo00<00000ooooooooool03oooool00`00003oooooooooo`1Wooooo`03o`00oooooooooooo00oo
oooo00<0003oooooooooool0=_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`0Looooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0>?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo03gooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`1Xooooo`03o`00oooooooooooo00gooooo00<0003oooooooooool0=oooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`0Mooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool0>Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo03gooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`1Xooooo`03o`00oooooooooooo00gooooo00<0
003oooooooooool0=oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0M
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0>oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo03gooooo00<00000ooooooooool03oooool00`00003oooooooooo`1X
ooooo`03o`00oooooooooooo00gooooo00<0003oooooooooool0=oooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`0Nooooo`?oo`000_ooool2ool003gooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0nooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool0JOooool00ol00?ooooooooooo`0;ooooo`030000oooooooooooo03Sooooo00<00000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool08?ooool3ool003oooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0nooooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool0JOooool00ol00?ooooooooooo`0;ooooo`030000oooooooooooo03Sooooo00<00000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool0Hoooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo03kooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Yooooo`03o`00
oooooooooooo00_ooooo00<0003oooooooooool0>?ooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`1Sooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0?ooo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo06[ooooo00?o003oooooooooool02Ooo
ool00`000?ooooooooooo`0iooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo06?ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0oooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool0J_ooool00ol00?ooooooooooo`09ooooo`030000oooooooo
oooo03Wooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0Hoooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo043ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`1[ooooo`03o`00oooooooooooo00Oooooo00<0003oooooooooool0>_ooool00`00
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Tooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool0@?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo06_o
oooo00?o003oooooooooool01oooool00`000?ooooooooooo`0jooooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo06Cooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`11ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0K?ooool00ol00?oooooo
ooooo`05ooooo`030000oooooooooooo03_ooooo00<00000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0IOooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo047ooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`1/ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0??ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1V
ooooo`;o003o1Oooool00ol00?ooooooooooo`12ooooo`0300000?oooooooooo00oooooo00<00000
ooooooooool0K?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo03gooooo00<00000
ooooooooool02?ooool000Wooooo00<00000ooooooooool0Ioooool2o`00o`;ooooo0_l00?m5oooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool0KOooool2o`00o`;ooooo0_l00?looooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo06Sooooo1?l00?m6ooooo`03
00000?oooooooooo00oooooo00<00000ooooooooool0K_ooool4o`00od3ooooo00<00000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_oo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?oo
ool000Wooooo]P00000AoooookH000002_ooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {-0.0517441, -0.0309082, \
0.00527191, 0.00527191}, {{9.8125, 190.438}, {240.312, 128.625}} -> \
{-21.1278, -0.00181649, 1.48442, 0.000210365}, {{208.5, 389.125}, {240.312, \
128.625}} -> {-4.15612, -0.610008, 0.0199387, 0.039217}, {{9.8125, 190.438}, \
{117.5, 5.8125}} -> {-21.1278, -0.0201682, 1.48442, 0.000153432}, {{208.5, \
389.125}, {117.5, 5.8125}} -> {-316.064, -0.0214651, 1.48442, 0.000163298}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify training and test image", "Subsection"],

Cell[BoxData[{
    \(\(cr1 = 
        ClassifyImage1D[trn, ComputeDecisionBoundary1D[p1r, p2r, x], 
          Red];\)\), "\[IndentingNewLine]", 
    \(\(cg1 = 
        ClassifyImage1D[trn, ComputeDecisionBoundary1D[p1g, p2g, x], 
          Green];\)\), "\[IndentingNewLine]", 
    \(\(cb1 = 
        ClassifyImage1D[trn, ComputeDecisionBoundary1D[p1b, p2b, x], 
          Blue];\)\)}], "Input"],

Cell[BoxData[{
    \(\(cr2 = 
        ClassifyImage1D[tst, ComputeDecisionBoundary1D[p1r, p2r, x], 
          Red];\)\), "\[IndentingNewLine]", 
    \(\(cg2 = 
        ClassifyImage1D[tst, ComputeDecisionBoundary1D[p1g, p2g, x], 
          Green];\)\), "\[IndentingNewLine]", 
    \(\(cb2 = 
        ClassifyImage1D[tst, ComputeDecisionBoundary1D[p1b, p2b, x], 
          Blue];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show classification results", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{trn, cr1}, {cg1, cb1}}], \ 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
%%ImageSize: 400 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0178571 0.47619 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0178571 0.477324 0.357993 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FFFF8000FF80000000FFFF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0178571 0.97619 0.357993 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FFFF8000FF80000000FF
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.392007 0.477324 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
10110910110811110A11110B10100E13131115161217181216170F16170F181810171810
181A10171B1014170D14170E15170E16180F18190F17190E15180E14180D13160D11140D
13170F131810141810131811151812181A13181913191913191A12191B11191B12191C13
191D14191D13191E121A1F13191E12191D11171A11171B131A1E141A1E13181B11181B10
191B111A1C111D1F131C1F131C1D151C1E171B1D161C20191C20191B1F171A1E16191C15
1A1E15181C14171B13181C12191C11181B111A1C121A1D131B1E151B1F181A1F181B1F17
1D20181B1E151A1D14191C14181A141B1E171C1F161C20141A1E131D20161B1E141B1F15
1C20161C1F161E20161D1F131C1D131D1E151D1E161D1E151D1E161B1D161A1D151A1D16
181B15181B15181B14191B131B1C141A1B13191B12181911181A111A1C13161711151611
15161015160E17171017171215151114140F16171216161215141011100B13130B13140D
13140C13150D15190D12170D10150C11140C0F12090E11080E10090E11090E0F070E0E07
0F110B0E13100E12140D10170E0E180F0C150E0C0E0D0E0B0A0C090C0E0C0C100E080B0D
010205000002000101000001000003010005000006000006000004000003000003000002
000001020001030101030000
3940383D453D404941414B4339403D23282B1B1F201C211C171B15161B12171B0F191F10
1C21121C20121D21121D20111D20121C1F111D20121D21121C21121C22131A1F131B2013
1C21141A20131B22151C22171E231820231A1F231A20231A2024182125172024171D2215
1D23171E2518202816232A19232A1923281922251822261924281A222718212617222718
242A19252A1A272C1C262B1D262A2024271F24271E242A20232A1D242C1C252E1C262D1B
282E1C262C1D262A1E272B1D262B1C252B1B262C1B272C1C272D1D262D1F232B1D232A19
252C1A242B1A262C1B262B1B252B1A292F1C282E1B282D19282F1B292F1D252A19262B1A
262A1B25291B272B1C2A2E1F2C30202B2F202C2F212D2F212C30222A2F22272C1E272C1B
272D1B282F1C292F1E2C301E2A2F1D2C30202C2E20292B1F2A2D202A2E2226292024261D
23261A22251923251926261C25261D22241C22241B2123191E21161F2115222516212416
2224152225152125151F22131D21121D20111D21111C20101C1F111C20131B1F121B1E12
1B1F12191F111920111F29190D100D0C0E0C0C0E0B0B0D0B0A0C0911150E13180F070905
060702060803050703040603060704060705060805050805050805050804050704050805
050804060903060803080803
94AA9699B19D9CB6A09DB8A08FA69040494812141A191D1C1316140F120E0E120911150A
151A0C171C0C171C0D181C0C191E0D1A1F0E1B1F0D1B1F0E1A1D0F1A1D111B1E121D2015
1E22171D22161D23181D22181D22191D23191D23191E23191F24181F25161F25161D2215
1E24161E25151D25131F26142126162226162225152124162224172022151E20131F2215
21251720261822271824291C25292023261F22261E24291F23291B262B1A272D19272C17
282C182B2F1D292B1E282B1D2A2C1E292D1D282C1B282D1B282C1C252A1A252A1A262B1B
282F1C2A311C262E1B242B1A252A18272D18282D17282E17282D17272C17242915242816
25291923271825271927291C292A1F2A2D212C2E212E31232C31222A2F20282D1D29301E
29311D2C331F2E34202E33202D31212E33232F34252D31222E31222E32242E30242B2D22
282A20282C21292E212C2F222C2F24272B2026291C25281B23251925271A242819232717
2426162527172427172327162426162325152427172326172024162125171F23171E2215
2023151F23131C21121C21111B1F10181C0E151A0F151911151813151A13161B1115190D
14190C14180D13160C11140B14170E171910161811131611121510121611121611131613
141912151B12141911131710
97B09E9BB5A49FBAA59DB8A19BB59D627367191D22151919161A17121612131810151A0E
171E0E19200D181F0E181E0E1A200F1C21111F22111E20101F21131F1F151E20181E2019
1F211A1F221A1E231B1A20181B21181C23191C23191E25181D25171D25151D24131F2514
222716222916222915222815232817242817232716232617242718232717222516222617
222618222619232719262B1E262A2023271E21261C232B1C252D1A282E172A2E16292C16
2B2D192F301E302F202C2C1F3030222E2F212D2F202E2F1F292C1E25271B25281C25291C
282F1C2A341E232C18242C18252C17272D17272D16272C15282D17292E1A262A18252817
25281925271B25261D27271F272720282A222B2E242D30242B31222A3120272E1D272F1A
2A311A2B321B2D331C2C321C2A301D2B301E2D32212D32222D30222F31233033242D3122
2C30242B2F242A2F222B30222C30212A2E1F282D1C272B1B27291A262919252A19272C1A
272B1A272A1A25271A24261824261824251925251B22231A21221922241A1F24181E2316
1D22151F25161E25151E25161F25171D2215181E12171D13161A14151A13151A11151A0F
181C0F171A0F17170E17180F191911191A13181A13161815141714131613161915151814
151913171C14161B13151810
8FA6949BB5A0A0BDA59FBBA39EBBA0849D88394540181C1D191E1A13191311150E13180F
141A0E171D0F1A21111C22131C20131F231521241722231622231721221B20221B1E2019
1D1F181B1F171C22191B21181C24171C23161C24151D26151E26142027141F2513202715
23291722261523271525291825291925281924271824281924291A252B1A252A18252919
23271822261822271823281B23281E20261E20261D242C1D27301D2A311A2B311A2D301B
2D2F1C2C2D1D2F2F212F2F212E30212F31242F30232F31222D2F21292B1E2A2C20282C1F
252B1A252E19252D18242B16262D16272D17282E182A30192B2F1B292C1C272A1B262B1C
23291B24271C23261C282A20282C21292D222B2F222C32222A30202931202A321F2C331E
2F351E30361F2F34212C2F202C30222B30232C32242E32252D32242E34242F33242E3323
2E33232E33242C32222D33212C321F2D321E2D321E2D31202B2E1F2A2D1F272C1D272C1E
282C1F282C1F252A1E262A1D272A1C24271A23251A2224192224192326192025161F2616
2026152228152127131F24141F23161D22151A2015181E15161D13161C11161D11181E0F
191E0C191C0C191A0D19190F1B1D121B1E13191C141A1D16171B15161A15181D16171B14
161B12171E12161B0F15180D
5D6959798B738DA58894AE929AB79897B5955F745E1A201C1014110F140E0C100A0E110B
11150D151B0F181E11191F131A1F141E231720251922271A222618212519202317202317
2023172023151D21141E22141F24161E23141E24131F261421271623281824291A202618
22291A222919212718242A1B252A1B262B1A272C1B272B1A252A19252918252A18252919
2326172025161F25171F251A20261D20271F232A1F262C20262E1E272F1B2A311C2B311C
2D321E2C301F2D31202C2F1E2D31202E33232F33242F31213031202E2F1E2D2E1E2A2C1B
292D1B272D1A242B17242B16262C17282E19292F1B28301B282F1C272D1C272D1E262B1D
252B1B242A19242816272A1A2A2C1D2A2C1E2B2D1F2C2F1F2A2F1F2B31212C33212D3422
3037243137253034262F32282F33292C31282B30262B31242C32232C32242C32242C3322
2D33212E33212B311E2D331F2F351E30341F3032202F31212D30222B2F23292E21262B1F
272D20242B1D232C1D242C1A252B18252A19242718232517222416222517212315212513
2226132126112024101C20111E21161B1F15191D16181F16171E12161C10141A0E151B0C
141A09151A09151A0A15190B181D10191E12191F121A20141B2114191F14171E13171D10
161C0E161C0C171B0D15180C
22281C2F3628424C3A5463496B815F839F75728B64242A1E10130E12180F0F120D0D100C
12160F151B10161D10191F121B22141D24161F251721261721251621241721241723251A
23271B24281B23261822241622251620241421261422271522261722251822251A21271C
21291B21281A22291A23291B242A1A252B1B272D1A292F1A282D1A252918252819252819
24281A242A1A242A1C22291C232B1E232A1D232A1B242C1B252D1C252F1A262E18293119
2A30192A2F1A2C301D2B311E2C321F2C32212F34263134263132223132212E2E1D2E2F1C
2B2F1B292E1B252C18242C18232C18222918232B1A242C18262E1A272E1C272C1C272C1C
272C1B262B19252817282A182C2E1C2B2D1C2B2C1D2C2D1E2A2E1F2A2F1F2B31202C3220
2E342130352332362731342930352A2E34282D32252B31212C31212C31212C32232E3624
2F36232F35222C321F2D332031352132341F3233202F301F2B2E1D2B2F1E282C1B272C1B
272D1B252B1A242B1A232B18232B16262C16272C19252918232617232717232616222615
2124151F23121D21111B21111D22141B2015191E14171E13171C10171C0F13170B15190C
15190B13170913160815180A171C0E181C0F171D0F191F111A2013191F13171D11161C0F
14190B141707141608121408
14190F191E131B20151B2115282F1E3C472E414F34262C1C2126191C2116171C1213190E
151B0F161D10171E11191F131C23151E241621261822261922271922251822241A24261B
25271C25281B24281A24261824251620241221251221251422251624271923271B24281F
242A1F22281D232A1E252C20252C1F242A1C242B1A272D1A292E1A272B19272A19292D1D
292D20292C20292D1F282E1F292E1E282D1B272D18262D16262E18252D18262D172B311A
2C311B2C2E1B2E301D2E311D2D311E2D33223035253033243132242E30212D2F1E2D301E
2A2E1C292E1A28301A272F1C262E1B2129181E2616212818232A1A262B1B272C1C272B1D
272B1D262A1B242719272B192A2E1B2B2F1B2A2E1C2B2F1D2B2E1E2B301D2C311D2C311E
2C321F2F34223238263237283036293036282D34242B311F2C321F2E34212F37242E3623
2D35222F36232F35232E312230322032342132332130311E2F301C2D2F1A2A2D192A2E1B
2A2F1B2A2F1C292E1C282D1C282D1A282E19292E1B292E1D292F1D242C1B222818232817
2125151F21131F22131F23141E22131E21131D20141A1F121A1F10181E0D181C0B181A0C
18190D17180C16170B16180A191B0D1A1D0E171C0E181D10191F12181D12161A1014170E
14160C1216091113070E1004
0E120A10140D12150E14160F171A131B21171E25191D23171B20141A1F12181E0F171F0E
161C0C161D0D181F11161C10181F111B22131F2515222717222617212517212517242719
25281A25281A25291B242719252919262B1A24291822271722271823281A23281B24281E
262A1F262A20262B1F272B1F25291E23281C262B1C282D1C2A2F1D292E1C282D1C282B1E
292C21292D21282C20292E1F2A2E1F2A2E1E282D1A252A16252B18292E1B292F1B2C321C
2E331E2F331F2F321F2E2F1E2E2F1F3133233236263134253335263133242E31202E3221
2D33212C311F2B321D2A321D29311C272F1B242D1A252D1A272D1B262B1B262A1A282D1C
292E1E272C1E242A1B252D1B28301B282F1A282F1C2A311F2C311F2C311F2C301E2D311F
2E331F2E341F2E33203236253338293238292F35252C32212C331F2C341E2C34202F3623
3038263137263034243032223132213132212F2F202E2F1E32331F30301E2C2F1D2B2E1E
2A2E1D2C301E2A2E1C292D1C2A2E1D292E1B282D1B2A2F1E2A2F20262E1F242B1B222919
2328172225162124152123162124162022151E20141D21131D20131D1F101D200F1B1E0D
181A0C18190C18190D18190C191B0B191C0B191C0B1A1D0F171A0E15190D16190E171A0F
14170C1115080F12050F1105
0B0F070E11090E100712130A15170F171C151A1F16191F15191F151B20151A20131A2113
1A2012181F10161C0F161C0F1A210F1C23101D23111F25131F2413212414232616222416
23251724261725281A24281C252B1D242B1E242B1D232B1C22291C21271C23291D25291E
262A1D272B1E25281B262A1B262A1B26291A2A2C1C282C1D2A2F1F2A2F1D2B311F2B301F
2A2F1F2A2F1F29301F282F1E282D1E292E1E292E1E272E1D282F1D2A301C292F1D2A301E
2C311F2E321F2B2E1D2B2E1E2E31213033243237273237273337283136283035272F3325
2D33232C32212C331E2A341C2B331B29321A29321B2B341D2B321D2B301C292D1C2A2E1C
2A2E1D292E1E282F1D28321C27321926301726301829321C2B321F2D33212F3321303522
2F34212D321F2D321E3034203236233539263339263036232E35212D341F2F361E2F361E
3138223137233036233035223236233032212E2E202D2D1F2D2E1E2D2E1E2C2D1E2A2E1E
2B2F1F2B2F1F2B30202C31212B2F21292D1F2A2E202B2F22292E22282F2028301F22291A
1F27161F26141F25132025142227162125162123162022151D1F131D1F131F21121E2111
1D1D0E1D1E101C1D121B1D12191B0E1A1C0D1B1D0D1A1C0E181B0E161B0E161B0E171B0E
13170B101409101409111409
060902070B020B0E04111409181B11181C141619131619121A1E171C1F181B1F141C2014
1B2013191F12181E10181F1019210F1C24111D25111F28131F27141F2615242919242819
25281926281A272B1C272B1E272C20242A20242B21262D22262D22252C21252C20252C1E
272C1C272C1B252919262918272B1A272A192A2C1B2B2E1D2B301F2B2F1D2C311E2E3420
2D32202A301F272E1F282F202A2F202A301F2A2F21292F2029301E29301E272F1D29301E
2A301D292F1E2C311F2B301F2B30202D322230362531372632382831382830362931372B
2F35272B32242A322029321E29321B2933192B34192D351C2E351E2E34202F34212D301F
2C2E1F2B2F1F2B301E2A311D29311A29331A28311A2A311C2C321F2F3322303523313624
31372430362130351E30351E2F341E3137213036203035213035233035213036202E341F
2F361F2E34202F35223137233036223034222E31212E2F202B2C1D2B2C1D2A2C1D292C1D
292D1D292D1E2B2F202C31202B2F1E2A2D1E292C20292D212A2F22292E1F282E1D212818
2029151F28131E26111E26112127142329172327161F23141C20131B20131E22141D2013
1C1E121C1E131B1E141A1C131B1D121D1F111C1F0F191A0D191B0D191B0D191B0C191C0C
181B0C15190B13180B11160B
070A02090C030D110512170B181D10191D1115170E12120C13161011140E12150D14190F
171D111920121B22121B22101B230F1C240F1D260F1D26111E26141E2416212617242918
242718252A1A292F1D292F1E282E20262C20242B21252C22262D23272E23262D21252C1E
262D1E272D1D282D1C292E1B292E1A272B19272B192A2F1C2C311D2D311D2C311C2D321D
2C301D2C2F1E2A2E1F292E202B30222B30232A2E222A2F222B30212C33222B34212A3221
27301D262E1C29311D2A311D2B311D2C331E2F36213138243038262E3724313927333A29
3139292E38262C37242C36222C361E2A341A2C361A2C351B2D341D2E341E2E341F2E3220
2D30202D31212D32222C32212C33202B331E29311C2A311C2D331E2F34202F35222F3522
30362031371E30341B32351D31351F3136203137213136213137243036222F33212E3320
2F34202F34213136243238253137243036232E34222C3020292C1E292B1F2A2B202B2D20
2A2E1F2A2F1F2A2F1F2B301F2A2E1F2A2E1F2B2F21282C1F272C1D272E1D272D1C242C1A
242D18232C161F28131E26122228152429172327162227172127171D23141C22131B1F12
191D11181B10171B11171A11181B121D21141D1F14191A1017170C1A1A0C1B1C0B1A1B0A
191C0A16190A131708111407
060903090B040A0D040B0F050D12061115071417081215090D1109080B05090C060F1409
12180C13180C161C0E1A21111C23121C24121D25131E26161F261820281922281A23291A
222918252D1928311B28301B28301C282F1E242C1E252D1F252D20262C20282E21282F21
2930212A301F2B321F2B311F2A2F1D2A2F1E2A2F1E2A2F1D2C311D2D321D2F341D2F341D
2E321C2F311C2C301D282B1C282C1D2B2F202B30212B30242B30242B31242D33242C3323
2A322028301D28311C29311B2B331B2C341C2F361F3037222F37222D3722303923323B24
313B26303B26303A25313C26303A222E381F313A203139203137202F351E30361E313520
3134223134243033242F33232F35232E35202C331D2C331B2C321B2D311B30351F303620
30361D31351C31351A33361D3539223338223037212F36212F37213037213036212E3520
3037213137223238253137242F35222F36232F34222D32212A2F21292B212A2C222A2C22
2A2E222B2F222A2F21292E1F2A2F202B2F222B3023292E20262C1C272E1C252B18252B15
252C15262D17252C162126122126142225152125162126182027191F27191F26181D2315
1B20131A1D111C1F121B1F121C20131F22161E20151B1D111A1B0F1A1B0D1A1C0C191A09
191B0A191B0A17190B131508
040503050703040701060900080B010B10021217061218081014050A0D020A0D040D1006
0C10060B0D050D110713180C191E111C21131F261521291921281A222A1B212A1A222A19
202817222B17232C17242D17262F1927311C262F1D252C1C282F1F2A2F202B30212D3222
2D31212E32212E31212D31202D32202E33222E33212C31202C33202E35212F3521303521
2F34202E34202D31202C2E1D2B2C1D2B2E1F2A2D1F2B2F212D31222D32242D32252D3424
2C35232C35222B34212A331F28311B2A331C2A341E2C351F2C36202F3922313B24303B22
323B23343C25353D25333B24333A23323921323922323922323722313722323922313621
3135203335213233222F32222E33222F35222C331E2B311D2C311B2C311B30361D2F361E
30361F30361E32371E343920373D24373B263237242F35202E351F2F351F313721313821
3038213239223037212E351F2C331D2B321E2C321F2E35212D33212B2E202A2D212C2F23
2C2F232D30222D30212A2E202A2D202B2E202B30212B301F2A2F1E292F1C272C16272C14
252B13272B16282D1A2427172125172226182125172026181F26182028191F26181D2315
1D21131F22152124151E20121C20101F23121E21121C20111C20121A1C0F181A0D1A1C0F
1A1C101A1C0F17180E13150B
030606040705040701040700030600070A000B0E010B0E010C0F010E1102101104101106
1012080E0E060C0D060A0C050E100814190C191D0C1E2411212715222A17242C18232B17
212A17212A18222B17252E18262F1A262F1C272F1C27301C29311C2B301C2D311F2D311F
2D31202E31213033233135243135243135243035232D33222C33222D35222C35212D3521
2E35223036223135232F311F2C2D1A2B2D1B2C2D1D2B2E1F2C311F2E33222F34242E3625
2C35242A34222B34212C35222B34202A341F2C361F2B351E2B351E2D36202F3821313A21
333B21353D23353C24333A22313821333923323822343924363B27353B28353B27323724
3236213336213335223134212F33222E33212B311F2B311D2B331C2B321B2D351D2E361E
313820303721323920333A21333B23343B24353C263239232E341F2F341F313721333A24
333B243239223037212F37202E361D2C331C2E351E2F361F2D331D2B311E2D31212D3122
2E32242E32222F31222C30222C2E232D30232B30212B2F1F292E1C272C18242B14232B12
232912242914282C1B282C1C25291C24281C2326192025191D23181E24181D23181C2216
1B21131C22141D23141C21121A1F0E1B200E1C200F1C21101C20101A1C0F16190D181C10
171B11171B1215180F11150C
0308050309030509010509000307000205000306000406000606000B0A01131207181A0C
17180C1212080D0F06090C03070A02090D030D1203141A071C220E212914252E19252F1A
26301D272F2027311F27311E26301D242D18232D162630182831182A31192D341D2E321E
2E31202F32233033263035293035283137293036282E35262D35242E36232E3823323925
3339233238233136233033202E2F1D2F301D30311F3132222F3323303524303524303725
2F37252C36232C36232D37232E38222F381F30391F2F371E2D341C2D341E2E341F2E3520
313722333B23323922323922313821333921323820343922373C26363B27373C27353B26
3439223639233537243235223135232E34232B32202A311D2A311B2B331D2A341D2E391F
30391F2F371E30381E31381F303820343A23363C26333A253036232F34222D3220303624
343C28333B27333B27333C25313A2330382131391F32391F2E351C2D331D2E341F2F3421
2F34242F34262F34262E32252D31262B2F252B2E242A2E21292E1D282F19262E17242B14
252A14262B17292D1B282C1C292D1E272B1D25291C24271C20231A1D20171D20171E2216
1E24161E24161D24171D24171D23171B21131A20101B20111D21121C20101B1F0F191D0E
171C10171B1015190D101409
040904040903060A01070B01070A000508000205000306000708000806000F0E02151406
1516081213060D0E020B0B000B0B010809000607000C0E021416091D211324281B292F21
2A33272A34292B362828332327331F25301A242F162530142833152B34172C321930331D
31342133342532342830342C2E332C2E352C2D352B2C35292E3727313A26313A25323823
353A2134382035382135372035362036382435372634352831332833372B313628303725
2F39242C36232B34212C35202F3821333B2132391F32381F343921343822333622323623
313624333826333824343B26353D27353C25353D23343C22353E25373E263A4128393F26
373A243638243637253335243134252E34252A332329322029331F29331F29341D2C381E
2F3C1D2F3B1A2F391930381A31391D343B21353C24353C2732392634392A32372A2F3428
2F3628313829343C28343D27323D26313C2330392030371E30371E30371F303621313522
3034243035272F34293035292E33292C30262C3126292E21282D1E28301D28301B283019
292E18292E192B2F1B2C2E1B2C2C1B2B2B1C2B2D1E292B1E2424192121171F20161F2218
1F23191E241A1F251B21271D21271E1F251A1D25171D23151E23131C210F1C210E1B200E
1A200E191E0C181B09131606
070B03080C040B0D040C0F030C0D030A0B01080A00090B00090A000909000A0B000A0A00
0C0C010C0C000E0D010E0D010C0B010C09020905020805020A070515151221221E272A26
29312B29332C29362B29372728372127341C2734182935162A35152D35162D32182F311C
32352333362733352930332A2F342D2D352E2D372D2D372A303A29323C27353C26363C24
373C23383A213B3C243A3B263B3B283A3A2A38392E36372E34362F33382E333A2D323B29
313C272F3B242E3821303920333C21373D22383C223B3E263C3E29393A2938392A37392C
35382C363B2D363D2C353D29373F29374128363F25343D22353D22383E23393E243B3F27
3A3D2A393B2B37392B3335293135282F36282B34252B35242B35232A352029341C2A3519
2C38172E3A17303A15323B17363D1F363C22363C25373F2A373F2D363E2E343D2E323B2D
2F37282D36242F3721313A20333D21333C1F313A1E31381E343920353823343724343626
33342832362B30352C2F352D2E342B2B31272A312529312229312129322028311D29321C
2B321B2B2F1B2D2E1B2E2F1D2E2D1D2F2D202E2C212C2B2128281F25261F21241C1F221C
1F251D1F251C1F261C20281D21291E1F271A1E26161E25141E26121C240E1C240C1D250E
1E250D1E240C1D210C191A09
0A0C050C0D050F10060E10060A0B03070801050700090A010B0C010A0C01090B00070800
0809000C0C000E0E040D0C040D0B030B09030905030904070803080C090E1515181D2121
242B2727322A28342827362428372027351C29351A2B36192E38182F361A2E351D303520
32362433372932362A30362B32372D313A2F303A2D2F3A2A313C27303B25333C243A4027
3A40273B3E263C3D263D3D2A3D3D2D38392D383A2F373B30363B32363C31343C2E333C2B
343D2A343E28333C25353C23373D233A3E243C3D273E3D2A3D3C2D3A392F393931383A32
353A31353B30363E2F353F2C37422A3943283A4227373E24373C24383C253A3C273B3D2B
3C3E2F3C3F32383D31333A2E323A2B313B292F39272E38242C36202C361D2B3519293315
2A32132B33142E3714313A1733391C33371F343B25353C28343E2B333E2D333E2D323E2B
313B262F39202E371A2E3717323B1931391933391C36391F373923373725353427323127
2F30272D31292E352D2A322C2A32292932262A33232A32212A31202D35222D34212C321E
2E321D2E2F1D30301F313021312F23312E252D2A232B2A24282B262529252127211D231D
1D241C1C241A1F271C1F281A20291A2029181F28141E27121F28111E270E1C230A1D2409
1E220A1F230C1E210D1C1C0C
0E120A0D100A0C0F080A0D05070904050703040601070A020B0E030A0D02080B00080A00
080A000A0C010D0E030D0C030A08020604010402000805040D0A0A0C0A0D0D0C11131519
1B1F21222927252F282532262633232935212B37202C371F2F371D2F361C2F361E2F3521
32352437392B35372D33372E353930343930323A2D303B2B303B27313D25333E25363F25
373F25383F25393E25383B253B3D293A3C2C3A3C2E393C2E373C30363C30343A2E353C2E
353D2E353E2D353E2A353C26353B23383B233A3B253B3B273B392A3B392D393930373933
333732353B32353D3135402E37432B3943293A4327384025383E26383D283A3E2A3D402D
3E3F2F3E40313B4132373E31353E2F343D2C333D29313B252D37202D361C2C3319293016
282F162A31162A30152C33152D34192F351D313721323825323927323929343C2A333B27
313A242F38202E371E30371B30371A30361932381C35391E363821363824363728323227
2D2F252B3026282E26282F272930262B33262C34252D34222C311F2D32202E33212E3220
2E321E2F2F1C2F2F1E2F2F1F2F2C1F302E222E2D242C2C252B2D27272B2523282120251D
1F261C1D251A1E25191F27181E26171E26151F27162026152026131E24101B200C1C220B
1E220D1E210E1E210E1C1E0D
0D120D0C100C0A0C09080A060A0C08070A07050703050801070901070901060801070901
080A01090B0108090008080007060005040004020008060315150E1818151A1A1B1D1D21
1F202622262A242C2C262F2D26322B2732292933252A34222C35202D351F2D341E2F3620
323723353827383A2B37382D35372D34382E33382D343B2E313B2B303B28323D28343F26
363F25363F24373F24363D23393E253A3E283A3E2B3B3F2E383E2F373D2F373D30363C31
353D30343E3135402F333E29333C24353C22373C23383B22393B243A3B273A3B2A393B2E
373A2F35392F353B2E37402F37422E39452D3D482C3D47293C46293C432A3D412B3D412B
3D402C3E402E3E42303B40313B4232384130353F2E333C2B2F37252C331F2B311C282E19
292F1A2A311A2A301A2B321A2B311A2C311C2E331F313621343925353926353A27323825
313724313824323A24323D23323B2030391C31391C32381D34391E353920383A24363826
3334253033272D30272B2E252B2F252C31252E34262F35252C33232D33242C33232D3321
2D321F2D311E2E311D30311E302E1E2E2B1E302D202E2D212C2B1F2B2C1F2B2C1F272A1F
23261C20241B1F23191F24191D24191C24181F26191F25182025172024161E22121D2211
1F23111E22101D20101B1D10
0A0E080A0D09080B07080A05090B06070904050803070A05070904070803090A04070902
060900070900050800040600030500030400020200030300080904171A132E3429353B31
3135312C302E2A302F2B32312F38332C3630283129252E23252E1F252D1C262C1B282E1A
2A301B2C321D2F342131352733362A35382B33382C353B2E323A2B303929303A27343D27
333A25343C25343C24333B22343C23353C25363D28383F29363E29353C29363D2B363C2C
373D2E373F30363F30353E2D363E2B363E28363E27343B23353B22363B22373C23383D26
393D28393D29363C29353D2938422C3B452B3C452A3A432A3B432B3A422C39402B373D29
383E293A3F2A3B402B3B412D3B42303A412F3A4230363E2B3037242C33202B311E29301E
292F1C2A311D2A301B2B311C292F1B272D192A2F1A2C311C2E311E2F331E2E341F303620
333922343B25343C26363F28364028333E23323C2130371D2E341C30361C353A20363A22
3537223335243033252D2F232D2F232B2F222B30242D32252B3224293124283023293120
2A311F2B301E2D321D2F321D2F2E1B2D2B1B2B291A2C2A1A2E2D1A2B28162B291729291A
26281B24261C22241C21231C20241D1E221C1E231C1D231B1D23181B21161C21161D2215
1E23152023151F21151B1D13
060A01070A02080B030A0B040908020808020B0D050E110A10120B0F0F0A0F110A0D1007
0B0E03090B01060900040600040600030500020300020400010300070A06273021323C2B
333A2D373F33343B3131372E353D31353F33242A241D231C1A20161A1F131B21101E2311
2126122226132529142B301D2E3423323828353B2A39412D39412D353F2A363F28384028
373F27393F28393E29393F29383E29383E2A373E29383F2938402A383F2A383F2A373F29
383F2A3A402D393F2F383E2F393F303A402E3A412C363C26363C24363D23384124384123
384024383F25384027373F273841263942263B42283B422B3D432E3C42313A4030373C2C
363C2A363C2A373F2A39412B393F2A3A412B3B432D383F2A343A263037212C321F2A301F
2A301D2B321D2C321E2C321D2A301C282D1B2A2F1C2A2F1C2B301C2B311C2B321C2E351D
333A20343B22353B24363E27373E29363F29353F28333B2430371F30371F31392030371F
2F35203238223136232E33212E32212C311F2A2F1D2B2F1E2C32212E35252D33252C3224
2D32242B2F212C32202E34202E321F2C2F1D2B2B1B2929192A2C19282915262713242614
25271724261822241921231A21241D21251E22271E1F251C1D231A1B21181D22191B2117
1C21171E21181F21191D1E17
050A02060A01080B010A0B020A0A01090A020D100811150C151910151810151911161A10
13180B0C1006080B030508010507000507010405000204000305010306010B100614190C
1F24153B452F373F2B303625373F2D3741301D231A171C1510140F0E120A0F1308141709
191C0B1C1D0E202111292D1B2F3522343A28373F2C39422D38412C38412A3A432A3B4429
3C44283F442A41452C40452D3E432D3B412B3A402C3B412C3C422D3E432F3E442F3B432C
39412B39412D3B412F3D422F3C41303D422F3C422C3B4029393F283A41273C45293C4529
3A44283942283A43293B43283B44283B45283F472B41482E4248324147343F45343C4332
3A3F2F363C2A373E2A383F2A373F273A412939412B3A412E3A412E363D2A2F37252E3423
2C33222B331F2C331E3036203036202D331F2C311E2C311C2C321B2C321C2B311B2B321C
2C331E2D341E2F3720313923323A25343D27354028374028333C24323A22313823313723
3037233038233138233139242E36232D35212E35202D331E2D331F2F36253138262D3423
2C32212A30212C31212C32202C311E2C331E2D331F2B2F1E2A2F1C282D18272C17272B17
272B19262B1B25291A23271A22271D23281D22291D1F261A1E25191E25171D24161D2416
1F26182025192024191E2017
050805070A06080C040709020608010608010709040A0D080F130C12170F151A13171D14
151B110F140A0A0E04060900040801040601030501010501010401040902080D030A0E02
0A0E02161B0C1E2213202415333A273D48332C362721281D15181311130F100F0B10100A
12130C15160E1E2015272B1C303623343A28383F2C3A432F39422D38402B39412B3A422B
3C442A3F452C41472F3F46303C422C3C412D3C422F3D43303F45314047323E45303E4631
3D45313C45323D46313F45303F432F4044303D412E3C412E3B412E3C432F3B442D3C472E
3D472F3D462E3D462B3C46293E472A3E472A3F482D414830424734424836424937424938
3F45343C432F3A402D373E2A353D29373F2A39402B3B432F3E46323B4331363D2D31392A
2F372A2F37273039252F38253038222E371F2E351D2D331B2E351B2C321A2B31192C311B
2C311C2B301D2B301D2C34202F3823313C26313E27333F28333E28333D26333E25313B25
2F38222E36202F37213139223139232F36222E35222D33202C31202E33212F35222C3321
2C31212E33242C31222B2F1F2A2F1E29301E2B311F2B331E2B321C2A2F19292E18282D17
272C17262B18262A1B24281C23281D22281D21291D20291B20281A1F26171E26151E2516
1F2617202717212818202417
0B0E0E090C0B0A0D09070A040406010304000204000608030A0C070D110B10140E12170F
1317100E130A0A0E04070B00040700040501030401020401030503070905080B04060901
050701060701080B030B0E05151A0F232C1C212A1B1E25181D21141D20141A1C12171912
1718131617101B1D1522271D2B3025303629353D2D39413038402E373F2B373F2A39402B
39412B3A412D3C442E3E47303E47303D442E3E45304048333F4731404933404933414933
424B344048333F48323E462F3F452E4147303E432F3D43303E44323C43323D44303E4730
404A323F49313D482D3E492C3E4A2B3E482C3D462E3F472F414934414836454939444938
444A374148344048363D4535384030373E2D373F2C39402C3C432E3E452F3B422D393F2D
383F2E373E2D363D2B323A28303825303A242F38212F371E2F361D2D331C2D341C2E341D
2F331E2E321F2C311E2C321D2C34202F39242F3B252F3B26323F28313E28313D25323B24
2E39222E37202C351F2E36212E38233038243037242D33202C301E2E321F2F311F2F3120
2F32212D30202E32232D31232B30222A30242930222931212C32202C321E2B311C292F19
292F18282D17272C1B25291B252A1D24291C22271B22281B23291D23271A2025171E2416
1D24151D24141E25161D2316
13171C0F14180C1113080B0C0608070407040305020608030E12081014080D12060D1105
0F12090D10080B0E060A0E04080B02070902060702050501060604080905070802030400
030300050502060702080A04090B040D11080F140B10140B12150B12160A14180B1D2214
23281A22281921271A232A1E272F242C3428303A2A343D2C353E2B353F2A37402A363F29
363D2A373F2B3A432E3C462F3C48303D4830404A32414A32404930414A32434B34454C35
444C35414833404833414931414A32424A324147304046303E45313D45313E46303F4931
404A31424D34414C333E49303F4B313F4B31414A32414A333F4A33414B33424933444A34
4349324348314147324146343F44333D43313A422D39402A3D42293D42293E432A3F442E
4247323F44313B3F2F363C2C323A29343D29343D27333A233038202F361F30371F30361F
3035202E33202E34202C321F2D33222C33232C35232D36232C37232D38232E3921313C23
333E23333C23323A223038222F37223038243238252F34222B301E2D311F2D311F2E3120
2D30202B2E1E2B2D1F2D30202C30212C31242B2E232C30242A3122282F1E29301D282E1B
282D1A292E1C292E1D272B1C25291B24271B23261B21251A2125192125191E23171D2216
1E24161C23151C22151A2114
192026192026181D251418201013190C1013090C0E0C0F0E1014100D0F090A0C040C0F05
0E11070F12081012090E0F060C0D040B0A030A09030A09050A08060A0909050505030302
0201010202010708050B0E080E11090C0F07090C050A0D060B0F06080B03090D040F1409
1A2112232C1A2A34202E3724303B28323D2C313B2B303927313A27323C28313A26323925
333B27343D2936402B37422B37442B39462D3D49303F4830424B33444D36444C37454C39
444B37454C37444E37454E36454F36464D35444C35444B364149343F48323D4730404B30
414B31424D34414C343D4A323D4B323D4A303E492F3F4B303E4C2F3E4A2D3F492D414830
40462E4348304348324346324246324247333F462F3E462D3E45293B40243D422641462B
43482F4347314044313E44313C42303B422E384029353D25343B24333923303521313622
2F33202F34202E341F2C321E2B30202C32222F35252E36242D37242E38252E39232F3B21
323E22353F22363E23343B223037212E34212F35243036252E33212C311F2C311D2C311D
2C311E2D311F2C2D1E2C2E1F2D30212D2F232C2F232D33232B3222282F2029301E2A2F1C
292D1C2A2D1D282B1C26291C24281A24271923271C1F241A1E24191E241A1E241B1C2219
1C2318191F131A20131A2013
232A2F232A2E21282B1F25281D2326181E2015191B1418181113130B0C0C0A0A090C0F09
0E13090F13090F12090D0F06090C040A0C040B0B040C0D060F0E0B0F0E0F0C0D0D070809
0404050304040B0E0B10141010140E0C100A0B0E07090C060B0E07070A04060902080B03
0A0D0413180C2229182E3622343D2739422D38402E363E2D353D2B333B2A333A2A2F3627
2D34272B32272B35272E3928313D2A36422C3A462F3D4730414A33434A36434A38434B3A
444C3A454F3A455038465138455037454E36444E36454F37444D35434B33414931404A30
414A30434C34424B35404A35414B333E4A2F3D4B2D3F4D2E404D2F404D2F3F4A2E414A30
4147304347334347344144334045334046333E452F40482E3F482C3E452841462942472A
42462B41452D4145303F43324145334147323D452D3A422A384027373D263439242F3521
2C311F2D32202F34202D311D2C311E2C311F2E35232F37252E37262E39272E39272E3924
2E3A22313C22343E23353D233239232F35222D33212F35242F34232E34222E34212D3320
2C311F2B301F2A2D202A2C1F2A2D202C2E222C31212B31202B3120292E1D292F1C2B311B
2B301B292C1A272A1B262A1D23261A21241820251A1F251A1F261C1F261C1E251A1C2317
1B22141A21121B20111A1E0E
23292E262C30242B2C222928232927242A27212726202626191D1F1316180F11120E110F
10140E11160B1014080D11050A0E02090C030C0E050E11060E11090E100C0D0F0D0D0F0E
0909090709070E120D14171211160F0C100B080B04050701060801070902070902070A02
0608010B0F0613170C1C1F13212417272A1E343B2B3C44333D47343B4433374031323B2E
2B3329252C2321281E1D231B232B1F2D3927343F2B3A452E404A32434D35434C36414936
414A37404936414A36434C37454F38454F3947523C48533A465036444C33444C33444C32
434A30454D34444D35444D37444E37424C35414C32414C30424C2F424D2F41492F434830
434733434736444838434738434838424836414934424C32434D32434C30444C2E444B2C
45492D41452C3D422D3D42323D44343D45313C452E3C452D3C442B384028363D26323823
3035232E32212D31202E32202F33212F33222F35243139272E38262C37252F3A272F3A27
2F39242D3822303B22343D24333B243338243338262F35252E3424303625313726303624
2D33212B30202A2F22282D21282D212A30232C32222C32202B301F292E1C2A311B2B331B
2B321A292D18292A1A27291D24261B24261C23261C1F231A20261C21261C1E25191D2417
1E23141D22111D21101B1E0D
282D30292E32262B2E242929232827262B29262B2A242A2C242A2C2026281C2122171C1B
161B1512170D0D11060B0E020B0F030B0E040C10050F12070F11080C0D08090B070A0B0A
0B0C0A0D0F0A11140D14180F12170C10140A0B1004070A00060900070901080903080B04
080B050809060B0D0A10131014161315181521251E343D2F3C4634404B37414C39384231
2C3426262D201E241A171B151519131D231A262D21303A2A38442F3F4A33404B333F4832
3F48333F4733404833414835434A38454C3A454E3A444F38444F36424E34434E34434E32
444D30444D30464E33464D34444C34414A34414B34424C33414B31404A31414B32444B34
454B36444937444836454938464B3A464B3A454C38434B36424B35434C34444E32434C2F
42492E41452C3C412A3B3F2C393F2E3A41303A41303C44313B432F38402D39412E38402C
353B293136242E33212F35212F36202F35212E34223037242F37252E3824303B252F3C23
303C232D381F2D371F2F3921323B23333A253238253035242D33212D33212F3622313724
3137243035232D34212D32212A30202A30212B31212C33202A2F1C292E1B2A301D2B311E
2A2E1C2A2D1C2B2E1E292C1F26281E24271E21241B20231A2024191F22181F22171C2113
1E22141F23131F22131D2011
272C2A2A2E2C2A2D2D292B2B282A28272A27282C29282C2E262A30272B31272C2F262B2B
212723181C1710140E0E100A0F100A0F0F0B0D0C0A0E0D0C0E0D0C070607030304040505
040504090C0612170C181D0F171D0E11160A0C1003090C01090C02080A020A0C050D0F08
0B0D080A0B070909080C0B0B1110111413121616131C1D18272A2133382B3D4434363D2F
272D2120261916190F171A11171A13181E151F251B2730232E392635412B38452C3A462D
3E482F3F4932404933404835404736414937414B37404D36414F36435036444F35444F31
445030444F2F454F30444D31444D32414A32404A323F4A323F4B323F4B31404A32424B34
444C36454B36454A37454A39464A3A474B3B474C3B424935424A34424B32424C30414B2E
41492D42492E3F442D3C402C393D2D383D2F3A40313B42313A423239423039412E37402B
374129343C25323921333A212F361F2D341F2D34212D36242F37242E38242F3B232E3A1F
2F3B1F2F3B1F2E391F2F3A20313B21333C243138233137242E34222E35212E351F313721
353A24353B243238242F35212B311F282F1D282E1C292F1C2A301A2A2F1B292E1C292C1E
2B2E1F2A2D1F2A2E20272A1F25271D23251C22251C21231A2022171F22161F22151E2113
1D21121F23131F23151C2114
202723252C242A2F262D30282E2F292C2D292D2F2C2C2E2E2A2B302C2E352F3238313639
2B31301C2120181A19151415131013110F130D0B110B091007060E05040B030307040505
0305030507011218081A200F171C0C1215080C0F05090B020A0C040A0D070F110B12140C
10110C0E0F0B0C0C0A0D0C0C1311111715141614131413121818141B1B1722241D24271F
1D221916191210110A12140C1B1F1421281B242B1E232B1D242D1D26311E2A3621303B26
37432B3D4830404C34414B36414B36424D37424E36435136435235475437475237465135
465135465133465034444E33424D31434D33434F35434F35424E34414D34414B33414B33
434D36444D37474D38484E38494E394A4E3A4A503B4B523C494F3A474E37444C33434C32
434B33444C34424A334248324146333F44313E45323F49333F49333D46313C453039442D
39472D38452B374227364024323C203039203039212F3722313A25323B26323C26323C23
313C23313C24313A23343C25353E26363E28353C27353C2831382530362330372030371F
353A22363C23353C24333B232F37202C341E2A321C29321C2A311C2B311D2A2F1C292E1C
2C311F2B30202C3221292E1F25291B25291C262A1F25281D24281C23271C21261A212619
2027182027171F2617202517
171E1E1A211C1E241B22251C262821292B252D312B2E312E2E31312E32342E3437323A3B
313938272D2D2025251F212419192114141E11111C0F101B0A0A1506051003030B010205
0103030305010D1106161C0E181D0F16170D11120A0E0E080D0D090E0F0C131412171915
171A171216140E10100E1011121313151516131113110F1112121111110F131410171912
15190F11130A0F10070B0B0216190C252B1A262C1E1D2319191F16161C13181E131C2416
242D1C2C362234402A39442D3C482F3E4A2F414F31435233445033465136475138464F37
485238475237455135455136445035424E34434E35444E36434D35434D34434C34424B35
424B36444B37464C38474B38484C39494D384B4E3950543F5155404D513C4A4F3A484E39
464C38444B37444B37434B34434B334148304048304149314149324147324047313D462F
3C47303B462F38442B364227344022313D2030391F30391F303A21323C23343F25343D26
333C26313C26323B25343B27353A26363D29373F2A363E2A343E2A333D27333C232E351E
2C321C30361D30371E30381F30381E2D351C2B3219293018282D17272C19282C1B292D1D
2B301F2A2F20292F202A2F20272D1D232A1A24291B23281A21261822261921261A20281B
1F281A21291B202719202517
1B20221A1E1E171C18171B141A1D1720221C282B232C2F282F332E3036332E35342D3436
3038382E3735282F2E272D2E252A2F24292F24263122242F1C1E281415200E0E18080911
04060B0305060B0F0A14180E161A1012150D12130C12110D12110E1413111A1B171D211C
2025221F25231C221F1A1F1E1A1F1E15181A0F11140D0D110D0D0E0C0E0C0D0F0B10130D
10140C0E11080C0F050A0C021A201029321E29331F1F2719191F1414180F12160C12160C
15190F181D101E2415242C1A2C36203440253C482B414D30455033465135475037475238
485336475235455334465437475539465238455138454F38444E37454E37464D36484F37
4A5038484E3A484E3A464C38474C39484D3A4A4F3B4E523C4E523A4E513A4C513A4B513B
4A4F39454E38454F38434D34434D33414B304047304147304147324248344248353F4634
3E46343B443138412C374229353F23313C1D313A1D313A1F313B20323D23364025343E24
323C24313C24323B25343B27353A29353B2B363E2C343B29353C28353E28353D27313924
2D351F2B341C2B351C2A331B2C351C2D361C2B321A292F182A2E192B311E2A2E1E292E1F
292F20272D1F292F1F29301F272F1E252D1A232B182029151F27142128162329181F2717
1D24161F25191F25181E2415
1F22221D2020181C1B161A17161A14191D151C1E151F2119232520282A272B2F2C2C3432
313A38313A362B34302B32302C33332E33343033373033392E31392B2E37232730181C25
10131B0B0D120B0E10101410151A1115191113150E12130D13130D1617101A1B151A1C18
1D211E202724252C27252C27272E282026221519181011130F0E100D0C0E0E0D0E101110
0F13100F120F0D100C0C100911170B181F0F1A22101B221119200F161B0E13160A12150A
13150B12140A12150B13170C1B22112229142C331B3942273F482C434D31465033485134
48523347533647523747533849553A49543A48543B47533B465239454F37444D35485038
49513A48503B474E3B474D38474D38484E39494F394C523A4C50384B50384C523B4C533C
4B523B465038444F36434E34434E34465136444F36434C34434B34434B35434934414735
4048343C44313B422E3B442C384227353F22343D20353E20343E21343D21353D22363E23
363E24353E26343B26323825353C28343A27343B28343C28353C28353C27343B26323B25
313B242F3A222E3A202D381F2C351E2E361E2D331F2C321F292E1D2B30202B3022292F21
282F20282F1E272D1D262D1B272F1A232C17232C16232D16232C16232B16222A16202815
1F2715212917232A181F2516
181D1C1E21201C1C1E17181A171816181A16181914191A151919161918171B1C1A202521
28302A2D362F2E372E2F38312D35312D33312F333430333831333C31353F2F353E2B3239
232A301D2227171D1F171D19181E17151A1413171012160E15180F171B1216191011140E
121510171C1721261F292F252E342A2E352B242A241C1F1C1819191311140E0E12100F13
0F1113101313111413111712121910161D0F171F0C171E0B171E0B151A09131708111506
1115061014050F140510140615190A1518081A1D0A292E17373C2240482B465032495235
49533647533847533746533848553A49553A49553C47533C47533C455139444E38454E3A
47513D49533D47523A454E36464E35474E35484E36484D364A4E37494E374A4F3B484F3C
48513D46503A444E36434E35434E35434D35434D34434D34444E36464E38434A35434835
444A364047333B43303A422E39422C353F28354026374224364022363F23373F23394125
384024373E26363C263339253138252F3523303625333B28343B27333A26303824313923
323A23333B23323A22333B212F361E2D341B2E331E2E33222D32212C31222C31242C3224
2C32222B311F272C1B252B18272E19252D18252E19242D19242C18252C19232B18212916
2028151E26121E26141F2415
1B201F292D282526251F1D201A191D19181C181619171618151314131211111311131712
181E171E251B272F212E362830372C31362E2F332F2F323231333834363E34393F32383F
2F373C2B3436252F2F2028271B2220161B1A161A18171A16161A15161A141418120E110C
0D0F0B10130E1B1F1722261C262A1E2B2E222D32282D312A292E292427261D1F2317191F
12151A1114181519181A201A1A21181A2115171F0F181F0D171D0C1319081217080F1406
0E13050E110310150513170715170912130712120519180722210E2C2D193B412B444D34
47513749553B4A563A49563849573747543647533848533949553B47513A46503B454E3C
47513C47523C48533A455034444E31454E32464D33464C33474B33464B34474C38474E3B
444C3A444D38444E36444F35434D33414A32424B33424B32424933444B34444A33444934
454B37434A373F47373C433539413236402E343F2B344029333E25333E22363F22374024
353E23343B23353B253338253137252E34252D32242D33242E3623303824313823303822
2F382130372030371F2F361E2D341C2C321A2D311D2C301F2B2F202B2F222C30232C3121
2C31202C3120292F1F262B1B252B1A242B18222A17232A17262B1A262D1B262E1C242B1A
2127171E25151E24131D2211
53635749554B353C363136322C2E2E28292B2221241E1C1F1B1A1A18191414171012160F
1318101519101C1F132224172A2B2230332C31342E303331333638373A3E373B41373D44
333B41313A3E2E3739293132232A2B2127282125271F21221C1F1E18191B1314170E0E12
0B0B0E1012121C201B1C201A181B13181A121F221A252A22292E292B322E2A312E212726
191F1E181E1C1B211C1B221A1C241A1A2016171C10191E0F191E0F16180B121409101208
1011090E0F0810110813140A15150C15160C1414091715061B19081C1B0A292C19393F28
4148304850344C54384D56394B573A4B573B49553B49543B48543A49553B49543A47523A
485138485038485037464E34454D34464F35454E35464E35454C33464C34464C34474D35
444A34434934444C34434B35444B35444C35444B34444A33444A35444B35464E34454C34
454B354449364248373F45383C4235394132363E2E323B2A303B26313D24323E23333D23
323C23313A24333B253339242E35212E34202F36222D33202D33202F3522313824313823
3038243038242F37232D35202B331E2B341E2C341E2B321E2A2F1D2B2E1E2C2E202C2F20
2A2F1E2A2F1F2A3020282F20252C1D222A1A212918222917252B1A242A1B222A1B232A1B
22281A2228192128171E2310
71867D72867C65776F5E6D6557625D4C5452454C4A3A413F282C2923282022271D22261D
24281E24261C2222191F1E182320202B2A2B2A2A2B2A2A2C31323335393A373B41394044
384145343D422F383B2C35382B32342C34332F38342D33322A2E3024252C1A192313101B
100D1715131B1B1D20161A1C1113130D0E0C0E110E1316131A1E1A212723252C27232A24
1F2720232C23242E24202A201E261B192014171D10191E101A1E10191A0C14150913130A
14140B1010080F0F08100F0911110A13130C14140D212315282C1A292F1B2C341E343C23
3A412541472A464C314B52384D543B4D563F4B554149554049563E48543B4953384B5538
4D55394C53394D52394A4E38494D38484E39464E38485037484F35484F34464E32444B30
444A31454A32484E35474D37484E3A474D3A464B38454A38434A38414936424C33434C32
444C32444A324348334247354045353F44343C4131373C2D323A2A323D28313D24313C22
313C21323B21343D22343B22323920313820333A22333923323722303622303522303623
3037252F38272E38262E38242D37242D37232C37222B35212A321E2C311F2B2D1D2C2F20
2D31212C30232C30242B3024282F23232B20232B1E232A1B242B1B252C1D22281B1F2719
21271A2128182028161E2612
7E928983968E85989283959081928F7A898877878470807E596768515D5D55615D5A675E
5A665A484F4834373636383B33343B2C2C332221271E1C2122202328282A303234343839
363D3D363F4031393C2B33382D3538313A3B353E3E363F3F384041373A3F2F313A252633
20202D20212B1E202714151C1012150E0E0F0D0D0C0F0F0E11110F131411171B171A1F1B
242C25283229293429263127212A1F1C23171A21131A20121A1F12191C0F16160C16160C
15170C13130912120912120B13130C100F0B100F0E30362A4A58434D5E464B5C4246543A
414C313E472C3F472D434A31464D3647503A4A533E4A553E4A563D4A543B4A53394B5339
4D543A50573E4F563D4E533B4C503A4A50394B513A4A5139495036495034484E34474D34
474C34484C33494D35484D37484D39494E3B464C38444A35444C36444D36434D34434D33
444E34444D34454C34464C34454A354549344145323D42303A402F363F2B343E28333C24
333C23343C23343C24353D25353D25333C24333B25333925333A263139252E36232D3522
2C35232C36232D38242E37242D37252D38262E38272D37272D36272B32242A2E212A2F22
2C30232C2F232A2E23282E23262C23252B22252B21242A1E242B1D242A1C22271A212519
2026182128182027171F2415
82968C8698918A9B988A9A9C8A9A9E88979D86979A8697988495987F90947F9292829793
82978E798B826C7B746F7E775C67652C2E381B19241A191F1513191614191D1D1E262826
2F3330343938353E3C323B3C3943423F4A493F4A493C46483B44483A4147383F46353C45
3239432E353F242934191C2713141E1010161111131111110F0E0D0E0D0C0F0F0C11140F
232A22262E26293127293227242C232129201E261B1C22191B20181A1F17181C14171B12
15180F14170C15160C18190F1716101616101F20182A2B23464E3E515F4A53654C53644A
50614549583E455337434E33434E32444F344750374C543B4B533C4B533B4D563B4D573C
4B553C4C573E4E573D4D563B4D56394D54384D53384C523A4C513A4B503B4B503C4A503C
484E3A474D38474D35474D35464C35474D37474D35474D34474D34454D36444D37434D36
454F37454E37444B36434B35434A334349314148313F47313F46303C432D3A412C353D28
333A27323A26333C29343D2A323C2A313C29303B27303B26313B27313C27303C262F3A25
2F39252F38242F39242E36232D3625323A2A313A2C30382E30392D2D35282C32252A3023
2A30232A3022293022293022282E20292E212A2E21292C21262A1E24291A212417202418
20241923261A24271B202319
80948E869A948A9B9A8B9C9E8C9DA18C9CA38A9A9F8A9A9C8A9B9C8B9D9D8A9F9E8BA19D
8AA2998BA3968AA1928CA1927E90843E43481A19241C1B2117151A141115131113171616
1D1F1D2225222C332E323B363B453F404C443F4A443E47463D45473B4348384048384047
3A434C3A434B3740483036402327311D202815171D121217100F130F0D100F0E0E141614
252B24222922202720252B22272E22242B2022281E1F251D1E241E1F241F1F251E1D231B
1B20171A1F15191E131A1D1319191118181223231B23231A3F433456624C505F493E4B3A
43523E495A414D5F414A5C3B47573547543345503147503449503849503848513849553A
48563A4A573B4D5A3D4B573B4A553A4C553A4C543A4C523B4B503B4B503E4B513F4A503E
484F3F474F3E464F3A464F37464E36474F36464F34474D32474C34464B35464B38444B38
444C3A434B39434C3A424B37414933424830414930424B304349304247303F45303C4330
393F2F343B2B313A2A2F392A2E392A2F3A292F3B26303C24303C23323D23323C24323B25
3239243137243037233036232F36242D33222C342530382A2E38292E37282D36242B3221
282F1E272E1E29311F29321F2B321F2A2F1D2D2F1F2C2F21282D1F25291C212417202217
20221A23261D22251D20211C
7F958D879D968A9F9C8B9F9F8DA0A28D9FA28C9F9F8DA09D8C9E9B8C9F9C8DA19C8CA29B
8CA49A8DA59890A79891A8958FA5926C7C712E3235222426202020181718151314141212
1413111818151C1E1A1E231E282F28303830373D363B413C3D43423E45473E46493F474A
40474C3F464C3E464D3F484E3C454A373F422C303424252A1F1F251A182014121A1E1E21
2327261A1E1E171B181B211A22291D22281C2025191F251B21271E21281E20271C21281B
20281B20281A1F25171C1F1419191216151318181519191645503E5E6F5544513F2D352A
2C34282B34253E4B324C5F3D50623E51623F4C5B3B47533847503848513B47513D454F3A
43503A44523A4A573D4B573E4A563E4B553F4B533B4A513A474F3948503B49523D49513D
48513E474F3E454E3D46503C46503A475138464F35464E34474F35464D35464D35464D37
454D39444B39454D3A434B39414935414A33414931434B31434A3142482F414730414832
3E453139402E343D2B30392930392A2F3827303A25303B22303A2030391F313821303822
2F36222F37222E36213038232F37232D35222B35212E36232E36242F37262F37252D3320
2D32202A301D272E1C252E1C252E1D282E1D2A2F1E2B301F292E1F252A1D2025191E2317
20241722261B20241B1F221C
849B9189A0988AA29C8BA29E8BA09E8BA09E8BA09C8A9F9A8B9F998DA09A8DA1998FA39A
90A59B90A69B92A89B92A79994A999889C8C5D6B63383F3D3034322021231C1B1E191719
161515171614181913161712191A151D1F1925272134362F3B3E383F443F424844434A49
454E4E444E50414B4E3F4A4C3F4A4A4047494046473D4144393C40313139282731292A30
24252A14141B101117121515141814151915191E171C21191E241A1E25191D2417202617
212918232A192226181F22171E1E181C1C1A1E201F1D2120242A262E372D252C24262A22
23271F1C1F171B20152C362446563B536749576A4C54654A4E5C4349553F424D3B3C4636
3A46363D4938424E3B46533F4855414A574249554048553C49553A4C563A4A5437495237
4A5238484F3B464E3C47503D47513A47533A454F35444F33464F34464E33454E34454C34
474D35464C36454B37454C38444C37444D36424B34414A33414B32424A3040482E40482F
3F47303E46313D45313A412F353C2D33392A323927303726313926333B25323A24303824
2B34212B34212B33202E36212D35212E35222D34212D34212E35222F35232F3623303722
2F36212D341F2B321F29301F272F20283020293020293120262E1D252C1C21281A1F2518
2127172126162125171F2318
81988F879F9588A09888A099879E9889A098889E97889C948A9F968EA29990A39B91A59D
92A69D92A59B93A49B95A59C96A79D93A59B899B91798A8057625F383C402E303524242A
2221231D1C1A1B1A161818151615121615121513111D1A1525231D2F302A393D36404640
424B47454F4C404B4B3D48493E494A40494B43494C44494C43484C43464B41434B3C3F48
2C2E391E1E2A1416200F10180E0E150E0F131012121519151A1F191E221B1D23191E2418
212819242A1B24281B24261D262822282929282A2C212527191C2017191C17191C1D1F1D
1E201B1B1C19181B17171B1721281E323D2D3E4C374D5E4457694D52624A3641312A3326
262F232831242C35283743313E4B3545523B47543D48543D49553B4B593A4A5637495435
495335475037485139485039454F36465038465037465035454F34444E33454F34454E33
464C31444830444A32474C36464C36474E35464E35454D35444B34434B333F48303E462F
3D452F3F47314048323E46303A422E39402E363C2A343929333828343A29333A29323B29
2D37262A33232B32202B321E2C321D2D331E2C331E2B331E2D341F3038213037202F3720
2E35202D35222B3423282F22252C20232C1F273020262F1E232B1A242C1B232B1A1D2415
1D2415202514212514202314
839890869D95879E97869F99869D97879D95899E968A9E978CA0998DA19C8DA19C8FA39B
91A49C93A59C94A49D97A79F96A69F95A59D94A59B93A59A86988E6F7D7750595835393C
313432292B2521221D1C1D19191A1617151416121116110F1711101B1714282420353630
383E393E4642414C47424D4A414C4B424D4C444C4C444B4A44494945494B47484F454651
41434E383B472B2F39181A2614141F1111190F10151112151619191B1F1D1D221E1E241D
21271E23291F24281E24251E2F322B363A35363A3A292C301F1F2518181F15151A17181B
1A1C1B191D19191F191A201A161C161920161E2718242F1C3E4D3448593E2E3926222A1B
1C2316181F13161C0F242C1C323B273E473045503848523C48523D49553C4A563B4A5639
4954384753364953364A5136474E34464D35474F37454E37434C36424C36434D37434C35
424B3140482E41482E42482F43482E454A31464B33464B35464A384449384147363E4534
3C44333C44303C452E3D452E3D452E3D452E3D422C3B3E2B383A2A36382A34382C32382B
2D35272C34242B32212A321E2A331C2C351D2A341A2831182831182B341B2B341B2D351F
2D34212C33242B3328262D25222921222920232A20232B20242D1E242D1C232B18202815
2129142328122024101E210E
81938B879C938AA09989A09B889E9B869B9A869C9A899E9D8CA09E8EA09F8FA2A08FA29E
91A39E94A59F95A49E96A59E96A69F96A69F97A89E95A79E96AA9F92A69B82938868766E
58635A4A54482C322B262C251D201C1919181715151813131712111812121A1514201D1A
2626232C2F2D343A363A413D40494447504B48514C48504B464C4A46494A44454C44454D
43464F444A544248513A4046282C3422252B1B1E2413141B12141C1B1F24202628202726
222926222A24212823212520292C26383D363E443E3B413D3034332A2D2D1F20231C1D20
1B1E20191C1C171B191518161015101419111A2114181F0F1D2415262F1D232B1B192013
181E11192013191F131D2417293120353F283C472E404A32424C354852394A563A4B5639
4B56394953374C55374B5336494F35484F36484F36464E37454F38454F39465039464F39
474E37444C343E452F3C422B3D422A3E432B41462F424731444834454B37444A37404737
3F46373D45353B43303B432F3B42303B422F3E452F3C412C3A3E2C3A3E2E383B2E33392D
32382C33392B3037262D35222E35212F38222F371F2D361F2B331E2B321F2A311E2A311F
2B32212B34242B3426293226272F24252D22242C20232B1D262E1D252E1C252E19242D17
272E15262C1323281021250F
83958B8B9F968CA39D889F9C859D9D869D9F869C9E879D9F8A9F9F8CA0A08FA2A191A4A3
92A5A394A6A295A8A095A89F96A79E98A8A198A9A298AAA397ABA295AAA095AA9F91A69A
899D907A8D7E5F6F6249524A3437352C2D2E2525271E1B1D1D1A1B1F1E1E1F1E1D1F1E1C
1D1D1A1E1E1C212220282A27363C3640473F474E464C534D4D53514A4E51474A51444852
404650454E55444E53455051434D4B3F4745393F412C2F3720212D272B35262C341E252A
1C23241B24211C231F1C221C1B1D1A2123202E312E373D383B433C3B433C363D372E3431
242A291D2122171C1C1215150E110F111510161B13171D121A1F1421281B252C1E21281B
1C24161C23171C2317252D1F313B2937422C3B462E3E482D40492C454D31484F32484F32
4A51344C52374C53394B52384951384852384852374954374853374750374A513A4B513C
4C503C4A4E3B464B394348374147333F46304047303E472F3D462F3F48303F48313F4731
3F47333F46333B42313C44333E46353942303A432F39422F37402E39412F394030373F2E
37402E39412D373F2A343C27363D29353C293339263239273038282D3528293225283124
2831242831222832222A34232933232932212A332029301E292E1C292F1C282E1B282D19
282D17272C16262A16252816
879C928DA39B8CA4A08CA3A38AA2A68AA1A5899FA2879D9F899E9F8BA1A18FA3A291A4A2
92A5A292A6A194A7A094A79E97A99F99AAA29AAAA599ACA798ACA697ABA597ACA497ADA5
97ADA496ACA093A8997A8A806C797067746B454B4D32343C373B3F3D41433133362C2E2F
292B2A2729252628222729232B2E2730322D383A3441433D4A4C484D4F4F4E52554B5356
454E52424C4E414C4C434E4B4954504A53524A5154474E543E444C3A4149272D381C222C
141B21131A1C141A181317151110121311141A17192D2C293B3F393C423B3E453D3C453D
363E392D3434252C2D1B21211115140F13101013101216101E251A252C1F293021272E1F
232C1B232B1B20271722281925291A2A2F1D2D321F343923383E253E442A454A2F474C32
474D32494E334A50364A5138495138475037475037485337485237475036484F394A503D
4C52404B513E484E3C444B38424935414A33414B333F4A333D48333D48313C462F3C462E
3D462F3D452F39422E39422E3B433038412F36402D343E2C353F2D36402D353F2C333E2B
353F2C363F2B353F2A343D2A353E2B37402D373F2C363C2C333B2D30392C2F392C2D362A
2A3327283123252E1F262F1E28311E2A341F2A341E29321C293019292E19262B19262B19
262B1824281626281826291A
879E968CA39C8BA29F8CA3A28BA1A48AA0A4899EA4899EA38A9FA18CA1A28DA3A28FA4A2
90A6A192A8A094A9A092A69F95A8A298AAA499AAA698ACA998ACA999ADAA98ACAA98ACA9
9AAEAA9AAFA99AAFA59AAEA28A9B9175827C656F6E596064727C7778847C666E6C606A66
576259414840363A3234352E31302B302D2C34312F3533313A39383F3F3F474A4A4C5352
4C57544A565049554D49544D4C56524D55564C52584C515B4C545D49545B3F4A52354048
242E3520282B171B1E141418120F151711151A141535332B3A393233322F313030323432
393E3A3D45403B4640323E3818211D1117130F130F0E100B1C2317212719232919272D19
282F1B28301D2A301C272D1A2226162123151D1F111E2012252718363B27495237495237
4A54394A5337495136464D35464C35464D36464D37465038444E3745503747513B47513D
48533D48523C465039444E37434D35424C34414C34424E35404C343F4B323D4A303C482F
3B462D3D462D3D452E3B432D3A432F3A423038413037402E38422F38432F36422D34402A
333F29343F29343E28333D29353F2A363F29373F2A363D2B353B2B333A2B323B2C2F382A
2D36292C35262832222831202A34202A342029321E2A311D2A301C2B311C292E1A262C17
242B15252A16252A17262B1A
849A9389A0998BA19D899E9E879C9F879DA0899FA2899FA2899FA08BA1A08DA4A48FA6A6
91A9A692AAA594ABA395A9A497AAA896A9A896AAA898AAA999ABA999ACA99AADAB9CAFAC
9EB0AB9FB1AA9EB0A79FB2A6899A90626C6A626A6A737D7992A09596A59998A89C9AAA9D
95A79773807758615C535B554D524C52564D45443E3937343534323634343C3A3B424344
454A4948504B4D574C515C4F525D535058554C53564A50584F555E5058614C56604A555E
4450553D484B323A3C292C302220241E181C2520204140392F2A2A252124211C211D191E
2323242D312F343E373844392B382C161F1713190F0D120810150B13180C14180B181D0D
1E24142128182329191F26171C2116262B1F252A1E21251B1F21182F34265563465B684B
5B684B576349515A4449513E464C3A434A37434A364047353F4734404936424B38454F3B
46513B48523B46503B444E38424C35404C343F4C33414F34404F33414D31404C313F4A30
3F492E3F472F4047313D43303C42333A423438413238423039443136422D36412C36422B
364229374127373F27353D27343B26323925343B27343B28333B29323C29323C282F3826
2D36252C352529332229322027301E28301E2A301E2A2D1D2A2D1B2A2E1C282C1B252A17
222616252919252A19252A1A
8597948A9E9D8DA0A38B9EA4899CA3899DA28A9FA18BA0A08CA09F8EA1A18FA2A68FA3A8
91A6AA91A8A991A7A694A8A798ACAB97ABAC97ABAB99ABAB9CADAB9CACAA9EAEADA0B0AF
A0B1AEA0B0ACA0B1ABA1B3AC95A59F747F7F6E7777838F8A9DACA19EACA2A3B0A7A6B4AA
A7B5AAA1ADA6949F9A87908D828C868D9B8A646C5F4B504645484040403B3F3C3A3D3A3A
3C3A3C3E3E3D4347414A50474F584D505A514F58534E555653575C53575D4E525B4D535D
4C565D4C585C4B58584652503D434231313434323340403B272326201D221B181F151219
1312161516181A1E1C20261F222A20192319151C11161D0F141A0D13180C13180C14170B
15180D171B10181C1115190F10130D161B141E231A22271C23271C2B31233E4634555F48
5C68506270586070585865514D5544414636363A2C333628353829383B2C3C40303F4533
434B37464E3A444E3C424E3D3F4B383F4D363F4E333F4E30404E2F414D2E404C2E41492E
424A2F4147314045333D44343C43353B443737423435402F35432D35422B35422A364228
384329394229373E28373C2A3439293037272F37263038272E39282D38262E3A252F3A23
2E38212E371F2B341D2B331C2A311B2A301C2B2F1D2B2C1C2D2E1D2D2D1D2B2B1E28291B
27291B272A1D262B1D24281D
8697988B9CA08C9EA78B9DA88A9CA78B9DA68C9EA68EA0A48EA1A38FA1A490A2A690A3A7
8FA4A790A6A78FA6A792A6A796AAAC95ABAE96AAAC98ACAB9BAEAB9BADAA9DACAB9FAEAE
A0B0AFA2B2B0A2B3ADA4B4ADA1B1AB9AA9A495A29D97A59DA1B1A6A3B1A9A7B4ADA8B5AF
A9B4AFABB5B0A9B2AEA9B3ADA7B1A9A5B3A595A49186927D686F616166595E605654554D
4C4D4742423C3E40373E3F3742453C474C434C514B4F5552535959555A5C52595C50575B
4C55584A56574B59594F5C59535E595157544D505145474925222E201F2C1A1A2615131E
12111A1012170F13130F15100F160F111910121A101720101C24121B2211191D0F181B0E
171A0E181B0F15150B1111080E0D070F0E0A13130F1616101617121D1F19292C25373D32
48524452604F596A5660735B5D6E554B5641373A2A28271B26231929251C2D2B21323026
383A2C3F4533414A37414C393D4A353C4A313D4C2D404E2B404D2B404B2A3E48273E4527
3F452B4045303D43323B433339403337403336403235403034402B344128344025384226
394127394028393D28383A28373B2C343A2D32392C2F382C2C362A2933262A35242C3722
2C38202E391E2C381C2C371C2C361B2B331B2D321C2D301E2E2F1F2D2E1E2D2C202A2A20
292B22282B2324282021241D
839797869A9E8A9EA58C9EA98B9CA88A9BA58B9BA38C9DA38E9FA490A1A68EA0A58FA3A5
91A4A691A5A790A5A791A5A697ABAB99ADAE9AADAD99ACAD99ADAD9AACAB9CADAC9EAEAD
9FAFAEA1B1AFA0B1ADA2B3ACA4B4ACA3B2AAA2B0A8A0AFA7A3B2A9A5B2ABA7B4AEA9B5B0
ACB6B2AEB9B5ADB7B3ADB8B2ABB6AEA9B6AAABB9A7A8B6A19FAA979AA593939D8C899283
777F6F5E64544A4F3E3F4234393B303738303738323B3D3A4649484E5453525A5A525C5B
505B5A4C58574A56554D5858545E5B59605D5A5F5E585C60484C543C414C292D3A1E222D
181B2613171E1015180B1210090E0A0E140B1820111E2713232D17252E18232A15202513
1D21111A1E0D161808121105110E05120F0916130D1916111714131512151613171C1A1B
262927353D3647544555664E46563F46553B4551373B402D3D403037352D2F2B292E2A26
313028363A2E393F323C45333B45303B462C3A44283C47273C46283A42273A40263A4027
393F29383F2B373E2D373F30363F31343D30333C2D353D2B373E293840283841273A4228
3B422A3A412A3A402B393E2B363B2A353B2B343C2C30382C2C34272B34262A32252A3323
2B34232B36222C37212D38212B351F2A341F2C341F2B311E292D1C292D1D282C1E272B1F
272B20282C21262B1F23271B
7E9597849B9D899FA38A9EA6889CA5899BA38B9BA18B9CA38C9DA38D9FA58EA0A690A2A5
91A3A591A4A792A6AA91A6A895A8A996A9AA99ACAC99ACAE9AACAF99ACAE9CAEAF9EAFB2
A0B0B49FAFB3A0AFB1A1B1B0A4B3B0A4B2AFA5B3AEA5B3AFA5B3AFA6B3AEA7B5AEA9B7B1
AAB6B3ACB8B4ACB9B4ACB9B3ABB9B0AAB9ABACBCAAADBCAAADBBA9ADBAA9AEBAA9AAB6A7
9BA69992A08D67706140443C3538322F332C2B2D272A2A252D2C283C3D38464A444E5550
525A57535D5A515C5A505B5A545E5C57615C585F5A5A605D5B61605860604A51543E464A
31393E1F252B151B1F0E14140A0F0B0E140B1921111F291429341D2E39212B351C222A14
1D210E181A091113040F11031010051211081A190F1E1D121E1C1326241B28261D221F1B
26252431332E393E36464F3F3036291C211722291B2B34234A573D606C505E6750565C49
474B3D3F43373F43374045373F45353C42313C422C3B43283B4428394127373E26373F26
353C26343B25343B26353C29363C2C353B2D323829333928363A29383C2C373D2D363D2C
373F2C363E2D363E2C363E2A353E27343D27343C263038242D34232C33232B31222B3223
2A31242931252931262933262A34242B34222A332029311E292F1D282F1C282E19262C18
272C19292E1C282C19272B18
809697859C9F8AA0A58A9FA8889DA6879CA38A9BA38C9CA68D9EA78C9DA68FA0A891A3AA
91A3A991A3AB93A5AB92A5AA93A4AA94A4AB95A6AC97A8AE9AAAB09BABB29EADB4A0B0B6
A2B1B7A1AFB5A1AEB4A2AFB4A3B1B4A6B2B3A7B4B3A8B4B3A8B4B3A8B4B1A9B4B0AAB6B2
ADB8B6ADBAB7ADB9B6ACB9B4ACBBB1ACBBADAFBDACB0BEADB0BDADB0BDAEB0BDAEB2BDB0
AFBBAFABBAAC92A094626C66474F4A3A403831362D2D2F242A2A1F2B2921312F2A3B3B37
3F413F474C495059535560595A665E5A655C565F56565E56555D57565E5956615C55605D
4E5B5943504D2C343413171811151213180F1A21131E2615232C1727301B28311B252B16
1E221016170A100F070E0D080E0F0810100B23261C1F20181C1C155661466D7C5A34382D
3D443B41483E3238312A2E2922231E18191312110D0E0E082023196E80618BA17D849878
6D7B67556054555F5450584C4C5345474E3F434A373F48303E482D3E482C3C452A3B442A
384026363E26353B26353A26373B29363B2A32372831362732362833362A31372A31382B
323A2D30392B2E37282F39262F3B242F3A222F39212D371E2C351F2C34202C33202A3120
29312128302327302528322629342429332129342029341E28331D28321A293118282F16
272D16272C18262B18272B19
7E9195879C9F8B9FA5899CA6869BA5879CA4899BA28C9EA48D9FA78D9EA68FA0A791A1A9
93A3AB92A3AB92A4AB92A3AA93A3AB95A3AB95A3AB94A4AC96A5AD99A7AE9BA9B09EACB3
A0AFB4A1AFB3A3AEB2A3B0B3A4AFB3A4B0B3A5B1B1A6B1B0A7B3B0AAB6B2ACB7B6ABB6B4
AAB6B4ACB8B6ABB7B4ACBAB3ABBBB1ADBCAFAEBDAEB0BDAEB0BDACB2BEACB2BDACB3BDAD
B3BEAEB2BEAFAFBDAEA0AE9F8A9888626C6141453E3B4034383B2E38392D34342D33312F
312E2E2F2E2E35363341453E4E564A555E51596355596355566053525C51576356566357
515F5651615747564C252D291D241D191E17181D13171C10191E0F1A1F0F1D2012202416
1F231516170E13120D11100D0F0E0D0F0D0D1919171716141E1F1E7F9377A6C29E94AF90
5F705F3D453B2B2F271B1C1716161215140F13110F11100E0E0C0C47514194AD88899F80
889C8170816F62716361705F63715D626F5D5E6B595D6B5558664E505D454C564048513C
444B384146353D42313A3E2E383C2D373A2B33352A32352A3134283236293035282E3327
2E34272C34262932242A34242A34232A33232B35232C37212C361F29321C29321C29311D
29301E27301F28312128322228322228311F28311D28301A272F1A272E19282E19262C18
242916242A19242A1C22291B
76888D84989A879BA28598A28295A28497A28498A1899CA48D9EA78E9FA88D9EA78E9FA7
90A1A98FA1A991A3A991A3A893A5AA97A7AC97A7AC95A6AD95A7AC98A8AD98A7AD9AA8AD
9BAAAD9EADACA1AFACA4B1AFA6B2B2A6B1B3A6B2B1A6B3AEA8B3AEA9B3AFABB6B4A8B4B2
A7B3B3A9B6B5A9B7B3A9B8B2AAB8B0ADBBB0AEBDAFAFBDAEAFBBABB0BCABB2BEABB2BDAB
B3BDABB4BFADB3BFAFB2BEAEB1BEACA5B19F82897C72786C71776B60655B47494442423E
363332302B2A2A262326241F3132293F43364C5242545B4957614E4A52444C5646485342
424F3E404E3E465543424F3D2A34252026191F24151A1D0F17190C17180C1A1A101E1F16
1E1F1818181212120C11120B12110D12100E1615131B1A1A1B1B1C3B413B5D6D5D92AE8E
7D95783A4435282C1F1E1E1417150D100D080F0B09100B0C0E0B0D2529257C94788EA78A
839A7F80957B63715F586453596453636E5E7D8E7883977D83967C819276758368646D57
6167565E645959605650584E464F4340473B3C4238393D35373B33353A3034392D32382A
3239292F38292E36292A31272C32282B32262930232A32202C331D2A311A2C321A2C321B
2B311D282F1D252D1B242C1D232B1C232B1B242A19242A19252A19262B1A26291A232719
21261821291B21281D20281D
7C8F8F829595869A9D879AA28496A28395A28395A18899A38B9BA68C9DA88C9DA78B9DA6
8CA0A88CA0A78DA1A68FA2A591A3A792A5A893A6A894A7A795A7A796A8A996A7AA9AA9AC
9BAAAB9DACABA0AFACA2AFACA4B0ADA6B2AEA7B3AFA8B4AFA8B4AEA7B2AEA8B4B0A7B4B2
A6B2B2A7B3B3A7B4B1A9B6B1ADB9B3ADB9B1AEBBB0B1BEB0B0BDB0B1BDAEB2BEACB3BDAA
B3BDABB3BDADB4BFAFB4BFAEB4BFADB4BEABB0B9A7ABB3A2A9B2A09CA5957C807673786C
3C353736302F302A2A2A26242825202D2D243334273B3E2E3E44313235272F34262B3122
272F1F29301F323B273B452D3036232A2E1E2528191E2015191A1116170F1A1B1420211B
20211B18191513151113160F13160F12130E181A161E201D2529232529242B312B4D5A4B
5968564A564522251D1D1D15191611110D0C0E090C0D050B0C070E353836738673839A85
7D957F83997F81947974826B677260616A5A7B8B7483957A86977C8C9D808C9E806D7864
5B615762685F646D64697368697565616B5D596358515A524D56504A534B475046444C41
41493C3D4438383F3532372F2F322A2C30262B2F232B2F1E2A2F1B2C2F1B2E301A2E311B
2D301C252A191E2414161C0F12170B11160B14190D161A0F1E221425291A25291A24271A
24261B22261C1F241C1E251B
7D918C859895899C9E879AA18497A18496A18598A28799A18A9BA28B9CA38B9CA48B9EA4
8BA0A68CA1A68DA1A48EA2A490A3A68FA4A78FA4A591A5A592A5A596A8A799A8A99BA9AA
9DAAAA9EAAABA0ABAEA2ADAFA3ADAEA5B0AEA6B1AEA8B3AFA8B4B0A9B4AFA9B3AFA9B6B2
A9B5B3A8B5B1A9B5AFABB7B0ADB8B0ADB7AEAEBAAFB0BCAFB1BDB0B3BEB0B3BDAFB4BEAE
B4BEADB5BFADB6C1AEB5C1AEB5C1ADB5BFAAB5BFABB4BDAAB3BDAAB4BFA9B1BCA6A9B59E
63625C3B3436403C383D3C333A392E37372A3738283233232C2C1D2A281C252419202115
2023142325152B2F1C3539253538262C2F2226281E1F201A1B1C181A1B171E201C222421
20221E1B1E1A171A16171914181B1314160E11130D191A1525291E2D3326363E2F444D3B
48533E424C38262A1F20221A1D1D19181515151114130D13110D13211F234E564F5E6D60
70836E798C73899C7E8B9D8087987E82937980917782957985977B84947B8A9B828B9B85
6670665C655D545A54626B5E8B9D83768371555E57555F595B665F5D6A61647266697867
67756364715E5C665550574945483E3C3E34383B2F35382831332231322032321E30311F
2C2E2025291C191C100F1208080B030407000608020508020C0F0615190D1B2012202315
21241722251A21251A1F2418
7588867F9493859A9E869BA28699A48699A6879AA7879BA6899CA68B9EA58A9DA48B9EA5
8A9EA58B9FA68DA1A590A3A591A5A891A6AA90A5A892A8A994A7A796A7A699A9A89CABAA
9FACACA1ADAEA4AFB0A6AFB0A5AEAFA5AFB0A7B2B0A9B3B0A9B3B0AAB3B1AAB4B3ABB7B4
ACB8B4ABB7B2ADBAB2ADB9B2ADB9B1AEB8B0B0BBB1B2BDB3B2BDB2B3BEB1B3BEB0B4BEAE
B4BEABB6BFABB8C1ADB7C0ADB6C0AEB5C0AFB8C2B1B9C2B0B9C1AEB9C2ACB9C3ABBCC9AC
9EA7905B58524A474279816B6B715D5459485257444345353736283131232D2D1F2A2B1D
282919282A182C2E1D3839293A3A2D3233292A2A2323241E1D1E191C1D18222420262924
2629242528222125201C1F1C1A1D1812140F0F100C10110C15170F1C20152B31213A422D
3B442E363E292B312024271A1F20181C1C181B1A1A1A1A1A1D1F1D1D201E252925363D34
434B3F484E427E8C7397A98C8FA18792A48890A1858EA0848D9F858A9B84889984889B86
8193807584736E7A69697564889A808FA5896B7A6A616F615B685B555F55626F62758774
798C767C8F777B8E7673836D6C7B66697561646D5A58604E535A494E5442464C393C4132
363C30282E251C221811150D0A0D06060801040600010300000100030501070A030D0F05
181A0D212414222716232A19
7387857D929384989F869AA48699A68699A78698A78699A7889CA8899DA78A9FA68DA0A7
8D9FA88FA2AA90A4AA8EA2A790A5A894A7AB94A7AD93A7AC96A9AF97AAAE9AAAAE9BAAAD
9BAAAD9EADAFA0AFB0A2AFB1A3AFB1A3AFB1A6B3B3A7B5B2A8B5B2A9B4B5AAB4B6ABB6B8
ACB7B7AEB9B7AFBAB5AEB9B5B0B9B5B0B8B4B0BBB6B1BDB6B2BDB5B1BDB2B2BEB2B5C0B0
B6C0AFB7BFAEBAC1AFBBC1B1BAC0B3BAC2B6B9C1B5BBC1B4BCC4B4BBC4B0BAC4ACBCC7AB
B9C6A89CA48D75746A9FA692A9B19C9DA79295A089777E6A49493D444636434734434731
3F432B3C4028383B283B3B2D3D3C3039382D2D2D2527271F21211A1E1E1720201A24241D
282A232C2F272C30292325241D1E1D1213120F100E0D100D0F120D1317111D2319242B1D
272D1D29301D252A182022141C1C161918171B1A1B1B1A1D303534444D47434E464E5C50
505B4E4C53474D504993A38A8A998484938080907B808F7A899C84899C858A9D878B9F89
879C858599817D9077778A72798B727C90757B8F767B8F76778A73738670738570738571
7486737788767889767889767889757A8B747C8B73798673748070717E6E6E7C6C677466
5C6A5C363F381C201D171B16090A06040501020300010200000100000100000200020400
0C0E031A1D0C222713252A17
7284857D90958295A08396A48296A38396A38497A38497A2859AA3889EA58A9FA58A9EA5
899DA68A9FA88CA2A88A9FA68A9FA58EA3A792A5AB94A7AF94A7B196A7B197A8B099A8AE
9AA9AF9BAAAF9BAAAF9CAAB09EACB1A0ACB1A3AFB1A4B2B3A7B3B5A7B2B5A6B1B4A8B2B6
A9B2B8ABB4B8ACB6B6ABB4B4ACB3B3AEB5B3AFB9B5AFB9B7B1BCB6B1BCB5B2BDB4B3BDB2
B3BDB0B4BDB0B6BEB0B8BEB2BAC0B6B9C2B8B8C1B7B7C0B4B6C1B3B7C3B0B7C2ACB7C1A9
B6C1A9B6C0AAB3B8A6B2B8A6B6BDABB6BEABB5C0A9AEB9A1787A706D6F647C836F818A71
7279635B614F525747484B3D4444393D3A313230272D2C2327261E21201A20201823241B
26261F282A22292B242224201D1D1C181718141315111413121713171D171B211A21291D
272E20293120252B1A1F22141B1C151B19171815171C1A1F373D3E7588776D8270617464
6476625A67544A4F4698AB908EA28B718373647365515B5271816D82957D849880899E86
889D878AA1885F6F60485349859A7C72836A6F7E6B7B8D797D917C7A907B7A907A778B75
76897575847474827572807572817573837374837174827175827074816E74816F74826F
788A734F5B501212170B0B0C010101000000000000000000000100000100020400090B02
121406171A0A1F2411232814
79898E7E91998093A07F93A08094A18194A08397A08397A08498A1869AA3899DA6889DA7
899DA68A9EA68A9EA68A9EA68B9EA68DA0A691A3AB92A4AD93A4AF95A3B096A4AF98A7B0
9AA9B19BA9B19CA9B19CA9B29EACB3A2ADB3A3AEB2A3ADB2A7B0B5A9B1B5A8B0B5A9B2B6
ABB4B9ACB4B8ACB5B7ADB5B5ADB5B3AEB5B2B0B8B4B1BAB5B2BAB5B2BBB4B2BCB2B2BCB0
B1BCAEB2BCAEB3BDAEB3BCAFB5BEB2B5BFB3B4C1B3B4C1B2B3C0B1B5C2AFB6C2AEB8C2AE
B8C2ACB9C1ABBBC1ABBBC2ABB9C0AABAC1AABCC3A9BBC3A8B4BBA2AEB39DADB39CB0B99F
ABB4999CA38A8D937B696A5A5C5A4E4B483D3D3B2F3535292D3024262A2027271E292A1F
2A2B2125281D20221B1D1D191A1A171817171515161618171B1F1B242920272D21293023
2B31252C32262B3122262B1D25281E22231D1D1C191818183036317B927688A48052624D
4D5A463F4839393E3464715E5F6D5D6A7F69697D675A6A566A7B647A8D747E927A82967F
849882899F86616F614045419AB18F51594E4248468FA48D7F948066786B7185747A8E7B
6D7B6D6C786D717C74727D7871807972817672827373817174826F707E696E7A656A7761
616D5A3F453D14121509050805030403010202010201000100010001030005070216180D
202314222717232A19242C18
7A898F7F929A8195A08297A18195A18296A18397A28497A38497A48698A5899AA7899BA8
8A9CA88C9EA88DA0A88C9FA78DA0A78EA1A890A1AB93A5AD94A4AD94A2AF97A5B199A6B3
9AA8B49CA9B39DAAB39EABB5A0ADB6A1ADB6A2AFB4A4B0B2A6B0B1A7B0B1A7B0B3AAB3B5
ABB4B6ADB6B7AEB7B7AEB7B5AEB7B3AEB8B1B1BAB2B2BCB1B2BBB3B2BBB2B2BCB2B2BCAF
B1BCAEB3BEAEB3BEAEB4BDAFB5BFAFB4BFAEB5C0AFB7C2B2B8C3B3B8C2B1B9C3B3B9C2B2
B8C2AEB8C2ACBAC2ABBCC4ABBDC5ABBEC6AABDC4A8BDC4A6BEC6A6BCC4A6BBC3A6BBC4A4
BAC3A2BAC5A1B4BE9AA2A98A93997E71745F4948374447323C422F353A2A333427313124
2F2E222A2A1F24241B1F20191C1E171A1C16191B161C1E1921241E2D31272F3327303528
3134293033283034282E31252C30252B2E241E1F17191A1216181024291D3A4532313829
2E3225282C22272B22272C2420251E4E5D496B7F6162735873866A71836A70816B6D7E6B
718574778C7B7387756E806D889E835E6A5F42494A8AA08B92AB92798C7A7C8F7B7F917D
3D3F404345487581786F79755F686668766E6E7D6E6E7D6C6D7D686C7C656B7B6467765F
515C4A363E33191B190D0C0D0B080A080507060404030202020101080A061417101F2318
272C1C292F20282F20293020
74868A7D919581959B83979E82969E8396A08496A18395A38596A38697A38797A28A99A6
8B9BA78C9CA78D9FA88EA1A78EA0A78F9FA890A0AB91A1AD95A3AD96A4AF97A5B199A5B2
9AA7B39BA9B29AA8B19CAAB39DABB49DABB39FACB0A2AFB1A4AFB0A7B0AEA9B2B1ABB3B4
AAB3B5ABB5B5ABB5B5ACB6B4ACB7B3AEB9B1AFBAB0AFBBAFB1BCB1B1BBB1B1BBB2B1BBB1
B2BCB1B5BDB2B8C0B2B8C0B3B8C0B2B8C1B0B8C2AFB9C2AFBAC3B1BAC2B3B9C2B3BAC3B4
BBC3B3B9C3AFB8C1ABBBC4ABBDC6AABEC6A8BEC6A6BFC7A5BDC4A4BDC4A5BDC4A5BEC6A4
BEC5A2BBC6A1BAC59EB7C29BB5C19AA8B48D6F71575E60485B5D46575A45525441464537
3E3C3133312829292024261C22241A1F21191E1F1720221924271D2F322635372A383A2D
383A2D36372C3233292D2E25292A222A2C23282B2220221B1C1E171517121516111A1B14
1919131819141B1E1820231C1C1F1A24292047543E505E46738866697C5E58674F3C4538
434D444E5B5465786A6B806E6F846F6A7E6D627568728876849D83879F84859A81707D6D
2E2B332B29346E7E737282763C414555605A7487725A67593A40394C564665755D61705A
4A564530392F1C201D12131209090A060506050404040301020200171C122B34222C3523
2D35232B3121272C2025291E
6F8088798C9380949C83969E83959E84959F8495A08597A18598A084979F8799A08A9AA3
8B9AA68C9AA78E9DAA8E9EA9909EA993A1AB95A2AD95A2AD96A3AD98A4AE98A6B098A5B1
99A7B29AA8B29AA7B19BA9B29BA9B19BAAB19FAEB1A2AFB2A4AFB0A6B1AFA8B2B0AAB3B3
ABB3B5ABB4B6ABB4B8ACB6B7ACB6B6AEB9B5AFBAB4AFBAB1B1BBB1B3BBB2B3BBB2B5BCB4
B7BEB5B8BEB4B9BFB4BABFB5B8BDB3B8BFB3B8C0AFB8C0AEBBC1B1BCC2B3BBC1B3BCC2B4
BEC5B2BDC6AFBBC4ADBCC7ACBCC8AABBC6A6BDC6A3C0C8A4BEC5A3BEC6A6BEC5A6BEC4A5
BFC6A4BDC6A2BBC5A0BCC7A1BBC6A0BCC7A0AFB8949EA3859BA183A2AA8997A080747761
45413A3F3D3533332A2C2F23292E20292D202A2B1F2B2B202B2C2332332A3F4233434738
3E4337373A3231362D2C2F29282A2624262224282123271E20231A1B1F151C1F161C1D16
1615101A1B1220221723261C21231D1B1D191A1F1823281F313A2B37412F38412F303628
2A2F22272B21343D3045524162765D556550424E415363536B7E69728771748976768778
515A573F48495D6E637C937C56655763736171836D4F594D1C1A1D292A285F6C59546050
3942392A322C1F2420181B170F120F080A08050804050802060902181F113F4F33445439
38442F2D3626282F2224281E
75878C7F929883979F8497A08394A08294A18294A28497A3859AA38599A0889BA28B9DA5
8D9DA88E9CA88E9EAB8FA0AD92A1AE94A2AE95A2AD94A3AC96A4AC98A5AD99A7AF9AA8B3
9BA8B49BA8B39CA9B39EACB59EADB49CABB09EADAFA1B0B0A3B2AFA6B4B0A7B1AEAAB3AF
ABB3B2ACB4B5ADB5B8ADB7B8AEB9B8AEB8B8AFB9B6AFBBB5B1BCB5B1BAB3B2BAB3B4BCB6
B7BFB9B8BDB7B9BFB7BABFB8BABFB5B9C0B3B8C0B2B9C1B0BDC4B2BDC4B3BDC3B3BEC3B2
BFC5B0BEC7AEBFC6AEBEC7AEBCC6AABBC6A8BEC7A6BFCAA6BCC6A5BCC6A6BDC5A6BDC5A5
BFC8A7BFC8A6BDC7A2BFC9A4C0CAA4BFC9A3BEC8A2BEC7A2BBC5A1BCC5A4BAC5A3AAB494
7172625250465355494B4F41454A394449374346364345363F42353D413544493A494F3F
41473A383C34373B353034302C2F2C292C2B2A2E29292D26272B2324282024281E22241C
1919131B1C1521231A24271D21241C1D1F1A181B1617191521261D272B2126291F23251D
2022191F221721261923281C48563E505F4438412E2F3427373E3140483C4751485C6A5F
7387765E6E635464595F71606779646C7E696D7D6C5F6C61414745494F4B5D665B4D534D
616F5E1B1F1F1B201D1116100C100A070A05050804090B060D100A0F130B2833223B4A34
3845333641332F382D242C22
7A8E8E83979986999F8698A28493A28594A68595A88597A88599A7869AA48599A2899BA4
8B9CA78B9DA88C9FAA8DA0AB8E9FAA90A1AD92A2AC90A2A993A5AB96A6AD99A6AE99A7B0
9BA8B29DA9B19DAAB19DAAB19FACB29FACB09FAEAFA2B0B2A2B0B2A3B2B1A4B0AFA7B2AF
AAB4B2ADB5B4ADB5B6ADB7B6ACB7B4ACB6B4ADB7B4AFB9B6AFBAB6AEB9B4AFB9B5B2BBB6
B5BDB8B4BBB7B5BDB8B9BFB9BAC1B7B8BFB5B8BFB4B9C0B3B9C1B2BBC3B4BDC3B5BBC2B3
BBC3B0BDC6B0BEC6B0BDC6AEBCC5ACBBC4A9BCC6A9BDC7A9BCC6A9BCC4A9BCC5A8BDC5A7
BEC6A8BFC8A7BFC9A6C1CBA6BFCAA5BEC8A4BDC7A3BDC7A4BDC6A5BDC6A6BDC5A5BBC6A5
B0BB9B959A82979F868D957C777D676F745E6669566062505154464A4E4145483C434538
3F41353B3C34393935383935373A35383A373437342F322E2F332D2D322B2B3029252922
1B1D18191A151D201821241A21231A1C1E161719121D1F182B2F262D3227292D2221221C
1E1F181B1C15191E141B1F141C2013282E1D2C321F2C3220262A1B2022181D1F19212420
4550434C584B343C38363E38475347576758627564677A6A657567687769626E64323638
48544A242B251F251F0D110D0C10090A0C050A0A040F0F0B0F100D0D0D0C0E0F0F111412
14181528302631392E272E26
7E909384969C8697A28696A58693A68693A98695AB8596AA869AA8879CA4889CA2899DA3
8A9DA58A9EA68CA0A88EA1AA8E9FAA90A0AD91A2AD91A3AB93A5AC96A6AD98A5AD98A5AE
98A4AE98A5AE9CA9B09EAAB09FABB09FAAAF9FABAFA2AFB2A3B0B2A3B0B3A3AEB1A5AFB0
A8B1B2AAB2B4AAB3B3ACB6B4ACB6B5ABB5B5ABB5B4AEB8B6AEB9B7AEB9B7AFB9B7B1BAB8
B2BBB9B3BAB8B4BCB8B8BDB8BAC0B9B9BEB7B9BDB7B9BEB7B9C0B7B9C0B7B8C0B6B8C1B4
B9C2B1BAC4B0BBC4B0BCC7B0BBC6AEBCC6AEBEC6AEBEC4AEBEC4AEBFC6AFC0C7AFC1C6AE
BEC3ACBFC4ABBFC6A9C0C9A8BFC9A6BFC8A7BEC7A8BEC7A9BCC5A8BEC6A8BFC7A9BEC6A8
BCC5A8B8C0A4B7C0A4B5BEA2ADB69A9AA286888F75767B645B5D4D585A4A5051454B4B41
45453C4141393E3C364C5043586150515A4B4C5446393D3230322A2B2D26282A24272924
21231E1C1D181F211923261B21261B1E20181A1B1624261F2A2E262C2F262A2C2225271F
22231C20221A1E21181B1D1314140B13130918190D1F20121E1E1217170E13140D11110C
23261D56664F2F372E242A25212727232B2936413A5262515D6E59576454576556435045
3E4C403F4D3C1E241C0D110C11150F12130C12120D13110F100D0D0C080B0A070A090609
0A060A0E0D10151516202320
80909485949D8595A48596A88595AA8494AB8192A98294A88498A7879CA7879BA5899DA7
8B9EA98DA0AB8DA0AB90A1AB91A0AB93A1AD94A2AF94A4B195A4AF97A6AE98A6AC99A5AC
99A6AD97A4AC9AA7AE9CA9AF9EAAB0A0ACB19FACB1A0ADB1A1AEB0A2AFB1A4AFB2A5AEB1
A7B0B3A8B2B3A9B3B3ACB6B4ADB7B6AEB8BAAEB7B9ADB7B8ADB7B7AFB9B8B2BBBBB3BABA
B4BABBB6BBBCB7BCBCB9BDBDBBBEBEBABEBCBABFBBBABFBBB9BFB9BAC1BBBAC3BABAC3B7
BAC3B4BAC4B3BBC4B3BDC5B3BDC6B3BEC6B4BFC6B5BFC6B5BEC5B4BDC5B2BFC5B2C0C7B1
C2C6B0C2C6B0C0C5ADC2C8ADC0C6A9C1C8ABC1C9ADC1C9AEC0C8AEBFC7ACBEC6AABFC7AA
BEC6ABBEC5ABBCC4A9BBC4A8B9C4A7B5C1A3AEBA9DA4B0938990777D836B7072605F5D53
524F4A4E4D4747483F4B4F425C695366775B6373563A3F2E2D2F2428282022221D20211E
2222202323222628242629242329241E23211D21203740373D473C31372F2C3127292B22
282A202A2D232629201C1D1613130C10100616170A1D1D0E1B1B0C1211090D0C070A0905
0F0F0B3740312B33292127221B211F171E1C1419181E261E293323252C1C272E1E303928
3F4A3847543D1C1F1615171021251B191B151F211A1D1D191412130F0B100D080F0D060D
0D060C0C050E0C0610141217
7C8E9483959E8597A58395A88293AA8293AA8395A98396A88499A8869AA8879BA9899BA9
8C9DAC8FA0AD8F9EAC919FAC92A0AC95A1AF96A2B195A2B196A4B196A5AF97A6AD99A7AD
9BAAAF9BA8AE9CA8AF9BA8AF9EABB19FACB19FACB29FACB2A0ADB4A2AFB6A4AFB5A4AFB4
A8B1B5A8B3B6A8B4B4AAB6B5ACB6B6AEB7B8AFB8BBAEB8BAAFB9B8AFBAB7B2BAB9B5BBBA
B6BBBAB7BBBBB9BCBEBBBFC1BCC0C2BBC0C0BBBFBFBABFBEB9BEBBBAC0BBB9C0BABBC3B8
BFC8B8BCC4B4BCC3B2BDC3B3BDC4B4BDC4B4BDC4B5C0C6B7BFC7B7BEC8B7BEC7B6BEC6B4
C0C6B3C3C8B3C2C6B0C3C7AEC1C7ABC1C8ADC2C8AFC2C9B0C2C9B1C0C7AEBFC7ACC0C8AB
C0C8ACC0C7AEBFC6ADBDC5ABBDC6ACBCC6ABBAC5A9B9C5A7B4BFA3ADB69BA6AF958B907D
6C6D6358575155554D494A4242453B494E3F454C3C353A2E2E3429282C232426201F211E
202220272A272B2F2A2B302B2A2F2B2629282427283B443D434E44353E36333B3230372D
2F352B2E342A2528221C1D1A12111010100A15160D1B1D101C1E1017190E10100A0D0C07
0C0B0711100C161913161A16141816111513111612171E16192015171E10171D0E161A0D
1A1C112225181C1F151D221721261C1B1E162E34273136282B2F2325271E26241F26231E
1F1919191316140F15110D15
7A8D9381959D8396A48598A88394A88293A88495A98597AA8496AB8598AC889AAE8A9BAF
8C9DAF8FA0AE91A1AE929FAD939FAE94A0AF95A1B195A2B096A4B097A5B098A5AF99A7AF
9BA9B09BA9AF9EABB09EAAB0A0ABB2A1ADB3A3AFB6A2ADB6A2ADB9A3AEBBA3AEBAA3AEB7
A4B1B8A5B2B8A6B4B8A8B6B8AAB5B8ACB5B9ACB5BAADB5BBAFB7BDAFB7BBB1B9BCB4BABD
B5B9BCB5BABDB6BCC0B8BEC0B9BEBFB9BFBFB9C0BFB8C0BDB8BFBBBCC2BBBBC0B8BCC2B7
BFC6B7BDC5B5BDC4B4BEC5B2BCC4B1BDC5B2BDC3B4BEC4B5BFC7B7BFC7B8BFC7B7BEC6B3
C0C6B1C3C7B0C3C7ADC3C6ABC3C7ABC3C7ADC2C7AFC4C8B2C3C8B2C3C8B1C2C8AEC1C6AB
C3C8ACC3C8ADC2C7AEBFC5AFBDC4ADBDC5ADBDC5ABBCC5AABAC3A9BAC3A8B9C3A6B5C0A3
A4AE957F837575796A61635752534B4E4F4544463C3B3E3533362F2B2D29292927232524
2527262B2F2B2E342D2F352C2D322A2E30292E2E2A2F302D2F322F2E332D2E332B2F352B
31392D2E362C282E272326231E1F1D1B1D181E211A1F241A1B2115161B1110130D0E1109
0D100811120B151811181C161519150F13100F130E131810151A1013180C13160B12140B
10120912140C141810181C15171B15181B161E23192C3322303720282D162B2C1732301F
302D212A261F2C2C26282A24
7C8E9081939882959F8495A48293A48595A68796A88797AA8595AB8495AC8597AD8899AF
899CAE8DA0AD8FA1AD8F9FAD909FAD91A0B092A0B092A0AF95A3B299A5B39AA6B59CA7B6
9AA7B69AA8B49DAAB29FABB1A1ABB2A1ACB3A1ADB4A2ACB5A1ABB6A2ACBAA3ACBBA3AEBB
A4B0BCA5B1BCA5B1BBA7B2BCAAB4BDABB4BCACB4BDAEB5BEAEB5BFAFB7BFB1B8BFB3BBBF
B4BCBEB5BDC0B6BDC1B6BEBFB5BDBDB4BDBCB6C0BDB6BFBDB6BEBCB9C1BDB8BFB9B9BEB7
BCC2B6BCC3B6BDC5B7BFC5B7BDC3B4BEC4B5BCC2B5BCC3B5BFC6B8C0C6B9C0C6B9C1C7B7
C3C9B3C3C8B0C3C8AFC4C9ADC4C8ACC3C7ABC3C7AEC4C8B1C4C8B2C3C6B2C4C7B0C2C6AE
C3C7AFC3C7B0C3C7B0C2C6B1C2C6B2C0C5B1BFC6AFBFC5ACBEC3A9BDC5A8BDC6A6BAC5A6
B7C2A5B0BBA0AAB49B9AA38D80867570746557595051544A3E3E393736333230312C2B2C
292829292A2A2C2E2C2D302D2D302B2E302931332A2B2C2427282124261F24261F272B22
2B3026292E25282D25272C252529232429222E3729262F231C241915191210120E0C0F0A
0B0E0910130E151913181D17171C1513181112170F161C11151B1013170C0F130A0E110A
0D120A0C0F070B0F0710120B0F100B1619111B1E14202516272B181E1E0D40442A211C13
38352E44473E2324212A3128
788B8F8092998293A08395A48395A48495A48696A58697A78495A78497AA879AAB899CAC
889CAC899EAB8A9DAA8C9EAB8D9EAC8FA0AF8F9FB090A0B194A2B397A5B399A5B598A3B4
98A3B59AA7B69CAAB59DAAB39EABB39EABB59EACB5A0ADB5A2AEB6A4AFBAA5B0BBA4AFBB
A4B0BDA5B1BDA5B1BDA7B2BDA9B2BDACB4BEADB5BEAFB7BFAFB6BFB0B8C1AEB7BFAFB9BF
B2BBC0B3BCC0B3BCC0B4BCBEB5BDBEB4BDBCB4BCBAB5BDBBB4BDBBB6BFBBB7C0B9B8C0B8
BBC2B7BDC2B8BEC3BBC0C5BDBFC4BCBDC2B9BEC4BABDC2B9BEC3B9BFC4B9BEC3B8BFC5B6
C2C7B5C2C8B3C0C7AFC2C9AEC3C9ACC3C8ACC4C7AFC2C6B0C3C7B1C1C5B1C3C8B2C2C6B2
C1C6B2C0C5B1C2C5B0C2C6B1C3C6B4C2C5B3C1C4B0C0C4AEBFC5ACBDC4AABEC6A9BCC4A7
BBC3A9B9C3A9B5C0A7B3BFA7B1BCA5A0AA968E96857E84765F605852504B43413E3B3835
38343035302E312D2C312D2C2D2A292927242B2A252B2B2527272124241F23251F22271E
20231C20231C232820252D24232B21232C212F3B292934231B2317141A1111150E10120D
10120B12160E171B12191E14191E14181D12171E121B2215191F13181E1212170F0D120C
0D120D0C100B070B04080B04090A040A09040B09040E0D0614150B14130A2D31201A1910
363A2E5C6A51171A131A1F16
798C9381959E8497A48396A58497A88496A68395A58495A78396A88598A98699A8879CA9
889CAA899DAB899CAA8A9CAA8C9EAC8E9FAF909EB192A0B493A0B496A3B497A5B498A5B5
98A5B59AA7B59BA9B49BAAB49DABB59EABB59EABB6A1ADB8A3B0B9A4B0B9A5B0B9A4AFB8
A4B0BAA3AFBAA5B0BAA8B2BCA8B1BCABB3BDADB6C0ACB5BEACB5BCACB6BDACB6BCAEB7BE
AFB7BEAFB8BDB1B9BEB3B9BDB3B9BDB4BCBEB4BCBEB5BDBDB4BBBCB6BEBCB8BFBBB9BFBA
BABEBABABEB9BBC0BBBCC2BBBDC3BCBEC5BDBDC5BCBCC2BCBDC2BBBCC2BABDC3B9BDC3B6
BBC1B1BDC3B0BDC4B1BEC5B1C0C6AEC1C6AEC1C6AEC0C4AFC0C5B1BFC5B2C0C6B1C1C6B1
C1C7B2C1C5B1C1C6B2C0C5B2C2C6B4C3C6B3C0C3AFBFC2B0BFC3B1BDC3ADBCC3ABBBC3A9
BCC4ACBBC6ACB7C2A8B5BFA8B6BFA8B6BFA8B5C0A7ACB7A09DA5928E97826F7361595B4B
535242474338423D35403B3437332D302D272D2A2629252224211E22211D242721232821
20261C1E24191D25191E251A212A1C212A1A1F2917212A181D2414191F11171D10151A0E
14190E171A10171A0F191C121A1E14181E14191F151C23181C23171A2217141E130E160D
0D140C0C120B0A0F06080B040809040808030707030705030607020608010709000E1205
161A0A1E24101E230F181B0B
7D919882969F8498A48497A78597AA8598AA8396A88497A98499A8869AA88699A7869AA7
889DAA8A9FAC8CA1AD8DA0AD8FA2AF90A0B092A0B393A1B693A1B594A2B495A3B399A7B7
9AA7B89AA8B69CABB69DACB5A0AEB6A2AFB6A2ADB7A2ADB8A3ADB9A6B1BAA8B3BAA7B3BA
A8B3BCA7B2BBA7B2BBA9B4BDAAB4BDABB6BEAAB4BFAAB5C1ABB6C0ACB6BEADB7BFB0B8C0
B1B8C0B1B7BFB2B9BFB4B9C0B5BBC1B5BCC1B3BDC0B3BDC0B4BCBFB8C0C1B8BFBFB8BDBE
B9BFBDB9BFBCBAC1BBBBC2BBBAC2BAB9C2BAB9C1BABBC1BDBEC4BEBDC3BDBCC2BDBEC3BD
BEC3B9BDC3B6BDC3B5BFC5B7BFC6B4C0C8B3C0C8B1BFC7B0C1C8B2C1C7B2C1C6B1C2C7B3
C3C8B4C4C8B5C0C5B4C0C5B4C2C6B4C2C7B5C0C4B3C0C5B4BFC4B3C0C5B0BFC5B0BFC7B0
BEC6AFBDC6AEBCC4ACBBC2ABBBC2ABBBC1AABAC2AAB7BFAAB7BFACB3BEA8A7B19B919885
8085736666595755494F4C404746393E3D3237362D2D2B25282621252521222320212420
20261F1C231A191F15171D131B23171A2113181E0F1E24131F25161F24171E23171C2318
1B2218191F16161B12171B111A20141C23151F26171E26161D27161B2515192214161F11
131D0E11180B0F15070C11050D0F060C0D040B0B040A0A05070904060902060901080C00
0C10021216061113050B0A01
798B957F929E8396A58497AB8395AC8599AE8599AC859AAA8498A7869AA9899CAB889CAA
8A9EAB8CA0AA8FA3AE8FA2AE8EA0AF90A0B291A2B492A3B593A3B494A5B496A6B498A7B4
9AA9B69BAAB69DACB69EADB5A0AEB6A4B0B9A4B0B9A3ADB9A4AFBAA7B2BBA8B3BAA8B4BB
A9B5BDAAB5BEABB6BFAAB6BFABB8BFABB9BFA9B6BDAAB6C0AEB9C3AEB9C2AEB7C0B0B8C1
B2B9C1B3B8BFB3B9C0B5BAC1B7BDC3B6BCC4B5BBC4B8BFC5B8C1C4BAC2C2B9C1BFB8BFBF
B8BFBEB8C0BDBAC3BDBBC4BDB9C2BABAC3BABCC2BBBEC5BEBEC4BFBFC4C0BFC4C0C1C5C3
BFC4C0BFC5BCC2C8BDC1C7BCC0C7B9C0C8B8C1CAB6C3CAB4C4CBB5C4CBB6C2C9B5C1C8B5
C1C7B6C1C7B8C0C7B8C0C7B9C0C7B8C1C8B8BFC5B6BFC5B5C0C6B5C1C6B3C3C8B5C2C7B5
C0C6B5C1C6B5C1C6B2C1C6B0C1C6B1BFC5AFBEC5ADBDC4AEBDC4B0BBC2AFB9C0ADB5BCAA
AFB8A6A1A997858A7A696D5E5C605050524643443D3A3A3537383234342E2F2F2B282927
2425252023221B201E191D191B2019191F18171D141A20151E251920261A1D241A1D231A
1E251B1E261A1C24171D25161F2715212A15232C17212A152029131E26121D25141C2314
1B22121A210E181E0D181C0D15190C13140A13140A11120A0D0F090B0F080B0F080C1008
0B0F070E12080F10090C0B05
7789957E909E8294A78394AC8192AC8495AD8296A98396A78397A58698A6899AA88A9CA9
899BA88B9DA88FA1AD90A1AE8E9EAE8D9DB08E9EB18FA1B291A3B192A4B095A5B196A5B0
98A8B398A9B499AAB49CABB49FADB5A0ACB7A2ADB8A1ACB6A3ADB7A6B0B9A8B1BAA8B1BA
A9B3BBA8B2BCA9B3BDA9B5BFAAB6BDA9B6BBA9B5BAACB6BCAEB7BEB0B8BFB2B9C1B3B9C1
B2B9C1B3B8C0B5BAC1B6B9C0B7BAC1B5B8C1B6B9C1B7BDC1B8BEC0B9BFC0B9BFBEB9BFBE
B9BFBEB9C0BEBAC2BFBAC1BDBAC0BABBC1B9BCC1B8BDC2B9BDC2BBBDC1BBBDC1BCBFC2BE
BFC3BDC1C4BCC0C4BAC0C4BAC0C6B9BFC5B6BFC6B3C1C7B2C3C6B4C3C8B6C2C7B6C0C6B7
BFC5B8BEC4BABFC5BBBFC7BABFC6B8BFC6B7C0C6B7BFC5B5BFC5B2C1C6B1C3C7B2C3C6B4
C1C4B4C1C5B4C1C6B2C1C5B0C0C5B0BEC4AFBEC3AEBCC1AEBBC1B0BAC1B0B9BFAFB8BEAE
B6BDAEB6BDADAFB5A7A3AA9C90968B7A7D7662645F54554F494A413E3F3534332E2C2A29
252125201D221B1A1F1D1F211D211F181C1A1114120F12100F131011151010150E12160F
14191013190E151B11141B0D131A0A141B09161E0B171E0A161D0A161C08161C09161C0B
141A08131807161D0A171C0C16190C14150B13140C0F100A0C0E0A090C09090C0A0B0F0B
0B0E0A0B0D0B0B0D0B0A0A07
7689947E909D8293A38494A98192AA7E8FA87F92A78094A58396A48598A58799A68798A7
8698A8879AA88A9CA98C9CAA909EAD8E9CAD8E9DB08D9EB190A1B293A4B293A3B095A4B1
96A5B595A5B498A8B49DABB69EABB69EA9B79FA8B7A0A9B6A1ABB6A2ADB5A5ADB7A7AEB7
A7B0BAA7B1BCA6B0BCA8B2BDA9B3BEA9B4BEABB5BEACB4BDAFB6BDB1B7BCB1B7BEB2B9C0
B2B8C0B3B9C1B4B9C1B4B9BEB7BCC1B6BAC2B4B9C0B3B9BEB4BABEB6BCBFB6BDBDB6BDBE
B6BDBDB5BCBCB7BCBEB8BCBEB9BDBCBABDBAB9BEB9BBC0BBBCC1BCBEC2BDBEC1BEBFC0BD
C0C1BDC0C2BDBFC1BBC0C3BCBFC3BABEC3B8C1C6B7C1C5B4C1C5B4C1C6B5BFC5B4BEC5B5
BEC4B6BCC2B8BCC2B8BEC5B7C1C6B8BFC4B6BFC4B6BEC4B4BDC3B1BFC5B0C1C5AFC0C2AF
BFC2B0C0C5B2BFC3B1BFC3B0BEC2B1BBC1B0BBC0B0BABFAFB8BDADB9BDAEB9BEAFB9BEB2
B8BCB1B6BBAEB5B9ACB3B7AAB1B7AAA8AFA39FA799939B8B858E7B585A4E3D3938373235
2B232D231B281D18241E1B241E1C241B1C2015161B1012170E11130C0F0E0A0D090E120A
10140B0C12090C13090B12070E1608131C09131C07131B04111801141C03181F06151A06
1315040F110210120411120610110810100B0F110D0E100D0A0C0A070906080A070D100C
0B0E0C0A0C0B0C0E0C0C0C09
748A917A8F987F929F8192A48091A77E8FA87E91A97E91A68195A58396A68597AA8799AC
8799AC879AAB899AAA8A9AA98C9CAB8D9CAD8F9EAF8E9FB18E9FB391A1B591A1B394A1B3
94A1B395A3B498A5B59BA9B79EAAB79EA9B69FA8B7A0A9B8A0A9B6A1AAB4A3ABB3A6AEB6
A8B0BAA8B1BCA8B1BDAAB2C0AAB3C2A9B1C1AAB2C1ACB2C2AFB5C2AFB5C0B1B7BFB2B8C1
B2B8C1B3B8C2B2B8C1B3B8C0B6BAC2B7BBC4B4BAC3B3B8C0B2B8C0B2B7BFB4B9BFB4BAC0
B5BCC1B4BBBFB5BABEB6BBBFB9BEC1B8BDBEB8BCBCB9BCBCBCBEBCBDBFBEBFBFC0BEBDC0
BFBEBFC0BFC0C0BFC0C0C0C0C0C1BFBEC0BDBEC1BDC0C3BDC0C5BDBFC5BCBDC2BABDC2BA
BCC2B7BEC3B7BDC0B5BEC2B5C2C5B7C2C5B7C0C3B5BFC2B4BEC3B3BEC3B2C2C5B3C2C4B4
C0C3B5BFC3B6BDC1B6BBC1B5BBC1B5BABFB4BAC0B4BAC0B2B9BEB1B8BDB0B9BDB1BABFB3
B7BDB2B7BCB1B6BBB0B3B8AEB2B9AFB2B9B0AFB7ADADB5AAA8B3A59AA29768666C534F5A
383042282032261F2C211B251D171F17131A1713191414181114161013121114110F140F
0F130E0D120D090E09060C060A1108131C0C121C08121C06121B03121C03141C05141A05
1216051214071214071111060F0F0811110A12120C10120B0C0E080A0D060A0C060D110B
0D100C0C0E0C0E0F0E0F0F0D
768C937C929A7F949F8194A27F91A37F91A47E90A58193A88395A98294A88595AB8999AF
8A99B08B9BB08A9AAD8A98AC8C9AAE8F9CAF909DAF929FB293A1B495A2B595A3B594A2B3
94A2B295A3B397A4B49AA7B69CA9B79DA8B89EA7B9A0A6BAA2A8B9A4A9B9A3A8B7A7ACB9
ABB0BEABB1C0AAB1C0ABB2C0ADB4C1ACB3C1ADB3C4AFB5C6AFB4C4AEB3C2B1B5C1B3B7C2
B3B6C1B3B6C1B3B7C1B4B8C1B5B7C0B6BAC2B5BAC2B3B9C1B4BAC2B5B9C2B5B9C1B6BBC3
B8BEC5B7BCC4B6BAC2B6BAC0B8BDC0BABEC0BBBFBFBBBEBDBBBFBBBCBEBCBFC0BEBFBEBE
BEBEBFBEBCBEC0BFC0C0BEC1C0BEC0C0BFBFBEBFBFBFC0BFBFC1C0BFC2BFBCC1BCBCC1BB
BCC1B9BDC0B6BFC0B6C0C1B6C1C2B5C1C3B5C1C3B5C1C4B5C1C4B3C0C3B2C2C3B3C0C2B1
BFC0B2BFC0B6BDBFB8BABEB7BBC1B9BBC0B7BABFB5BABFB1BABFB1B9BEB0B8BEAEB8BEAC
B9BEAEB8BEAFB8BDAEB6BAAEB3B8ADB4B9B0B2B8AEAFB6ABAEB5ABADB6ADA2AAA498A19A
616268332E3B3B363B31292B271E2222191D1E181A191518181718181819171817121313
1214141012120C0C0D0B0B0B0D100D12170F141A0E141B0D121B0B0F1807101806141C08
131A09151A0C15190D15170C12130A12120A11110A12130B1012090D10060C0F050D0F07
0F100B10100D0F100E0F100D
7487937D919D7E91A08094A57E91A47D8FA17E90A38092A68193A88293A98494AC8796AF
8795AF8A98AF8B9AB18B9BB08D9AB08F9AB1919CB2929EB395A1B596A1B595A1B595A2B4
98A5B698A4B49AA6B599A5B499A4B49BA6B79DA6B99FA6BAA2A7BBA5A8BCA6A9BDA7AABE
A8ABBEA9ADC0ABAFC2ACB1C2ADB4C1ADB4C2AEB4C3AFB4C4AEB4C4AFB5C3AEB4C1B0B5C1
B1B6BFB2B6BFB3B7BFB2B5BFB2B6BEB4B8C0B4B9C0B2B8C0B4B9C1B6BAC1B7B9C1B7B9C1
B8BBC1B8BBC1B7BAC0B7B9C0B7BABEB8BCBEBABEBDBABEBABABFB9BCC0BABCC0B9BDBFB9
BCBEB9B9B9B6BEBEBABEBFBBBEBEBBBDBDBBBEBFBDBEC0BEBDBFBEBCBFBDBCC0BBBBBFB9
BBC0B7BCC0B4BEC1B5BFC0B4C0C0B6C0C1B7BEC1B6BDC2B4BFC2B3BFC2B1BFC1AFBDBFAD
BCBEAEBDBEB1BCBEB5BABFB7B9C0B7B9C0B7BAC1B5BAC0B3B9BEB1B8BCAFB7BCADB8BDAC
B8BFACB9BFABB9BEABB7BDADB7BCAFB6BAAEB4BAACB3B7AAB2B7ACAFB5ACADB5ABABB4A8
A0AA9D7C80766C6D6233292B3127282C2123251D1E1F17191C16171B17171B1716181414
151012141012130F110D0B0C0E0E0D141611171D13171D11171E11161D0E171E0D161D0C
13190B141A0D14190E13180C12150C0F120B0F110C11140D12150B0F13070B0E030B0B02
0C0C040D0D050C0D060E1008
7586937A8C9C7D8FA27D8FA57C8DA47B8CA27D8FA57F91A78092A88192AA8494AC8695AD
8795AF8A99B18998AF8B9AB28E9CB48F9DB4909DB4909DB4929FB694A1B795A1B994A0B7
96A1B797A3B698A4B697A3B399A5B59AA7B79DA8BA9EA7BCA1A9BDA3A8BDA5ABBFA5A9BF
A5A9C0A5AAC0A6ABC0A8ADC0A9AFC1AAB2C2ABB2C2ACB4C4ADB4C4AEB5C3ACB5C1AEB7C1
B0B9C3B0B9C1B0B8C0B1B8C0B1B7BFB2B9BEB2B9BDB2B9BFB3B9C1B4BAC2B5B8C1B6B9C2
B8BAC3B7B9C2B8BAC1B8BAC0B7BABFB7BCBEB8BFBEB8C0BBB7BEB8B8BEB9B8BEB8B9BFB7
B9BFB8BABEBABBBFBBBAC0BCBBC0BDBBBEBABBBFBABBC1BEBCC1C1BBC1BFBAC1BCB9BFB9
B9BFB8BBC1B9BCC2B9BDC0B9BFC0BABFC0BCBCBEBABBBFBABBC0B8BDC2B6BEC1B4BDC0B4
BCC1B4BBBFB5BCC0B9BCC2BBB9C0BBB8C0B9B7C0B7B6BEB6B7BCB5B7BBB4B6B9B2B6BAB1
B6BAAFB7BCAFB6BBAEB5B9AFB4BBB1B4BAB1B2B9AFB2B7AEB1B6AFAFB5B0ADB4AEABB2AB
AAB4A8A9B3A4A0A999534D4D382F31332B2C2E2526271E1F251D1E221A1D1E171A1A1517
191316171419161315100F0F0C0D0B0F120B13180D171D111A21131C23131B2111171D0D
141A0D141A0F12180E11160C10140C0D110A0F140C11150F0F140A0F13080E11060E1005
0E10050E0F040E10040F1105
7889967C8E9E7E91A67D8FA87D8FA87B8CA77E90A78092A78092A68091A78494AB8694AC
8795AC8A99AF8897AD8998AD8C9AB08E9DB38F9EB48E9EB48F9EB491A0B692A0B7929FB7
93A0B8939FB794A0B695A2B599A5B69AA6B798A3B897A3B79CA6BAA0A9BBA1A9BBA3AABD
A4A9BFA4AAC0A4AAC0A5ACC0A6ADC0A6AFC0A8B0C2ABB3C3AAB2C3ABB2C2AAB3C1ACB5C1
AEB7C3B0B8C2AFB8BEB1B8BDB2B8BEB2B9BFB1B8BDB0B8BEB0B8BEB1B9C1B1B9C1B2B9C2
B4BAC3B3B9C3B4B9C1B6BAC2B5BAC2B3B9BFB5BCBFB5BDBDB5BCBBB5BBBAB6BDBCB6BEBD
B6BEBDB6BCBBB7BDBBB8BDBCB9BFBDB9BEBCBABEBDB9BEBDBABFC0BABFC1B8BFBEB8C0BC
B7BFBAB8BFBAB8BDB9B9BDBABCBDBDBBBCBEBABDBFBABDBFB9BDBDB9BDBAB9BDB8B8BCB7
B9BCB7B9BDBAB9BDBAB8BFBCB9BFBEBAC0BDB8BFBAB6BDB8B7BBB6B8BCB6B7BCB5B6BDB6
B5BCB3B5BDB3B4BCB2B3BBB2B3BCB3B2BBB3B1B9B3B1B8B2AEB5B0ABB3AFAAB2AEA8B1AC
A8B2ABA6B0A9A7B2A88F958E6564653C353B3A3233352E2F2F282C272028201B24252229
28262B1A192215161D0F11130B0D0D0B0D0B0E120C141811181E161B21171B2016171B11
161A11161A141015100E120D0F130D10140D11160F12160F0F130B0D11080D10090D1009
0E12090E12080C0E04070801
7686997A8BA07C8DA77D8EAA7D8DAB7B8AAA7C8DA87E8FA87E8FA78190A78492A98A97AE
8A97AF8997AE8B9AAF8D9BAF8E9CAF8E9BB08E9CB3909FB68F9FB58FA0B492A1B694A2B8
94A1B9939FB8939EB795A0B598A3B79AA5B99AA5B998A4B99BA6BB9DA7BAA0A7B9A1A8BB
A2A7BEA6ABC2A4ACC4A3ABC2A3ACC0A3ACBEA5AEBEA7AFBFA8B0C0A9B2C0A9B4C1ABB6C1
ACB4BEADB4BEB0B6BEB2B7BFB2B6BCB2B5BDB2B6BEB1B7C0B0B7C2B0B8C3B0B9C2B1B7C2
B2B8C3B0B7C3B0B6C1B1B8C0B4B9C2B3BAC3B4BAC2B4BBC0B4BCBFB5BCC0B6BEC1B6BEC2
B5BCC0B6BCBDB7BCBBB8BBB9B9BCB9B9BDBBB9BCBBBABCBABBBCBCBABEBEB9BEC0B7BEBF
B6BEBCB6BEBAB7BDBBB9BDBCB9BCBDB9BDBEBABDBDB9BDBDB8BBBDB8BBBBBABDBCB8BBB9
B8BCB7BABDB9B9BCBAB7BBBAB6BABBB7BBBBB8BCBAB7BBB7B7BBB4B7BBB3B4BBB1B2BBB0
B2BBB1B3BCB3B2BCB4B1BBB1B1BBB1B0B8AFB0B8B1B1B9B3B1B9B1AEB7AFADB4ACAAB1AC
A9B2ADA8B2ADA7B1ACA6B0A99BA59D6F7271504D514D4B4D48454935313A28252F2A2B31
2B2D321E20271B1E24181B1C13161410141011140F141711171B151D1F191C1D19191914
1919131A1D1816191615181314171214180F1419101519111215100E110C0C0F0B0F120F
1115100D110C080B06040501
7282997787A17C8CA87C8CAB7D8CAB7D8DAB7D8EA87C8DA47D8EA38090A28391A38795A9
8996AC8694A88796A78B9BAB8E9BAD8C99AF8C99B28D9CB58E9DB48F9EB2919EB3939FB4
95A0B6959FB7959FB697A1B599A3B498A1B599A3B79DA7BC9EA8BC9DA7B9A0A8BAA1A7B9
A2A8BBA4AABFA3ABC1A2ABC1A2ABC1A2ACBEA5AEBEA6AFBFA8B1C0A8B0BEA9B2BDACB4BE
ADB5BEAFB6BFB0B6BFB1B4BEB1B3BCB2B3BDB4B5BFB2B6C0B1B7C0B2B7C1B3B9C2B4B8C3
B5B7C4B3B7C4B0B8C5AFB6C1B0B7C0B1B7C0B2BBC3B2B9C1B2B9C0B3BBC0B4BBBFB4BBBF
B4B8BCB5B8BAB7BAB8B9BAB8BABBB9BABABBBABABBBBBBBBBABABAB9BABCB9BCBFB6BABC
B4B9B8B4BBB8B6BCBBB6BBBCB7BBBEB8BDBFB8BCBDB9BDBDB8BABBB7B9B9B8BBB9B8BAB7
B8BBB7B8BBB6B8BAB6B8B9B7B8B9B8B8BAB9B6B8B6B6B9B5B5B8B3B4B9B3B2B9B2B0B8B0
B1B8B0B1B9B1B1B9B1B1BAAFB1B9AEB0B8ADAFB7ACB0B6ADB0B6B0AEB5B0ADB5ADAAB1AC
A9B0ADA7B0ACA6AFAAA6B0AAA7B1AAA0A9A48C9094898E92838B8C575D6230333B252A2E
22262A1F21261D1F221D201C24281C1D20141A1B1117180F1818121A18141C1A161D1A17
1D1C191E1F1C1B1D1A1A1C18191B17151813151811171C141317111114100D0F0E0D1110
0F13110D100D070906010201
7384977889A07A8BA67A8AA87B8BAA7C8DAA7C8DA87C8EA67E8EA57E8FA38192A38495A4
8595A68695A78594A68896A98998AC8896AE8A98B18C9AB18D9DB18E9EB1919FB2939EB2
959FB498A1B79AA4B899A3B69AA2B59AA2B799A1B89AA5BB9BA7BA9BA6B99EA6BAA1A9BA
A2A9BCA1A8BEA0A8BFA1A9C0A1A9C0A3ABC0A4ACBFA5AEC0A7B0C0A6B0BDA7B1BDAAB2BE
ACB4BEADB5BFAFB5BEB1B6BFB1B5BEB2B6BFB1B5BEB1B6BFB2B5BFB2B6BFB2B6C0B5B7C2
B6B8C2B3B7C2B2B8C3AFB7C1AFB7C0AFB6C0B0B9C0B0B9C0B2BAC0B2BABEB3BABDB4BCBE
B5BBBFB6B9BDB6B9BBB8BABDB8BABDB6B8BDB7B7BDB9B9BDB9B9BCB8BABBB6BBBCB6BBBB
B4B9BAB3B9BBB3BABCB4BBBDB5BABDB5BABEB7BBBEB7BBBDB6BBBBB5B9BBB3B8BAB4B8B8
B5BAB8B7BBB9B8BBB8B8BAB8B8B8B7B8B9B8B5B6B5B5B6B4B4B5B4B4B8B6B2BAB6B0B7B4
B0B8B2AFB9B2AEB8B1AFB8B1AEB7AFAFB6AEAEB4ADAFB6B1AEB4B4ADB3B4ABB3B2AAB2B0
A9B1B0A7B0AFA5AEAEA5AEACA4ACABA3ABABA4ACAEA1ABAE9DAAAB91A3A04C545D262A37
292E3623282E1F23261E231E23271B25281B2427192022161C1D171B17161C18161F1E1A
1F201C1F211C1D211D1D211B1A1E1A171C18171C16191E17161B141318110F120E0A0D0B
0A0D09080A07040503010201
748796788C9F7B8CA67A8BA77B8CA87B8CA77C8DA67D8DA77F8EA88192A98294A88395A7
8495A68594A78795A98896AB8796A98896AB8A98AD8C9AAF8D9CB08D9CAF8E9CB0919DB2
939FB597A2B797A1B697A1B798A2B89BA4BA97A1BA98A3BA99A4BA9AA5B99CA7B89EA8B9
A0A9BB9EA6BBA0A8BCA1A9BFA4ABC1A5ABC2A4ABC1A7AEC3A9B0C4A9B0C3A9B1C2A9B1C1
AAB1C0ACB3C2ADB4C1AFB4C0B0B5BFAFB6BFAEB5BDAEB6BDB0B6BDB1B5BDB1B6BEB3B7BF
B2B6BEB1B6BCB0B5BCB0B6BCAEB5BCADB6BEAEB7BFAFB8BFAFB8BFB0B7BDB2BABCB2BBBD
B4BBBEB5BBBFB4B9BDB4B9BEB4B9BEB2B7BEB3B6BDB5B7BEB6B9BEB6BABEB4BABEB4BBBD
B4BABDB4B9BEB4B8BCB5B9BDB7BABDB6B9BCB5B9BDB5B9BCB2B8BAB1B8B8B1B8B7B2B9B9
B5BBBAB7BDBBB8BDBCB8BBBCB7BABAB7B9B9B5B7B7B3B5B5B2B5B6B2B6B7B0B7B9B0B8B8
AFB8B6AFB9B6AEB8B4AEB6B3AEB5B3AFB5B4AEB4B2AEB5B2ACB3B3ACB3B4A9B1B2A7AFB1
A6B0B1A5AFB2A4AFB1A4AEAEA3ACACA1AAABA3ACACA0ACAA9DAAAA9BAAA9879697697379
4A505A393D492D2F3D2B2E38484F4D5964583539362C2E2D2121231A161B1813181C1B1A
1E1F1A1F221B1C221A1A2019181E18161B17171B16171C14161B1212160F0B0E0A080907
080806060504040201040100
7589977A8FA07C8FA67D8FA97C8CA77B8BA67E8DA6828FA98390AB8290AB8293AC8191A9
8292A78492A88694AC8796AE8898B08899B08798AF8A9AB08C9CB28C9AB28D9BB48E9DB5
8F9DB4929FB594A1B695A2B896A2BA97A3BB96A2BB98A4BB98A4B998A4B89BA7B89EA8B9
9FA9BA9FA8B99FA8BAA1AABEA1AAC2A3AAC4A4ABC5A4ABC3A5ADC2A7AFC3A7AEC2A9B0C3
A9B1C4A9B1C3AAB3C3ACB3C3AEB5C3AEB5C3ADB6BFADB6BCAEB6BBAFB6BBAFB6BDB1B7BE
B0B6BEAFB6BBAEB3BBAFB3BCB0B5BEAFB6BFAFB6BFB0B6C0B0B6C0B0B6BFB1B8BFB0B8BE
AFB7BBB0B8BCAFB7BCAFB6BCAFB7BCAFB8BDB1B9BEB4BABFB4B9C0B5BAC2B3B9C0B2B9BF
B4B9BEB5B8BDB4B7BCB4B7BBB4B8BAB4BABBB4B9BCB5BABCB2B8BAB1B7B8B2B8B7B4BAB8
B4BABAB5B9BCB6BABCB4B9BCB3B9BBB5B9BAB5B8BAB3B7B9B3B7BBB1B5BAAFB4B9AFB4B9
AEB5B8ACB5B7AEB6B7AFB8B8AFB5B7AFB5B6AEB5B5ABB3B3A9B1B1A8B1AFA7B0B0A7B0B1
A5AFB0A6B0B2A7B2B2A6B1B1A4AFAFA0ABACA0ABABA0ABAB9FADAD9CABAB9BA8A899A6A5
879295767E865E617157596B848F918A97936B747568736E36373A150E1A18131D141218
12101314131215161214151213161313141014151014160E12150A0E0F07070703090705
0C0B070A0806070503070403
718095798AA17B8CA67C8DA87B8CA87A8AA77E8CA8808DA9818DAB828EAA828FAB818EA9
818EA88390AA8492AE8493B08596B28697B38798B08A9AB08C9CB38B99B38D9AB68E9AB5
8F9BB5909CB5929DB595A0B996A1BC96A1BD98A3BD99A4BD99A4BB99A3B99AA4BA9DA6BA
9FA7BBA0A8BDA1A8BFA2AAC19FA8C2A0A8C4A1ABC4A1ABC3A2ABC1A5ADC2A5AEC3A7AFC4
A7AEC4A6AEC3A9B1C4ABB2C4ADB4C4ACB4C1ADB6C0ADB6BEACB5BBAEB6BDACB4BDADB5BE
ACB4BDADB3BDAFB4BDB0B5BFB0B5C0B0B5C0B0B5BFB1B6BEB1B5BDB2B5BDB3B7BEB1B5BD
AFB6BCAFB7BCB0B8BEB0B7BDB0B7BBAFB8BBB1B8BBB3BABDB3B9BDB4B9BFB3B8BFB2B7BF
B3B7BFB3B5BCB3B4BCB3B5BBB3B7BAB4B9BAB5B9BAB5B8BAB4B7BAB4B9BCB5BCBAB5BAB8
B5BABAB5B9BCB3B7BBB3B7BCB3B7BBB4B7BAB3B6BAB3B4BAB4B6BCB1B5BAB0B4BBAFB4BB
ADB4B9ACB5B7AEB6B5B0B8B4B0B7B3B0B6B1AEB4B1ACB3B1A8B1AFA8B1AFA8B1B1A8B1B4
A7AFB3A8B0B4A8B0B4A5AFB2A4ADB1A2AAAFA0A9ADA0ABAF9FABAF9EAAAE9BA6AB9BA6AB
9AA4AB9AA4AA949CA38F989E919A9E929D9D919D9B92A09970797424212D1D192618141F
15131A0F0C121311131D1C1A19171616161114150C15150C12120B0E0D090A09060A0A06
0D0D080C0C06070501080501
6D7A917988A07B8AA77B8AA97B8AAA7A8AA87C8BA77F8CA7808DA7828EA8818DA7818DA8
828FA98490AA8491AB8592AC8695B08496AF8395AC8597AD8899AF8B9AB08C99B08E98B0
8F99B2909AB4909BB6929DB8939EBA96A0BC97A1BD99A3BD9AA5BC99A3BA9CA5B99CA4B7
9FA7BBA0A6BD9FA5BDA2AAC1A2AAC1A1A9C2A2ABC3A2ACC3A3ACC1A2ABBEA4ABBEA6ADC0
A8AEC1A8AEC0A9B0C0A9B2BFAAB2BDAAB2BBABB3BCAAB3BCAAB3BCACB4BDABB2BDABB1BC
ACB3BDAEB3BEAFB5BFB0B5C1AFB3C2AFB3C1AFB5C1AFB4BFAFB4BDB0B4BDB2B6BEB2B4BB
B0B3BBB1B6BEB1B6BEB2B6BDB0B6BCAFB4BAB2B6BCB1B6BCB2B8BCB1B7BAB1B6BBAFB5BB
AFB4BBB0B4BBB2B4BCB3B5BCB4B5BAB4B6BAB1B5B8B2B7B9B2B7BAB2B9BBB3B9BBB3BABB
B4B9BCB3B6BBB3B5BBB2B4BBB2B5BCB0B4BAB1B5BBB1B4BBB1B5BCAFB3BAAFB4B9AFB5B8
AEB5B6ADB5B5ACB5B3ACB5AFACB4ADABB3ACADB4AFADB3B1AAB2B2A7B0B1A6AFB0A7AFB1
A7AFB2A6ADB3A5ABB3A6ABB2A7ACB2A5ABB1A2A9B0A1A9B19FA8B19EA8AF9AA4AC9CA5AC
9CA3AB9DA4AC9AA3AA98A2A897A0A697A0A5969EA4919B9E8C98966973734F545634363A
2220271A171F19151B2C2C2B2826262222201718141514101514121414141010120D0F10
0C0E0D0C0F0A080904060500
71809178879D7C8BA57E8CA97C8AAA7988A77B8BA67E8EA48190A4818EA37F8DA37E8DA5
7E8DA78090A98191AA8393AB8594AD8393AD8392AC8494AC8492AA8795AB8B97AC8C97AB
8E98AE8E98B08E9AB3909BB3929DB5969FB8979FB897A0B897A1B698A2B49BA5B49BA4B5
9DA5B79DA4B99DA4BB9EA6BC9FA6BD9EA6BDA1A9BFA1AABFA2AABEA1A9BBA4AABAA6ACBA
A7ADBCA7ADBDA5ACBBA7AEBAA8AFB8AAB1B9AAB0B9A9B0BBA8AFBAA8AFBCAAB0BBAAAFBA
ACB2BCADB3BDADB2BEADB1BEACAFBEABAFBEADB0BEADB1BEADB2BDAEB2BCADB2BBAFB3BB
AFB3BBAEB2BBAEB2BBAFB3BAB0B4BAAEB2BAAFB3BBB0B5BCB0B6BBAFB4BAAEB3BAAEB3BB
AEB3BAAFB3BAB1B4BBB1B2B9B2B3B9B2B3B9B1B4B9B1B4B9B0B4B8B0B5B9AFB5B9AFB3BA
AFB3BAAEB3BBAFB3BAAFB4B9AFB3B9ABB1B7ACB2B7ABB0B6ABB1B7ABB0B7ACB1B9AAB1B6
A9B1B4AAB1B3ABB3B2ABB3AFABB4ADAAB2ADAAB1AEAAB1AFA8B1B1A6B0B0A4AEB0A4ACAE
A5ACB0A6ABB2A6A8B3A5A7B2A4A7AFA4A7AFA4A8B1A2A7B29FA5B29DA5B09CA5AD9AA3AB
9AA1AA99A0A8979FA7969EA7969DA6959DA5949CA4919AA28F999F8B97998895927A8581
54575C40424A3A3B4237373D3B3D3F29293125262D24252A24272818181C14141A0C0E14
08090E070808040603040501
70808D778798798AA07B8BA57B8BA67A8AA4798AA17C8BA07D8BA07E8BA17D8AA17B8BA3
7B8BA47D8EA67F90A88091A98392AC8392AC8592AC8694AC8593AA8794AB8B97AD8D97AE
8D97AF8B95AE8C95AE8D97AF909AB2949DB4969DB4979EB5979FB4969EB298A2B398A3B4
98A1B598A1B69AA3B99CA5BA9DA6B99CA7B99EA8BC9DA7BCA0A8BDA2AABDA3AABBA5ACBB
A6ACBCA5ABBAA3AAB8A6ACB9A7ADB7A8AFB8A9AFB8A8AEB9A7AEBAA6ADBBA7ADBBA8AEBA
A9AFBBA8AEBAA8ADBBA9AEBDA9ADBBA9AEBCABB0BDACB0BCACAFBCACB0BDABB0BBABB0BB
ABB0BAAAAEB8AAAFB8ADB1B9ADB0B8ADB1B7ACB1B7AEB3B8AFB3BAAEB2BAAEB1BAACB0B8
AEB1B9AEB1B9AFB3BAADB0B8ADAEB7AEB0B8B0B1BAB0B1B8ADB1B6ADB3B7AEB4B9AFB4BB
ADB1BBABB0BBADB2BCAAB1B8AAB1B6A9B0B4AAB1B6AAB1B6A9B0B7A9AFB8ABB0B8AAAFB6
AAAFB5ABB1B5AAB0B4A9B0B3AAAFB1A9AEB0A7AEAEA5ACACA4ACADA6AFAFA4ADADA2ABAD
A3AAAFA2A8AFA3A8AFA4A7AFA1A4ADA1A5ADA0A5AE9EA4AE9CA2AC9CA3AB9BA3A996A0A7
979FA8969EA6979EA6969CA5959CA3939BA090989E8F989E8F989D8B959A8B94988B9597
848E907A8488737E816770765B646A4042514C525E5A65694A52541615221717200A0B14
04050D020306010201020201
6B7C86748693798A9E7B8CA3798AA47A8AA4798AA3798AA17A8AA17C8CA37D8CA57C8CA6
7B8BA67C8CA57E90A67F90A88291A98392AC8393AC8394AB8594AB8694AA8A96AD8B96AE
8C97AF8A95B08B96B18B97B18C98B2909CB4929CB4939CB5959DB5919BB4919DB4929EB4
929EB4949FB596A1B897A3B999A6BA9AA7BA9BA7BA9BA5BC9BA5BD9DA7BEA0A9BDA1A9BB
A4AABCA6ABBDA4AABCA4AABBA4ABBAA4AAB9A5ABBBA5ADBDA5ADBEA5ADBDA4ACBCA5ADBB
A6AEBCA5ADBCA5ABBCA7ADBEA7AEBEA8AFBFA8AFBFA8B0BDA8AEBDA8ADBCA8ACBAA8ADBB
A8AEB9A9ADB8AAAEB9ACB0BBACB0BBACB1BBABB0BAABB1BBACB1BCACB2BBABAFB9ABB0B8
AAB1B8AAB0B7ABB1B7ABB0BAAAAEBBABAFBBACB0BBACAFBAA9AEB8A8AEB8A9B0BAACB2BC
ACB1BCABB0BCACB2BDA8AFB9A7AFB7A9B1B7AAB2B9AAB2BBA9B0BBA8AFBAA8AEB8A7AEB6
A7ADB4A8ADB4A9AEB5AAB0B7A8AEB4A9AEB3A7ADB4A5ABB3A2A9B1A4ABB1A4ABAFA3AAAF
A2A8AFA1A7AFA1A7B1A0A7B19FA6B09FA7B09DA4B099A1AD98A1AA98A0AA98A2A996A1A9
96A1A995A0A995A0A8959DA7939BA4939CA4919BA2919B9F909A9D8E989B8E979A8C959A
899399869095838E92818D917C898F79858C79868F7A8790728087434A593F4A501B212C
070B17060A10030507020203
6B7B8372839077899A7A8B9F798AA37889A47889A67788A57889A6798AA57A8BA47A8AA4
7A8BA67B8BA57D8FA67E8FA68191A68493A88493A98293AA8294AA8495AB8795AC8995AD
8793AE8693B08794B18895B38996B28B99B28D99B38E99B68F9AB78D9AB68E9BB78F9DB8
8E9CB5909DB6929EB893A0BA93A1BB92A1B996A4BA99A5BC9AA6BD9AA5BD9FA9BD9FA8BA
A0A7BBA3A8BCA4AABDA3A8BDA3A9BDA3AABDA5ABBEA3AABDA3A9BEA4ACBEA3ACBEA3ABBD
A4ACBCA3ACBDA3AABEA4AABFA7ADC1A6ACBFA5ACBEA5ADBEA5ACBDA7AEBDAAAEBCA9ADB9
A8ADB8A8AEB9AAAEBAABB0BBABB0BDABAEBFABAFC0AAB0C1AAB0C0A8AFBFA7ADBBA6ADB9
A7AEB9A8AFB9A7AEB7A8AEBAA8ADBCA8ADBDA9AEBFAAB0BFA9AFBDA7AEBBA6ADB9A6ADB9
A7AEB9A7AEBAA9AFBAA8AEBAA7ADB9A7AEBAA7AFBBA8AEBBA7AEBBA6ACBAA7AEB9A6ACB6
A5ACB5A6ACB4A5ABB4A5ABB5A6ACB5A6ACB5A5ABB5A4AAB5A2A8B3A1A7B2A1A7B0A1A7AF
A0A6B0A0A6B3A1A7B69EA5B59EA6B59DA6B49AA4B298A1B098A2AF97A1AE969FAC94A0AA
93A0A8929EA7929CA6919AA7919AA7909AA58F9BA38E9AA08D999D8C979B8C979C8B969B
89959A869194838F93818F92808E927E8B917D89937B88927A8890748289708083566768
242E37090E1803070D010206
697B82758791798A9A798A9E7989A47686A57382A37183A37285A47588A4778AA3798AA3
7989A57B8CA77D8FA77E8FA48091A28292A28391A48190A78192AB8192AB8493AB8694AC
8794AE8793B18592B28693B48795B18996B08C98B38D97B38F99B78F99B88F9AB9909BB9
909BB4909CB3929EB6929EB6919FB7919FB793A1B898A4BA9AA5BB9AA4BA9DA6BBA0A9BC
A1A8BAA1A7B9A2A8BBA3A8BDA3A8BFA2A7BEA3A8BEA1A7BDA1A7BEA4A9C0A3AAC0A2AABF
A2ABBCA2ABBCA3A9BEA4A9BFA4AABDA3AABCA6ABBBA6ACBCA4AABBA5AABBA6ABB9A7ADB7
A7ADB6A8AEB8A7ABB8A7ABBAA7ACBFA9ADC1A9ABC1A9ABC2A7AAC0A5A9BFA4A9BDA5AABB
A5ABBAA7ADBAA7ABB8A6A9B7A7AAB8A7AAB8A7AABBA8ABBBA7ABBBA5ABBAA4AAB9A5ABB8
A6ADB8A6ACB8A6ACB8A7ACB9A5AAB7A5ABB7A6ABB7A6ACB7A5ABB7A4AAB6A5ABB6A6ABB5
A5ABB5A6AAB4A4A9B4A1A7B4A1A8B49FA7B2A2A8B2A2A8B49EA5B29EA4B19EA4B09DA3AD
9DA3AD9FA5B0A0A4B49CA1B49AA1B4989FB2979EAF99A1B098A0B1969FAF95A1AE939FAB
919EA8929DA7929BA8919BA88E99A68C98A38D9A9F8B989B8A989A8B969C8A959D88939C
88959B828E94818D92818F93828E95808B95808A947D8A917B898D798689768185788685
5A67681619270C0D17090712
6C7D8A7587967B8C9E7B8AA37989A87787A87385A67487A57488A3778AA2788AA37B8BA5
7C8CA77C8DA98092AA8092A78092A48192A58290A68392AB8393AE8192AE8293AD8392AB
8694AD8693B18693B38694B28796B08B99B0909AB18F97B09098B38F99B58F99B6909AB5
919BB3939CB2939DB2939DB394A0B494A1B495A1B498A3B69BA4B99AA3B99BA4BA9DA7B9
9FA8B8A2A9BBA2A7BBA1A6BDA4A7BFA3A8BEA1A8BDA0A8BCA1A8BBA3A9BEA4A8C0A3AAC0
A3AABEA4ABBEA3A8BCA5AABDA6ACBDA3ABBAA5ACBBA5ABBAA5ABBAA4A9B8A3A9B6A4AAB4
A4ACB4A4ABB5A5ABB7A6ABBBA6ABBEA5AABFA5A9BFA6AAC1A5AAC0A4A9C0A5AAC0A6AABD
A6ABBBA8ADBAA8ABB9A7A9B9A8ABBAA9ACB9A9ACBAA8AAB9A8ACB9A7ACB9A6ABB8A5AAB8
A5ABB7A6ACB8A5ABB9A5ABB9A6ACB8A7ADB8A7ADB7A8ADB7A8ADB8A8ACB8A8ACB8A8ABB6
A7ACB5A6ABB4A4AAB4A2A8B4A0A9B39FA9B49EA7B39DA5B29DA5B29DA6B39EA6B39DA4B0
9DA2B09FA5B19DA3B49CA2B69BA2B699A1B399A1B099A1B099A1B197A0AF949FAD929FAC
909BAA909CAA919DAB909CAB8D9AAA8A9AA58999A089999F88979C8A989D89959D87949C
86959B829195828F92848F93848E95828B96818B967D889279868D7A868A798388798286
788486545C66373B4B2F3242
69798B7485987B8CA27A8BA47A89A77987A87686A67689A5788CA47B8DA47B8CA57D8CA6
7D8DA77E8EA97F8FA98090A78192A58494A88390A98391AB8392AD8292AE8394AF8494AE
8695AE8895B08895B08894AF8A97AF8D99AF8E98AE8E97AF9098B19198B39199B59199B3
949BB3959CB4949CB4949DB495A0B595A1B298A3B29BA4B59CA4B89CA5BC9CA5BC9DA5BA
9EA7BBA1A9BDA1A7BCA1A7BDA2A8BEA2A9BEA1A9BEA1AABEA2AABFA3AAC1A3A8C1A2A7C0
A3A8BFA3A9BDA3A8BAA5ABBBA5ACBCA4ABBBA4AABBA4AABBA5ABBDA2A9BBA1A8B9A3AAB8
A4ABB7A4ABB7A4ABB7A5ACBBA5ACBEA4ABBFA4AAC0A4A8BFA5AABFA5AAC1A6ABC3A6ABC0
A6ABBDA7ACBDA8ACBEA9ACBFAAADC0AAADBFA9ACBDA9ACBAA9ACB9A8ABB9A7ABBAA5AAB9
A5AAB9A5ABB9A5ACBDA6ABBCA5ABBAA5ABBAA7ADBCAAAEBEAAADBDA8ACBDA7ACBCA6ABB9
A5AAB6A4AAB5A4AAB6A3ABB7A1AAB59FA9B49EA7B39DA5B39CA5B29DA7B39EA7B39DA6B3
9CA4B29DA6B39BA4B39AA3B498A0B497A1B299A3B299A2B197A0B097A0B295A1B2929FAF
909DAD909CAA919CA9909CA98F9AAA8C9BA88A9AA489999F88989B8B9A9B8A9A9C88999B
879899859595859394859194848E94848F97828D987F8B987B89957C88937D89917C858D
79838A7682886C7980647478
6574897183997789A27789A37889A5798AA57688A57688A47487A27788A37B8AA57B8BA4
7C8CA67D8EA77F8FA8808DA68391A78693AA8491AA828EAA818EA9818FAA8492AE8593B1
8694B18795B28794B28996B18C98B18C97B08C97B08C96B18F97B18F98B29199B49299B4
949CB4949DB6929BB5929BB3939EB394A0B295A1B297A2B29AA4B698A3B999A4BA9BA5BB
9BA5BA9AA4B99BA3BB9DA6BE9EA7BE9DA6BE9EA5BF9FA6C09EA6C2A0A7C39FA8C3A0A6C2
9FA6C1A1A7BFA3AABEA4ACBFA3ABBBA4AABAA4AABBA3AABDA4AAC0A2A8C19FA6BF9FA7BE
A0A9BCA2ABBBA2ABB9A2ABBBA2A9BCA1A8BDA1A7BDA3A8BDA5A9BEA5A9BFA6AAC3A5A9C2
A5AAC0A4A9C0A3A8C0A5A9C0A6AAC1A5A8C1A6A9C1A6A9BEA5A8BDA4A7BDA4A8BDA3A8BC
A3A9BCA4A9BBA4AABEA5ABBFA4ABBFA4ACBEA3A9BDA4A9BDA5A9BEA3A9BCA3A9BDA2A8BA
A3A9B9A4ABBAA3AABAA1A9B9A0A9B89FA7B59FA6B5A0A7B79EA6B69EA7B69CA5B59AA2B2
9AA4B19AA4B299A3B197A3B095A1B095A1B196A0B1969FB1949DAF949EB096A1B2929FAF
909DAD909DAB8F9AA88C97A48B97A48B97A48B98A48998A188979D89979B87969A849399
829297829296829195828F94818D93818D96808D977E8B957C8A947C8A947C89947A8691
76838C7583897181856C7E7D
6372896F829A7489A3768AA77689A77789A67687A57585A47485A47687A57989A57A89A5
7B8BA57D8DA68290A88390A78491A78794AB8591AA8390A98390A98290A8828FAB8591B0
8691B28792B38791B28792B18A95B48A94B28C96B18E96B39095B49096B49197B59299B7
929AB5919AB5909AB5919BB5929DB5929DB493A1B493A1B396A3B695A1B896A2BB97A3BD
98A2BB9AA4BB9CA4BC9DA4BE9CA4C09BA4BE9CA4BE9DA6BF9EA6C19DA6C19DA5C19EA6C2
9FA6C29FA6C0A1A7BEA3A9BEA2AABDA3A8BBA3A8BBA1A7BCA2A8BEA3A8C2A1A6C2A0A6C1
A1A8BFA1A9BFA1A9BEA1A8BDA1A7BEA0A7BEA0A6BEA4A9C0A4A9BFA5A9BFA4A8C1A4A7C1
A3A7C2A4A8C3A3A6C2A4A7C3A6A9C5A4A7C4A4A8C4A4A7C3A3A7C2A4A9C3A4A9C2A2A7C1
A0A7C0A1A9C0A2AAC0A2AAC0A2ABC1A3ABC0A1A8BDA1A9BCA2A8BCA1A8BBA1A6BCA1A7BB
A2A8BBA2A9BBA2A7BAA2A7BAA2A8BBA0A6B89FA4B79FA5B79FA4B79EA5B79CA5B699A2B3
99A2B29BA3B39AA2B298A1B196A0AF96A1AF969FB0969FB1969FB0959EAE939DAD919CAC
8F9CAC8F9CAB8E9CAA8D98A78B97A48B97A48A96A28A95A18A95A089949F87929D85919D
83929D84939C839299829097818E967F8C987E8C997C89967A87947A879378859277848F
74838C7382897182846D7F7D
67778B70829A7286A27588A87588AA7386A97183A67183A67486A77789A8788AA5798AA5
7B8BA47C8CA57E8BA5818EA78390A98591AB828EAA818EA9838FA98491AA8491AA8794AD
8792AD8890AF8890B08791B08993B08C95B18E97B19097B39197B69096B69095B69197B8
9098B68F98B59099B6919BB6919DB7909CB7929EB5929EB3929DB3929EB596A1B996A2BC
959FBA99A2BC9BA3BC9BA2BC99A0BE9BA4C09AA4C09AA5C19CA6C09DA6BF9DA6BE9DA6BE
9DA5BE9EA6BE9FA6BDA1A7BCA1A7BCA1A6BCA1A7BCA1A7BCA0A6BCA1A6BDA2A7BFA1A6BF
A2A6BFA1A6BF9FA5BE9FA6BE9FA4BE9FA5C09FA5C1A2A9C2A2A8C0A2A7BFA2A8BFA2A7BF
A2A7C0A3A8C3A5A9C6A5A8C5A4A8C4A3A8C2A3A7C1A3A8C2A3A7C1A3A7C2A4A8C2A2A7C1
A1A7C29FA7C2A1A9C2A1A9C0A2AABFA2A9BEA1A8BDA1A8BBA2A9BBA1A8BBA1A7BCA3A9BD
A3AABEA2A8BCA0A5B99FA5B99FA6B99FA5B79EA3B49DA4B59DA4B59DA3B59AA2B499A1B4
9AA1B39AA2B298A1B196A0B1959EAF969DAD979EAE969EAF969FB1969EB0949DAD929BAC
909BAB8E98AA8E99A98F9BAA8E99A78D99A68C98A58995A28A95A38994A287919F85909F
84919E83919B84929A839099838E9A818B9C7E8A9E7A869B778596778695778793768690
75868D7385897183836F827D
6575896F819870849F7287A47286A67183A66E81A47084A77184A57285A57386A57587A5
7687A47B8AA67B88A67E8BA8808EA9828FAA828EA98290A98290A98391AA8492AB8593AA
8592A88692AA8691AC8793AD8892AE8A94AE8A94AD8B94AF8D95B28F97B58E97B68E97B7
8E98B68E98B38F99B28E98B28F9AB6909BB7909BB4909CB3909BB2929CB4949FB795A0B8
969FB8959DB8969EBB969FBB959FBB97A1BE99A4C097A3BF95A2BE97A3BD97A2BB97A3BB
99A4BC9BA5BD9CA5BB9CA4B99CA3B89CA3B99EA5BA9DA4BA9EA4BA9EA4BA9EA4BB9EA2BB
9EA4BD9FA6BD9DA5BA9DA5BB9EA6BD9EA5BF9FA7C29FA8C3A0A8C19FA8C09EA7BE9EA7BE
9FA7BFA0A7C0A1A7C1A0A5C0A0A6BEA0A7BDA0A7BF9FA5BF9EA3BCA0A5BEA1A6C0A0A6C1
A1A8C09FA7BF9FA8BF9DA6BD9DA6BC9FA8BCA0A8BC9DA6BA9CA6B99DA5BA9DA5B99FA7BC
A0A8BD9FA7BB9EA5BA9CA3B89BA3B69DA5B69CA3B49BA3B39CA5B69BA3B798A0B6979FB4
97A0B397A0B096A0AD949EAC959EAD949CAD959CAE939BAD919AAC919AAD8F99AE909BAD
8E9AAB8C98A88B96A68B96A68A95A58B95A58A95A58893A38792A28690A1828D9E828D9D
828E9C808E9A7E8E977F8D97808D97808B997F8B9C7B879A77879776889574859172838D
7183897083846D817F6C807A
67758C6A7B966D819F6D84A26F84A47386A77285A77185A76E83A57084A67388A87488A6
7689A6798BA77A8AA67D8CA67E8DA77F8DA77E8CA67E8DA67E8DA67F8FA88090A98090A8
8191A88191A78693AA8792AD8893AF8894B08894AE8894AE8B95B08D97B38D98B68B95B5
8D98B68D9AB58E9AB38D99B28C98B68C97B68B97B58C99B28D9BB2909CB3939DB4939DB6
959EB8939CB8919AB9939BB9939CB8939DB8939EBA93A0BB91A0BB93A1BC95A1BB949EBA
95A0BC959FBC96A0BA99A2BA9BA3BA9BA3BB9BA4BB9AA4BB9AA3B99AA3B99AA3B89AA2B8
9BA3BA9CA5BB9CA6B99CA5B99CA6BC9DA5BF9DA5C09DA5C09EA7C29EA6C29EA6C19EA6C0
9DA5BE9DA5BF9DA4BE9DA5BC9CA5BC9CA5BA9CA6BC9CA6BD9BA4BB9BA3BB9DA4BD9DA4BE
9DA5BF9CA5BF9CA5BE9AA5BC9BA5BA9CA7B89FA9B99EA9B99DA8B99CA5B89CA4B79CA4B9
9DA5B99DA6B99DA5B99BA3B79AA1B599A1B69BA3B79AA4B89AA5B899A3B897A0B5959EB4
969EB4959FB2959FB0939EAE929DAD929CAC909AAC8F9AAC8D99A98E9AAA8E99AA909AAD
8E99AD8D98AB8B97A98B95A78892A48992A58993A58692A38591A28491A2808D9E808D9F
808EA1808FA07C8D9C7C8D9C7D8D9C7D8C9A7C8B9879869676859677889774859371828E
7083896F83836E82806B7F79
6774906C7C9C6E82A46F85A67083A57284A77486AA7385AA7186AA7287A97489A6778AA7
778AA7798AA77B8CA87C8DA87E8FA87F8FA7818FA77F8DA77E8CA77F8EA9818FAB8191AB
8192AB8190A98592AC8692AF8691B08792AF8996AF8996AF8B96AF8B96B18D96B58C96B8
8A95B78A96B78C98B68E99B88E9BBA8C99B98B98B68B99B38E9CB4909BB3939CB5939CB6
969EB8959CB8949CB8959BB9959CB9939BB7949EBA95A1BB94A0BB949FBB98A2BE99A2BE
98A0BD97A0BB99A0BB989FBB999FBC9CA2C09DA4C09CA4BE9BA4BD9CA5BC9CA6BB9BA3B9
9BA3B89CA5BB9DA7BC9BA4B89CA5BA9EA5BF9EA5C29EA6C29FA7C3A0A7C3A0A6C29FA5C2
9EA5C29EA6C29EA7C19EA7C09DA7BE9BA6BD9AA6BF9AA6BF9BA6BF9BA5BC9DA4BC9CA3BD
9AA2BE9BA5BF9BA6BF9CA6BD9DA7BC9EA8BB9DA8B89FAAB7A0AAB79FA8B79FA8B89EA7BA
9FA7BB9FA7BC9EA6BB9DA5B99DA3B89CA2B89CA4BA9DA5BA9CA6B99BA3B798A1B699A1B6
98A1B6979FB5959EB4949DB5939EB5929CB3909CB1909DB0909DAD919CAE919AAD9099AD
8E98AE8D97AC8B95AA8B96AB8B96AA8C97A98B97A88795A58694A48593A58390A3828FA4
8290A78290A67E8EA27B8BA17B8B9F7B8C9C7A8B9978879877859A78879B758596758692
74868D7285877084816D827A
6873917381A17484A77384A77282A67282A67584AA7483AA7485AA7386A87587A67888A8
7988A87A89A87C8CA87E8DA77F8DA6818EA6828DA7848FAA848EAC838EAE838FB0828EB0
8390B18591B18592B18591B18890B08992B08993B08B95B08E98B38D97B38C97B68E97BA
8C96B88A94B58A93B48D96B78F99B98E99B98D99B78E99B4919CB3929CB3939BB3959CB4
969DB4969CB2969DB3979DB5999EB6969CB6969CB798A0B999A0BA979EBA999EBB9AA0BC
99A0BA99A0B99A9FB99CA0BB9B9EBD9C9FBD9DA0BE9CA1BF9CA1BF9CA2BF9EA4BD9DA3B9
9BA1B79DA4B89FA6BB9EA4B99FA3B9A0A4BBA0A3BE9FA3C09FA5C1A1A6C1A1A5C0A1A5C0
9FA3C09FA4C19EA4C19DA3C09DA4BE9CA3BE9DA5C09DA5C09DA6BE9FA6BBA0A4B99EA3B9
9DA2BB9CA2BC9BA1BC9CA4BC9FA6BE9FA5BD9EA5BA9EA4B79EA3B69FA3B6A0A5B79EA5B7
9FA5B99EA4BA9DA3B99DA3B89CA1B59CA0B39B9FB39BA0B59DA2B69BA0B499A0B3979EB2
979EB2989EB2989EB2979CB3959CB4939BB3929BB0929AAF939BAE939AAF9096AC8F95AB
8E94A98E95A98C94A98B93A98990A58993A48892A186919F8591A08490A1838EA2838DA2
838DA6808BA57B88A17B89A07B8A9E79879A788698768396768296768396758193758290
74828D7282896F80816A7C78
646D8A6A7796707FA16F7FA37281A57281A67280A57584A87685A87687A87686A87887A8
7A89A77B8AA67B8BA57D8DA57E8BA5818EA7808CA7828DA9848DAD828DAF818EB1818EB2
818EB2818FB08291B08392B08592AF8792B08992B18A93B28A94B38A94B48B96B68D96B7
8D96B68B96B68B96B68E99B78F9AB58D96B28C96B18E97B2909AB3919BB4919BB3929CB2
919AB1939BB1969EB2969CB3969BB4969BB5969CB6979DB7979DB7979EB89AA0BB9AA1BD
9AA0BA9AA1BA9BA0B99CA0BB9CA0BE9CA1BE9AA0BD9AA1BC9AA1BD9BA2BD9AA0B99BA2B8
9CA4B89CA4B89DA3B69FA4B79FA4B89FA2B89DA0B89CA0B89EA2BBA0A5BDA0A4BDA0A4BF
9FA2C09FA2C19FA3C19FA3C19FA3BF9EA3BD9FA4BE9EA5BC9FA5B8A0A6B89EA3B69CA1B6
9EA2B99EA5BC9BA2BB9BA2BB9DA3BB9FA3BB9EA2B99D9FB69EA1B89EA0B79FA1B79FA2B7
9EA2B79BA2B699A0B699A0B69BA1B6989EB299A0B2999FB4989FB5979FB4969EB4969EB3
979FB1979EAE979CAD979CB0959BB1929AB09199AF8F96AC9097AC9299AE9095AA8D93A8
8D94A88B91A68B92A68A91A6878FA38791A286929F85909B85919D828D9C828D9D828D9F
828BA08088A27D88A27C879F7D8A9D7B889A7A8598778295748091758193768294748091
707E8D6E7E896D7E81687B77
636E8A6C79967180A07382A57381A57180A47281A47584A77887A97989AB7889AA7688A7
7789A4798AA37A8BA27D8DA47F8CA6808CA97F8AA97F8AAB818BAC828DAD818DAE818FB0
808EAF7F8EAC7F90AB8091AB8392AB8491AB8591AE8792B18894B28995B28A95B18A93AE
8C95B28D97B58E99B68D99B68E9AB38D99B18D97B18D97B18F98B28F99B28E99B18E9AB1
8E98B1919AB2949CB4959CB6949BB7949BB7959BB7979CB9979CB9969AB8979CBA999FBB
99A0BA99A1B99AA0B79A9FB79AA0BA9AA1BC99A1BB979FB897A0B79AA2B798A1B499A3B4
98A3B398A3B298A0B09BA2B29DA3B69EA4B79EA3B79EA3B69FA4B79FA3B9A0A4BBA0A3BC
A0A3BF9EA3BF9FA4C09EA2C09DA1BE9DA2BE9DA3BC9AA2B79BA2B49BA3B59CA2B59CA2B6
9BA1B69BA2BB9BA3BB9CA3BA9BA0B79CA1B59DA1B69C9FB69C9EB69DA0B69C9FB59DA1B6
9DA3B79BA2B7989EB4969CB3969EB4979FB2979FB1979EB3969FB5959DB5939BB3939CB2
949DB2949DB0939BAE939BAF9199B08F97AE8E97AC8C95A98D96A98F96A98D94A78C92A4
8A90A48890A3868FA18790A2868FA1858FA18491A183919D808F9A7F8E99808E9B808D9D
808B9E808AA07D889F7C889E7C889D7A8698798394788293758091737F92738195707F91
6E7E8C6C7D856A7C7F677A77
616D886A7794717D9E727EA3717EA3717FA37481A27785A47887A77986A97887A97789A6
7588A47789A57888A37B8BA37F8CA67F8BA97F8BAB7E8BAA7F8AA7818EA78390AA8390AB
818FAC808FAC7F90A98090A88290A68390A88490AC8590B08793B28B96B18B95AE8D95AE
8F96B18F97B58F98B88E97B78E98B68C96B18E97B08E95AE8F96AF9097B08F97AF8E98AF
8E97AF9198B09299B39399B59398B79299B9939AB9959CB8959AB79499B8969BB9969CB8
969EB7969EB498A0B49AA0B59A9FB699A0B999A1BA979FB6969EB398A0B199A0B09AA0B1
98A0B198A1B298A1B198A1B199A1B29BA3B69DA4B99CA3B69CA3B39CA2B29DA2B39FA2B5
9FA3B89EA3B99EA4BA9DA2BA9B9FB99A9FB99AA0BA979EB798A0B69AA1B69AA2B69CA2B8
9CA1B9999FB99AA1B99AA2B89AA1B49AA0B39DA1B49DA1B69C9FB59A9DB3989DB1999DB1
9DA1B39BA0B2989DB2959BB3969DB3959EAF959CAD959BAF939AB1949CB3939CB2929CB1
929BAF9199AE9098AE8F97AF8C96AE8A93A88A94A58B95A38D96A48C94A38C94A38B92A2
8990A18991A087909F88909F8990A0878FA1848FA1808D9D7F8D997D8B977F8D997F8B9A
808A9D80889E7E879E7C86A07A859E798499788294788094777F96747D96727E966E7D91
6C7E8B6B7C83697C7D687C77
606B856976926F7C9C727EA1707CA2717EA37481A27381A27583A57886A87785A67787A6
7889A6788AA67989A57A8AA57B8AA37D8AA57E8BA77E8BA87E8BA47F8BA2818DA4828DA6
838DA8828FA9818FA8808FA78392A88492A88492AA8592AC8691AC8993AC8993AA8B94AA
8D94AC8F95B08E94B28F95B38E95B28D93AF8F96AF8F96AF8F95AE9096AD9198AF9299AF
9097AD9196AE9297AF9297B29398B79198B99198B99399B7929AB59299B69298B5949AB6
969DB6969DB4969CB2989CB3989CB59599B6959BB6969DB4979EB1979DAE999DAF999DAF
989EB0979EAF969EAE979EAE969EAE979EB2969DB4969EB596A0B298A2B09BA2B09DA2B1
9EA2B49DA2B59EA2B79CA1B69BA0B5999FB4989FB5969CB4959DB3969EB4979DB4999DB5
9A9FB7989EB5989EB7989FB6969EB3979EB2999FB19A9FB39CA1B49A9EB3999DB2999CB0
9A9DB2999CB1999DB3979DB5969DB2959BAE9299AB949AAD9399AD9299B0939AB0929BAF
919AAD8F96AA8E96AA8E96AC8B94AB8992A58A94A38D94A28E94A08F94A08C92A18B92A0
8B92A18A919F88909D858D9A868D9C898FA0858DA0808A9D7F8A9B7D89987F8A987F8899
80889A81889C7F859D7C829D79809C79819B787F98777D96767C97757C97727D956E7C90
6A7B886A7C83697C7E687B78
636E896B7895707F9D7180A0727FA1717EA27380A4717EA27481A57685A77583A67685A7
7888A87A8AA97B8AA97A89A97B8BA77F8FA87F8DA77F8BA6808CA6818CA5818CA5818CA7
808CA7818DA7808DA7818FA88290A88391A98492AA8693AC8793AC8994AB8993A98C95AB
8D95AA8D95AA8C93AB8D94AD8D95AE8E96B08D94AF8E95B18D95AF8E97AE8F98AE9096AE
9096AE9197B09197B39197B49297B79299B9939ABA939AB9929AB99198B89198B6919AB5
959DB5969DB4969CB2979CB3979CB3949AB4959BB7959CB6969EB5979DB5989DB5999DB3
999FB1989FAF979FAE959CAC949CAC949DAF949CB2969FB4959FB398A1B399A0B29AA0B3
9C9FB39CA0B69DA0B79CA0B89CA3BA9BA2B99BA1B79BA0B69BA1B599A0B5979DB3979CB3
979DB4979EB5979EB6989FB7969DB6979EB59A9FB5989DB49A9FB5999DB49A9DB39C9DB3
9B9BB49B9BB5999BB6979CB4969CAE959CAD939AAB939BAB939BAC9299AC9097AC9098AC
8F97AC8F98AC8D97A98C96A98B96A98B94A58C93A38D93A28C919F8D92A18A91A1878F9E
87929D88919C878F9B858C9C848B9D858C9F868DA0828A9F828A9E80889D7F879C7F859B
80849D80839D7D829D7B819C7A809D79809C777E99757D99747D99747E98727D936C798B
6A7888697A8566787F647779
636D886977946D7C9B707F9F727F9F727FA1727FA2717EA27380A47481A37683A47B89A8
7B89A97B8AA97A89A87A89A97C8AA97F8DAB7F8DAB7E8AAA7F8BAA818CA9828DAA808CA9
818EAA818EAA828EA9838FA98390AA838FA98591AB8692AB8691AB8893AC8A95AD8994AA
8A95A98A94A98A93AA8A92AB8A91AC8B93AE8D94B08C94AF8C93AD8D94AE8D93AF8E93AE
8D94AE8F95B09197B39096B49095B39196B59298B79299B99198B99199B99299B8929AB7
949CB6969DB4959CB3939AB0959BB1949BB2949CB4959CB6969CB8969BB6969BB4979CB3
979DB1969CB0949BAD949BAC949DAE929BAF949CB298A0B698A0B7979FB7979EB5999FB5
9A9FB5999EB59A9EB79B9FB99BA0BB9BA1B99DA2B89DA1B49B9FB19B9FB19A9EB3999EB5
999EB5979DB5979DB5989EB8989DB8989DB6999DB7999CB7999CB7989AB5989AB3989AB2
9A9CB2999AB3979AB49599B0939AAB949BAD939BAF9199AD9099AC9099AC8F97AB8F97AB
8D95AA8B93A88D95AA8D96AA8D95A98D95A78D92A48B91A38A8FA2898EA1888FA1858E9F
858F9C848E9A858E9C858D9D838B9D828A9D838A9F81899E80889E80879E7E849D7D839D
7D829E7D829E7B809E797F9C777E9B757D99737C95707A91707B92727C92717B8F707A8C
6C77896A768766768263757B
636E876875926C7B9A6F7DA0717FA3727EA3707DA1717EA27481A47481A27683A27986A6
7A88A87989A67989A47B8AA57E8CA77F8CA97E8DAB7D8BAD7E8CAC7D8AA8808CA9818DAA
838FAB838EAB828EAB838EAB8390AC848FAB848FAB8691AE8692AE8691AD8590AB8693AB
8896AC8894AC8B94AD8A93AC8A93AC8B94AF8B93B08B93AD8C94AE8F95B08F94B19095B2
8F95B19197AF9298B09398B19397B19398B39298B59297B69196B69298B6939AB6949BB5
969DB6959CB59399B49298B2949AB2949BB2959BB4959BB5959BB7969BB4999DB2999CB1
989BB0979BB0969CB1949BAF959CB0939BAF949BB0969DB3979EB5979EB6989EB7999EB6
999DB5999DB5999DB6999BB6989CB5989DB3989DB1999DB0999DAF9C9FB39C9FB69B9EB7
9A9DB6989CB6999DB69A9EB7989CB4989CB4989BB5989AB6999CB4989CB3979BB2979BB1
989BB1969AB19498B09299AE9298AC9398AE9398B09197B08E96AE8E97AD8E97AB8E96AA
8F95A98D93AA8E94AD8C92AA8C91A88C92A68C91A6898EA4898EA4888EA4888DA4868DA3
858CA2828AA0838AA0848AA18488A08387A18288A28086A27E84A07C839D7D829D7C809B
7B7F9B7A7D9B797F9B787F99757C96747B94727B9270798E6F798D70788E6F778E6E778D
6A758B69748766748161727A
636F896975926D7B9B6F7CA0717DA3727DA4717BA2717DA27580A37782A37781A17985A4
7885A67887A67A89A57A8AA57C8CA67D8CA77D8CA97D8CAB7E8DAC7F8DA97F8EA6808EA4
8290A5828FA7838EAA848EAB848EAB8490AA838EA8848FA98690AC858FAA838EA88491AA
8693AB8995AC8C95AE8C95AF8B94AF8C96B28A93B08B94B08B95AE8D95AE8E94AF8F96B1
8F97B1929AB0939BAF939AAE9297AD9398B09197B29298B49198B49197B29299B29299B2
9399B19399B29196B29196B39096B39198B3949AB5939AB6949AB7959AB4979CB3969BB2
989CB3979CB3949AB2939AB0929BAE929CAD949DAE949CAF959DB3959CB4959CB4979DB5
969BB3959AB0979AB1999BB4989BB4979CB2969BAF979CAF989DB29A9DB3999CB49A9CB6
989BB5969BB3979CB2989DB2989CAF979CAF979BB19599B19599B0959AB0969BB0959AB1
969AB29499B29297B19197B09196AD9094AB9195AD8F95AF8C94AE8B94AB8A93A98B94A8
8B93A68D93A88D93AC8C91AB8B92AA868FA58890A38A8FA3888DA3898CA5888DA7878CA7
858CA6828AA180899F82899D82899F8287A18186A17F86A37C84A177809B7981997A8197
7A7F99797E99777D99767F9A727C97707A94707A936F79926F798F6D768E6B748E69728C
65718A657287647381607178
636E8667738F6D7B9A717EA1737EA3747DA3747BA2737AA1777EA27880A27880A27B85A6
7986A57986A47B89A57C8BA67C8BA67C8BA67C8CA57D8DA57F8EA77F8CA57E8CA27C8CA0
8190A1828FA1858FA3868EA4858DA58590A88590A9868FA98790A9868FA9868FAA8890AD
8991AF8890AE8C93AF8D94B28C95B28A93B08B93B18C94B18C95B28B94AF8B95AF8B95AF
8B96AD8E98AD9099AD9097AC9096AB9197AD9197AF9297B09198AF9197AD9399AF9297B0
9196AF9095AF9095B09095B18F94B18F95B19097B39097B49198B39298B19299B09399AF
9398AF959AB1949AB19298AF939AAD939CAC949DAC949CAE949CB1939AB2949BB3969BB3
959AB19699AE9699AF999CB4979AB2949AB0959BAF949AAB959AAC979BAF979AB0979AB4
9598B39398B0949AAF9499AB949AAA959BAA9499AB9397AD9296AE9296AF9396B09397B1
9297B29196B29094B19195AF9195AE9195AD9094AC8E94AB8C93AB8B93AA8A93A98A92A8
8990A5888FA68A91A88990A78A91A78891A48890A1898F9E888C9E898DA1878BA38589A4
8289A47F889E7D889C7D869A7E859A7E859B7D839C7D859F7B839E78829B778198757E95
767C96777C98757B98737A997079986E78956D75926B738F6C738F69708E676F8D666E8C
636F89626F876170825E6E76
666E8468718D6C769670799B737C9D757C9F7579A17578A1787CA3777EA27882A17A85A2
7A85A17A85A07B87A07C88A17D8AA47E8CA6808DA57E8CA27E8BA27D89A17E8AA27D8BA2
808EA3828FA2848FA0848DA1858DA5878EA98990AD8991AE8992AC8891AA888FAB898EAD
8D91B28C90B28A8EB08C91B08B92AC8890A98B91AB8C92AD8B91AF878EAC858EAA8490A9
8692A98892A68D95A88E94A98F95AA8E95A88E96A98F97AA9097A99097A99197A99296AA
9297AC9096AC9197AD9299AD9198AC9298AD9095AD8F96AF8F96AE8F96AB9096AA9095A8
9094A79296A99398AB9399AC9399AA9299A7939BA8939AAA9499AC9397AD9497AE9599AF
9497AE9597AE9698AE9699B09698AF9498AD949AAA9399A69397A69699AC9799AF9598AF
9599AF9598AD9498AB9497A99498A99499A99497A89294A89193AB9294AF9495B09395B0
9295B09396B09193AE9294AE9193AD9193AC9093AB8D92A88C92A68C93A98B92A8888EA4
898FA3888EA3888EA3888EA3888FA18A91A2898FA0878D9E888C9D898D9F888A9F8588A2
8386A38186A27E859E7C83997A82967C83967D82977C83987C8197797F97777E98757C95
757B95767C967379957177956F76956E76956C74926C73926B7392697190656D8A656D89
656E88626C845F6B7F5D6C77
696D816D728C737995757C9A777D9C777A9B76799E777AA17A7DA47B80A47C84A17C869F
7B839D7C849F7C86A07C869F7C89A27F8CA5818EA4808DA0808BA0828CA4828BA5808AA5
808CA6838FA58690A3878FA2878DA58A8EAA8B8FAE898FAE8990AC898FAA898EAA8B8FAD
8E92B08D91B18A8EAE898FAC8A91AB8C92A98B91A78B90A7898EA7888DA8858BA6838AA4
828BA082889C83879D8789A2888AA2878BA1858BA0868EA088919F89919E8C93A18E95A4
9197A88E95A68F97A7919AA9929AA9939BAA939AAB9399AE9096AB8F96A89198A89297A5
9397A59498A7969BAB9499AA9396A79498A69599A79498A89698AC9497AC9498AE9397AD
9296AC9497AD9698AE9799AF9899AF9597AD9497AA9599A99497A79698A89697A99596AA
9597AC9598AC9497AA9496A89597A99597A99497AA9193A99092A99294AA9192AA9092AA
9395AD9495AE9192AC9294AD9293AB9092A88F93A68F92A48F91A48C8FA38A8FA2898FA1
8B90A08C91A1898EA1878CA1878CA1878CA1868BA0858A9E868A9C898C9D88899C86869F
8585A18185A27E839F7B83987C84967D83957C81947E82977C80977B7E97797D97787D97
787C95777A927579927377937176956D73956970926A72916B748E6A738B677088676E87
676C86656A8361687D5D6775
696C8073768D777D97787E9A797D9A797C9A797B9B7B7C9E7C7FA17C80A27E84A07F859C
7F849A7F859C8288A18088A17F89A27F8DA1818EA0828E9F838D9E848DA1848CA38188A3
8089A2838CA1868FA1888FA1898EA38A8EA88B8EAB8A8EAB898EAB898EA9898EA88A8FA8
8D91AB8D91AD8C90AD8A90AA8C93A88E94A68E93A58D91A38B8FA48A8EA7898DA7868CA4
858BA084899C85869B85849C83819D81819C7D7F987D81967E83937F8492818594838796
848998828A98848D9B87919E8994A08D96A18F96A29098A59097A69098A69199A4929AA3
9299A39398A69598A8949BAA9298A79299A6949AA59498A49597A59598A89497AB9298AB
9196A99297AA9598AB9598AB9596AA9394AA9294A99295A79396A79597A89596A69494A6
9696AA9395A89295A79295A69497A89597A89697AB9396AB9092A79093A59194A79294A6
9394A69392A69292A89393A99193A69193A29093A18E90A08C8E9E8C8F9F898E9E898F9E
8A8F9C8C919C8C909C8B8D9E8A8BA086889F86899F868A9D878B9D888B9B87889A87879C
84839C80819E7E829D7B81977A81937B81937B80927D80957E80987C7E97787B93787C92
777B9078798E77798F75768F7374907072906B7090686E8C687188687185686E83696D82
65687F64677F64687C5D6271
6A6D8073788C767C93777B95787A94797B967A7C987B7D9A7B7E9C7D819D7F849E7F839A
7F849980859C8289A08189A0818AA0808C9F828D9D848E9C828C9C858D9E848CA1848CA1
848BA1878EA08990A0898FA2898FA48A8DA68B8DA78A8EA88A8EA8898EA7888DA68A8FA6
8E92A78C90A78C91AB8C91A98D94A88E94A48F94A38E91A28D90A38E91A68D92A68E92A6
8C91A48C8FA28B8CA08989A086839E84829D8181997E7F937D7F8F7E808D7E7F8D7C7D8E
7B7D8F787C8D777D8E787F8F777F8E7E8691858B95898F998D939D8E979E919A9E919A9D
90989E9198A39096A49299A59098A39099A39299A29399A09498A09699A49495A59194A4
9296A59397A79497A89698A89495A79393A79193A59094A39295A49296A39193A19293A3
9595A79294A69296A69397A69498A69395A69495A99497AB9093A68F93A59396A59395A3
9393A29291A19393A39192A290929F90939C8F929B8D919B8B8E9A8B909C888E9C898F9B
878E97898F968B90978A8E97898A9B87889D86869D86879B898B9C878998878897888799
8382977F7F987F829A7D81977A80937A80917C80917C7F927E80947C7E9277798D777A8E
77798D76768B75748A75758C72728B70718C6D718C686C87666E84676F82686E80696C7D
64667B64667A6367775F6571
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.392007 0.97619 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 300},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001;2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`003Ooooon]0?n001[ooooo[@3oP00?ooooo`003Ooooon]0?n001[ooooo
[@3oP00?ooooo`003Oooool50000ojP0oh006_ooool50000ojP0oh003oooool000gooooo1P000?nW
0?n001[ooooo1@000?nX0?n000oooooo000=ooooo`H0003oY`3oP00Jooooo`H0003oY`3oP00?oooo
o`003Oooool00`3oP000003o0000o`050000ojD0oh006_ooool20?n000@0003oY`3oP00?ooooo`00
3Oooool40?n000@0003oY@3oP00Jooooojd0oh003oooool000gooooo103oP0040000ojD0oh006_oo
oon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n0
00oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo
000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=oooo
ojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh00
6_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]
0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oo
oooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=
ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0
oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oo
oon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n0
00oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo
000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=oooo
ojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh00
6_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]
0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oo
oooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooo`<0003oZP3oP00Jooooo`80003oZ`3o
P00?ooooo`003Oooool90000oj@0oh006_ooool90000oj@0oh003oooool000gooooo4@000?nL0?n0
01[ooooo3`000?nN0?n000oooooo000=oooooa80003oV`3oP00Joooooa80003oV`3oP00?ooooo`00
3OoooolC0000oiX0oh006_oooolB0000oi/0oh003oooool000gooooo4`000?nJ0?n001[ooooo4`00
0?nJ0?n000oooooo000=oooooaH0003oU`3oP00JoooooaH0003oU`3oP00?ooooo`003OoooolH0000
oiD0oh006_oooolG0000oiH0oh003oooool000gooooo60000?nE0?n001[ooooo5`000?nF0?n000oo
oooo000=oooooaX0003oT`3oP00JoooooaT0003oU03oP00?ooooo`003OoooolL0000oi40oh006_oo
oolL0000oi40oh003oooool000gooooo80000?n=0?n001[ooooo7P000?n?0?n000oooooo000=oooo
ob00003o0`3oP0020000ohP0oh006_oooolP0000o`@0oh0000<0003o0?n0003oP000QP3oP00?oooo
o`003OoooolO0000o`<0oh001`000?n40?n001[ooooo7`000?l30?n000H0003oQ@3oP00?ooooo`00
3Oooool]0000oh00oh006_oooolP0000o`80oh002`000?n00?n000oooooo000=oooooc00003o>`3o
P0000`000?l0oh000?n0000o0?n001[ooooo<0000?mm0?n000oooooo000=ooooocD0003oN03oP00J
oooooc@0003oN@3oP00?ooooo`003Ooooolf0000ogL0oh006_oooolf0000ogL0oh003oooool000go
oooo=`000?l_0?n000030000o`3oP000oh0000T0oh0010000?lg0?n001[ooooo=`000?ll0?n00080
003o>03oP00?ooooo`003Oooooli0000ob`0oh000`000?l;0?n000@0003o=P3oP00JooooocT0003o
;@3oP0020000o`/0oh000`000?lg0?n000oooooo000=oooooch0003o:@3oP0020000o`X0oh001000
0?l40?n000H0003o;03oP00Joooooc/0003o;03oP0020000o`X0oh0010000?l40?n000@0003o;P3o
P00?ooooo`003Ooooom10000oc80oh001`000?l00`3oP000003o0000o`050000o`<0oh000P000?lV
0?n001[ooooo?`000?le0?n000@0003o103oP0050000ob`0oh003oooool000gooooo@@000?ld0?n0
00d0003o103oP0020000o`D0oh000`000?lM0?n001[ooooo@@000?lf0?n000@0003o00<0oh000000
o`000?l010000?l40?n000030000o`3oP000oh0002@0oh003oooool000gooooo@@000?ld0?n000d0
003o103oP0020000o`D0oh000`000?lM0?n001[ooooo@@000?lf0?n000@0003o00<0oh000000o`00
0?l010000?l40?n000030000o`3oP000oh0002@0oh003oooool000gooooo@P000?l20?n000030000
o`3oP000oh000300oh004P000?l50?n000L0003o603oP00Joooood80003o=P3oP00;0000o`<0oh00
0P000?lU0?n000oooooo000=ooooodX0003o;P3oP00T0000oa40oh006_oooom30000o`030?n00000
0?l0003o0080003o<03oP00<0000obT0oh003oooool000goooooB`000?l0103oP000003o0000o`00
0?lS0?n000@0003o0P3oP0040000o`030?n000000?l0003o00D0003o0P3oP00G0000oa00oh006_oo
oom:0000obh0oh000P000?l50?n000D0003o0P3oP0000`000?l0oh000?n000050000oal0oh003ooo
ool000goooooD@000?lQ0?n00080003o1P3oP0020000o`030?n000000?l0003o00D0003o0P3oP000
0`000?l0oh000?n0000C0000oa40oh006_oooomA0000ob80oh0000<0003o0?n0003oP0002P3oP004
0000o`80oh0000<0003o0?n0003oP0000P000?l30?n000040000o`3oP000oh000?n00080003o6@3o
P00?ooooo`003OoooomD0000obL0oh0030000?l20?n000H0003o0P3oP0020000o`030?n000000?l0
003o00H0003o4@3oP00Joooooe<0003o<03oP00010000?l0oh000?n000000?l20?n000H0003o0P3o
P0000`000?l0oh000?n0000I0?n000oooooo000=oooooe@0003o:@3oP0030000o`@0oh002`000?l2
0?n00080003o0P3oP0000`000?l0oh000?n000020?n000030000o`3oP000oh000100oh006_oooomD
0000ocH0oh0010000?lO0?n000oooooo000=oooooe/0003o:`3oP00010000?l0oh000?n0003oP005
0000o`<0oh0000@0003o0?n000000?l0003o5`3oP00JoooooeX0003o=03oP0001@000?l0oh000?n0
003oP000003o01X0oh003oooool000goooooG0000?lc0?n000040000o`3oP000oh000?n000<0003o
5`3oP00Joooooe/0003oDP3oP00?ooooo`003OoooomQ0000oc@0oh001@000?lC0?n001[oooooG`00
0?m>0?n000oooooo000=ooooof<0003oBP3oP00Jooooof40003oC03oP00?ooooo`003OoooomW0000
o`H0oh000P000?ln0?n001[oooooH`000?m:0?n000oooooo000=ooooofP0003oA@3oP00JooooofP0
003oA@3oP00?ooooo`003Ooooom[0000od80oh006_oooomY0000od@0oh003oooool000goooooJ`00
0?m20?n001[oooooJ@000?m40?n000oooooo000=ooooofh0003o?`3oP00Jooooof`0003o@@3oP00?
ooooo`003Ooooom`0000ocd0oh006_oooom_0000och0oh003oooool000goooooM0000?li0?n001[o
ooooL`000?lj0?n000oooooo000=ooooogH0003o=`3oP00JooooogD0003o>03oP00?ooooo`003Ooo
oomh0000ocD0oh006_oooomh0000ocD0oh003oooool000goooooN`000?lb0?n001[oooooNP000?lc
0?n000oooooo000=ooooogl0003o;P3oP00Jooooogl0003o;P3oP00?ooooo`003Ooooon00000obd0
oh006_oooon00000obd0oh003oooool000goooooPP000?l[0?n001[oooooPP000?l[0?n000oooooo
000=oooooh@0003o:@3oP00Joooooh<0003o:P3oP00?ooooo`003Ooooon50000obP0oh006_oooon5
0000obP0oh003oooool000goooooQP000?lW0?n001[oooooQP000?lW0?n000oooooo000=ooooohP0
003o9@3oP00JooooohL0003o9P3oP00?ooooo`003Ooooon80000obD0oh006_oooon70000obH0oh00
3oooool000goooooR`000?lR0?n001[oooooR`000?lR0?n000oooooo000=ooooohd0003o803oP00J
ooooohd0003o803oP00?ooooo`003Ooooon?0000oah0oh006_oooon?0000oah0oh003oooool000go
ooooT@000?l20?n000@0003o5P3oP00Joooooi40003o0P3oP0020000oaP0oh003oooool000gooooo
V0000?lE0?n001[oooooU`000?lF0?n000oooooo000=oooooiX0003o4`3oP00JoooooiP0003o5@3o
P00?ooooo`003OoooonL0000oa40oh006_oooonL0000oa40oh003oooool000goooooW`000?l>0?n0
01[oooooW`000?l>0?n000oooooo000=ooooojD0003o203oP00JooooojD0003o203oP00?ooooo`00
3OoooonX0000o`D0oh006_oooonX0000o`D0oh003oooool000goooooZ@000?l40?n001[oooooZ@00
0?l40?n000oooooo000=ooooojX0003o0`3oP00JooooojX0003o0`3oP00?ooooo`003Ooooon]0000
oa[ooooo[@000?l?ooooo`003Ooooon]0000oa[ooooo[@000?l?ooooo`003Ooooon]0000oa[ooooo
[@000?l?ooooo`003Ooooon]0000oa[ooooo[@000?l?ooooo`003Ooooon]0000oa[ooooo[@000?l?
ooooo`003Ooooon]0000oa[ooooo[@000?l?ooooo`003Ooooon]0000oa[ooooo[@000?l?ooooo`00
3Ooooon]0000oa[ooooo[@000?l?ooooo`003Ooooon]0000oa[ooooo[@000?l?ooooo`003Oooool0
0`3oP000003o0000o`2Z0000oa[ooooo[0000?l00`3oP03oooooooooo`0=ooooo`003Oooool00`3o
P000003o0000o`2Z0000oa[ooooo[0000?l00`3oP03oooooooooo`0=ooooo`003Oooool00`3oP000
003o0000o`2Z0000oa[ooooo[0000?l00`3oP03oooooooooo`0=ooooo`003Oooool00`3oP000003o
0000o`2Z0000oa[ooooo[@000?l?ooooo`003Oooool00`3oP000003o0000o`2Z0000oa[ooooo[@00
0?l?ooooo`003Oooool00`3oP000003o0000o`2Z0000oa[ooooo[@000?l?ooooo`003Oooool00`3o
P000003o0000o`2Z0000oa[ooooo[@000?l?ooooo`003Oooool00`3oP000003o0000o`2Z0000oa[o
oooo[@000?l?ooooo`003Oooool00`3oP000003o0000o`2V0000o`040?n000000?l0003o0?n001[o
oooo[@000?l?ooooo`003Oooool00`3oP000003o0000o`2R0000o`P0oh006_oooon/0000o`030?n0
0?oooooooooo00gooooo000=ooooo`80oh00X`000?l80?n001[ooooo[0000?l00`3oP03ooooooooo
o`0=ooooo`003Oooool00`3oP000003o0000o`2O0000o`030?n000000?l0003o0080003o1P3oP00J
oooooj`0003o00<0oh00ooooooooool03Oooool000gooooo00<0oh000000o`000?l0W`000?l;0?n0
01[ooooo[0000?l00`3oP03oooooooooo`0=ooooo`003Oooool00`3oP000003o0000o`2N0000o``0
oh006_oooon[0000o`80oh003oooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool000gooooo00H04149010A200A4@X04A4;010@3P0C4a4201DF
4P0;01LH4P0F5`l05QL?01PH400G610061X@01LK400D5`d051L>01DG3P0F60l00P0H6@l02`0G6@h0
5AP>01@H3@0C5Pd04A@=01<G3`0C610051P@01<H4@0E618061XC008061TC00`06ATC01TJ4P0I6a40
6A/B01TL4`0I7A@06AdC01TN4P0J7a<06AhB01TM4@0G6Q4201LK4`0;01XN500J7Q<061/A01PK400I
6a406Q`A01dO4`0L7a<071dE01`N5`0K7AH00`0L81T02P0K7aL06QhF01TL5@0J7QD061`D01LK4`0H
71806A`A01PK4@0J718201XM4`0;01/N5@0K7aP06QlH01/O5`0M81P06ahE01XM500I71@061XD01/N
5`0L7aH00P0L81@0300J7Q<07B0F01/N500K7aD0720F01`O5P0N81H07AlC01`M4`0M7QD07AhF01dN
5@807AhF00<06adF01XM5@0J7AH00P0H6aD01P0H6a@06A/C01/L500J6a<06A/B01PI4@8061XA00/0
6Q`C01HG4@0E5Q405AH@01DF3P0G5a005aLB01DE4@0D50l05QLB01HF4P0201DD400<014@2`0C4`/0
4a@=01<D300C5@d05AT=018G3@0@5@`04A@<00lB2@0>4@P03Q090P0>4@T02`0>3`L03Ph700lA2`0>
4a003Q8D00d@5`0>3QP03``E00h<3P0=3P/02P`9008030h<00P0310>00P;3@010PD0000200010@00
0040000300401@80000600T0000400000`0000<0000300000P0000400P0100<10@0300006_oooon]
0?n000oooooo000=ooooo`0603U0>00mACd0@4U1045;@`0i@3d08bP[0P0K7b002`0L8A`05a/E01HK
4P0G6`l06Al@01`Q4P0L81807B4B01dP4@0M818071lA00807B0B00/07B4B01`Q4P0L8Q<06QlC01/P
4`0L8A@06R0C01/R5@0L8QL07R<H020S6P0201lS6P08020S6P0P91P08BDG020T5`0M8QD07B<G01hU
600P:1H202<Z6@0?02<X6@0R9AP08RHI028V6@0T:1X08RLH024V5`0R9aP092XI02DZ6P0W;1`09R/M
02HZ800T9al092LN008092XP00/08bXM02@/700U;Q`09RdK02P^700V;1d09RXN02L[7@0V:a`09B/K
02H/6`0202L/700;02L]7@0V;Al08b/M02<Z6@0U;1X092/J02H/6`0V:a/09B/J02T_700X;Q/00P0X
;AT0300X;a/0:BlM02DZ6@0V:aX09RXK02DY6`0W:a`0:RhO02``800[;b00;2lQ02d_8@80;30R00/0
:RlR02L/7P0W;1/09bdK02P_700Y;ah0;30N02X_7@0/<200;2hP02T[7`0202X]800;02X^8P0V:B00
92HM02<V6P0R9AT08bDI02HV700U9Qd08R@L028T6`0Q8aT00P0N8AH0300O8AD08RDF024T5P0R91D0
8RDE024U5@0O8Q<07B4B01dP4@0M8A40720@01`O4@80720C00/06alB01/N4P0K7a806AlA01TP4@0O
:AT03A0=00`>300<3P/02`d;00X<2@02014E3P0901<H3`072@D01PL200H80`051`<010H300H71006
1`D01PP500801@P50P0520@01P051`@01@P500D810062@<01PP300P80a[ooooo[@3oP00?ooooo`00
3Oooool01P2DZYH0VK6M09bfX02M^:00SjJ@0419B0804Q@J00/06AdL01<F500?4Ph03Q89014E2P0E
6P`05a`<01LL3@0H70`06Ah=01XO3P0201/O3@0:01/O3P0J7@l06QdA01/N4P0M81D07R8G01dR5P0M
8aP07B8H01dR6@<07B<I00`07R<I01lT600O9AH07bDF01dR5@0N91H07RDE01dU4`0O9Q@08BHF028V
5P0R9AD2024T5P0;028T5`0P8QD07R0C01lR5@0Q9AL082HH028W600T:A`09BTP02<V7`0R9Qh00P0T
:Al02`0S:A/09R/J02L]6@0W;1L0:2`H02/_7@0Y:ah0:2/M02X/7P0Y;Ad0:2`K0080:2dK00/0:2`L
02DZ6P0U:QX09R/K02P_700Z<A`09RhK02@[6P0U:QP09bdH02P]5`0202P^5`0<02P]5`0W;1L092TE
02@X5P0U:AT08bLH02DW6@0W:A`0:BXO02X]8@0/;R40;S4S0P0/<B802`0Z;b00:2dM02T`7P0Y<Ad0
;3<O02hd800^<b00;C4Q02hc8`0_=2D0;C4R0080;S4R00/0;S8T02h`900[;B80:2XP02P/8@0Y;R40
;2lR02`_900W:b009RTL02DX6`0202<U6@0<02DW6P0T:1T08bLG02@V5P0U9aL092LG02<W5P0T9QH0
8bDE02@W5`0S9QL082@F0P0Q9AL02`0O8aL07R8E020S5@0O8a<0724B01`Q4@0K7a0061`>01DJ3`0E
6A405APC00805AXC00/05Q/A01DI3@0D6@`051P=01<F300A50/051L>01LI400F61404aHA018E4003
018F4@0501<F4`0D6A805A/B01@I4@0C5a006_ooool50000ojP0oh003oooool000gooooo00H0Uk2N
09^eY02O^ZD0WKRQ09^eW@1RLfL201TM8P0;01DI6@0F6QL04QHB01<H400E6Ph05ah>01TP3@0H7`h0
61h>01XP3`0L8A400P0O8Q402P0N81007b4C01lO5@0N81P07R0I01lQ6P0O8QX07R<K01XP600K8AP3
01`S6@0<01hU600M9AL07BDE01dT4`0O9A@08RLF028Y5P0R:AD08RPE02<X5`0T:1L08bLF0P0S9QL0
2`0T9aP08bLG028U5P0R9QL08RHH028V6@0S9aT09R/N02HZ800S9ah08BHL00808b/L00/09BdJ02P^
5`0Z;QH0:B`F02/]6@0_<1h0<2lP02`/7`0`<280;RlQ02d_800202h_7`0;02T/7P0U9a/09BPL02DY
700X;a`0:S@N02</600T;1P09B`G02L]5`0W;AH00P0W;1D0300X;AL0:BhJ02HZ600U:1L09BPI02DW
6`0U9Qd09bLO02LW800X:R80:bhT02d`9080:c4R00/0:S4P02L^7@0W;aX0:S4J02/b6`0]<a`0;38L
02X`7@0[<1h0;C8Q02db8P0202d`8P0;02la8`0`<b@0;C4R02``900[;b@0:RlR02/`8P0/<240:RhO
02P]700W:a/00P0W:AX01P0V:AT09BXI02L/6P0W:aX09bXJ02DW6P8092HH00@092DI02DU6`0R8aX0
8B8I0P0R91X02`0O91P07R<F01dR5@0O9AH07RDE01hU5P0O9AL07B8E01PN4P0G7A<05QXD00805AXC
00/05AXA01DJ3`0H70l05aX?01LG3P0G60l06ATA01TJ4`0H6Q<05QPE01@G500201<F4`0601HI5@0E
61@05ATC01LL500F6a<05AP@6_ooool50000ojP0oh003oooool000gooooo00H0SjJD09^eX02P_JD0
Wk^S09jkX024WHP203U5@00;01PL7@0I7QX04aTC014E3P0C60l051X>01LM3`0J8A40728C01`P4`0O
8aD00P0Q91L02`0R8aH08R<G024R6`0P8Q/07R0I01dO600K7aL0728I01/Q600L91L072<F008072@E
00`07BHE01hV500P9a@07bDC020W5@0S:AL08RHE02<W5@0U:AP09BTI02DX6@0T9aP202@X6@0;02@Y
6P0U:aX09BXH02DY6@0S9aP08RHH028W600S:1/08bPN020V7P0P9Qd00P0T;1d01P0W<1d0:S4J02/a
6P0]<1/0;BlL02`]7@80;blQ00<0;S0Q02la900_<2<00P0_<B802`0];b40:B/N02X/800X;1l09B/J
02D^6@0U;AP092/F02H]5P0W;AL0:2hH0080:S0I00`0:blK02T/700W:Q/09R/L02<Y6`0T9a`08bHL
02PZ800X;240:BdR02/_8P0/<R8202X`800;02Ta800Z<Ql0;3<N02le7P0`=Ql0;c@Q02`_800/<280
:c0S02`b900^<RD00P0]<R@0200^=2@0;c<T02hc8`0^<b<0;S<T02`b8P0]<b40;38O0P0]<Qh01P0]
<B00:bhO02/^7`0Z;Al09b`M02L/7P80:2`O00D09BXN02HZ7@0W:Q`092LJ02<U6P02028T6@808bHI
00/082DF01lV5P0P9QD08RPE024W4`0O91@07b<F01dR5@0J81D061hE01HM4`0201HL4@0;01HM4@0H
7Pl06Ah<01TL300I6Pd06AT?01/M4P0K7Q<06A`D01XM5P0G6aD00P0F6QD01P0H7AH05a/D01HK4P0G
7Q805Q/?01DH3A[ooooo1P000?nW0?n000oooooo000=ooooo`0605eYF@1iRg<0SJF809B^TP2J]iP0
UkFE0P1OM5h02`0J81`041@A00lD3P0<40X03Q4;014E3@0E6`l061hA01TO4`0J7a@07R<G008082DI
00<08RLJ028V600Q9AT00`0P8aL01@0P8aD07B4D01hR500O91H07R<D00807R@C00`07bHD024W5P0S
:1P092TJ020V600R:AX08RTI024W600T:Q/09BXK02H[6P0W;1/202L[6P0;02DZ6@0U:AP09BXH02DY
6@0S9QL082DF01lU5`0O9AX082HM020W7`0S:Ql00P0V;2002`0V;Qh09blK02Xa700[<A`0;C8N02``
7`0]<B00;2lN02da800^<b<0;c<T0080;c4Q00/0<34P02h_7P0];Qh0:R`K02T]6`0W;AX092/G02@[
5P0V;1L0:2hI02T_6`0202P`6`0<02P_700W;A`09bdN02H[7@0U:a/092XI02@X5P0W:QX0:R`M02X/
7P0[;Al0;2lO0P0Z;al02`0[<B40;3<Q02dd8P0`=b@0<CLU030d9P0_<RP0;c<Y02`a:00[<2H0:c4T
0080;38S0P0/<R@02@0/<b80;C<Q02hc8@0[<Ah0;C<O02le7P0`=1l0<38P02la8@0202d`8P0<02/_
8`0Y;R409R/O02L]800T:ad08b`M02@/6P0U:aP09BXI02@W600S9AL08R@F0P0R9AL02`0Q8aD08BDC
028V4`0Q9Q4082@@01`P4@0N8AH06alE01TM5P0H7aH05ahB00805Q`@00/051X>01DK300D6PT05AX9
01DJ2P0E6@/061d@01TN4P0I7a806R0D01/Q500201TO500601LN4`0G7A005Q`>01HL300G6`d05AP<
6_ooool00`3oP000003o0000o`030000ojL0oh003oooool000gooooo00H08RPL02lf:012C3X0E6=9
06^1G`23WgD207:;I00;02@Z7P0@4`h04QP?00lB3@0=40`04QH?01DK400F7A006AlB01/R500M91H0
0P0O9AL02`0Q9QL08BDF024T5`0Q91L08bDJ02<W6`0T:1/08bHH028T5P0R9AH082@D00808BHD00`0
8RLE028V5`0R9AP08RDJ024W700Q:A/08BPJ028Y6P0S:A/092XJ02D[6`0W;AX202T_6P0;02P]6P0U
:AP09BPI02DX6@0T:1X092XJ02@Z700R:A`08b/N02<Z7@0S:Q/00P0T;1/02`0U;A`09BlJ02H^600Y
<AT0:S0I02X_6P0/<1d0:c4N02`b7`0/<R40;c@V0080<C@V00/0<C8R034b8@0^;Qd0;RlL02/_6`0Y
;Q/09B`H02@/600S;1P08RTH02<[6P0202@/600<02H^6P0W;Q`09b`L02L/700W;1/09R/I02DX5`0X
:QP0;2hL02/]700[;1d0;2dN0P0Z;Ql02`0Z;al0:c4P02`b800^=240<3DS038f9`0a=2T0<3DZ02hd
:00]<RD0:c4Q00<0;34Q00X0;38S02hf900_=R<0;cDR02`b7`0]<b00<CDQ038d7`0b<b00;c0O0P0[
;Qd0300[;ah0:2`K02L/6`0W;A/09B/J02@[6P0S:aP08b/F02H/5P0W;1T09BTH02<V5`808bLG00/0
8bHF028V5@0Q91D07b<B01dQ4@0K8A407B8D01/P5@0I7Q@05ahC01LL400201LL3`0;01<G2`0E6@`0
5AT;01<G2@0C5PP05AP:01LL3P0H70l05ad?01TO4@0J81<00P0I7a<01P0G7A405Q`?01@I2`0D5`L0
51H8018D21[ooooo103oP0040000ojD0oh003oooool000gooooo00H08RPL02lf:012C3X0E6=906^1
G`23WgD207:;I00;02@Z7P0@4`h04QP?00lB3@0=40`04QH?01DK400F7A006AlB01/R500M91H00P0O
9AL02`0Q9QL08BDF024T5`0Q91L08bDJ02<W6`0T:1/08bHH028T5P0R9AH082@D00808BHD00`08RLE
028V5`0R9AP08RDJ024W700Q:A/08BPJ028Y6P0S:A/092XJ02D[6`0W;AX202T_6P0;02P]6P0U:AP0
9BPI02DX6@0T:1X092XJ02@Z700R:A`08b/N02<Z7@0S:Q/00P0T;1/02`0U;A`09BlJ02H^600Y<AT0
:S0I02X_6P0/<1d0:c4N02`b7`0/<R40;c@V0080<C@V00/0<C8R034b8@0^;Qd0;RlL02/_6`0Y;Q/0
9B`H02@/600S;1P08RTH02<[6P0202@/600<02H^6P0W;Q`09b`L02L/700W;1/09R/I02DX5`0X:QP0
;2hL02/]700[;1d0;2dN0P0Z;Ql02`0Z;al0:c4P02`b800^=240<3DS038f9`0a=2T0<3DZ02hd:00]
<RD0:c4Q00<0;34Q00X0;38S02hf900_=R<0;cDR02`b7`0]<b00<CDQ038d7`0b<b00;c0O0P0[;Qd0
300[;ah0:2`K02L/6`0W;A/09B/J02@[6P0S:aP08b/F02H/5P0W;1T09BTH02<V5`808bLG00/08bHF
028V5@0Q91D07b<B01dQ4@0K8A407B8D01/P5@0I7Q@05ahC01LL400201LL3`0;01<G2`0E6@`05AT;
01<G2@0C5PP05AP:01LL3P0H70l05ad?01TO4@0J81<00P0I7a<01P0G7A405Q`?01@I2`0D5`L051H8
018D21[ooooo103oP0040000ojD0oh003oooool000gooooo00H051T?01TN4`0K81D06b4E02P_7P0l
Abh2045?=00;02H/700Q9QT0724F01LL4P0C6@h05A/?01HM400G7Q406AlC01`S5@0N91H00P0Q9QP0
2`0R9QT08RLI028U600R91X092HK02DW700U:1/092PJ02@V600T9AH082@B00808BDB00`08BDD028U
5P0T9aT08bLK02@X7`0T:Ql08RPM02<Z7P0U;2009B`O02@Z700T:aX202L]6P0;02T^6P0W:aT09bXI
02T]7@0Y;B00:B`P02T]7`0X;Ql0:BhN02P]6`0W;AP00P0V;AH02`0V;QP09BdH02H]5`0[<AX0;34K
02`^6`0^<1d0;S4M02da7P0]<b80<3DU0080<3<T00/0<C8T02h`8@0];ah0;C0N02X^700Y;QX0:30J
02L_700V;Q/08BTH01hV5P02024X600302<Z6P0V:a/09b`L00809b/M00L09RXK02@W6@0W:aT0:RhK
02/_6`0Z;Q`0:blM0080:bhN00/0:c0M02`a7@0/<Ah0;38O02ld8P0b>2H0<SLX030f:@0`=RP0;C@T
02/a7`0202`b7`0;02hd8@0_=b@0;SHS02de8P0_=R<0;cDS02ha8P0`<R00<S@Q038c8@0`<Ah00P0_
<1`0300];aX0:RdI02X^6`0Z;a/0:RlL02T^700X;A`0:2dJ02P^6@0Y;Q/0:BhM02T_7@8092`K00/0
8RPH02<X5`0Q9AD07b4C01lR4`0O8a@07R8C01hQ4`0M81@06QlB01XO400201PN3@0;01PL2`0H6P`0
61T=01LH300F5`/05QP:01TK3@0J7@h05a`>01PM400I7a800P0H7A801P0F6Q0051L>01@F300B5PT0
4A<700h@11[ooooo[@3oP00?ooooo`003Oooool01P0>4PX041@=018E3P0D5Pl05aXC01/Q5`807RDI
00/07B<G01/P500J7a8061h?01LO3P0F70`05Qd=01PO4@0F710061lA01/R4`0201lU5@05028W5`0R
9QL08BDG024U5`0T9aT00P0U:1X0100U:A/092LI02DY6@0V:aX202@Y600<028W5`0R9aP08bPJ02<X
6`0T:1h09RXO02HZ800V:al09b/O02DY7P0S:1`09R/L0P0X;A`02`0Z;ad0:BhL02P]700X:ah0:B`Q
02T]8@0X;200:BhO02X^7`0Z;Qh0:2dJ00809BXF00/09B/H02T^6`0Y;a/0;38L02hc7P0_<al0;c8O
02h_7P0^;al0<C<S038f9P02034d9@0;03<e9P0a<b@0;S4P02hb8@0]<b40;34O02/b7@0Z<Qd0:C4L
02L_6`0T;AX00P0U;AX0300W;A/09R/K02HZ6P0X;A`0:BhN02L/7P0T:Q/09BdK02P`6`0X;aX0:2lL
02Xa7`<0;34O00X0;30N02da7`0^<al0;S@O02hc800b=RD0<cPY038h:@0_=BD0;38Q0P0/<al01`0/
=1h0;3@P02lf8`0`>2H0<CLV030d900`<R800P0a<R40400_;b00;RlN038c7`0b<al0<30N02`_7@0[
;Qh0:RhM02``7P0Z;Q`0:BdL02X^7@0Y;Q/0:2dK02X_7P0Z;b0202H^7`0;02@[6`0R:AT08bPG028U
5P0Q91D08B<F024T5P0P8QD07R0D01dQ4`0M81<00P0M7a001`0M80l06ah=01PJ300H6@`061T=01PI
300I6`/00P0I70/02P0J7@l05aX>01DI3@0E6@d05QT>01LJ3`0D5``04AD800lB1@0?4@DJooooojd0
oh003oooool000gooooo00H02`l700hA2@0>40L04Q<:01DG3`0G71D201XO5P806AlE00D06b0E01XP
4`0J8A<06R0B01PO400201HL3`0?01XQ3`0L8a007B<A01dS4@0O9A<07b@C024T500S9QH08R@F02<U
5`0T9QL09BPJ02@X700U:ad092/N008092/M00P08b/L028Y700Q9a`08bTM02DY7P0V:Qd09b/N02DX
6`809RXK00P09RTJ02X/700X;1d0:2`M02X_7`0Z;ad0:c4O02/`7`80:RlO00<0:C0O02P_7P0X;Ah0
0P0Y;Qh202L^7@0:02P_7@0Z<1`0:BlM02X`7P0/<Al0;S8O02/^7@0[;Qh0;S4Q030c90<0<SLW00/0
<cLX034f:00`=BL0;c<U02dc8`0/<R40;3<N02Xd700[<a/0:C8J02Tb6`0202/d7@0<02/b7@0[<1`0
:BdL02X^700Z;Qd0:BhN02P_7@0X<Q`09c8I02H`5`0V<1P0:C8L0P0[<Ql02`0]<b40;c<Q030e8P0_
=240;C8O02db7P0`=200<SHS03Di9P0c>BH0<3HS0080;SDQ00/0;C@O02lf7P0_=Qh0<CPR034g8`0`
=R<0<3DR038f8`0`<R40;RhP02d]7`0302d^7P0;02`]7P0Z;Qh0:blO02/_7`0[<200;34Q02/_8@0Y
;Al0:RhP02/_8P0Y;R800P0X;b002P0X<1l08RTJ01lW5P0O9Q@07bDC020U500R9aH08BDF024S5P0P
8QD301dO4`0;01lQ4P0N8A407Ad>01dN400L7A806adB01TK3P0J70d06ad=01XL3P0H6`h00`0F6`h0
1@0G6`h04aL;010D2@0@50T04A@901[ooooo[@3oP00?ooooo`003Oooool01P062@801`/200/>100A
50T061/A01PL50805QTC00/05QTB01XN5`0L7aP06alD01`P500K81<06AlB01PN400H7a006B4?01`T
4@0201dU4@0;01lX4`0O9a@07bHE02@Y6@0T:1T09BPI02HX6P0W:a`09b/N02L/800T:R000P0T:b42
02H]8P0:02D/8@0U;2009B`N02L/700W;1/09BTI02HY600W:aX09bXI02X/6`80:bhM00/0:c0O02/_
7@0/<Ah0;S@P02db800Z<1l09bhO02P_800Z;b00:S0O02X_8@0202T_8080:C0N00T09blM02T`7P0Z
<1d0:BlN02`a7`0[<1l0:c0P02db8P0`=RD00P0a=bH02`0b>2P0<CPX030f:@0a=b/0;cDW02/b900Z
<R00:C8N02Tb6`0Y<aT0:c@I0080;CDL00`0;SDN02hd800_=240;C0O02`^7`0[;al0:c0N02Xa7@0Y
<AX0:C<J02Pa6P0Z<A`202`b7`0502lc8P0`=B<0<CHT034g900`=R400P0`=Ah0100_=1h0<CLQ030f
800`=B42030e8`0;030e8@0`=R00;S@O02lf7`0^=200;cDR034g8`0`=R80<3@R02ha8@0^;b000`0[
;1d02`0Z;1d0:B`M02T]7@0Y;Ah0:blP02`a800[;ah0:RdN02T/800Y;B40:RlR0080:BhO00@0:2hM
024X600P:AD07bPC0P0N9Q401@0Q9a@08bTG02<W5P0O8a@0720C00806b0C00X07R8D01dP4`0L7Q80
71hC01/N500J71<06adB01dO4@0L7`l06AX=0`0I6`d01P0I6``06A`<01PK300E6@/04aP;014F2a[o
oooo[@3oP00?ooooo`003Oooool01P072P802@`300dA1@0B5`/061d@01TM4@805AL>00/04Q8<01<F
400A50h04QD=01@I3`0G7A406B0B01/R4P0K8Q006b<?01`T3`0201dV3`0;01dV4@0N9Q@07R@F024V
5`0T:AP092LH02DZ6P0Y;ad0:BlN02P^800V;2000P0T:b402P0U;2809RdS02L^8`0V;B409B`N02H]
7P0W;Ad0:2dL02T^6`0Y;QX202L[6@80:RlL00/0;34M02da7@0/<A`0;C8M02``7@0/;ah0:RhO02T^
800[<280:c0S02X^8P0202X_8P0;02/`8@0/<b80:c@Q02Xb8@0W<1d09RhL02Ta7@0Z<Ad0:c4M02`c
7P0_=R400P0a>2@02`0`>2H0;SLT034i9`0c>RT0<CTY02hh9P0/=b@0;3HR02`f7P0Z=1X0;3HJ0080
;3DK00`0;C@M02hd7P0^=1l0;S8P02d`800]<B40;C8R02`b8@0/<b00:c<N02Ta700Z<A`202dc7P0;
02ld800_=B80;cDR030f800a=ah0<3@K038e7@0a=Al0<CHP034g8@0a=R400P0a=b@02`0`=R80;c<Q
02hc800_=200;c@Q034f900b>2D0<CLT030f8`0^=280;30P0080:B`N00@0:B/O02X[800[;B00:RhO
0P0Z;al01P0[<1l0:RhO02X^7`0[;b40:2`O02L/7@809bhM00/09bdL02@/6P0T;AP08b`F01lX4`0N
9Q808RPE02@Y5`0S9aH08RLG024W5`0201dS500;01`R4`0K7a806AdA01PK400G6a405aXA01PK4P0M
8A@07AlD01TJ400G5``00P0J6P`01P0K70/06Q/:01TL2P0F6@X04aL8014D1a[ooooo[@3oP00?oooo
o`003Oooool01P062@<02@/400X=100;3`D03A86014E1`8051L800/04QD900dA2@082`D02@`600lD
2@0B60`04aP<01HL3P0J8A4072<B01`T4P0201dU4`0;01hV5P0O9QP082PI028X6P0S:AX08RTH02D]
6@0X<A/0:30K02P`700X;ah00P0T;1h02P0U;Al09BdP02H/800X;R40:2lQ02T`8@0Z<1l0:c8O02/a
7`0Z;ad202X_7P80:RlM00/0;34M02db7@0_=1d0;c@M02hb700_<A`0;30M02P[700X;1d0:blP02/`
8@0302/`900:02/a900]<b@0;3<S02Xb800X<1d0:34L02Ta6`0[<a/0;3@L02lf7`80<3LR00/0;cLR
02dg8P0`>B<0<S/T034k9P0`>bH0<3XU034l9P0`>R80;SPO034j8002034i800<034g800_=Ah0<3HN
034e800a=280<C@T030c900_<b<0;cDS02he800/<ad0;3<K0P0/<Q/02`0]<A/0<3DO030f800`=Qd0
<CDL034e6P0c=Qd0=CTR03<h8P0`=b40;cHQ0080;cLQ00/0<3LQ030f8@0^=B00<3LQ034g8P0b>2D0
<CLT02le8P0_=R<0;c@R02db8@0202X_8@0<02T[8@0Z;280:R`R02X^8P0[;b80:RlQ02T^7`0Z;b00
:blR02/`8`0Y;R009R`L0P0W;Q`02`0U:aP09B/E02D/5@0V;AL09B`F024V4P0Q9Q@08RDE024U5P0Q
9QP082LI00807bLI00/07bHH01dS5@0K81<06QdA01`O4P0K7a80720C01lR5P0N81D06adA01XK3`02
01XK3@0601XL300I6PT06A/:01TK2P0G6@/04aD86_oooon]0?n000oooooo000=ooooo`0600@50`05
1`<010L100H900082`402a020P0B5`H02`0B60P041@500X=0P0:3@@03A0600`@1P0;3@D03A4701<H
300I7Q40724C00807bHE00/08BTI024X6P0R:Q/08BXJ028Z6@0P:1L08R/G02</5`0T;AL09RlI02La
700202H_7@0<02D/700X;al0:RlP02/`8@0]<R80;C4Q02hb8@0^<B40;C4P02db800^<b80;S<Q0P0/
<B002`0/<b00;SDQ02le8@0`=B40;c@P02hd800]<B00;2hM02//7@0[;Ql0:RdO0080:blQ00/0;C4R
02db900]<RD0;C@T02`e8`0/=B80:c@Q02Xc7`0X<A/0:S<L02Xd7P0202`e7`0:02`f800_>B80<C/T
030k8P0b>b<0=3`U03Dm9@0c>b@0<cXS038i8@<0<STR00`0<SLR034g8P0b>B80<CHQ034e800c=B40
<S<R02lb8P0^<b80;cDR02`c7P0[<Ad302`a6`0:030f7@0_=Qh0<3HO030f7P0b=ah0=3TP03Lm900g
>bH0<SLT02le8080;SDO00/0;cDO034g8@0a>240<3PQ038i8P0`=b40;SDO02`c7@0[<Qh0;38O02he
8@0202dc8@0<02/^800Z;B40;2lS02`_8`0]<280;C0Q02X^800Z;B00:bhP02/`8@0[<1l0:RlN0P0Y
;a`02`0W;1H09b`D02D[4`0W:aH0:2dJ02@W5`0Q9AL08RHH024U5`0P9QP07bHH008082PI00/07bHH
01dS5@0M8A<07b8E024T5@0N8180720@01lS4P0N8A80720A01`P4P0201XL3`0601PJ3@0J70l06Q`@
01XL3`0G60h04aD;6_oooon]0?n000oooooo000=ooooo`0600<61P041`D010L100@700031P001`X0
0`0;3P402P0<3`403Q42010A100@4@H0418800h>1P0<3@H02P`500h@200D6@`201TM300;01hT4@0Q
9aD08RXG02@/600S:aL08BXG024Z600R:aL09BhH02H_6P0V;a`00P0W;a`00`0W<1`0:C4L02/`7002
02da7`0302da800^<B40<3<S00<0<CDT00h0<3DS02dc8P0]<b80;3<R02de8P0/=B40;CDQ02he8P0`
=R80<CDS02la7`0/;AX0:bdK02`]7@80:bhO00/0;34O02hc8P0_=2@0;SHU02`e900Z=280:c@Q02`e
8P0[=200:S@O02`f7`0302/e7P0:02df800_>240<CXQ03<k8@0e?B<0=C`T03<j8P0a>240<cTS038h
8P80=3TT00`0=S/W03Dk:00e>bL0<SLT038f8@0c=R40<cDR034d8@0_<b80;S<Q02/a7`0[<Ad202/c
700;02/b6`0]=Ad0;SHN034h800`=b40<STP03<j8@0c>b<0=3/T03Dl9P0b>B<00P0^=1l02`0_=1l0
<CLQ03<j900c>b@0<STR030g8@0_=b00;SHM02`c700^=Ah0;cHO0080;C<M00`0:c4N02da8@0]<B80
;S8T02hb8P0_<B80;30R02`^8`0]<2<0:c0Q02/_7`0Y;Q`202L/600;02@[500S:a808bTB02@Y500X
;1/0:2`L02DY700T:1`08bHI020U6@0M8aP00P0N91P02`0M8aP0728F01/Q4`0L8Q@07B<D01`Q4P0J
7`h06b0>01`P3`0L8A00720@00806Q`?00H05QT=01PL400G6a405a/B01DH3`0A5@`Jooooojd0oh00
3oooool000gooooo00H00`P500<90`052@401@T000<700021@0200<6000;00@600061P002`X101<B
1`0H6P`05aP<018B200=3`H02@`300L:0P093@<00P0=4P<02`0D6PL0728>024Y500U;QT09BlJ02H`
7@0W;b009c4O02La7P0V<1d092dH00808bdF00`09S0H02Pa600Z<AT0;C@M02hb7P0^<B00;c8S030c
9P0`=BT0<3DX034g:@0`=RP202he9P0;02de900^=R<0;SPS038i9@0c>B<0<SPS034f8`0`<b00;RlM
02l`7@0`<Al00P0a<R801@0_<b<0<3DT030e900`=bD0;cLU0080;3HS00@0;CLS02hh8P0_>1l0<3TO
0P0_=ah01P0]=1`0;C@N02hd7`0^=B00<CLR03<k8`80<STR00<0<CPQ03<i8@0b>2000P0d>B80300g
?2H0=S/W03Ll9`0e>bH0=3TR03Hi8`0e=b@0<SDR034e8`0^=2<0:c8P02Xa7@80:S4K00/0:c<M02Xd
7@0^>Al0<3TO02lg7P0`>1h0<CPO030h800d>R<0=S`V03<j9@02030f8`0402ld8P0]<R00<3HT03@l
:080<c/W00D0<c`U034j8`0`>240<CTO038i7`0202he700402dc7@0^=1l0;c@Q02ld9080;c@V00H0
;S8U02da9P0[;bD0:bhT02X^8@0Y;Qd202P_6@0;02H^5`0T:a@09BXD02H[5`0Y;A/0:2`L02T]7P0W
:ad09BTL02@W700P8aX00`0M81L00`0N8QH07R@F01hT5P0201dT5`0501dS5`0K8A<06R0@01/P4@0M
8A800P0L81001P0K7`l06Ad>01LL400G6a005AT=010D2A[ooooo[@3oP00?ooooo`003Oooool01P04
2@@010T300H:0@072`401`X000D800800PD000/00`H000L800081P003`h201DD1P0E5PP04Q<600d>
0P0;2`002`/100P9000200H7000;00`>0P0D5PT07B4C02@X6`0Y;b40:S<W02Xd:@0[=RP0:3<S02Lc
7`0U<1X00P0T;aH0300U<1@0:3<E02/d5`0/<QT0<3<M034d8@0c=2D0<S@X030d;00^<b`0;SD/02de
:`80;3DY00/0;SLW034j9P0a>RD0<SPS03Dj8@0d>200=CPQ03Dg800e=R00=SPT03Dg9P0203@e:00;
034c:00c=b/0<CHX030g9@0_>B@0;3HS02/d8@0/=B00;cPQ03<k8@0b>Al00P0b>1l02`0d>B40=3PR
03<f8P0b=R<0<CHT03<h9P0c>2@0=3/V03Dm9`0e?2D0=CdS0080=3`R00`0=ChU03Ln9P0j@BP0>ClV
03Lj900f>2@0=SLU03<e900a=2D0;S@U02Xc8`0Y<R0302Tc7`0:02Td7@0/>1h0;c`M02lk6P0_>AT0
<3PJ034i7@0d>b40=C`T03Dl9`80<STV00X0=3TZ038g:P0_=2P0;cHX034h:@0d?2P0=3dW038m9P0a
?2<0<3TP0`0`=ah0300`=al0<3HQ034e8P0`=2@0<3DW02ld:@0`=BT0;S<Y02``9P0/<BH0:BhQ02P]
7P80:30M00/0:30K02P`6@0Y;QP0:BhI02/_6`0/;Q/0;2`K02/[700[;Ah0:B/N02@T6@02024Q5`0;
01lP5P0O8QP07b<I01hT6P0O9A/08BLM024W7P0O9AX07BDG01dS5@0N8a<00P0L8@l01P0L8@h06b0>
01XP3P0I7P`061/901<F1Q[ooooo[@3oP00?ooooo`003Oooool01P072`<020`400/=100<3`<030d3
00X;0@8020X000L02@/000T:00092@002P/000X:000<304030`000803Pd100l030/100`90P091@80
2@D200P50P0:1`D05ADB024R7P0W:RH0:C4[02Tc;00Y=R/0:CLW02Pg8@0W=1`00P0W=1P0300Y=AH0
:SDE02de5P0]<QP0;c4L038e8`0c=RL0<cDY030c:P0_=2d0;CD^02dg;@80;CLZ00/0<3XY038l9`0e
?2H0=S`T03Ll8`0h>R40>c`T03Xk9P0k>bP0>SXZ03Pi;P0203Hg;P0;03@f;`0c>2h0<cX]038k:@0a
?2L0;c/T02hh8@0`>B00<c`Q03Lm8P0h?2800P0k?RH02`0l?RT0>CXY03Pi:P0g>B`0=CP/03Hk;@0f
?B`0=CdY03Lo:@0g@BP0=SlU0080=3dR00`0=CdR03Pn8`0i?R@0>clW03Xm:P0i>b/0=cT[03<e:@0a
=BP0;cHX02/d9@0[=B@202/e8`0;02Xe800Y=1`0:SDI02`h5`0^>QL0<3XE038k5`0f?Al0=S`R03Hl
9@0g?bX00P0g?bd02`0f?Rh0=3d^038k;@0_=bP0;CHT02lg8@0a>R00<cdQ03<l7`0a>Qh0<CPN0080
=3TP00`0=CPS03@g900d=RH0<c@X038f:`0`=B`0;cD]02hd:`0[<BL0:S4U02Ta8P0Y<B4202Tb800;
02Pa7@0Y<Q`0:c8K02/_6`0];Q/0;RlM02h]7@0_;B00;R`Q02`[8@0X:1l00P0U9Ql02`0Q91`07b8L
01lU7@0O9A`07bHL020X7@0Q:Ah07bLJ01hV5P0N9A@07RHB008072@>00H072@<01dU3P0N9@d07R@<
01dQ300I6PTJooooojd0oh003oooool000gooooo00H02P`500`=1@0?40H03Q0600X;0`07204200D7
000;00T:0@0;30402P`100T;0007200020T000`<000>3P@03@`400d;0`0;2@<00P091@<02`0910L0
20<800`93P0E5AP07B4Q02@[9`0W<RX0:3@X02Lf900X=b009cDL0080:CDJ00`0:cHI02hh600_=QX0
;SDM030e800b=R@0<cLY038f:P0`=R/0<SL]034j;`0`>Rd202lj:P03034l9`0`>bD0<c`T0080>T0W
00H0>chV03`m9P0m?BX0?Cd]03Pi;@0h>Rl203Lk<00;03Hk<P0f?340=3`^03<l:`0d?BX0=3hX03<l
9@0e?2<0=cdS03Xn900l?BL00P0n?BX02`0m?2d0>ST_03Ti<@0h>S80=CXa03Dk<00f?Rl0=Cl/03M2
:P0i@bP0>T8W0080=chT00`0=c`T03Pl9@0j?2L0>cd[03`n;`0l?c80>3da03<j;P0b>R/0<C/Y02li
9`0^>2@202`f800;02`f7@0[=AT0:C<E02Xb4`0[<a@0;SLD034j5`0c>A`0<cLO03@k9@0e?2P00P0d
?R/203<n;@09038n:`0a>bH0;cTP02hg6P0^=aL0<S/I034i6@0c>A`0=STO0080=cTS00`0=cLU03Dd
9`0b<BL0;c0W02da:@0^=Bd0:S8/02Xb:@0Y<RH0:S<S02Xb8@0Z<B0202de8P0;02dd8@0/<Qh0;S8M
02h_7@0`<1l0<C0Q034_8`0a;RD0;BXS02/Z900X:bH00P0U:BD02`0Q9b407B<M01dT700L91X07bLL
01lX6P0P:AX082TH01lX500N9a807bPA00807RL>00H072<:01dT2@0N8PX07b<<01hQ3@0L70`Joooo
ojd0oh003oooool000gooooo00H03Q8:00d@2P0<3`P02Pd500L910051`<200@60@0400L:0P0;3P<0
2Pd200P;008020X000D02P`100d>0`0=30<02PP200H40@0200@2000;00P5100=2PX030X=00d<4@0C
5AT06alQ028Y9`0U;bP09C8V02Hc8`0Y=B400P0[=b00300/=al0;cLM02lf700_=Qh0;cDQ038e900g
>B/0=CL]03<g;P0e>C00=3T`038j;@80<3/[00/0<3/W034m9@0c?RD0=SlU03Lo9@0h?bD0>ChU03Pk
9@0k?BT0>S`/03Xl;P0203Tl;P0;03Ll<00f?300=3X^03Dl;P0e?Bh0=Ch]03Dn:P0e?2H0=C/S03Pk
8`0j>bD00P0k>bL02`0k>BX0>cT]03Ti<00g>C<0<cLb03Dk<P0e?C40=D0^03M3:`0i@bT0>T<W0080
>40U00`0>3hV03Pm:00j?RX0?D0]03ho;`0n@340>d4b03Ln<@0e?Rl0=3d/03<m:@0a>bD202dg800;
02df700/<aT0:C0F02P_5P0Z<AH0:S0E02`c5@0]=1T0;cDM034g8@0b>2D00P0b>BL02`0b>BT0=3`Z
03<k9`0a>R@0;cPP02hg7P0`=a/0<3LJ030f6@0b>1`0=CTN0080=SPQ00`0=SPT03Hg:00b<RL0;BlU
02/`9P0X;RH0:2lW02T`9P0[<bH0;3@U02dd8P0/<Al202db800;02hc8@0^<R00;S8N02l_700_;ah0
;blO02l/7`0`;R80;RdT02`/9@0[;BL00P0W:bD02`0S:24082DM01lV700M9AX07RDI01lW600N9QL0
7RHE01lW5P0P9QD082HC00807R@@00<06b0<01`R2`0N8Pd00P0N8@h00`0L7Pgoooooooooo`0Hoooo
ojd0oh003oooool000gooooo00H03A8=00`@300:30T020X600X<20072PL200D70`0;00D80@072@40
1`T100H80@072@4020X100T;0@082@0020P000L6000510000P040P002`081P<05AD>01PH5@0J6Q/0
7AdQ01lP9P0R9RX092`/02H_;@0V<R/09c8Y0080:C<U00`0:S@R02`e800]=Al0;C@N02lf800b=b<0
=CPW03Pj:`0g>2d0=CL]03@h;P0c>2d203@k;P0;034k:`0`>bP0<SdX03@o9P0f?bD0=SlT03Lo900f
?B<0>ChU03Xn:00j?R/00P0k?bh02`0h?Rl0=cd_03Lm<00f?340=Cd`03@n<@0e@2l0<chY03<l900e
?280=c`S0080>3/R00/0>C/T03Xk9`0j>bX0>C/^03Lj;`0e>Bl0=C/^03M0;`0g@Rh0>DD]03e8;002
03e7:@0<03a6:@0l@bX0?D4[03e1:`0m@2`0?T0^03i2<00k@340>d8b03Q1<00e?bh0<c`[0P0_=bD0
2`0/<al0:c4L02P^6@0Y;aX0:S4J02X`6P0[<QX0:c4J02`a700^<al0<CHQ0080=3TU00/0=CTV03Dj
9`0b>2D0<CLT034h900b>R@0<SdS038k800`>A`0<CTL038h7@0203@i7P0<03Di800h>R@0=SPV03<d
9@0`<bL0;C0W02/^9@0[;bD0;34U02hd9P0_=BD0;3<S0P0]<b@02`0/<b<0;C<Q02db7`0]<Ah0;S4M
030a7P0`;Qh0;R/N030]800^;B40;2/O00<0:b`O00X09bXO02<V700P91/07b<I01lT6@0M91T072@H
01lV6@0O9AP082DG0P0P91H01P0N8Q807B8A01lS4@0N8Q007B0@01/M41[ooooo[@3oP00?ooooo`00
3Oooool01P0=4Pd0310<00X<2@082PH02P`800L:1`801@L300/01@P100L90@072@401PP100L90@08
2P402@/100P9000820001`H000D4000200@2000;00P60`0E5@h061PE01XJ6`0M7B407b0V028V:P0T
;2`09Rl]02Hb:`0W<RT00P0Y<bD0300Z=280;3DP02de7`0]=1h0;cHP038g8`0e>2L0>3X[03Lh;@0e
=bd0=3P^03<h;@80=3/^00/0<C/[030k:00b?BP0=3lV03Ho9@0f?b@0=clT03Hm8`0i?RD0>ShX03Xn
:`0203/o;P0;03Pn;`0g?Bl0=cd`03Hl<@0e?C00=3ha03E0;`0c?RT0<c`T03Dl8P0g?2<00P0h>b80
2`0i>b@0>S/W03Xk:P0i>bh0=cX_03Di;`0e>bh0=d0_03M2;P0iABd0?DP/0080?DLY00`0?4HY03a3
:P0m@B/0?D4[03e0;00n@2h0?T8`03]0<@0k@S80>44`03Do;P0c?2/202lg9@0;02`c7`0[<A`0:2hI
02T_6P0Z<AX0:S0J02/b6P0[<AX0;34L02hc7`0a=R400P0d>BD02`0e>BH0=CXW038h9@0a=b@0<CPT
038j900b?B<0<S/P030i700a>A`0<SPM0080=3TN00`0=CTP03Pj900f>2H0<c@U030c9`0]<2L0:bhU
02/_9@0/<BD0;S@V02le9@0/<b<202dc900;02`c8`0]<b40;C8O02da7P0^<Ad0<34N030^7P0^:ah0
<2dP02h]8@0/:al00`0[;1l02P0W:Ql08bHL020T6`0O8aT07b@I01dT6@0L91P07bHI01lU600P9AL2
020T5P0601hR4P0M8Q407b<A01hR400M81006ad@6_oooon]0?n000oooooo000=ooooo`0600X>200:
3@T020/700P:1@092`H01`T40P0520<02`072PD01`T400L80`092P@01`T200H900072@001@P000@6
00031@000`@000800P8000/00`<000P9100G6Q<0;S@Y03Dk<@0a=C40;30^02X`;`0[<S40;cPc02`f
<00202Pa:@0<02D^8`0U;Ql09BdL02H/6`0X;QX0:S0K02`b7@0_=240<CDW03<f:P0e>2/0<cP/0P0e
>bh02`0b>R/0<3TY030j9`0d?BL0<cXU03@l9@0d?2@0<c/R03@l8`0e?2D0=SdX0080>3lY00/0=ShY
03Dl:@0f?B/0=S`/03Lm;P0g?c00=Sl`03Dn;@0f?R/0=ShX03Hn9`0203@k8`0;03Dk8P0f>b80=c`S
03Pm9P0i?BP0>CdY03Hl:@0e?BT0>48/03]5:`0lABX00P0j@bX0300k@b/0>T8/03U0:`0g?BT0>3hY
03Xo:P0k@2/0>d4]03]2<00j@Bl0>T8`03Hn:`80<3LT00/0;3<P02/a7P0Y<1h0:BlL02Xa7@0Z<1/0
:c4L02T_6`0W;AT0:RlJ02`a700202ha7P0;02lc7P0^=1l0<3HP03<i8P0d>bD0=3`V03Ho:00f@2P0
<chS038l8@0`=ad00P0^=1`01P0`=Q`0=CXP03Hj8P0e=b80<cDT030c9@80;BlS00@0:blR02/`900]
<RD0:c8T0P0Y<B@02`0X<2<0:C4P02Xa7`0[<1h0;C8M02lb7@0_;Q/0;B/K02/Y6P0/:QX0;RdJ0080
:bPF00/0:bTG02TY6P0V:1/092HL028T700Q8a`082@M01hR700N8a`07B<K01dS600201/Q5P0601`Q
5P0M8QD07R<E020S5@0O8AD06adC6_oooon]0?n000oooooo000=ooooo`0600H:0@072P8020/300X;
1009208020P20P0;3@D0200>4@X0418;00l?2P0?4@X03A0700/>0`092`401PT00P041P003P031@00
0P<00083000210000@<000L:1P0W<240<S`[03<j;@0g?c<0=3/a034g;P0e?C40=Clc0P0T:R@0300M
8a`06R0F01XO4`0K8A007R<A024V4P0R9Q<09BTD02/`7@0^=2<0<SPX03Dk:P<0>D4]00X0=ClZ03Ho
:00h@2P0=clW03To:00i?RT0>ClY03Pn:@0h?RX0=chY0P0h?bT02`0h@2X0>3lZ03Po:P0g?bT0>3lZ
03Y0;@0i?bl0>3h_03To<00j@2h0>T4/0080=S`V00/0=S`T03Hm8`0h@B@0>44S03Q0900h?bD0>40W
03Lo9`0h@BH0>D8V03]2:00203]2:`0403e3;P0l@S40>T0`03Ll;080=S`Z00H0=clZ03U1:`0i?bX0
>T4[03]3;@0h?bX203@j9P09030g8@0/<Ql0:S0O02X`7@0[<Qd0;38N02`b7@0Z<1`0:2dK0080:RlL
0P0[<1`02`0[<A`0:c8L02he7@0c>R00=3/R03Dk900f?RL0=chY03Ho:@0e?bP0<c/T00<0<3LO00/0
<CTP030g7`0_=B00<SPR034f8`0^<b40;S8Q02`a7`0Z;ad0:blN02`b8@0202he9@0;02dc9@0/<R@0
;C8T02/_8@0/<R00;S@P02hb7`0/;ad0:b/K02TY6@0Z;1T00P0X:AD02`0V9a<092HD02DW5`0T9QP0
8R@I024S6P0Q91d08BDN028W7P0O9A`07B<J00806b4H00H07B8I01/Q5`0L8AL07R4H01lQ6@0M7QLJ
ooooojd0oh003oooool000gooooo00H01@X200H:0@082`402P/200X:0@092P8200d@200;014E300E
6A005AP@01DI4@0F6Q004aP;00`@1P082`<01@P100D700051`400P041@002`0210000`D100<60@0;
40H051T<01lT5@0kABl0=cl[030f9@0g?bd0=d4`00807B<J00`05a`E010D3`0>4PX03a<801@G2@0I
70/071d>020Q4@0Y;A/0;cDR03@j:00g?b`203U2;@0;03Q1;00h@BX0>T<Z03]4:@0lA2P0?d@Z0455
;010ABd0?T<]03]1:`0j@2`00P0k@B`02`0l@Rd0?T<_03i4;`0k@b`0>D4[03U1;@0k@Bl0?D8_03a1
<00m@Rl0?48/0080>d0Y00/0>ClX03Y19`0lABT0?4DY03Y4:00i@RP0>T<Y03]3:00kA2P0>dDX03m7
:`020458;P0;0498<P11Ac@0?dDd03a3<P0j?bl0=S`Z03Ln:P0h?bX0=clW03Y1:@0i@B/00`0j@Bh0
1P0f?BX0;cLU02hd8`0/<b80:c<O02`c7P80<3HP00<0;C<O02`a7P0/<A`00P0/<Q/02`0/<Q`0:c4K
02/b700/<ah0;C@N02lg800a>B<0<SXU03@m9`0e@2P0=d0X0080<c`T00`0<SXR034h8`0a=b<0<3LS
030h8`0a>2<0<CTT02hf8`0]=B40;SDP02dc7P0]<al202lf9@0;034h9P0]=2<0;38Q02X`8@0/<B40
;38P02`a7P0/<ah0;C<O02/_7P0Z;a`00P0X;AP02`0W;1L09b/G02L[6@0V:a/09BTJ02<W6P0R9ad0
8bPM028Y7@0O9QX07RDI00807RDG0P0M91H0100O9QP082DI020T6@0N81LJooooojd0oh003oooool0
00gooooo00@01@P500L:1P0830@01`T20P06204200L9100;00X=200?4``04QL?01DJ4`0G7A@05A/A
00lD2P0:3P@01PT000@80@041P400P031@4010011@400@@100@90P083@<200X>0P0501HK300N8Q<0
82@E03<j9`0mB3<00P0/=RL0300Q:1d05APC014C3`0@3`/0410:018C300E5Ph07R0E02L[700`=R<0
=3XX03Po;080>T<_00/0>D8]03Q0:`0i@B/0>T8[03a4:P0oAB`0@DL_03m6<00l@R`0?44]03a2;`02
03e3<00;03m5<@10Ac80?TD`03i6<@0mAC40?4Db03e6<@0oAC00?d<_0414<00m@Bh00P0l@Bh0200k
@Bh0?4<_03]4;@0lAbh0?DL_03e6;P0mAR/0?4HY0P0nAbX03`0oB2d0@DP`0458<012Ac@0@TPf0499
=`12BCP0?dDd03a3;`0j@2d0=chZ03Dm:@0g?bX0>D0[03]3;`0203i6<P0;03]3<@0f?Bd0<CTZ02lg
:P0_=bL0<3TU02lh9@0`>280;SLO02he7@0]<a/00P0^=A/0100/<QX0:c4I02`a6`0/<A`202/`7@05
02`d800_>2<0<C`V034n9`0c?bP00P0c?RP0300c?BH0<chU034k9@0_>280;SHP02lg8@0a>B80<CTS
02lf8P0^=B80;C<P02`a8080;S<Q00/0;cDR02`c8@0/<B40;S<T02`a8P0[;al0:RlN02T`7P0[<Al0
:c<N02/b700202X_6@0;02T^600X;AL09b`G02H[600V:Q/092PL02<X7@0R:1d08BTM020Y6`0P:1X0
0P0O9QL01P0N9QD07RDF01lV5`0P9aL08BPH020T5a[ooooo[@3oP00?ooooo`003Oooool01P0;3Ph0
2@`;00X=2@072P@010H100<400800P@000/01PP300X<1`0=4@/041@>018G3`0C5a003Q<:00X>1007
2`0010L000@50@0200<40@0;00840@031@<01`T500P;10062@401@L100H70@082`<02`h501DJ3`0S
;1`00P0Q:Q/0300N9AP07B4D01dP500J71805aTB01LH4`0F5a006adE028W7@0[<2D0<3HY03Dm;@80
>D4`00L0>40^03Lo:`0g?bX0>D0[03U1:`0j@Bd0?4@^0080?TL`00D0?D@^03i5<010B3<0@4Pc03m7
<@020419<`080459<`12Bc@0@4Pc03m8<P0nARl0?dD^0457<00n@bl203e3<00;03i4<P0l@c80?D@`
03i7<010BS80?dTa03e8;@0nBB`0?TX[03i8;00mARh00P0oAbl03011BC@0@DPf04E9>@14BCP0A4Xg
0458=010B3H0?DDe03Q0<00g?Rd0=cl/03U0;080?4<^00/0?TD_03]2;@0i?bd0>3l^03Ln;@0f?B/0
<SXX030h9@0`>R@0;cPQ02lg7P0202lf7@0;02dc700]=1`0;S@M02lc7P0^<Ql0;34N02`b7@0/=200
;cTT02lk9@0_>bH00P0b?bP0300a?RP0<CdU038k900^>B80;SLP02`e7`0^=R40;SPS030h900`=b@0
;C<P02``7P80;S8O00/0;c4O02la800_<R40;C0P02hb8`0]<B<0:c0R02X`900Y<280:C4Q02`b8002
02`b7P0;02/a700Y;aT0:BlH02P]5`0W;1/09BTK02DZ7@0T:A`08RLK028X6`0S:Ad00P0S9aX01P0P
9AL07R@F01dT5@0M91@07RDF01dS5Q[ooooo[@3oP00?ooooo`003Oooool01P0C5a`03a@H00`A4`08
2``01PP700@710800`D200/01PP300hB200@50P03A8600dA1@0?4PT03A0800/>1P0:3P@020/200L9
0P0200H70P0;00D50@061P@020T500L80P0310000`<000D50P061`8020X400T;100=4@P00P0?50/0
300@50/04QD;018F2P0D60/07B8D02<X6P0R:1T08BLJ02<Z7P0W;b@0;3@X030j:P80=3d/00/0=Ch[
03Do:P0g@2X0=SlY03Hm:P0g?b/0>T<^03a6;`0lB300?DP`041:<P02045:<P0;0419<011BS80@d/d
04E<=@14C3D0@DPc0418<`11BC40@DXb049:<P11Ac000P10AS00200nAC40?DDa03i6<00oBC40@4Xa
049==011C3<0?TT`0P0oBc403`11BS80@DXc045:<`0oBS<0@D/c0499<`14BS@0@dTb04=8<@11Ac80
@DHd03m4<`0m@c40>T8]03U0:P0303e2:@0:03i3:P0oA2h0@TLb03m4<@0k?bl0=S`/038j:@0d?BT0
=3dW03<j8`80<3PP00/0;cHO030g7`0`=Ql0<3DP02hc800^=200;38O02dc8P0/<b<0;3DS02df8`02
02`g8`0<02dh8`0^>B40<C`S03<n8`0c?2<0<SXR030h8P0_=b80<3PT038h9@0_=280:c0N0`0]<Al0
2P0^<B00;C0P02/^7P0[;Al0;C0P02``8@0/<B@0:bhS02``900Z<B8202P_7P0:02T`7@0X;Q/0:2dJ
02T^700Y;Qd09b/L02DY6`0T9a/08bHK024U6P<08BDI00H07R<G01dR5P0N91H072<E01`R5@0J8A@J
ooooojd0oh003oooool000gooooo0P0I82H0100H7BD051PP010C6@0<41<200T<3P0;00`?3P0@5100
3@l900X<100<3`D03Q4700lB200@4PT03Pl600`=100;2P<00P0:2@<02`0:2@D02PP600X92@051@D0
0`<200810@020P401`P500/>200>4@T030l700802@`500`02Pd600/?1P082`<02@d400lD2@0J8A80
8b`J02Xd800^=b@0<3/X038m;00a>b/2030i9`0;034j9`0b?2P0<CXV038i9@0c>bL0=3dY03I0:`0g
@R/0=d@[03U6;@0mBC000P0oB3002`12Bc<0A4df04A<=`15C3T0A4/g04E<=`14CSL0ADhf04E?=P16
CCD0A4`e0080A4/f00/0@DTd03m8<P0mAc00@4/`045;<@12CC@0@D`d03e:<P0mBc80?DX`03i9;`02
03m;<00<03i<;`0nBRd0?dT]0458<010ARh0@dP`04=8<P13AS80@THb0497<`0oARl0?TH]0P0nABT0
2`0k@2@0?D8V0456:`13B2l0@dLa0414<@0nA340?48`03]2;P0h@2T0=CdU0080=3/T00/0<cTS030e
8@0a=R80;c<P02ld800^=1l0;38N02/`800/<R80;cDU02hf900202dg900<02hh9@0^>B<0;c/Q038n
8P0e?b80=ShS03@k8P0`=b40;S@Q02le900`=RD0;S<Q0P0/<Al202`a7@0902`a7P0]<Al0;2dN02`^
7`0]<240;BlS02`_8`0]<b<0:c8R0080:2lP00/0:C0N02X_700Y;A`0:RdM02P[700V:A`092PJ02@W
6@0S9a`07b@J01hT6@0201hT6P0401hT6`0L8QT072<H01TO4`806R0C6_oooon]0?n000oooooo000=
ooooo`0602<Z;`0S:Rh08BP[01lU:00M8bH061hP0P0E6A/02`0D61P04A<C00/<300:2PT030l900hC
2@0?4`T03a8900d?1P0930@02P`400802`/400/030d600l>2`0?3Pl030d=00L82@0410D00`@400/>
2`0@510041@>00`@2P0200/>1`0<00T<1P0;3PL01`X400H90P082`<02Pd401<H300R:AP0;SHR03@m
9`0i@Rd0>40^0P0f?Rd02`0e?B/0<c/Z03<j:P0_=RL0;C@W02/b9`0[=BL0;STX034m:P0f@R`0>TH_
0080?DL`00/0@DXc04=:=P13BSP0@d/j04A<>P15CcX0AE0h04IA>015D3L0ADhf04A>=P0204E?=`0;
04A==@13Bc<0@DTa041:<011BS00@d`d049;=@10BSD0@D/c03i:;`0mBbd00P0oCBh2041=;`0:03m:
;P11BS00@DL`04=7<`13Ac@0@D@c0415<`10AS<0?TD_0418;P80?dP/00/0?TDX0456:@12AbX0@TH[
0455;@11AC00?d<b0455<`11Ac80?DD]03Y2:P0203Q09`0;03Lm9P0d>B@0;cDQ02`a7`0]<R00;c@P
02da7@0/<Ah0;34O02he8`0_=bD00P0^=bH202hi9`0:02hi900^>R80<C`R03@n8`0e?B<0<STS02le
8P0]<b40;cDT02ld8`80;S@R00T0;S@Q02dc800/<Al0:c0O02X]800Z;1l0:RdP02`^8P0/<B400P0[
<B0202T^7@0:02T_700[<A/0:c0K02T/6P0W:Q/09RXM02<V6P0Q91P082DJ01lU6P<07bHL00H07RDJ
01`S5`0K8Q@06R4B01/P4@0J7PhJooooojd0oh003oooool000gooooo00H08bT^02H/<00T:b`08RTX
02<Y9`0T:RL2024W9P0;020V9P0I7Al04aHH00lA4P0>4@l041@>014F2`0@50P03A4500X>0P0930<0
0P0<3PD02`0>4@H03Q4900h@300=3`d03@l>00T92@072@L03Q8=01@G4P0A5Pl0310;008020/400`0
1@L100H80@072@801`T200L:0P0620402`l601<G300L7a<08B@G02LZ7P0d>b/203a4<`0;03e7=00k
A3<0=d0a038k;P0[<bT09B`S024X7P0M8a/08b/O02di9`0d?b/00P0jABh02`10BS80@dde04=<=P11
BCH0@DXg0419=P11BSH0@d`g04E?>015CcT0Ae8l0080B5<j00/0AU0f04A<<`14C3<0A4`b04=:<015
CC@0A4de04A==`14CSL0@T`e045<<P02045<<00<049<;`12CBl0@DT_04=8<013Ac<0@dLf04A8>013
AcP0@dPh0498=P11BC@0@T`b0P13CC802`13C300A4`^04A;;015BBd0@DD/03e2;@0m@S80?D@d03e5
<@0lABh0?4D]0080?4@[00/0>40X03Hm9P0b>2<0<3DS02hb8@0]<B00;S8P02lc8@0_<b80;cDT034i
9`0202hh9P0<02`g9@0_>RL0;cXW02li900]>280<3/R03@m900c>b@0<cPT03<h9P0_=BD0;S@T0P0`
=RD01@0a=bH0<3HT02dc8@0[<200:RlR0080:2dQ00@0:S0S02`b8P0/<R00:c0O0P0Y;Q`02`0Z<A/0
:c<K02/b6P0Y;AP0:BXJ02LY7@0T9Q/092HL02<V700O8aX082HL00808BHL00H07RDI01dT5`0N8a@0
7B8A01dQ400K7PdJooooojd0oh003oooool000gooooo00H0:2d`02T^<P0V:bh092TY02<X9`0V:bT2
02H[:P8092X/00T082HX01`Q8P0G71/05Q/E018G3@0=4@H02`h200/?0`0;3P@00P0<40D02`0?4PL0
3a4800`=20092`L02P/:00/<2P0=3`X04A@=01@H3`0B5``041@:00802a0400`01`X000H900072@40
20T300P;10082`D020T600/=2P0@4a0051HC01DH5@0Q9Ah203@m;`0;03a6=010BcL0@D`i03Q2<@0/
=2H09RdP01hT6P0G6aD05ATC01dS6P0V;B400P0`>RX02`0hA2l0?dXc041;<`0oB380?dPc03m7<`10
B3<0@DPe04=:>015C3X0ADhj0080A4lh00@0A4lf049>=013CS@0@dhb0P14CC001@16CS<0ATdd04A<
=011BS@0@D/d0080@T`c00P0@D/a041:<@11Bc80A4/d04E;=P14BCL0A4Pf04E9>080AT/j00`0AD`h
04=;=P12BcD0@T/e04=<=014CS80@d`_0499;P11AB`0?44Z03/o;00i?bh203Y1<00>03a4<@0k@bl0
>d<_03Q0;@0i@Bh0>40/03Dk:@0a=R@0;S<Q02le8@0_=R00;cDQ02hd8P0`=b@202lg9@0;02hh900`
>bD0;c`S030l8`0]>1l0;CLO02li8@0b>b<0<cXU038h9@0`=B@00`0]<b402`0_=R80<CLT034g900`
=B<0;C@Q02db8@0Z<200:S0Q02/a8@0/<b00:RlL0080:BhK00/0:S0M02/a7P0Z;Q`0:RdL02/^7P0Y
;1l09RPN02@W7P0Q91/082<J020T6@0201lR600601lR5`0L8A<07R8D01lS4`0O8Q<07B0A6_oooon]
0?n000oooooo000=ooooo`0602L/:P0Z;R`0:Rd]02T[:`0X:RP09bXW0P0X;2T02`0X;2h09RX`02L[
<@0W;2l09R/[024W8`0H71L041@>00h@2P0?40X03`l;00803@`:0P0>3@`02@071PL00`<400@51@04
1@@02@`6018G300H7@l05ad>014F2P0200`@0`0<00T<0@09308020X200X<1@0=3`P02`d800X;1`09
2@P030/;014@4@0D4a805QHC0P0L7AP02`0W:R40<cP[03e4=00f?Bl09bdQ020V6@0F6@l05aXA01LJ
4`0H7QD07bDK00809c0S00/0;STV03E1:`0hAB`0>TH]03i8;`0oBC80@4Tc0418=@10AcH0@DTg045;
=`02041==P0;045?=P13D3H0A4le04A?<@14D300A4l_04E?<014CC40A4db045:<P10BS800P0oBS80
300oBc80?d/a041:<P12Bc@0A4`f04E;=P15BSL0ADXi04I:>P17Bc/0Ad`k0499=@80@TXd00/0@T/b
049<<011Bbh0@DT]0499;P0oA2d0?40/03Tm;@0h?Bl0>T0a03]2<@0203Y2<P0;03U2<00i@Bh0=d0[
03M1:@0d?2D0<STQ03<j8@0_=Ql0;C@O02dd8@0]=R@00P0_=b@00`0^>2@0;c/S02hj7`0202lk7`07
02hi7`0_>R00<C/Q03<l900a>2<0<CLT02hd8P0202he8@0;02he7`0a=b40=CXT03Dk900b>2@0;cDQ
02/a7`0X;ad0:2hL02T_700Z<1X00P0Z;a/02`0Y;Q`0:B`N02/^7`0Z;Al0:RhP02LZ7`0U9ad08bDL
028U700Q8aX0828G00807b8F00H07b8E01hQ4`0M8A807b<C01lS5@0L8A@Jooooojd0oh003oooool0
00gooooo00H082LS02D/900Z;bH0;C0X02h_:@0/;BT202d_;00;02`^;P0Z:c00;2he02lb>00a=ST0
:c4`01`Q800H6QT05A@E01<@4`0A3a<00P0=2a402`0;2A001`H>00D42`030`L010D500<50`051`40
4QP801XP3`0G70`04QD8008030l500`02@/200X<100:3@L03a4;018D300@4@`03Pl;00`<2P0=30`0
4a4A01LE500F51<201@C4P0;01PH500K6aL08R@M02@W7`0M8QT05QTB010A2P0B50`06alD024X6`0T
:ah00P0S:ad01`0T;Ad09S4N02Xf8@0`>bH0=d<[03e8<010C3@00P11BcH01`12CCL0@Thf04=A=P13
DCH0@e8e04MD=`17DSL00P16DCD01@16DC<0AU0d04A><`12CC40@ddc00<0@dle00`0@Thd045==011
Bc<0@D/c04===P14CCL0Addh04Q>>019CST0BThj04Y@>`1;DS`204U?>P0:04M>=`14C3<0@d`b04=;
<`14C3@0@TXc0498<P11AS<0?d@a03i5<P<0?dTc00/0?DHa03a5<00iA2d0>DL]03Q5:`0g@RL0=T0T
038l800`>B00<3TQ02lg8P02034j9@0<038k9P0b?2H0<S`S034l8`0a?2@0<CXS03@l9@0e?RH0=ShX
03Dl9`0e?2P0<CPU0P0`=R<02`0`=b00<3LO03Dj8P0f?2<0=C`T03<k8`0_=b00;3@N02Xb700Y<Q`0
:S4L0080:c4M00/0:RlL02T^700/<Al0:c0P02`b8@0Y;Ql09BTK02DY700V:Ql09BPM02@X700202<W
7006024V6P0Q9QT082LH020W5`0O9QL082DG6_oooon]0?n000oooooo000=ooooo`0601LN7P0J8A`0
7R@K028U700V:240:B/U0P0]<B/02`0^<Bh0;S4a02hb=00^=3L0<SXk034i>00W;Bd082DU01lQ900I
6B4051@N00804A4L00/03a0K00X:5@061A000`<;00421@010`<00`D100dA1P0F70h061d?01HG3@02
014B2P0<00h>200=3@T03Pl<01<D4P0G6AD05aXG018F500>41003Q0A018C4`0E5AH04a4C0P0A3a40
2`0B4Q404A4?01<D400G6A805AT?014C2P0?40L02`/201HI300U:aX09R`N00807B<I00/06AlF01HL
4`0H7Q<072@F02@]700/=R80=40Z03U4;@0lB2l0?TX_045?<@0204=B<`0;04A@<`16DCH0Ae4h04I?
=`18DSP0Ae8g04EA=@15DCH0A50e049>=013CSD00P14CSH03013CCD0@ddd04=<=012BcD0@T/f04A;
=`16C3P0Ad/h04Q<>@19CCP0Bdhi051D?`80DEE000@0CE4l04Y?>P18CST0AT`h0P14BcL01@13Bc@0
@d/c0458<010B300@DTa0080@DTb00T0@DLb0417<@0mARl0?4L`03]6;`0hA2/0=T8W03A08P0a?B00
0P0`>Al2030j8@0<038l8`0d?bD0=3dV03<l9P0a?2H0<S/U03@k9`0e>RH0=SdY03Lo:P0f?RX0=3hZ
0P0c?BL02`0c?2<0;SDN02`b700`=Qd0<3LN030h7`0`>1h0;CDL02/b6@0Y<1P0:2dG00809b`I00/0
:2`K02T]7@0[<1l0:RlP02T_800Z;b009bdM02<Z6P0T:A/08bPJ024V6002028V6@06024V6P0P:1/0
7bPJ024Y6`0P9aT082DG6_oooon]0?n000oooooo000=ooooo`0601LN7P0J8A`07R@K028U700V:240
:B/U0P0]<B/02`0^<Bh0;S4a02hb=00^=3L0<SXk034i>00W;Bd082DU01lQ900I6B4051@N00804A4L
00/03a0K00X:5@061A000`<;00421@010`<00`D100dA1P0F70h061d?01HG3@02014B2P0<00h>200=
3@T03Pl<01<D4P0G6AD05aXG018F500>41003Q0A018C4`0E5AH04a4C0P0A3a402`0B4Q404A4?01<D
400G6A805AT?014C2P0?40L02`/201HI300U:aX09R`N00807B<I00/06AlF01HL4`0H7Q<072@F02@]
700/=R80=40Z03U4;@0lB2l0?TX_045?<@0204=B<`0;04A@<`16DCH0Ae4h04I?=`18DSP0Ae8g04EA
=@15DCH0A50e049>=013CSD00P14CSH03013CCD0@ddd04=<=012BcD0@T/f04A;=`16C3P0Ad/h04Q<
>@19CCP0Bdhi051D?`80DEE000@0CE4l04Y?>P18CST0AT`h0P14BcL01@13Bc@0@d/c0458<010B300
@DTa0080@DTb00T0@DLb0417<@0mARl0?4L`03]6;`0hA2/0=T8W03A08P0a?B000P0`>Al2030j8@0<
038l8`0d?bD0=3dV03<l9P0a?2H0<S/U03@k9`0e>RH0=SdY03Lo:P0f?RX0=3hZ0P0c?BL02`0c?2<0
;SDN02`b700`=Qd0<3LN030h7`0`>1h0;CDL02/b6@0Y<1P0:2dG00809b`I00/0:2`K02T]7@0[<1l0
:RlP02T_800Z;b009bdM02<Z6P0T:A/08bPJ024V6002028V6@06024V6P0P:1/07bPJ024Y6`0P9aT0
82DG6_oooon]0?n000oooooo000=ooooo`0601/P8P0J7Qh05a`H01LK500J7AL0828L0P0X:b<02`0/
;bP0;c<^030f<`0^=C@0;C@f030h>00^=cD0:2l^02L];P0U:Rl092T_008092Ha00/08R@_01`N:00D
5B003PhH00P94@041P/00`D600/?2P0D60h05QX@018E3@02018C3008018A3@0B4@h051<A01XK5`0M
8A`082DR01lU8`0L8Ql201XO7P0?01DH6P0?4A@03@dA00d=4@0=3@h030h<00d?2`0@4`d041@<00hA
200<3`D02P`201XP400Y<Qh0:C<O00807bLI00/06AlD01@H3`0B5P`04QH<01DI3`0H7A007R@E02@/
6P0/=R00=40U03a8:`02045=<00;04E@<`16DCD0Ae0g04MB>018DcH0Ae8e04EC=016E3L0AeDi04IB
>015DCP00P15CcP01@14CSL0ADhg04I==P18CcL0BU0h0080B4hj00D0AT`h04M<>@18CCX0BTlk04iB
?00204iB>P0;04iA>P1<DCX0Be4k04Y?>@15CSP0ADlh04===013CC<0@D/`0417<011Ac000P11Ac80
2`12B3@0@TPe03m6=00nAS@0>d@a03Q1;00g@RT0=ClS034l7@0a>Qd0<CXO0080<C/P00`0<SdS03I0
9@0d?R@0<S`T034l900b>bD0=3/W03Dj:@0e>b/0=Sh/03@k:@0e?2P203Dn:00;03Dm9`0a>B@0;CDO
02/d700[=A`0:S<K02`e700]=Q`0:c8J02T_600Z;QT00P0[<Ah02`0Z;Qh0:BhO02T_800W;Al0:BlO
02T`7`0W;ah09BdJ02<[600P:AD07bLD00808BPF00H08bTH01lW5`0M91H07bDI01lU600N91DJoooo
ojd0oh003oooool000gooooo00H07b8R01dP800H71/05QXG01HJ500I7AD201`N5@0;01lQ6@0S9B00
:2XW02/_;00/=380<CXh034j=P0[=300:c8`02`c<`0^<c@00P0`<cL02`0`<cT0;S4i02/^=`0S9c00
61`U010C6`0;3A802`h@010D400E6Q405ATA00804aD>00L04Q<=01<C3@0F5a006Q/E01XL600M8Ah0
82LT00809B`W00<09bhX020V8P0E6AP00P0@4A<02`0?3Q003@`>00h=3P0@4A003a<@00lB3`0=40`0
3109014G2`0H7`l06R8@00806b8A00/06B0?01HK3P0C5PX04QD:01<E2`0B50X04QD;01<G300K8Q40
8RTD02`c6`0203U29`0;03m8;013CC40AU0c04QA=018DS<0Ae<f04MB=`17DcP0BEDj04UD>P18E3/0
0P17Dc/01`16DST0ADlg04A==@18D3P0BE4j04Q@>`17CS/00P17CCP00`18CST0BDli04aB>P0204a@
>00604]@>01<DS/0C5<l04]B>`16D3P0A4lf0P13CS@00`16DCH0A4lf04=<=00204=;=00;04=;=@13
BC@0@DLe0418=00lA340>d8^03]4;00h@RL0=ClR03@m800e?R000P0d?R40300d?B40=CdR03Hn8`0f
?R@0=ChV03@k9P0b>2D0=C`X03@j9`0d>bP0=3`X03Dl:080=C`W00/0=3/V038k9@0a>b@0;cXR02hj
800]>1l0;3DN02hf7P0]<al0;38O02T^7@0202/`800;02/`8P0Y;b40:2lP02P_7P0W;Ad09RdK02L_
6P0S;1L08b`F02<]5P0S;1H00P0S:aH01P0R:QH082PE01lW5@0Q:AL08bXH01lU5Q[ooooo[@3oP00?
ooooo`003Oooool01P0H7A`07R4P01`L7P0G61X05aPF01PJ5P8061TD00/06AXE01TI5P0I61L06a`J
020U8@0X<2X0;CH_02hg;P0_>340;CDa02dc<@0202lc=00;030c>00a<c`0<CDo02le?P0[<ST08bX`
01dR9`0G7Al05adI01PN5`0E6Q@00P0C5a00300B5Ph05AP?01LK4P0F6A004A@>018E400G71L08BHO
02T_9@0^=2X0;SD[02@Z908071lL00/061TI01<A500>3Q8040lC00lA4`0@4a<04A@C014G4P0B6A00
5Qd?01LO300301LN2`0:01DJ2@0C5`P04AD6014E1P0@50D03a@5010D1P0E6@X05AP801XM2P80:BhG
00/0=c`R0418:`16D380BE8e04UC=P17DcP0Ae<g04IC>018ECX0BEDj04UE?00304MC?00;04EA>@14
CSP0ADhj04MA?@19Dcd0Ae8j04E>=P16CSD0Adhe04Q>=P18CCH00P1:CSL01P19CSL0BTlk04Q??018
DCd0AU0j04A>=P80@dhe00<0@dde04===013CC@00P14CSH02`16CSP0@dXe04=8=@14BSH0@4Lc03]3
<00j@Rh0>D8/03Do:00e@2H0=d8T0080=T0R00`0=SlS03Lo8`0i@BD0>40T03Ln9P0f?2H0<cTU034h
9@0_=B<0<3HU03<k:00d>bL203<j9P0;030h900a>B<0<SXS03<k8`0b>R80<c/Q02lf7P0]=1/0;S<N
02hc8P0]<R400P0/<B802`0/<B@0;38T02`b8P0[<Al09b`K02D[600W;QT09BdH02D^6@0T;AT092`H
00809B`I00H08b/H024Y5P0P:1D07RHB01hV500O91DJooooojd0oh003oooool000gooooo00H06b0O
02T]:00U9RD07adP01XI7@0I61`201PF6@0;01LF600E4a@04a8A014C4@0C5a8061hG01hU6`0W;b40
;SHX030g;00a=Rh00P0_<bl02`0_<S80<C<h03@f?P0d>Cl0<SPo02lg?00[=3H09Bl_020X9`0K8R00
5Q/J00805QXH00`05aXF01HJ5@0F6Q@051PB00hA300=3`/041<>01/O5`0R9Q`09RXN02/^8P0]<RP2
02da:P0;02T^:@0T9bH07AlS01LI7`0B5AX04A@H01DI600J81X06R4H01XQ5@0G7`l00P0H7`d02`0G
7@`04aT8018G200?50H03Q<500hA0`0@5@D04aL701DG2@0B4`L04Q8500806AP700/08R4>02`]6@0k
@B/0A4dd04MA=`19EC/0BUHj04UF>019EcL0Ae@f04MC>00204QC>@0<04UE>`17DCX0AU0k04E>?017
DC`0Ae8l04QC>P15D3@0A4ha04E><P16CC<0AT`c0P17Bc<02`16Bc@0Ad`h04M>>`14C3X0A4dh04A>
=P14CcD0@ddc045:<P12Bc<0@T/b0080@TTc00/0A4/d04A:<`14BC@0AD/g04=:=`0oAcL0?4<e03U1
<P0f@2h0=3l[03A0:@0203<n9@0<03<n8P0f?b80=d0T03Dn8`0d>b<0=C/U03<h9@0a=bD0;S@U02db
900]<b@0;SHS0P0`>2@02`0a>2<0<3PR02lh8@0`=b00<3LO02lf7P0]=1`0;38J02da7@0/<1l0:blP
0080:blR00/0;30S02`a8@0/<B00;34P02T_7`0V:a/09B/J02@[600R:QL08bXG02H[6P0202H]6`06
02H^700T:aX08BLG01hU5@0N91<07B8A6_oooon]0?n000oooooo000=ooooo`0605=SE`19ED/0=C`f
034f<P0/;Rh0:2T[0P0R8B@02`0N71l06aXJ01PI500D5a004QH?01<H400E6A0071lC028T5`0Z:b80
<3</0080<C@^00/0<3<a03<f>00g>Sh0=c]103LmA00c>d40<CXn02hg>@0Y<C808bX[024W:002024U
9`0<01lQ8P0L7ah061TK01<D5`0>3Q802`/>010B4P0L81/0720J01PK4`0H6Q807b8J0P0U:R802`0Y
;RT0:c8^02Xa;P0Q9bH06AlN01PN700K8A`06b8J01`T6P0J81H05a`@00<06Ah?00X05QP;018D2@0@
4PP0414900h?200@4@P04a@:01DE300E5P`051@90P0G5@H02`0K6@P071/:02T/6@0i?bP0@DP`04Q@
=01<E3P0CEHi04]G>P1;Ec/0BEDk0080BE@k00`0B5@j04UE>`19E3X0Ae8j04QA>018D3P0B50g04I>
=015CC@0ATle04E>=@16CSD204E<<`80AT`d00T0Adde04A:=013BC@0A4`d04=;=@14BcD0A4`e04A;
=014BS<00P14BSD02`14BcD0AThd04E<=015BcD0A4Tf0498=`0oACP0?48e03U1<P0f?Rh0<S/Z0080
<3/V00X0<CdT038n8`0c?B<0<S`S034j900c>bD0<cTT02he8@0^=200;cHR0P0]<b0202le8P0;034h
900a>2<0<3PT030h900_=b<0;CDP02/c7P0[=1h0;3@N02/b7P0Z;ad00P0[;Qh02`0/;R00;2lP02X_
7P0Z;al0:S0P02P_800U;1d08RXJ024Y600R:AL09B/J008092XK00H08RXK02<Z6`0R:1X08RPI024X
5`0N8a0Jooooojd0oh003oooool000gooooo00H0LHIm07:6O01UMfl0GVeU05MRG@1<E58204E<BP0;
03Y1?`0X;2T08bPP028W7@0R9Qd092PN02@V700R8QT07ahH02<P800[:R/00P0Z:R/02`0Z:R`0<C8c
03Di>P0g>d40>D1403Q1A@0d?D80;cPk02`e>00[<S@0;3@c0080;cPd00`0;C<b02X^<00T9B`06QTS
01<@6`0@3AL05A<K01/M800F6Q`04A<C00d>300>4@h201<F4`0;01XN6P0Q9b<09B`W02<Z900O9b00
8b`S02@^900P:R007RHK01TP500G7A000P0I7Q002`0J7Q006AX<01@E2@0C4`X051@;010@200?3`P0
40l9014A2P0C4``051@=00808B<E00/0:2`J02T_6`0/=1h0=3`S03Y19@11AbX0AT`a04]B>01=E3/0
CEHo04]E@@0204UE@00<04UF?P18E3/0BE<h04]E>01=ECT0C5<i04eB>@1:CSP0BDdh04Q>>@16CSP0
B50g0P18CcD02`18Cc@0AThb04A;<014BS40ADXb04Q>=@17CCL0B4hj04M=>P16BcP0ADXh0080@dXh
00/0@DTf049<<`13C380A4`b04A:<P13B3<0@TLe0415=@0oA3@0?44a03Ll;@02038j:P0<038m:00a
?B@0<C`R034l8@0b>b40=3dR03@k8P0b>B00<CPP03<j8P0c>B<0<SLR0P0`=R802`0`=B80<3HS030g
9@0_>2L0;SPV02hh900]=b@0;CLS02`g8P0[=B40:S8N0080;34O00/0:bdM02`_800]<B40;30S02``
900[<2@0:2lS02<[800S:ah08bXK02@[6`0202D/7@06028X6`0O9aT08BLJ024X600P:1H07RHB6_oo
ool20000oj/0oh003oooool000gooooo00H0OY:908>FSP25V980PiF@086BS`1jRHP207N7Q00;0720
OP1IIfP0DEeM05EQG@1JIeh0FVIJ04Q?B00d=cH0=SPk03<d>`0/;3<00P0R8BL02`0N72408R0S02PX
:P0`<S@0=3Pi03Hm?@0f?d00<CTl02/c>00]=CP0<CXk0080=Chn00`0=Slo03Q0@@0g>Sl0;c4j02DV
<`0P82d0824[01hP9`0D5A`0418E00h>3`0=3@`200l?3P0;014A3`0C51405a/G01XO6`0T;2D0:38Y
02Td:@0V<BL08BXO01`S5`0J8A<00P0J81802`0J7a806A`?01HF300F5P`05AL<01<C2@0B4PT04Q8;
01<C300@3`/040l>0080<3HZ00/0BUQ304eNAP1;G480AU@j045<<@0nAb`0?dL]04=:<@16CCH0Ae0j
04YC?P0204YE?P0<04YF?@1:E3/0BU<i04]C>@1=E3X0D5Ln04mF?@1>Dc/0C50j04Y@>@1;DCX0BU4i
0P19D3H02`19D3@0B4hd04M==017C3@0B4`c04U==@18CCL0B4di04U>>`16C3P0A4Xe0080A4`f00/0
A4df04===013CC<0A4hd04A==015C3@0AT`d04E:=@15BC@0@DDb03e2<00203Y0;`0603Ho:`0d?RP0
<c`T03<l8`0d?2<0=3`T0P0e?BD0100c?2@0<c/U03<i9@0c>RH2034i9@0;02hf8`0]=B80;3DS02`f
8`0]>2@0;SLT02dg9@0]>2H0;SPW02dg9`0]=RL00P0[<R@02`0Z;R40:RlR02``8`0/;b<0:RhS02P^
8`0V;2<09B/R02D[8@0T:Qh092/M008092XL00H08RLJ024U6@0P9QP08BPH020W5`0O91DJooooo`T0
003oY03oP00?ooooo`003Oooool01P22UX`0QYRA08ZKV02:VY`0RYZN08RGW@80QYNJ00/0QYNH08BE
V01oT9@0Oi:B08:GT`22Uhh0NH^206akM01_OWL0G6MU02`^>00201/I900:01XI7`0E4aT05Q@I01dM
7P0V:2H0;c<`03@i>00e?S`0<S/l03U3@P<0?dY900`0?4I803]4B00j@DL0>3m603DlA@0b>D<0;SDo
02@Y=00I72L04a@N010@5P0A4A<2014A4@0;00l>3@0>3@`03`l<014D3`0S:R809RhV02Ta9`0Y<RL0
92`S024Y800N9Q/00P0L8QT02`0K81P06QlG01PL500G6a805AP?01@G300E5P`061T?01LF400F5Q00
7b0H0080:R/S00/0AThn055OBP1CID`0DfA:051QA@19F3h0AE<g04=><`13CS80A4ld04M@=`0204aD
>`0<04]C?01;Dc/0CEHk04eG?01;EC`0C5Ln04iG?@1=ES/0CEHi04eD>01=DcP0C58j0P1<DCX01@1;
D3/0Be0l04Y@?018CSX0Addh0080Adde00<0AT`e04M==`17CCD00`17CC@02`15CCH0A4dg04===P15
CcL0ADhg04A;=P13BcD0@dXc04=9<@11B340?dLa0080?dH`00`0?4<]03Y1;00e?BP0<cXW038j9P0c
?2T0=3dZ038l:P0a?2T0<3/W030k9P0a>bL2034l9`0;030l9P0_>RD0;cTU02lh900_>B@0;SHS02df
9@0b>RX0<CX/030h;P0`>Bd00P0]=BP0100/<RD0:S0S02X`8`0Z<28202T`8P0502P^800Y;R40:RhQ
02T/8@0V:Qh00P0T:AX01P0Q91L082@H020T6@0S9QX092LK020S6A[ooooo4@000?nL0?n000oooooo
000=ooooo`06082DSP26VY@0RY^J08^LWP2<WJ40S9bS0P2:VYl02`2:VY`0RY^L08^MW@2:Wih0Rj6M
08ZRV@2;XiH0RZ6B08bQTP1nT8@0?T=800806QTT00/071/Q01LE6P0D4AD04a4C01LF5P0M7ad08RDR
02`c;P0b>cH0>dDo041<A00203m:A00<03i7AP0mADL0>d=803Q0B00h@4L0>T=<03Y3B`0g@4P0<3I0
02<W<@0M82P05ALM0P0B4QL02`0@3a<03`d@00l>3P0D5Q@09B/T028Y8P0P9b009B/R02L^8P0T:b00
8RPN00807bDM00/07R@N01lT7`0O9Ah07B<K01/P5`0J7aD06AhC01XM4`0I6A4061PB02<S6`0202<S
6P0;03m3=01FHT`0D5m903i;>P13DSh0BEY104eO@@1:G3/0AeLe04MD<`15D3400P17D3@204U@>00:
04QA>019ECX0B5Hj04YG>`1=FSd0BeLk04YE>P1<ECX0C5@j04aB>`80Be0k00/0Be0n04]A?`1:D3h0
B4lo04M??P16CcX0ATlg04I>=P17CcH0ATld04M=<P0204M<=00;04I;=@16BcP0A4/h04A<>P13BcT0
@d`j049;=`11BC<0@TP`0459<012Bc000P13BC003012Ac00?dD`03a3<00i?bl0=3/[034j:P0_>BX0
;STZ02lj:@0_>bH0<3`T030l8`80<SdS00/0<S`T038k9@0b>B@0<CLT030g8`0`=R<0;cHT02dc8P0/
=2D0<3PZ02hh:@0202hg:00;02df900[<R40:2lN02L^7P0Y<Al0:C8O02/b7`0Z;ad0;BlO02`_8@0X
;Al00P0U:A`01P0Q91L0828G020R6P0S9Qd08RDM020Q71[ooooo4P000?nK0?n000oooooo000=oooo
o`0607nES@27WIH0RYnL08^OW`2=X:80SInR0P2<Wil02`2=X9d0S9jK08bOW02=XI`0S::K08bTVP2=
YIP0T:NH096XU@2?YI80K7aa0080;S8e00/08R@V020P800H5aP05A<D01@B4P0D4a4061PE01`N6P0N
8ah0:2lX030h<00203Lm=P0<03]1?00m@d80?TE703i6B@0oAdX0@4M<03m6C00nATd0?dQ>03a5BP0g
?d80;30d0P0T9BX02`0O7bD06QPP01@B6P0N7R408bLV01XN7P0G6aP06b4J028Y7@0R:1`082DI0080
7bDK00/08BLN024X7P0P9a`08BPK020X6`0P:1X07bDG01`O500I6A805QDC01PH5@0201TI5P0;04E@
?P1NKeD0A54o02de:P0/=2P0:c@U03i;<P1<Gcd0D68n055R?`1<Fc/00P17DcP03017D3P0B54k04MA
?@15CcX0@e0j04AB>P1:Ecd0BeLn04YF?P1;ECl0Be<k04YA>P80Adli00/0B50k04UB?@19DCd0B54n
04M??P15CSd0AU0l04I@>P17DCP0ATle04I>=00204M?=@80ATde00T0ATdg04E=>@14BcT0ADdj04=;
>@11BCD0@DXc0459<@13Bc400P13BS403012B2l0@DL`0458<P0nAC40>D0^03@m:`0`>BT0<3TZ02lh
9`0`>RD0<3/R030j8080<3TO00/0<CPQ030h8P0_=R80;cLR02hf8@0`>2<0;cLS02de8P0[=B40;SHS
02hf900202lg9P0;02lg9@0]<b00;C8P02X`7@0W;Q`09BhL02D^7@0X;Qd0:RlN02/`7`0Y;Ql00P0U
:Qd01P0P9AT07R<G020T5`0R9Q/082@K01lR71[ooooo4`000?nJ0?n000oooooo000=ooooo`0408BK
T@29X9P0RZ:L08^RWP80Rj2N0P2;X9`02`2:WiX0RinI08fPVP2=XIT0Sj>J092UV`2@YY/0TZRK09:W
V@2DZIT0R9b<0080GF]S00/0>3lm030d<P0P8B<071/N01TG6@0F5AD05aHD01PI4`0F5a806AXE01dO
6@0202DW8@0<03@f;`0k?SP0?d@o0498A013BTT0ADi>04A>D011Bdh0?dY<03m:BP10AdT0@4I70P0m
@D@02`0i?400<C4i02PW<@0Y:S0092DZ01@D6`0@4AL04QDE01@H500E6AD06AhG0080724I00/07R@J
01hU6@0M91L082HG024Y600S:QT08RHH01lR5`0N7QP071`J01hP7`0201dQ800;02@Z9P0^=bd09B`T
02HZ8P0S9al071lG01/P5@0/=R@0AUHk05=WB@1GJT`00P1DIDX0301>G4<0BEDo049=>`0lASH0>THf
03e9>012CS/0AU<o04QE@@1:Ed80BEE004QE?080BEDj00/0C5Hj04YD=`19DSL0BU8h04Q?>`16CS`0
Ae0m04MA>P17DcX0ADle04A?<`0204I?=00;04I><`15CS@0AD`d04M==@16C3H0AD/g04E<>014C3L0
A4df049;=011BS<00P11Bc803012BS00@4P^0418;`0oAc00?THa03e5<@0j@Bl0=C`]03<i:P0b>BL0
<3LV034i9P80<c/U00P0<SXT030h900[=240:c@Q02/c800^=R40;CDQ02he8P80;C@Q00h0;SDR02le
8`0_=B<0;cHS030g8P0_=R40;C@O02/b7`0Y<1l09blP02P`800Y<200:C4P02H^7@809B`L00H08BPJ
01lU600Q9aL08BHF024U5`0O8aPJoooooa<0003oVP3oP00?ooooo`003Oooool01P21V8l0QinE08RP
V028X9T0QijH08VPV080R9jG00/0R9bD08ZOUP2>XYT0T:>K096UW@2BYYd0TZFK09>TV`2EYI`0UZNM
09>UV`0208VKT@0907V:P01GHUl0>3a002h`=@0T92X08R4S01dL6P0K6QH061PE00805QDB0P0E4a40
300M6QD09B<M02l`:P0i?CH0@4I0049;A`15Cd`0@4];03e8B@0nBDX0@4U;04=9C080A4U<00/0@dQ<
04=6B`11@d/0?3m802`^>@0N7RX051HP00l@600>3QD03PlC010B4P0201DI5@0;01XO6@0N8Q/07B<I
01hT600Q:1T092XK02@X6`0T9Qd09RPR02PY:@0X:R`00P0Q9BL02`0I72005aTL01LI700M7ad07R0K
01/L6@0H6aL05a/G024X7P0b?Bd0?T`g0080CEi400`0EfU=059RBP0f@C40:S<V02H_8`0X<B@0;3DX
03M3<@0nBcD0AE8k04MD?@18E3d204UE>`0;04]I>P1:ESL0BE@e04UC=@17D3L0B54i04Q@>@15CcH0
AU0h04I@=`16D3D00P15Cc@02`14CS<0ADld04E><`16C340A4P`04A:<P17C3H0AT`f04M>=@16CSD0
ADde0080A4/d00`0@d/c03m8<00nARl0?DD_03m7<@10B380?TH`03Y2;P0i@2h0=S`Z03@i:@0c>2P2
03@j:@0;03<j:@0b>bT0;CLV02Xc8`0[<R00:c8N02`b7@0]<ah0;3<N02/c7P0]=1l00P0`>2402`0`
=b00;cLP02he800]=B80:c@S02P_8P0U;2008b`O02L`800V;ah08b/J008092`K00H08b/J01dT5@0M
91D082DD024U500P8a@JoooooaH0003oU`3oP00?ooooo`003Oooool01P23V900QYfE08NNU`26WiT0
QYfG08NMU@80RIjF00/0RYjG08bPV@2=XI`0SJ6L08nSV`2AY9`0TjFL09BTW@2GYil0UZJO09FUW@02
09BUV`0;09>UVP26V8h0Kgeg051IF00e>C`0<C@b02T[9@0Q8Qd071dI01TJ5P0G5A@00P0F4Q40300F
4@l05a4@01/G500X9200=CH`03Pn>@0nAT80@Da7049=BP11C4/0@Te<04A<C080A4]:00/0A4U904E9
B`17B4l0ADIA0453CP0h>dL0:bli01PJ9P0D51l04A4I00l@5@02014B5@0;01HI6@0K7ad07B8N01hT
7@0Q9ah08bTO02@X7P0T9Ah0;c8[03Hj=@0f>SX00P0Y;3002`0O7bD061PO01DE6P0G61/06Q`K01TM
6@0I7aT06R0J01HL5P0I81H07RLH008092lL00`0?Tdd04QI?P0^>BH08RXK01`S5P0H7a<05Q`?02@/
700b>bL0?TL`04E@>018DS`204QB?@0;04UE?01:ES/0BUHi04UD>017DcH0BE<f04YA=P17CS@0ATde
04M?=`15CSL00P13C3H02`12C3H0@ddg04=<=@12Bc40@4P^0458;P12B2l0@dP^04E:<@16Bc<0AT/e
0080ATXh00H0A4Th0457=P0nAC@0?4@c03a4<00lABh303e5;P0303e2;00k?R/0>3XZ0080=SPZ00T0
=3P/038h:`0]=BL0;3@T02/b8@0Z<Qh0:S<L02`e7@0Z=1X00P0X<AP302/d6`0:02de7`0]=240;3<T
02/c:00V;BD08RTQ028Y800S:R008b/P02@]7P8092dL00H08b/H020X5@0Q:A@08bPB020T400N8@hJ
oooooaP0003oU@3oP00?ooooo`003Oooool01P23V900QYfE08NNU`26WiT0QYfG08NMU@80RIjF00/0
RYjG08bPV@2=XI`0SJ6L08nSV`2AY9`0TjFL09BTW@2GYil0UZJO09FUW@0209BUV`0;09>UVP26V8h0
Kgeg051IF00e>C`0<C@b02T[9@0Q8Qd071dI01TJ5P0G5A@00P0F4Q40300F4@l05a4@01/G500X9200
=CH`03Pn>@0nAT80@Da7049=BP11C4/0@Te<04A<C080A4]:00/0A4U904E9B`17B4l0ADIA0453CP0h
>dL0:bli01PJ9P0D51l04A4I00l@5@02014B5@0;01HI6@0K7ad07B8N01hT7@0Q9ah08bTO02@X7P0T
9Ah0;c8[03Hj=@0f>SX00P0Y;3002`0O7bD061PO01DE6P0G61/06Q`K01TM6@0I7aT06R0J01HL5P0I
81H07RLH008092lL00`0?Tdd04QI?P0^>BH08RXK01`S5P0H7a<05Q`?02@/700b>bL0?TL`04E@>018
DS`204QB?@0;04UE?01:ES/0BUHi04UD>017DcH0BE<f04YA=P17CS@0ATde04M?=`15CSL00P13C3H0
2`12C3H0@ddg04=<=@12Bc40@4P^0458;P12B2l0@dP^04E:<@16Bc<0AT/e0080ATXh00H0A4Th0457
=P0nAC@0?4@c03a4<00lABh303e5;P0303e2;00k?R/0>3XZ0080=SPZ00T0=3P/038h:`0]=BL0;3@T
02/b8@0Z<Qh0:S<L02`e7@0Z=1X00P0X<AP302/d6`0:02de7`0]=240;3<T02/c:00V;BD08RTQ028Y
800S:R008b/P02@]7P8092dL00H08b/H020X5@0Q:A@08bPB020T400N8@hJoooooaP0003oU@3oP00?
ooooo`003Oooool01P21Th/0QibC08ZPV@29X9/0R9jK08JKVP80QYbJ00T0RIjM08bPWP2>X9l0Sj:P
08nRWP2AXih0U:FO09FTWP2FYIh00P2FYYl209NXWP0;09FWWP2FZYl0TZJK08:CR01XMVh0F6=J04YD
B00/<R/09R`U01dP700I6AP00P0G5AD0300H4a<05a8A01PB4P0J5A@081dJ02HV8`0/;bd0=3Xf03Y1
?@10BD@0Ae1;04QAC080B51;00/0ATa:04I9BP14AD`0A4E=04=6C`14BU@0@TQA03Y0AP0X;3@08RD[
01/N900201<D6`0;018D700K7b@082HX020W9P0R:BH08RXT024X8`0Q9B00:B`V03Pm=P0nA3h00P0k
@Cd02`0`=3<0:Rd]01lP8`0L7B006ahP01TL700G6aT05APF010E400D6A406R4D008061l?00`07B@E
02H_7@0S:a/06B0C01PN4@0I81<06AlC01dT5`0Y<B00=ClX03a7;P10BS82049<=@0804QB>@1:ESX0
BeHi04]F>@19DcL0C5Dg04]C=P19CcD204Q?=P0>04I>=`15CcP0ADlh04E?>@16D3T0ATli04M>=`14
C3@0?TD_03a2:`0m@RX0?T<[0456;`12Ac4204A8=00<04E;=`14BSL0@4Lg03m6=`0mACD0>d<`03]3
;`0k@S00>d8_03i5;`0l@B`0>Sh/0P0j?Rh02`0h>bh0<cT]038h;00c>B/0<3LV02de8P0^=B40;cPR
02lg7`0]=Ql0:c<N0080:c8O00/0:S4N02Xa7`0[<R40:c@T02/d9P0Y<RH09blT02D]8P0T;2008b/M
02H^7@0202D^700602D^6@0T;AL09bhE02H/4`0S:1008BD?6_oooolJ0000oi<0oh003oooool000go
oooo00H0PiF;08^OUP2<Xid0R9nL08FMW@26WIl208JLWP0;08NMW`2:Wil0S:2P08nRX@2AY:<0TZFS
09BVXP2EZ:00UJRO09JWWP2HZ:400P2HZJ802`2HZZ<0Uj^R09FZX02EZYl0TJJJ08VMT01jSGh0GfmR
04UBBP0d=cD0;2d^00809BDW00`07Q/M01dJ6`0O7Qh07ahM01lN700M7AX07QhL024R800X:RL0=S`f
0417?`17CTH204aCC@0;04eCD@1:CU40AdYA04A8DP10AU00ADiE04A>D`15D540@de;03m7A@0i?d40
0P0/;cL02`0P8Bd09b/e02H/=00N9BX072<T01/T8@0L8al0728L01/M6P0Q8b00;S4^0080=cdh0P0k
@c`02@0f?CL0;S@a02@Z:@0M8B805a`L018E5@0>4@l04AD@01HK4`0201LM4P0501XO500Q:1/09B`N
024X6`0L91H00P0L8aL01@0U;Al0<C/Y03M2;00kARh0?TP]0080@4T/00/0ADda04Q?<P18Cc80BU4d
04aB=`1<DcT0Be8h04UA>018DSP0B58g04UD=`0204QC=`0;04M@=`1:DCX0Be4l04a@?01:CS/0AT/i
04=8=`11Ac<0?dH`0417<00nAbl00P0mARl0300oB300?dPa03m7<@0oAc<0?dHc03]2<@0lA3<0?THe
03U2<00j@bl0>D8_03M0;P80>D4_00/0>D0`03Lo;P0g@2h0>D4]03Lo:P0d?2L0=SdY03Dl:@0c>BH0
<STW030h:00202de:00;02Tb9@0X<B@0:34T02Pa8P0X<R80:S@S02Tc8`0Y<R40:S<P02T`7P0Y;Q`0
0P0Y;a`01P0X;Q/0:2dI02P]5`0W;1H09RXF02DX5Q[ooooo70000?nA0?n000oooooo000=ooooo`06
08NLTP2=Xi/0S:BP08bSX`2:XZH0RZ6U0P29Wj802`27WIl0RIjO08^QX@2?Xj80TJBR09:UXP2BYZ40
U:NP09BWWP2GZIl0VJZR0080VZZU00/0VJbW09R/YP2GZjD0UjbT09N]Y@2G[J@0UZbP09>XV@1jRX00
K7U`06MdJ`0204E;C@0<038d?00g>cl0?D53034c=P0/;Rl0:B/Z02LY9@0V:2809bTS02/^9`0`<Rd0
>3Xd0P11@cd02`1:C4P0CDm?04iBE@1;DeH0ADiB049<CP11C4`0@di;04UDD01:De80BU5D0080AdiD
00/0?TA<03Y1B@0W;CP0728/01@K8@0C6Q`051XH01<G5@0A41804a4D01XG6@0202d/:@0;03/o>@0l
@S/0?TDm03a5?@0f?ST0;C@d02D/;@0K8B404ADD00lC400@4a000P0B5Q00300N9AX09B`O02T`8@0W
;Ql08b`K02<[6`0P9aL08RPI02DY6P0Z;ad0;C8O03@i8`80>3hU00P0?T@Z04E:;`17C380Addb04U>
<`1:D3H0BU4h04UA>080Ae0g00h0B5<g04QB=`18DSL0Ae0f04Q?>@1:D3d0C59004]A?P18CS`0A4/h
0499=@11BS<0@D/c03m:<`80?DPc00D0?DPa03a6;`0lARh0?DH_03e5;`0203U2;P0503]3<00h@Bl0
=T0]03@n;00e?bd00P0f@2d02`0e?b`0<ch[03Do;00f?b/0=ClZ03@m:P0e?R/0=d0]03Lo;00f?2`0
<c/]0080<3T/00/0;cT/02df:P0Z<bL0:34S02D^7`0V;ah0:34N02Xd7`0Z=1h0:C8L02T`6@0202T^
6@809R/I00@09R/H02@X5P0V:1P09RTJ6_oooolP0000ohd0oh003oooool000gooooo00H0QijF08bS
W02;XYl0S:>R08^QY02:X:@208VNY00;08VNX`2:Wj40S:6R08fSXP2?Y:80T:JQ09:XX02DZJ00TZJO
09FXXP2HZZ@00P2IZZH209R/Z@0909V]ZP2H[:X0V:bY09Z^ZP2J[jT0VZnU09Z^XP2:Vi40MH9l0080
IFm^00`0FF1T079lM`1hQ7`0IVi/061ZIP1GHUT0@DQ003Hj<P0d=Bh0<C0[030];00d<Bl203Dc<@0;
03Xi>00o?cl0AdY:04aCDP1<Ee@0BUI@04UEC@19E4d0C5IB04eEEP1<DUP00P1<DE/02`1<E5d0BEAK
03m:DP0e@4P092he020X:`0G6ah051@H018?5@0G4AD06Q@E0080=C<[00/0>STb03<b;`0a<300<S@b
03Tn>P0mAD00>dI0038n>00H8Ad04ALC00lC3`0200h@2`0<01`S5`0Q9aT08bTI02L]6@0X;a/0:30M
02X`700W;AX08RHF024S5@0M7a407R0B0P0U9aP02`0f>bL0BE8g04UB=`1:E3T0BU<g04UA=P16CCD0
AT`e04I==P16CCL0AU0h0080A4hg00/0AE0g04MA>`17DCd0B5<m04QB?016D3T0A4hg04===@12C3@0
@D`d049>=@02041<=00<03m;<P0mBS00?4P_03]6;@0mARd0?DD^03]3;@0j@bl0>T8`03Q1<00g@2h0
>48_0P0h@bl02`0f@Rd0=40Z03<o:@0d?bT0=3hX03<m:@0e?bX0=SlY03Lo:P0f?B/0=C/[0080<cX[
00H0<S//02lh:P0]=RT0;3DV02Pb8P0X<B0202Xd800302Tb7P0Z<Ad0:S0L0080:c4L00H0:BhJ02H/
5`0T:aD09BXF02DZ5`0V:aXJooooob00003o0`3oP0020000ohP0oh003oooool000gooooo00H0Q9ZC
08VPV@2;XId0RIjN08NLW`27WJ0308VOXP0:08VOX02;XJ00SJBT08nVYP2AZJH0TZZU09B[X`2EZJ@0
UjZX09JYZ080UZZX00/0V:ZY09V[Z@2I[:T0VZf[09b_[02N/:/0Wk6Z09j`Y`2O/ZH0RIZ@069/JP02
069ZJP0<07=mN@2BX9D0UZFI09RXW02JZYd0UJNG07>0M`1HHE`0De]E04eBC01BETd0AD@n0P0i=c@0
2`0e=380=S@d03`j>`12@d@0ADY904Q@B`1=Ed`0DEa?059MD`1@F5D0C5=F0080BU1H00/0CeEN051H
H@1<EV00BUEN04A@E@0mB4/0<SXl02T/<00R82@07QPL02DP80020450>@0;02lZ:P0U8B@08A`Q01dI
7P0S8b@0;C4_03@n=`0hA3T0:cP/01HO5`0C6@l00P0=4PP0300@5@/04aP<01@H2`0H7@d07R@D024X
600S:AT07bHG01`Q5P0V:al09BXN024U6`807b4H00/0;c@V05ESAP1KJ4/0FfQ;05MSB@1AFT@0BE4n
04I<>P13BSL0@dXf0417=@0203m7=00;0419=P12BcP0ADlk04IA>`18DS/0AU0k04A>>012C3D0@4`d
03m<<`11Cc@00P10Cc<03011CC40@4`a03m:<00oBBh0?dL_0417<@0m@c00?48c03Y2=00h@C80>48`
03U4<@80=T8]00/0=T4/03I2:`0f@RT0=d4W03Lo9`0e?BL0=3/V038i9@0d>bL0=3/X03<k:@02038l
:@0;038l:00_>2H0;CHU02`e9@0Y<b80:C8P02L`7P0X<1h0:S0N02X]7@0Z;A/00P0Z;Q`01P0X;1/0
9BXG028V5P0U:AT09BXI02DZ6Q[ooooo7`000?l30?n000L0003oQ03oP00?ooooo`003Oooool01P25
Ui@0RYjM08fPX`2;WZ@0RIbS08VMXP80RYnQ00/0Rj2P08bPW`2>XJ40Sj:V08nSZ02AYZX0TJRY096W
YP2DZ:L0V:b[09N[[00209N[Z`0;09V[Z`2L[J/0W:bZ09j^[@2P/:l0X;6^0:2`[02P/J/0XK>/09FU
W`1dOgl00P1^MgL03023ShX0WJbQ09j/XP2S/:L0Y[BZ0:NeZP2Q[JH0U9nJ08N@S@22S8H0SI^:06A/
G`80Be1600/0ADQ00410>`0o?3X0?CXj03`j?00n?Sd0@dM104Y@A`1?F4d0D5YA04mHD`0204iEEP0;
05=GG01CEed0CU9K04eCG@1<EUd0C5QL04]HF016DU00?D=2034a=00d<S<00P10@3/02`0W8bH081dR
01/H7`0E4QT04a8F01DF600J7Q`082HO028Z800I8aT05A`A00805Qd?00`051X=01<H300C60`051L;
01DH3@0G6a0061`A01DI3`0@4`d05Q/D01hS6P0R9a`202<W700;02/a8`0nAS@0EEm805aXD01RL5P0
H71H05QUD@1=ED@0@DHf03Hj;00c=RP00P0e>2T02`0h>b`0?40`03m5<`13BcL0AThj04A>?012CSd0
?d/h03m==P0oCS<0?dh`0080@4h_00`0@Dd^041<;P11BBh0@TX_0457<@10AC<0?D@d03a3=@0kA3L0
=d8d03E0;`0e@bd203E2:`0;03E2:P0f@RP0>4<Y03U2:@0g?RP0=c`Z03@i:@0`=bL0;cLV030h9`0^
>BP00P0]>2H02`0^>RD0;cXS02hh8@0^=al0:c@M02/c700Z<A/0:S0L02/_7@0[;1`0;BhM0080;BdM
00H0:b/N02PY6`0W:A/09bXM02H[7@0T:1dJooooobd0003oP03oP00?ooooo`003Oooool01P26UiP0
RibP08bNY`2;WJP0RYbW08^MYP80S9jV00/0SZ2T08jQX`2?XJ@0T::V092SY`2?Y:L0T:JW08nVY`2B
YZL0UZZ/09F[[P0209JZ[00;09R/Z`2K[Z/0VjfZ09f/Z`2O[Zh0X;2_0::b/02R/jd0Y;B]0:6aZ`2J
ZJ@00P2EXYd0302GYId0XK6V0:>aZ@2W]:d0Z;F_0:Vd[`2[]K00ZK:^0:Vc[@2W/JT0YK>U09FTT@80
QY9m00/0J6mQ065VF@1NH5H0E5E=04a=A`12@S`0?T0g03ho=`12AC`0Ada304aAB`0204mEDP0;05=I
F@1EFU`0DUUL051GF`1<EEP0BUIG04]IF@1?G5T0DeiI055GE01=D5400P15AdT02`0U8Rh081l/01XJ
9P0E4ah04Q4J010B5`0?4a<03aD@00lF3`0A6A004QX@00805b0@00`072@B01/R4@0I7@l061/>01LJ
3P0H6`l05AD;014A200>3@L03`h:01<C3`0F5Q0201HG4P0;01dO6@0Y;2D0=cdb04QBA01BH4l0FFYF
061cF`1MKUD0BeI103Lj:P0X9a/00P0V8aT02`0Y9A`0;B/Q038`9P0h>R`0?dDc045:=`11C3T0?DXe
03a:<@0mC2d0@4h[0080@4d[00`0@4/Z03i89`0nABL0?dD[0415<00m@c80>d<c03U0<`0g@3<0=T0b
03E0<00d@2/203A1:00;03A09@0h@RH0>D4W03U0:00i?BP0>3XX03Lk;00d>Rd0<ST/02lh;00/=RX0
0P0Y<bH02`0Z=B@0;3LR02`h800^>Ah0;3PL02`g700/=Q/0:c<K02db700]<1h0;RlO0080;BhN00H0
;B`P02XZ800Y:b80:2/S02@X800Q91dJoooooc40003oO03oP00?ooooo`003Oooool01P23UiL0QYZN
08ZNY@2<WZT0RibX08ZKY@80Ri^S00/0S9fS08jOY02@XJH0SZ2U08nSY@2AY:H0TJFW092UY`2AYJH0
Uj^[09V][P0209Z][@0;09V/[@2I[Jd0VZb[09b][02N[Zd0Wjn^0:6a[`2P/Jd0X[>/0:Bd[02S/ZX0
0P2R/:P0302P[jL0Xk:Y0:FbZ`2W]:h0ZKF`0:bf/P2^^KD0[KNc0:fh/P2[]Zh0ZKJZ0:^iY`80Z;JQ
00/0WjZG09ZUT`2CWH`0RI:307MoK`1NI5@0BTln03m2=00i>c00=cP`03Lh<P0203/m>P0;04I9B01>
E5<0DUYJ059LF`1@FeX0C5QG04YFE@1=F5P0E5iK05UPG@1JGeh00P1HG6002`18C5@0?45<02T]>P0N
8Rd061/V01<G7P0@5AP02a8@00T>2P0>50/0620A00807RLC00`08bdG02D^600S:QD082DC01dQ4@0J
7Pd05QP8018A1@0A3PD04Pl901HC3@0I5Q4201LD4`0;01DB5@0F4aL071XK02HY9`0e?CH0AeA505EV
CP16ESl0AUDk04EA=`0k@2d00P0m@3002`0g=Bd0;b/Y02hZ9P0a<2P0=SX^03To<P0lAC<0>dD`03]6
;00jA2P0?4LW0080?4HX00`0>T8W03Y09P0j@2L0>ClY03Po:`0g?Rd0=cl`03Ho<@0d?C00<c`]03Dm
:`0g?RT203Q0:00;03Q19`0j@RP0>d8Z03Y1:P0j@2/0>Ch[03Hk:P0e>b/0=3`/030h;00/=2L00P0[
=2H02`0Z<RD0:S<S02/d8`0[=R80;3LQ02dh8@0[=Al0:S@O02`d7`0[<Ah0:BdL0080:BdM00H0:2`N
02L[7`0W:b00:2`Q02H[7`0S9a/JooooocD0003oN03oP00?ooooo`003Oooool01P1nUIL0Q9^M08VO
X`2:WZH0R9bU08VKX`80Ri^Q00/0RibS08bMX`2=WjD0SZ2V092RY@2AXjD0TJBW09:VZP2AYZP0UJRY
09JYZP0209V/[00;09V/[P2J[:l0VJb^09b^[`2N[k80X;2d09n_/`2P[k40XK6`0:Bc/02T/Zl00P2U
/jh20:Fc[`0:0:Jc[P2W]Jh0ZKNa0:Zf/`2/^;@0[;Vd0:bi/`2[^K00Z[V[0:blZP80[KbZ00/0[K^Y
0:fjZ@2^^ZT0Z[JW09^VV@2BX8d0Ig1Q0414?00e>380;c</02/]9`0202XZ9@0;02d/:00l?CP0ATY4
04iED01BFUL0DeeJ055LFP1@FeX0E5iL05MQG01HGeX00P1JH5d02`1KHF00F61P04YAE00nATX0<CTn
01lU:`0E6al03Q@D00X?2`0>50/06B4A00807bTD00`0:C@M02hi8@0[=A`08RXD01dQ3P0H6PT04A<4
00lA0`0@40D04Q4801XI3`0N7A8201hL4`0;02HT6`0X9Qd08QlK02HU900a<bh0>Chf04I??`0`=RT0
724G028Y6`0[=2<00P1:Ecd0101PK500GVM@05ILB@17Bcd203m3=`050415=`0oACD0?48a03a2;00k
@bP00P0kA2P0300i@BL0=chV03Lo9P0e?2H0=3/U03@k9P0e?2T0=S`/03Dk;@0b>2T0<cTX03Hj:@80
>3`/00/0=cd]03Hm;00g?b`0=Sh]03Hn;00f?RX0=ChW03@m9`0d?2H0<3PT02dd8`0202`c8`0;02/a
8P0[<R<0:S4T02Ta9@0Y<BH0:C<V02Xd900[=280:S<P02Ta7P0Y;ad00P0X;a`01P0X;QT09R`H02L/
6@0Y;Q`0:2`I02L[61[ooooo=`000?mf0?n000oooooo000=ooooo`06082FU`25W9l0RZ2U08ZOZ028
WJH0QibS0P2:Vj<02`2<W:H0SIjW08bMYP2?X:P0TJ>Z096SZ@2AXj/0TjF[09:UZP2CY:X0U:B[0080
UJJ/00/0UjR^09ZZ/02KZk80WZfd0:2`]P2R/KL0XJne0:6^]02R[k@0Xk6d0:Jb/`020:Nd/`80Z;Bc
00X0Z;Ba0:Vd/02Z][80[KRf0:fj]`2]^KH0[;Vd0:bk/@2/^jd0[kf/0P2`_Zd02`2`_Jd0/;f^0;2m
[P2b_K00[k^_0:^j[02BX9@0HVaV04M?BP0j@3P0<CH]0080;BlT00/0:RXO02/Y8@0a;bX0>c/g03m1
?`17C4T0D5UC05EPF@1JIUh0FVEL05IOEP0205INEP0;05EME`1FGUT0EV5L05EPG@1>FeT0@e1=02`d
=00C5aP04ADB01<H3`0J8A<00P0N9QD0300S;1L09c0K02Pa6`0U:aH07R8@01HG2P0@3`L03Pd800h?
200@40/08bHL01lP608071`E00/0EV5606elFP0d>2d0?D@k0458?P0b>340:RhY028S7P0H6A<04Q4=
00h>2002020S6@0;06j0H@2;XGd0Q9Qh06ekI`1EH5@0EEmD051HC01<DdD0Adho04=:=`0oB3000P0n
B2d0300nB2`0?4DZ03]4:P0h@2H0=ShV03Dk9P0e>RH0=c/Y03Hk:P0b=bP0<CHW038f:080<cHZ00/0
<CLZ034h:`0b>Rd0<3T[02hg:00_>BH0;c/T02lj8P0_>B40;CLN02`e7`0202`d800;02`c800Z<B00
:C4Q02P`8`0W<2D0:38V02Td900Y<b40:C@P02Td7P0X<ad00P0X<QX01P0Y<AP0:2lF02L]5P0W;1P0
9R/H02L[6A[ooooo=`000?l_0?n000030000o`3oP000oh0000T0oh0010000?lg0?n000oooooo000=
ooooo`0607jAU@27W9l0RinU08VLYP26VjD0QibT0P29Vj802P2<WZ@0SInW08fNYP2?X:L0TJ6Y09>S
Z`2BXj/0TZB[09:SZP2CXj/309FSZ`0;09BT[02FYJd0VJN^09^Y/02N[;<0X:nd0:6_/`2S[[80Xk2c
0:B_/`2T/;<00P2U/K40302V/K00Yk>`0:Zf/P2/]kH0ZkJd0:Zf]02/^;H0ZkNd0:bj/`2[^k40[Kb_
0:jm[P80/;f^00/0/;f/0;:n[02b_J`0/kf]0;>n[P2b_Zl0[kf^0:2^W`2:V8P0HVaQ0455?P0203]0
=00:03Pk;P0h>Bd0=3@]03<a;`0a;Rh0;bh^03Df<`11ACh0CUI:05END@<0FF=E00/0EV1C059LD@1G
HeH0EV=G055OEP1AHEL0AeI<02D]:@0M91d06AhG01PM4`0201LL400<01TN3`0J7`l07B0B020T5P0O
8aD05QL>01<B3@0A40d03`h=00l=3@0I6AL05aHD0P0N7ah02`1oTgL0Y/:N09B_T01OL5l0?DDk02/_
9`0K71L05QHB01DD3`0C4@l04A0>00803P`<00/0Ae5109B]R029Wh00R9b10721K`1RLF<0HG1O06=a
G@1RKed0GV]I05e[E@0205QVCP0<051MA@1<ET00B54l04A;>011ASD0?D8a03Xn;P0h?2d0=cX[03<e
:P0b=BX0<C@X0P0b=RT02`0`=BP0;S<W02hd9`0/=2H0:C8T02Xd900Z=2<0:S<S02/e8`0/=b40;3HO
00<0:C8L00@0:C4M02T`7P0W<1l0:34Q0P0X<R80100X<Al0:34M02P`6P0W;aX202L^6@0602P^6@0V
;1P092TF02@Z6@0T:Q`08RTK6_ooooli0000ob`0oh000`000?l;0?n000@0003o=P3oP00?ooooo`00
3Oooool01P1fR8d0Q9RJ08NKXP25V:80PYFR08BGXP80Q9RQ00X0RIbT08fNY`2>WjP0SIjW08jOY`2@
XJT0Sj6Y096SZ@2AXjP0TjFZ0`2GYj`02`2EYZd0UJN/09RX[@2HYjd0VZR]09^Z[@2N[J`0XJn/0:Ba
[`2V/[80Y[6c0080Y[:a00`0Y[>^0:Rc[P2Y/jl0ZkJd0:Rd/P2W/k<0ZKJe0:Vg/`2Y^;80Z[R`0:fk
/02^_Jl20:nm[P0;0:nkZ`2`_:/0/[j[0;:mZ`2c_J/0];n]0;>o[`2b_Zh0/Kj/0:FaW`22RG`00P1b
N6`02`1aMf/0H6EK04M9A012@Sh0=S<b030[:P0Z9R<09R@O034b:@0o@cH0C5920080E5]900/0Ef5>
04YBA01<ETH0B5=2049??P10CSh0AUE3049??@0Z=2D082HI01lT5@0201XM3`0<01LI300G60`06QX@
01hO5P0N7aP061PB018B300A4P/04Q4=018@3P0F5A<06aXJ0P0K6a`02`0k@C/0GFeM09:^SP1mUGP0
>T@e02P/7`0N7Q@05aD=010=200?2`T040/<00803P/=00/09BTU07bDN02>YhX0PiYo082EN`1SLEl0
F6AC05UTD`1SKUh0OHih08>GO@0208>FO00<086BMP1ePfP0I6eG065WEP1NI5T0FF1F051HCP16Cd<0
@4Lk03a2>00i?CD0=c/c0P0e>S002`0d>Bd0<SPZ038i:@0_>2T0;SHY02Xa9`0/<RP0:c8V02T`8`0Z
<R00;3<M0080:S4J00P0;38J02`b6`0[<Ad0:2lM02D]6`0T;1d08b/L02<[6`8092XI00T09BXI02H[
6P0V:aX09RTJ02<W6@0Q9QP08BTK024X7@0P:1d06_ooooln0000obT0oh000P000?l:0?n000@0003o
103oP0060000ob`0oh003oooool000gooooo00H0O8n?08:EU@26VYd0QiZR08BFXP23UJ8208>EX@0;
08RIX`2;VjH0S9fX08bMY`2;WJH0S:2X08bPY`2=XJH0Sj:U096SY`2BYJP00P2CYZP02`2DYjL0UJNW
09JXZ@2FYjX0VZV/09^ZZ`2M[:/0X:n/0::_[02T/:d0Y[:^0080Yk>_00`0Z;B_0:Rd[P2W/Zh0Z;B`
0:Nd/P2V/[80Yk>c0:Nd/@2Y][40[KVc0:fi/@2^^k020;6n/00;0;2m/02a_Jh0/[j/0;>mZP2c_J/0
/kf]0;Bo[`2d_jh0];n]0;BnZ`2`^JL00P2[/j802`2Y/Z00W:FE07b0MP1cN6`0?3Dg03H`;`0`:RX0
:RHT02PU800];B@0<c@W0080>ch^00/0?T@a038e9`0_=2H0:c4R02L_7`0Y<1l0<S/W03]5;@0`=R<0
:RhN02DX6@0201hP5@0301TJ4@0F5`l06Q/D0080824K00L061TE01<E4@0C5Pl04aH?018C3P0H6QH0
7R0M00809BTS00/09BTT02/a:`1=FT/0FFQF04YFA@0R9Ad07AdE01TF4@0A3@`03PT<00d52`0200`7
3P0;03Dh=P1cQW<0PiZ507fEO`23VGl0PIAi07B2J`1WLV00HFYJ07^;M023UGX00P26Ug`0302<WH00
S9j006ehI01KHEL0HVQO06A]I01YLfP0JGEU065[G@1IHeP0DEYB04eFD080BU=;00/0Ae1604A<@@11
BC`0?D@h03Po=@0b=bl0;c8Z02``9P0[;b<0:blN02X_6`0202`_6`0;02h`6P0^<A/0;C0L02DZ6@0N
91@05Q`?018G2`0A5P/051T=01HJ3`0N8Q@00`0U:AX01@0T9aX092HK028V700O91`07RDK01[ooooo
@@000?lb0?n000L0003o00<0oh000000o`000?l01@000?l30?n00080003o9P3oP00?ooooo`003Ooo
ool01P1mTH`0QIRE08VLWP27VZ40Q9NQ08BFX@80QIRR00/0QiVQ08ZKXP2;W:<0RibT08^NY02;X:H0
S:6V08fQY02>XZ@0T:>V08nTY`0208nTY@0;096UY@2BYJD0UZRW09VXZ@2KZJX0WJZZ09jZZ`2PZjh0
XZf_0:>][P2U/:h00P2V/Jh0302X/jl0Z;B`0:Vd[`2Y/jl0ZKJb0:Ve/`2X]K40ZKF_0:^g/02]^;00
[KN^0:jj[`80/;b_00/0/Kf`0;>n/02c_Jl0];j^0;Bn[@2e_jd0]/6^0;G1[P2e`Jd0]KnZ0;FoZ`02
0;BmZP0;0;>mZP2d_jT0/KbV0:VeWP1SHU`0>c@f040l>00m?3<0>ST^03Lg:P0g>2P00P0b<b<02`0/
;1d0:RPL02DT6@0P8AD082<D02<U5@0[;a`0=CTU03Dh9P0/;b809RPN00807b0J00`06a`H01XK5`0N
81`08R@Q020R7P0K7QX05aXF01LI500H6a<051H>014C3@0I6QD202DY7P0;02dc9P0f?Rl0A4dk04QC
?P12C3P09RXO020R6P0M7AT061DE01DA500C3A<00P0A3A<02`0Q7b<0CUI?05i]H01`Pfh0NHac08VL
OP2;WH00QiQn08:CN@20TGL0PYEi0080QIMk00`0Q9Ak08ZKPP2;VhD0IW1V05aUG@1DFU@0HV]N08^M
P`1fPg40EEiG05EOF@1KIUl205eZH@0;06AbIP1YN6L0IgES06AaGP1LIUD0D5M904E8?P0l?S@0>3/_
03Dh:00a<b800P0a<R002`0b<Qh0<34O02`^800U:A`06A`@00lB20082`<010L000H80P05208030l6
00805AT=00H06b0B020S5@0Q91L08RDJ024U6P0O91PJoooood40003o=03oP00=0000o`@0oh000P00
0?l60?n00080003o7@3oP00?ooooo`003Oooool01P1mTH`0QIRE08VLWP27VZ40Q9NQ08BFX@80QIRR
00/0QiVQ08ZKXP2;W:<0RibT08^NY02;X:H0S:6V08fQY02>XZ@0T:>V08nTY`0208nTY@0;096UY@2B
YJD0UZRW09VXZ@2KZJX0WJZZ09jZZ`2PZjh0XZf_0:>][P2U/:h00P2V/Jh0302X/jl0Z;B`0:Vd[`2Y
/jl0ZKJb0:Ve/`2X]K40ZKF_0:^g/02]^;00[KN^0:jj[`80/;b_00/0/Kf`0;>n/02c_Jl0];j^0;Bn
[@2e_jd0]/6^0;G1[P2e`Jd0]KnZ0;FoZ`020;BmZP0;0;>mZP2d_jT0/KbV0:VeWP1SHU`0>c@f040l
>00m?3<0>ST^03Lg:P0g>2P00P0b<b<02`0/;1d0:RPL02DT6@0P8AD082<D02<U5@0[;a`0=CTU03Dh
9P0/;b809RPN00807b0J00`06a`H01XK5`0N81`08R@Q020R7P0K7QX05aXF01LI500H6a<051H>014C
3@0I6QD202DY7P0;02dc9P0f?Rl0A4dk04QC?P12C3P09RXO020R6P0M7AT061DE01DA500C3A<00P0A
3A<02`0Q7b<0CUI?05i]H01`Pfh0NHac08VLOP2;WH00QiQn08:CN@20TGL0PYEi0080QIMk00`0Q9Ak
08ZKPP2;VhD0IW1V05aUG@1DFU@0HV]N08^MP`1fPg40EEiG05EOF@1KIUl205eZH@0;06AbIP1YN6L0
IgES06AaGP1LIUD0D5M904E8?P0l?S@0>3/_03Dh:00a<b800P0a<R002`0b<Qh0<34O02`^800U:A`0
6A`@00lB20082`<010L000H80P05208030l600805AT=00H06b0B020S5@0Q91L08RDJ024U6P0O91PJ
oooood40003o=03oP00=0000o`@0oh000P000?l60?n00080003o7@3oP00?ooooo`003Oooool01P1e
R8H0OiBC08FJWP26Vj80QYVT08JIYP80QiZW00/0Qi^V08VLYP2;WZD0RYfT08^NY@2:WZD0RinV08fQ
Y@2@XjD0TJFX096VZP02092UZ00;09:XZ@2DYjL0UZNV09VYZ02LZjX0Wjb/0:6][P2T[k00YZn`0:F^
[`2U[k000P2W/[020:Vc/00:0:Zc/@2Z];<0ZkNd0:bh]02[]k80[KZb0:fi/P2]^K40[[R`0;2k/@80
/[fc00/0/[fb0;>n/@2c_[00];j^0;BnZ`2f_j/0^<6]0;O0[@2f`:h0]L2_0;S2/@020;W2/00;0;W1
[P2i`Z`0^L>[0;c9[02NYi00FeQB04Y7@P1iPF/0Jg5M05AIB01BEd@00P13ACD02`0g=RP0<C4S02d]
7`0Z:ad0:2TI02PZ600/;Qd0>3TY03Xj;@0b<bT0:RXS00808b@N00<07AhI01`M600R92000P0V:B@0
1`0U:2808BDP01`O700J7AP04Q@?00l@300@4@`00P0E5`l02`0L81D0:c4Q03Y2;@0kA2h0=ShY02/a
800T9aX07b0H01`L600K6QX06QXJ00807AlM00/07B0N02DY9@0f?C@0@d/o04Q>@P1nS7<0UjV<08nQ
Q`2BY8P0T:6508jPQ00208fOQ@0<08ZKQ028VH@0R9^6086CP01eQ7<0KWYY06UeI028VX00SjF906]j
JP1QKf40FfQK0P1EGeD02`1RKf80MHMd07V<MP1lSgL0Nhif07>3K@1/NfH0JGEQ06A]FP1HH4h0DeY9
0080CUA200/0AT`i03a1<P0f?300:2hU01`R600A5@d02Pd600H80@041P000@<00001000200<50@06
00L:0`0=3`D061X=024T500R9aH08bXI6_oooom20000o`80oh000P000?la0?n00180003o1@3oP007
0000oaP0oh003oooool000gooooo00H0LhN507fBT`24V9l0QYZT08JIYP26VJL208JHY`0;08JIY`28
W:P0RIfW08ZOYP2=X:L0SInX08nRZP2@Y:X0SZ:W092UZ02DYj/00P2DYjd0102CYj`0UZV_09NZ[P2J
ZZh209^Z[@0309j][`2P[k00XZna0080Xjna0P2V/k<0302W]K80Z;Fb0:Vd]@2Z];H0ZkJh0:bg]`2^
^KL0[kZe0:ji]@2`^KD0/;Rd0;2k]P80/Kff00/0/[fe0;6m/P2b_[80]L2`0;K0[`2g_jh0^/6_0;_1
/@2j`;<0^/:f0;W1]@020;_1]00;0;c4]02ka;00^/B/0;c7Z`2iaZP0W:B=07EdJP2OYY80ZK6L09fW
TP2EX8T00P1gOVX02`19BCd0A4Hf04=7=013Ac40?d<[03a0:00h>bP0>c/]03dl<00i>2d0;BdU0080
9bLO00`08B4J01hN5`0P81X092@M02PZ8`0/;bL0;30Y02<U900M7Qd04Q<B00l@3P0=40d200lB3@0;
01<G4@0M8aT092/M02L]7@0Y<1d09BXH020R500L71H06APG01/J6`0K6Qd00P0`=C@02`14CDL0@di6
04iLD01@Fdh0C5=704e@B@2CXhX0RYV408BCP020T7/0P8mj0080RIb400T0RIb508ZMQ`2;WhT0Qib5
08FIP@1mT7L0MhYb07V;LP1lT7D00P1kSgH01`1gRW<0LhI`07>6L01cQG00LhEa07B6L`1gR7H00P1h
RGH01@1hRGD0NX]d07b;L`1iQW<0M81`0080LGi^00X0KWa/06MdIP1LJU`0=Slh01`P7@0G6aH02@X6
00@50@020`000@800`000@001P000P000P@000`>0`0J7@`08RLC02DZ5a[oooooBP000?l^0?n002@0
003o4@3oP00?ooooo`003Oooool01P1bQ8D0OI2E08:EX023UZ@0PYJS08>FX`80Q9NS00/0Q9NR08FJ
X`28WZD0RYnU08ZNY@29WJH0RYnX08bRZ02:WjH0RYnU08jSY`0209:UZ`0609BW[`2DYk40UZNa09NX
/02IZ:h0VZV_0P2KZZl00`2LZ[00WZba0:2//@020:>_/@0<0:Bb/`2W/kD0Yk:e0:Ja]02X/[H0ZK:h
0:^d^02/][H0ZkBd0:bc/`2^]K<0[kVe0P2_^KL02`2a_;H0/Kbe0;:m]02c_K80/kf`0;Bm/02f_[00
^;jb0;[0]P2i`[P0^<6g0080]l2d00/0]/6c0;O3/02g`Z`0]l6Y0;K1Z@2f`:X0/kRV0;:hYP2f_J/0
][j[0;G0Z@020:jiX@0;07QjL01]Kf@0O8=_086:L@1bNF<0Ff5?059GA`18Bcd0A4@i03dj<@0b<2L0
0P0];2<0300W9Qh08B0J020P600S91/09RHO02PZ8P0Y:b@08R@P01dM700H5aP051<E014D4`804QLC
00/05adG01/Q6P0Q:Ad09bhP02Ta800U:aX07b8D01/L5@0K6AL061DG01`J7`0203Lm?P0;07F8M`1]
PW00HGAT06AfHP1JIe@0BTm609R[T02>XX/0LH=c06AcI@1AFe800P1aPFd03022UGd0Q9R008VNQP28
WHL0RZ6805m_H018DdT0QIYl07:3JP1_OV/0Nhei07fAO080NY1k00/0NY1j07N;M@1fRGD0MHAd07B2
M@1bP7D0LX5e07>3L`1dPg40M89a07F2L00207B1KP0707B1K`1dPVl0N8Yc04mKD00B4QL02`/<0041
0@03000000<0004000H00P@000T;0P0B50H05aX:01lT4@0S:1@Jooooodl0003o8`3oP0020000o`@0
oh000`000?l20?n000L0003o0P3oP00G0000oa00oh003oooool000gooooo00H0NHV>07jAV@20Tj00
Oi>P082DX@21U:0308>GX00508BHX@26VZ<0RIfV08RMY`29WJH00`2:WZH03`2;WZH0SJ2V096SZ`2A
Xj/0TZB]09>T[`2EXk00UZB_09RW/02JZK40VjVa09bY/@2LZK80WZbc0::]/`020:>^/P0<0:>]/P2W
/;D0ZK6e0:R`]@2Y/[H0ZkBi0:bd^02/]KL0[KFe0:fe/`2^]K80/;Rd0P2a^[D02`2b^[D0/[^d0;:l
/P2b_;00/Kb^0;:l[P2c_Jh0/kb_0;Fn/P2e_k<0]<6c0080]<6b00/0/l2a0;G2[`2f`Zh0^<:^0;S2
[02i`J/0^l6[0;_2Z`2i`:X0^/6Z0;c3Z@020;_3Z00;0;BkXP2^/id0[K>L0;2iW`2[]9T0W:>:08fC
N`1YJUX0G5Y>04]8?@0m>bl00P0e=BT0300]<2@09RXP02LW7P0Y:Ql0:R/Q02DX7@0P8Q/07AdI01XJ
5`0H5aL05ADF01HH5`806alK00/092TP02L]8@0Y<2<0:c4U02`b9P0[<B809R/M02DX7P0R8ad07A`I
01PH6002030f<@0;07^BMP28Y800DV9=04eJAP0oB3T0>Chd06AaGP1OKEd0JWmY06UmI`1JJUH00P1Z
Nf@0301jSG@0OY9j08:FO`24V880RIn6065_H@10AD40V[6?055ICP12B4H0SjB=07nDP080IWQ[00/0
LHEd07Z>N`1]Nfd0K7Q]075lM01bOGP0LH1i07:1MP1bPW<0Lh5a07B2K`02071nJ@0;06ijI@1ZMf40
HFeJ03m5?@0D4QD02@D800D310030@800P4200400@000@000P010`001P051`805QP=020S500R9aL0
8bXI02@/61[oooooDP000?lP0?n00080003o1P3oP0020000o`030?n000000?l0003o00D0003o0P3o
P0000`000?l0oh000?n000020000o`80oh003`000?lA0?n000oooooo000=ooooo`0607Z9S`1oTYX0
PIFP08:GX@21UJ40PYJQ0P23Uj802`24Uj<0Q9NT08JHY@29VZL0RI^X08ZLZ02<WZP0SJ2X08bOY`2=
X:L0SZ6X0080T:6[00/0TjF]09BT[@2DXZl0UjFa09VV/`2JZ;@0W:Vc09fZ/`2NZkD0X:ff0:6]]P02
0::_]00<0:B`/P2V/;40Yk2a0:N`/`2Z/kD0ZkBf0:ff]`2^]kL0[[Ne0:jg/`2^^;40/KZb0P2b_;40
1@2b^k<0/[^b0;:l/P2b_:l0/Kb^0080/kj^00@0];f_0;Fo[`2d_jh0]L2_0P2g`[802`2h`k<0^<:a
0;W3/`2i`[80^<:^0;S2[02j`Z/0_<B[0;g5Z`2naZX0_LBX0080_LBV00/0_/JV0;c4YP2k`jH0^lBT
0;[3XP2jaJ40];jJ0::YRP2CVGh0LGAO04U8=`0204A7<P0<03a2;`0e>RX0<c@W034a900_;R80:RXO
02@T6`0O81T071hG01XL5P0I6aH071hI0P0Q91h02`0]<BL0;c<W030e:00a=2T0<3<X030d:00^<BD0
;30U02/^900N7aL06AXB00805QP@00/092TM03Y5<P0a>2T0;S8U02P/8P0W:b809b`T020U7P1>GDT0
JgmQ069cF00207>6JP0<0763JP1`PF/0KGi[0765M01gS7/0LhMe06j0K@28WX<0GVYO0499BP2:X8/0
TZ^B0P1iS7X02`1lSg/0Oi5m03do@013ADP0MH5h06miM@1OJ6H0J7I^06imKP1^OF`0KGeX0080K7aU
00/0Jg]T06MfG`1AG4X0=Shc01TK6@0=30d02`P:00P51`0610@00`8200810@0200P:1P0601@G400O
8aP09b`L02T_800X;b00:C0P6_oooomD0000obL0oh0000<0003o0?n000000?l02@000?l20?n000H0
003o0P3oP0020000o`030?n000000?l0003o00H0003o4@3oP00?ooooo`003Oooool01P1dQXX0OI6E
086EV`23Uih0PYJN08>FX080Q9JQ00/0PiFS08FFX`26Uj<0QiNR08ZIYP2;VjL0S9bW08fOZ02>XJL0
SZ2W08nOZ002092PZ`0;096Q[@2EXjd0UZB_09NU/@2IYK80VZNc09^Y/P2JZ;40W:Zc09f[]02MZk<0
0P2O[;001P2R[k40Y:n`0:N`[P2Y/[40Zk>d0:Zc]@80ZkFe00@0[;Jd0:bg/`2^^K40[kZ`0P2_^jl0
2`2a_;40/K^a0;6k/P2a^k40/[ba0;Fm/P2h`;80^<2c0;S0/P2h`K00^<:_0080^L:_00/0^/>a0;[2
/`2i`[<0^/>d0;_3/`2i`jl0^<6[0;_4Z`2maZX0_/JX0;k6YP020;o7Y@0;0;g4Y02ma:D0_LBU0;k6
Y02naJ80^lJQ0;[5WP2g`Y/0]L6J0:RdS@1_LEL00P1NH4P0301KGDH0EeY5059D@@16ACL0?S`a03<a
:00Y:B0092HL028T6P0O8AT07QlG020R6@8092LM00/0;c8V03Dg:P0h>Rd0>3X]03Hg;00b<bT0;BhU
02TZ8P0Z;2<0:2/R020R6`0201`N5`0;01DG4P0E5Q406Q/D01TI4`0H6A@06ahH020S700L7aX092TP
04MD?P1@GTH00P1cR6H0301YO5h0F6M?03a5>013CD@0CU]D06EhJP1[P6h0KhA_06YnK@1RMFP0LXQf
08BMP`80Qin400/0QIZ1071mK@0^:c<0:bTd06inL`1bPWH0?45505EPFP1dQg80FVMI03Y0>@0204aF
AP0;06EeG@1QL5X0BUI5030i;`0L81d04Q<B00T92P061@H01@@400@30@020P000P0G71801P0[=280
;3DS02de8`0[<B409b`P02DY7Q[oooooE@000?lX0?n000<0003o1@3oP0030000o`030?n000000?l0
003o00@0003o0P3oP0020000o`80oh0000<0003o0?n0003oP0005@3oP00?ooooo`003Oooool01P1_
P8P0NHbC082DW023UYh0PiFN08BEW`80Q9FP00/0QINQ08FHX024Uil0QiVP08ZJX`2;VZH0S9ZW08jM
ZP2>WZT0T9jY09>QZ`0309FR[@0:09JS[@2HY:h0V:J`09RU/@2IYk80VZRb09ZW/@2KZK80VjVa09^Z
/@80Wjja00`0XZnb0:B_/02V/Jl0Z;:`0:Zc/`2[/kD0ZkBf0:^d^02/][L0[;Jf0:ji]@2_^[@20:nj
/@0;0;6k/@2c^k80/k^b0;Fl]02g_[D0^;jd0;Vo]02j_kD0^;fc0;Ro/`2h`:l00P2h`:h02`2k`K40
_<:c0;_1/`2l`[@0_/Fb0;g6[`2ka:d0_<N/0;c8ZP2kaZH0_LJS0080`<RT00/0_/FS0;k6YP2naJH0
_/BU0;o6Y02maZ80^lFP0;c7X@2kaZ00_<NP0:nhU00209jSQ@0<09^QP`2RZXT0Uj2007AgH@15@CX0
?cde03<c:P0/;b<0:BhP02T]800Z:al0:b/P0P0[;2<02`0b<bX0?d8c04=7>00n@cL0=cXb034f;@0/
;bT0:2XV02@V8P0T:2408bLN008082<J00/06alE01`O5P0L7AH05QD@01XK4P0P8QL08bHL024S7@0K
7AT06QlH02<X7`02034j:`0<03M1;`0h@Bl0<3HX02X_8P0W:b40=3d`04EB@@1RMUd0EFE@049>@@1C
He<0JgiY0P1bQg402`1dRGH0MXMh055JE`0oB4T0GFiS07bCO01FIEL0Hg=Q0763K@1?FDd071XM0080
:BXX00/0GfaI05APD00i@ST0:S8/01lT800H6aL03a8?00P:200520@01@P200H90P0201PO4@0603m?
<`14E3T0>4@_02df9P0X;b8092PN6_oooomK0000obl0oh001@000?l30?n000040000o`3oP000oh00
0000oaL0oh003oooool000gooooo00H0MHN<07nBV023Uil0Q9NP08>DX022U:4208:DXP0;08BGX`25
VZ<0QIVP08RKXP2;WJD0SIfX08jLZ02>WZ/0Sj2]09:Q[P2DXZh00P2EXZd02`2DXj`0UZB/09RU[@2I
Yjl0VZRc09^X]02KZ;<0W:Vc09j/]@2N[K@0W:^`0080WZf_00`0XK2`0:>b[`2V];00Yk6^0:Zc[`2[
/k80[;Be0:fe^02]]kP0[[Vh0:jh^02_^KH20:nk]@0;0;6l]@2a^[<0/[Zc0;Bl]P2g_kT0^;fg0;Vo
]`2j_kP0^[ne0;W0/`2h`;800P2i`K002`2ma;80_LBc0;g3/`2n`k80_lF`0;k7[P2oaZh0_/N^0;c6
ZP2kaZP0_/NV0080_lZV00/0_<JU0;c6YP2maJH0_LFU0;o8Y`2ob:H0_LNR0;o9Y030bZ@0_lVS0;k8
XP020;k7XP0<0;_5X@2laJ@0^/FS0:ZdU01aLV80DU1605=EB@1;Cd40ADXi04A9=`13ASH0@dDf0P0o
@SD02`0m@CD0A4Tj04U??`11AcX0>3`d03Lk=@0`=300;2l/02T/:`0Z;RT0:BdV00809b/S00/092PP
02@X7P0R91`06ATC01/L5@0Q8aX092LM024T700M7aX061/F01LI5@02024V7@0<02L[8@0V:Al08bDM
020R6@0O8QL08BHI02<X7018ESh0D5m403Q1;P0_=2L0=cha0P10B3`02`17DDP0G6YO07>7MP1NKV<0
E6AI05maH01WNF@0K7iY06emK01OK640@DM50080BDm;00/0GFIK04eCC@1QKeh06alO01/P7@0A5Q00
310:00L:1@0520@02@/600d@2P0200lC2`0602Pc8P0kBS@0>4Dc03I1<`0_>2d092`R6_oooomL0000
oc<0oh0000@0003o0?n0003oP000oh000`000?lG0?n000oooooo000=ooooo`0607Z>SP23UiT0QYVO
08JHXP24Tj80QIBV0P25UJP02`25UjP0QIVW08JJY025VJ80RI^T08^LY`2;WJP0S9nZ08fPZ`2>WjX0
T:6]0080TZ:/00L0T::Y09>UZ`2FYZd0VJJ^09VW/02KZ;80WJVa0080WJZa00@0Wjbb09n//02O[Zl0
Wjj_0P2R/;802P2S/[40Y;2_0:Nb[`2Z];80[KFd0:fe]P2]]kH0[;Nd0:bf]02]]k@20:ni]P0;0:nj
]P2^^K@0[kVe0;:k]P2e_KP0];^g0;Fm^02i_kT0^/6g0;Ro]@2h_k@00P2i`;<02`2i`K80^l>d0;g3
]@2k`[<0^l>`0;g6/02na[00_LJ^0;c5[02ka:T0_<JY0080_LNY00/0_<JY0;c4Z@2laJP0_LFW0;k6
Z02ob:L0_lVV0<7;YP2obZD0_/RT0;g7X`020;g7Y00<0;g6Y@2maZH0_LFU0;_6Y@2`^i/0UIZ209NO
QP2=UG`0MgeW06mdGP1VJEH0H69@0P1AE4H02`1:CT40ADPl04=5>00o@CD0>c`d03Ti=@0h>CD0=cXe
03Pj=`0d=c@0;c8^0080;c<]00/0;C8[02/`:@0U:B806adH01TJ5@0M81P08B@J024S6P0L7QH05aTB
01dO600202/_9P0<02db9`0Y;B808B8L01hO600K71D06AhD01/O500L81<0:2hM02`b7`0/<R009RXK
0P0P8QP02`0M7aT08B@P04E@@`1<F4/0=3`h03Hn>017DdL0EfMH069eI01WNVX0IGEW0080J7MY00/0
HViT038f>018E4X092/U01lU7`0=4@d0310900X<1@0:2P@03`l;00l@3@0200d=300600h?3`0A5180
51PE02P`9P0a>Bh09bhV6_oooomQ0000ocD0oh0000@0003o0?n000000?l0003o4`3oP00?ooooo`00
3Oooool01P1nT9<0Q9JL08JGXP26UZD0QY>V08JCZ@80QYF[00/0QIJZ08JJZ027W:@0R9bR08VMX`2:
WJD0RYjV08bPZ02>XJX0SYnZ092P[@02096R[@0;096SZ`2CYJ`0UZJ]09RU[@2HYJh0V:B^09RU[P2L
ZK00WZZ`09n[/02OZZl00P2OZjl0302R[k80Xk2b0:>`/`2S[[40YJn`0:Ra/P2Z/[@0Z[>c0:bf]02/
][D0ZkFe0:^e]080[[Rf0P2^^KL02@2_^KL0/KZh0;:k^@2c^[P0];bh0;Rm^02j`;T0^Kjg0;Vm]`02
0;Vn]`80^L2g00T0^<2f0;S1]02i`[40^/B`0;_4/02lak00^lJ^0;c6[P2naZh00`2na:h02P2oaZl0
`<N_0<76[P2n`j`0_lB[0;o6Z@30bJP0_lVV0;o8Y`2najP20;k7Z@0<0;c5Z02naZP0_lNY0;k6Z02l
aJP0^<2T0;O0Y02e_Z80[KJJ09ZRQP28SgD0MW]T0P1KGDd02`1HFTX0D55504];@@15AC`0@D4i03hl
=P1<D4<0F65@055JB`1<E4H0>Cdb0080<38Z00/0:bdV02PZ900W:B@08B<N01`M600O8AT08bHK024V
6`0N81P06Q/F02@V7`0202X^9P0<02`_9P0Z;2809BLO028S700P8QX07R4H01/M4`0D50/04a<901PI
3@0O81807QhB0P0G5`h02`0C50d04A4<02<V7@1FITl0;cL^02@Z9@0Q9bL08b/Y03I1>P1BHU40GFiI
0080EfAD00/0EfEF04=@A@0nC400?ddl01hT700=4@`04AD?018C300B4Pd04a4?010=3@0200`82`06
00X72P091PT02PH:00h=400E5AH082<P6_oooomS0000odX0oh003oooool000gooooo00H0P92D08FD
W@25UJ@0QIJX08FEZP24U:/2086BZ@0608:DZ024V:L0QibW08NKY@29WJL0RijY0P2=X:/00`2@XJ/0
TJ2[09>Q[@0209BR[`0;09BT/@2EY:l0UjJ^09RV[02IYJ`0VJJ]09NT[02JYjh0W:V_09jZ/02P[;40
0P2O[;40302P[K40XJj`0::_/@2T[k80YJja0:N`/`2X/[<0ZK>c0:bf]02]]kH0[[Rj0:jg^@80[KNh
00X0[KNg0:ni^02b^k/0/kZj0;Bj^`2f^k`0]kbl0;Vm_@2k_[h0^[jl0`2j_k/02P2i_kT0^/6k0;[3
^P2j`kL0^/>d0;[4/`2ka;<0_LFc0;g6/`2na[@30;o6]@040;k5]02maK80_lFb0<37/@80`/J`00D0
`<F]0<;8[@30aZT0`LR[0<79[@020<79[P0<0<38[P2oaj`0_/JZ0;o7ZP2naZ/0_/F[0;c4Z@2ka:P0
^LBW0;G1X`2^^Yd0Y;2C0P29T7L02`1mPf/0L79P05mMD`1BCdX0CTe704M8?`1;Cd80G6UC06IgF`1S
LeH0>Sl^0080;BlT00/0:2PP028R7@0P8Ah08R8P02<S8P0V:2@09RTT02<Y900N8b407B4P03M0=`02
03e7?00<034g;`0/<BL0:B/R02PZ800Z;B<09RTP01`M5P0C4``0410601HG2P0M7@h06a/<0P0B4@T0
2`0=30L02PT500l?2`0g@340:c<Y024W8P0K8Al05ahL01@I600N9Qh0:C<S00809B`L00/09bhN030i
:00oBSP0Ae@m01`O5P0E5a008BDK01TK5@0O8AX07AdI01@B4`0200l;400600d83`0=1Pd03@H<00`5
3P0<1Q00518G6_oooomW0000odH0oh003oooool000gooooo00@0O8jD08>EWP25UjD0PiFX0P22TjX2
08>EZ@0;08>FZ024VJP0QYZX08NKZ@29VjT0S9f/08nP[@2?WZ`0TIn/09:P[02EXJl00P2FX[402`2E
X[40UZBa09JU[`2GYZd0VJN]09^Z[`2KZ:h0W:R_09^X[`2NZk40Wjba00<0Wjbb00/0X:fd0::_]P2T
[kD0Y:nd0:Ra]@2X/kH0Z;Bd0:Zf]@2/][H0[[Nh0:nh^`020:jh^P0;0:ni^02_^[L0/[Zi0;Fk^P2f
^kX0]k^k0;Vl_P2k_l40_<320;_0`02k_kl00P2j_kh0202i_[/0^/2k0;W0^P2k`kP0_lRh0;c4]02l
`k80_L>c0P2ma;@03P2ma;D0`<Jg0<36]`2oakL0_/Rg0;k7]P2na[@0`<Jc0<?8/`32a[00`lN^0<77
Z`31b:d0`/R_0P32bK003032bK40`<N^0;o7[030b:/0`<R/0<37[P2oaZd0_LF[0;g6[02laZ/0^/FY
0;W5Y`80];nS00/0[KJK0:J_U@2;T7d0K6eS05QGD@1EEDd0BDY20495>`19CSl0AD`l03Dj;P0202hd
:@0;02P/8`0T9R007b4N020R800W:RL0:blZ02/`:`0Z;b/09RTX02@W:00kA3d00P13CT@0300e?SH0
<c/b030g;@0_=B/0;S@Z02DX8P0L7AX04Q4@010@2P0E5Pd06ad@01`N40805aT>00/0410:00d<1`0<
2`L04A0<01HI4`0F6QH051PF014E4`0A5Q805ahF01TP5@0201LN400;01LM3P0F6Pd06Q`A028U600L
7aD07B8G024V700K7QH0;S@W034f:00[;b<00P0U9ah01P0V91l09R<N01lI6@0I4aH050lE014=5A[o
ooooJ@000?m40?n000oooooo000=ooooo`0607Z=T`21UId0PiJT08FHZ023U:P0PY>X0P24UJT02`25
UjX0Q9J[08FH[028VZh0RY^_08bM[`2?X:h0TJ6^09:O[@2CWjh0U:2_0080UJ6a00/0UJ:`09JT/02G
YK00V:F_09VW[`2KZK00VjV_09j[/02NZ[00X:^b0:6]/`020:>_]P0<0::]]P2R[KT0Xjjk0:>^^P2S
[[L0Y;6h0:Fb^02V];P0Z;Jh0:Ze^02/]KT0[;Fj0P2]]K/02`2_]kd0[kNk0;6i_02d^[d0]KVl0;Fj
_@2f_<00^;k00;Vn_`2i_kl0^L2o0080^<2m00/0^;nk0;c2^`2k`;P0_<:g0;o6]`2maKD0_LBd0;k5
/P2la;40_LFb0;g3]0020;k4]@0;0;o7]`2oakP0_lNg0;k6/`30a[40`lN`0<?7[@33aZ/0`lN[0<?7
[@32ajl00P34b;803033b;80`lRa0<;8[P31aZ/0`lR/0<?8[@32ajh0_lF_0;g4[@2maJd0_LF[0;c5
ZP80^/>Y00/0^/>X0;W3YP2e`:<0Y:jE07n3M@1eNFX0HF=G059CB`1>CdD0A4Hl03/n=@0203<f;`0;
02/]:@0Y:BL08bDT02DW9P0[;b/0;S@]02le;00]<RX0;S0Y02h^:P0_<2d00P0_<Rl0300^<bd0;S<[
02le:`0a>Bd0;SH/02P^9`0S9R<07QlM01/M600N8AX07b@J01/Q5@805Q/A00/041<=00hA2@0=40P0
4A8;01DH4@0H71H05ATE00lC400?4`h04aP@01DJ400201<H300;01<F2`0B50/04189018D300D6100
61`E01LK5@0H6aH07R<I02`c8P0`=b000P0X;AH01P0[;1L0<S0O030]8@0Z9Ql0;2`V02PZ91[ooooo
J`000?m20?n000oooooo000=ooooo`0607Z=T`21UId0PiJT08FHZ023U:P0PY>X0P24UJT02`25UjX0
Q9J[08FH[028VZh0RY^_08bM[`2?X:h0TJ6^09:O[@2CWjh0U:2_0080UJ6a00/0UJ:`09JT/02GYK00
V:F_09VW[`2KZK00VjV_09j[/02NZ[00X:^b0:6]/`020:>_]P0<0::]]P2R[KT0Xjjk0:>^^P2S[[L0
Y;6h0:Fb^02V];P0Z;Jh0:Ze^02/]KT0[;Fj0P2]]K/02`2_]kd0[kNk0;6i_02d^[d0]KVl0;Fj_@2f
_<00^;k00;Vn_`2i_kl0^L2o0080^<2m00/0^;nk0;c2^`2k`;P0_<:g0;o6]`2maKD0_LBd0;k5/P2l
a;40_LFb0;g3]0020;k4]@0;0;o7]`2oakP0_lNg0;k6/`30a[40`lN`0<?7[@33aZ/0`lN[0<?7[@32
ajl00P34b;803033b;80`lRa0<;8[P31aZ/0`lR/0<?8[@32ajh0_lF_0;g4[@2maJd0_LF[0;c5ZP80
^/>Y00/0^/>X0;W3YP2e`:<0Y:jE07n3M@1eNFX0HF=G059CB`1>CdD0A4Hl03/n=@0203<f;`0;02/]
:@0Y:BL08bDT02DW9P0[;b/0;S@]02le;00]<RX0;S0Y02h^:P0_<2d00P0_<Rl0300^<bd0;S<[02le
:`0a>Bd0;SH/02P^9`0S9R<07QlM01/M600N8AX07b@J01/Q5@805Q/A00/041<=00hA2@0=40P04A8;
01DH4@0H71H05ATE00lC400?4`h04aP@01DJ400201<H300;01<F2`0B50/04189018D300D610061`E
01LK5@0H6aH07R<I02`c8P0`=b000P0X;AH01P0[;1L0<S0O030]8@0Z9Ql0;2`V02PZ91[oooooJ`00
0?m20?n000oooooo000=ooooo`0607b>T021TiP0PYFO08BEY022Tj@0QIFV0P27UZP02`27UjX0QIF[
08BE[025Ujd0R9V_08VL[P2=X:d0Sj6]08nO[@2@Wjd0TJ2`0080TZ2`00/0TZ2_09FS/P2IYK<0VZJe
09bW]P2JYkH0VZRd09fZ/P2OZk40XJ^b0:6//`020:6]]00<0::/]@2QZkH0XZbj0:>/^`2S[[/0Y;2l
0:Fa_02U/K/0Yk:l0:Zd_@2[];`0[;Bm0P2^]Kh02`2^]Kl0[kNo0;6h_`2c^kl0];bn0;Fm`02f_L40
][jo0;Fm_@2d_K`0]/2m0080][nm00/0][jl0;W1_@2h_kT0^Kjg0;c2]P2l`kH0_LFg0;o5]`2m`k@0
_/Be0;c2]@020;c3]@0;0;o6^030a[T0`<Ji0<77]`33bK<0`lR`0<?8[`34bJd0a<R/0<?7Z`33ajh0
0P34b;401@34b;80`lJb0<C7/032aZh0`lN_0080`lN`00D0`/Ja0<;6/P30aK40_lJ_0;o5[0020;k3
Z@0;0;g5Z02maZH0^/FV0;O2Y@2`^j00Z[BK09ZSS@20QWD0L7AU05MID01AE4X00P0n?ST02`0g=S<0
<S0a02`[;00Y:2T0:BXZ02`^;00]<2d0;C0[02h`:@0a<bX0:b`T00809bPQ0P0T9Ql02P0W:b80:c0V
02T^9@0X;BD09b`U02DY8`0T:B80;SLY02H_8`0L91T201DI4P0;010B3P0<3`X02`h9010C3P0E6A<0
61dG01LL5@0C61404QL?01HL4@0E6a000P0C5``02`0?4`X03Q4:00dB2P0<3`L02`l7010B2`0?40/0
5QTA01/N500P9AH09b/H00807Qh=00H0@4@Z024L4`0h=Bh0A4Ln02<T8@0Z<BPJooooofh0003o?`3o
P00?ooooo`003Oooool00`1hRhl0P9:I08:CX00208>EY00>08BEY026UZD0QYJU08JGY`24UJL0Q9NZ
08NJZ`29W:`0R9b/08VNZ`2:WJX0S9j[08fN[02?X:l208nO/00;092P/@2DX[<0UjFc09VU]@2HXk@0
V:>e09ZW]P2LZ[D0WJZc09j[/`2NZkD00P2N[;D01P2P[KD0XZjf0:B_^P2U/;/0Y:nk0:B`_@80YK6m
00@0Yk:m0:Vb_@2/];h0[KFn0P2_]kl01@2_][l0/;S10:jg_`2_^Kl0/[_00080/kc000@0];bn0;Fm
_P2d_K`0];bj0P2e_K/02`2d_K/0][nk0;O0^@2h`;P0^l:g0;g2^02n`k/0`<Fm0;o4_02m`[T0_/Bj
0080_L:i00/0_/>i0;o4^@2n`kP0_lFf0<;7]@32b;<0`<N_0<;9[P33bJ`0`lR/0<C7[`020<;6/00<
0<?7/@31aK40`lRb0<;6/P31a[80`<Fa0<;5/032a[40`lJd0<;5/`31a;00`<B^0P2oaJ`02`2ma:X0
_/JY0;c4Y`2k`jT0^L>Y0;G0Y`2c_jL0/KbU0:2ZUP2>UXD0OXAf0080Gf1H00D0DU1;04=1?P0k>3D0
>3@`03D`;P02034];00402dZ:@0Y9b@0:bXU02/[9@809bLQ00<092@O02<U7`0R9ah00P0P8a`01`0S
:2009BdT02<[8@0S;240;c/Y02Td8`0K8aL00P0D6Q401@0A5@h0418=010B2`0B5Ph05a/B00806AhD
00@061dB01LN4P0K8QD06AlC0P0H7Q802`0B5`l03A8<00dB3@0<40/01`/400P;10092P@02PT400/9
100>3@H051D;008051<:00H0;C4P01XI400f>Rh0G6YA01LJ4`0J7aHJooooog00003o?@3oP00?oooo
o`003Oooool01P1iS9<0PIFN08BGY023UZD0Q9NX08BFYP80PiFU00/0Q9FW08>FZ025V:T0QYVX08NL
Z@28W:X0RIf[08VLZP2:W:X0S9j/08jO[`02092N/@0409:P]02CX;@0UZ>d09NU]080V:Fe00D0VZNe
09^Y]02KZ[@0WJ^e09j[]@0209j[]P0<0:6]^02S/;T0Y;2i0:F`^@2T[kP0Y;2j0:>_^P2U/;X0Z;:l
0:Ra_02[/kd0[KK00P2/]Kh01`2/]K`0[;Jm0:bf_02^]kh0[kNn0:nh_@2a^Kh00P2c^Kd20;Bl_P80
]Kfm00/0];^l0;Jn_02h_k/0^Knj0;Zn^P2j_[T0^l2k0;c2^`2m`k`0_/Fm0;g5_0020;c2_0090;g2
^`2l`[X0_L>i0;g3]P2k`K40_L>`0;g4/@2naK40`<J^0080`LJ^0P30a:l03030aK40_lFb0<36/@31
a[40`LNb0<75/@31a[80`<Fb0<;6]033a[<0`<>_0;o2/080_l>a00L0_L>]0;c3Z`2k`jT0_<B/0;_6
[02g`ZP0]KnX0080][nX00l0]L2W0:bgX02MYI80WJFB08jGPP1_Lf40FE];05=B@P17@cP0@Sde040k
=00g<bd0<2dW02dZ9P0Y9B800P0T8Ah0300R8Ad092LQ02<X8@0P9Q`07R@I01dU6@0N9AX08BXL024Z
6P0O:AL08BXH01dT50806AlA00/05ad@01DJ3P0D6@h05aX@01LJ3`0I71806QhD01PN500I7aD072<H
01`S5`0201XR5`0;01@N4`0>5Pd03A@<00`B2`0:3`H020/400P9100820<01`L300L50`061`800P06
20401P072@003Q8501HJ2P0N91007R<?01PK2a[oooooM0000?li0?n000oooooo000=ooooo`0607fA
V022UYl0Q9RT08BGY`25UjX0QIRZ0P23UZP02`24UjT0Q9VX08JJZ026VJL0QYZW08RMZP2:Wj`0S:6]
08fP[@2?XZl0T:2`0080TZ2c00/0Tj6f09>Q]@2DX[@0UJ>c09VW]`2JYkP0VZRf09b[]P2M[;D0X:jf
0::_]P020::]]`060::]^02S[KT0Y[6j0:Rc^P2W/kX0Z;>l0P2W/[/0102Y];d0Z[Bm0:^f_P2Z];l2
0:Ze`@0:0:^f`02/][h0[KNo0;2h`02a^<00/KNo0;:i_`2d^L00]K_10;Fl`@<0/kg000/0];bo0;S0
`@2h_kl0^;fn0;Vo_@2i_k`0^/6k0;_2^`2j`[X0^L:j0;W1^P020;_1_@0;0;k4_P2m`kd0_<:m0;k3
_@2n`kT0_L>f0;g3]@2oaKL0_lJd0<38/`30b;400P2oak001P31b;80`LNb0<76/@32ak<0`lRd0<C8
]@80`<Fd00@0`/Jd0<;7]@30a;<0`<Fd0P2oa;<01P30aK00_lF`0;o7/02naZl0_LJ^0;c4[080^l:[
00<0^l6Z0;[2ZP2g_jX00P2g_j`02`2c_ZP0Yk6K096HQ@20QG<0IVII05MEB@1?C400AdHi03hm<P0g
=Rd0;B/U0080:2HQ00`09BDQ028S800Q920082HO01`S6P0I7aD05adC01/S5`0J8A<061h?01hT4`0O
9AH201lT5`0;01hS5`0L8aP06b8H01TO5P0F6a805a/A01XP500L8aD07bHG01hV5P0M9aH00P0K9AD0
2`0I8Q@05QlA01<M3P0A60/03aD700`A1@0=3`H030d400/;100:2PD01`T400801PT200H01PT100P<
000<40804QH6014C1@0;2P4JooooogH0003o=`3oP00?ooooo`003Oooool01P1iRiD0Oi:N08>FY@24
Uj/0PiF/08FI[P80QIV/00/0QIZZ08BHY`26VZT0RIb[08RLZP2:WZ/0S:2Z08nS[P2?XZh0SZ2_092P
/P02096R]00:09:S]@2CXk@0U:Fd09JV]02HYk@0VZVf09^Z]P2M[;H0WZfe0:2^]P<0Y;2i00`0Xjfi
0:B_^P2W/[/0Z;>j0:Rd^`2Y]Kd0Z[Fn0:^f_`2Z][l0ZkRo0:^i_`2Y][d20:Zf`00;0:ji``2^^L80
[[O00;2h`@2b^L40/kRo0;>i`02e^/40]kg30;Jla02e^l@00P2h_lD02`2h`L@0^/;20;W1_`2h_kl0
^;nn0;S0_@2j`kd0^lBm0;W2^P2j`kX0_<:k0080_/Fn00/0_/Bo0;o4`02oa<00`LG30;o4`02oaK`0
`/Rm0<77_030akT0`<Rh0<7:]P020<?:]00<0<C;]@34bkH0`/Ve0<78]@31akH0`LNh0<37^030akT0
`<Nh0<78^02oaKH0_lFe0P30a[D02`31a[<0`lRe0<;7]@30a[D0`LJe0<76/P31a[00`LJa0;o5[`2n
aJd0_LB^0080_LB`00/0^l:_0;W0[@2e_:X0[kRV0:6YU`25RWX0JFeN05aPD01@DTH0@d@m03Xj=@02
03Lh<P0<03@d;P0_;b/0:2TW02@U9@0P8b806b0N01TM6@0K81T06AlH01LM500J81D07RDI0P0P9QX0
2`0M91X07B<J01hU6`0N9QX072@G01dU5P0O9aD08BXE02</5`0Q:QD082TC00807RHB00L07BDD01`S
500K8Q806R4>01PN3@0H70d05AT<00804a@:00<04A8:00d?2@0;3`P00P0;3`P01@0<40P02`l700hB
200?40T030/501[oooooN@000?ld0?n000oooooo000=ooooo`0607N9U@1nT9h0PYBW08>D[021TZ`0
Q9F]0P22UZT02`23UZL0PiNU08JHYP29VZP0RYbY08VKZ02;WJP0Sj6]092Q[P2>WZh0SIf`0080SYja
00/0Sj6b096S/@2BY;00UJFa09JU/02HZ;<0V:Vd09VZ]02LZk@0Wjfe0:2/]`020::]^0030:6/]P2S
[KL0Y[2i0080Z;6j00L0ZK>k0:Rb_02Y/kd0ZKFo0:Zf_@2Y][/0ZKFj0080[;Jl00/0[[Nn0;2h_`2b
^L40/kW10;:i`@2c^<00]K[10;Ji`02g^/40]KS10;Ji`@020;Nm`@030;Rn`02i_l00^Knn0080^Knn
00H0^L2n0;[2_`2j`Kd0^/2j0;_1^@2l`KP20;g2^@060;g2^`2m`K/0_L6l0;o2_P2o`kd0`LBl0P30
a;X00`30a[T0_lFf0;o6/`020<77/P0<0<?6]033b;H0`/Nf0<36]`2oaKP0_/Bj0;o5^`2oakX0_lJh
0;o6]`30a[L0_lFe0P2oaK802`31a[40`lNb0<?6]031a;@0`LFd0<76/P31aK00`<F`0;k4[`2n`jh0
_<6^0080^l6`00/0^/6`0;Vo[`2h_Zh0][f^0;Jm[@2_]JL0XjZL092FR`1jOGH0HVAO05AEC`0204U:
@@0<03ho=@0d<bh0;2XY02DQ9@0P7B806aXO01dO8@0M8Al061`J014D4P0?4Q003a<@0P0A5A002`0@
5@h04QH?01@I400C6@h05A/A01@K3@0C6PX051/901HN2`0G7PX05Qd:00805Q`800/05Q`901HL2`0D
6PP04aP701HM2P0G70`05QT<01@E2`0C50`03a0:00`>2P0200T<2@0300T<2P0;3`/02`h:00802`d;
00<02PX7ooooooooool06?oooomk0000oc80oh003oooool000gooooo00H0MXVD07j@W@22Tj<0Q9BY
086BZP1nSjP207nBY`0;082DY@23UZ@0QIRU08NIYP27V:L0QYRX08NJZ02:W:T0S9bZ092N[@2>W:d0
0P2>WK002`2=W[40T:6b09>T/P2CXk00UJBa09JU]@2EYK@0V:Rd09f[]P2NZkH0WZVg0080WjRg00`0
X:Vf0:6[]P2R[KD0YJfg0:N^]`2W/;X0Yk6l0:J`_02X/[d0ZK>n0:Vd_P2[]Kh20:bd_@0;0:nf_@2a
]k`0/KNn0;:i`02b^<00/kW10;Bi`@2d^Kh0]kc10;Jj`P2d^L000P2c^Kh02`2d^[h0][bo0;Jm_@2f
_Kh0][fm0;Fl_02g_;h0^;bn0;Vm_02j_KX0^Kji0080^l2k00/0_<6l0;k2_@2n`Kh0_l2m0<31_@30
`[d0_l6k0<33_02o`kX0_/>h0<76]`030<75]0040<76]@2oaK@0_/Fe0;k4]P80_<:h00D0_/Fg0<76
^02oa;H0_lBf0;k4]0020;g3/@0;0;o5/031aJl0`<:_0;o2/030aK80_l>a0;o3/02n`[40^l6`0;_0
/02j_jl00P2h_Jd02`2i_Jh0^Kj_0;Vn/P2h_;40][^^0;Fi[02c]jX0/KNZ0:R_X`2OYiT0Ti^;0080
QHik00`0F5Y>03di>00g<SD0:b<]02<K:00M62@07Q/T01hL900K72005AHK010B5`0>4A<200`?3P0;
00X=2@0>4PX041@;00`B2@0<4`T02a8700hF200C70T04a`701<K100A60400P0D70<02`0H7`H05AX6
01<E100?4@804184014B1P0@4@P0410;00lA3@0>40d02P`:00801`T600H020X700d@300;3P`02P`;
00`>300<30TJooooogl0003o;P3oP00?ooooo`003Oooool01P1dRY40NXnH07nBW`21TZ@0P96W07j?
Z080OY6Y00@0OY6V086EY@23UZH0QINZ0P27VJ`01@27VZ/0RIZZ08ZJZ@2<W:/0SIb]0080Sij_00@0
SYna08jO/`2AXKD0TJ6c0P2DXK<01@2EXk@0V:Fe09^Y]`2NZ[L0WZVf0080WjRg00`0X:Vh0:2Y]P2Q
Z[@0Xj^c0:J^]P2X/;X0Z;6l0:Ra_@2Z//00Z[?20:Va`@2Z//420:bb`P030:ne`P2_]L00/KNo0080
/[S100H0/kS20;:h`@2c^<00][[20;Nka02d^/<20;>h`00;0;:h`02b]kl0];Vo0;Bj`02e_<40];^o
0;Fj_P2f^kl0^Kk10;Rm_P2h_;`00P2i_;`01@2l_[`0_Knn0;no`02n_L00_kjo0080`;o000@0`<30
0<31_`2n`;d0_/6m0P30`kd02030aKd0_lFl0;g2^P2m`[X0_<:g0;k3]`2m`;D0_/:e0P32aKL02P30
`kD0_l:d0;k3/`2n`k<0_/>b0<;5/`32a;@0`<>e0;o3]P2m`KH20;_1]@030;Zo]02j`;@0^/2b0080
^Kja00/0^;f`0;Vm/@2j_k<0]kfb0;Nl/@2f^k00/kR^0;:i[`2b^K00[kN]0:feZP020:RcY@0<09ZR
U`1XIV`0DdmJ03P`@P0X83809Ql/024K9@0M5al05a<J01LC6@0D51P04A@F0P0@4a802`0A51403a@?
00lC3P0=4Pd02@h900H<1P0:4@P04a`<018L200B70H04Q/300804Q`300<051`501@J1@0B5PD00P0B
50L01P0A4@H03`l8014A2P0B4P`0418;00`>20802Pd600H02P`600dA2`0=40`030h<00h?3P0?3`dJ
oooooh40003o;03oP00?ooooo`003Oooool01P1fS9<0O9:J07nDW`21U:80Oi6S07nAY080OY2U00/0
PI>X08>EZ@22U:P0QIF[08VI[`2:VK00Ri^`08ZJ[@2:V:`0S9Z^08nL[`02092M[`0;09:O/P2CXK@0
UJ:e09FS]@2DX[<0U::b09FS/`2GY;@0VZNf09bY]`2MZ;P00P2NYkT0302PY[X0XZRi0:BY^@2SZ;L0
Yjbi0:^`_P2[/L00Z[700:^b`02]]<40[;?10:fca080[kG600@0[kC40:jc`P2a]L40/kO20P2c]/40
1@2c]l40];S10;Fg`02f^/80]K[20080/kW100/0];[20;Fi`P2e^L40][_30;Rna@2g_<@0][[20;Jj
`02h_L00^[k00;^o_`020;^n_@0;0;^o^`2l_[`0_l2n0;nn_P2n_[l0_[bn0<2o`030_/40`;k00<2o
_`2n_kl00P2o`;l02@2o`L00_l:o0;c1_02l`K/0_<6i0;g0]P2o`;H0`<6f0<72]@020<73]@0=0<74
]@31a;<0`LBc0<33/P32`k<0`<:a0;o0/P2o`;H0_Knh0;Zn]`2k`KT0^l2g0;Zo]@030;Zo/@0;0;Vn
/02h_Zh0^;j/0;Vn[P2h_Zl0^;f^0;Jj[P2c^:d0];V`0;:h[P2_]Z/00P2^]J/0302]]Zd0XZZT09RQ
VP1QHVP0<bhk03/f>`0a:B/09ahR028I7@0N61X06ADH01PG608061PI00/05aPG018C4`0B51@0418B
00`<3@0;2`/03A0=018G3`0D6Ph051/=018K2`0200lH1`0;010H1P0D70P04aX901DJ300E6@d05AL<
018C2P0B4PX04A4:018C2`0@4PT00P0=40H01P0<3`D03@l700l@2`0@40d03a0>00l@3A[oooooPP00
0?l[0?n000oooooo000=ooooo`0607B7T`1mTId0OY6P082DY@1nTJ@0OHnQ0P1nT:<02`20TZH0PI>X
08:CZ@24U:`0QiJ_08NE[`2:V:l0RiZa08^K/02=V[00SiZa0080TIbb00/0TYjc09FQ]@2FXKD0UJ6e
09FR]02HYKH0V:Bd09ZV]@2IYK@0VJBd09^V]`0209fV^@0<09nV^P2RYk/0YJRl0:JY_@2WZ[h0Z:^n
0:V]`02[[l80[;720:fd`@2]]<80[[C30P2_]<@02`2^]<@0[kG30:jd`@2`]L40/KJo0;:f_`2c]kl0
/[Fo0;:f_P2d^<00];W00080/[S000@0];W10;Jj`@2g^L40]kW10P2h^l401@2g^/00]kW00;Nj_P2h
_;h0^[jm0080^[jj00/0^[ni0;c0^P2l`;T0_Kni0;bn^@2i^KH0_[jj0;jo^`2n_[/0_Kfk0;jo_@02
0;k0_P0<0;fo_P2l_kd0_<2k0;^o^@2k`;L0_<2d0;k1]@2o`;@0`<2f0<31]`2n`KH0_L:d0P2o`[<0
1`2o`[40_l6_0;fo[@2l_Zh0_Kja0;bn]@2j_kL00P2i`;L03`2j`KD0^/2c0;Vn/@2i_[40^;b_0;Nl
[@2h_J`0^;n/0;VoZ`2i_Z/0]kf]0;Nl[`2f^Zh0];Z/0;>gZP020;:g[00<0:ne[02]]J/0ZkBX0:2Z
W@1lP7H0K6eR03<Y:`0a9bP0;24S02DM7P0O5aT071HG0P0K5aL02`0K5aH061@D01D@4P0D41804`lA
00d;300>3Pd051HA01LM4`0G7A405ahA00805Qd>00/05ah=01HM300C6@/051X=01@I3P0C60`04QD<
00lB2`0?4@`04A@=018E2`0200lC1`0600/>0`0;2`8030`400d=1@0<3@H03Q086_oooon50000obP0
oh003oooool000gooooo00H0MHJC07Z<W01mSj80OHnU07b=Y01kS:8207f?Y@0;07nAY`20TZP0PI:Z
08BD[026UJd0QiF_08ZI/@29V:l0RiZb08jL]02?WK@00`2@WK@02P2BWkH0U:6g09FQ^@2DX;L0UZ6g
09NS]P2HY;H0Uj>c09VU]@2JYkL209fX^P0<09jW_02QZKd0XjRm0:F[_`2UZKl0YJW00:FZ`02VZl00
Z:g00:V_`@2Z//80Zk;20P2/]<@02`2]]<@0[[G30:be`@2^]l40/;W30;2i`@2`^<00/KS00;6g_`2b
^Kh0/[Vm0080/[Vo00/0/kW10;Bj`P2e^<40][W20;Rj``2g^L80^;[10;Rj`02g^[l0]kbn0;Ro_P02
0;S0^`0;0;Nn^02h_[T0^;jh0;Vo]`2i_kP0^[jj0;^o^`2j`;`0^l2m0;^n^P2k_kX00P2k`Kh0302l
`L40^l6o0;[1_02i_kT0^Knh0;_1^@2l`[T0_L2i0;o0^P2o`;`0_;jj0;^o^P80^l2h00/0_L:f0;k1
]02m`;@0_<6d0;^o]@2l`;T0_<:k0;W0^`2h`;T0]l2g0;Jn]P020;Nl]@0;0;Nk]02f^K80][Za0;Jj
[`2g_:l0][^^0;Fi[`2d^k40];Za0;:i[`2b]jh00P2a]Zl0302_]K00[KB^0:^bZ`2Z]:P0ZK>T0:2Y
V@1CCDd0>2la03<[;00^9BH09ahO02DM7P808QXM00/07QLJ01XE5`0I4aH05a@I01HC5@0@3`l030d;
00lB2`0C60d05adA01XQ4`0201`S4`0;01/Q4@0G7@d051X=01@J3`0B60h04AH<010D300=4@X03a@<
014E3`0?50X00P0?4`P01P0>4@H03Q0500h@1@0>3`@03Q0400lA1A[oooooQ@000?lX0?n000oooooo
000=ooooo`0307R9UP1lSYh0OY6V0080OHnX00h0NhbW07j@Y`1nT:L0P9:W082BYP20TJL0Q9B[08JD
[027UJ`0RYV_08RG[@29V:d0S9Z`08jM/`80Sijd00/0SYjd08nN]02AX;H0TZ2g09:O]`2CX;P0Ting
09BP]P2EX[D0VJFf09ZV]`0209RS^00609NS]`2LY[X0X:Vk0:6Y^`2SZ[d0Y:Vo0P2TZ/00102U[<00
YZg00:J_`02X/<820:^c``0;0:Zb``2[//80Z[?10:be`@2^]l<0/;S20:nh_P2a^;d0/[Rn0;:i_`2a
^;d00`2`^;h20;6i`@080;:i`P2d^/<0/kW30;Bi`@2f^/80]K[20;>i_`2e_;l20;Fm_@030;Fl^`2e
^kX0][fl0080][jm00H0][bk0;Nm^`2h_K`0^Knm0;Vn_02j_[d20;Vn_@0:0;Zo`02j_l40^;nn0;S0
_02g_kX0^;nj0;Rm^@2i_KX0_;fm0;^l_P80^[fo0P2i_Kd0102i_KX0^Kfh0;Rl]`2i_;L20;Vm^P05
0;Ro_02i_kh0^/2m0;Ro^P2f_KP00P2g^kH02`2h_;H0]kbe0;Jm]P2e_;<0]Kfc0;Bl/P2c^k80/kbc
0;:k/`2a^K<0/KRb0080[[F`00`0Zk>_0:Zb[P2X/J`0Z;:[0:J`Z@2W/ZP0SiF>06ETI@0l=C/0>S8c
03D^;`0_:2`202LP:00;020K900U8RT0:2H[01XI8P0E5Qd03a4C00/=3@0;3@/03Q8<01@H4@0H7QH0
0P0K8AL02`0K81H05a/A01HJ4@0F6Q@041D@00hB3@0?4`d041@=014F3`0B5Pl03a<;00803A480P0=
40T0100>4PT03Q8800`>1007204JooooohH0003o9`3oP00?ooooo`003Oooool01P1fQYT0NX^P07b=
Y`1mSZX0OHf[07^:ZP80O8fX00/0OXnX07j?Y`21T:L0Q9:Y08ZG[P2:Ujl0RIN^08^J[`2=Vjl0SYb_
08jK/00208jL/`0:092O]P2?WkD0Sj2d09:Q]P2DX[P0U:6i09>O^02CW[L0UJ2e09RS]`<0VZFi00`0
V:Bi09^V^`2MYkX0X:Ni0:6X^`2RYkh0YZ_20:B/a02SZl80Xjc00:>/_P2U[[h20:N__`0;0:R``02Y
//00ZKC10:^f`@2/];h0[KBn0;2f_P2b]kl0/[Jl0;:e_@2b][h00P2a]l002`2`]l80/;S30;2i`P2a
]l80/[S30;2g``2`]/40/KS00;Bi`P2c^/<0];[20080];_000/0];bo0;Fl`02f_/40][k20;Fl`02f
_;d0]kbk0;Rk^@2i_;T0^Kfk0;Vl^`020;Zl^P0<0;^l_02j_[h0^Kk00;Nn_`2f_[`0][jj0;Nm^`2i
_K`0^Kbm0;Vm_P2j_Kd0^Kfm0P2h^kd02`2h^k/0^[fl0;Rk^@2h_;L0^[fi0;Vl^P2g^kX0][Zk0;Nk
^`2h_;X0]k^g0080]k^d00H0]k^c0;Bk/@2b^k00/[^a0;>l/`2b_;@20;6k/@030;2h[`2`^;40/KVc
0080/KVa00`0[[N_0:fd[02Z/J`0ZK:]0:Rb[@2W/J`0Y[2Y09^UW@1_LW40D4eA04e;C@18ADT203Da
>P0;02PU;`0Z:c40:bdb01hP9`0K7R@061/L01<F500@51004A@?01@G4@0G6aD00P0M7aT02`0L7AT0
6ATD01TI4`0J7AP05QTF01DH4`0D5a8051P?01@I400E6A404QD@00803Q4<00H030l;00lB3`0A5A00
3A4<00P;1P041@4JooooohP0003o9@3oP00?ooooo`003Oooool01P1fQYT0NX^P07b=Y`1mSZX0OHf[
07^:ZP80O8fX00/0OXnX07j?Y`21T:L0Q9:Y08ZG[P2:Ujl0RIN^08^J[`2=Vjl0SYb_08jK/00208jL
/`0:092O]P2?WkD0Sj2d09:Q]P2DX[P0U:6i09>O^02CW[L0UJ2e09RS]`<0VZFi00`0V:Bi09^V^`2M
YkX0X:Ni0:6X^`2RYkh0YZ_20:B/a02SZl80Xjc00:>/_P2U[[h20:N__`0;0:R``02Y//00ZKC10:^f
`@2/];h0[KBn0;2f_P2b]kl0/[Jl0;:e_@2b][h00P2a]l002`2`]l80/;S30;2i`P2a]l80/[S30;2g
``2`]/40/KS00;Bi`P2c^/<0];[20080];_000/0];bo0;Fl`02f_/40][k20;Fl`02f_;d0]kbk0;Rk
^@2i_;T0^Kfk0;Vl^`020;Zl^P0<0;^l_02j_[h0^Kk00;Nn_`2f_[`0][jj0;Nm^`2i_K`0^Kbm0;Vm
_P2j_Kd0^Kfm0P2h^kd02`2h^k/0^[fl0;Rk^@2h_;L0^[fi0;Vl^P2g^kX0][Zk0;Nk^`2h_;X0]k^g
0080]k^d00H0]k^c0;Bk/@2b^k00/[^a0;>l/`2b_;@20;6k/@030;2h[`2`^;40/KVc0080/KVa00`0
[[N_0:fd[02Z/J`0ZK:]0:Rb[@2W/J`0Y[2Y09^UW@1_LW40D4eA04e;C@18ADT203Da>P0;02PU;`0Z
:c40:bdb01hP9`0K7R@061/L01<F500@51004A@?01@G4@0G6aD00P0M7aT02`0L7AT06ATD01TI4`0J
7AP05QTF01DH4`0D5a8051P?01@I400E6A404QD@00803Q4<00H030l;00lB3`0A5A003A4<00P;1P04
1@4JooooohP0003o9@3oP00?ooooo`003Oooool01P1bPYT0MhNQ07b<Z01lS:/0OHb[07f=Z`80OHjX
00/0O8fT07f>X`20T:80Pi6S08NEZ@29UZ`0QYBX08NFY`2;Vj/0SY^]08bI[`0208bI/P0;08fL]@2>
WK@0Sijb096N/`2CWk@0UJ2f09FO]`2EWkH0Uj6e09VS]02HXKD00P2IXkL0202MYk`0WZRl09fW^@2P
Z;X0XJNi0::X^`2TZ[l0Xj_10P2RZl403`2R[;h0YJjn0:J__`2V[kl0Z;700:R`_P2Y/[d0[;Bn0:fe
_P2_][l0/;Jo0;6d_P2a/k`0/[>m0;Be_`020;:f`00;0;6g`02b]l40/kW20;Bh``2e]l@0/kO40;2h
a@2_]/40/;O00;6g`02b^l<00P2b^L402@2b^L00/k_00;Bk_`2d^kl0];Rl0;Fh^P2g^[P0^KZh0;Zk
^@020;Zj^`80^k^k00`0^[Zj0;Vj_02i_;l0][Zl0;Bi^02d^kP0][bk0;Jk_02g^kh0^;fo0;Rl_@2i
_Kd20;Rj^`0;0;Ni^@2h^kT0^;Zg0;Rk]`2h^kH0^;Zf0;Ri]`2h^KP0^;Zi0;Jh]P2f^KD00P2e^;<0
102d^K<0/[Vb0;2h/02a^;020;6i/@050;6j[`2a^Jh0/;R]0:ng[02`]Zd00P2`][00302^]K00[KF]
0:Za[02Y/:d0Yk2/0:J_ZP2V/:X0Yk6Z0:2YY02<T9@0RHjB08>;S080EeeR00/0<3<k02DZ;P0R9RX0
7b4V01dO8P0M81`092PL01dP500J6a405aP?01PH4P0201XH500;01`J5P0M6QL07A`I01hO700K7AX0
6Q`H01TK5`0E61<05APA01LL500C5a400P0A51001P0=3`h03A4@00lC4@0=40d01`T600420A[ooooo
R`000?lR0?n000oooooo000=ooooo`0607>4U`1hRJ00NX^V07Z:Z01kRjX0O8fZ0P1lSJP02`1lSZH0
OXjU07j?X`21TZ<0Q9FT08FEYP26UJL0QIBV08RFZ@29V:`0R9J^0080RYRa00/0S9Za08fM/@2>W[40
TInb09>N/P2EWk@0V:6g09ZT^02IXkH0VZ:e09ZR]`0209VQ^00809ZU^`2KYkX0VjJi09jV^P2QZKX0
XZVl0:6X_P2PZ;l20:6Y`00?0:>[`02T[;l0YJk00:F^`02W/<00Y[2m0:Na_@2Z/[h0[;Bn0:fe_`2_
]Kh0/KJo0;6e_P2b][l0/KFn0080/KJo00X0/[Fo0;:f_`2b]/00]KO20;Jh`P2c]l80/[S30:ng`@2_
]l00[kK00`2`^L001`2b^/00/[Zn0;>j_@2d_;h0]K^o0;Ji_@2f^K/00P2h^[d0402f^;d0]kNm0;Vi
_@2i^Kd0^KVl0;Rj^`2f^k`0][^k0;Bi^P2c^K/0/kZl0;Bk_@2e^[d0]KZn0;Nk_P2g^kd20;Jk^`0;
0;Fi^`2c^;X0];Rh0;Fj^02g^kT0^;^h0;Rj^02h^;L0^;Vh0;Ff]@2e][@00P2d]K@02`2d^;H0/[Zf
0;2g]02`^;80[kVb0:jh/@2_^;40[[N_0:nf[P2^]:d0[kJa0080[[Bd00`0[K>d0:^c/P2Z/[00ZK6`
0:N`[`2U[Zh0YJj/0:B/Z`2SZj/0Y:b^0:6[[P2MZZ/2096SX00;04aDG@0V:SL0:Bhf02<X;P0O8bH0
7R<N02<W6`0U:1/092LI020R5P0L7AL00P0K5aH02`0L61H07ahJ01lP700O8A`07B4M01dQ6`0J7QX0
5a`H01LL5P0I7QL05Q/D00804aPA00H03a8>00X=2`0:3@T020X700@50`010P4Jooooohd0003o803o
P00?ooooo`003Oooool01P1dQiH0N8bO07^<YP1jRjL0NhbX07^<Y`80O8fV00/0OHfW07n>Z021TZT0
PYBX08>EY`24UJH0QIBW08NEZ@28UZ/0QiJY08RFZ`0208ZH[@0;08bJ[`2=W;00SIb_08jL/02AWK80
Tine09NR]`2GXKH0Uj6g09RR^02KY;X00P2GXKX0302HXkX0VJBj09ZU^@2LYkP0WZRi0:2Y^`2NY[/0
X:Rl0:6Y_`2TZl40YJ_20:B[`@80Yjk300/0ZK340:V```2Y/L80ZK710:Za`02//l80[KC10:nd`02`
]Kl0[kJo0:je_@020:jf_@0;0;2f_@2a]Kd0/KJn0;>g_`2b][h0/KJl0;2e_02`][`0[[Fl0:ff_P2^
]kl00`2_^;l01P2`]kd0/[Zl0;:k_@2d^kh0]K^o0;Bi_@80];Vn0100/[Nn0;>f_@2e]kh0]KNn0;Ji
_P2f^[h0];Zn0;Bk_@2d^[d0];Vn0;Bh_02e^Kd0]kZm0;Ji_02e^Kd0]KVl0P2b^;X02`2a^;P0/KRg
0;:i^@2e^kX0]kfk0;Rm_02h^k`0]kZj0;Ni^@2e]kL0/kFe0080/[Ff00/0/[Jg0;2g^@2`^;P0[kRf
0:ni]P2^^;@0[[Jc0:je/`2_]K@0[[Bb0:je/P020:bc/`0<0:bc]02Y/K80Yjna0:J`/@2U[k80Y:na
0:B^[P2S[:`0XJZ[0:>/[02P[:X0WJZZ0P2KZZT02`27UYL0JG=i04Y@FP0i?DT0;Blm02/^>018Cdd0
FFAH03Di=P0/;Rd08B4S00806QHK00/061<H01`K6P0N7aX07b8K01`R6P0J81T061hH01HK5`0G6aH0
5a`D01HK4P02018F3`0600/>2P082@L020P600H510040P4010406_oooon?0000oah0oh003oooool0
00gooooo00H0MHVG07Z?X01lSjH0OHnY07b<Y`1kRjH207j=YP0;08:?Z@23T:/0PY2[08:C[021TJT0
PY:W08BBZ026U:`0QiJ^08RH/028VK000P27V:l02`2:V[00S9bb08bJ/P2=Vk@0SYfe08nM]02BWkD0
U:6f09FR^02FX[X0Uj>k0080UZ:k00`0V:Bk09RT^@2HY;P0VjNh09jX^@2OZKX0WjRi09nX^P2QZ[h0
XJ[20:>Za02TZlD20:B[``080:F]`P2W[l<0Yjk20:V```2Y/L@0ZK730:Zc``2//l<20:je``0<0:ff
_`2]][`0[KJl0:jf^`2_][/0[kJm0;6g_P2`][h0[kJk0:jc^`2_/k`0/;Fn0P2_][l30;2f`00:0;2f
_`2a^;l0/;Rn0:ng^`2`^;`0[kNl0:nf_02_]k`0[kRm0;6i_P80];Zo00`0];W00;Fj`P2c^L00/[Vo
0;Bi_P2e^;d0];Nl0;Bg^`2d^;X0];Zk0;Bi_02e^[`20;:h^P0;0;6g^02b^;L0];Zh0;Bj^P2e^K`0
][Zl0;Bi_02c^K/0]KVj0;Fh^P2c]kT00P2c]k/02`2a]KX0[kBi0:nd^@2^]KP0[;Fg0:jf]`2_^;P0
[kFg0:ne]P2^]KD0Zk>c0080ZK6a00T0Z;6_0:N`/02W/;40YJn`0:J`/P2W/[80Y[6a0:B_[`2PZj`0
0P2PZj/03P2O[Jd0W:^[09b[Z`2KZ:P0VJJU08NBU@1fOXH0GV5a05MIJ`24Si40RYNC06]dM@1XLfh0
=SLj0P0E3QX02`0H4ad0518H018@4`0D4a805AHB01@E4P0C5Q<04a@@01@E400D5Ph04QD:00803Pl7
00H01`L300T71@0<2`L02PP600L50`0710<Joooooi40003o0P3oP0040000oaH0oh003oooool000go
oooo00H0LH2E07V:X@1kS:H0O8fX07^<Z01jRZL207j<Z00;082=Z@21SJ/0PXjZ08:?Z`21SZT0PHjX
08>@ZP24TZh0Q9>`08FF/P26Uk<00P27V;002`2:V[00S9bc08^I/`2=V[H0SYZe08nK]@2@W;D0TYfe
09FP^@2FXK`0UZ6m0080V:>m00`0VJBm09VT^`2IXkT0VZBj09fV^P2OYk/0X:Rm0:6X_`2RZ/40WjS2
0:2Xa02QZl@20:6[``0;0::[`@2U[L80YJk30:N_a02W[/@0YZk30:Vaa02[//@0[KC40:bd`@2]]/00
0P2]][h0202/]K/0[[Jm0:bd_@2]]Kh0[;Bm0:fc_@2_];d0/;Fo0P2`]L003P2`]Kl0/KJn0;6f_P2a
]Kd0/[Fm0;>g_P2a]Kd0[kJl0:ng_02`^;h0/;Nm0;2g^`2_^;/0/KRk0P2c^[d0302c^Kd0];Vo0;>h
_`2b]kl0/kNo0;>e_02c];`0/kFk0;>g^P2d^KX0]KVj0;Fh^P80];Nj00/0];Vl0;Fl^P2e^[P0]KZj
0;Fi_02c]k/0/kNl0;>g^`2d]kX0/kJj0;>d^P020;Bf_00;0;6e^P2`];/0[kBk0:fd^@2/]KL0[[Je
0;2h]02`]k<0/;Ja0:jd/@2//k400`2X/Jl00`2X/K40Z;6d0:N_/`020:R`]0060:F_/P2T[K40XZZ_
0:2Y[@2PZjl0Wj^_0P2NZZh209^VZ`0909ZTZ`2JY:X0U9bS08nHWP2AVYh0TYfM096MV`2BX9T0L7Ud
0080924]00/07ATV01PD7`0E4aX03``B01<A4`0M71X06ALF01HF4@0D5@`05AD<018B2`0200h=2@06
00X91P0:2PH03@d800`<1P071@4020D16_oooonH0000oaD0oh003oooool000gooooo00H0KGZA07V8
X01kRZL0NhZY07^:ZP1jRZP207b;Y`0;07n<Y`20SJL0PXjX086=Y`21SJP0PXnY08B@ZP24TJ/0QI:/
08JE/024UZl00P23UJ`02`25Ujd0R9V_08^J/02<VK00SYR`08nI/P2@V[@0T9^f09:M^02CW[X0UZ2l
0080Uj6m00P0VJ>m09ZU_02IXkX0W:Fi09bT]`2OYk/0X:Jm09nU_@80XZ[100l0XJW20::[``2R[<<0
XZc30:>/`@2RZkh0Y:^n0:J]`02X[/40Z:k00:V``02Y/[l0Z[:m0:Zb^`2[/k`00`2Z/k`02P2/];d0
Zk:m0:^a_02//kd0[[>n0:ne_`2`]L40[k?20:nc`@2_]L420:nd_`050:nd_@2`];d0/[Jn0;:d^`2`
/k/00P2a][h0102b][d0/;Jl0:nd^P2b][`20;6f_00<0;:h_02a]kX0/KJk0:ne^`2_];/0/;Bk0;:d
_02c]K`0];Fj0;Bf^P2a]KP0/[Ni0P2b]kX02`2b^K/0/kVk0;>j^`2d^K`0/kJk0;>e^`2b];/0/[Fl
0;2d^P2a]K/0/KBk0080/KFl00/0[k>j0:nd^@2_]KP0[[Ff0:fe]@2/]K<0[;F_0:bd[@2[/j`0[KB_
0:fc/@020:Zb/P0<0:N`/@2V[k00Yjna0:N_/P2V[K<0YJ^c0:J[/P2W[;80YJ^a0::Y/02QZK40WjRa
0P2NZ:l02`2JY:`0W:F/09bSZ`2MY:`0VZ>Z09RRZ02GX:H0Uj2U09JNY02AVih0S9RF0080JG=c00/0
CeAF03@f>P0R82L06QLO01TE6`0/;2/0:2HV028R800G61@05A@@01DD4P0201@D5006010@4P0=3a00
30h=00`?2P082@@01PD06_oooonJ0000oa<0oh003oooool000gooooo00H0LH2A07R7W@1lRjD0OXbY
07b:ZP1iR:L207^;YP0;07j>Y021T:@0PHjS07n=X`1nSJD0OXfW082@Z@21TJX0Pi>[08FD[@23Tjd0
0P23TZ`02`24U:`0Q9:Z08NEZ`2;Uj`0S9N[08jH[P2>V;00SYZc092K/`2BWKD0UYnh0080Uinh00`0
Uj2h09NQ]P2HX[@0VjFd09^T]@2MYKL0WJBi09fT^`2NY[`0WjJm09jV_@2QZKl20:6Z_`0;0::Z_P2Q
ZK/0Y:Zj0:J/^P2W[K`0Yjfm0:F/^`2W[[X0Z:nh0:Za^@2Z/;T00P2Y/;/02`2X[kX0Z:nl0:Z`^`2Z
[kX0[;:l0:fc_@2]/[h0[K6n0:b__P2[[kh0[K2n0080[K6n00<0[K:m0:jb_02]/[/00P2_/k/20:jb
^`040:nc^P2`];X0[[:j0:nc^`80/;Fl00P0/;Jk0:nd^P2^/kX0[[>k0:jc^P2_/kX0/KBk0;6b^@80
/[>i0P2a];T20;2d^00;0;2e^@2_]KT0[k>j0:nc^P2^/k/0[k>j0:nd^@2_/kT0Zk6g0:bb]`2[/;H0
0P2[/KL02`2[/;L0[;6i0:Za]P2Y/K@0Z[6c0:^c/P2[/jl0ZkB]0:Zb[@2Z/Jh0Z[6_0080Z;6a00L0
Y[2`0:B^/02T[:h0YJb`0:J[/P2VZ;<0YJNb0080Y:N_00<0Y:Ra0::W/P2OYK800P2MYK002`2LYJd0
VZ>[09ZQZP2IX:P0UinW09JNY`2FWJH0UIfU09BLY02AVZ80SiVO0080RiNI00/0R9FB07Z5P@1DEe`0
@49:03Xk@P0g=cd0>cdo02TY<@0U9Rd092DZ02@W:00201PH700601@D6P0<3Q@020T>00L820041P<0
10D16_oooonL0000oa40oh003oooool000gooooo00H0L82=07N7V01iRZ00Nh^U07^;YP1jRZ@207V:
X@0907b;X01mRj00OX^Q07f:X@1kRj<0Nh^T07f>YP1oT:P0P96Y0080Pi:/0P25TZ`02`26U:`0QI>Z
08NDZ`2;Ujd0SIN^08fG[`2;UJh0S9F^08fG[`2@V[80U9fd0080UYfd00`0Uije09NO]02FW[80V::c
09RS]02HXKD0V:6f09ZS^@2LYKX0WJJi09bW^@2NZ;`209fW_00;0:2X_@2RZ[d0XjZk0:F/^`2V[;`0
YJ^j0:>Z^02V[;T0Yjfg0:R_^02Y[kP00P2X[[T02`2W[[X0YZfk0:N]^`2X[[X0ZJnk0:R^^P2X[K/0
ZJjm0:V]^`2Y[[`0Zk2m0080[;2l00/0[:nl0:b`_@2[/;/0Zk2k0:^`^P2Z[[P0ZZnh0:fa^@2]/;P0
[K6g0:ba]`020:jc^0040:nc^P2^/[X0[[6j0:b`^080[[6i00H0[k>j0:f`^02][[L0[[2h0;2a^P2`
/KP20:fa]P090:fc]`2^];T0[kBk0:fa^`2[/;/0[K:l0:Za^02Z/KH0ZK2d0080Z[6f0P2Y/;L02`2Y
[kP0Zk2h0:Z_]P2Z[kD0Zk6e0:Z`]02Y/;<0ZZna0:V^/02W[Zh0YJb/0080Y:b]00`0YZn_0:B][@2R
Zjd0XjZ_0::X[`2SZ:l0Y:N_0:6T[@2QYJd0X:F^09jT[P2LXZ`209bSZ`0;09^SZ@2FX:L0UinX09JN
YP2GWZH0UYbU09FLX`2CVj00T9RN08nHWP2?V9d00P2;UIX02`2;U9P0RiFG08B>T01jQ8P0Lgj106M`
MP1KI6X0@49A04aBGP1JIFT0BU9D00805QDR00H05aLP00X;50041@d00P<600420@020P4Joooooj00
003o3@3oP00?ooooo`003Oooool01P1[O8H0M8JC07V:WP1kS:<0NHZT07Z:Y080NHZS00/0NHZQ07Z:
X@1lS:<0OHbU07b<YP1kRjH0O8bU07j@YP1oT:P0PY6Y08>B[00208>C[00;08>DZ`25U:/0QYBZ08ZF
[@2;UZh0S9N_08ZE/02;U[40RiNa08bH/P2@W;@00P2BW;@0102CW;D0UIfe096K]02AWK@209:N]006
09BO]@2FXKP0Uj>i09VV^P2JYkX0VjNj0P2KYK`02`2KYKd0WJNn0:2Y_@2QZK/0Y:Zl0:J[_@2TZ[`0
Y:Zk0:B[^P2TZ[T0YJ^k0080YJfm00T0YJfn0:F]_@2T[;`0YJfk0:J^_02U[K`0YJ^l0:N]_P2W[[h0
0P2X[kl20:R`_@070:R^_@2X[K`0Z:bj0:R]^`2X[[T0ZJfh0:Z^^@020:b`^`0@0:ba^`2[/;X0Zk6k
0:^a^`2//K`0[;:k0:^_^@2[/;P0Z[6h0:Z`]`2[/KL0Zk2j0:Z^^`2[[k/0[;2k0:b_^P80ZJjh00/0
Z:jh0:V`^P2//[`0[;6l0:^`_02//[d0Z:ni0:N_]`2Y/KL0Z[:i0:Zb^`020:V`^`0;0:R_^P2X[[P0
Yjjf0:N]]02X[K@0ZJje0:Z`]`2X[[@0ZJjc0:N]]02UZk<00P2RZK40302TZk40Y:^_0:>Z[`2RZ:l0
XJN_0:6W/@2PYk40WjJ`09nW/02MY;00VJ6]09RQZP80V:2Z00/0V::Y09JQZ@2FXJT0UJ2Y09FPZ02E
WJL0Ti^T09>LY02AVj80TI^O092JW@0208jHV`0;08jGVP2<UIX0RI>I08J@U@23SY80PHfA07b9S`1i
QH`0NHJ?07Z7T01bP8L00P13BUT01P0oBU006b4/00L;5`062Q000`D700820a[oooooY@000?l80?n0
00oooooo000=ooooo`0606]kP`1bPi00MhVJ07Z;W`1iRZ<0N8VT0P1hRJH02`1gR:D0N8VV07V:Y@1j
Rj@0NXZT07Z;YP1kRjD0OHnV07j?YP21TJH0Q9>X0080Q9>Y00/0PY>Z08:DZP24UJ/0QiF/08VE[@27
Tjh0QY>`08ND/@28UK<0RIJb08^I/P0208fI/`0<08jI]P2?V[L0SIZf08jK]`2?WKP0SYbe092M]P2B
W[P0Tj2j09>Q^`2BXKT0UZBj0P2IYK`02`2JY[d0VZFm09nY_@2OZ;X0X:Nk0:>X_02TZ[d0XjRm0:>Y
_@2SZ[d0YJ^n0080XjZm00/0XjVn0:B/_P2S[;h0Xj^m0:B/_02S[;d0XjZn0:BZ_`2W[L40YZbo0:F/
_P020:F]_P0;0:F/_@2W[[d0ZZjl0:V]^@2X[KP0Z:ji0:Z^^P2[/;/0Zk2m0:^^_`2[[l000P2Z/<40
302Z/<00Z:no0:N]^`2V[KT0Yjji0:R_^@2W[[L0Z:jj0:R]_02X[Kd0ZJjo0:Z`_`80ZJnm00/0Yjjk
0:J]^@2V[KT0Yjji0:N^^P2Y[kX0Z:jj0:N]^@2W[[X0Yjnk0:R^^`020:N^^`070:J/^P2W[[T0YZbf
0:F/]@2V[;@0YJ^d0:F[]@020:J/]@0@0:F[]@2TZ[D0XZRc0::X/`2QYk80XJN`0:6W[`2PY[00X:Jc
0:6W]P2NYKD0WZJe09fV]02JY;80V:6`09RR[`80Uj6^00D0UYn/09BPZP2CX:P0TYjW09:LYP02096J
Y`04092JY@2?Vj<0SYZP08fIW@80S9NK00/0S9NL08^FV`29UIX0QY6D08>?T`21Si80P8jB07j;T@1m
RI<0NhRB07Z8T00207B2R@060720P`1FIfP092hg00T>60031`d00@866_oooonX0000o`D0oh003ooo
ool000gooooo00H0JG^207F7T@1iRYX0NHZN07V9Y01fQZD207>2X`0;0763X`1bQJ@0MHRT07N:X`1i
RZ<0NHVU07^<Y`1mSjL0OXnT082AXP22TZ800P23TJ@02`21T:L0PI:[086BZ`24Tj/0QYB/08ND[P27
Tk40QI:b08JC]027UK40RIJ`0080S9Rc00L0SINc08nI]`2?VKP0SiZi092K^@2@Vk@0T9bc0080TYjf
0P2AWkL03P2CXKP0V:Bj09RT^P2JYK/0VZBj09fV^`2PZK`0XJRj0:6W^@2RZ;/0XjRm0:>X_`2RYkh0
XjRn0P2QYkd0102QYkh0Y:W00:>Z`02RZ[l20::[_0050:>Y_P2TZKl0Y:Zm0:>Z_02VZk/00P2V[;`0
2`2TZ[/0YJZk0:J[^@2W[KL0Yjff0:R^^02WZkP0Yj^j0:N/_`2Y[L40ZJ_10080ZJ_200P0Yj[00:FY
_`2TZKd0YJZk0:F[^P2W[KX0Yj^h0:JY]`80YjZh00P0YjZk0:R[^`2WZk/0Yj^k0:F[^P2TZ[T0YJ^h
0:J]^080YZbh00D0Yjbi0:FZ]`2UZkL0YZ^g0:J/]`020:F[]`0;0:BZ]P2UZkH0YZ^e0:F[]@2VZ[@0
Y:Vd0:6W]02QZ;@0WjNb0::X/P2RZ;@00P2NYK80302NY;40WZB`09fS[@2MXjd0WjF`0:2T]02LXK@0
VZ6d09RO/P2GWZl0VJ6`09RP/@80UYn_00/0UJ6^09>OZ`2AWZP0TYfW09:KZ02AVjP0SYVV08bHX`2=
VYl0RiRK08ZHVP0208^FW00;08ZEW@28Ti`0R9FK08:>U021SI80PHnC08:>U@20RiD0P8ZD07f:T@1k
RHd00P1iQXT01P1fPHD0N8J505YWJ00F6BL030dG00T74Q[oooooZ@000?l40?n000oooooo000=oooo
o`0606amRP1eQiH0NhbN07^:X`1iRJP0MhNX0P1cQJH02`1dQjD0M8RS07N:XP1hRZ<0Nh^U07b<Y`1l
SJT0P9:Z082BY`20TZ@0PI:U0080PY2V00/0Pi:[08>C[P21TZh0PY>]08>BZ`26U:d0QY>a08JC/`26
U;80QiJ`08^I/002092J/@0<08nG/02@V;<0SiVe08nI]P2@V[D0TI^c09>L/P2CWK80Tifc09BP]02D
XK@0UJ6d0P2HXkH02`2KY;T0VZ>i09^T^P2MYkT0WjRh0::Y^`2RYk/0XJJm0:BW_`2SZ;h0XJRm0080
X:Rl00/0XJRk0:>Y_P2TZ<00Xj[00:>Z_P2TZkh0XjRl0:FZ_@2V[;d0Xj^j0:F/^`030:F[^P0:0:BY
^02SZKH0Y:Zd0:B/]02TZkD0YJ^g0:J[^`2VZkh0YJZo0:FY_`80YZ[100`0YJ[00:BY`02UZ/00YZZm
0:J[^`2X[KX0Z:^i0:NY^@2XZkX0ZJbi0:V/^P2XZ[T20:R/^@050:N/^@2VZkP0YJZh0:F[]`2V[;P0
0P2UZkT0102V[;P0Yjfh0:N]]`2X[KL20:R]^080Z:bh00P0Z:^f0:N/]@2VZk@0Y:Zd0::X]02PZK<0
WjVd09jW/`<0WJFb00T0WJJc09jV/`2MY;00WJ:`09nU/@2MXk@0W::f09^R]P2IXK<00P2IXK003P2I
XK40Uj2_09NP[`2DWjd0TYn/092KZP2@W:X0TIf[092LZ`2=VZX0RYZU08VIX029VIl0R9NL0P2:V9d0
2`29UId0QiBL08JEV`22TID0PXnB08B?T`24SYD0PX^F086;UP1mR980NHJ=0080NXJ:00H0NH>807V2
QP1hQ8H0E5aV03LkB`0_<T8JooooojX0003o0`3oP00?ooooo`003Oooool01P1YNH/0M8FH07^<XP1j
Rj@0NXVW07V7Z080MXJV00/0MXVU07R<Y01kSJ@0NhbU07f<YP1mSJL0OXjY07n?Z@20T:L0PI:U08BD
Z00208>@Z@0608>AZ`23TZd0PY:^08>D[`24U:h0QYF^0P28UK000`28U:l0RYN_08fI[`0208jH[P0<
08jG[`2@V;40TIRc096I]@2AVK<0U9^c09FL]02DW;@0U9fd09FP]@2EXK80V:>b0P2KY;D02`2LY;P0
W:Fl09bU_02MYKX0WZNk0:6Y_@2QYk`0XJNm0::X_P2RZKh0XJVn0080XJZn00X0XZZo0:>Z`@2SZ<40
XZO00:>X_`2SZKd0XjRj0:F[^`2U[;`0Y:^k0`2TZ[/0102UZkd0XZVk0:6X^@2SZ[P30:B[]`040:F/
^`2U[;h0Y:^o0:BZ`080Y:Ro00`0YJZo0:FZ`@2VZl<0YZ_00:J[_@2W[;d0Z:bn0:V/_`2Z[L00ZZfo
0:V/_@2Y[;X20:V/^@070:R[^@2WZkX0YJZi0:FZ^@2UZkT0YJbm0:J[_0020:F[^P0?0:N]_02Z[[h0
ZZfm0:Z]_@2X[;d0Yjbl0:J[^@2UZ[H0Y:Ze0:BZ]P2SZkL0XJZe09nY]02NYk<0WJFc0080W:Fb00`0
WJNc09jW/`2MY[<0W:Bb09fV/`2KY;<0VZ>d09RP]02GXK80VJ>b09VR/@2GX;0209NP/P0;09FQ/P2B
Wjl0T9f]092LZP2AW:T0T9bY08nJZP2<VjP0RYZT08VIW`28V9/00P2;VY/02`2:VY`0R9VK08NHV@25
UID0QI>D08FAU024SY@0Q8nG08:=V01oRiP0NhVE0080O8RC00H0OHVA07b5S@1iPhX0MX:806aiP01T
M7PJoooooj`0003o00<0oh00ooooooooool03Oooool000gooooo00H0IGB90763V@1gRJ80MhVS07R9
Y@1iRZD207J8Y@0;07J8Y01dQj80MhRS07^:Y@1kRj@0O8bV07f>Y`1oSjP0P8fV08>AY`26TjX00P24
TJX02P22SZX0PHjY086?ZP24TZh0QI>a08JD/@27UK80QiBb08VF/@2<V;4308bG/00<08bF/@2?Uk40
SiRb096I]02BVK@0U9bd09BM]P2BVkD0TY^c09>N/`2DX;80UJ6b0P2GX[802`2JY;H0V:>i09VT^P2K
YK/0VjFj09ZT^@2KXk/0WJJn09jW_P2MY[h0WZFo0080WjK000/0WZK20:2W``2OZ<<0X:K209nV`@2Q
Ykl0XjZn0:B/_`2SZk/0Y:Zj0:BZ^`020:>Z_@0;0:BZ`02RZ<40WjJo09nW_P2PZK`0XZ^k0::[^@2R
Zk/0XZVl0:6X_@2QYkd00P2SZ;d0302UZKh0YJVo0:JZ``2UZL80YJ[00:BY`02SZ<00YJW00:JZ`@2U
Z<40YZW10:JY_P80YJRm00/0Y:Nm0:BX_@2SZ;`0XjVl0:BY^`2TZ[h0YJ^o0:B[_`2T[;h0XjVm0:BY
_@020:FY_P0;0:>Y_02SZKd0XZRj0:>Y^@2TZkX0XjZj0:6Y^@2PZKP0WjNe09nV]@2PYkL00P2NY[H0
302NYkH0W:Fe09ZR/P2JY;40VZBb09VS/@2GXk00UJ6`09FQ/@2FX;40UYna09BM[`80U9j`00H0UZ6b
09:O[`2@WJd0T9f[08nJZ02<Uj@208^GY00308^HY029V:40R9NM0080RINK00X0QiJJ08BCV@22TYL0
PY:F08:AU@22Si@0PHfC086=UP20SIL0OX^E0`1lRY@01P1lRI@0NXJA07J3S01ePhT0LH6506anOA[o
oooo00<0oh000000o`000?l0ZP000?l?ooooo`003Oooool01P1UM8T0LH>I07N9XP1gRJ<0N8VU07V:
Y@80MXRU00/0MXRT07B7XP1gR:<0NhZU07^;Y01lS:H0OHjW07n?Z020SJH0Pi6W08JCZP0208BAZP0:
08:>ZP21SZT0PHnZ08BB[P25Tk40QYBa08NE/P27U;80RIJa08bH/@<0S9N`00`0S9Ja08nG/@2?V;80
TIVd09:I]02DW;@0U9ff09:K]@2BVk<0Tijc09BP/P2EXK8209NR/P0;09ZT]P2HXkT0VJBj09^U^`2K
YKX0VZBi09^S^`2MY[h0WZNn09fV_P2NYKl00P2OY/002`2NY/80X:O309nX``2PY/80WjK10:6W_`2S
Z[h0Y:bo0:>[^`2TZ[X0Y:Zk0080XjZm00/0Y:[00::X`@2OY[l0WjNn0:2Y_02RZk/0XZ^i0::[^`2R
ZK`0XJRm0:6W_@020:>X_@0<0:FY_P2UZKl0YZ[30:FY`P2UZ/00Y:W00:>X`02UZL00YZ[10:FX`@2V
ZL40YZVn0P2UZ;d02`2TYkd0Y:Rm0:>X_02SZK`0Y:Vk0:BZ_P2UZkl0Y:^o0:B/_P2SZKd0Y:Vm0080
YJVn00/0XjVl0:>Y_@2RZ;X0XjVi0:B[^P2SZ[X0XJVi0:2Y^02OYkD0WjJe0:2W]`0209jV]P0<09jW
]P2LYKD0VZ:b09ZT/@2JY;80VJ>a09NS/02EXK00UJ6a09JP/@2FWk40U9f_0P2DW[001P2FXK80TYn_
092M[@2@WJ/0SiZX08bGY080RiNT00<0RiRT08VHX@28Uid00P29Ui/02P27UYX0Q9>I08:BU`22TYH0
PY6E08:?U021SI<0PHfF082=U`1nRiD307b:U00607b9U01jQY40MX><07F3R@1aPHD0K7im6_ooool0
0`3oP000003o0000o`2Z0000o`oooooo000=ooooo`0606=bR@1_PYX0M8VS07J:Y`1fRJL0MhVV0P1f
QjD02`1eQJ@0M8FT07J7Y@1iRJD0NXVU07^;Y@1mSJH0PY2X08>@Y`24TJL0QiB[0080QI6Z0P23T:T0
2@22T:P0PXn[08FA/026TK80Qi:c08NA/P27T[40RYFd08ZD/P0208bF/@0<08jF/`2@UK@0T9Jd096G
]@2BVKL0TYZe096J]@2@V[D0TI^e09:M]@2BWK@0Tj6d0P2CXK<02`2FXkH0UJ6h09JR^`2GXkd0V::k
09ZT^`2LY;`0WJBn09bT`02KY;h0W:Bn0080WJJo00T0WZK109fV`@2MYL40WZK209nV`P2OY/00XJNn
0:>Y_P2RZ[d00P2SZ;/20:6W_00;0::X_P2SZ<80XJK20:2V`@2QZ;l0XJVo0:6Y_P2QZ;d0XJNn0:2W
_P2PY[h00P2TZL00302TZKl0YJVo0:BX`@2TYl40XjO20:BX``2SY/80Y:O30:JYa@2TYl@0Y:S40:BW
``80XjO200D0Y:W30:BY`P2RYl40X:O00:6Y`0020::Z`0040::[`@2SZl00XJRm0:6Y_080XZRl00D0
XJRk0:6V_02QYk/0XZRk0::Y^`020::W^P040::X^`2PY[P0WjBg09nU]`80WjBg00`0WZFg09bU]P2I
X[<0VJ:b09^S/`2JX[80V:6a09JP[`2FXJl0UYn`09JO/@2FWk0209FN[P0609>M[@2AW:`0Sib/08nL
Z`2>W:X0SIRW0P2;Uj@00`2:UZ80RYFQ08ZEX00208VDW`0;08NBW@25TId0Pi:M08BCW023TYT0PY2G
086>UP1oS9P0OXbI07b9UP1jQi@00P1jQi<01P1hQI80MhB?07B3S01cPXT0LH:406eoOA[ooooo00<0
oh000000o`000?l0ZP000?l?ooooo`003Oooool01P1WMh/0L8:J07:6XP1eR:P0MHRZ07>6Z@<0LH>V
00X0M8JW07N9Z01hRZD0NHZU07^;Y01lS:D0OX^U086>Y`23T:T0QI6[0P22SZX02`21SZT0PhnY08BA
ZP24TJX0QiB]08NB[@28T:l0R92`08NA/029Tk00S9Fa0080SYNa00`0T9Nc096G]P2@U[H0T9Ff096G
^02@V;H0SiRe092I]P2AVkH0TIfg092L]`2BW[D209:N/`0;09:M/`2BW[D0UZ6i09JR_02EWkX0VJ:l
09^S_02KX[`0VJ2n09^T`02JY<000P2JYL401`2LY/00WJJo09fV_P2MY[h0WJFn09jV_P2OY[d00P2Q
Yk`03`2QY[`0XJNl0:6W_02QYk`0X:Jl0:6V_@2RYkl0XJJo0::V_`2QY[l0WjFn09nV_P2OY;h0WjG0
09nU`@020::Y`P0<0::X`02RYkl0XZRo0::W_`2RYl00XjS30:FYaP2UZ<D0Y:S40:>X`P2SYl40XjS2
0P2SYl402`2SYl80Y:S20::W`@2QYl80WjO20:6Y`P2QZL00XZZo0::Y_P2QZ;d0XJRk0080XZVk00X0
XJRk0:6W_02SZKd0XjZn0::X_02PYKT0WjFi09nV^@2OYKL0WZ>d0`2MY;D0302MXkD0VZ:d09VQ]02J
XK<0VZ:b09RQ/@2FX;40UIj_09JM[@2GWZh0UYj_09JO/@80UYj`00/0U9f]09:K[02@Vj/0SYRZ08jI
Z@2?VjX0SYVW08fIYP2<V:D0RIFR08ZEX`0208VDXP0;08NAW`25T9l0Q96N08>AV`24TYX0Pi2I08>>
VP21Ri`0OXZN07Z6V`1gQIH00P1gQYD01P1gQi<0MXJ@07F6S@1cQHT0LH>306n2OA[ooooo[@000?l?
ooooo`003Oooool01P1UMHT0Kh6H0724W`1bQj@0LXJV0763YP80KX6T00/0L8BW0764Y@1bQJD0LhJU
07F7Y@1fQj@0NhZV07^8YP1nRjP0P8jY08:?ZP0208:>Z@80PY2Y00T0Pi6Z08BBZ`25TjX0QI:X08JB
ZP26TJ`0Qi>]08RB[P2:U:h00P2:U:d0302;U:l0SIFb08nG]@2>UkH0SYNg08jH]P2>V;<0SiVb08jH
/P2?V[H0T9^g092K]080T9bc00/0T9^b09:L]02DWkL0UJ2h09JO^02EWKP0UYjk09JO^`2EWk/0Uj6n
09VT`00209NS_`0;09FR_P2GXkd0Uj:k09NS^`2IY;`0VjFm09bU^`2LY;T0W:>h09bS^@2NYKX00P2M
Y;X209jT^P0909jT^`2NX[/0WZBm09nV_@2MYKX0WJFk09jV_@2NYKl0WjO20080WjS300`0X:S109nX
`02NYkh0WZNn09nW_`2PYl00XJO10:2U`02PY[h0X:Nm0:2W_`2OYKl209jS_00;0:2U_P2QY/00X:K1
0:6X`02OYkl0WjRo09fV_@2MY[`0WjRl0:2X_02MY[X00P2LY[T02`2MYKX0WJFi09nW_02PZ;d0WjNk
09jU^P2LXkP0Vj>f09fU]P2LXk@0Vj>c0080W:Ff00`0Vj>g09RP]P2GWk@0Uj2c09NP/02FX:d0U9j/
09FN[@2DW:d0UIb^09>K[@2AVZ`2096J[@0408nI[P2@Vjd0SYZ[08bHZ080RiJV00D0RYFU08^EY@2:
UJD0R9>S08NBXP0208J@X@0;08:=WP22SId0PXjL082>VP1nSYL0OhfG082=U`20RiT0Oh^L07^7VP1g
QiL00P1fR9D01P1dQI40LX>=0763R@1`Ph@0KH5o06b0NQ[ooooo00<0oh000000o`000?l0ZP000?l?
ooooo`003Oooool01P1WMH`0JW^F06f1W`1]Q:80KhBT07>6Y`80LXFW00/0LHFW06j3Y@1`Q:H0LhRX
07B8YP1fRJH0NH^W07Z:YP1mS:H0OXfW07n=Y`0207j<YP80OXfV00T0OhnX082@Z@20T:P0PI6X086A
Y`26TjX0Qi:]08RC[`28U;000`28U:h02`2;UK00SINc08fH]P2;UKD0SIRf08fJ]@2>V[<0SIVb08bH
]P2<UkH0RiNe0080S9Vb00/0SI^b092L/`2CWK@0Tiff09FN^02CW;P0TIZi09>K^@2CW;P0Tifh09>N
^P0209>P^`0;096P^`2CXK`0UJ6k09BN^P2EX;`0UInl09JP^P2IX[X0Vj>j09^S^`2KY;/00P2JY;/2
09ZS^@0809ZS^02JX[P0Vj>j09bU^`2LY[T0W:Fi09bV_02MYKl309fU`00<09jW`P2NY/80WZK109jV
`02MYKh0WJFo09fT_P2MYK`0W:Fl09bU^P2LY[`0W:Jm0P2KY;/02`2KXk/0WJBm09fT_P2MYKl0W:Fo
09bU_P2JYK`0VjFj09bW^02OZKT0WZVi0080WJRi00/0W:Fh09bT]`2LY;T0WJFi09fV^@2MYKT0Vj>g
09ZQ]@2IXKH0Vj>g09ZT^00209ZU^00<09VS^02GX;D0UIjd09JN]02EWk80UIn`09>N[P2BWJd0TYb/
092J[02?VZ`0SIVY0P2>VZX02`2>VJX0T9Z]08jI[@2=V:/0RiNY08^EY`28TZ@0RI:U08VCY@26TZ<0
QI6R0080Q96R00@0P8fN082=W`20SZ40P8nP0P1lSI`01@1mSI`0OHbJ07b;V01iQYH0MXFF0080MhRG
00H0M8FC0762SP1`PhT0Kh>306j2P01[OgTJooooojd0003o3oooool000gooooo00H0IgB@06alW01^
PZ@0KhFV0723Y@1bQ:L207B6ZP0407>5ZP1aQZX0LXNY07B9YP80MhZW00D0NHZW07^<Z01lSJP0OXnX
07n?Y`02086?Y`0;07n=Y`1nS:L0OhjY086?Z`21TJ/0PI:[086@Z@25TZ`0QY:_08JA/027TZl00`29
UZl02`2;UZl0RiJa08fF]@2<U[P0RYFg08ZF]`2<V;H0SYVh08jK^P2<VKT0RiRf0080RiVc00/0SYbd
092K/`2CW;D0Tibf09JN^02EW;P0U9bh09FK^@2EW;T0Ti^g09BN^P0209FQ^`0;09BP^`2DWk/0V::n
09VR_P2HX;d0Uj2k09VP^`2HWk/0VInl09bR`02MY<000P2LY;h02`2KY;d0W:Fl09bV^`2KXkT0Vj>h
09bU^`2MYk`0VjBh09bU^P2NYKl0WZG20080WZK200X0WjO30:2W``2PY/80WjG209jU`P2NY/80WZO1
09jW`02MYkh0VjJm0P2JY[l209^V_`0;09^U_02MY;`0W:>m09ZR_P2KYKl0VjJo09bV_@2MYk`0WZRk
09fX^02OZ[L00P2PZ[L02`2OZ;L0WjRh09jW^P2OYk/0WjNl09jV^`2MYKT0WJ>h09bR^02LY;X0WJFj
0080W:Ji00`0Vj>g09RQ]P2IXKH0V:6f09NO]@2EW[@0U9fe09>N]@2BW;<0T9ba092M/02@WJd2096L
[P0;096J[@2@VJd0SYR^08fG[02;UJX0RiJ[08^FZP2<UjT0RiNX08NEY@26U:@00P25TjD02`23T:<0
PXnT08:@Y`22T:H0OXjR07^;X@1kRil0NhbL07Z;V@1hQiP0MhFJ0080N8NK00H0MHFF07F6TP1dQXd0
LXF70724P@1]PWXJooooojd0003o3oooool000gooooo00@0J7>A07>1X@1dQ:L0LhBW0P1bPZH207F4
ZP0;07B3ZP1dQJX0LhJX07F7YP1hR:P0NHRX07Z9Z01lS:P0OXfW07n=YP21SZH00P22SJL02`24SjX0
Q8j/08>>[P23Sk00PXj`08>@/@25TK40QI:a08FA/@28T;00RI:`0080RI>`00`0RiF`08jH/`2=Uk<0
S9Nf08jG^P2<U[P0RYBe08ZC]02=U[L0SiVi08jI^@2=VKL208jI]00;096L/`2BW;<0Ti^c09FL]02F
WK@0UYbb09JM/`2GWKD0VIjf09JL]P2FW;L00P2HX;T02`2IX;X0Uijj09VN^`2JX;`0VJ2j09VP^@2J
WkT0W:2k09^N_@2LWkd0WJ2n00<0W:6o00X0W::o09jT_@2MXkT0Vj6g09fT^02OY[/0WZBi09nS^@2P
Y;/0X:>n0P2OXl002P2OYL40XJK10:6U`02QYL00Wj?009nT`@2NY<40WJ?009fT_P2LXkh209fU`080
WJJn00/0WjJk0:2T^@2NXkT0WJ:k09bR_02KXK`0W:Bl09nV_P2OYKd0WZFj09jT]`0209jS]P0;09nS
]P2PYKL0WZFg09nU^@2NY;X0WJ>i09fS^02LXKD0W:2c09^O/`2KX;D00P2MX[H0102KX;@0VJ2c09NN
/P2GW[8209RN/P0609NL/`2EW;@0Ti^c09:K/02BVZl0Ti^^0P2CVZl02`2@UZ`0SiF[08jDZ@2>UJT0
S9BY08^CZ@29T:D0RI>T08RBX@26TIl0QI6P0080Q92Q00/0PhjR08>=XP23SJH0P8^U07^8X@1kRJ00
NhZN07V7VP1hQYP0MX>F07J2UP0207J3UP0607F1T`1ePY00M8:=07:2R@1_P840JWah6_oooon]0000
o`oooooo000=ooooo`0606A]RP1ZMiH0L7nQ06moX`1bPJD0LX6V0P1bP:D02`1eQ:P0MXFX07J7Z01f
QZP0N8NX07Z9Y`1kRZH0Nh^U07f=Y@1nRjD0PHjW0080P8bW00@0PXfY08B=[@22SJl0PHja0P21S[80
1@21Sk00PY6`08>B/025TZl0Qi:`0080RI:a00H0RY>b08ZD/`2:U;@0RiJf08fF]`2=U[H208^F]P04
08jI]`2?V[D0SIJb08bF/@80SYNb00/0T9Zc096K]02AVk<0TYbb096J/@2CVk40UYjb09JL/`2FVk@0
UY^e09JL]P0309NM]`0:09NN^02JX;/0VZ6m09ZP^P2JXKX0Vj2i09bP^`2LX;h0W:6n09ZP_@80VZ6l
00@0VZ6m09^R_@2JX;T0Vj:h0P2LY;P01@2MXkH0WjBg09nT^02OX[P0WJ2h0080W:2h00H0WZ:k0:2U
_@2PY;d0X:Bo09nR`02OX/4209nS`@0409nS_`2NXkd0WjBn09jU_080WjFh00D0X:Jh09jS]P2LXKH0
WZ:i09jU_00209^R^`0409fS^`2OXk/0WZ:i09fO]P80WZ6h00D0WZ2g09nQ]`2OX[L0WZ:g09^R]P02
09VP]P0409^Q]P2HW[80VJ2b09VO]080V9ne00`0Uind09JN]02FW[<0Uina09NN[P2GW:d0Uib`09FK
/@2BV[00TIV_08nF[02@Uj`209:I[P0;092EZP2=TjP0SIBX08^AYP2;TZH0RY6V08N?X`27TJ80QY:O
08F@V`25TId00P22SI`02`22SId0PXfO08:;X020R:80OHRR07b7W`1mRYd0NhRJ07Z5V01gPYD0M82A
0080MH6C00H0MX:D07B0T@1`OXd0KWj906enP@1XNgLJooooo`030?n000000?l0003o0:X0003o3ooo
ool000gooooo00H0Hfj:06aiUP1aP:00Lh:U07>1Y@1aP:@207:1Y00;07F4Y`1hQjT0NHV[07R9ZP1f
R:L0MhVT07V:X`1jRj80OHfT07n<YP20S:T00P1oRZT02`1oRZ/0PH^/08:=[@21SJh0PHn`082>[`1o
SZ`0Oi2[082AZ`23TZ/0Q96[0080QI6^00/0Qi:a08RD/P29UK80RYFa08ZC[P2<UK80SINe08jI]P2=
VKH0SYZc08fI/@0308fG/@0808nH/P2?VK80SYVa08jJ/@2>V;40TIZb09BL]02EW;H209BK]`0>09FK
]`2GW;T0Uibi09NL^@2FV[P0Uibj09VO^`2IX;X0VJ6i09ZP]`2JWkL0VZ2j09ZQ_02IXK/209NO^00;
09NP]`2JX[L0V:6d09VS]02HXk<0V:>b09RP/02KX[80WJ>f09jT]`2NXkL00P2NXkH0302OY;L0Wj>i
0:2T^`2PXk`0X:>o09jS_`2OY<00WZ;009fQ_P2MX[h0WJ>l09ZR]`80Vj:d00/0Vj>e09bR]@2LX[H0
Vj6f09^R^`2KXk/0W:>j09^P]`2LXKD0WJ6f09bO]P0209bN]P0;09fP]P2LWkD0WJ6f09fS]`2KX[L0
V9jd09JL/`2FW[@0Uinb09NO/@2GW[<00P2FWkD0302EWKD0Ti^c09>L/P2DWK80U9f`09>K[P2CVjl0
TIV`08nG[P2>Uj`0S9FY08fFZ@80SiJY00/0SIBW08bBY02:T:@0R92S08J?X@27T:80QXnQ08F?X@24
TJ40Pi6M082?VP0207n>V@0;082>V`20SId0P8^N082:X01mR9l0O8RN07b8W@1jQYP0NH>D07R2T`1e
P9400P1cOi801P1cPID0L7nA06inS01/OHD0JWao06MjMa[ooooo00<0oh000000o`000?l0ZP000?l?
ooooo`003Oooool01P1QKHP0JWND075mWP1bOZ<0LGjS075oX`80M86R00/0MhFT07R7Y`1iQZT0N8NY
07N9YP1eR:@0MhVU07R8X`1kRj<0OhbV07n;Z@0207n;Z`0;07j;ZP1oRZL0PHjW08>@ZP23T:/0PHn/
082?[01oT:T0P92X08:@YP23T:P00P24T:`03025T;00Qi>b08^F/@2;UJh0SIF^08nF/@2?UkD0SiRh
08jG]`2>V;H0S9Ja08jG/080SYF^00/0SiJ_092G/02?Ujl0SYR_08jG[`2AV;00TYVc09>I]@2CV;L0
TYVi09>J^@0209FL^00;09FJ]`2DVKP0UY^i09JL^02FW[L0UYjd09RP]02JX;D0VYnf09VP^@2IXKX0
0P2GWkH01P2FW[<0V:2a09VP/02JX;40V:2a09RQ/P80V:6a00<0VJ6b09^S]P2MY;T00P2LXkH0302L
Xk<0W::b09fR/`2OX[D0Wj>h09jS^@2NY;X0WJ:j09^O^@2JWkT0VZ2j09NN]`80V:2f00/0VZ6f09ZR
]P2LX[P0W:6i09VO^@2JXKT0VZ:h09ZQ]02JX;<0WJ6d09fQ]P0209bO]@0;09ZM/`2HWK40VIfa09fQ
/`2KX;80V9fb09FK/`2FWK<0UIj_09FL[@2EVjl00P2CV[40302DW;<0Tibb09:L/@2BVjl0TIV^092H
[P2?Ujl0S9J^08ZCZ02:U:D0RiFS08fFY0<0S9BS00X0Ri:R08V@X@29TJ00Qi2O08R@W`29T:00QhnQ
08B?X@20SId0OhfI0P1mRiL02`1oSIT0Oh^J082:W@20R9h0OXNN07b6X01jQIh0NHBI07R2U01hP9@0
MgnF0080M7fF00H0LWjF06imT@1/OX/0Jgb306UlO@1XO7LJooooo`030?n000000?l0003o0:X0003o
3oooool000gooooo00H0H6^506UfTP1_O9`0LWjQ071lXP1aOZ<207B1XP0;07>1XP1ePjD0N8JX07N5
YP1gQjH0N8VV07R:YP1iRJD0NXZU07^:X`1mRZD00P1nRjL02`1nRjP0OX^T07n;XP21SJ@0PXfV08>=
Z022SjT0PHnX082?Y`23TZP0Q9:X0080Q9:Z00/0QI:/08JA[029Tj`0RI>Z08^DZP2=U:`0SiF`08jD
/P2?UK<0SYFb08fC[`0308nF[`0908nE[P2@UZd0TIR_09:I[`2@Ujd0TIJ^09:G[`2BUk80TiRg0080
TIRi0P2CVKL02`2BV[D0TYVf09:H]@2DV[H0UYff09JM]02FW;80V9bc09RL]@2EVKH0UI^f0080UYfd
00/0Uija09NM[P2IWJl0VIf_09RN/02GWZl0UYj^09NN[P2FWZh0Uijb09JM]00209JN]@0<09JP/P2H
X[00Vj:`09fR/@2NX[@0WJ:e09jR]`2LXKH0Vj2e09VO]02HWkD0UYbd0P2EWK<02`2FW[@0Uifd09VM
]@2JWkL0V9je09RN]`2HWkH0UYjc09NN/P2IWk40VYnc0080W:6d00/0VYjc09VM/P2IW;00VYfb09VL
/@2IWK<0Uife09JM/P2EVjh0TYV[09BJ[@0209>I[@0<09:I/02CV[00TY^_096J[@2?UZX0SYJZ08jF
[02;U:/0RI:U08ZDX`2=U:80SYBP0P2?U:002`2<TZ40Ri:P08^BX@2:TIl0R92M08F=VP26SI`0RHnP
08F=X020RYd0OhZK0080OHVH00/0OhZH07n8V@20R9X0PHRL07n5W@1lPYd0NH2L07V1V`1hOiP0MgfF
07IlU`0207ElU`06079mU@1^O900JW^806YlP`1YO7h0J7]h6_ooool00`3oP000003o0000o`2Z0000
o`oooooo000=ooooo`0606=^R@1[N9D0L7nM0760X01bOj40LGjR0P1cP:@02`1aOZ80M86U07J5Y`1e
PjH0MXFW07R8Z01jRZT0NhZY07Z9Z@1kRjL0OhnX0080OhfW00/0Oh^V082<YP21S:D0PHbU086<Y`20
S:L0PHfW082=Y`21SjP0PY2X08>AZ@0208BBZP0508JC[027Tj`0RIB[08VCZ@2<UJ/00P2=UJX01@2<
Tj/0SIB]08fE[P2>U[00SIB_0080SYFa00<0SIF_08jG[P2?V:h00P2@UZh01P2AUk00TINc096G]02B
UkL0TYVi09>J^P80TiZi00L0TYZi096H^02AV;H0TIZe09FM]@2FWK@0UYbb0080Uibc00l0U9Zd09FK
]`2EW;H0UIbf09JN]@2GWKD0V9fe09VM/`2IWk40V9n_09NO[P2EW:`0U9b/09BM[`2DW;800P2FWk@0
302EWk<0V:6c09VP/P2JX;<0W9nc09bP]P2MX;L0W:2h09bS^P2KX[T0Vj6g09^P]P80Vj6e00/0VJ2e
09NM/`2GW;<0Uifd09NN]@2GW[H0V9ng09JM]P2GW[D0VYne09RM]00209ZO]@0;09VM]02JWK<0W9fc
09^K]02KVkD0VI^f09NL]02FW:h0UIb]09>JZ`2CVj/00P2CVj`0302BVJ`0T9N/092H[02?Uj`0SiR/
08fGZ@2<UZT0RiJY08^DY@2<Tj<0SI>R08bAW`80SI:Q00/0RY6Q08N?WP27TYd0R96L08N?V`25S9`0
Q8^M08F<W`26SJ00PXZO08::WP020828W@0;07n7W01oQI/0P8BM0823W@1mPYd0Nh6L07Z0W@1iP9`0
MgjI07EmV@1dOIT00P1dOYP01P1bOI<0K7V;06YhR01YNXD0IWQo06AgNA[ooooo00<0oh000000o`00
0?l0Z0000?l20?n000oooooo000=ooooo`0606=]R01YMi@0KGbK071oW`1bOil0LWnQ0P1bOj802P1a
OZ80Lh2T07B1X`1fPj@0NhVX07^9Z@1kRZT0NXVX07Z9Z@1lRZT307n=Z`0507j:ZP1oRjX0PHbY08:=
ZP20S:T00P21SZX01022SZT0PhnY08>@ZP23SjT208FAZ`0<08JBZ`26TJ/0R9>/08ZE[@29U:X0RYFY
08ZDZ@2:TjX0RY:[08ZA[02;Tjh0SIB`0P2<U:l02`2<Tjd0SIB^08fC[`2>Tjh0SIB^08nE/02AUk<0
T9Jd092E/`2AU[D0TYRg0080TYVi00/0TIRi096I^@2BVKP0TYZg09BL]P2FWK@0UIbc09>J/02EVk40
U9^b09BL]00209FL]P0;09JL^02FVkH0UY^d09NL/`2GWK40UYb`09BK[@2DVj`0U9f^09:K[`2DW;80
0P2HX;H0302HX;L0Uing09NN]@2IWkD0VYne09VN]@2JW[L0Vini09^P^`2KXKT0WJ:h09fQ]0<0Vina
00<0VYjc09VN]@2IW[D00P2GWKD0102HW[P0V9fh09RM]P2IWKL309VL]`0;09RJ]@2HV[<0V9Zb09ZL
/P2IV[<0UiZd09FI/02CVZ/0U9^]09>K[`2AVJd00`2@VJ`208nGZ`0908fEZP2;TjP0SIFZ08fFZP2=
UJT0SIFW08fBY02;TJ<0RXnR0080RHjQ00/0R8nQ08F>W`25Si`0Q8jJ08F>W025SId0Ph^M08::W@23
RYl0PHVN0828WP020827WP0;07j4W@1mPid0OH:N07f2WP1kP9h0NGnL07MnV`1eOIT0LgbE071jT@1`
Ni800P1bO9801P1aNhl0L7Z<06agR@1ZMXL0IWJ206=eNa[ooooo00<0oh000000o`000?l0Z0000?l2
0?n000oooooo000=ooooo`0606=^Q`1XMI80K7^J06mmX01aOj<0LWjS0P1`OJ402`1aOZ80M86T07B1
XP1fPj80NHJV07Z8Z01iRJH0NHVT07^:Y@1nS:L0OhbY0080OXf[00X0OH^]07j<[01mRZP0P8bY086=
ZP23Sj/0Phj[08:>Z`23SZ/0Pi2/0`24Sj/02026TJh0QY:^08JA[@25T:/0QY>[08RF[028U:`0RiB]
0P2:Tj`03`2;U:l0Ri>`08^C[@2;Tjd0S9B^08nE/02?U;40T9Fb08nE/@2AUjl0TYR`09>H/@2CUk40
TiRc09:H]@0209:G]P0;096F]P2BV;H0TiZf09BK]@2FWKH0UIbe09>I]02BV;80U9Zb09BK/P2EVk@0
0P2EVkD02`2EVkL0UY^d09VM/P2IW;40V9^`09NK/02FW;40U9^_09FL/02CVjl0U9^`0080UYfc00@0
Uije09NN]P2HW[L0VIjf0P2IWKD01P2IWKH0VI^f09RL]@2HWK<0V9fa09VM/080VIf_00L0W9nc09bO
]P2KW[L0VYff09RL]P2IWKH0VYjg0080V9bd00l0V9^e09RJ]P2IW;@0VIbd09RL/`2GVk80Ui^a09RK
/@2FV[40U9R`09:I[P2BV:`0TiR^09>H/02AUk000P2>UZh02P2>Ujd0SYN[08jFZP2?UJT0SI>Z08jD
[@2<TZX0S96X08bBYP2<TJH208V>Y080R8jT00/0R8fT08J=X`25S:80PXZP08>:X024RZ40Q8RP08>7
X@22R:80P8JR07j4X00207b3W@0;07f2W@1lP9/0NgnK07YmV`1iOi/0N7nI07ElUP1dNi@0LW^B071i
SP1_NHd00P1`N8h01P1_Mhh0KWN=06YeR`1YM8L0IWB1065bNQ[ooooo00<0oh000000o`000?l0Z000
0?l20?n000oooooo000=ooooo`0606=^Q`1XMI80K7^J06mmX01aOj<0LWjS0P1`OJ402`1aOZ80M86T
07B1XP1fPj80NHJV07Z8Z01iRJH0NHVT07^:Y@1nS:L0OhbY0080OXf[00X0OH^]07j<[01mRZP0P8bY
086=ZP23Sj/0Phj[08:>Z`23SZ/0Pi2/0`24Sj/02026TJh0QY:^08JA[@25T:/0QY>[08RF[028U:`0
RiB]0P2:Tj`03`2;U:l0Ri>`08^C[@2;Tjd0S9B^08nE/02?U;40T9Fb08nE/@2AUjl0TYR`09>H/@2C
Uk40TiRc09:H]@0209:G]P0;096F]P2BV;H0TiZf09BK]@2FWKH0UIbe09>I]02BV;80U9Zb09BK/P2E
Vk@00P2EVkD02`2EVkL0UY^d09VM/P2IW;40V9^`09NK/02FW;40U9^_09FL/02CVjl0U9^`0080UYfc
00@0Uije09NN]P2HW[L0VIjf0P2IWKD01P2IWKH0VI^f09RL]@2HWK<0V9fa09VM/080VIf_00L0W9nc
09bO]P2KW[L0VYff09RL]P2IWKH0VYjg0080V9bd00l0V9^e09RJ]P2IW;@0VIbd09RL/`2GVk80Ui^a
09RK/@2FV[40U9R`09:I[P2BV:`0TiR^09>H/02AUk000P2>UZh02P2>Ujd0SYN[08jFZP2?UJT0SI>Z
08jD[@2<TZX0S96X08bBYP2<TJH208V>Y080R8jT00/0R8fT08J=X`25S:80PXZP08>:X024RZ40Q8RP
08>7X@22R:80P8JR07j4X00207b3W@0;07f2W@1lP9/0NgnK07YmV`1iOi/0N7nI07ElUP1dNi@0LW^B
071iSP1_NHd00P1`N8h01P1_Mhh0KWN=06YeR`1YM8L0IWB1065bNQ[ooooo00<0oh000000o`000?l0
Z0000?l20?n000oooooo000=ooooo`0606=_R@1YMI80KG^K06mlX01aOJ<0LWfT0P1aNj802`1aOJ80
MH2S07N2X`1gPJ40NHFT07R5YP1hQjH0NXVU07Z:Y@1lS:H0OHbW0080OHbY00P0OHb[07j=[01oSJT0
OhjV082>Y022T:D0PXnW08>>ZP80Q8j[00l0Q92Z08>>Z023SZP0Q8nY08J@[025SjX0PhjX08BAZP26
Tj/0RIF/08bE[P2<UJl0RiB_08bF/P2:Tk000P2;U;002`2;UJh0SIF^08jD[`2?U[40SiNa09:J/02C
Vjl0TiZ^09:G[@2CV;00TINb0080TYRd00/0TIRd096G/P2BVK80TYVb09>I/@2CVK80TIJb096F/`2@
U[<0TIRc09BJ]@0209>J]P0;09BJ]`2EV[@0Uibc09JK/P2HW;<0Uibc09BJ/P2CV[00TY^^09:L[@2D
WJh00P2DW:l0302EWK<0UIbd09FL]02GWKD0UY^c09FJ/02GV[40VI^d09RK]02GW;80UY^_09NL[`80
V9fb00/0VYfc09VL]02JW;H0V9^e09JK/`2GW;80V9fb09RL[`2GW:l0Ui^a09FI/@0209FI/00;09FJ
/02FVk00UIZa09JJ/P2DVK80TYNa096G/02AUZd0T9B[096E[@2?UJl00P2<U:h0302;U:/0RY>Y08^D
Z02;TjH0SI>X08fC[02<TJ/0Ri:Z08J?Y@28T:<0RXnS08R=X`80RHbU00/0R8fW08N<Y`25S:H0PXZQ
0829W`22RId0PXVO08:7X@21QZ40OhJS07b4X@0207N0V`0;07V1V@1jPIL0NWnI07UnV@1gOIT0MWnJ
079lU`1`NY@0L7ZC06miTP1_NHl00P1]MXh01P1[M8h0JG:<06EaRP1ULXL0I7>1061aN1[ooooo00<0
oh000000o`000?l0YP000?l40?n000oooooo000=ooooo`0606=^QP1WLhl0KG^J075nX@1cOZ<0M7fS
0P1dNj80201cNZ40MgjR07R0XP1hP:80NhFV07V6Y@1iQZ@0NhVU0`1lRjH207b<Y@0;07f=Y@1oSZL0
OhbU07j<XP1lS:00PI2Q08:?X@25Sj<0QXjT08F=Y@25T:P00P25T:T03026SjT0Qi2Y08J?Z@26SjX0
R92]08VA[`28T:h0S9>_08fD/P2<UK80RY>`08^C/@80S9Ba00/0S9Fb08^D[`2;UJl0RiF_08^F[@2>
V:d0T9V]092G[02@UZ/0TIN]096G[`0209:G/00;096H[`2AUjd0TiV_09:G/02AUZl0T9F_092E/02@
UK40SiBa08nE/@2@Uk<00P2@Uk@02`2AV;<0TYRa09:I/02CVJl0TiR_09FJ/@2DV[40TYR_09>J[@2C
W:`0U9f/0080U9b^00`0U9ba09>J/P2DVk<0UY^c09FJ/@2FVJh0UYV_09VL]02GV[80U9Z`09FK[`2D
VZ/209FJ[00;09NK[`2GV[00UiZd09FH/`2CV;00U9Z_09BIZ`2DVZX0UI^Z09BIZ`2CUjd00P2BUZh0
2`2BUZl0TiJ`09>G/@2BUk80TIJb092D/@2AUJl0TIF^096E[@2@U:`0SYB[0080S9>[00`0Ri>Z08ZC
Z@2:TZP0RI2U08R?YP2:TJP0RI2W08ZAY`28TJ@0R92Q08V?WP28S9h208V=X@0;08N;X`25RJ@0PXVT
07n8WP1mR9`0OHJJ07j5VP1nQI/0OH>L07f5W`1kPih00P1hPY/02`1gPIP0MGjE07IlUP1gO9P0MG^H
07=jV@1`NIP0KWRE06eeTP1[Lhl0K7>?0080JG2>00H0Ifn=06I^S01SKhT0HVn7065`PP1NKWHJoooo
o`030?n000000?l0003o0:D0003o1@3oP00?ooooo`003Oooool01P1VKX@0J76=06afUP1`NI/0LgbM
07ElW`80MGVQ00/0MGRQ07QlX`1gOZ80N8:Q07Z5XP1jQJ40NXFP07^7X01lR:40OHZT07j<YP02082=
Y@0;07j<XP1nRj80OHVQ07j:XP1mRj80P8jS08:?XP24Sj00Q8fQ08F=Y@27SZT00P29T:d03029TJh0
RI:/08RAZP28Sj/0RHj]08fA/P2<T;80RXj`08bA/02;TZ`0R92Y08^AZ`80S9:]00/0Ri6_08N>[025
SZX0Q92Y08JBZ@28TZH0SIFX08jDZ@2?UJX0SYFX08jFZ@0208nGZP80T9NY00T0TINY09:FZP2BUj`0
T9J/096G[@2BVJd0TIR/09:H[@2@UJd00P2?UZl02`2?UZh0SiJ[092FZP2@UJP0T9BW09:FZ@2CV:/0
TiV/09>IZP2BVJL0Ti^X0080TiZZ00`0U9V/09>G[@2DUjh0UIV_09BG[P2EUjh0UYR^09JI/02FV:l0
U9R]09BJZP2CVJH209>GYP0;09JI[02GVJl0UIR_09FI[`2EV:d0U9R[09BGZ@2DV:T0U9VY09BGZ02B
U:P00P2ATj/02`2BU:l0U9F`09>E/02BUK00TiJ`096C[P2BU:h0TI>]096C[02@Tj/0SI:X0080S9:V
00@0S9>Y08^BZ028SZ@0RHnS0`28SZ<01@28Sj40RY6R08V?X027SIh0R8bM0080RHfO00/0R8ZO08F8
XP23QZ<0PHJR07j5WP1lPiT0NX:F07b3UP1mPYL0O8>H07b1U`0207UoU`0;07MnV01eO9D0MG^E07Il
UP1cNID0LGNE06mfU@1^MYD0K7BB06acTP1[Li800P1YLI001P1UKHX0IFf906E^R01RK8@0Gf]o05e/
Ma[ooooo00<0oh000000o`000?l0Y0000?l60?n000oooooo000=ooooo`0606U]P@1]LX`0LgVE07El
VP1gOI`0MgZK0P1fNIh02`1gNZ40NWfT07^0Y01lQ:40O8JO07^3W@1lQ9l0O8JP07b6W`1lRJ80OhbU
0080PHjT00/0P8fP082;X022S:@0PX^U082:Y@20S:H0PhnU08J@X`27Sj80QhfU08Z>ZP0208^?[P0<
08V?[P29T:`0RHnZ08V>ZP2;Sjd0SY:`08fA/@2:SZh0RHn/08ZAZ`2<TZT0Ri6W0P2;T:L02`29SZL0
R8fX08F;YP23RZ@0PX^P08:8W023Qid0QhVR08R:XP27Rj40QH^P0080QXjP00/0R96O08VAWP2<Tj40
SYFT096GZ02>UJH0SiNW096JZ@2BVZT0Ti^Z09>JZ`0209>I[P0;092FZ`2?UZP0TIRX09:GY@2CUjD0
U9RW09JKZ`2DVJX0TiJW09BHYP2EVJL00P2DV:P0302FV:`0U9N/09BH[P2CUjd0TYJ/09BG[@2FV:h0
UiV_09RI[`2EUjd0U9NZ09FIZ@80U9NW00L0UYRX09JGZ@2EUZX0UIN/09FH[02DUjX0U9JX0080UINY
00l0U9NZ096CZ@2@TZT0T9:Y09:DZP2ATZX0T9:Z09>E[@2DUJh0TI:/09:D[@2BTj/0T9:X08nCYP2?
TZ@00P2?TJ@01P2<Sj<0RXnR08V?X@2;T:00S96Q08V>X@<0QhbQ00<0QX^P08F:WP26RY`00P29S9d0
2`28RI`0QXJO08F5X@21QJ80OX>O07^3V01lQ9H0OH>E07b1U01nPYL0O82G0080NgjG00/0NGfG07Qm
U`1hO9D0MgZB07EiTP1cMi<0LGJE06ecU@1YL980JW:A06]dSP0206YcR`0606M`R01WKXL0Ifb606EZ
P`1QJ7d0GFMe6_oooonZ0000o`<0oh003oooool000gooooo00H0JFb007=fS@1gOIL0N7jJ07UmVP1i
O9X207UkV`0;07]lWP1lOj40O82R07j4X01oQI`0OhBJ07n5W022R:40P8RQ07n9XP1oSJ400P21SZ00
2`22SYl0PhfN08B=X@24S:<0PHRS0829XP23S:40QXnQ08R?X@29SZ<0RXjX0080Rhj[00`0RXj[08V>
Z`29SZT0RHjX08Z?Z02=TJ/0SI6]08b@[@2:T:X0S9>X08jDYP2>TjD208fAX`0;08^?Y02:SZL0RHfW
08J<Y025Rj00Q8VL08F6V`25Q9`0Ph6M0861W01mOiP00P1mPIH02`1nPi<0OhBB0865U023QiH0Q8VH
08::V024SI/0Qi6N08VDX02=UZ40SiJR0080T9RU00/0T9NV092HYP2AVJ@0TYZS09:IX`2CV:H0UIRX
09BKZP2BV:L0TYVV09BJY@0209BHY00609FGY@2EV:P0U9N[09:HZ`2AUZT0TYNZ0P2EV:/0102EUZX0
TiBZ09:DZ@2BUJL209>FY`0;09FGZ02EUZH0U9BV09JFZP2CUJP0TYFW09:EYP2DUjP0UINX09JGZ`2C
UZ/00P2@TZL02`2@TjD0TIBW09:DYP2CU:H0Ti:V09:BZ02CTjT0TI>V096CXP2@Tj40SY2P0080S8jN
00`0S8nO08V>WP29Sih0RXnL08bAW02<T9`0RhfN08Z;X026R9l0QXVO08J:W@27Rid208R;V`0;08N8
VP27Qi`0Q8>L0821WP1nPYd0Nh6G07Z1T`1kPI<0Nh2B07f0U@1nP9P00P1lOYL02`1hNi<0N7bB07Mk
T01hNHh0MgV?07EfS`1cM900L7:@06]`T01XKX`0J7680080J76500H0J6j306U]PP1UJ7l0I6Mo06AX
O01MHW4JooooojT0003o103oP00?ooooo`003Oooool01P1ZKH00LgR<07IlT`1gNiD0N7ZD07UkUP80
NWbH00/0NgfJ07]nW01mPId0OhBN07n3VP1oQ9T0P8FL08:9X021RJ00PHZP082<W`0208:=W@0308B>
W022S9`0QHfN0080Q8bQ00H0Q8^Q08N>X029T:00RHnR08V?Y02:SJH208^=Y`80RXjX00X0RHjW08R=
YP2:SjH0SY:W08b@Y`2<TJ/0S96Y08fDZ02>U:@0SiBS0P2>TJ802`2=T:<0SY6V08fBYP2>TZH0S96T
08b?XP2;S:00RHVP08J3WP24PYd0PH6I0080OWnC00/0OGn?07j0S@1nOhd0O7f>07]mS`1hO8d0Mgf>
07QoS`1gOhh0OXJA08F;U@0208V?V@0;08fCW@2>Uih0TIZN096JW@2@V9h0TIRS092FY02BVJD0T9RS
092IX`2BVJ800P2CVJ00302DV:00UYVT09BEY@2AU:@0TYJU09>GY`2DUjP0UYRX09BEY`2CTjL0TI>U
092DX`80TYFT00/0TYJS096CX@2BTj<0UIFW09:DYP2BUZH0TiNV09BHYP2CUJH0U9FY09BGZ`02092C
YP0;08nCY@2CUZD0TiFS09>CXP2BTJ40Ti>S096BXP2@TYl0T9>L08nBV`2=TI/00P2;SYX0302;T9`0
R8jL08V?V`27SYL0RHnF08^@U`2:SYL0RHZK08N8W@26QYd0QXNK08V;W080QhVH00/0QhRG08R7V@23
PYL0OgnH07n2VP1mPIL0NX2C07Z0T@1lP940O7nB07j0U00207anTP0;07MiS@1gNXh0MgV=07IfR`1e
M8X0MGF<079bR`1`LH`0KG6<06Q/Q`1VKX@00P1WKh801P1XKX00JFam06AVN`1TIWX0HfMg05mULA[o
ooooY0000?l00`3oP000003o0000o`020000o`@0oh003oooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {299, 0}} -> {-0.0508884, -0.0375078, \
0.00526762, 0.00526762}, {{9.625, 190.438}, {291.875, 156.25}} -> {-12.9439, \
-9.62807, 0.929149, 0.929149}, {{208.5, 389.312}, {291.875, 156.25}} -> \
{-197.728, -9.62807, 0.929149, 0.929149}, {{9.625, 190.438}, {142.688, \
7.0625}} -> {-12.9439, -148.245, 0.929149, 0.929149}, {{208.5, 389.312}, \
{142.688, 7.0625}} -> {-197.728, -148.245, 0.929149, 0.929149}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{tst, cr2}, {cg2, cb2}}], \ 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
%%ImageSize: 400 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0178571 0.47619 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0178571 0.477324 0.357993 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0178571 0.97619 0.357993 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.392007 0.477324 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
2F3A1A2D3A1A2A391C2A38222A37292A382C2B382D2D39312C38322E3736303938303939
313A3A313B38303B38313D39333D39333D3A323C39333C3A333D3B333D39323C3A333E3C
343E3D36413E35403D35423E35413C36443B36433A37443C38463E39473F3B49413C4B42
3D4B423D4B443E4D463F4E47404F48404E48404E4941504A41504941504841504944534A
44534944544A44554C46574D44554B44544C46564E47574E47584E49594E4A5A4F4B5B4F
4B5C504C5D514D5E514C5C4E4C5D4F4D5D4F4B5D4F4D5E514D5E514D5E514B5C4F4B5C4E
4A5A4D4A5A4B4B5D4842553A15200E1018071016060B1003090D02080C02080C02070700
070600070600030300020300010200000200030400030400030300030300030200050203
0502060604060302050202040404020606010605010909030B0B050E0E080F110912130B
14150D15160D15170D14160D13130D10100A0E0D090B0B080C0C080C0C08090A06070803
060803060701050701030500030300020200010200020300030300050601070802050701
0405000606020A0A040F10080F11090F100A10110B0F110B0F100B0D100A0F130B0B0E09
01020001030002030001030000020001010001020000030000030100020500020900010D
01001002000C050407000100
404D45556756425147364041323842363B4A383F4A3B414D393E4D3C41533E44553E4656
414958434C5A45505C47525D48525D48515C48525C49525E49535F47525F47525F46525F
4853604954604954604B56624B55604E575F4C545D4E57604F59624D58624F5A63515B63
515B64515A67525C69545D6B555F6C555D6A565F6C58616E59636E5A646C5B656B5C666C
5D676E5E69715E6A725E6A705F6B705F6B72606D74616F74637175677477687579687578
66757B66757D68787D68797A697A796C7B7A6C7B7B6C7B7D6C7B7E6D7C7E6E7C7D6E7D7B
707E7B707F78707F776E7F725A685C59685A596759576357556154556054515C51363A38
3337353034322C312C292E28292D28282C29282B29272929262727252726242725131117
0F0C130E0D11090A0D07090A070906080A04090C050A0D04090C030A0D04090D060B0D06
0C0E060C0D060F11090F120A0F130B0F130B0F120C0E110D0E110C0E100A0C0E08090C05
090C03090C010B10020D11040E11060E12080E130A0D110A0D10090E10090E0F080C0E07
090B040A0B050B0E050E11080E11080D10070B0E06090C04080B040A0D05090C04060801
060902060902060803060804090C07080B0603050101050103050A030414020316040418
0807170C080B0B0803060701
32384A353C4E343A4F353950353951353952373C52383D52383D53393E55383D56394057
3B41583940573A40573B42583E455B3F465C41495C424A5C424B5D41495D40485E40495E
414B60444C60434B60424A5F454C5F464B5D464B5E474D624A4F654A4F664A50654B5064
4C51664C51684D526A4C52694D536B4D526B4E53694F546950556A505669525969535A6A
545B6C555C6F565D70565D6F575F6F585F705A62725B65735B65735F6876606978606A78
5F6A7A5E697B616C7A626E79646F7A656F7A66707B66717C66717C66727C68747D69747D
6B767D6C777B6D797B6E7C7C707E7E71807F71807D74827D75827E778280768280737F7F
73807F72807D72817A738178748077747F77758079747F7A737E7A707C76707F74393D40
1B1B211B1C1F1114140D110E0A0D090A0C04090C03090C02080B01060A00030600030400
040500040500040400050601050701040501060703070803060502060502070603060703
0608010609010F1308151A0B181D0E1A20101D23131C22131A20121C1F121C1E13181A10
14150C1111080E0F070C0D060B0D050A0B04070A02060900060800040600030400020400
020400030500030500050702090C060A0D06080B020305000304020505040506040D0F06
14160B191A0D16170B11120A
32384B33384F333853333952333952353B54353B53363C54363C53383E55383F56383E56
3B4358383F543940553A42553D45583E465B40485B414A5D424A5F424A5E43495E43495F
434A5F444B60444C61454C62464D62474D62484C63484D64484D654A4F664C51674E5166
4D51654F54674F54684E53674C54674E556950566A505669505669525A6A515A69535A69
545B6A565D6C565D6E575E6F575F6F5960705A62725C65755D65745F68755F6876616A78
616B79626C7A626C79646E7A676F7A68707B67707B66717B66707969737B6A747D69747E
6A757E6B787E6D797D6D7B7C6E7C7C6F7D7E707D7C717F7C727F7E727E7E727E7E727F7F
72807F74827E75827C75827C75817B75807B75807B77817E757F7E747F7B73827A464D50
20202920222517191A1012100E110A0C0E05080C02080C03090C03090D02050801030500
0304000305000403000504000505000908000C0B030B0A03080602060401080702070802
0607010508010D110614180A181C0D1C20111E23141F23151E22131E22111D20101A1C0E
16170B12130A0D0F080B0C05090B05090C05090C04090C02060A01040700040500030500
040700050801040601040600070A01070A010509000204000203000303000403000A0B00
11110514140913130911120B
353A4C353950343953353A53353B51363C52383D53393E55393E563A4056394055393F56
3B42563B41533A41543D44553F45573F465A40485B40475D42495E434A5E444A5F444860
434861434961444B62444B62464C63454C64474E65474D64484E63494E634B4F644D5064
4E52654F54664E53664E54664D54664E56674F556750556851566A52586B51596A525A6A
535B6A555C6B575E6D585E70585E715961725A63725C64735D65735F6874606974626B76
626C77626C78636D79667079666F79676F7A68707B67717B6670786871776A74786A7479
6B767B6B777D6C787D6D797C6F7B7C737E7E747F8075807F73807D73807C73807E73817F
72817E74817D75827D74827B77837D78837E78837F75807E757F7D747F7C73817A50585A
201F2C1E2026191B1D1314140E0F0D0C0D09090B06070904070A03080C02050900030600
0204000203000404000505000405000808000A09010A0903080704050602090A050A0B03
0A0D02090C010A0C020E10051517091A1C0C1E20111F22132024121F220F1E220F1C1F0E
17180B12150B0E120A0B0E07090B05090C05080B03090C03090C04090D02080A00060900
060900070901060801050700080B00070A00030700010300030300040200040100070600
0D0D0411100612130814150C
343A4B34384C353A50363A51373B50393D503C3F533C3F563B3F57393E56393F543B4054
3D42543E42543F435442465742455A42465D444A60434A60434A60434A60434A60434862
444861444A61454B62444B62464C63474D65484E66454D65474E64484D624A4E624C5064
4E52664E53664D53664F55654F556650556750556852576953586A52586A52596A545C6C
545B6C555C6C585E6F5860725960725961735B63735C64735D66745E68745F6973616B74
616C74626D76646F7864707865717966727B67727A68737A68737A6973786973766B7477
6C76786C77796C78796F7A78707B79727E7D737E7D74807E74817D74817D74837D72817C
72827B72817B72817B74847C77847D78837E78827E76807D76817B7580797480795F6866
2626331E20281C2022181B1A1114120C0F0D0A0C09090C05080B01070A00050800040700
040700030500030400030400040600080901090A020A0C050A0C06090C06090D060B0D03
0D12030D12020B0D010A0C01101406161A091B1F0E1E220F1F25121E23111D21101C1F10
1A1D0F161B1012170C0F13090D0F070B0E050B0E040B0E040A0E020B10020C1101090D01
070B01080A02060801040500060800060900030600010400010200010200010100030400
090C040F110611140712150A
343B49363D4C383E4F383D53383E533A3F523C3F513B3F543A4057393F563B41553C4253
3D44533F4554414755434A5943495E43465F444762454964464C65464B64454B63464B63
474C63474D64484F66464E65474E65484F66485067464F674951674951644B51624E5264
4F52664E53664F556650576750566851566953596A53596B54596C535A6C545A6C545B6D
555B6D575E6E585F6F596070585F705961725C63735D66745D66745E6875606B74626C74
616B73616B73626D7564707864707965717B66727A69737A6B757C6C757B6B75786B7678
6C77786D79786C79766E7C76707D79717E7D727F7E73807D72807D74817D75837E73827D
75837E74837E74827E76847F77827E78837E78827D76817C75807B75807B77827C68726F
2D2E3A24252F2022271F2021191B1811120F0B0D08070802050800070A00060A00040700
040701030500030500040601050701090A020A0C040B0F050C10050D11080D11080C1007
0E13060E13070C1006090C030D110712170B181E101B21121E25131F25151C21131B1F12
1B1F12191F11171D10161C1013180C0F14080B10040B10050A0F040C11040D12030B1002
0B0E030C0D03080A00040500050500060700050700040600020300000200000100000200
0608020C0F050F130812170B
343B4A353B4D363C4F363D50363D51393F523A4052393F533A40553A42583C44583E4557
3F47563F4856404856424A59444B5E43485E444660464865484C69484C68464B65484C64
484D63494F67484F69484F694850684950674A51684951684A51664B51644C52644F5365
51546851546851556751576851566852596A535B6C545B6E53596E535A6D545A6E545B6F
555C6F565E70575F6E585F6E5960705C62745D62745E64755E67765F6977626B79626C78
636D7864707A636E7965707B65717B65727C67737D69747E6D767F6D767D69747B6A767B
6C797A6C7A796E7C796E7D796F7E7B707F7D72807E77848076827F778380798481778380
79848179848178848079848077827F7A83807A837F78817D77817C76827C77847C717B75
3B3D4526263024252A2426261E1F1D17181311120C0B0D06080B02080C00080C00090D03
0B0E05080A04050702040603050603080A040A0D050A0D040C11050B0F050C0F060D1208
0E130A0F140B0F130A0C0F070B0D0611150B181E111C22141F25152026171E24161D2215
1E22131A2013161C1013190D10160B0F15090C11070B10060B11070D12080D11050B1002
0B0E020D0E02090B00060900050800050700040700040600030400010200000100010100
0608020C0F050E120810140A
333B4C353C50363D51353C51383F52383F50383F52393F543A41573B425A3C435A3E455A
3E46583D44563F465741485941495B42495E444962474A67484C69484D68464C67474D66
484E67495067484F694950694A50694A50654C51654B51644D52654C51654D52654E5366
4F546751566851576750576651576751586952586A51586B535A6C555B6C555A6D555A6E
555C6F575F70586071595F705B61715D62725E62745D64755E6776606978626B7A636D7A
626C7A636E7B65707B66717C65707B65717B67737C6B767D6D767E6D757C6A737C6B757C
6C767B6B787A6D7A7B6E7B7B6F7C7B71807E727F7E768380778481788381798381798380
79837F7A84807A83807A838078837F7A837F7A837F7C84807B847E78837C76827A788479
4C4E4F24222C26252923242320221E1D1E1715151010110A0C0F06080B03090C030C0F07
0E110A0C0E09090B080708070606060809070A0C080A0C060A0D06090C040A0D040D1107
0E130A10150C10130A0D0E06080A020D1006161C0F1C22142027172027182025181E2317
1D22141B2113171D1013170C10150A0E13090C10070B0F060A0F060B0F06080C030A0D02
090C000A0B00070800050600040600050700040600030400020300010200010200000200
0305000A0C020D10060E1209
353D4E363F50364050373F50373F503940513841533940563B435A3B425B3D435B3E455A
3F46583F4756414959424A5A424A5C444B5E464C62484D65494E65474D64464E64474F63
484F614951624A52654B53674D53694D52684E53674E52664F52664E52664D53664E5567
505668505668505667515867515867525968525A6B53596B555B6C575C6D585D6E595E71
595F715961735B63745C63745E65745F66745E65755D66755F6777616A78636C79636C78
636E7964707966717A67737B67737A67737B69747C6A767B6A757B6C757B6D767D6E767D
6D777D6C787B6D7B7A717E7A72807B75807E727F7F73807E77837F7883807A85817A8482
7B83817B83807B83817B83807B85807A847F7B857F7A847E7A847E79837C76817978847B
545A59231F2824232721212221221F20221B191A1212130C0F110B0E110B0C10090C0F0A
0D100B0D0F0A0C0D08090A060808050908040A0A070A0B08090C07080A040709020A0E06
0F140A12170D11150B0E10060B0B010E1005161B0E1A21131E25151F26171E24161D2416
1E24161C2215181D1114180D10140A0D12080C10070B10060A0E05080B030709020B0D04
090B000A0C00080900050600040600050700060900040600020400020300010300000200
030400090A010C10040C0F06
3740513740523841543841533941533B44553C44583B445A3C435C3D445D3E475D3F475B
3F495A414A5A404959424B5B444E5D464E5F474D60484E62484E61474F61475061485161
4952614952614A51634D52684E526C4F536D4F546C50546A5055695056694F5468505769
515869505666505765525967525A68535A6A555D6E575E6F585E6F575D6F5960705B6272
5D62735C63755C65765D65765E66735F69745E67755F6875606878626B78646D7965707A
65717966737867747867747868757869757A6A757B6B757C6D777E6D777D6E797D6F797E
6F7B7F707D7E707E7A72807873807A75817D74817E76837F7985807A84807B84817D8784
7E87857D85837E85837D85827C86817B857F7B867E7A857D7B867D7B867E79847B7A887E
606B6523212B2323282324262124221F231D1B1E1616181013140E11130D0F120C0E100A
0D0F080E0F080D0D05090B04080800090A020A0A040A0A06090A07070907060805090C08
0F140C12170E12160C0E10060A09010F0F0517190D1B20121D24161F2617212719202619
1F25191E25181A2015151A0F10150B0D11090B0E070A0D05080B03080A03070802080A02
070900080900060700040600040600040700050800060800040600030400020300000200
0507000C0D020E10040C0E05
373E52373F553840573941573941553A42563A42573C435A3E445D3F455E40485F404960
414A60434D60434D5F444E5E475060464F60474E60484F61485262485161485161485261
4B54644C55664D546750556A4F536C4F546E4F546D4F546C4F556A51576A505669505669
51586A515A6B535B6B555D6B545C6C555C6D575F6E575D6E585D6F585E70596172596272
5C63745D65765D66775E67785D66765D66745E67755F6875626A77646B7A646C7A646E7B
65717B6671796773796875786A767A6A757B6B747B6D767C6E767D6F787C6F797B727B7F
727D80717E7E73807E75817E74827E75817F7782807884817A85817A85807C86827D8783
7D86847C85827D85807F87837F89837F88817F89817F89807D887E7D877D78847B7A877C
6C786F2E2E36292A2F292E2C2229241A1F19161B1413140E12130D12120C11110A100F09
0F0E060F0F050B0B01080B01060900080B00080A02090C050A0C06090B07080A070B0E0A
10150C10140C0F13090F10060A0A010A09011618091D211220261721271822261921261A
1F25191E25191A201413190D0F13080C10060B0E050A0D050A0C04080A03070903070903
040600030500010300020400020500040600050700050700030500020500010300020200
0505000B0B021011060F1007
373D54383F563B42593A42593A42583C44563A41553C435840455D40465F404761414963
434C62454E63444E62454E61464F61464E61484F624A5164495364475062485162495162
4951644B53664E55684F546B4F536C4F536E4E546D4F556E4F566D50566A505769515769
52596C535B6E545C6E565E6F565D6E585D70595E72585D70595D705A5E725A60755A6175
5C64765D65775D66765F68765F67765F67755F6976606976626A78646B7C646C7D666F7E
67717D67717D69737D6A757D6A767D6A757C6C757B70777E71787F70787F707A80717C82
727D82737D80747F807782817682817782817982827A84837B85837A84827C86847C8684
7C86847D87847D86827E88837F8983808A837F8A837F89817E887F7E897E7B867C78847B
778478383A3E27282D2C312D2126201619151114100E110C0E100A0E100A0E10090D0F07
0B0C030A0C020A0C00080B00080C020B0E03090C030A0D040A0C04080B030709030B0C06
0E11081012070E10040C0D020908000908011518091C22131F25182027192026191F2418
1E24171E2416191E1112160B0D11060B0E040B0E040A0D040A0C04070A03060902070902
030500010300000200000100010200020300030500040600030400010300010200030300
0909020D0E05101108101209
3940523A41553B42583D435A3E455B3F465C3F465B3F465C41475D414860424A63414963
424A64444D64444D62444E61464F624851624952644C53654B5265495165485265495267
4953664C55694F566D50556F50546F505570515772525873535972535A70545B6D535A6C
535B6C555C6E575F70585F6F565D6F595F725B60755A60745A61735C61745D62765D6377
5F66785E66765D66755F6975616B76606A76626C78636D79646C7A676E7E687181687280
67717E68737E6A757F6B757E6C767F6E787F707A80727B83727B83737E84727D84727E85
727D83767F827780817881827882827982827983827B85847C85847C85857C86857E8887
7F8A877F8A857F89847F8A84808A84818B83808B82828C83828C83818B817E887E7C877D
7C897D45484B25242B292C2B242722191B171112110F0F0B0E0E090F0F090F10080D0E06
0A0B04090B04080A02070901090B030B0E050B0E060B0E05090B04070A02090B040B0D05
0B0E040B0E020A0D010A0C01090A000C0F03181C0D1D23142027172028192027191F2417
2024161F25161B1F1313170C0F12080B0F050B0E040A0C03080A02060903050701050800
020500020300020300020300010300010300030400050600040500020300010100030401
0C0F0510140A12170C10140B
3B43523C43553E445A40455C41455F41466041485F41495E414A5F434B5F434C62434C63
434C62424C5F434D5F454E5F4850614B53644C54654D54664C53664A53664B55694A546A
4B556B4C566C4F586F525970525972525870525A71525971535A72555C72555C71555C70
565E6F575E70596172586071575E705961745A62735961735A63735D65745E66755F6676
6066775F68775F6976606A76626D76626D77636D77646F7B656E7D68707F697183697283
6A74836C76826C77806D777E6E787F707980707B82707C83727E84747E83747E82747E83
757E837881827982827A83827A84837B84837C86847D87857E88877E88877D88877F8989
7F8B88808B877F89857F8A867F8A85808A85818B84838E86848E86838C84808A807D877D
808C7E54585727242D282A2D2629271D1F1C1515120F0F0B0C0D070D0E060E0F060C0C04
0A09030A08040A0904090902080A020A0C040C0E050B0D060A0D06080B050A0C060A0C06
090A04070A03090B030A0D030A0D01101206191D101F2317212618232819222719212518
2023161F24151B201215190D1014090E12070C10060B0D050A0C05080A04050802030500
010400020400020400030300000200010300040600050600030500030400020300030400
0E110814190D151A0E12160E
3B42533C43563F465A40475C41465D41475E41495F3F475F414860434C61444D62444D63
464F6247516248515F4A515F4D53624E54654E54664E55674D56684C55674C55684D566B
4E576B4F586C515A6C535C6E535B6F535B6F555C70555B70555B70555B6F565B70555C72
565D72565D72565E71575F715960725961725A61715A62715B63725C65745E6576606676
626778626878636B79626B78646E78656F7A656D7A666E7D6A707F6B70816C72846C7386
6F76876E75856F78836F79816E797E6F797F717B81727C82737E82767F83767F82767F84
767F867781847881847B85847B85847D87857F89877F89877F8A89808A897E8989808B8C
818D8B828C89838C88838C88838D89818C87818C86818C85848F85858E84838C817F887E
818C7F5E635E27242E28292E2427251B1F1A14171110130A0D10070C0F060D11070B0E05
0B0C04090803080703080A03090B03090B030A0C030A0C050A0D050A0D050A0D05090C06
080B06070A05080B03090C03080A020C0E05161B101D2216212619242819232719222518
2024162025151D2214191E1015190C0F14080C11060B0E040B0E050A0C05070903040601
030500020400030400040400020300030400040600040700020400020400020200030301
0F120914180E161A12151913
3C43533D45563F475941495C41485C434A5E42495F414863424963444C63464F63454F63
4750634A53634A53624D53624F55654F56665056684F57694F58694E58694F586950586A
51586B52596B535B6C545B6D545B6E555D6F555C6E565C6E575D6F5B5F715A5E72585E74
575E74565E72555E71575F705860705A62725C64735D65745E66755F6677616779626877
646979646A7A666C7B656C7B666E7B666F7B676F7C69707E6C71806C73836C72836D7585
717886707884717984727983727A80727B80747C80757D82777E83787F84777F85788189
78818A7982897B83897D86887C86857E87867F89877F8987808A88818B89808A8A838D8D
848E8D858E8C848D89848E88858E89848E89838D86838E84848F83848E83828C81818A7F
818C7E6870682F2C342F3032282A291D221E14191311160B0F12090C0F070B0E070A0D07
0B0D080B0D080B0D080A0D050A0D040A0D040A0D040B0E050B0D050B0E060B0F06090D05
080C05070B03080C03090E030A0D030B0F0512160C1A1E111F241623271824281923271A
2226172227162126161E2214181C0F13170A0E13070C10050B0E030A0D03090C02090A01
060800050500060500070600050500040300030300020400020400010200000100040502
13170B151B0E171C11151810
3B43533D465640495A41485B40475D41485E424A61424963434C65454E65475064485264
4952654A53654C54664D54654E57674E57674F58694F586A4F596A4F5A69515B69535B6A
535C6B545B6C555C6D565D6E565D6F565E70555B6F565C70575D705A5F725A5F72595E73
5960765962755963735961705A62705B64725D66745F6776616A77616B78616A78626B78
636B78656D79666E79656E7A666F7B66707C67717C68717C6B737F6E74826C74816D7781
707984737C85727B83747B82757C81757E80767E80777F817981847A8186798188788189
79818A7A838A7B848A7D868A7F8888818A88818B89818C88828C89838D8A838D8B838D8B
858F8D868F8C868F8B87918B87908A868F89868E87859085848F84838E82858F83838D81
828E80727B7137363C343639333736222423181A181316110E120B0C0F0A0B0D09080A08
0A0C090B0E0A0C0F090A0C05090B020B0D030D0E030D0F030D0E040B0D050A0E05090E04
0A0F040B10040E14040E1405111707101507101407171A0D1D2214212718222818222618
2126162025152128181F25171B2013161B0F11140A0D11060A0E02080C00090C000B0B01
090901070600070600080700060500040300030300020300020200010100000200020401
0D110613190B181D0F181C0D
3C45533E4856404959424A5E434B60434C60434C61444D61444E62465163475264495466
4A54664B56674E57694D57694E586B4E5A6B4E5A6A4F5A6A4F5A6A505A6B4F5A6A515B6A
525C6A535C6A535D6B565E6D575E6E585E70595F71595F72595F72596072595F72585E73
5960775A62765A63745A63715B63705D65715E6673606876616A77626A77626B78636A79
636A79656C7A666F7B666E7C67707D68717E69737E69747E6D757F6E757F6C757F6D7781
707A83737C85747C85757D85777E85787F857880847A82867B82877C838A7B828B7A828C
7B838D7C848B7C85897F8789818989828A89838C8A838D8A848F8B848E8B848E8B86908D
868F8D868D8B868E8B89908D89908C878F8B878F8A879089859188859085869184849083
8591817985783E3F4336393C353A381F2223191B1A1215130E110D0C0E0B0B0D0A090A09
0A0C090A0D090B0D060A0C030A0D020D0E020E0E030E0E020D0E010C0C010D0D020E1005
1115081117081016061015061015060F12040E0F0314150A1F21142327182227181F2516
1E25141D24132027151F26161B2214191D1014170B0F13080C10030B0F010A0E000B0D01
0A0C01090A00090800090900070800050600030400040500030400040300010200010300
0D0F0615180C181E0F181B0C
3E4753404958414B5A424B5E434B5F444D60444D60444E614650634852654853664A5568
4C57694D57694D58694E596C4F5A6C505C6C505C6B505A6A4F5A6B515C6E505B6E505B6C
525D6D535E6D54606E56606F576070585F70585F71585F725A62725961725A61745A6075
5B62775B63785B63775C64755D66755E6774606875606A76626B77616A78646D7A656C7A
646C7A636C7A666F7B67707C6A727D6B747D6B747C6C757B6E777C6E777D6E767F707782
717984737B87747C86747E85767F87767E88777F8879818A7A828B7B838D7B828D7B838D
7C858C7D878B7D878B80898C828B8E828C8E858E8F848D8E848E8F868F8F869090879191
86909086909186908F88918F88928D88938D88938C88938B87928C869389859187839085
8391847C8D7D3B3F422C2F332A2D2B1C1E1C1316120E110C0C0F090A0C070A0C07090B06
080A050A0D050A0C030C0E030E10020E0F020E0E020D0C020E0E010D0D020F0E03121206
1113090E11070B0E03090B01090B010B0B010E0E0317180C1E2013222516222517202416
1F24162024152226162026171B2213191F11161C0F11160A0E13060C11030C0F020C0F01
0A0C010B0D010B0C000A0C000A0C01080B01060900060800050700030400000200010200
0B0C0513150A15180C15170A
404755424A5B444D5F454E60454D61464E61464F614650624851644954654A55664C5668
4E596A4F596A515C6D515C6E515C6D515C6B505C6A515C6A525C6A535E6D535E70535F70
556172546071556070576171586272575F735961755B64745B64735B64745B64755B6475
5C65765D64765D64775C65775D6778606A78626C78626C78636C79636C7B656E7D666E7C
656F7C65717D67727C69737C6C757E6D757E6E767E70777E70797F727B82727A84727A83
737A84737B85747D87747E8676808878818977808978828A7A848B7B868B7B868B7B868B
7D888C7E8A8C7E8A8C818C8E838E90838D90869092858F92869091889191889292869192
86929388949387939187938F89958E8A968C89958A8A978B8A978C88958A869489849388
8494868091824248482325292023231518160F120D0D0F080C0E05080A01080A02090D03
090B010A0C020B0E020D10040E12051012041212061112061110050F0F040F1006101007
0F10080C0E07090B04070902090B030C0D0411120717190D1D2113212616232718222617
21251821261724291A252B1C2027191E24161B2214181F11151C0E141A0C151A0B111507
0E13050F12050E12040E12061116090F14070E13050D1204090D01050800020500020400
090B0312140715180B17180C
434A59444C5F464E63485066484F654951654751644953664B56674C58664D5967505B6A
535C6C535D6D545E6F535D6F535E6E535E6F535E6E545F6F555E6E555E6E565F71566173
5660755660735860735962735A62745A62745C63765D65775B64745B64735D66735C6573
5C65745E66765F66775E66795E677B606A7A626B78636C79636B79656B7D676D80686F81
6770816871816972816C74806E7580717881717781717883737A84747D85747C85747B84
767C85767C86767E89767E8879828A79848A78838979848A7B868B7E898C7D8A8B7D8A8C
808C8F818C8E808C8C828E8E848F8F85908F889491879290889290899291889290879292
8895928895918A95918A95908B96908A968E8A968C8B988D89978B899689899689879589
8696888698864F595326292A1D201E1417140F120C0C0E080A0C04090B020B0D040B0E04
0C0F040D0E040D0E040C0F050E11061014081112081213081113080E11070E11070D0F06
0B0D050B0E060A0D060A0D050B0D040D100410140714180B1B2012212716232817222817
212617232818232A19242C1A232A192027171D24161D24151D25141E25141E2413181D0E
14180912160812170A10160B14190E151B0E171C0F191E0F1115080B0C03060700040400
07070111130817180D181A0E
454C5D464E614852654953684952684B55694852654853664C58694D5A6A4F5B6A525D6D
545E6F555F6F566071546072546171556271556272556072566074576074586174576174
5560755760755A63765B64765C64755D64755E66765E67765C64735C65725B65705D6671
5F68745F68785F677B5F687D606B7E606C7C626D7B636E7A656F7C666E7F687082697184
6971826972816B74826C74826E7583707885717985727987727988757D88757D88767D88
767D88797F8B797F8E77808E78828D79858E79868C79858C7A878E7D8A917D8B907E8D91
808C90828D91828F918291938492938692928996948A95938995938A96938B97958B9696
8B96958A95958C96958F99958F99938E99928D9A928C9A908D9A8E8D9A8C8D9A8C8B988A
8897888A9B88606B612C2E301F2122171A191114120D110C0B0E070A0D040F11080F120B
10130C11130A1011081011081012080E11070E11071012071113080F12080E11080E1108
0C0F060B0E060B0E050B0E040D1204101405111607181D0E1D2213222716232817242917
2328182428172328162329172229162228162026141E26141F27151F28151F27151D2314
1C21121A1F11181E11171D0F191F0F1B21111E22132327171A1B0F1212090D0D050A0803
0707030D0F0813160C161A0F
464D614851654954694955694953684955684956684A56694B57694E5B6B515D6E525D6F
545F71566171566272556272556371566372556370556272566275556275566274566274
5561735762745864745A64735B65735C66745C66735C67715A656F5C68705C67705F6973
606A765F69785E68795F6A7C616C7F646F7F656F7E65707F65707E656E7F677182687385
6972846B74846C75866E76876F77886F78896F7A89707B89707B88727D88727D89757E8A
77808B777F8C77808F7882917783917985927986907A88907A87907C88917E8B927F8D92
808C92818E938290948191958392958593948794948895968996968B98968A97968A9696
8C98978C98978C97958D98948D99928E9A928D9A928D9C918C9A8E8C9A8C8C9B8D8C9A8B
8A98888B9A886E7B6E31343726282A1C20211618191213130F110C0D0F0716190F191C14
16191412151010130B0F12090E11080D10070D10061013061113061013070E12070E1208
0D12060B0F040B10030C1103111706141A09141909161A0B1A1E0F1E2212202515212717
2128172128162228162429172229182128152026142026151F26151E26131F27131E2614
222A172229161E25141E26121E25111E2310202514282D1C2225171B1C1213140C0E0D08
090B080B0D090E130A10150A
444D624650664752684955684955684A56684A56694A57694A58694D596B515D6E535F6F
546071556170566271556170556271576472576571586573576475576476566375566375
5763745863735963745A65755A65765A657559657459667258676F5A68705D68725F6975
5F68765E68785E6A7B5E6A7C606B7D626D7C636E7C666E80666F80666E806871836A7285
6A71846A73846C76866D76866E77876F798A6F7A8B707B8A707B87717E87727E88747E8A
76808C76808D77808F7881917884937986947986937B87927D89927E89907E8990808B92
828D93818F948292958393958494948694938794938895948B97968C98988A96978C9896
8B98958C9A968C9A958C99938C9A928C9A908D9A8F8C9A8E8C9A8E8E9C908F9D8E8F9B8C
8C99898D9B8A79867A3D41453033372327291D2022191B1C14161416181247523E252B22
1114121115120E120C0C0F080B0D060C0D060D0E050F11060E10060E11070D11070C1007
0B0F04090E020A10010F1606141B0A171D0C171C0C13160914160A1A1C0F1E23141F2617
1F26171F26162026172228192329192128162027152026142127162026172027141F2713
232B16242C18222A172028161F27131E26111E2412262D1B262B1B2025171B1E1214160C
0E110A0E120A0C1208090D04
444D614750664853694954694B566A4C56694B56684C57684D58684F5969535D6C55606F
556171546170566472576572566371566372566372576475576376576376576276566276
5864765964765863765A64795B647A5A647A5A657A5965795966775966745B66775D6777
5D67785E687A606A7C5F6A7C5F6B7C606D7C636F7E656E81677183687083697183697281
6972806A74826B75846D76856F788770798B707A8D707B8C727D8B73818975838B76828C
75808E76818F7682917884937885947A87947B88947B87927F8B91808B8F7F8B8F818D91
848F938491938593938794958794938995958995968996968C98988E999B8D999A8E9A98
8D99978D9B978E9C978E9C948F9C93909D93919D91909C91909D92929F92919D8F919D90
8E9C8F8C9B8C8290834B4F52383B402C2F33272B2C2528271C1F1E191C194A5843222A21
11151113171310140F0D110A0C0E090C0D060C0E040D10050D11060D11060C10050D1007
0B0E060A0D050A0E0312180A171D0F191E10151B0D0F140811140A171B101C21151F2518
2025192227192126182227192328192228172128162128162228162026172026161F2515
232A19252D1C222A1B1F27181E26161F28141E26112229142229171F27161E2615192011
13170C1013090D1107090D04
494F5E4B52644C556A4C566C4B556B4B556A4C56694C57674D5865515B68555E6C586270
566271556271566473586675576673566372566373586475596575586575576376576277
57637958647A58657A5A647A5B647B5B647C5B647D5C657D5C677C5D687A5E697C5E697B
5E697A5E6A7B606A7D5F697D626C7F626E81636F82647083667184677284687383687380
6B76806D77826E78856F79866F7A88717C8C717D8E737E8E737F8D74818B76838C77838D
7883917882937781947886957987947987927B89927C8A927E8C91808E91808D91818E92
848F938490938491938692948995958A96978B97998C999B8D999C8E999B8C999A8E9A9A
8F9C9A909D9A909E99909E96919E93929E91929E90919E90939F92939F92929E92919F92
909D908F9C8E8A9788585D5D3A3A4136363C2D2F322C3030262A291A1E1C20251F20261D
1C2319161A1211150C0E130B0D110B0C0F070A0D030B0F030C10040C11050B10040D1106
0C10060A0C05090B040D110714180C181C10181C1113160D10130C161A111B21151F2517
2126192128192027181F2617202717212817202716232918252A182329182126171E2417
22291B262E1E232C1B1F28181F2717202717202716242B172229172027172127181B2113
11160B0F13060D10030A0D02
4A525B4D54604F57684D566B4C566D4B566C4A55694B57684C5867505B69515D6B545F6D
55617054607156627557657957657A566479576578586577586577586578586477596578
59637959637A5964785B65765C66765C66795C657B5D667D5D667C5F677C5F687B60697A
60697A616A7B61697D626B7F636D81626D82636F83646F836570836772826973836A7481
6C76806E79826F7A82707B84717C87727C8B737D8D747E8E747D8E75808D76808E77818F
7A83937B84967984967986967B88957B88947C89947F8C95828E96838F95838E95828E94
8590968591958491948793968895978A97988B98998D999A8C989B8C99998C98988E9A99
8F9C9A919E9A929F9A919E99919D95929C92929E92939F9294A09393A09493A094919F91
8F9D8F8F9D8E8F9C8C6367633A363F39373F3030352D2F322C2F2D2024231C1F1D1C1F1B
1D221A191D1415181010130B1012090E10060B0F030C10030C10030B10030A0E030C1006
0B0F06090C040A0D040F120814190C181B0F1A1D11171A1011130D1518101E221623281A
2328192329192128181F27151F28162029162128152229182128182027171F26171F2517
22291B252C1C212A191F27161F25141F25161F24151F22151E22141E23142025161A2112
10150A0F14060D1103080A01
454E584A525E4E57674E566A4C566A4C576B4B576A4D5A6A4E596A4F596B505A6C535E6F
54617154607155617756627A57647D57657C58657B57637A56637957647A586578596578
5A65785B64795B63785C65755B66755C66775C66795C677A5E677B5E677B60697C626B7B
626B7C626A7E616A7F646D82646D82636E836470846772856872856973836B75836B7582
6C77816D78816C77816F7A85727C8A747C8D747D90757E92768092788193788093798295
7C84977C84987B84977C87977C87967D88967E8896808A97828C96828D95838F96849097
8691978793968794978995988996988A97988C98998E9B9B8D9A9A8D99998E9A9B8E9C9B
8E9C998F9C99909D99929D99939E98959F97949F9794A19693A09592A096929F94919E92
909F90909E8D909F8B717A6E4343453F3F433130362C2E312B2E2B2225221E1F1C20221E
2328201F251B191F1414160C1112080F10060C0E040C0F030C10030B10030C10040C1008
0C10080D10080F120911150B14180D16190E16190D14170C11130A16170D22261825291B
24291A232819212818202817202816212A17212916222A172028171E26161E26171F2618
20281A21291B1F27181D23131A2110191F0F181D0F171B0F15180D15180D151A0E151A0E
12160C0E12080B0F04070B01
464F594953604D5867505B6B505A6C4E596C4B576B4E596D4F5B6E525D70525E70536070
526070536171546273556274566477576578566578576578586577586678596679586578
5A657A5D667C5E667D5D657A5D66795D66785F68785F6979606B7B60697B60697D626A7E
636C7F636C80606A81636D84656F856571876772876973866A73856A73846D77856D7785
6D78866F79886F798A707A8C737C8E747D91757E94767F94757F94767F937881937A8294
7B83967C85957D85977F889880899A80899A818A98818C98838D98858E98859099869099
86919988949989969B8A96988A97998B98998D9A9B8F9D9D8E9D9D8E9D9D8E9C9D8E9D9D
909E9C909E9A919F9A939F9C949F9B95A09A95A09894A19892A09892A09790A095909F93
90A09191A08D93A38D798576494C4B4649473132342B2E2E2B302A252B2421251D262A20
272D2220261B171B1112150A1012071011060F11070D11060E13050D12040D12050E1308
0D110A0F130B12160C12160B13170B12160B12170A11160A1014091215091E2111222717
252919242A19252A19242A19222A19242B1A222918242A162429172127171F25181E2518
1C24171B22151A2113171D10141A0C12180A1115090F13090E11080D10080D12080F1409
11140B11130A0D1007080B03
47525E4955624C58684E596A4F5B6C4E5A6D4D586E4D596F4E5A70515D72505C72505C70
515E705261725160705462715563725664735866755967745A67745A66745B67775A6677
5A66795B667B5D667C5D667C5D677C5C677C5C677C5E6A7C5F6B7C616B7D616A7D616A7E
656E81646D83636C85646D85656F866672876872876872856B74856D77876F78886F7788
6F788971798B717A8D717A8D727B8F747D91767F92768093757E927780917882907A8491
7D85937E86957E8696818998818A99828A9A838A99848C99848E9987909A888F9A89919C
88929C88939D89949C8B959A8B979A8C999B8E9D9F8E9E9F8E9E9E8D9E9D8D9D9D8E9E9E
92A09F93A19E93A09D929F9C939F9C94A09D94A09B93A098919F9793A19992A29790A192
91A29190A18F92A2907F8D7E5155534D524E3233352A2C2C292C2A272B2623272021261E
24292022261F1D1F1818191014170C1213091213081012060C11040B10030C11040D1106
0D10080E11090F120A0F12090F130912160C14190D12170B1014091215091B1E0F222616
242818252A18262C17242B16242B17272D19242B182228162227152024151D2013191D12
161C10151B0F151A0E13180B10140910140A0F120A0D11090B0F090B0F080B0E070C0F07
0D11080E11080D1007090C04
4853604B57644D5A6A4E5A6C4E5A6D4E5B6E4E5C704E5A704F5B70505C71505C71515C70
505C6F526071525F705462715764725865735A67755966745966735C67745D68765C6777
5A66795A66795A667A5B667B5E687C5E687D5E687C5E6A7C5E6B7C5F6B7C626B7C636C7D
656F81646E82646F84646E856470866471876572876873866A73866C76886F7789707789
70798A71798A70798A717B8C737D8E757F907681917781917680917780917882917C8493
7D85937E86947F8895808A96808995828B97848C99838B99858D99868F99868F9889929B
89939C88939B89949A8B969B8D989D8E999E8E9B9F8D9B9E8E9C9E8E9D9D919F9E929F9E
93A09E95A09F94A09D939F9B939F9C94A09E94A19E929F9A919F9892A19991A19891A196
91A194909F9291A191808D81505452545D54323634262928252725242725232624242825
282F282B302823261E191B1414150F1010080F10050F10050D0E040B0E020C11030D1104
0E12070C0F0A0A0C090B0D090D100B11150F13181012170F0E130B0E1309171B0E1F2415
232818252A18252C16232B14242B15232C172129171E26161F26161F23151A1C1015180D
13170C13180B1116090E12060D10060E120910140D0C0F0C0A0D090A0D070A0C050A0D05
090C04090C030A0E04080B03
47535D4A56614C59684E5A6C4E5A6D4D5A6E4D5B6F4E5B704F5A71505C71525D71525D6F
535F6F53617053606F55636F5866725866745966755865765A65775C66795C66795B6679
5A677B5B677C59667B5A667A5D687B5F687D60697E626C80636E82646F82646E80656E81
646F82636F826270826370846471846470846672846873846A74846E76866F7788727A8B
727B8B707A8B707A8C727D8D737D8E777F9079819079818F7881907A83927B84937D8694
7E87957F8895808995818A96818A95818B95838D98848E9986909B86909A869099879199
88929A88949B8A969B8B979C8C979D8E999F8E999E8E9A9F909C9F909D9F93A0A094A1A0
94A09E95A09D96A29D96A39E96A29E96A29F95A29F929F9C93A09A94A29A95A39996A398
94A39692A29493A2928999864C504B4E564C393E39282A2A2527262B2E2B272A29272B2A
2B322C2B312823271F1B1D1815171110110A0D0F070E10070C0F040B0F040C10040C1004
0C10060B0E080A0D090A0D080E140B141A0F141B1112190F0E140A0D1309151B0F1C2315
212919232B19232B16242B15252C16242C17232B182129182028171C2213171C1014190D
10150B10150A0F14080D11080C0F060D11070E13090C0F090A0D06080C04070A01080B01
060A00050A00070C00070B00
47535C4956604C59654D5A6A4E5A6C4E5A6E4D5A6E4E5A714E5A734F5B74515C73515C71
536071556272535F6F54606F5663715865735865745764755864775A657A5C657B5B667A
5A657B5B667C5A667B5A657A5D667B5E677D616A7F636B80656D82656D81646D80646D80
656F82656F83636F83636F826472826471816773816974826B7682707A85727A87737A89
727B8B707A8C717C8F727D90737E90757F9077808F78818E7A84907D86927E85927C8492
7E8795808996818B97818B96818C96828C97838C99848E9A848F9B858F9B86919C87919C
87929B89949B8B979D8D989D8F9A9D919C9F919B9E939DA0939DA2929DA2929EA3939FA4
959FA196A0A1949FA095A1A095A2A097A3A097A3A094A19D95A19C96A19B96A29997A396
96A39494A29293A19092A38D575C5637393A3C413E303332282A2B2B2E2B292C2A242727
242926202521191E1A1518141418140F130F0E110B0E11090D11070D10060C10050D1107
0C10060C10070C10080B10080D130811180B131B0D12190B0F14080C1007181E111F2717
222A19242C1A252C1A262C19272D19242B17242C18222B171E27131A2210161D0F141A0D
0F14090C10080B10070C10080C10070C10060D11060B0E050A0D04080B02050800060900
040700020700020600010400
46515C4955604C59664C596A4E5A6D4E5A6E4D5A6E4E5B704F5B71515D73525D73515C71
525E71545F71545F7054606E56636F5663705764725865725864745A65795C667B5C657B
5C647A5C65785D66785D66785E677961697C616A7D61697C626C7D636D7D636C7C636C7C
646D7D646E7E656F816570836571836572806875806975816C77826F7A83727E87747D89
737C8B717C8B727D8D74808F75809075809077819077818E7A838F7D85917F8694808695
818796828B98828B98828B98828C97828C97838D99848E99858F9986909A87919B88929D
88939C8B959C8D979B919A9D919A9D919A9F939DA1939FA3949FA4949EA4949EA4949EA4
959EA397A0A3969FA2969FA297A2A297A2A096A29E97A39C97A39C97A39B96A29897A395
95A29394A29293A19095A5916770693130363C413F3537362C2D2C2B2E2B2A2D2B292B2B
282B2A1E2122181C1D14161413151011140C0E13090E13070D12040D10020C10020C0F02
0C0F030C10050D12070C11080B10070C12070E13080E12070C10050C1005192012212919
222B1A252E1C262D1C262C1B242919222918222A162029141C2411192010161D10151C0E
10160C0C11080A0F060C11080B10070B0F040B0F030A0D03070A02060801040700050800
040700030700010500000300
46515C4953624C57684B576C4D59704F5A714E5A704F5C72505D73525E72525D71535E71
555F73576374566172555F705762715863725763725865735865735B66765B66795C6679
5D667A5E67785F68776069785F6879616A7C626A7D616A7D636C7E646E7E646F7D646E7D
666F7E67707F6871806771836872846973826A75816C77836E7884707A86737D88747E88
757E89757E8976808E767F9078819078818F7882907883917A85927C85947D86967F8898
81889983899A838A99848C99848C99858D99868E9B878F9C88919D87929D88929C89949D
89949C8B979A8E999A919C9C919B9D919A9F929DA2919DA3939FA495A0A595A0A4969FA3
96A0A398A1A297A1A197A19F97A29F97A39E98A49D98A49C97A49B97A49B96A49996A398
96A39796A39694A39495A6956D786F3133383C4240383C3A3032313134322F32302F3430
2F34301C1F201B1D1D16181511110C1011080D10050C11030B10010C0F010D10030C0F04
0C0F060C0F080D120B0E120C0D120A0C11070C10070D11060D12051116081D2412232B18
252D1C252D1D252D1E242C1E222A1C232B1B222A181E26131A220F161D0E141B0E131A0E
12190E0F160D0D12090D13090C11070B0E040A0D040B0D04080A02050600030500060700
040700030600020500010300
49535F4B56664C576A4C586D4E5A70505C71505B72515C74515C74515D74525D74545D74
555E765760765661755861755962755862735A63755A64755A65765A66775A66775C6778
5E68795F6878606A79616B7A606A7B616A7E616B7E616C7F656F81646E7F666F7F677081
6972826971806872836972846973846A74846D76876F7989717A88717A87737D8A757F8A
757F8877818B78808F797F917A81927B82917B83917B84917C85937E86957F8899808999
838A9A848A9C848B9C848C9C848C9B858C9B888F9E89909F8A91A08A93A08C94A08B959D
8C979D8D979A8E999A929C9B939D9E959EA0949EA2929DA194A0A296A1A397A2A399A3A2
98A2A298A2A198A2A097A29E98A39E99A49E99A4A09AA4A099A49D99A49E99A49C97A39A
97A29997A39797A59498A895768277393B414148463C413E363A37393F38353A332E322B
3338301E1F1D1C1D1917181311130C0F12090E11060C10030C10020D11040D11060D1108
0E120C0E120D0D110C0E120C0F140B0E12080D11070E13060E13051217071C2411232B17
28301D28301F272E20252C20252D20222B1D21291A1E25161A2112151C0E12190C12180C
131A0E11180D0E140A0C11080C10070A0D04090C040A0C04080902060701060500060400
030400020500010400010300
49565F4C59644D59694F5A6E4E596F4F5A70505A70515C72525C72545E73556075545E75
545D76565E77575E775961775963765762745862745862755863755965775965785C6779
5D67795F6978606A795F697A606A7B606A7D616C7E626C7F656E82666F81677081687083
6971846972846972846872826A74836C76846F7987707A87717B89727C89727D8B727D8B
737E8A75808C777F8D7A80907C82907D84917D84917E86927D8691808995808998818A98
81899982899A818A9C838D9E838C9E838C9E868E9E89909D8A929D8B939C8C959D8D959C
8E979C8F999C90999C939C9E949D9F959E9F959E9F949D9E969FA096A0A097A2A297A2A2
97A2A198A2A098A3A099A4A199A4A099A49E9AA49F9AA49E99A39C9AA49B9CA79C9AA499
98A29798A39698A59297A7918391813F4346444A483A3F3D333732343A32343A302D3028
2E32291D1E191B1C1616171111130A0E11070E11050C10040C10030B10040B0E050C0F08
0D100C0E100C0C0D0A0D0F0A0E11090E13090D11050B10020B0E010C10031E2611232B16
272F1A272F1C252E1E242D1F262E20232B1D21291C1E2719192013141C1012190D0F150B
0F150C0D130B0D130A0B0F06080B03080A01080A01070901050600060700060700060600
030400010400010300000200
4A585C4E5B63505C6B505B6E505A70505A72515C73535D72535E70565F70565F71565F72
556074556075565F7758627957637956627855617557627757637758657958647A5B677C
5D697C5D69785E6B795E6B7B5D6A7B5E6B7C626E7E626D7F646D80677082687183677083
6871836972856972856A74856B75836D77826F79826F7A84717B87717C87717D89717D8A
727E8A737E8C76808F7981917B83917C84927C84917D868F7C878E7E8991808996808A99
808B9C818B9D808A9D828B9E848D9F858E9F86909D88929A8B959A8C95998B96998B9598
8E989C8F9A9C8E989A909B9D919D9E929E9E939E9D949E9D969F9F95A09F96A1A296A2A2
96A2A197A2A098A3A09BA6A19BA7A19BA6A09AA59F9AA59D99A59B98A39899A49899A497
98A49697A39698A49497A6928B9A88484B4C404544383D3B2D302D2A2D262B2F26292B23
2C2F251F211A1A1C1415180F11130A0F12070F11040E11040C10050B0E050A0D060B0E09
0D0F0C0E100D0E100B0F100C0E120B10150B1015070E14050E12040C0F031C230F232A16
262B18272E1A262E1D262E1F252E1F252E1F222C1D1E2618181F14131A1011180C10160C
0D12090C10070C1006090E04080C02080B00090C00080A00060800060800060800060801
040600030400010300010100
4A585D4D5A634F5B6A505B6F505A72505B74515B74525D72545F7055606F56616F55606F
5460715561725662765560775562795562775562755664765966795A667B5B677D5B687D
5D6A7B5C6A775E6C785E6A795E6A795F6B7A62707C62717D64717D687380687382687284
6872846871856974866975856974836D7883707984707986707B87727E89727E88737F89
75818C767F8D7981927B82947D84937D86947D85937D86927D87917D87917F89957F8997
7F8B9A818C9C818C9D838C9D848D9D878F9F89929F89939F8B949D8B959C8C969B8B969C
8C989D8D999E8D999D8E9B9D919F9F919FA093A1A094A19F95A2A095A1A293A0A295A2A3
96A4A298A5A299A6A29AA6A29BA7A19BA5A19CA7A39CA8A19BA69E9AA59C9AA69A9AA699
9AA79897A39698A39598A49495A491535756393A3E393D3D2B2D2D252924262A22232620
23261F20231C1C1F17181B1215180F16170D15170B1315090E12070C10070C10080C0F0A
0E110D0F130D10130D11130D12160F12170F11160B1015091115081114051417071D2010
202513242A17272F1B272F1D272F1E252F1E242E1D212B1B1C2416181F12141A0F10160B
0D10070C0F060C10060D11060B0F040B0E030B0F030A0D02070901050701050601070A03
070A02050700030400020200
4B59614D5B64505C6A515C6E525C72525D74515B73525D73525D72546071556371556271
5563725564725765755763765865785664755664725765735966745B68775C697B5E697D
606B7E606C7C606D7A606C78626C7A646F7C65727E67737E67747F677381677383687383
6873846872846A74846A74856B74856E7887727B89737B89747D89747F8B737E8B75808B
78828C78818D7A818F7C83927C84927D85937C85937D86957D87957C87947F88967F8996
808B98838D9C848E9C838D9A86909C88909E8B93A28C94A48C95A38C96A18C979F8D98A1
8C989F8E9A9F8F9B9E909C9E929F9F93A1A095A2A195A2A095A3A196A3A397A2A397A4A4
98A5A398A5A19AA7A19AA6A09BA7A09BA6A09CA7A09CA8A09CA89E9DA89D9DA89B9CA79A
9BA79999A59699A49699A49697A493585A5A3D3D42393C3D2D3031282B2A262A28242824
1F231E1F241B1F261A1D23171B20151D20131A1D0E15180B1014090E12080D11080B0F07
0C100A0F120D11151013171113170F11160C0F140A0E12070C11030C10020C0D011C2010
222716252A18272F1928301A27301A26301B262F1D252E1D2028181B2113171D1211160C
0E12090D11070D12070E13080E12070E11070E11070B0E05070902060801050601060802
070A03050701020400010200
4A56644D5968505C6D515C6E515B71535D74535D75556078545F77535E75546173556372
5563725665735967765966775865775865755966755A67755A68765B69775C697A5E6A7E
606A7F606C7E616D7D626E7B646F7D66717F66717E66727F677281667182667182687382
6975826A75836B77846C76866D76876E7789717A8B737B8B757C8B747D8C747E8D75818D
77828B78828B79828C7A838E7B85907B84917C85937D88957E88957F8796818999828B9A
828B9A848D9C848E9C858F9B87919C88919D8A929E8B94A08B95A18C96A18C98A18D99A1
8D98A18F9AA2909CA1919D9F939F9F95A1A196A1A297A2A397A3A498A4A499A5A49AA7A5
9AA7A499A6A29AA79F9BA89E9BA99F9CA8A09EA99F9EAA9D9EAA9B9CA9999BA7999AA899
99A7989AA7979AA7979AA6969AA7956163603B393F39373A2C2B2D262627232426252A29
1D211F242A21272D2120261A1D22161C1F13181A0D15170B1214091113090E10070C0E06
0C0F080D110A10140E11160F11160D0E12080B0F06080C02070A010709000A0A011E2210
242916272D18272E1828301828311926301927311B27301C232B191F25151A1F1112170C
10140A0F14090E13080D12060D11060C10060D10060B0D04090B03070902050700040601
040600030500020300010300
4A55674D586B515C70525D72525C74525D74545F75556077546076556077566276576474
5665755765765866765966775967775B68785B69785B68785C697A5D6A7C5D6A7C5F6B7D
626D7E636E7F636D80666F816771806973816873816872826872836973846B75856B7586
6A75856B77856E79866D77876E79896F7A8B707A8D727B8C757E8D747F8E768190768291
7682907884917885917985907A85917A87927C89927D8B927F8C95828D97828C99848D9A
838C9A848D9B848D9C858F9D88919F8A94A18B94A08A949E8B96A08E97A28E98A18D99A0
8F9AA1919BA3929DA3939FA296A1A298A3A39AA4A598A2A599A3A59AA5A69CA8A59BA8A4
9DAAA59CA9A49BA8A19AA7A09CA8A29FA9A39EA8A09EA99F9EAB9D9DAA9A9DAB9A9BA999
99A79899A7989AA89899A6969CAA987781763A383C3734372C2A2C2624262323252F3331
2528282527242528231E1F1B22251E23261D1E2116191B0F14150A1213090F11080D0F07
0C0F070D12080D12080D12080E13090F12090D1108090C030608010607000B0C031D2210
252B17292F1C2B311D2B321C2B331D28311C262F1A262F1A242C192026171C2214191E12
14190E11160B10150A1015091115090E12070D10060C0F050C0D040B0E04080A03070A02
060801040600030400030400
4B586A4F5B6E525E74535F74535E75515D73515D71536072546072566274586575576476
5765785663765765765867775867785B687A5967785A68785C697A5C697C5E6B7D606D7D
616D7C646F7E65708066708166718066717F6872816973846972846973856A74866A7586
6B75876B75876C76896E798A6F798A70798D727B8F737C8E757E8E747F8F737F8F758091
7682937884937885937885927A86927C89937C89927C8A92808D94808D94808B96838D99
838D9A838D9D86909F87909E8892A08994A08A959F8A959F8C97A18D98A18F98A09099A0
929CA2929CA2939CA2959EA496A0A397A1A298A2A398A3A39AA5A49AA5A49DA8A69CA8A4
9CA8A49DA9A69CA8A59BA7A59DA9A69EA9A59EAAA39EAAA19FABA09EAA9E9EAB9C9CA99A
9BA89A9BA89A9BA89A99A99799A9988594843D3F403232352D2E2E2827272223222A2C2A
2A2D2C2424262123241F2021414A3D30362B1F21181C1F1316180C1314081113080F1208
0C10050D11050D12070D10080D11090F130A0C1008080B030608010507000B0E051D2412
232A16272F1929321C2A341C2A341C28311B242D17222A151F26141C22131D22131C2114
1B1F12181D1114180D12160B13150A1114081014080F12080D10050A0E020A0E030B0E05
0B0F05080A02060601050501
4C59674F5B6D525F73525E73525F75525E72525E71515E6F525F6F546170556271556473
55647656647656667755657958677A58657A59667A5B69795C697A5C697C5F6B7E5F6B7B
626E7C64707D65717E646F7E66717F6872816873806A75816B75836A74836A7485697484
6A75856B76866C77886E788A6E78896E778970798C727C8D727D8F737F8F748090768291
7783927783937783937986937B87947E89947E89947E8994818B96808B967F8B98818B9A
828B9B848D9D878F9F89909E88909D88919F89929F8C95A28C96A18D97A28E97A19097A2
9199A2939BA1939BA0949CA2979EA5969FA498A1A397A2A297A2A299A4A49CA6A69DA7A7
9DA8A69DA8A79EA9A89CA8A79CA7A69EA9A59EA9A49FA9A3A0ABA29FAAA09EAA9E9DA99C
9CA79B9CA89C9BA99C97A69797A8978A99883F41412F30312E2F2F2A2B2A262825272925
2A2D292224231D21203239323A44372B32251D20151A1D1114160A121307121408101508
0D12050C11060C10070B10080C10080C10070A0D050609010809010608000A0E041C2311
1F2714242E1927311C28321B29321A29311A262E172127101E230F1B1F0F1D2012202315
1E21141D20131C1F131A1C1016170C13130912130916190C151A0A111606131808141A0B
1217090D12060A0C04050601
4D58664F5A6D525F7453607654617655627554617253616F53616F54636F556371556374
5564765665785766795766785967785A67785A68795C6A795D6A795E6B7C606C7D616D7B
626E7C626F7B636F7C636F7D65717F6771826974836B76826A76836A74836B75846A7584
6774836A77866B78886D79896F7A8A707A8B6F798B717C8F737E91737F91758191758291
7783927885937884937984937C86947E87957F8996818A98818A99808A997F8A9A80899B
818A9C848C9C878E9D888F9D89919D8B929E8B939E8D959F8E96A08F97A19098A2929AA2
9199A1949CA0949EA0969FA297A0A397A1A398A1A498A3A398A4A59CA7A89CA6A79CA6A7
9DA7A79EA9A89EA9A79DA8A59DA8A69EA9A39FA8A39FA7A2A1A9A1A1AAA0A0AAA19FA89E
9EA89C9DA99C9CAB9B97A89797AA978E9F8C454A46373B37373B3530332F2A2C27272A24
2D312922241F1D1E1A3A42333C4533343C282226151B1C0D1514091111071114090E1207
0D11050C11050B11070B0F060B0E060A0E05080A03070701080800080800070801191D0C
222916262E1C28311E28311C2B341C2B331B272E192429142226121E21101F2213232617
25281A242919252B1A2326171F201419190F16170D2024152529182125152126121E2511
1D2310171D0C0F1306060901
4D58674F5A6E535E7454607754627755627553607253616F53616E54636F556472546273
5664755967785A687A5967785967765B69765C69755D6A775E6A775D6A785E6A79606C79
616E79616E7A636F7B65717C67727E6873816872836974856A75866975866A7586697687
6876886A78896A78896D7A8A6E7A896F7A8A707A8B707B8E727D8F737F9074808F768291
7883947985947987957984947C87967E8A977F8A97808A99818C9B808B9C7F8B9C808B9C
818B9C848C9D878E9F878F9F88909E89909D8C939F8D959E8F979F9098A19199A2929AA2
9199A1949CA4959EA5949FA595A0A596A2A499A4A698A3A699A4A79AA6A79CA7A69DA8A7
9EA7A89FA9A99EAAA89DA8A59EA9A59FA9A4A0AAA49FA9A3A0A9A3A1ABA2A1AAA39FA8A1
9FA9A09EA99D9CAA9B99AA9A97A89794A691525852353737373A362E2F2C2425221E1F1C
31352B2A2E2320221922251A434D344753351E200F1D1E0F18170C14140B13140A111309
0E12050E12050C11060B0D050A0D050A0C04080902080600080600080701060600181C0F
232917282F1C29321E29331D2A321A293219252E16222A152129141E2313212515252A19
282D1D2A301F2B321F2C321F292D1D25291A2125192830203038242E342129301B282D18
262B16212714161A0C070801
4B58654E5A6B525E72536074546075546174535F71525F6F52626F526271566474566577
57657959677B5A687A5A677A5B68795B67765C68755E6877606A795F6C7B5E6C7B5F6D7B
616F7B61707B63707C67727F69738168738167728468728568738668738769758869768A
6A778C6D798D6D798D6E7A8E707C8D707C8C707C8C717D8D717E8E737F8F74808F768190
7982917A83927A86937A85947C86967E88977F8B987F8B98808A9B818B9C818C9B828D9B
848D9C858E9E848E9F858FA08791A18992A18C95A28E96A18F96A19198A3929AA3939BA2
939BA3949DA5959DA6949EA695A0A897A3A897A4A897A4A997A3AA99A5A89BA6A89DA8A8
9FAAA9A1ABABA0AAA9A0AAA8A1A9A5A0A9A4A0AAA6A0AAA7A0AAA7A1ABA5A1ABA49FAAA2
9FAAA19EAB9E9EAB9B9BAA9999A99799AB9760696235373A33363828282920211E181615
292D233136282D322322241839402B5260402022151D1E1219181014150D14140C12130A
1012071013060E12070E11070D0F050A0B030A0A030C0A030D0C030C0B04080902171B0D
232815292F1A2B311C2A311B272F18252F16212A111C251019210E1A2110202716252C1B
2A2F1F2C33212E36223139242E36212C341F2E3521313A2638402C363D282E351F2A2F1A
282C18272B181D2111101106
4D5A65505D6A52606E546171556074566175556173546171566472576674586577586679
58667A5A67795A687A5C697A5B68795B67785D68785F687B616A7C616B7D616B7D616D7F
636F7F62707E65718067718168738267738267748467738568728769728969748A69748B
6C768D6E778E6E788E707A8F707A8D707B8C717C8C727E8E747F8F758190768290778390
79828F7B858F7E87917E87917E87937E8795818A97828A99838B9B848C9A868F9B868E9C
868F9D86909F86909F86909F8892A28993A48C95A68E96A68F96A59098A39199A2929AA1
939CA2949DA3959DA4959EA5969FA797A2A998A5A898A4A79AA6A99DA9AA9DA8A79EAAA7
9FABA8A0ABA8A0AAA5A0AAA5A1AAA3A1ABA3A0AAA3A0AAA5A1ABA6A2ACA5A0ABA39EAAA1
9EAA9F9EAB9E9EAC9C9CAB9A9AAA989AAB9869736C37383E3032352224241E201D171813
1F2217272A1D2E342325291B4750398DA679343B2A12120C18191213130C111009101007
12120811130711140714160914160811130811120816180B191D0E16190B1214061F2311
272C172A30192A3019262B152228131F28111B220D181F0C171D0B1E2412272E1B293020
2B32212D34223037243139242F36212F3621323923343925363D28343B272F35202A301C
272B19292D19272B181C1F0F
4A58624E5C67525F6E546073566177566178556076546074566273586574596575596676
5A677A5B687C5B697C5C6A7B5E6A785D69785D687A5F697E60697E626B80616A80626D83
636E83646F836470826571816773816674836674846774866773876974896B758B6B758C
6C758C6E778C6E778C6F788D6F7A8D707B8C717B8B717C8C747E8E758091758291758090
7782907984917A84917C86927D87957F8997808A98828B9A838B9A848D9B858E9B848D9B
848E9C8490A08490A084909F8793A18A94A38D96A68D95A68F97A69199A6919AA58F9AA3
919DA4929EA4949FA4949FA5959EA695A0A696A2A698A4A69AA6A89BA7A99CA8A89EAAA7
9EACA79EACA79EACA69FACA4A1ADA4A0ACA39FACA2A0ABA3A3ACA5A4ADA5A1ACA49FACA3
9FABA19FACA09FAC9F9EAB9E9CAA9C9DAC9B76817738383D333635272B2820241E1D1F17
1C1C121D1F13373F2A3F49324C593E95B18144513A10110A1B1E1215150A111204121204
13130512130614160915170A191B0C191B0E18190E222816242C18212915202612272D19
2A311C282F1A242A141E240E1B210D1D240F1E25111F2510222713272C192B2F1D2C3120
2C32222F3625323826313925303723303623323824343926383E29363D293137252D3322
292F1E272F1C282E1B242817
4C58654F5C6B525F71545F76545F77555F77545E76555F76576276586477586477596578
5A667A5C697C5D697D5D6A7C5E6B7B5C69795C687A5E697E5F697E606A7F626C81636E82
636E83636F84636F836371826471816573826775856775886673866774876975896D778A
6E788A6D778B6E778D6F788E707A8D717C8D727D8C727E8B74808D768190768292758191
76828F7884907985937A85957C87987D88987F8A997F8A9A818B9B838E9C838D9C838E9C
828E9D828F9E83909F8491A18693A38995A48B95A58D96A58F98A58F99A48F99A38D99A3
909CA4919EA4939FA494A0A594A0A695A1A796A1A897A3AA9BA6AD9CA6AD9CA8A99DA8A8
9EABA99EACA99DABA79EABA7A1ACA5A1ACA3A1ACA2A2ADA3A4AEA4A4AEA3A3ADA4A1ACA6
A0ABA59FABA39FAAA2A0AAA09EA99E9EAC9E7D877E3D3C4238393A28292822241F1E2018
1C1D111F20134B573C536043525F43859F7246523817190C1E1E10191808151504171706
20211027291A1B1C121B1D13232719232A1A202716262E1A29311B28311A2A321D2B341D
2A331E28301B2229141C230E1E2610232C15262F172A321A2C331C2D33202D32202D3221
2F352632382A333929353C29333927303624323725383E2B3E45303A422C353C292F3526
2A3022272D1E262C1B25291A
4E5969505C6D536073535F75545F75525D74545E75556076566277586578576478596579
5B667B5C687C5C697D5E6A7F5E6B7E5C697C5B677C5D687D5E697E606B7F616C80636F81
646F816370826472846573836573836572826673836874856775856774846873866C7789
6F7A8B6F798C6F798E707A8D717B8D717B8D727E8D727E8D74808F768290788492788392
78838F7985917A87957C87967E88997E899B808A9B818B9B818B9B828D9B828D9C838E9F
83909F83909E85919F8793A38894A58A94A58C96A69098A89099A6919AA6919AA6929DA6
919EA392A0A193A0A394A0A395A1A497A3A798A3A999A3AA9BA5AD9EA7AF9EA8AC9FAAAA
A0ABAAA0ABA99FAAA8A0ABA8A1ACA5A1ABA3A2ACA3A3ACA3A2ACA3A2ACA2A3ADA2A2ACA4
A2ACA6A1AAA4A1AAA2A1ABA19FAA9FA0ADA0828981403E4638383C2D2D2D2122211E1F1B
1A1A132A2D1F5967485360424B563B6374504F593A42472B32321C282612211E0D363824
545C434F58421F20182022192B30232B32222A32202A311E2C331E2C341F2D36202B351E
2A321D2D361F2D351D29301929311A2A331C2B331C2E361E2E35202E34222D32212E3422
303625333928343B29373E2A363C28363B27353B263E4730404A3238422B333D282C3523
262D1E242A1C24281B222518
4E586A505C70525F74525E73535E74535D75545E77566179556177576378586479586579
59657A5B677C5C687B5A677A5C697B5D6B7C5D6A7C5D6A7D5E6A7E5E6A7F5D6A7E616E80
636F806470806472816572816673836774836774836873836775846975866B76886D7789
6E78896F788A70798B707A8A707B8B717C8D727D8E737E90737E91768194778293798592
7884907A86917B87957D87957F8897808A9A818A9C838B9E838B9E828B9D838D9E838D9F
8490A18491A08693A18995A38B95A68B95A68E97A89097A89299A8929AA7929AA5939CA4
949FA394A1A195A2A197A3A299A4A598A2A599A3A89BA5AA9CA6AB9DA6AD9EA8AD9FABAB
A1ABA9A2ABA9A2ABA9A2ABA8A1ACA7A0ABA5A0ABA5A1ABA4A3ACA6A2ACA5A3ACA4A2ACA4
A3ACA4A1AAA19FAAA09FAAA19DAA9F9DAA9B8D988B47484C38393D2E30312325241C1D1B
161613363D2C5665485462464D5A3F434D354B553A63704C5D644455583C3D392A828E6E
8899794B52432D2F2627281F2E32252F34252F35242C33232B33232C35242F39252F3A25
2E3823303A213039202D341D2C321B2D341D2D341C2C331C2D341E2D33202D32212D3221
2E3423313826333928343B28363D29363D28363C274149323E4730353E28323C262A3320
242C1B24291B25281D22241B
4C5768505C6E535E73525D74545E76565D77565E78576079586278586477586577596576
5966775C697A5D6A795C6A785D6B795C6A795C697A5E6B7D5E6B7E5E6B7F5F6C81606C81
616E82626E8164708266718367718367728568748667738568758769768A6B778A6D788A
6D778A6E788A707A8A707A8B707A8D727C90727D91758093767F92788193798392798590
79848E7A85907B85947E87977E8899818B9D818A9C828B9D838D9E848D9E838D9E858E9F
858FA08591A18694A38794A38995A38B97A68F98A79099A6929AA7949BA7949DA6959FA6
949FA594A0A195A2A197A2A299A4A599A3A69AA4A89CA6AA9DA7AC9DA7ADA0A8AEA0A9AC
A1ABACA1ABACA1ABAAA1ACAAA1ACAA9FACA89FABA6A1ADA7A2ACA8A2ABA8A3ABA9A2ACA7
A1ACA5A0ACA39FACA19EAAA09DAA9E9EAC9B93A18F4E4F503A3A3D2E30311F2021171918
111211333B2D5360475361484E5D4446533C57654A6A7B5B707E5D8C9B735C5F4AB4CA9E
88987B42473C3C4134373A2C37392A363A29353C2A343C2A3039272D37262E39272D3826
2E3824313B25303A232E36202C321B2D341C2B321B2A2F1B2D331F2E33212E33212D3222
2E3525303727333C2A353E2B363E2B363F2A363E283E472E3C452D353D27313A2529331F
242C1B23291924281B24261C
4C5967505C6D535F755360775561785660785660765760755964755A6776586675596776
5B68775C6B785D6C7A5C6C7A5C6C795B6A785C6A795F6D7E606C7F5F6B80606C81606C82
616D85616D846470846571846671846672866673876875866875866975876C778B6E788D
6E788D6E798C707A8C717B8E717B90737C93747E947681947781937883927A85937A8591
7B86917B85927E87977E879A7D889B7E8A9C818B9B828B9C838C9E858EA0868FA1878FA1
868FA2858FA38591A38693A48895A48996A48E99A7919AA6929BA4939CA5949FA895A0A9
95A0A894A1A694A1A495A1A498A3A69BA5A99CA6AC9DA7AD9FAAAEA0AAAEA2A9AEA1A9AC
A2AAACA2ABABA1ACABA1ADAAA1ADA9A2AEA8A1ADA8A1AEA8A1ADA8A1ACA8A2ABA7A3ADA6
A2ADA4A3AEA3A2ADA0A1AC9F9FAD9F9FAE9D98A7935154533535382F2F302526251F2120
1817182F332B4E5946525E4A505B47434C3B535F4969785C69765BA1B89086957ABDD8AD
727F6749503E424835373A29343525333525353927343C282F37242C36242D37262D3725
2F3824313B26323C272F38232D33202D3320292F1C272D1B2A301F2D34212F36232E3524
313828333A29353F2A36402B343F2A36402A3540293E492D374025323B212D361E29321C
272E1A272D19262B19272A1C
4C5867505D6D53617453607755617954607755607556617758657959677A5867795A687A
5A68775B69775B6B775B6A7A5B6B7A5B6A7A5B69795D6A7B5F6C7D5F6C7F5F6B7F5E6980
616C84616C856370876471866673866573856573856774836775826975836B76876E7789
6D78896E7B8C6F7C8D707C8E727C8F737D91757F94768192768291788492798591798691
7B88917B88937D88977F899A7F899B808A9D828B9D838B9E838BA0868EA2868FA2868FA2
8691A38590A28592A28695A38897A38998A28C99A3909BA5919CA3939DA4949EA7959FA9
96A1A996A2A795A2A695A2A796A3A899A6AB9BA7AD9CA8AE9DAAAE9FAAAD9EA8AA9EA9A9
A1AAAAA1AAAAA2ACAAA4AEABA4AFABA4AEABA3AEABA2ADA9A1ADA9A2AEA8A3ADA6A5AEA5
A4AFA3A3ADA2A3AD9EA3AE9FA1AC9F9FAD9E9BAA9B595D5E2F2C37312F3428272B212123
1C1B1D2E2F2B535C4C586151474C4230312B3C3F336773595E68539DB18DACC29DAAC29B
59644E383E2C3438252525172525182A2C1F2E32232D32232A2F20282E202A32222C3522
303923323C24323B252F37232D35222B332028301E272F1E28311F2B34202D36222E3623
313825353C29363D2A363D2B353D2A343C28333D283B452D343F27303A222C351C28321A
262E18252C16252A16262A19
4E5B67515E6C546171546074556076555F77535E7556617958657B59667C5A677C5A687A
5967765B68765C6A785B697A5C697C5E6B7D5D697C5C697C5D6A7E5F6C805E6B7F5E6B80
5F6B82606C82626F836470856773856773846773846774836975846974826B75836D7787
6D78886E7A8C6F7D8E717D8F717D8D717D8F747F9276829277839178859078858F79878F
7B88917E88947E88957F88967F899980899C81899D828B9F838CA0868FA28790A28690A2
8692A28591A185939F8796A08897A18A98A28B99A38E9AA58F9AA5929BA6949DA8949FA8
949FA895A1A996A2AB96A3AC98A5AC99A6AC9BA8AD9BA8AD9CA9AC9DAAAD9DA8AA9EAAA9
A0ABA8A1ABA7A4ADA9A5AEAAA5AEAAA5AEACA4AEACA3AEABA3AFACA1AEA8A1ADA4A3AEA3
A3AFA3A4AEA3A2ADA1A3ADA1A1AD9F9FAE9D9DAD9C5D6261302D382D2C33232128201D21
201F203538325F6A5771816843473F302F2D30302D5E69535A634F7785678EA27C819571
4E5A42363D2B2A2F1E1F22151D1F1523251B26291E282C1F272B1D25291D272C1E2A311F
2D35202F371F2C321D292F1E2B32202A332027301E272F1E26301D28321E2B36202D3821
303820323922333925343B27353C273138243037243A422B343D282D36222A321E28301B
262D19232A17242917262B1A
4E5B68515E6D546071545F72545F74566177555F7857627C59657F59667D59667B5A687A
5C69795C6A785D6B795C697A5C697D5D6A7E5D697D5C697C5D6A7D5E6C7F5D6A7E5D6B7E
5E6B7F616E81636F826670856770866972866A75866B75876C76886C76876C76866D7788
6F7A8B6F7A8D707B8E727E8F727E8F727E8F7481907582917683917784917884907A8790
7B88907D89917D88927F88947F88958089987F8A9A818B9C848D9D848E9F858FA08690A0
8791A18792A18694A08795A08A97A38E9BA68F9BA8909BAB909BAA939EAC949EAB949FA9
94A0A896A2AA96A4AB96A3AB98A5AB99A7AA99A7AB9CAAAC9CAAAB9EAAAB9FABAB9EABA9
9FACA7A1ADA5A4AEA8A5AEA8A4AEA7A5AFA9A5AEA9A4AEABA4AEACA3AEABA3AEA7A3AEA4
A4AFA4A2AFA2A1AEA2A1AEA1A0AEA09EAE9D9DAE9B676F6B3E4146303137242429222022
1C1A1B373B3356624F61705A55604F40453B373A3356614E5C6852545F4958654B57664A
4F5C41373F2D29302121261A1D211521241724281A272C1C252A1B212416222517242A1A
272D1C252C1B202418262D2028302129312028321F28311C28311B29321B2C361E2E371D
2F371C2F361C2F361E323A23323A232D332031382439412A343C263037232C33202B321E
2A301E272D1C252B1A272E1E
4D5B67525E6E535F74535E76545F77545F7755607A57627D5A65805A65805A667C5C697C
5D6A7B5C697B5D6A7B5C69795D6A7D5C687E5D6B7E5D6C7E5C6C7C5D6D7B5E6E7A5F6F7D
6170816372826371836471846671856771856973866B76876B75876D77896C77886E788A
6F7A8B6F7A8D707B8E727D8E737F8F73808E74828D7683907683917784927884927A8893
7B89937D8B927D89947F8995818B95828C98828D99828C9B838D9B858E9B85909C86919C
88939F88939E88949E8A96A18C98A48E99A78F99A8919AAB919BAB919DAB939EAB929EA8
94A0A994A1A895A3A896A4A898A5A99BA8AA9CA9AC9DA9AC9EA9ADA0AAADA1AAAFA1ABAD
A1ABAAA4AEA9A5AFA9A5AEA9A5AEA7A5AEA6A5AFA8A6B0AAA6B0AAA6B0AAA5AFA7A4AFA3
A4B0A3A4B0A1A2AF9FA1AD9EA0AE9F9DAC9F9DAE9D79857C454A4D363A3D2C2E2E272825
22211D31322A474C3F4A5245505C4B444E3F39413357664D606F544D59414B573F48533B
454E37353B2A2D322425281D1F221822251924291C22281A1F25161D2113202516232919
252A1C252B1D191C1424281C272D1E272F1E29321E2B341E2C341D2D351D2E351E2F361F
3037202E351F30371F3036212E34202B301E303621384028333A212F371F2B331F2A311F
28301E292E1D272D1E2B3123
4C5A69515D70535F77555F7B55607B55607B55607B57607C5A637E5A657D5D687D5C697B
5E6A7C5E6B7C5E6A7D5D6A7D5E6B7E5E6A7F5E6C805E6C805D6C7F5D6E7E5D6E7C5E6F7D
60707F637181616F806270826471836672856872866A75876C77886B77896C77896F798A
6F7A8B707B8D727D8E737E8E74808E75818D76838F7783927783937782937884947A8795
7C88957F8B97808B97808996808A95818B97828D9A828D9C838E9C848E9B848E9B86929D
88939F88929F8994A08C96A38F99A78F99A89099A99199AA919AAA919CAA929EA9929FA7
94A2A995A2A996A3AA97A5A999A6A79DA8AA9EA9ACA0AAAFA0A9B0A2AAB1A3ACB2A4ADB2
A3ABAEA4ADACA5ADA9A6ADA8A8AFA6A7AFA6A6B0A7A6B0A7A6B0A6A7B1A5A5B1A2A5B1A1
A4B09FA6B19FA5B09EA4AE9EA1AE9E9FAD9E9DAD9D829083484C4D393B3C2F31302A2B28
28272229282238382F494E3F4852403F4838373F2E5463476476554F5C404A563B495338
4349313639272F3122282A1E21231921251A242B1F222A1E1F271A1F2618222A1A242B1A
222A19222819161A0F1A1D11202214222716272E1B2A321D2C341D2E361E2F3720313823
3339252F36233036232E34222D32202A2F1E3137243C442C333A222F371E2B331D29321E
282F1E292E1E2A2F202D3323
4D5A6B515E72535E76545F7A54607C55617D55617B56627A59637A5A647B5D687D5D687D
5D697C5D697A5D697B5D6A7D5E6A7F5C697E5D6A805F6C825D6B805D6B805D6B7F5D6C7D
5F6E7D62717F61707E63727F6573806673826975866A75886B78896B78896C7A8A6E7A8C
707B8D717C8F727E8E727F8D737F8B73808B73818D7583927783937783947884957B8796
7D8896808A96808996808895818896808999838C9C828D9C828D9C848E9F858FA08691A0
8692A08792A08A94A38D98A78F9AA98F99A9909AA8909AA6909AA5929DA6929EA693A0A6
95A3A695A3A797A3AA99A5AB9AA5AA9CA7AB9FA9ADA1AAAFA1A9B0A0A9B0A2AAB0A3ABB0
A3ABAFA3ACACA5ACA9A6AEA9A8AEA7A7AEA6A7B0A7A7AFA9A6AEA7A7B1A6A6B2A4A6B1A2
A4B0A0A5B1A1A6B1A2A5AFA1A3AEA0A0AC9D9EAD9C8B978A484A4E37363B3231322E2D2C
2C2C2A2C2C2732342B4D56434A54403C4533333A2B48533E697A5B515D4349533A495138
454B323A3E2730341F292A1A23241721231722261A23281B24291D24291C232A1B262C1B
2227171C201216180D12140A15160C191C0E282D1A2C311F2E3420303723323925323927
343B27353C283238242F34222E33212A2F1E3137243B432D333B252F38212B341D2B331F
2B3220292F1F272E1D2A311F
4E596E525D74535F78545E7956617D555F7D545F7B56627B58657C5A667D5A667C5B677D
5B687C5A677C5C687C5C697D5E69805D68805D6A815D6A815C6A805E6B815F6C81606D80
606E7F62707E63727D65747E65747D66737F6974836B76876C76896B76896C788A6E7A8D
717A90727C91747D90757F9074808E75818D75818D75818F7783937884977883967C8698
7E87997F8898808899808998818998818A9A838B9B838C9B848E9C848E9F8690A18691A1
8792A18793A08994A38C97A68D98A98E98AA8F9AA8909BA6909BA6929DA7929DA5939FA6
93A1A695A2A796A2A799A3A79AA4A99DA6AC9FA6ADA0A7AE9FA7B09FA8B0A0A9B0A2AAB0
A3ABB0A3ABAFA4ACADA4ACABA6ADABA6ADABA7AEABA7ADABA6ADA9A4AEA6A4AEA4A4AFA3
A3AEA1A5AFA2A5AFA3A4AEA3A3ADA2A2AD9FA0AD9E8C988C494A503C3D413A3B3B383834
32312D2E2C2832332C525B48525D48434C39343B2B424C37697B5A535F444A533B474F36
454B3342472F373A272F2F1F2A2A1C28271C282A1E26271D24261E23251D2023191F2217
1D2114181B0E13160A0F13070D0F060F1207272F1A2C331E303622323825333926323827
3239273239263036232E34212D32202B301E2D3422313C262D37212B351E28321C28311C
2A311E292F1F262B1D2A3220
4E596D515A72535E78545E7B565F7C56617D57627D58637D59657D5B687D5B687D5B687D
5B677D5A677D5C687E5D6A7F5E69805C66805C677F5B687E5C6A7F5E6B7F5F6D815F6C81
5F6C7F616E7F62707D63717C63717D6672816872856A73876A73886C758A6E778B70798D
717A90747C91747D90757E907680917581907682907582917783947883987983987A8498
7B85997E879A818A9D808A9D808A9C828C9C828C9D838C9D838D9E848EA0858FA08690A1
8790A28791A48994A58994A58A95A68C97A88C96A98D98A98F9BA88F9BA6909DA693A0A7
94A0A896A1A997A1A99AA3A99CA4AB9EA5AC9FA7AF9FA8AFA0A7AFA1A8B1A2A9B0A2A9B0
A2ABB1A3ABB0A3ACAEA4ACAEA4ACAEA5ADAEA5ACADA5ACABA5ADAAA4ADA8A4ACA7A4AEA5
A4AEA4A5AFA3A6B0A4A3ADA3A2ACA2A1ABA0A0AC9F919E924D4E544244484347433C3F38
30302A2D2C253030294D53444C53423E45362F34283C44316E825D566547475138485239
464E35454B344347323C3D2C37382B32332A30302A2A2A2424242020211C1E21191E2117
1D2115181B0F13170B1014070E11060A0C042128182F38232F3822313924303925303925
3039242E36232E36212E361F2D331F2A2F1E2C34222F3A252B351F29331C2A331C2B311C
2B311E2B2F1E282B1C292E1E
4D596A505A70555F7756607A555F7A57637D58637E59647F59657F5A657E5B677C5D687D
5B687C5D687E5D687F5D68805E69815E69815D68805D697F5E6A805E6B80606D80606D80
616D81626F816471816673826671836772856973896A758A6A74896D768C6F788E707990
727B91747C92737C90747D91757F937581937681937782947883967984987A85997A8699
7A85987C879A808A9D818A9D80899E818A9E838B9F838C9F848DA0858EA0858E9F8791A1
8891A28892A48A94A68A95A58B97A78C98A88C97AA8D98AA8F9AAA909DA9929EA8949EA7
96A1AA99A2AB99A2AA9BA5AB9CA4AB9EA6ACA0A8AFA0A9B0A0A9B2A0AAB4A1AAB3A0A9B1
A0ABB1A1ABB0A2ABAFA5ADAFA5ADAFA5ADAEA6ADADA6ADACA5AEABA5AEA9A5AEA8A4AEA6
A5B0A7A5AFA5A5AFA4A4ADA4A3ADA3A2ACA3A0ABA196A2985253583C3C434142413D3D38
32312A2F2E253230274A5040494E3E3F433533362B3A3F3170815F59674C454E3A4A543E
48513B464E384B4F3A4748374545373E3E3539383233332E2A292725262220231A1D2014
1A1B1016160D13150B1114090F1208090C041D25162F39252F38253039262E37252D3824
2D38232D38232C36212D37202B331F2A311F2A33202C36222A341F29341E2B341F2B331E
2B311C292E1C2B2E1D2D3220
4D5869505B70545F7556607757617959647C5A637E5A64805B65815A64805B677F5C687D
5B687B5C697C5D697F5D6880606A82606A835F68825F6882606983606A82606B80616D81
626D81616E816370836672866873866973876A748A6C768B6C758B6C758C6E77906F7992
717B93737D93747E937580937480927580927783937883937982937A83947B84977E8698
7E88987F8899818A9B818A9D81899E818A9F828B9F838C9F848D9F858FA08890A18991A1
8991A28A93A58A93A48B94A68C97A88D97AA8E98AB8E99AB8F99AA929DAC949EAB949EA9
969FAA98A1AA99A1AA99A3AB9AA4AA9CA6AB9FA8AE9FA8AF9EA9B19EA8B29EAAB29FAAB1
9FAAAFA1ACAFA2ACAEA4ADACA4ADABA5AEABA7ADABA8AEAAA7AFA9A6AFA7A7B0A5A6AFA3
A5AFA4A5AFA4A6AFA5A6AFA5A4AEA4A2ACA2A0AAA19BA89C6165653E3D434041423E3E3A
36353033312B33312A484B3C4B5140414537313329363A2B6D7D5B667556454B3A4A513F
48503E454C3A5156415D634B5559454C4D3E42423742453B29282626272221231C1C1E14
19190D16160913140912140A1012080E1006171A0C282F1C29301B29301E262D1D252D1D
2831202C37232A352228311E28311D29321C29331D2D381E2D381D2B341C2B331D2B321D
2A301D292F1E2B2F1F2E3321
4D566950596F535D74565F765860775A637A5A637C5A637F5A64805A65815B66805B677E
5A677B5C697C5D687E5D687E5F69806069815E667F5F6780626A81616A80616A80616D82
636E816470826470836671856872856972866A73886C73896D74896D748A6E778D6F798F
727C92757E94757E95757E95757F95757F947680947782937883947983937A84937C8594
7D86958088968088997F889A80899D7F8B9E7F8A9D7F8A9B818D9C848E9D868F9E88909E
88919F8891A08993A18B95A48C95A78C96A78E98A88F9AA9909BA9929CAA939DAA959EA9
969EA997A0A998A2A999A3AA9BA5AB9CA6AB9EA7AC9EA8AD9EA8AF9CA8B09CA9B09DABAF
9FABACA0ABAAA1ACAAA4ADAAA5AEAAA5ADA9A8AEAAA9B0A9A8AFA7A6AEA5A6AFA3A6AE9F
A6AEA0A7AFA3A7AFA4A7B0A4A5AFA3A3ADA2A1ACA1A0AEA0686D6C3937404040423A3A38
3E3F3A42443C474B3F4B50414A4F4041473833372C32372A667757708160444A39474E3E
464D3E414638545B46899A766A725A636A566068564D53482B2B2927292520211B181911
13130A111006100F051010061213091213091416092328142328122125121D21101E2313
262C1B2A321F252D1C1F2516222918262F1C29321C2D381E2D371D2E361C2D341C2D331C
2A301B2A2F1D2C31212D3322
505969545C6E575F7657607659627959647A59657A5A667D5B677E5B687E5D687F5D687E
5B677C5C677C5C677D5D687D5D697E5D697E5E697F616B80616B7F636D80626E81637082
636F816773836872836871846872866972866A74876B75886F7688707788727A8A727B8D
747C90777D94777D96757D97747E96757F95778095788296788396788494788493798494
7C86957F899681899A80899B808A9C7F8A9C7F8A9D808B9C818C9B838E9C848E9B87909C
89929D89929E8B95A08D96A28E96A38F97A5919AA8929CA8939DA8949EA8959EA8959DA7
959EA697A0A69AA3A799A3A79DA6AA9DA7AB9EA9AC9FA9AC9EA9AD9EA9AE9DAAAE9EAAAC
9FABAAA0ABA8A3ADA9A5ADABA7AEACA8AEABA8AEA9A8AFA7A7AFA5A5AEA3A5AEA3A6AFA2
A6AFA1A6AFA2A9B0A4A8AFA3A5AEA2A4AEA3A1ACA2A1AFA36B707235333E3F3F3F373633
5155465358465E644F5A604B4F54434D54433C42353940336070566B7C5F4A5341495240
414739363A2E4E564497AC888B9C7E87957A86947A585F522928282628231E20181A1C12
15160B1112060F0E04100F0514130916170C181A0D1D22101E240E1B220D191F0D191D0D
262B192E35221F231714160E202618252D1C2A331F2F37212F361E3036203137212F3520
2C321E2C321F2D3323303726
4E5869535E6F5962785A637B59637B58647B57637A59657B5B667B5B667C5E687E5F697F
5D687D5B677C5C677C5C677C5D687C5F6A7E5D687E5E697F5F6A7F606A7F616D80616E80
626E806571826872836872846972876A74866A74866A74856D77886F7889717A8A727B8D
747C8F757C92767E95757E97757E97767F967981977981987A81977981967B84957E8799
7F89997F889981899C80889D7F879D80889D818A9F838CA0828B9E828C9F838D9E868F9D
88919E8A929F8B949F8D96A08E97A19098A29299A4939BA6949BA8949DA7949CA8949BA8
959DA897A0A999A3A89AA3A79DA6A99EA6AA9EA8A99FAAAB9FA9AB9EA9AB9DAAAA9DAAA8
9FAAAAA1ABABA2ABABA3ABAAA5ACABA6ADABA8ADA9A9B0A7A8B0A6A6AFA4A6AFA4A6AFA4
A6AFA3A7B1A3A8B0A2A7AFA3A5ADA3A3ADA3A0ABA3A0AEA4737A7A3E3E473E4041363836
5159494F5543626A51616951515745525B49414A3B3B43355A684F697A5C4F59434C5540
40453433342950564491A4838D9F8191A28499AB8C6C7763221E1F2423202022191A1B11
15150B121207110F06111006181B0B1C1F0E1E21111E24121D24121A2111171D0F16190F
3239293D4532151712090A081E24182D362330372232392230361F30361F3236222F3422
2D32222D33222E34232F3625
4C586B515D7155617655607957627C57627C58627A59637A5A647A5B647B5B647C5B677C
5A677B5C697B5D697B5C687A5C697A5D697C5D677D606A7F616B7F5F6A7F606D81616D81
626E81646F836571846772846872866974866A74866A74876D768B6F778C70788D717B8F
727C91737D93747F95757F97777E98787E987A80997A80987980967980947C82967F8497
80859980869A80889B80879B7F869B80879C80899E818BA1818CA1838CA1848DA1858D9E
88909E8892A08A93A08C94A08B95A18C95A18F96A39199A5929AA6939BA89199A8929AA9
949DA9969EA9979FA9979FA898A1A899A3A79BA5A89CA7A89DA8A99EA8AA9DA8A99DA8A7
9EA9A9A1A9ABA1AAABA2ABACA3ABACA4ACABA6ADAAA8AEA9A6AFA5A6B0A5A5AFA4A4AEA3
A5B0A4A4AFA3A5AEA1A5AEA3A6AEA3A4ADA3A1ACA1A0AEA27F888247484D4245453A3E3A
40453C474E3F58604B68745A4F5645535A48454D3D394031515E466A7D5A5563474E5940
4A523B3A3E2F4C52418EA1808A9B7E8C9C8196A689818F752E2D2925221F22221C1C1C16
17160E131209111107121206181B0B1B210E1C21101F25131E24141D2314191C0F13140C
2A2E243E47381A1D1A0B0D0C181E14303A252E3721333A2331371F3036203137232E3423
2D32232E3325313725323825
4B576A4F5B71546077545F7757627A58637C5863795964785A66795C677B5C677C5B667A
5A67795C687B5E6A7B5D69795E6A7B5E6A7C5D687E5F697D606B7F5F6A7F616D81606D81
616E81646F836670846770846772856973876A74886A73896C748B71778E737A8F747C91
747E92758093768095767F97777F98777F987880987881977981967B83957D83957F8395
7D81947E84987F869A7F879B7F879B7F899D7F8A9E7E8A9F7F8B9E818DA0838DA0858DA0
868FA08891A18892A28B94A48B95A58A95A58C96A58E97A6919AA8929BA9919AA8929BA7
929DA7949DA997A0AB98A1AC98A1AC97A0AA9AA3AB9BA5AB9CA6AC9DA8AD9DA9AC9DA8AA
9EA9ACA1AAAEA2ABAEA2AAAFA4ACB0A5ADB1A4ACAFA5ACABA5AEA8A6AFA6A6B0A5A4AFA3
A5B1A4A3AEA3A4AEA3A4AEA3A4AEA3A4ADA3A1ACA2A1AFA48B968E47484D3F4041393B38
3F423B4B51454D53466B79624B52454F5749475041363C314B57446D815F58674A4D5940
4B573E444E3948503E8B9D7B8C9D7F8A9A7D8E9D828F9D824D50462825242524221F1E1C
19191415140F14140D15160C1A1E0F1C21131D22132025152126161F22141A1A0E16150C
1E1F172D31283E47390F11110F130F2932212D35223036232F35222E35212F36232F3421
2E3220313423343827353A28
4E596C505B72525E77515D76535E775460765561755763745865745B67785D697C5B667B
5A677B5B687C5B687C5B687C5D697D5E6A7E5D6A7E5E6B7F5F6B805F6B80606C81616D82
606D82636F82657083666F846670846871876A73876A73876D778A6F798A70798A727B8C
737D8D747E8E757E91768094758096757F967580977782997982987781967A82957C8396
7B81957B82967D84987D85987E889A7F899D808BA1808BA17F8CA0808DA0818DA0838D9F
8690A18791A28790A28892A58994A78894A68A95A68B97A68D98A68F9AA58F9BA3909BA4
919DA6929EA895A0AA96A0AB97A1AC98A1AC99A2AD99A4AE9AA6AF9CA7B09CA8B09DA8AF
9DA8AE9EA9ADA1AAADA2ABAEA4ABB0A3ABB0A4ACAFA3ACABA4ACA8A4ADA7A3AFA7A2AFA5
A2AFA3A2ADA2A3ADA3A4AEA4A3ADA2A2ADA2A0ABA2A0ADA38F9C934A4A513E3E44393A3D
474D475A635550564C6875624951484C564B454F44353C35455042697D6059694F4C5842
4C574247513F4750407F90728A9C7E88977D89987F8997816973643E413C262727212224
1E1F1F191A191818141A1C131D20152123182224182427192527192022151B190F1A1810
515C443F4738596550111211121411252B1F2A31212C32212D32202E33212D33212F3421
2F341F333723363927363927
4E5A6C505D72535F77535F77536077556276546273566373576474596676596678596679
5A667A5B687C5A677B5A68795A67775C69795C697C5E697E5F6A7F5F6B7F5F6B805F6B81
5E6B80616E81626F826370826571856671866973876973876C77896F7A8B707A8B727D8D
717C8D727D8E737F8F7580927581937581947580937780957780967981967A8297798297
7A82977A83977A84967C86987E879A7F899D818A9E818AA0808BA1808CA2818DA3828DA2
8490A28590A28691A28792A48892A48893A58A94A68B96A58C97A48F99A4919BA3929DA3
939EA4929DA6949EA896A0A996A1A998A2AB98A2AC99A3AD9BA7B09CA7B19CA7B09DA8AE
9DA7AC9EA8ABA0AAABA1ABAAA4ABACA4ABADA4ACADA4ACABA3ACA9A3ACA7A2ACA7A1ADA6
A0ADA4A1ADA3A3AEA4A3AEA4A2ADA2A1ADA29EAAA19CA99E8E9B904D505443454A404445
4D544D636D5E52584E5B65584C544B4B5448444D41353B334751416171565C6B514F5B45
4D5744495142495043808F74899A7E88967E89978084917D85937D727D6A201E211F1C21
1B191D161417151313191A151D2016202217222418272A1B2A2C1E2222161C1911191611
63705767775E4751441010131518182F382D2F382C2F38282C34222D34212C34212D3321
2D3421303622333925363A27
4A586A4D5B70505E74515F76525F775462775563755664755765745865755966765A6777
5B68785B68795B68795C6A795A67775B67785D697D606980616B84606B82616C83616D81
5F6C7F616E7F6270816471836572856873886C768B6D768B6E788D727C90737D91737D91
717C91727D92747F927681937682927682937882967781957781957882987A839B7A839B
7B849B7B879B7C869A7F899C80889B808A9E808A9D808BA0808BA1818CA3828DA6828FA6
8390A5838FA3838FA18691A28893A48B96A88D97A78D96A58E98A69098A5929AA6939BA4
939DA4949EA5969FA597A0A797A1A798A2A798A2A89AA4AB9BA6AE9BA6AF9BA6AF9CA6AE
9DA7AE9EA8AE9EA8AD9FA9ADA2ABADA4ACADA3ACACA2ACABA3ADAAA2ADA9A2ADA8A2ADA9
A1ADA9A3AFAAA1ADA6A1ADA59FABA49DA9A09BA89E99A79B8D9B90575C5E45484E4A5152
616C605C655751574A52594B4C54474851443F463A33382E3E4636647457617156525E48
4C5643484F4045493E7A88708D9F828998808B9A8386937F8C9B8385947D2422231B161B
1D1A1C171416141011141210191913212318313424373A2933362724261A1C1D1317140F
545C487E906F55604F1C1D1E141519323C34333D322D37292933222A33212A32202A3320
29311F2B33212F3824333A27
4856684B596C4F5E71505D74515D74535F765563765765775865755966755A66775C6878
5A66795B677A5B677B5B687C59667A59667B5C687E5F69815F6A82606B83616D83616E80
616E7E626F7E63717F6572836873866A76896C778D6F788F707990717A90737C91727D91
737E9274809474809474809375809376819578839777819677829978839A79839B79839B
7A859B7B869C7C879B7E889C7F879C80899E7F8A9F7F8AA17F8BA2818CA3818DA5818EA5
8490A68490A6838FA58691A48892A58A95A78C96A78D97A79098A89098A9919AA9929BA7
929CA5949EA696A0A696A0A796A0A699A3A899A3A99AA4AC9BA4AD9BA5AF9BA5AE9CA7AE
9DA7AF9DA7AF9EA8AF9FA9AFA2ABB0A2ABADA3ACABA4AEABA3ADAAA2ACAAA2ADAAA1ACA9
A2ADAAA4B0ACA2AEABA2AEAAA0AAA79FAAA49DA9A19CAAA096A49A666C6C45474C4C4F4D
88977D595F5054594A5A62524C54483F463E3438342A2D2A353A3163735864745756624A
5059444B524143483B73806792A5848B9C808D9E8389987F89987F8B9B8031312E1B171A
23211E1B1917100D0D0D090A100D0C34382A5B674C606C534A5241282B2424261F22221F
5A64527A8B706E7D663237311413163C473B323A30293126262E20262E1F272F1E29321E
28331E2A331F2E3621323824
4955684B586B4F5B71505D74505C75525E775460765563765663755865785B657B5C657B
59647C5A657E5B667E5C687F5B687D5B677D5C687F5D68805E6A805E6A7F5E6B805F6D80
616E7F626F7D62707F6472836875876B7A8B6C788B6D798C6F7A8D707B8F707B8F727D90
737F90748092737E93737E94747F94757F95768096768097768198758098778199788398
7884987A859A7A859A7B869A7B85997D879E7D89A17D89A27C89A17E8BA17F8CA2818EA4
8490A68490A6838EA6848FA68690A68791A58A95A78D97A98D97A88E98A9909AAA909AA9
909BA8919CA8939EA9939EAA939EA995A0AB98A2AC99A3AE98A2AE9AA4B098A3AF9AA5B1
9BA6AF9DA7AF9FA9B0A0A9AFA2A9AFA2ABADA3ADABA4AEAAA3ADAAA3ACAAA2ACAAA2ACAA
A1ACAAA1ADABA2AEADA3AEABA1ABA8A1ABA6A0ABA59EAAA59BAAA46B7275494B51454746
5960514F54474B50445F6958525B4F444B443A403D2D31303036315767515F6E5356624A
535B474D534341463A68755F91A584899A7D8D9C828C99818B98808F9E844040391D1718
25221F1B18150D0A080907050B0909454E3E849A787E927476876D3A3F3B434A454E564F
64726173846D6F80694952451B1D1B49554332372D2B3226272D20252C1E242D1E252F1D
26311C2A331E2E3520303521
46526749566C4D5A724F5A74515D77515D77535F7754607856627857627959647A5A637B
59627D59647E59657D59657C59657C5B677D5B677F5C67815E69825C69805D6A7F5E6B7E
5E6B7D606D7D616F7E6573826876856A78876A79896C798A6F7A8B707B8E707C90717C91
727D8F727E8F727D90727C92727C92747E92757F94757F95757F95758097768098778198
7882997984997985997985987A85987B869A7C879C7D879D7D899D7E8B9F7E8B9E7F8BA0
828EA3818EA4818EA4828FA38591A48793A48A94A78B95A98A95A88C98A98E9AAA8F9AAA
8E99A98F9AA9919DAA919DA9919DAA929FAB94A0AD94A0AD94A1AD97A3AE98A4AF9AA5B0
9AA5AF9CA6AE9EA9B09FA7AE9FA7ACA1A9ADA1AAABA2ACA9A3ADAAA2ABA9A1AAAAA1AAAA
A1ABAA9FABA99FAAAAA1ABAAA2ABA9A0AAA79FA9A69DA8A59DABA46D757744474E434747
3E433E42473F41473F6C7A67535E5449514C434B46323735313833475242535F4A505A47
4F5546494F443F423B68766390A4878898808C9B848C99848B98828F9E8540413B1D181C
2522211C1B1813130F0E0F0B0E0F0C292F2568795C7B8D6D8394745F68586B7666717E6E
71806E717F6D71816D616E5C3F463D505B4A343C302B3226272D1F232A1C232B1C262F1D
262F1C28311D2D3520313824
4757694A5B6E4E5E73515D74515D75515D75535F76545F7854607A55617B566179576279
58637959657A58657B5B677D5C677F5C687F5B677F5C68815E69835D6A815E6B7F606D80
606C80616D806270816573816978846C7B866D7B886D7A8A6F7A8B717B8E717D90727C90
717C91727D91727E91727C92737E93757F94757F94757F94778196798398788299778198
77829978859B7A869A7986987A86977C88997C889A7D899B7E8B9D7E8B9E7F8C9E7F8C9F
818DA0808DA1818EA2838FA38491A28793A48994A58A95A68B96A78C98A98C99A88D9AA7
8D99A68D9AA78E9AA7909CA7919EA892A0A894A1AA94A0AB95A1AC96A1AC98A2AE99A3AE
9AA4AE9CA6AE9DA7AE9EA8AFA0A9AEA0AAACA1AAABA2ABAAA3ABAAA3ABABA3ACAEA2ABAE
A1ABADA0ACABA0ACABA1ABABA0AAA99FAAA79EAAA59CA8A09EACA1767F7E41424B3C4043
383D3B3F463F4951478194795E6A5A475046454D44323632333830444C3E4B53444F5747
5057484C51453C3E39646E5F94A78A8A9A808D9D838B9B838A998191A286484B43181215
201E1C1A1A1816161412140F12140F161711262A1E525C44829571717F6676836D788771
77867175836F7584706F7E6A63706063725E394035262B21262E1E232B1A242C1928311C
29321D2C3620303824333926
49576A4B5B6E4E5E724F5D72505C71515D7254607655617856627A556179566278556176
58647758667A59657B5A657C5D677E5E68805E68805E6882606A83606C845F6B825F6B7F
606C81626E826471836875846C79846E7C856F7C886F7B8B707B8C717C8E717C8F717C8F
717C91727D93707D94727D95737D94737E93747F94758196768095778296788398798399
78829979849B78849B7B889B7A86997A869A7C889B7D8A9C7E8B9D7F8B9D808D9E818D9E
828E9E828EA0828DA1838FA38390A28491A28794A48A97A48C98A58A97A48B98A48C9AA3
8D9BA48F9BA68F9BA7909CA8919DA892A0A794A2A995A2AB96A1AC97A1AC99A2AD99A3AF
99A3AF9DA6B09DA6AE9FA7AEA0A9ACA0AAACA0ABABA1ABACA2ABADA2ADACA4ACADA2ABAE
A3ACAFA2ACADA2ACACA2ACAC9FABA99FABA89FAAA69DA8A39EACA1818D8544474C3B4042
3537373A3D3850584B7D8C72687460485045464E433135302E2F2A454A3C4D5443515947
525A494F554740423A5E665795A8898A9A808D9D858B9B848A998293A689586151161111
1E1C171816131515131314111314111414111A1A14353B2C6E7E5F57614C6C7960728067
73806974816B7886707686716E7F6B6E7F6A3A4138292E242B3223272E1C272E1A29321D
2B331F2F3622343925333926
4954664C596A4D5B6E4C596D505C70535E73545F76546078566179566279566278566177
58647959657B5A667C5B667C5D677F5D67805D667F5D66805E6882606A835E69815E6A80
606D81626F826673816D79836F7A83707A83707A86717B8B727C8F717C91727D92737E93
727D93737F95727E95737E97727C95727D95757E97768097757F95757F93768093778195
77819579839879849C7B859C7B869B7A859B7D869E7D889D7E8A9C7F8B9D808C9C828D9C
838F9C828D9B838D9C848F9E8390A08491A28794A48A96A48A96A38B98A28C98A38C99A3
8D9AA38E9AA4909CA5909CA6909CA7909DA6919FA794A1A996A0A997A1AA99A1AB99A2AC
9BA3AD9DA5AF9EA6AF9DA6AE9DA7AD9FA9AC9EAAA99EAAA99EAAA99FABA89FAAA7A1ABA7
A2ABA8A2ABA8A3ACA8A3ACA7A2ADA6A0ACA59EAAA49DA8A29EADA286938B474A4F414545
36373738393652584C68745F616B59555E4F41473F2F322F2C2D294043364D5341525945
535A474E5444464A3C5A614F96A7878C9B818D9B858B9B868A9A848EA1875B6455191516
21201B1E1B181C1A1815141212110E12120E16150F363C2A4C573E35382A3B3E316B775F
6E7B65717F68788870798B7073866C708167353B302C31262C3124272D1F262C1C29301E
2A311E2C3220303624333827
4751674955694C596C4F5B6E515B71545E76535E7A535E7A535F7A546179556278566379
57647A58657B59667C5A677D5D68805C677F5C657F5B657F5D66805F68815E68815C6881
606C816370826875826F7B85707B86707A87717B89717B8B737D8F727C91737E92747F93
727E92737E93727D93727C94737C95737D96747E96747F95747E94767F94758092778294
7782937782947884987883997A83977D859A7D859C7D869C7D889C7E899B7F8A9A818D9B
838E9B858E9C858F9E858F9E86909F858FA18892A28A95A28A96A18B97A18C97A28D98A2
8D98A28D99A38F9CA3909CA3929EA4919EA5919FA592A0A695A1A797A0A698A0A798A1A7
9AA3AA9CA4AB9CA5AC9BA4AC9CA6AC9DA8AC9EA9A99EAAA99EAAAA9FAAAAA0ABA8A0ABA7
A1ABA4A0AAA2A1ABA3A2ABA3A1ACA2A0ABA19DA99F9BA89E9EADA189958D484A50424447
363537383A395862555962545A6453545E4F4D5649393D3930332F3E44374B5442515946
5158454B503E464A3B5259488FA2818D9D808C9C848D9D868C9E868FA2885C6557191518
211F1D1D1B191A1A1714141110120D11120C12120B343B294D593D2F31211C181368735C
74836B6F7F6B768871798C72768A6D738768363D30292D25292D23272A21262A1E282D1E
2A301D2C311D2F3420313624
4A54664D576A4F5A6E4F5A71505B73515C75525D78545F7B54617B535F7955617A56637B
56637B57647B58657B59657C5B677E5B667E5B66805B65825D67835E68835D68835D6982
616D846571856975856E7987727D8A717C8A717B8B707B8C717D8E717D8F737E92727D93
717D92717D92717D92717D93737E95737E96758096758196758195758193768192778393
78849478839579839979839B7B839B7E869B7D859A7E869B7F879B7F899C808C9C818E9B
818E9A838F9C848F9E868FA08790A28790A18892A18A939F8A96A08B97A08B979F8B979F
8C99A08D9BA18D9CA08E9CA1909EA3919FA592A0A8919FA795A2A897A2A798A2A799A2A8
99A3AA9AA4AB9BA5AC9CA7AD9CA8AB9CA9AA9DAAAB9EAAAA9EA9A8A0ABA9A2ABA8A2ABA5
A1ACA4A0ACA4A0ADA49EABA49EABA39FACA29DAAA09DAB9E9DAD9F8D9B904A4D52404447
37383A37373850564C4E5449555E504C56484C5749454E43353B3440473A4953414D5743
4F58444B51404144384144398B9D7E8C9E818A9B818B9C848699828A9E84616C5C1D1A1E
2220201D1D1C1A1A1717171316161114150E14160E272B1E5D6B4B3E422E24221C66735D
74856E6E7E6E748574798C757A8D73788B6F3F463C292D273032282D2E242A2C212A2E1E
2B301D2D331E303621333723
4851634C5568505A6F505B72515B75515C77525C78545E7A545F7A55617C56627B56637B
56647B58647B59657C59667C5B677E5B677D5A657F5B66825D67835F68845F6984606A84
636E866772866A74876F7A8A737E8C737F8C737E8C727D8D717D8D707D8F717D91737E92
727E92707D906F7C90717F92727E93747F95747F95737F93758293758192758192768292
7783957983997A839C7A839E7D839E7F869D80879C80879C80899C808A9C808A9C808C9B
808E9B828F9C848F9B848E9B87909E87909E88929E8A95A08B96A18C98A28B98A08A979D
8C999D8D9CA08E9BA18F9BA38F9CA5919EA7929FA9919FA893A1A994A2A998A4AA99A4AB
98A3AB98A3AB99A4AC9BA6AD9CA8AB9CA8A99EAAAA9EA9A89EA9A7A0ABA6A1ABA3A2ACA3
A2ACA3A2ADA3A1ADA49FACA39EABA29DABA19EABA09DAB9D9DAC9C92A1944C4E523E4146
36383D3131334F554A4A4F45494E45464E424B5648475243343B303A433548533E4A553E
4B563D474E393B3D3033342B8091748DA0828A9B818A9C85859883889C856B7A691F1F23
24232321201E1E1E181B1B141A1A13171911191A1320241A2F35272F322840483A718368
75876E71826E748571798C757C8E767D8F754850452B2D2834372D2F31262B2D22292C1E
282D1D2C31202F3423313725
4951644B53674E586C4F5970505A73515B76515B77535D7A56617C56627D56627D55627B
56627C58647C59667C5A667D5A657C5B687D5C687E5E6980606981606880636B84646C85
646E856772866873876D788A727E8D76828F78849076818F748090747F92737F91737F92
737D92707B91727C92737F93727F92727E92748094737F92758092748091758092778394
7682947782977882997A839B7C849D7E869E7F889E7F889D7F899D818B9F818C9F818D9F
808D9F818E9D84909D85909D87919F87919F8892A08994A28A96A38B97A48B98A38C98A2
8C99A08E9BA28F9BA3909BA5919CA8929EAA939FAB93A0AB95A0AC95A1AB97A3AC98A4AC
9AA4AC9AA5AB99A4AA9AA5AB9CA8AB9DA9A99FAAA9A0ABA8A2ACA7A2ABA6A2ABA3A0ABA1
A2ACA0A3AEA1A1ADA1A1ADA2A2ADA2A0ABA1A0ABA2A0ACA09FAB9C9AA898555759414246
3B3E40323234494E444E5346494E43484E434F5A4B434C3F31362C353B2E515E454E5A41
4D563E484E393E4133302F2A78866E8FA1858A9B838D9E88899A858B9D877F8F7C29292D
222022211F1D2120181E1D1319190E14150C16170E20241821241A1F201A21231E6C7D62
76896D71816A7888707D8D747E9076849578565E4E2F3029383A3132362E2D31292A2D24
272C1F2C31212F3525323728
4751654953684C586B4E596D4F5A70505A73515B76525C78535D7955607B56617C55617B
56627B58647B58657B59657A59667A5A677A5A677A5B677C5D687D5E697D626C82636D83
647083667385667384697586707E8C768590788793778492758392748092737F93727E94
737D95717D94717C93717F94707E93707E92727E92727E91758091758091758091778391
7885927884947883967A85997D869B7A849B7B869E7A849D7B869D7E89A0808A9F808AA0
818AA0838CA1848EA0848FA0868FA085909E85919F8692A08793A18894A18A96A38C98A5
8D9AA48D9BA58F9CA6909DA6919DA8929DAA929EAB939FAB95A0AD96A0AC95A0AC98A3AE
9AA4AE9AA5AE9AA5AC9AA6AC9CA8AB9DA9A9A0AAA8A1ABA8A2AAA8A2ABA8A2ABA5A1ABA3
A1ABA3A0ACA29FACA3A1ACA4A2ADA5A0ACA49FABA49FABA39CAA9E9CAC9C5E6261444549
4546463635373F413C474B404C52444D5647525D4D4B5648363E34373F315A694D57654A
505B444D5440464A3C363733707C6A94A78E8A99848C9B878998868C9B888593802C2A31
211E2323221F2020171D1E121B1B0E13140A13150B1F221721261C23291E1515115E6C54
76886B6D7E6678886F7E8F74819277819376535A4B34352F3A3D34363B303035292B3023
2A2E202E3221333726333626
464F6549536A4C586E4D596F4E5971505A73515C75535D77535E7755607957647B56627A
57647B59657B58657A58647959667A5A677A5B677A5A677B5C687C5E697E606A81646F86
6572866674836674816775836C7B8771828D748591748491738190727F8F717D90717C93
727E95727E96707D95727F96727F95727E95737F94737F93758192768291778491778491
7986917884907883917A85957C86987B869A7B889D7B869E7C88A17E89A27E89A17F8AA1
838CA4838CA4848DA4868FA4868FA38691A18692A08793A18895A38A96A38B97A48B98A4
8C99A68A98A68A99A58D9BA58F9DA7919DA9919EAB919EAB929EAB939FAB95A1AD96A2AE
98A4B09AA5B09AA6B09CA7B09CA6AD9CA7AB9FA9AB9EA8AA9FA9A9A0AAA9A2ABA8A3ACA9
A2ABAAA1ACA9A0ACA9A1ACA9A0ACA89FABA8A0ABA99EAAA69AA8A19BAB9F656C6A414247
4245433434343E413C454B424D564A515C4E535F504E5B4C3D4A3C3A46355A6C5059684C
5360464C564042473A3A3B3775836F95A88D8B9B868B9A888896858B9A868493802E2B32
201B232321211E1E171A1A1018190D14160B191B10272C212F372C2E352A292E255C6A54
73856C6E7F6874856D7B8C737F90778093784F584C3539323A4135353B2D3036262D3222
2B301F2F3422333625333725
47516649546A4B566D4D57704F5A73515C76525C77535D78545E79555F79566078566179
56617A57627C58647E58647E58657D59667C5A677C5A657C5C677F5E69815F6B83646F87
6572886674876674866775866876876B7A896E7E8C707F8F727F90727F91727E92727C93
717C94727D94717C95737E96747D97727C96737E96737F95748095758193788593798593
7884937784927783927884947985967B87997B889C7C889D7C889E7B879F7C86A07E89A1
818BA3818BA3838CA4868FA5868FA38790A08893A08993A18994A18894A18995A38995A2
8A96A18A96A28B97A48E99A5909AA6929DA8939DA9939DA9929DA9939FA996A1AA96A0AB
97A0AE98A2AF99A3B19BA5B29DA6B09EA8B09FA9AF9EA8AD9EA9ABA0AAAAA2ABABA2ACAC
A2ACABA0ACAAA0ACA89FAAA79EA9A69EAAA79EABA79CA9A499A79F9CAD9F717B733C3E40
3D413D2F312F4349404B54494C564B5563544F5D4F3F4A3E354034323B2F596B505A6B4E
5260464B5740373D3033352F76866D95AB8C8A9A858B99888A97878B9A88839180333236
1B161D1F1C1F1B1A181B19141A19131718101C1E142D3326444F3D363F324A574760705C
6E806971836B73856F7688747A8C767B8E77525E51373D35394033343C2E3036262E3422
2C32222D3322323826313725
4953674A566B4C586E4E576F4F5972525D76545E78535C79555D7B565F7A586079576179
58607957607A59627D58627D58647E59657F59657F5B66815D67835E68855F6A86626E89
64718A68758C68768C69768D69768B6B788B6E7B8D707C8F717E92707D92717D91717C90
717B92727C93737C96747D99747D99747D99737D99747D97767F97768096758094778295
7681957783967884967984977985977A86997B889B7C889D7E8A9F7E8A9F7E89A07F8AA2
7F8AA1808BA1828DA1838FA0858FA087919E88919E8994A08994A18893A08994A18A96A2
8B96A18C96A28E98A28F9AA3919BA4949DA5949CA6959DA7959EAA949EAB94A0AA95A0AB
98A2AD99A1AE9AA4B09BA4B29BA4B09EA8B19FA9B09EAAAE9EAAAC9FA9ABA1ABABA0AAAA
A0AAA8A0ABA9A2AEA9A0ADA69FACA59FABA49FABA39DAAA19BAA9D9CAD9C737E733B3D3E
3D423E30313043483E4E584A515C4D53605041493F333A31282F28272E26596A515B6F53
49594349564031362A2D2F28707D6795A98B8A99838D9B888D99888C9B8984948336373A
18131A201D1E1E1C181F1D171C1B161616121818112F34275F6D545965514A5447586557
71856F71836E72846F71826F6E806C72876E53604E353A30383E30353B2E3137292F3525
2E34242E3524323926313824
47516848556D4C5A714D5A6F4E5A704F5A71505B73535D77545E78535D76555F76566177
57627857617859637B59647C59657D5A66815965805B65815C67845E6886606B88636E8A
64718B67748D69768F69768E69768D6B778C6D7A8D6F7B8E6F7D916F7C92707C91707C8F
727E92727D93727D95737D99727C98737D98747F98737D97757E96778095747E94757F94
7580947782957886987885987B869B7C879D7D889E7B889E7E8A9F7F8C9F7E8B9E7F8BA0
7F8BA0808C9F808E9F818E9F848F9F86909E88919F8892A08995A08995A08995A28B98A4
8C9AA58C99A48D9AA38F9CA3909CA3929DA3939EA5949FA8949EAB939FAC94A1AD95A1AE
97A2AF98A3AF99A5AF9AA3B09AA4B09DA8B09DA8AE9DAAAD9EAAAEA1ABAFA1AAAEA1AAAC
A0AAAA9FABA9A0ACA9A0ADA89FADA6A0ACA59FACA39EABA19BAB9D9BAC9A7480743F4443
42474336393740473E4F5A4C505C4E535F5140493F38403531392E2D34294D5B4556674C
46523E48554033392C2F312A6D796592A3888998818D9D878F9E8A8E9D8985968237393B
1A171D2220211C1B191B1A161919151516121A1E172931247085656B7E62677863454E47
7B91797288736274623F4B42414E436B816557664E31372A383E2E363B2B333828313725
313724333926343C27323B26
45536846556B48586E49596F4B5A6E4D5A704F5C72515D74515E75525E74536074546074
55617556627857637A57647C58657E5A67815866815A66815A67815C68825E6984626F89
64728A65738B67758C67758C66738A6A778B6C798B6E7C8D6D7B8E707D91717D936F7D93
728095727E94707D94707D96707C96707D95717D94727E94737D94758094758195737F93
737F9075839376859777859878869A7A879D7C899F7B879F7A879E7E8A9F7E8B9D7E8B9D
7E8B9E7E8B9F7F8D9F808D9E838E9F8690A08590A08592A08694A18695A18796A38998A4
8999A48B9AA58C9AA58D9BA3909BA4909CA4919EA6919FA892A0AC92A0AD93A1AE94A2B0
94A1AF96A3AE98A5AE99A5AE9BA7AE9BA8AE9AA8AD9AA8AC9CA8AB9EAAAD9FAAAEA0ABAD
9FABAB9FABAA9EABA99EABA89EABA89DABA79CABA49CABA198A89F9AAC9E7B8980444A4C
3F4445393C3E3B413F464F474B584D5563544B57493C473B373F3534382E383F30414B37
3A42303F4836383E312F302B60695992A4888896828C9C898E9F8E8D9F8C879987393D3F
1410191D1C1E171516151412151611121410252A222F372B5E70566F856763745F454E47
7A8E79768C7659695B161A1D1A1E1D3C463649543F34392B373C2E363B2B343A28323725
343A25363B27363D28343B28
48566649576A4B59704A58714C59724C5A734E5B72505C74505E76525E75525E73525E73
535E7355617656627957647C57647D59657F59658058657F59667E59677D5C697F606E84
63718663728765748967758B68768B6A778B6B778C6D7B8E6D7B8E707D91717E93707E94
6F7D93707E926E7D906E7C916F7D92717E93717E92718092728093748194738095728094
72809274849476859577869977869B78859C78869B7B879D7A879D7C889E7D899F7C899E
7D8B9E7D8A9D7D8A9D7F8C9D818E9D838F9F838FA08491A18493A18493A18595A28797A3
8998A48A9AA78D9AA88E9BA6909BA68F9BA7919DAA909EAB919EAD90A0AE90A0AE92A1AE
93A2AD93A3AD93A3AC96A4AC98A7AD99A8AD9AA9AD9AA9AD9CABAD9CA9AC9EA9AD9FAAAD
9EAAAB9EAAA89EABA89EAAA79DABA79BAAA79AAAA59AAAA498A8A19AABA17A86824B4F54
3C4046454C4A464D47404741505C50556253485244363C3333372F2F33292B30242B3021
2B301F313625383D2D31332A626C5990A2858795818A99878A9C8A899C8B829485313439
16131C1A191D15141414120F15130D13120E272B223033295F6C55778A6E687763637063
708071778B795260540E101516171A1211112528202F3426323629333929323927323826
343A26363C29373C2C35392B
4751634954694B56704C57734C56734B56714D59734F5B75505C75525D76535F76535E75
525E74535F76545F7754617A55637C58647E59648058647F59667F59677E5B6B7F5F6D82
61708264738564738667758868768A69778B6A778B6E7B8E717F91738093738095707E94
6E7D936E7D916D7C8F6E7C8F707C90717C90717D91738093728193718092728094738095
74819576839577859678859979859C78839B7884997A879A7C889C7D899D7E8A9E7E899E
7D899E7F8B9E808D9E808D9D818F9F8290A08290A18391A28291A18393A18594A28594A2
8795A38A98A68D9BA68E9CA68F9BA6909CA88F9CAA8F9DAC8F9EAE8E9EB08F9FB0909FAE
94A3AE95A4AC96A3AC95A3AC98A6AD99A8AD9CA9AE9DA9AD9EAAAD9DA9AC9DA9AC9DA8AC
9EA9AC9EA9A99EAAA79DAAA79DAAA89CAAA79AA9A599A9A397A8A09AABA27B8683494C53
4044484046443D433C32362F4852435A6753535E4C3A40373237302F332B2E33262A3020
262B1A2A2D1B37392734342A60695796A98B8A9A828C9D878B9C87889985839582343839
15131A1B1A1C18171717171417161215141020211928291F616D5376876A6F7E6673826C
72826E7A8D78586459111119110E140F0A0D201E182F3225313424323624343A26343926
343A26353C27363D2B363C2E
464F644952694B556F4C55724D56734D56734D5673505A764F5B76515D76535E76535F76
535E76525D77535F7954617B53617B58647F58657F59667F5966805966805B68805E6B80
606D7F627082657385667485677585687687707F8E7B8A987E8D9D7C8A9C768399707D96
707D956E7D936D7C926F7C91717C91717C91737D92737F93737F92738091738091748094
7581947781957782957783957884977984987985997A869A7B879C7C889D7C889F7D889F
7F8A9E7F8B9E808C9C808D9D828EA0838EA1848FA18591A28592A28592A28592A28694A3
8896A38B97A38D99A38D9BA48E9BA58F9CA7919DAA909DAC8F9DAE8F9DB1909FB192A0AF
95A2AE95A3AF96A4AF97A5AE98A5AE9AA7AD9CA8AD9EA8AC9FA9AB9EA9A99EAAA89EA9A9
9EA8AB9EA8AA9DA9A99EAAA99EAAA99DAAA99CAAA69AAAA498A8A099AA9F85938A45484D
4045463438382E32302425233B42375F6D575965504B56463F463A383D3233382C2E3426
2D32234F583F41443437383153594E94A78C8A9C858A9C858B9C86889882879681454845
16121A201F201D1E1B1C1E191A1B1717171316161024271A5762487B8E6B70816574846B
76856D7787717584713639391C1A1D1F1C1C22201A303123313322333724333825343A26
353B27353C28383E2C373C2D
4850634A53694B556F4C55714D56754F58774F58754F5B76515C77515C76535D76535E77
535E7853607A55617D56617E57627F58658057648058667F59667F57647E5A67815C6880
606C81606D816370846572866674866C7A8D798A9B8294A38697A7808EA378849D717E98
707C946F7C916D7B906E7B906E7B8F6F7C90737E92737E92737F91748093748093758094
7480947681957682957783957985977985987B889B7B879C7B889C7C889C7C889F7D88A1
7D8AA27E8BA17E8B9E808D9F818DA0848FA1848FA3858FA38691A28893A28893A18994A0
8A96A18C9AA38D99A28C99A38D9BA48F9CA6919DA9909CAB8F9BAC919DAF929FB094A1AF
95A1AD96A3AD97A4AD98A5AD99A6AD9AA7AD9CA8AA9CA8A99EA9AA9FAAA79EAAA59EAAA7
9FAAAA9FAAAC9EAAAC9EABAC9DABAA9DABA89CABA59CABA49AABA29AAB9F8FA092474B4F
3B3F402F31322A2D2D2425263439345E6C595865525764524E5A493D4537353B2E2E3327
2C30266C7B5E43483A3A3C364C50488E9F868E9F888C9D878EA0898A9B83899A8051564E
1B151C2321231D1C1C1C1B1A18191717171517181322251B505C457F947172836874856C
76866F7586707588716D7D6855615159665149544134382A3B3E2B383B29313525323726
333A29343C2A373F2D373E2E
444E5D4750644A526B4A536F4C55744E56764E58764E5977505B78505B78505C78515D78
505C79515C7954607B545F7C57627F59648058657F58657F58667F58667E5B68815D6983
5E6A835F6C846370876470886670896F7D937C8CA08091A48091A47C8BA077839A748098
727D94717C906F7B8E6E7A8E6C7A8E6C7A8F6F7C90717D90727D91727E92737F95758097
76819875819777839776829776819776829878849979859C79869D7B889E7C889E7C899F
7D89A17D89A17F8B9F7F8DA0808DA0828E9F838DA08590A38790A58790A58791A38893A1
8893A08996A28A97A28B97A18C98A28E9BA48F9BA68E9AA78F9BAA8F9BAB919DAD939FAD
939FAA929FA993A1A994A3AA98A6AB99A7AA99A7A999A7A99BA9A99DA9A79DA9A69CA9A6
9EABA89FABAA9DA9A99BAAA99BABA89AAAA69AAAA29AAAA199A99E99AB9C90A3934E5756
3D42413134322C2D2C2B2B2B3437325B6856586554566252525E4C454F3F3840312F3628
2C302434382A33342935342E494B4490A28891A28B8E9F8990A28B8B9D868B9C835C6457
1A141A2421221E1B1C1A19181716151717141A191621201B464D3D84997674866C748670
74857374847273856F75896F75896E76896C65735B393D303F4331383B2B2F33252E3325
313728333B28363F2A343B28
444F5D4751634A556A4B55704D57754C57754C57754B57754C59774E5B794E5B784F5D78
4E5C77515D78525E79545F7A55617B57647D56647B55637C56657E57657F5867825A6883
5B68835E6A84626E87636F8865708A6B769175819A78869E78879D748398728095717D94
707B926F7B916F7B926D7A916D7A906D7A906E7A90707C91727D93727D93737F94747F96
747F9875809875809774809875819977849B78849B78859B78879E7A89A07B89A07A89A1
7B89A07C8A9F7E8C9D7F8D9D808D9E828F9F848FA08690A48790A68590A78590A68693A6
8793A48794A48897A58997A58998A48B9BA58C9AA78C9AA88C9AA98E9AAA909BAB929EAC
929FAB92A0AA90A1A991A2AA93A3A995A6A897A6A999A7AA9BA9AA9CA9A89BA8A69CA8A7
9EAAA79EACA99CABA99AAAA79BABA79BABA599A9A299A99F97A99C97A99993A79657615F
454C4C35393A3032313639353C413A576353576554566351515C4B4854433943362C3429
2C31262B2E242929212825213F3E3998A98E9AAC938F9F8B8EA08B8C9F8A8D9E8A6B7668
1D1A1F2223221C1C1B1C1C18191A13191A1117150F1F1E17424838899E7C74866E738472
72827673847772857272896F72896C758B6C5D6B5540463A3F4639383E3133392C30352A
31372A353C2C373F2B353C2A
434E6047516649546C4B54704B56744956734956734C59744C59754D59764C59764D5B76
4F5C76505C77525C79535E7A54617A54627B55627B54607A55637C55647F576681596782
5B67825D69835E6B84606D86626E8865708A69768D6E7B926F7D936E7D936D7B936D7A91
6E7B936C79926B78936A76926B77906D79916E7A916D79916E7A92707B93717D94717E95
727E97737E98747F99747F9975819976829A77849A77849978869B7A899F7A89A179899F
79899F7A8A9D7C8A9C7C8B9B7C8A9C808C9E838FA0848FA28491A58491A58391A48593A5
8694A58794A48795A58997A68997A68B99A78C99A78B99A88D99A98F9AAB909BAB939DAD
959FAD95A1AD94A2AB93A2AB92A1A995A4AB97A6AC99A6AD9AA7AC9CA8AB9CA8AB9EA8AA
9FA9A89DAAA69CAAA69AAAA59AA9A699A8A39AA9A39AAAA198A89D96A79994A7965A6561
464D4C3032362F32323B413C404841596556596656576454515C4D4F5B4B454F432D312C
30332E2C2D28272421231C1E3834339DAD91A2B49992A18C90A08C8F9E8A8E9F8A6C7869
1D1C202323231D1E1A1D1E17191A1117170F16140F23221A4C52418FA58073876E708571
6F83786A7F7777928159705F5F76616B81695865563F48403E453B373E3332392D30372C
30352B343A2D373D2D333B29
424E6345506746526C4A54704A54734852734752734853734854734B56744D59744E5A75
4F5A754F5A754F5A77515C79535F7B53607B54607A535F7955617B56627E576580596680
5B67815B66805C68815E6A83606C84626F8564728767758969778B6A798E6B7A916B7992
6C78956A75946975946B76956B76926B76906C778F6D78906F7992717A93717B93737D95
737F94727E9672809873809775819775819776819876819976829A78849C78859B79869A
7A879B7B879B7C889B7D8A9B7D8A9C7E8B9F818DA1818EA1828FA38390A38390A38390A1
8492A28593A38693A38996A68A97A78A96A88A97A88B98A98C99A98D99A98F9AAA939DAB
959EAA94A0A9939FA894A1AB95A1AE97A3AF97A4AE99A5AE99A5AE9AA5AC9BA6AC9DA7AB
9DA7A89CA7A59BA8A49BA8A59AA6A49BA7A39BA9A19AA89E98A79C96A69992A494545D5B
3A3E412E30342D3030393F383E463C5C6A585A6656586253525B4F4F574C4F574B3F433C
3637342B2828262022231A1F373233A0B094A4B59A93A38D90A08D8E9E898D9F87677365
18171C2021211C1E1B191B1518191017180F16160F1E2017444E3D7E95726A80646A8067
718772586860718878697E6C3F4B446B7E6A5360543D443E3C433A353D3232392F333A2E
33392D353A2D363C2D343A28
404C65424F6845516D4853704A53734A53744953744854734854714A546F4B566E4D5970
4F5B704E5970505B74505B77515C79525E7A535F7A545F7A56627C57637D58647F596580
5A64815B66835D68835E6983616D85626E84626F8564728866748966748B67768E687490
6874916975926A75936C76946D77936B76926B77916E78916E7890707A91717B92727D94
727D93727E94727E95737F957682977783977982977B849B79839D77829B77829A7A859A
7C879A7C879A7C869A7F899C7F8A9D7F8A9E818BA0808BA0828EA1828EA18390A18490A0
8492A08492A08592A18894A38A96A58996A78996A88B98AA8B99AA8C9AAA909BAB919CAB
939CAA939DA9939DA996A0AB97A1AD98A2AD99A3AD9AA4AD9CA5AD9BA4AC9BA6AA9BA6A9
9AA6A79AA8A59BA8A49AA7A499A5A29AA7A19AA69F99A59C98A69B96A69991A193525858
3032393437392F323131342D41483A5E6B5459634F52594A4A4D444A4C4454584E494A44
3F3E3D363335342E3130292D433F3F96A48D9FAE9695A59090A08E8C9D8A8A9E88677567
1A1A20212324191A1A191A1418170F18170E17180E23271A30392B4653405C6E56667C60
596C54586A5363765E91AB88566455536054505F522C322E363B33363C30353A2F353B30
373D30383D2F373C2F33392B
414B64434D6848526D4A54704A54734A53734A54724B56724B55704B556F4B566F4C586E
4F5A6F4F5A70515C74505C75505B764F5B77505B76525D77535E7956617A57627D596381
5A63835C66855E68855E6A84606C85626E86626E8763708963718A64718C65738E66728F
6775916875916975926A76926C77936B77936C7A936B78916A77906D79916E7992707C93
6F7B93707D95727E97717E95747F977680987882987B839A7B839C78829D78839B798599
7B85997C86997D869A7F889C7F8A9E808B9E828B9F828C9F848EA2838FA38591A38491A0
84939E8594A084939F85939E8795A18795A48997A78A97A88A97AA8C98AB8F9AAD919BAD
929CAD929DAC939FAD949FAD97A0AD97A1AB99A2AB9BA4AC9BA4AA9CA5A99AA5A79AA5A7
9AA6A79BA8A69AA8A69BA8A69AA7A59AA6A39AA7A299A7A097A69D95A59A96A7995C6262
313136363A373234303131294044365D664E565E4A45483E3938374848475D615B61665E
4C4D4C4748484544424543404D4D4A88948098A69096A59190A08E889A88889B886C7C6E
1B1B202021211D1D191C1D1518160D17150B15140A2327182E3525343D2D3F4C394F5F47
2A34272F3C2C26302584A07B72896A252B24455242191B19282B232D312730342A34382E
373C2F383E2E373F2E323929
414A61434D67464F6C48516E48517048527049527049526E48526F4A54714C55724B5571
4C57704D58704F5A734F5A75505B784F5A78505B78515C78525D7754607956617B58637E
5963815A64845B66855D68835E6982606C84606C85616E8763708A636F8E647290647191
6572926672916672926774936974946A75946B77946B77936B76926C78936D79946E7A96
6D7A966E7B976F7D98727F98747F98747E98747F9977829A778099767F99768199778398
7984987A86987B869A7D869B7E889C7F8A9D828B9D828B9D828C9E838DA0838EA182909F
83929D83929D84939D84939F8493A28594A38796A68896A78A97A98C97AB8E99AC8E99AD
8F9AAD919CAD929EAD939FAE94A0AD95A0AB97A2AA99A4AA9AA5A99BA5A89AA4A69BA6A7
9AA6A69AA6A59AA8A699A8A798A6A698A5A597A4A396A4A296A59F95A49A98A899666F6A
3433393D403D393B3635352F3D3F36575F4C575E4E4C51463B3E39586156616C62829381
606960595F584445444B4B484B4A497E8779919F8C91A08F90A08F889787869784718070
1E1F242122221D1C191C1C1518180F14130B13120B1F22162D3525384331313C2C20271C
1B22181A21160F140C607655657B58151A122E372A1416121F2119272A212D312734372C
383C2E353B2C343A2B2F3627
414A5F434C65454E6A47506D48526F48517049537249527048516E4B54724C54734C5573
4B55744C56734E58754E59755059774F5977505A78515B79525C79525D77545E7956617B
57627D5963835A64855A64835C67825E6983606B85616D86626E88636F8B636F8D636F90
636E90636E916470936572956672956873956773946974956B76956C79946C79956D7995
6E7A936F7B95707C97727D97747E96747E98757E9A757F9A77829B76819B75819977839B
77839977839978849B7B869C7C879E7D899F7F899F818A9D838D9F818C9E818D9F8290A0
82909E81909D82919C8392A08492A28695A68694A88895A98994AA8B96AB8A96AA8B97AC
8D99AD8F9BAC919CAB929EAC929EAB939FAA94A1A896A3A897A3A698A2A59AA4A799A4A6
9AA5A699A5A69AA8A899A7A997A5A795A3A595A3A394A3A195A4A094A49B98A99A6B746F
37373E4042413A3C39323431454A4052594C555D4F4F594C40473F535E51636F61849680
81907C7C85753E3B3E4845473D3840777F76929F8F8B988994A3918D9C8A899885798777
201F261E1D211C1B1A18181315150E14150D16170F252A1C262C1E242B1E22281C191F16
161C14161C1112170C2B362338452F1218101C221A141813131610252B1F2F3627333B2A
373E2C363E2B333A292E3324
414A5D444D62464F6949526E48526F4850704A53734B54744951714A53724B53734B5272
4B54744D56754D56754D56754E58764E58774F5977505B77525E79515D78535E7A55617D
5661805863835864855A64845C66835F6984606984606A84616C87626E89626D8B626D8D
626F8F636F90626F906371916573926673926672926974946B76946A75946B76946D7993
6E7A91707A92717B94727B93737D93747E95767E97777F9877819976819A74809A77829B
78839A78839A78829979839A7C869C7F879E81889F838A9F858D9F828C9F818C9F838EA0
8491A18593A28592A18591A28792A38894A58996A68996A78996A88B97AA8B96AA8B97AB
8E99AD8F9BAD909BAB919DAC929EAC929EAA93A1A995A1A997A2A697A1A598A2A798A3A7
99A4A798A4A699A6A699A7A897A4A696A4A396A4A296A4A296A5A196A59D98A89C737D76
3C3D424145443A3E3D333735393E39464E42535E4C454D42323634505851636D63869581
8D9D879AAA914B4A4A3D383E35303A6D746F90A0908794878F9F8E90A18D8A9C87798977
1F1F2419181B17161613120F11100A11110814150A2025172127181F23171E2116191E13
171C13141A1112170E12160F11151013181215191312161110140E20271A2D3624313A27
343E2A333D28333C262F3723
40495B434D6246506948516E47516E48516F4952724B54744A53724952724B54734A5272
4B53724C55744D56754D57764C57764C58774E5977505D79535E7A525D7A535E7C55607F
5862835862855863835963815A65825E6883606985616986606B88636D8A626D8B606C8B
606D8B616E8C63718F6472916774926774926773926A75936B75926D77946D77936F7991
6F7A91707A90717B90727C91747F93747F94767F9677819977819977829B76819A768198
7783977983977B84987C84987C84987E869A81899C848B9E858CA0838C9F838CA0828CA1
828CA0848FA18691A38792A48792A48792A38894A38895A38795A38997A78A99A88C99AB
8E99AD8F9AAE8F9BAC909DAC929EAA939EA9959FAA97A1AB96A1A897A2A997A1A897A3A7
98A4A898A5A899A6A797A5A596A4A498A5A498A3A397A3A298A4A197A49D98A79C7B867F
3938414143453D403F37393A3336373D423D525D4E4B5448383B3850564F646B62849080
90A08DA4B89F636A6339373D3A393F646D6591A38F8695848B9C898CA08B889D877B8E7C
22252A13141918191916161314130E13120B12130A17190E1A1F121A1F121B2013191D11
171A111418111218121216130F121312151514181613171412160F1F26182A331F2F3725
323C29313D29323D27303A23
3E485E404C62434F68454F6A47506C47506F4851704852714852714953724A54734B5474
4A53734C55754B54754C55764C56764C58774E5A784E5B79505B79515C7A525D7C545F7E
5762815863825864825863815964815C67835F69845F6986606B895F6A89606C89606C88
606D8B616F8C63718E6370906673926874916673926672916975916A76916B778F6D788F
6F788F707A92717B93717B93727D94737E96737D96757F9A75819C75809B768199778398
7783967782957A84957B85967B85977C869A7F899C808A9D838B9F828A9F838DA1838EA1
828D9F848D9F858FA18590A28791A48793A48994A38995A38794A28896A48A99A78B99AA
8C98AC8E9AAE8E9AAB8F9BAB929DAA959EAA969FAB97A0AB95A0A996A3AA96A3A897A4A6
96A3A697A5A698A7A696A5A496A4A399A5A398A3A196A19F97A29D96A19A99A69A78807B
38333F403E444142444346453E403F3B3F3C545F52525C4F494F474D524A626B5F839280
8B9B8998AB957C887A4041453C3D43636D679AAF99879A88899D8B889D8B8A9E8B819483
282C3314151D191C1E191A1916171213130D11110B14160E181C12181D121B1F131E2215
1D1F161C1D171B1D1A1A1D1E1A1B21191921181A1F15171810140E2028192B3420313925
333C29333D2A323C2A323A27
3E485F404C65424E68444F68444E69454F6C464F6E46516F475170495171485170495272
4A53734A52734B53744D57774D58774D59774E5A784D59784E5979505A79525C7D535D80
565F815862825763825763815763815A66835C67845D69855F6B895F6A8B5F6A8A5E6A89
606D8A616E8A616E8B626D8C636F8E65718E6571906470906974926975916A768F6C768E
6E778F6F7A926F7A956E79966E7A95727E98727E98747F9B75809D75819B758099768197
7783977882977983987A83987B859B7C889E7C889E7D899F7F8BA07F8BA0818DA0818C9E
808C9E818C9E838C9E858FA0858FA18691A38792A38592A28593A38695A58896A58998A6
8B99A98F9AAB919BAC919AAB939CAC959DAD979FAD979FAA95A0A895A2A894A2A693A2A3
93A3A294A4A296A4A395A4A395A4A297A5A397A4A296A2A096A2A095A19C99A79C6D7370
352E3A3D38404140454A4E4D414644393D3A515C4F505A4E51594E4B4F485C635A849280
8A99858B9B84899882454547302D38646E6B9AB09D86998A8B9D8C8697878A9B8880917F
24242C1A19201D1E1E19191715151212120E13120D181A121C1E141C1D152B3122282D1F
20231727272027252542454432343927272D26282918191913140F242A1A2A321E2E3623
323A25333B27333D28303924
404961414B65424D69434E6C434E6A444E6B444D6B444D6C47506E47506F464F6E474F6E
4951714951714A53724B53724C55744C56754D57754E58774F5878505978515A7B515A7D
545D8057608156628158637F57637E5965805A65805B66825C66865E68885F6A895F6989
5F6B89616C89626E8A636F8B646F8C64708E646F8E646F8E67718F68728E6A748F6C758F
6D768F6F79916E7A936F7B946F7C95717D95727C96747E99747E9B747E9C747F9B747F98
7781977982997A83997983997A839B7B869E7C879F7C89A17E8AA27F8BA27F8CA07F8B9E
7F8D9E808C9E828C9E848E9F858FA18690A28691A28592A18693A38795A58795A58896A6
8A96A68D98AA9099AC919AAA929BAA949CAB959DAB969EA8959EA795A0A893A1A593A1A3
94A3A394A3A395A3A294A3A293A2A195A2A295A2A197A2A296A2A194A09D98A69D727976
2D263444414744434944474B3A3E42373C3C4C574D4D594D505A504347446B756890A18B
78847587968183927D41414329243262696798AC9A8A9B8B8D9E8C8997858C9B878D9E86
29272B1E1B1C1C1B1717161114140E14140E15150E1B1D131F22181919144049373A4234
2E322A5861523C3F3D59625B3E4245292A2F292B2A141414191C14282D1D292F1C2B321F
2F3624323926333C272E3925
41485F404862424B68424B6B424C6B414B6B424C6B444D6C444D6C454E6E454E6E474F6E
464F6E48506E49526D49526F4A53714C54734C54724D55744E56775058774F5A77505B78
535D7B545F7D55617D55617B57627A58637C59647D5964805B66835E6985606985616987
606A87626C88626C89626D89616D8B636F8E64708E65728F67728F68738F6A748F6A748E
6B758E6D778E6E788F6E7990707A92707C94707C96717C97727D98727C98737D9A748099
767F997881987982977882977982987983997B869B7D899E7E8A9F7E8AA07E8B9E7D8A9D
7F8C9D808D9E818D9F828EA1838EA08590A08692A08792A28A95A48A95A58993A48A94A5
8B95A68E97AA8F96AA9099A9939CA9939CA8949DA8969FA896A0A796A1A795A2A596A3A5
96A3A496A2A396A2A395A2A395A1A395A1A395A1A396A1A295A19F95A19B96A49C7F8884
2B2835676F694C4E514A4D4E3E42453033384F58524F58514F57523D41426672669EB699
727F718595817683743B3B41312F3B5B61628191868696888E9E8B89978287967F8D9E83
2F2E2C1F1C1A1F1D161B1B1018190E17180D17190E1B1D111B1F1415191222271F4D5847
5A66566E7D6A646D636E796D5C655D484E48363C371B1C1C21231D262A1F292F202D3223
2F3425333927353D29303926
41485E424B63434C67424B69424A6B424A6C444D6F444D6E444C6D454E6E464F6C474F6C
48516D47506B47506B49526D49526F4C55734D56754D56764E567850587B4F5979505C79
525D7A55607D555F7B555F7A58627B58637B59637D5B64805B65815D65825F6783616885
616885626A84616A84616B85626C87646E8A646F8C65718D65728D66738C68748C69758C
6975896C768B6E788D6F7990707992717B94717B96707C97707C97717C98727C99747F9A
7580997681987580967982977B82987B83997C859A7D889C7F8A9D7F8A9D7E8A9C7E8A9D
7F8B9E818C9E828DA0838FA2848FA08590A08792A28993A38994A28893A18994A28994A2
8C96A68E96A98E96AA909AAA929CA8929CA6949DA696A0A796A1A695A1A596A1A696A2A5
96A2A598A3A698A3A697A3A697A2A597A2A396A2A296A2A195A19D94A09996A499869189
2F2C385054544D51504F55513E43422D2F345059534E56524E5650454B4850595394AC91
849882899E86788878565D5C40414B5F666B666E7185948A8FA08E8A9B8486947B7E8E72
2A2A251B18151E1C1519190F18190E181A0E181B0D1A1D0F1C1F121C1F1512120D4A5241
7B8A716F7A69737F70768375707F6F68776640473F2426242A2D262B2F232B31222D3323
2F3424303626343A28313727
434962444A66434A69424A6A42496A43496B43496D444B6C444A6B444B6A454E6A474F6A
464D69464D6948506A49526C4A536E4C53704D54744C54744B54754F577950597B505B7D
515B7C535D7D545E7D545E7C56617D58627C5A637C5C637E5D64805E64815E6481606882
616A84616A83606A81626B82646D85666E8766708964708B65728C65728A66738A677588
6874866A75876B75896D768C6F788E6F7A90707A91717B92707C94727C95737C97747E98
757F97747F95747F947781947A82967C83987C84997D85997D86997E889B7F8A9C7E879C
808A9F828AA0828BA0848CA0848E9F878F9F87909F8792A08892A08892A18893A38A94A5
8B95A68C95A78E96A88F99A99199A8939BA5969EA4959EA2959FA1959EA1949EA295A1A5
95A1A597A3A698A2A597A2A595A1A496A3A296A3A295A2A093A09D93A09A92A1978C9B8E
3A39404244465B635C49514C3A3F3C26292A4D574D4D554D4E564E4C52495F695B91A68B
7686767F907F8293837B897C5C60614C4B556F74757C84808D9B8D8A9A8686957E7D8E74
2829261C1B191C1C1717191017190E171B0F151A0C181B0C262A172A2C1E1714103F4137
7F8F756D7769727E70748374708170697A663C453C1C1F1C2B30272C32272C33252C3424
2D35252E37273038292F3729
43465F45486545496944496A454A6C45496C44486B44496B444A69444A68454C68454C69
464D6A454D6B464E6D49526E4B546F4C536E4C536F4C55704B54714C53734F5677505A7B
515B7C535C7D545E7E56607D56617C57627B59627A5B627B5D637D5F647F5D63805E6581
626A84626B84616B83636C84646D86656E88676F8967708A68708B68728C68738B6A7489
6A75876B75876B74896C758B6F788C6F798D6E778C6F788E707A90717B91727B92757E95
767E96777F96777F957881947B83957C84947B83957D85977D85977E86997F879B80889E
8189A18088A1818AA2828BA0838D9E868F9E868F9E88909F8991A08A92A38B93A58D95A8
8E95A98D94AA8E96A99098A99199A7949BA6969DA4969EA2969FA2959FA1949EA1949FA3
96A1A595A0A7959FA595A0A594A0A695A2A695A2A494A1A194A1A1919F9D8F9D9791A195
46484B4044457381724B524D3C413E27292B4B554B4C564C4D574C474D4450554A7E8D76
7785727B88768796838391807981753E3941646666767D788B978A8896868595817B8D77
30342F1919181E1F1A17191314160F15190F13170D11150A3743294D593D1614104E5447
7A88736C786B717E71738274718373697B68424D412D352D313B2F2E362B2C33272C3526
2C36252E39272E39282D3727
434660444865454967454967464968464869474A69464A69454A68454A69454B6A454B6B
444C6B454D6C464D6E4950714951704A526F4A536E4B556E4C566E4D56704E5774505978
515A7A535B7D555F7F55607D545F7B56607B59617B585F795A617A5D637C5E627F5F6481
606583606785606785616984646C86646B87656C87666E88676E8B686F8B687089697289
6972886972886A73896B748A6C76896E798C6E798B6D778A6F798B717B8D727B8E747C8F
767D91777F92777E927981937A82927B85937A84927B84957B84977D85997F879C8087A0
8188A28188A38189A1818AA0818A9D838C9D868F9D88909D87909F8891A18991A28C94A4
8E97A78F97A98F96A89096A79198A69299A6949BA4959DA4959EA5949EA3939DA1939DA1
95A0A4959FA6949FA594A0A794A1A893A0A892A0A6929FA2929F9F8F9D9B8E9B9792A299
6067672C2936677168535B544046412D2F2F4E584C4D574B4951473C3F3A41443D5B6354
75826B8494798A9B8286957F838F7D3A373E5B5D5E78807A859186849184849584778876
3135341B1B1C1F201D1A1B1715171212150D11140C0E100B35402C4B583F12100B454A3C
75826C6D786B6F7C7072817472837370826F4651472E352E323A2C2D35252C32232E3424
2D34232E37242E37242E3724
41455F42466244476446486646486846486A46496A454969454969444A69434B69434B68
434B69444C6A444C6A464E6C49516F4A52714A52714A54704C56704C56704D56714F5774
505775515979535C7D545D7D545E7B555F7B59617C59607A5A62795C627A5D617C5F637F
5F64815F6582606783636B82636B81656A83676B86686B87676C8A676D89676E88677089
67708969728A6A738A69728B68718A6A748B6974886A74866D77876D77866E7887727B8B
757D8D767F8F7880917981917982907984927883927983937B85957E86977F879A7F869D
7F869E7F879F818BA1818B9F828B9E848D9E858E9D87909D87909D88919F8891A08A93A1
8D95A38F97A49096A49297A69299A69299A5929AA3949DA4939FA3919EA1919EA0919E9F
939FA195A0A2959FA296A1A593A0A393A0A3939FA3939FA1929E9E919D9C919E9993A29A
6F7776292533454948424843373B37383B364D55494C54474D564942483F383C363F433B
65705C88987E92A38B899683859082403C466D747079837C869288859285859485798777
2C2D2F1C1C1E1F1F1E191A1614161011140B1012090F0E093E453456634B110F0F30322E
72816D6B796A6D7B6E70817271837270826F57665532382E292D212B301F2C321F2D3320
2E34212D35222C35232C3422
3E455C40465E454962474866474868464768444668444768444868424865424A64424B65
434C65444E66444D66434C66464F69474F6C48506F48506E4B53704C54704C56714E5773
4F5875505A78525C7B545C7C545E7C545E7C57607D59627C5A627B5C637B5D647C5D647D
5E657F606781616781626B8161697E62697F676C82686B83686B85686D88666D88666E89
666F8A65708967728A67718A666E87676F85666E83646C81656D81676F82656E81677182
6B74846D75866F7888717B88717C8774808A77838E7985917B87947D88967F89997F8899
7F899A7F8A9A818C9A828D99838D9A858E9D858E9D858F9C87919D8A92A08B92A18C93A3
8C93A58E94A69096A59097A49299A5939AA5939BA4929CA1909D9F909EA0919E9F909E9F
93A09F95A19F95A0A095A1A294A0A294A0A3939FA1939F9F919E9D8F9D9A8E9C9791A198
6D76742C28363534372D2D2E2322244C5445515B494F57464E56443F4536393E32353730
575E51A3B99A92A28E8B9988889484474449838C80858F848A95888894868492807E8C77
31322F1716171E1F1B1A1A1516170E14140A1212090E0C05424A3659654E161213363A37
67766964736867786C6A7D6E6C806E687C675565512E3529212619292F1E2C311F2C311F
2B33202D36222C35232A3322
3D445D3F4660434865454867454768454668434667434667424866424965424964434A64
444D65444D65444D66454D67464F6949516D4A516F4B50704C52724E55744D55744D5575
4E587850597A50597B525A7C545D7C545D7C555D7C58607E59617D5A627C5A637B5C667C
5D657D5F667F606781616781616880636A82656D83656C84666C84676E87676D8A676E8C
656F8D65708C67718B687289667087677086666E84656D81666C81666C83626A82626B81
646C81636D7F636B7E656E7F66717F6874806C78836F7B8873808D7582917986937A8894
7C89957D8A957F8C957F8D93808D94838F99848E9A848E9887919D8992A08A91A08A90A0
8B91A48D92A68D92A48F94A49297A4949AA4939AA5929BA2919C9F919C9E919D9E929E9F
94A1A095A1A0949FA0949FA2939EA3929EA5919EA2909D9E909E9E8F9E9C8A9A968EA096
727F782F2D363432332D2B2B1F1C1C575F4D5A65505059454C544131332932342A3A3D32
42453B9AAE8E97AA92909F8F8C9A8A5152518C9786939E908D988C8A988884958182957A
3F46391514121F20191D1D151D1C1319190F17160D110E083D4232616D56201D1F4C534D
66746B61706B5F716A5F716661746361745F343E342A3228272F22282F1F2A31202C3221
2D34212C34222B3322293222
3E435D404662424966434967444868444768434667434767424766434766444866444966
444B67444C67454D68464D6B464E6D48506E48506E4A506F4A51714C53734D53734E5375
515779525879535A7A545B7B565D7B575E7C575E7C585F7E575F7D57607C59627B5B647B
5C647C5E657E5F667F606681606682626883646B84646C85646C86666D87686E8A676D8C
666D8D676F8D69708D6A728C6A728C6A728C6C728B6C72896C72896C718A6A708A677089
666D87646C85636A81646C81656D82626B80636B80636C80666F816871826C75846F7885
717B86747F8975828B78868D7B888E7F8C91818D93848E9487919989919D8A929E8A919D
8B929F8C94A38D94A28E94A19197A29198A19299A0939B9F919A9B919B9C929B9C929C9D
949D9F969DA1959CA1949DA2949EA2929EA1919FA1909F9F909E9D8F9D9A8C9B968D9F95
7D8C823F42443737342F2D2825211E5C624F5B63504F55454A5241383E31353B2D3D4435
3739317B89729BAE9390A0908C9B8E69716E808C827E8984818E888C9E9084978581947C
3D4337161411201F191D1C171E1C171B1A1418161016130F4246386C7A62454B44606B5E
647165637167434C4B33393B4A584C677B61313A2F272F242A332529302129301E2A3220
2B33232C33222C332129301F
3B415A3E455F4047613F4561414563434665414564414765424665444766454767464868
454968454B69444A69444A6B454C6E464D6D454D6B464E6B474E6D494F6E4C50704E5273
4F5374505475525778535979545A79555B79565D79575E79595F7A59607B5A617B5B627A
5C637B5E647D5E637E606481636684636683636583646784646885666A87686C896A6D8B
696C8B686E8C68708C69708C6A718B6A708A6D728B6F758D70768D71768D70778E6F768E
6E768F6D768E6C758B6B73896B73886A70876B7186696F82676E7F676E7D686D7D6A6F7F
6A6F806B70816A70816A72806C76806E7981757E867982897F878D838A92858C94878F95
8890998C939D8D949D8D949C8F979E90989E91999E919A9B919A98929B9B929B9C939B9E
959C9E979DA0969DA1949CA0939D9E929E9D93A09E929F9D929E9D909C998E9C95919F94
7E897F47474A3937382C25254542397F886E575A4E51564B4E5548444B3D3F4737404538
41443B727C6896A58C92A18F8A978B838E87828F885E666B6E7C778DA28F7F927F80937B
3D42391B171621201C1C1A18191815181613151310181614474D3F697862606D5C667563
667463697967373B3C1A1A25282E31556755323D31272F252A33272A3124293122293222
2B34242B33212A321F2A311D
3C415A3D435D40466040455F414660424761424761404662404663414765444768454869
43466943486B444B6C454D6E464E6F444C6E444C6C454D6B464D6B4A506E4C51704D5271
4D52724D52734F5476515676525877545A78575D78575E77585E77595E785A607A5C637C
5C637C5D627E5D6180606383616485636685646785646883636783666986676A86696C86
696C86696D87696F886870896770896870896A718A6B728B6D748C70778C71788C72788F
7178906F788F70798F727B8F747D8F757D8E777E8F777E8E747C8A727A86717884727786
7174876E71876A6E84686D82676E80666E7D6A707F6D73816F7583727785767A88797E8C
7C838F808892838B93868E938993978B96988E999A909B9B909B9B939C9D919A9B939B9C
959D9C969E9B969E9C939D9C929D9B929C9B919D9B929C9B939C9B929B9B919B97919D93
8691864240463734392D282D646A5BA4B6924C4D424B4F444B5045454C3F4148393E4134
4141366A705E919D8595A28F8D988B8A958B7C8582575A62667170899C8C7D8F7F7D907E
3F46431513181F1F201A1A1A1717161716141614131613144950426E7E67647160687765
6B7967707E6C4248451817233942422C343328312B283127283126293126283125293324
2D35232C35212A311F292F1D
3D415A40435E42466142466141466042475F424760424761434762434665434666444667
43476842476943476A444B6C464E6D454C6B454C6B464C6D474D6E4A50704A51714C5272
4E5272505474515675525775535774555A75565C77555B77555B75575D765A60795B6179
5D637B5D627C5E617F60628360628262648365688565688265687F686A81686A836A6C84
6B6D856B6F886A6E87696E86686E876970876A70876C71896E748C6F758C70758B72778D
73798F73788E747A90757B91767B92787F92798092787F90777E8F79808F7B838F7D828F
7C7F8F7B7E91787C8F757A8E73778A7176887074876E72876E73876D71866E7186707386
737687767A8A767C89797F897C838A7F878C838C908890938A92948A93938D9695909897
939B99959C9A969E9B949C99949E99949D99939D9A929C9A919A99919A9B929B99929E94
869185444146322E34322F3177836B839173505445484D414A4F4443483D373A2F35362A
35322759594897A2878D94868E958D8C948D7C817F72777464696A89998B7E8F817C8F7F
3F464416141B1F1F211B1B1B1A1A19191916151311141211505A476F7E625D6754596253
5C66566C78654D554B19181D4953491E2122212623262E2527302528302328302128301F
2C34202D34202C311F2A2E1D
3F425740435941445D42446042456044475F43465E43465E434760424562424463414663
414762424863434965444966454B68474B68474D6B494E6E4A4E704A4F714A4F724C5072
4D51714F537050556F525670535770545A71565C72555B73565B73565C74585E765A6077
5C60795D617A5E627C5F627E61627F626281656683656882676A7F696D80676B7F686C81
696C836B6D846A6D846B6E856B6F866B6E856C6F856E71876F738A6F748A6F748A71768B
71778C73778C767A8E777A90777B91787D907A80907A808E797F8E7A808E7B828E7D838D
7D828F7E83917E84937F86957F84947F83957F85967E83957B8194787E91777C8F777A8B
787B8A767A89767A88757985777B85787C837C7E857E81877E8388808689848B8D868D8F
888F908E9595909795929996949C97949C97949D99929C9B919A9A909897919996929C93
8A9386423E432F282E4F514869715E5153474E4E46494A434B4F45484D413B3E31383A2B
3E3D2D52514098A1839096869AA1969399928589837577746C6E6A8F9D8B81907F7C8D7A
373C3A17161820201D1C1C191A1B17191B1513141016171355624A5D6A50373B2E33362D
4D53436570594F5645201F1C34382E1D1E1B212720232A21262E22272F22272F21282F1F
2B31202D33212D33212B301E
3F40543F415640435A42455D44465E43455C43455C43465C41455D42455F424561414862
3F4660424861444A62444A62454B64464A65464A67484D6B4A4F6E4A4F6E4A4E6E4B4F6F
4C51704D526D4E546E50556F51576F535A6E555C6D555C6F565C71575C73575C74585E76
585E775C60795D60785F627B61637E63637F65658164668065677E676B7E666B7C666B7D
64697D666A7E696B816A6D836A6E84696C836C6F836E70866F718870748A6F73886F748A
71758A73798A74788B76798E777B8F787C8E7A808F7B818F7A7F8D7B808D7C808D7C818E
7D82907E84927D84937D85937F8695808796838B9A848C9A848B9A838B99848B98838796
8185937E83907B808C797D88797D86797C847B7D837B7D827C7E837D81867F8488808588
818789858B8C888D8C8B908F8E9493909896939A98939D9A929C998F98948E98928F998E
8C9786413E41281D246B705E757E685B5E514A48444A4A454D52484A514444493B404434
4245324C4D3B8E9879939C86ACBAA59DA7998A91857F83796B6D658A978183917B798973
383D381412141E1E191A1A15171A14151913121610171C1337422E424D372F34252A2C21
4A513E677659515C451C1D1823261D22271E232920252A20262D20272E21272D22293022
2C32232E34222C32202A2F1D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.392007 0.97619 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FFFF80000000FFFF8000FF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF80000000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 300},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001;2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`003Ooooon]0?n001[ooooo[@3oP00?ooooo`003Oooooln0?n001@0003o
F`3oP00Jooooocl0oh004@000?mM0?n000oooooo000=oooood/0oh0070000?m60?n001[ooooo?`3o
P00P0000o`80oh0010000?m80?n000oooooo000=oooood/0oh0070000?m60?n001[ooooo@03oP00W
0000odH0oh003oooool000goooooC03oP00K0000odH0oh006_oooom20?n000T0003o00<0oh000000
o`000?l06@000?m60?n000oooooo000=ooooodH0oh008@000?m60?n001[ooooo@`3oP0090000o`80
oh006@000?m60?n000oooooo000=ooooodL0oh008@000?m50?n001[oooooA03oP00<0000o`80oh00
5@000?m60?n000oooooo000=ooooodL0oh008@000?m50?n001[oooooA03oP00<0000o`80oh005@00
0?m60?n000oooooo000=ooooodH0oh008P000?m50?n001[ooooo?`3oP00X0000odH0oh003oooool0
00goooooA`3oP00Q0000odD0oh006_ooooln0?n002X0003oA@3oP00?ooooo`003Ooooom40?n002@0
003oA@3oP00Joooooch0oh00:P000?m50?n000oooooo000=oooood80oh009P000?m50?n001[ooooo
?@3oP00[0000odD0oh003oooool000gooooo@`3oP00V0000od@0oh006_oooolg0?n000030000o`3o
P000oh0000@0oh00:P000?m50?n000oooooo000=oooood<0oh009P000?m40?n001[ooooo?@3oP00/
0000od@0oh003oooool000gooooo@03oP0000`000?l0oh000000o`0V0000od@0oh006_oooold0?n0
00030000o`3oP000oh0000<0oh00;`000?m40?n000oooooo000=oooood00oh00:@000?m40?n001[o
oooo>`3oP00^0000od@0oh003oooool000gooooo?`3oP00Z0000od@0oh006_oooold0?n003D0003o
A03oP00?ooooo`003Oooooln0?n002/0003oA03oP00Joooooc80oh0000<0003o0?n000000?l0=000
0?m40?n000oooooo000=ooooocd0oh00;@000?m30?n001[ooooo<@3oP00h0000od@0oh003oooool0
00gooooo>P3oP00`0000od<0oh006_oooolb0?n003P0003o@`3oP00?ooooo`003Ooooolh0?n00380
003o@`3oP00JooooobP0oh0000<0003o0?n0003oP0001P3oP00i0000od<0oh003oooool000gooooo
=P3oP00d0000od<0oh006_ooool[0?n003l0003o@`3oP00?ooooo`003Ooooolf0?n003@0003o@`3o
P00Jooooob/0oh00?`000?m30?n000oooooo000=ooooocH0oh00=0000?m30?n001[ooooo:P3oP010
0000od<0oh003oooool000gooooo=@3oP00e0000od<0oh006_oooolX0?n00480003o@`3oP00?oooo
o`003Ooooolc0?n003P0003o@P3oP00JooooobP0oh00@P000?m30?n000oooooo000=oooooc<0oh00
00<0003o0?n000000?l0=@000?m20?n001[ooooo:03oP0130000od80oh003oooool000gooooo<`3o
P00h0000od80oh006_oooolM0?n000H0003o103oP0140000od80oh003oooool000gooooo<@3oP00j
0000od80oh006_oooolJ0?n00540003o@P3oP00?ooooo`003Ooooola0?n003X0003o@P3oP00Joooo
oa00oh001@000?l20?n000030000o`3oP000003o00<0003o0P3oP01<0000od80oh003oooool000go
oooo;P3oP00n0000od40oh006_ooool@0?n000d0003o0`3oP01;0000od80oh003oooool000gooooo
;@3oP00o0000od40oh006_oooolB0?n000@0003o00<0oh000000o`000?l0DP000?m20?n000oooooo
000=ooooob`0oh00@0000?m10?n001[ooooo6P3oP01B0000od40oh003oooool000gooooo;@3oP00o
0000od40oh006_oooolJ0?n00580003o@@3oP00?ooooo`003Oooool]0?n003l0003o@@3oP00Joooo
oaL0oh00E@000?m10?n000oooooo000=ooooob/0oh0000<0003o0?n000000?l0?P000?m10?n001[o
oooo5`3oP01E0000od40oh003oooool000gooooo:`3oP0000`000?l0oh000000o`0n0000od40oh00
6_oooolG0?n005D0003o@@3oP00?ooooo`003Oooool/0?n00400003o@@3oP00JoooooaL0oh00E@00
0?m10?n000oooooo000=ooooob/0oh00@P000?m00?n001[ooooo603oP0040000o`030?n000000?l0
003o04d0003o@@3oP00?ooooo`003OoooolW0?n000030000o`3oP000003o04<0003o@03oP00Joooo
oaT0oh00D`000?m10?n000oooooo000=ooooobP0oh00A@000?m00?n001[ooooo603oP01E0000od00
oh003oooool000gooooo:03oP0150000od00oh006_ooool@0?n000<0003o103oP01F0000od00oh00
3oooool000gooooo903oP0040000o`030?n000000?l0003o0480003o@03oP00Joooooa40oh0000<0
003o0?n0003oP0000P3oP0050000o`030?n000000?l0003o04l0003o@03oP00?ooooo`003OoooolP
0?n004d0003o@03oP00Joooooa40oh0000<0003o0?n0003oP000103oP01E0000od00oh003oooool0
00gooooo8P3oP0020000o`80oh00A`000?m00?n001[ooooo203oP0000`000?l0oh000?n0000=0?n0
05D0003o@03oP00?ooooo`003OoooolO0?n004l0003o?`3oP00Joooooa80oh00F`000?m00?n000oo
oooo000=ooooob00oh00CP000?lo0?n001[ooooo3@3oP00010000?l0oh000?n0003oP01M0000ocl0
oh003oooool000gooooo7`3oP01?0000ocl0oh006_ooool@0?n005h0003o?`3oP00?ooooo`003Ooo
oolP0?n004h0003o?`3oP00Jooooo`h0oh00H0000?lo0?n000oooooo000=oooooah0oh00D0000?lo
0?n001[ooooo3P3oP0030000o`H0oh00E`000?lo0?n000oooooo000=oooooah0oh00D0000?lo0?n0
01[ooooo3P3oP0030000o`H0oh00E`000?lo0?n000oooooo000=oooooad0oh00D@000?lo0?n001[o
oooo3@3oP0050000o`@0oh00F0000?lo0?n000oooooo000=oooooah0oh00D@000?l;0?n000030000
o`3oP000oh000300oh006_ooool<0?n00680003o303oP0000`000?l0oh000?n0000`0?n000oooooo
000=oooooah0oh00D@000?l;0?n000030000o`3oP000oh000300oh006_ooool50?n000030000o`3o
P000oh0000D0oh00H@000?l<0?n000030000o`3oP000oh000300oh003oooool000gooooo7`3oP01@
0000o`/0oh0000<0003o0?n0003oP000<03oP00Jooooo``0oh00H`000?ln0?n000oooooo000=oooo
oa`0oh00D`000?l;0?n000030000o`3oP000oh000300oh006_ooool:0?n006D0003o?P3oP00?oooo
o`003OoooolL0?n005<0003o4P3oP0020000obX0oh006_ooool80?n000030000o`3oP000003o06@0
003o4`3oP0000`000?l0oh000?n0000X0?n000oooooo000=oooooal0oh00D0000?l=0?n000@0003o
00<0oh000000o`000?l0:P3oP00Jooooo`H0oh0010000?l40?n00640003o4P3oP0020000obX0oh00
3oooool000gooooo7`3oP01@0000o`d0oh001`000?lZ0?n001[ooooo103oP0020000o`P0oh00H@00
0?l@0?n000<0003o:`3oP00?ooooo`003OoooolN0?n00540003o3@3oP0000`000?l0oh000?n00003
0000ob/0oh006_ooool40?n000030000o`3oP000oh000080oh0010000?l30?n005l0003o403oP003
0000ob/0oh003oooool000gooooo7P3oP01A0000o`T0oh0000<0003o0?n0003oP000103oP0030000
ob/0oh006_ooool80?n000D0003o0P3oP01P0000oa40oh0000<0003o0?n0003oP000:P3oP00?oooo
o`003OoooolO0?n00500003o?P3oP00Jooooo`H0oh00J@000?ln0?n000oooooo000=oooooa/0oh00
00<0003o0?n0003oP0000P3oP01@0000ocd0oh006_ooool60?n006X0003o?@3oP00?ooooo`003Ooo
oolO0?n00540003o3@3oP0020000obh0oh006_ooool30?n006d0003o?@3oP00?ooooo`003OoooolM
0?n005<0003o3@3oP0020000obh0oh006_ooool30?n006d0003o?@3oP00?ooooo`003OoooolM0?n0
05<0003o3@3oP0020000obh0oh006_ooool30?n006d0003o?@3oP00?ooooo`003OoooolL0?n005@0
003o3@3oP0020000obh0oh006_ooool20?n006h0003o?@3oP00?ooooo`003OoooolO0?n00540003o
3@3oP0020000obh0oh006_ooool20?n006h0003o?@3oP00?ooooo`003OoooolM0?n000030000o`3o
P000003o0500003o3@3oP0020000obh0oh006_ooool30?n006d0003o?@3oP00?ooooo`003OoooolM
0?n005<0003o3@3oP0030000obd0oh006_ooool40?n006`0003o?@3oP00?ooooo`003OoooolN0?n0
0580003o3@3oP0030000o`D0oh000P000?lV0?n001[ooooo1@3oP01[0000ocd0oh003oooool000go
oooo6`3oP0020000o`030?n000000?l0003o0500003o3`3oP0000`000?l0oh000?n000030?n000@0
003o903oP00Jooooo`@0oh00K0000?lE0?n000@0003o903oP00?ooooo`003OoooolL0?n005H0003o
3@3oP0000`000?l0oh000?n000030?n000D0003o8`3oP00Jooooo`80oh00L0000?lC0?n000@0003o
903oP00?ooooo`003OoooolM0?n005D0003o1P3oP0000`000?l0oh000?n000040?n000030000o`3o
P000oh0000<0oh001@000?lS0?n001[ooooo0`3oP01_0000oa<0oh0010000?lT0?n000oooooo000=
oooooah0oh00E0000?l60?n000030000o`3oP000oh0000@0oh0000<0003o0?n0003oP0000`3oP005
0000ob<0oh006_ooool40?n006h0003o4`3oP0050000ob<0oh003oooool000gooooo803oP01B0000
o`H0oh0000<0003o0?n0003oP000103oP0000`000?l0oh000?n000030?n000H0003o8P3oP00Joooo
o`X0oh00J0000?lD0?n000@0003o8`3oP00?ooooo`003OoooolP0?n00580003o4`3oP0080000oa00
oh0000<0003o0?n0003oP0003@3oP00Jooooo`/0oh001P000?l00`3oP000003o0000o`1N0000oa@0
oh001@000?lR0?n000oooooo000=oooooah0oh00E0000?l=0?n000030000o`3oP000oh0000<0oh00
20000?l@0?n000030000o`3oP000oh0000d0oh006_ooool=0?n000@0003o00<0oh000000o`000?l0
GP000?lD0?n000L0003o803oP00?ooooo`003OoooolM0?n005D0003o0`3oP0000`000?l0oh000?n0
00070?n00080003o103oP0080000oa00oh000P000?l>0?n001[ooooo303oP01V0000o`<0oh0000<0
003o0?n0003oP0003P3oP0070000ob00oh003oooool000gooooo7@3oP01E0000o`<0oh0000<0003o
0?n0003oP0001`3oP0020000o`@0oh0020000?l@0?n00080003o3P3oP00Jooooo``0oh00IP000?l3
0?n000030000o`3oP000oh0000h0oh001`000?lP0?n000oooooo000=oooooad0oh00EP000?lB0?n0
00P0003o203oP0030000o`@0oh000`000?l>0?n001[ooooo2P3oP01X0000oa@0oh001`000?l80?n0
00030000o`3oP000oh0001D0oh003oooool000gooooo7@3oP01F0000o`D0oh0000<0003o0?n0003o
P0002P3oP0080000o`P0oh000`000?l20?n000D0003o3P3oP00Jooooo`P0oh00JP000?lD0?n000L0
003o803oP00?ooooo`003OoooolM0?n005H0003o1@3oP0000`000?l0oh000?n0000;0?n000L0003o
2P3oP0090000o`030?n000000?l0oh0000X0oh006_ooool80?n006/0003o1@3oP0000`000?l0oh00
0?n0000;0?n000L0003o803oP00?ooooo`003OoooolM0?n005H0003o1@3oP0020000o``0oh001`00
0?l:0?n000030000o`3oP000oh0000P0003o2`3oP00Jooooo`P0oh0010000?l20?n006D0003o4`3o
P0070000ob00oh003oooool000gooooo703oP01G0000o`D0oh0000<0003o0?n0003oP0002`3oP007
0000o`h0oh001`000?l;0?n001[ooooo203oP0040000o`030?n000000?l0003o06@0003o4`3oP007
0000ob00oh003oooool000gooooo703oP01G0000oa<0oh001`000?l>0?n000L0003o2`3oP00Joooo
o`H0oh00K@000?lC0?n000L0003o803oP00?ooooo`003OoooolL0?n005L0003o4`3oP0070000o`h0
oh001`000?l;0?n001[ooooo1P3oP01]0000oa<0oh001`000?lP0?n000oooooo000=oooooa/0oh00
F0000?lC0?n000P0003o3@3oP0070000o`/0oh006_ooool60?n006d0003o503oP0060000ob00oh00
3oooool000gooooo6`3oP01H0000oa<0oh0020000?l=0?n000L0003o2`3oP00Jooooo`P0oh00J`00
0?lD0?n000L0003o4`3oP0000`000?l0oh000?n000090?n000oooooo000=oooooa/0oh00F0000?lC
0?n000P0003o3P3oP0060000o`/0oh006_ooool80?n006/0003o503oP0070000oal0oh003oooool0
00gooooo6P3oP01I0000oa<0oh0020000?l>0?n000H0003o2`3oP00Jooooo`X0oh00J@000?lD0?n0
00L0003o4`3oP0000`000?l0oh000?n000090?n000oooooo000=oooooaX0oh00FP000?lB0?n000P0
003o3P3oP0060000o`/0oh006_ooool80?n006/0003o503oP0070000oal0oh003oooool000gooooo
6`3oP01I0000oa80oh0020000?l>0?n000H0003o2`3oP00Jooooo`H0oh00K@000?lD0?n000L0003o
7`3oP00?ooooo`003OoooolK0?n005T0003o4P3oP0080000o`h0oh001P000?l;0?n001[ooooo1P3o
P01]0000oa@0oh001`000?lO0?n000oooooo000=oooooa/0oh00F@000?lB0?n000P0003o2@3oP004
0000o`040?n000000?l0003o0000o`80oh0000<0003o0?n0003oP0002@3oP00Jooooo`T0oh0000@0
003o0?n0003oP000oh00IP000?lD0?n000L0003o3P3oP0000`000?l0oh000?n0000>0?n000oooooo
000=oooooaX0oh00FP000?lC0?n000L0003o2P3oP0030000o`030?n000000?l0003o00l0oh006_oo
ool>0?n006H0003o4`3oP0070000o`h0oh0000<0003o0?n0003oP0003P3oP00?ooooo`003OoooolK
0?n005T0003o4`3oP0070000o`X0oh000`000?l00`3oP000003o0000o`0?0?n001[ooooo3`3oP01U
0000oa<0oh001`000?l?0?n000030000o`3oP000oh0000d0oh003oooool000gooooo6`3oP01I0000
oa<0oh001`000?l:0?n000H0003o3`3oP00Joooooa00oh00I0000?lC0?n000L0003o3`3oP0000`00
0?l0oh000?n0000=0?n000oooooo000=oooooa`0oh00F0000?lC0?n000L0003o2P3oP0070000o`h0
oh006_ooool?0?n006D0003o4`3oP0070000oal0oh003oooool000gooooo7@3oP01G0000o`l0oh00
00@0003o0?n0003oP000oh001`000?l:0?n000P0003o3@3oP00Jooooo`d0oh00I`000?lC0?n000L0
003o7`3oP00?ooooo`003OoooolO0?n005D0003o4`3oP0070000o`X0oh002`000?l:0?n001[ooooo
2@3oP01[0000oa<0oh001`000?lO0?n000oooooo000=oooooal0oh00E@000?lC0?n000P0003o2@3o
P00:0000o`/0oh006_ooool:0?n000<0003o00<0oh000000o`000?l0I0000?lC0?n000L0003o2P3o
P0020000oa<0oh003oooool000gooooo803oP01D0000oa<0oh0020000?l90?n000L0003o00<0oh00
0000o`000?l02`3oP00Jooooo`l0oh00I@000?lC0?n000L0003o2P3oP0020000o`80oh0000<0003o
0?n000000?l03P3oP00?ooooo`003OoooolP0?n005@0003o4`3oP0080000o`T0oh001@000?l01@3o
P000003o0000o`3oP000003o00/0oh006_ooool@0?n006@0003o4`3oP0070000oa00oh0000<0003o
0?n0003oP000303oP00?ooooo`003OoooolR0?n00580003o4`3oP0080000o``0oh0000<0003o0?n0
003oP0000P000?l=0?n001[ooooo4@3oP01S0000oa<0oh001`000?lA0?n000030000o`3oP000oh00
00/0oh003oooool000gooooo9@3oP01?0000oa<0oh0020000?l@0?n00080003o303oP00JoooooaH0
oh00GP000?lC0?n000L0003o4@3oP0000`000?l0oh000?n0000;0?n000oooooo000=ooooobD0oh00
00<0003o0?n000000?l0C0000?l=0?n000030000o`3oP000oh0000<0oh0020000?l@0?n00080003o
303oP00Joooooa40oh001@000?l00`3oP000003o0000o`1K0000o`d0oh0000<0003o0?n0003oP000
0`3oP0070000oal0oh003oooool000gooooo:P3oP01;0000o``0oh000`000?l30?n000P0003o7P3o
P00Joooooa<0oh0010000?l00`3oP000003o0000o`1J0000o`d0oh000P000?l50?n000H0003o7`3o
P00?ooooo`003OoooolZ0?n004/0003o303oP0030000o`<0oh0020000?lN0?n001[ooooo4`3oP004
0000o`030?n000000?l0003o05X0003o3@3oP0020000o`D0oh001P000?lO0?n000oooooo000=oooo
ob/0oh00BP000?l<0?n000<0003o0`3oP0080000oah0oh006_oooolF0?n005h0003o3@3oP0030000
o`@0oh001P000?lO0?n000oooooo000=ooooobX0oh00B`000?l<0?n000<0003o103oP0070000oah0
oh006_oooolE0?n00600003o303oP0030000o`@0oh001`000?lN0?n000oooooo000=ooooob/0oh00
BP000?l<0?n000@0003o0`3oP0070000oah0oh006_oooolC0?n00680003o303oP0040000o`<0oh00
1`000?lN0?n000oooooo000=oooooc00oh00A@000?l<0?n000@0003o0`3oP0070000oah0oh006_oo
oolC0?n00640003o3@3oP0040000o`<0oh001`000?lN0?n000oooooo000=oooooc40oh00A0000?l;
0?n000D0003o0`3oP0070000oah0oh006_oooolF0?n005h0003o3@3oP00010000?l0oh000000o`00
0?l30?n000L0003o7P3oP00?ooooo`003Oooool^0?n004L0003o2`3oP0050000o`<0oh001`000?l>
0?n000030000o`3oP000003o00d0oh006_oooolI0?n005`0003o303oP0000`000?l0oh000000o`04
0?n000L0003o7P3oP00?ooooo`003Oooool`0?n004D0003o303oP0040000o`@0oh001P000?l=0?n0
00H0003o2`3oP00JoooooaH0oh00G`000?l<0?n000@0003o103oP0050000oal0oh003oooool000go
oooo<03oP0150000o``0oh001@000?l20?n000L0003o3@3oP0060000o`/0oh006_oooolG0?n005h0
003o303oP0000`000?l0oh000000o`020000o`<0oh001@000?lO0?n000oooooo000=oooooc40oh00
A0000?l20?n000030000o`3oP000oh0000L0oh001P000?l20?n000H0003o3@3oP0060000o`/0oh00
6_oooolI0?n005`0003o3`3oP0020000o`<0oh001@000?lO0?n000oooooo000=oooooc<0oh00@P00
0?l=0?n000D0003o0P3oP0060000o`d0oh001P000?l;0?n001[ooooo6@3oP01L0000o`h0oh001000
0?l20?n000D0003o7`3oP00?ooooo`003Ooooole0?n000<0003o00<0oh000000o`000?l0>`000?l=
0?n000@0003o00<0oh000000o`000?l01@000?l=0?n000H0003o2`3oP00Joooooa/0oh00FP000?l>
0?n000@0003o0P3oP0050000oal0oh003oooool000gooooo=P3oP0000`000?l0oh000?n000080?n0
03D0003o3@3oP0040000o`030?n000000?l0003o00D0003o3@3oP0060000o`/0oh006_oooolK0?n0
05X0003o3P3oP0040000o`030?n000000?l0003o00@0003o7`3oP00?ooooo`003Ooooolg0?n00003
0000o`3oP000oh0000`0oh00<0000?l=0?n000@0003o00<0oh000000o`000?l01@000?l=0?n00004
0000o`3oP000oh000?n00080003o2`3oP00JoooooaX0oh00G0000?l=0?n000@0003o00<0oh000000
o`000?l01@000?lN0?n000oooooo000=ooooocL0oh0000<0003o0?n0003oP000303oP00`0000o`d0
oh0010000?l00`3oP000003o0000o`050000o`d0oh0000@0003o0?n0003oP000oh000P000?l;0?n0
01[ooooo6P3oP01L0000o`d0oh0010000?l00`3oP000003o0000o`050000oah0oh003oooool000go
oooo=`3oP0070000o`h0oh00:P000?l=0?n000@0003o00<0oh000000o`000?l01@000?l90?n00080
003o1`3oP0000`000?l0oh000?n000090?n001[ooooo6P3oP01L0000o`h0oh000`000?l00`3oP000
003o0000o`050000oah0oh003oooool000gooooo>P3oP00<0000o`/0oh009@000?l40?n000030000
o`3oP000oh0000H0oh001P000?l00`3oP000003o0000o`030000o`T0oh000P000?l0103oP000003o
0000o`000?l?0?n001[ooooo703oP01J0000o`h0oh001@000?l20?n000@0003o7P3oP00?ooooo`00
3Ooooolk0?n001@0003o1P3oP00Q0000o`@0oh0000<0003o0?n0003oP0001`3oP0050000o`80oh00
10000?l90?n00080003o00@0oh000000o`000?l0003o3`3oP00Joooooal0oh000`000?l20?n00580
003o103oP0000`000?l0oh000?n000070?n000D0003o0P3oP0040000oah0oh003oooool000gooooo
?@3oP00K0000o`80oh0070000?l30?n00080003o2@3oP0060000o`030?n000000?l0003o0080003o
2@3oP0020000o`<0oh0000<0003o0?n0003oP0003@3oP00JooooobD0oh00D@000?l>0?n000D0003o
0P3oP0040000oah0oh003oooool000gooooo?@3oP00i0000o`h0oh001P000?l00`3oP000003o0000
o`020000oah0oh006_oooolW0?n004l0003o3P3oP0050000o`80oh0010000?lN0?n000oooooo000=
oooooch0oh00>0000?l30?n000030000o`3oP000oh0000P0oh001P000?l00`3oP000003o0000o`02
0000o`h0oh0000<0003o0?n0003oP0003@3oP00JooooobP0oh00CP000?l>0?n000H0003o00@0oh00
0000o`000?l0003o7`3oP00?ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`003Oooool01P0_>QX0;CXJ02Xi700Z>280:SLY02Xh;080:cP]
00/0;CTa02`h<P0^=cH0<3Th030i>@0a>SX0<C/h030k>00a?CT0<cdi03<m>P02038l>@0;03<l>P0c
?C/0<cdi038l>P0c?S`0=3hm03I1?P0e@3d0=D8n03E1?00fA3/00P0f@cX0300gA3`0>4Hn03U7?`0k
BD40?4]203e;@P0mBd@0?Te603m>A`10CdP0@4i8041>B@80@E1:00/0@E19045@B011D4T0A5=:04AC
B@14E4X0A5E<04IGC@14ED/0A5A<04IFCP0204MGCP0;04MHCP19FDh0BUY?04]KC`1;G500C5eA04eN
D@1<G4h0C5e?04eMC`1;GDl0101=GU402@1;G4l0Bea>04YJC@1:FT/0Bee8049E>P0E80h041P7010F
1P0200/@0`0400T=0P08308020`200L700801`H000@00`<0008300010P0000800P03100300<3000:
00<200050P<01@8600H41P030PD00P8400@40P061P401PD100T90`802`/500/03Ph800lA2@0B4`/0
51D=01DF3@0E5`d051H=01<C3@0@40X03Pd900/;200300`<200;00T:1P0720<01PP300H70@051`40
0`D000<300020P000@80008300030`000P051P402`0720801@L100@500061P802PX400l@200?4@T0
3a0:010A2`0?4@/03a0;00803A0:00/03a<;00/>2@010P000@<0008300010`000080004100010P00
00<000030@0200021@0600022@000@d00@0@0080300510L000406_oooon]0?n000oooooo000=oooo
o`06041=A@1EIeH0@U5703I0@@0b>480=S]:0P0h?dX02`0k@Dd0>Ci=03a1D`0nA5D0?TIF0459F013
C5X0AE1L04MBG@18DUd0B55L0080B59L00H0BE9N04UCG`17DUl0Ae9O04IBG`18Df0204UDH00304]F
HP1;EF00CUMO0080C5AM00`0CUMP04mIHP1=F680CeYS055KH`1AFf@0DEYW059LJ@1DGF/0EEm/05EM
JP1FGf`205QQKP0;05USKP1JI6`0FfE[05aVK01MIfh0GVUa05iZLP1NJW00Gf]`05m[LP1PKG@00P1Q
Kg@02`1SLGD0IgAg06QeN@1XMGP0IWEk06IeO@1XN7d0J7Uj06UjN@1/NgX0K7]k0080K7]m00/0K7]n
06elOP1^O7d0KWek071nN`1`OgP0L7mg06ioLP1JJ5`0FFQJ05UWF@0205MSE`0<05EQE01EH5@0DEaA
03Hj>00c=cD0<3@b02`a;00Y;RP0:BdX02P/:@0X:bT09bTY0P0V9bL02`0U9bH092LU01<A5`0?31<0
3PdA00T:3@072@X01`T600P:100930D02Pd400802@`300L02Pd400T=1P0;3@H030h600`=1P0?4@T0
3a8:00803a<;01003a8<00hA3@0>4@`03Q4<00h@2P0<3PP02@`500T<0`0930402a0200dA100>4@H0
3Q8800hC2P0=4@X03A090P0>40T01@0>3`P030h700T;100:2`D02`h500803Q4800@03A0700/>1P09
30@020/40P0:3@D02`0930@01PP100H90P062@801PP300H8100930L020/600<50@011@400`D:0080
0`@D00H00P<F00@460081aL030P;00/80`061`4Joooooch0oh000`000?l20?n000l0003oF`3oP00?
ooooo`003Oooool01P0b>4X0=Ca>03@jC`0e>E00=CUA03DiDP80=caB00/0>3eB03PmD`0i?UD0>3eF
03U0E`0k@EP0>D1G03Y0E`0k@UP0?TEK03m6G0020459G00;049:G012Bed0@DUM0418GP10BEh0@D]P
04A<H013Bf00@TYO04E<G`16Bed00P16Beh03017CF80BTmU04Y?IP1:D6D0Be1T04aAIP1<DFP0CE9Z
04aBJ@1=Df/0CE9[04iCJ@80CeAY00/0D5EZ051FJ@1BFFT0DeYZ05AKK01EG6l0EUe`05IMK`1GGfl0
F5m`05YRLP0305]UL`0:05mXMP1PJGP0H6Yh05mZNP1NJG/0HFaj069^N@1TKgX0IFmj06I`N`<0IW5l
00X0IW9l06QdO@1YM7d0JgIm06agN`1]NG/0KWal071nOP1aP7l0LH1m0P1dPWd0301ePWh0Mh:007J2
P01cOgl0Lh1o07:0O@1bPGX0Lh5h07B0M`1dOgL0MH1i07AoNP80Lgij00/0L7af071oM00i?D006a/Q
01/L7`0A51@03A4>00X=2@0:30@02@`300T<0P0200P;0@0300H:00031P000`@0008010D000H010@0
00D60@051`4010D100H70`0720<300H50P0;00L60`061`<01PP100H90@0?4`P05AX;01PM3P0J8100
7B<C01`R4`0J81800P0L7a802`0L7Q<061X@01@E300A4@P03Pl700`=1P0;3@D02P/400L:0P062@00
1PP0008010H000<00`@00084000210000P031@001P051`802@`600X=1P082`800`D000<40P801@D4
00H01@H400d?1P0D5P/06AX=01HG2`0A4PXJoooood`0oh006`000?m60?n000oooooo000=ooooo`03
038hB`0c>4l0<cQC0080<cUB00h0=C]D03DkD`0e>e<0=SaD03HlD`0h?UD0>3mF03PnEP0k@eP0>3mD
03U0E@0j@UD0?DEH03i6F`80@4QK00/0@DYM049:G`12BUh0@dUN04=9G`13BUl0A4]P04A<H@15C680
ATeR04M=HP0204Q<H`0<04Q=I018CFD0BTmV04aAI`1>DFH0CE5U04mDI`1?E6P0CU=W04aDI`1>EFT0
D5IZ0`1@EVT02P1BFVX0DEYY05=JJ@1DFfX0EUe/05IMKP1GGVl0Eem_05UPL01JHW8205aUM@0;05eU
M01OJ7D0GfQf065ZN01QJgT0HVaj069/N@1TKWX0Ifmj06Q`N`1WL7/00P1VLG/02`1VL7T0JG=k06Yd
O@1YM7h0JWEn06]hOP1]NGd0KG]l06ilO01_OGh0L7el0080LGml00H0LWmn079nOP1bOWh0LWmo07:0
O`1dPWh207F2O00407F1N`1eP7/0MH1k07N1OP80MGmn00/0M7mk07>2NP16CE00820Y020R9@0G6AX0
418@00hA2P0<3PD020`200P<0`0200T<0`0;00T=0P0520400`D000<400031@0010<000D400051@00
2@P000`;0`0;2P<00P081P803006104020L200L80P061`401@P100dA1P0D60X061`=01`P4@0N8a@0
7b<E01hR4`807R8A00/07B0@01XL3P0F5`/04Q<:00d?200;30D02@/500T<1@0930@02@`200H:0@02
00@7000600@500031@0010L000D80@041P4010H00P072P400`052@000P@00083000200<3000600@3
000:2`004A4501@D2@0C4`T04A8;6_oooom50?n000<0003o0`3oP00L0000odH0oh003oooool000go
oooo00H0=CY<03DiD00d>E<0=CYC03DkD@0f?58203PmD`0;03TnE@0i?UH0>T1F03U0E@0i?eH0>d9F
03]1D`0j@E@0?DAE03m5E`0oAUX00P10B5/01`10Aed0@TUN04=:GP14BUl0A4QP04=8H@13BF400P14
Bf804016C6<0ADaT04M>I@17CVD0AdeT04Q>H`19CV<0BdmT04e@I01>DVD0CeAV04iCIP1>E6H0CEAV
04iFI`1?EFL2051EJ00;055FJP1BF6/0DEUZ059JJP1CFfX0EEa[05MNK@1HGW00F5ia05UQLP1JHg80
0P1LI7<02`1MIG<0GfQd061YM01RJgH0HVag069/N01SKGT0IW1i06I_N@1WKgX0J71k0080Ig5k00/0
IW1h06QaM`1ZM7P0JWAi06]fN`1[Mgd0K7Qm06eiO01_Ng`0Lgin07AoP00207F0O`0<07>0O@1cP7`0
Lh1n07>1O`1bPGh0M85m07F2O@1dPW/0Mh=m07R3OP1hPgl0MH1n0P1eOgd02`1dOg`0Lh5j051HFP0P
7b`07R0V01TK7@0C51@03Pl=00`=2@092`H01`T400801`X300/020`200D900031P000P@000830004
10001@D000@5000820002PT100X90`0200P7100<00D60P092PD02P/300X=0P0930402P`200h@1@0E
5`T06Q`<01hP4@0O8Q<082@B0P0O8Pl02`0N8Pl071l>01LH2`0B5@/03Q8:00/>1`092`D02@`500P;
0`0930<02@`400802@d200/020X000H900062@001`T100H80@051`0020/000L:00031`000@<000<3
000200@2000600@100071P003@d4014@1P0B4`P051D<6_oooom60?n000@0003o00<0oh000000o`00
0?l06P000?m60?n000oooooo000=ooooo`0603@jB`0d>4`0=CY@03HjD@0g>e00>Ce@0P0l?e<02`0l
?eH0>cmG03TnEP0i?e@0>d1D03e2E00n@U@0?d=D0496E`12AEX0@TIM0080A4YP1013BV001`13B680
A4QQ04A:H@15Bf80A4]R04I<H`17CFD00P18CVH03015CFD0AdiT04Q=HP1:CV80C51T04iBIP1>DfH0
CE=V04mEI@1?EFH0D5EW051EJ080DUMY00/0DeQZ059HJP1BFFX0E5a/05AKK01EG6`0F5i_05QPLP1I
H780FF5c05]SL`0205aTL`0;05eVM01NJ7@0GfUc065[M01QK7@0HVef06A_N01TL7P0IG5i06IbN`1W
LWX00`1XLgX02P1YLgP0JG=f06]dM`1/MWP0K7Mi06ahN@1_NWP0L7]i079nO@1cOWd207B0OP80M85m
00<0M8=m07:1O01bPW/00P1bPG/01@1dQ7`0MhAm07R3OP1hPWh0MX1m0080MX5k00/0MH1i07B0N@1O
J6H09RHc01hP:00L828061/J014D4P0<3`d02P`900T<1@0200P;0@0500L:0005200010L000@70003
1@000P03100010041P0020T100T:0P0:30D200X<1P0<00T<1P093@H02`d300dB0`0=4P802`d100X<
0@0@50H05QX901/O3P0N8Pl07bDB0P0N8a40200M8A0071l@01XM3`0F6a004QL<00lC2@0=3`L02`h5
0P0;3P@03@0:3P802a0200/@0P0<4@402@d100L;0@082P801PP100@5000620001PT000<600011000
0`010P001P010@000`@000T<100?4@H04A@7018E2Q[oooooA`3oP00P0000odH0oh003oooool000go
oooo00H0=3]903HmC00h?Tl0>3eC03PnD`0j?e8203`oD@0;03/oE00j@5L0>CmF03]1E@0l@U<0?DAC
03m5E011AeD0@dYI04=9GP13AUl00P14Af802`15BF@0ATaU04I;I015Bf<0AT]S04M<H`17CF@0B4mV
04I>I@17CVD0B4mV0080B51W00`0ATmW04UAI`19DF@0Be5R04iBI01?DVH0CU=V04mEIP1@EfL0D5IX
055FJ@1CFFX205=IJ`0;05AIK01CFV`0E5Y/05AKK@1EFfd0Eei^05QOK`1IH700F5m`05UQLP1LHg<0
0`1MIW@00`1NJ7D0H6]d069/M002065[L`05069]M@1TL7P0I71i06EaN`1VLWX00P1YLgX02`1[MG`0
K7Ek06]eN01[MWP0K7Mh06eiN01/NGH0KWaf071mN@1aOWd0LWmn0080Lh1m00`0LX1m07B1O@1ePgh0
Lh9m07F3OP1dPgh0M89n07J4O`1gPWh0N8=n07R2O@1fPG`307F0N`0:07N2O01XLVl0;Bhj02@U;`0P
8RL07b0Q01TK600A4Pl02`d800L80P801@P000@01`X000H:00041`0010L10P031@001@041P401@L1
00T:0P0:30@02`l5008031050P0=4@P02P0<40L03Q<600hC1`0<40H02@`300dA1`0B5`/061h@01/Q
4P0N9A<201lU5@0;01`Q4`0K7a806alB01TO4@0G7A005Q`@01<H300?50P02a0400/@1@0:3`@00P0<
4@@02`0=4P<02a0200/>0`0<3@<020X000@500051@001PL000D700041P000P<00080008000H00040
00020006208030l500lC200B5`/JooooodP0oh0080000?m50?n000oooooo000=ooooo`0603@kB@0f
?D`0>3i?03PmD`0h?U<0>SmB0P0l?e402`0k?e@0>T1G03ToEP0k@ED0?49C03e4D`0oAE@0@DME04=:
F@13BEh0@dIO0080A4MR00/0ADUT04I<I@16Bf@0AD]S04I;H`17C6<0AdeT04Q?IP16CVD0AdiU04Q?
IP0204Q@I`0<04I?I`19DFL0BE5T04]AHP1>DV@0Ce9V04iCIP1?EFH0D5MW051FJ01AEVT0DeUZ0P1C
FF/02`1DFF`0DeY/05AJK01DFfd0EE]]05MNKP1HGfl0FF1`05QOL01IHG80G6=c00<0GFId00<0GVQe
061[M01RK7@00P1QJg<01@1RKGD0I71h06A`N@1ULG/0IW9j0080JG=j00/0JgEl06aeN`1[MGP0JgIh
06agN01]NGP0K7Uf06ilMP1`OGT0LGim079oOP0207>0O@0<07:0O@1dPGd0MH=n07>2O@1ePgh0M8=n
07B2OP1fQ7l0Mh9n07R3OP1hPWd0MX5l0`1eP7/02P1gPW`0J79_02d^>P0T9Bl0828W01lP8@0I6aP0
4A8?00/=2007208200D8000400L:00062P0010L000@70@800`D000D010H100D70@092P802P`400/?
1@0200`@1@803A4800X0310700hC1P0>4`L0310600T<0`0=4@L04QL;01PN400K8A807RDC0P0O9AD0
2`0L8A<06alB01/O4P0I7a405ad@01HL400C60`03a@800/@100;40D02Pl40080314400/03A8300/@
0P0;3P<030d300P:00041@001@D000H700051`0010H00083000200020006000100000P001PP200`?
1@0?4`P04QL;6_oooom80?n00200003oA@3oP00?ooooo`003Oooool01P0d>dX0=C]=03HlC`0f?E00
=SeA03ToDP80>T1B00/0>CmC03Y0E@0j@UP0?4AH03i5E`0oAeH0?dQF0418EP12BUT0A4]N04=8GP02
04A6H00704I8I@18C6T0B4aX04I;I@18C6@0B4eS04U?I`0204Q?J@0904Q@J019D6L0BU5X04YAJ019
DFP0BU5V04]AI01<DV@0Ce=U0080DEAX00D0DEEW055GJ01AEVP0DUUZ05=KK00205AKKP0;05=IKP1C
FVd0E5Y^05AKK`1EG6l0EUi`05MOKP1HGfh0FF1`05aRM01MHW@00P1NI7D02`1NIgH0GfUg069[N@1R
K7P0Hfeh06A`NP1SKWT0IG1k06EaN`1ULW`0Ig=m0080JGAn00/0KGIo06efO@1YM7/0JWIk06aiNP1/
NWT0KWai06imN@1_OW/0L7mm07:0OP0207N4P00407J2O`1gPh00NHB107N3P080NHB100H0N8B007V4
P01gPWl0NX>007Z3O`1hPGd207N1O00;07J2O01gQ7`0LG]e03/mA@0V9S0092DZ02@V9P0N7ad05aPC
014B300;3@H00P082`8200P<000900T=0`0;3PD020X400D70P041P<01@H300P:100:3@D02Pd40080
314500`02`l500`?1P0=4PP03Q<:00lD2`0?4`X030l700/=1P0A5@/061hA01`R500O9AD2020V5`0;
01hT5P0M8QD07R8C01XP4`0F71004aT=010F2`0?5@T0314700/@1P0;4@L00P0=4PP02`0=4@D02a02
00/>0P0=3P802@/000H9000520001@L000@700041P000`@000800@8000H0004000410006208030l5
00hB200@50XJooooodL0oh008@000?m50?n000oooooo000=ooooo`0603<kC00e?500=SeA03DlD@0h
?e80>3m@0P0h?e802`0i?e@0>T5G03]2FP0l@eX0?TEJ03i6F00mA5H0?dIG0458F@11BE/0@TUN0080
A4UR00/0AdYW04Q<J@18CFP0ATaW04M=IP18CVL0BE1W04Q?J@19D6T0BU1Y04Y@I@0204aAI@0<04]A
I01=DVD0C55U04eBI@1>DfH0CeAW055FJ01AEfL0D5MV055GI`1AF6T0DUQZ0P1AF6/02`1CFV`0EE]/
05EJK@1EFVh0EEa_05MOL01HH740FEm`05]QL@1MHW80GV9d0080GFAe00/0GVMf061YN01RJgX0Hfej
069/NP1SKW/0IG1k06IaO01UL7/0IG5k06McO00206]fO@0;06efOP1]MG`0JW=l06]eO01/MW/0JgQj
06ejN`1^Ng/0Kgak0760OP1bOgh00P1fPh001P1gQ840N8>107V3P@1iPh00NH=o07Z4P080NX>000@0
N8=o07Z3O`1jPgl0O8B00P1kQ7h02`1hPg`0MX9j07R4N@1<CTl0928/02HU:@0S92<0828N01dN5`0E
5A00414:008030l600/020/300T<0`0<3`L03Q4:00`>2@092`P01`P700H61P082@L02P`800X<1P02
00X=1P0<00T<100:3@@03A4700hC2P0@5@`041<:00d>1P082P803A0601HL3`0L8Q@082LG0P0P9aP0
2`0P9AP07R<G01dR500K8A<05ad@01<G300@5@X03Q<900`@1`0;3`H02Pl600802`l600/020`300X=
0P0930002P/000L800051P0010H000D700041P000`@00083000300420005000200031@002P`200d@
1P0>4PT06_oooom70?n00240003oA@3oP00?ooooo`003Oooool00`0e?Dh0=Sm@03I0D00203LoD00>
03U0D@0h@E<0>45C03U0EP0k@eX0>d9K03e3F`0nAEX0?dIH03m7EP11BET0@TYJ049:G014Beh204I<
HP0;04Q=I@19CVD0AdeT04I>I017Cf<0B4mQ04UAHP1:DVD0Be=W04eCJ@1=DVP00P1>DfL01@1>DVH0
Ce9V04iBIP1=DfH0CUEW0080D5IX00D0D5IW055HI`1AF6L0DUUX059JJ`0205=IJ`0;05EKK01GG6d0
F5e^05UNL@1IGg40FF5c05]SM01LHg@0GVEd05mVM01NIGD00P1MIWD02`1OIgL0HFYh06=/N@1SK7P0
Hfii06A`N@1VLGX0Ig=k06McNP1WLg/0JGAl0080JWIk00/0JWEk06aeN`1]MWd0KWIm06egO@1/N7/0
KG]j075nNP1bP7/0MH1n079oO`0207>0OP0;07N3O`1hPh00NXF107Z4PP1kPh40Nh>007^3P@1kPh00
NhF007Z4O`1kQGl00`1jQ7h02`1iPg`0MX5i07R4N`1DFUT08alX02@S9`0Q8B808B8O020R6`0I6Q80
4Q<<00803a4;00/03Q4;00`@2@0<3`X03A0;00d?2P0<3@P02@X600P81@0920@02PX700X;200200T<
1`0<00P:10072@802Ph600lD2P0B5`d04AD;00h@1P0;2`403Q0501HK3P0J8A<07RDE0P0O9QL02`0N
91H07B@F01hT5P0L8QD061dA01@H3@0@50X03A8800`@1`0;40H02Ph5008020/300/01`T200/=1009
2`002P`000P900051P0010H000D700062@0010H00084000200830006004300000P000`@000T:0@0<
40@030l66_oooom40?n002@0003oA@3oP00?ooooo`003Oooool01P0g@540=d1B03Q1E00h@E<0>D5C
03]4E@80?4AH00/0>dAJ03a3G00mA5d0?TMM03m7F`0oBEX0@DYJ0419F@12Be/0A4iM04I>G`0204M=
H00504Q>HP18CV40AdmQ04M@H@18DF400P19DV40101:DF<0CE9X04iBK01?Dfd204mDK00<051DJP1@
EFT0D5IY04mDJ01@EfT0DEQY051FIP1@EfD0DUUW059JJ01CFVX0EEe^0P1GGVl02`1HGVl0Eee_05UP
L01KHW80GF9c05aSM@1LIGH0GFEf05iVL`1OJG@0GVMe0080GfQe00H0H6Qh069[N01TKGT0IG1j06Ea
N@1VLgP206MdN00306QeN01YMGX0JWEk0080JgEl00/0KGMn06egO@1^NGd0KgUn06mkO`1`OGh0L7ij
07:0N01cP7X0MH5m07B1OP0207J3O`0<07V5P01jQ800NhB107f7Q01nQhD0OHF307j5P`1mQH80O8J1
07^5O`1kQWh0NXEm0P1kQWd02`1kQWh0NHAk07Z8OP1PJfD08b4[02<S:00S92H08B@R01lS7@0K7QH0
5QP@00804a@>00/04A<=00lB300>40X03@l800h?200=3@D02@/400P800092P802PX400X:1P0200T:
1`0<00L91`0620D02@`800lD300B5`h04QH<00h@1P0:2@403`l501LI3@0K81807B@F0P0O9QL02`0Q
9aT082HI01lU6@0N9AP06R0E01DJ3`0@5@/03A4900/>1`0:3@D020/3008020X300D01`P200P:0P07
2@0020T000H7000200@6000400@7000520001PP000@600800`@000H00P<0000200051`0030d200h@
100<3PDJoooood<0oh009@000?m50?n000oooooo000=ooooo`0603LnDP0g?eD0>41G03U1E`0i@ED0
>T9F0P0j@UL02`0l@eX0?TAM03m5GP10B5l0@4UP045:H013CF00@deO04A>GP17D600ATmP0080AdiP
00/0B4mQ04QBHP18DF40B55Q04QBH@1;E6@0C5EV04eDI`1@EFX0Ce=/04mDKP0204mDK@0304mDK01?
EFX0DEMZ0080D5IY00L0DEQZ055JJ`1CFf/0EEe[05ALK01EG6d0Eem^0080Eee^00/0F5e_05QNL01I
HG80FF9b05aSM01MIGH0GFIg05iWN01MIWH0GFId05iWM@0205mXM@0;069ZM`1TJgX0I6aj06A^N`1U
LG/0IW5i06McN@1XMGP0JWIj06YeN`1[M7/00P1]MW`02`1^MWd0KgQl06miN`1bNgl0LWf0075nOP1c
P7h0MH5n07B2OP1ePGl0Mh:00080N8B100`0NXF107Z5P01lQX80OHN307f6Q01lQH80OHF007n7P`1o
RH<0OhR107n9P@1oRH0207f8OP0;07f7O@1hQ7/0NXMl06ahK`0^;SH0:BX_02T^;00R:B@06QlI01HK
500C50h00P0B4`d02`0B4P`04A4:010?2@0?3PH03`l500/;0@082`401PT000P;00082P802@`50080
2P`600`02@/700P:1`0;3PX041D<010D300?4`T03a0600X:0@0:2@405QP901dQ4P0P9QL2024W600;
028V6@0Q9QX07bDI01hU6@0J81@04aT=00lC200<40H02`h500X=1@0:30@00P082P<200L90`0600@6
00031@000@<0008400021@0010H00P051`002@031@000PD0008500010`000P8000D5000;2`804146
00l@1`0Joooood<0oh009P000?m40?n000oooooo000=ooooo`0603LmE00h?eH0>d9I03Y2F@0j@UP0
?4AF0P0j@ED02`0l@eP0@4EM0416G`10Af40@DUS04=<HP15CV<0A4iR04E>H@16Cf40ATiQ0080B4mR
00/0BU5T04UCI017D680B55R04UAHP19DF@0Be=V04iEJ01?E6/0Ce=/04mCKP0204iDK@0<04mEKP1?
EVd0D5IZ051GJ@1AEfT0DUU/05=KKP1DG6h0EUi_05IMKP1HGG00FEib0P1HGG002`1IGG00FUib05YP
M@1JHGD0G6Af05eUM`1MIWH0GfQf05mWMP1OIgD0GfUf0080H6Uf00@0HVYh06A[O01TK7d0IVmn0P1W
LGd01@1YLgd0JWEm06YfO@1ZMG`0K7Ek0080L7Mn00/0LGQo071hO`1`NX00LGb2079mPP1cOH00M7n0
07N2P@1fPX40Mh:107V2PP0207Z4P`0307^5P`1jQ880O8J40080O8J400L0OHN407f6PP1nR8<0OhV3
082:P`1oRX<0OhV10080OXQo00/0OXUn07^6O01hQ7/0MhAh03Pj?P0W:2d0;34]024V800F6AD04A@@
00hA300300h@2P0:00h@2@0=3`L02``300X<0P0:300020/000P<0P0;3P<02@`300X=10802P`400`0
20/300L90`0;30H03Q48010B1`0>40@030d200T8000920405AP901`R4`0O9AP2020W6@07020V6@0O
91P07R@G01hT5P0I7Q404QH;00dA1P0200/>100?00X=100:30@01`X300L:0`062@801`T200<50001
0`000080000100010P000P<000<500041P000`@000800@<000H00@8000<300092@803@h5010A200@
4PTJoooood40oh00:0000?m40?n000oooooo000=ooooo`0603U0DP0j@ED0>d9H03e3FP0nAE/0?dIL
0P0oAU/02`0oAU`0@DMM0458H012BV<0@DUS049:I014CF@0A4eR04A>H@16Cf80B55R0080BE9T00/0
C5=U04]BI@19DFD0B59U04UBI`19DfH0C5EY04mFK@1@EFl0D5A_051EL002055GLP0<059HL`1CFG80
DeY`05AKK@1CFV`0De]/05ELKP1GGg00F5m_05IMK`1IGg80Ff1e0P1JH7@02`1JHG<0G65d05eRMP1M
HgL0GfIh05iVMP1MIWD0GfUe065[MP1PJWH0HVah0080Hfei00/0I6aj06M^OP1XLH40J7:006MaOP1X
Lgh0JWEo06]eOP1/MWl0KWQo071jP003079kP`0:07=nQ01bOH@0LWj5079mP`1fOh80Mh2107R1PP1h
PX80NH:207V3PP80NhF400/0O8F407b5Q@1lQXD0OXR707n:Q`1oRXD0OhV407n:Q020RX@0PH^3082;
PP0308:<P`0;086;P@1nR7h0O8Mm07b9O@15B4/09B@[02T/:`0T9b806A/G014B4@0?3`/00P0>3PT0
2`0?3`T03a0800d>1P0:2`@02@/400P:0P072@402@/300/>1@0;3PH02`h500802@/400`01`X200T;
100;3@D02`h400/>0P0:3@402P`100T:000<3`<061`=01dS500P9aL2020X6@0;020W6@0O91L082@F
01lU5P0K7a<04aL<00lB200;3`D02`h400X<0`082P800P062@<00`051`401@P00085000300830080
0@<000<00`@000D600041@000P020`001P010@000`@100`?1@0@50X04QL<010D2a[ooooo?P3oP00[
0000od@0oh003oooool000gooooo00H0>d=B03a3E@0nA5X0@4EL0455G`11AV020458G`0;0459GP11
BUl0@d]O04=<HP13C6<0@daR049<G`13CEl0ADiO04Q@H@1;Df@00P1<E6D02`1=E6H0C5=V04YCIP1;
EFT0BUAZ04]EJ`1<EV`0CeQ_059IL01BFG80DUQ`0080DUYa00`0DUUa05=JLP1EG780EEaa05ELL01F
GVl0Eei`05UQLP1HH740Eei`05UQM01JHW<205UQL`0;05YSL`1MIG@0GVIe05mVMP1PIWL0GfQg05mY
MP1PJWH0HVef069]M`1SKGL00P1TKg/02`1UKWd0J71o06UaP`1YLX<0JWB306afPP1/Mh00KGMn06ih
O`1`NH00L7^20080L7b300/0LWj407AnP`1dOX80M7j307EnP`1hPH80NH:207Z3PP1jQ8<0NhB307b6
Q00207f7Q@80OXR700X0OHR707n9R@1oRhP0P8^707n9Q@1oRXH0OhZ5082:Q@21Rh@0Phj60P24SXH0
2`23S8@0P8Z007f7O@20S7h0E5QG02LT;@0X:Rd09RTW01dO700E5A803`l;008030d700/03@h600h?
1P0<30@02PT300X8100:2@@02@T200P:0P0:30@030h500/=1P0200X=1P0<00P;1@0:30H02P`600T:
10072P<02@/300X=0`0:3@40418601TM400O8aL08BHH0P0S:1T02`0R9aT08BDH020S5P0O91D06b0B
01DI3@0@50T03Q8700`@1P0;3@D02P`5008020X400<01@P200<5000110000P0210001P030`000080
004300041P001@H000<500800`@000H00P<000<4000>4@P051T=01DJ3P0B5PhJoooooch0oh00:`00
0?m40?n000oooooo000=ooooo`0603]2D`0l@eH0?dIJ0417G011AUd0@DMN0P11BEl02`0oAel0@DQP
04=<H@14CF80A4eS04I?HP17DF80B55O04YAG`1=Df80CUAU0080CUAV00T0CUEW04eFJ01<EFL0C5EX
04eFJ`1>Ef/0CeQ/055JK01CG6h00P1CFfl205ELL080EE]`00<0EE]_05IKL01EG7800P1FGG801@1F
GW40Eema05UPLP1IHG80FV5a0080FV9a00/0Ff=b05aUM01NIGH0H6If069WN01RJ7P0Hf]i069[N01T
KWP0IFmj06E]NP0206I^O@0;06Y`O`1[L840K7:406acQP1_MXL0KWF506mhP`1_NH40KWUn06miO`1a
Nh400P1bO8801`1cOX80MWn307IoPP1fOh@0MWn607N1Q01hPH@00P1kQH@02P1mQhD0OhV707n9Q`1o
RHL0OhZ9082:R@1nRHT0P8^<086=R`22S8T208><R00408>=R@21S8L0PHb6086<Q@80Q8n500/0QHj4
08><P@1oR7h0PHao05iSGP0W92h0:2T^02@W9@0K7aX051LA010C2P0200d@1`0700`?1P0=4@L02`h5
00/<100920<020L300P:0`0200T;0`0300X<0`0:30D02Pd500<02Pd500X02@`600P;1P072PD020/3
00T<0`082P8030h501HK400M8QH08BHI0P0T:1T02`0S9aT08RDH020T5P0P9AD07B8D01TN400E6@`0
3a@800`A1P0;3P@02`h500802P`500X01`T300@60@031@000P@000<4000410000P<000<400041P00
10L00`0210001P020P000`<100lB2@0D60h05QXB01DI4a[ooooo?@3oP00/0000od@0oh003oooool0
00gooooo00H0?4=C03e5EP0oAeT0@DUL0458G013BUh20499G`0;0458H`12BF<0A4aS04I?H`15Cf<0
Ae1S04YCH`1:Df80CE=R04mEI@1?EVH00P1@EVP02`1?EfT0CeQY04iHJ@1?F6T0D5QZ055HJ`1BFF/0
De]/05AKK@1DFfh0EEe_0080EEa^00`0EUa^05MMK`1KGg40FUib05QNM01GGW@0EUib05ENL@1GGg00
F61`05YRLP1LI7<205eUM00;05iVM@1OIWL0HFMi069XM`1TJGT0I6Yj06I/N`1UK7/0IVik06I_N`1W
Kg`00P1YL7h02`1/LH00K7>306abP`1]MHD0LGR6071hQ01aNH@0LWV3079jP01bNh00M7b00080MGf2
00X0Mgj307QoQ01gOhD0N86907R1RP1iPXT0Nh>907f6R01lQXD0OXN60`1oRHL03020RXP0PH^9082:
RP23SHd0Q8j=08F>S024SHT0Q8j808F>R@24SXT0Phf608>>Q080Q8n300/0Q8j308:<P@21RWl0PHan
06Q`J00_;3@0;c0b02PZ:@0M8Qh051TC014F2`0200lB2@0300`?1`0;3PL02Pd700<02`d800D02Pd5
00X=100:3@@02Pd400/>1@0200/=1@0<00/>1P0;3`H02@d500P<1@072`<020`300T>0`0:3@<02`l5
018F300J7Q407b@F0P0S9aP02`0T:1T08bLJ028V5`0R9aH08BHF01hR500H70l04aL:00hC1`0<40D0
2`h300802Pd300T02@`200T:0@0620001@D000H500071P001@D000@300030`000P02100200420006
000100041@804aL;01DK3P0G71405AP@6_oooolj0?n00300003o@`3oP00?ooooo`003Oooool01P0k
@e<0?DIF0419FP11B5/0@4MM0458GP80@TYQ00T0@TUS04=<I@15CVD0Ae1T04QBI019DVD0BU=U04aD
IP1=E6D00P1>EfL204mHJ@0;04mHJP1?FFX0CeYY055KJ@1CFfX0Dea[05AKK01EG6d0EUe^05IMK`1F
GW000P1EFfl0301FG700Eee`05YOLP1JGg80FEic05UPMP1IHWD0FF=c05UQL01JHW00FfAb05eVM080
GfMf00/0HFYg065[N01QJWP0HV]h06=[N01UKGT0IVii06E^NP1VKg/0IW1l06MaO00206QaO00;06]c
O`1^M880K7B106egP@1`NH@0Lgb5079kP`1dNh80MGb107EnP01fOX000P1gOh402`1iPH@0NX6607V1
R01hPHT0NH6:07Z3RP1kQ8X0OHJ:07n8R021RXP0PH^90080PHb800`0PXb908>=RP23SH/0Phf;08F?
S@26Sh`0QXn;08NAR`27T8X0QXn908J>Q`25T8D208B?Q00;08>>PP25Sh<0Phf108:>P01bNg40=cHl
03@f>@0c=cH08R@S01PJ600C5Q400P0>4P/02`0<3`X02`d900P:200:30T02`h:00`?2@0:30D02@/2
00/=0`0=3P<03@l300803@h400`02`d500X>1@093P@02Pl400/@100>50@03Q@5014G1`0@5@L041@7
01LJ3@0M8Q@2024W600;028X600R9QP08BHF020U5@0Q:1P07bDG01/P4`0F6`l04A@:00dA1P0:3P80
0P0830000`0930002`/100T90@0200L6000600P700061@0010<000<300020`000P800P010@001P00
0P000P@100dA1P0C6@/061d?01PL3A[ooooo>P3oP00`0000od<0oh003oooool000gooooo00H0?4EC
03i8EP10BET0@TYN04=;H013C60204=<H@0;04A=H@14CV80AU5S04MBI019E6H0BUAV04]FI`1>EfT0
CEMY04iHJ`1>FV/00P1>FVX204mJJP09051JJ`1?FVX0DE]Z059LJP1CG6X0Dee[05INK@1GGVh0F5i`
0080FEma0P1IGg802P1IH780FEmb05QNL`1IH7L0FV9f05YSM01JHg40Ff=`05eUL@1NIW<2061XMP03
065ZM`1RJWL0HV]h0080HfYi00H0IFaj06I_N`1VKW`0Ig1m06QaOP1YLgh206UdOP0;06eeO`1^MGl0
K7Eo06egP@1`NX<0Lgb507AlQ@1eOHD0Mgj507QoQ@1hP8@00P1jPXH02`1kPXL0O8>:07^2R`1jPX`0
Nh>=07b4R`1lQHT0OhN90869R@22RXT0Phb:0080Phf:00`0Q8n;08B>R`24SX/0QY2=08J?S@26SH/0
QXj;08V@S@29T8`0Qhn;08N?RP27T8T208FAR00;08F@Q@26TH@0Q92308FAP@1iQGP0?Sm303Hi?00e
>SP07b8S01TK6P0B5A<00P0>4@d02`0<3P/02`d:00T:2@0:30T02Pd900/=1P0:30<02Pd200d>0P0>
3P<03Ph200803@h100H030`100d=0P0>40D04AD8014G200@5PH2010E1P0400lB100>3`<051D:01lQ
50808bLH00/08RLH01lU5P0N9A@07B@C020W5@0O9QH06b8D01TM400D5`/03a<800`@0`0200/?0@0;
00X>000;3@402P`100T:000920002@T000L800051P000`@000@5000310000P040`001P010P000@<0
00d?1P0E60`061h?01PK31[ooooo>03oP00b0000od<0oh003oooool000gooooo00D0?TMC0419F011
BeX0@T]N04=;G`0304A=H00;04A>H@16D6<0B59U04QCIP1:EFP0C5MY04eGJ@1=F6T0CUU/04mJK01@
G6`00P1@G6/02`1@FVX0CeY[055LKP1@Ffh0D5]/059MK@1CGVd0E61^05IPK`1GH700F5m`0080F5ma
00`0F5mb05YRLP1IHG80FV5d05YPM@1KHWL0Ff=h05]SM`1LI7D0GFIe05iWM01PJ7D2061ZMP0;069[
M`1QJWP0I6ej06E/NP1TK7X0Hfaj06I_N`1WL7`0JW9m06]dO@1[M7`00P1/MG/02`1^Mg`0KWMm06if
O`1`Mh80LGV407=kQ`1dO8H0M7j507IoQ`1fOXP0Mgn80080NH6:00D0NX:;07^3S@1kPXd0Nh>=07b5
S00207f7R`040829S022Rhh0PXb>08F>S`80Q8f>00`0Q8j?08J?S`26T900Qi6A08J@T026T940QY2?
08RAS`28TXd0R9>=08RCS028Th/208NBS00;08JCR@25THL0Pi2508>AQ01lSGd0>cm202`_<`0Z;B/0
71hL01<F4P0>4@`00P0<3`T200X<1`0900T;1P082PD02Pd500X<0`0<3P<03Q0200h?0P0>3P803@`2
00803Ph100H03@d200l>0`0B4PH04A<900hA1`0;3P<200T;0@0400/;0@0>3P<05aP<01hP4`808RDF
00/08RDG020T5P0O91H082@E028V5P0P9QL06b8C01TO4@0F70l04AH:00hC1P0200`A0`0;00`?0P0<
3`402P`100/=0@0;30002P`000X<0@082`401PT000H800051`000P0310001P000P000@8000/<1@0C
5@X05AP<01DG2Q[ooooo=`3oP00c0000od<0oh003oooool000gooooo00H0@4ME049:F`14CEl0ADiP
04E=H@16CV4204I?H@0;04I@HP18DF@0BEAU04YEIP1<EVP0CUUZ04mIJP1AG6d0DEa^055LK@1AG6/0
0P1@G6X02`1AG6X0DUaZ05=NK@1CGW00Dem`05EQLP1DH740EF1`05MQL@1HHW80Eemc0080FF5e00<0
FfAd05]TL`1KI7@00P1KI7D01P1LIGH0GFAf05eTM`1LIGL0GFMh061ZN0<0HVah00/0Hfai06=/N`1U
KWd0IVil06E_O01ULGd0Ig9l06UcO01/MGh0KGEn06ifOP02071gOP0;071iO`1bNh80LWZ4079jP`1c
NX@0Lg^507AmQ`1dOXH0MX2807R1R@1gP8T00P1hPXX01@1jQ8/0NhJ;07^6R`1kQX/0OHR<0080OXZ<
00@0PHb>08>>T023SI00QY2B0P25Si803026T940R96A08RBTP26TI80QY:C08RDT`27Ti40Qi>?08VE
SP2:UX`0RIF:08ZGR`80RYN<00/0R9F:08JDR@24ThP0Q9B6082APP12B4P08bDY020S8`0E61H03a8=
00d?200200`>1@0;00P:0@082P802@d300T;0@0:30802`h200d@100>4PD04184018B1P0A4PH00P0A
40D0300?3`@03a06010@1`0?40P030h700T;10072@802@/300`=100A4PL05aT=01dQ4`808BHF00/0
8bLH028V5`0Q9AP08BHG02@Y6P0U:a`082LI01hT5P0K8Q@061lA01DL3P0201@J300;01DJ2`0A5@L0
3Q<500lB1@0>4P@03Q86014F2@0?50L03Q<500dB10093@400P0520001P021@000P@000T;0`0B50L0
5AP;01LH31[ooooo=P3oP00d0000od<0oh003oooool000gooooo00H0@4ME049:F`14CEl0ADiP04E=
H@16CV4204I?H@0;04I@HP18DF@0BEAU04YEIP1<EVP0CUUZ04mIJP1AG6d0DEa^055LK@1AG6/00P1@
G6X02`1AG6X0DUaZ05=NK@1CGW00Dem`05EQLP1DH740EF1`05MQL@1HHW80Eemc0080FF5e00<0FfAd
05]TL`1KI7@00P1KI7D01P1LIGH0GFAf05eTM`1LIGL0GFMh061ZN0<0HVah00/0Hfai06=/N`1UKWd0
IVil06E_O01ULGd0Ig9l06UcO01/MGh0KGEn06ifOP02071gOP0;071iO`1bNh80LWZ4079jP`1cNX@0
Lg^507AmQ`1dOXH0MX2807R1R@1gP8T00P1hPXX01@1jQ8/0NhJ;07^6R`1kQX/0OHR<0080OXZ<00@0
PHb>08>>T023SI00QY2B0P25Si803026T940R96A08RBTP26TI80QY:C08RDT`27Ti40Qi>?08VESP2:
UX`0RIF:08ZGR`80RYN<00/0R9F:08JDR@24ThP0Q9B6082APP12B4P08bDY020S8`0E61H03a8=00d?
200200`>1@0;00P:0@082P802@d300T;0@0:30802`h200d@100>4PD04184018B1P0A4PH00P0A40D0
300?3`@03a06010@1`0?40P030h700T;10072@802@/300`=100A4PL05aT=01dQ4`808BHF00/08bLH
028V5`0Q9AP08BHG02@Y6P0U:a`082LI01hT5P0K8Q@061lA01DL3P0201@J300;01DJ2`0A5@L03Q<5
00lB1@0>4P@03Q86014F2@0?50L03Q<500dB10093@400P0520001P021@000P@000T;0`0B50L05AP;
01LH31[ooooo=P3oP00d0000od<0oh003oooool000gooooo00H0@dYI04A<G`16CV<0B51V04Q?I@19
DFD204MAI00;04UCIP1;EVL0C5QV04eII`1@FfX0Dea/05=MK@1DGVl0Dee_05=NKP1CGVl00P1CGVh0
2@1DGfl0EEi^05ENKP1FGg40EV5c05IPM@1FH7<0F61c05URL`0205YRM080G6=f00`0GFEg05]TM01K
I7<0GFIc05aUL`1LIG@0GVIf05mVM`1NIWT0GVMk061ZNP1RJgP206=/N@0;06=[N@1UJgd0Iff006Q_
P@1WL840J76106UbP@1/M800KWF0075hP@1aMh400P1aN8<02`1cNX@0M7f507AlQ@1dNh@0MWb507Il
QP1fOXT0MWj807V2RP1iQ8X0N8>90080NHB:00/0NhJ;07j9S01mRX/0OHZ<082<S`21S8h0P8b<08:>
SP24Shl0QI2?08RDT@0208NBT00<08RBT029TY40R9:@08NBTP28UI80R9FA08ZET@2:UI00RiJ@08ZF
SP2:UX`0RiR=0P29Uh/208VFR@0908NER@26UXP0QYR604mID`0V:BX07B0N01@G500?4P`030h80080
2P`400@02@/200/=100;3P@030l40P0=3P@01@0<3`D03Q46010D200A4PP04Q<800804A<80P0>4@L0
2P0=3`H02`d500/>1P0:3@H02Pd500/=100=40@041@701@H2`0K8182024W5P0;02<X5`0R:1L08BHG
02<X600S:QT092`J02<Z6@0P9aL07B@F01dT5@0M9A@00P0N9A@02`0N91<061d>01@H2@0B5PP04QL:
010F2`0D6@h05A/>01LL3`0I7Pl04AD800802``300H01PL000@400071`404A<801LH3@0H6PhJoooo
oc80oh00>0000?m30?n000oooooo000=ooooo`0604E<G@16CV40B59U04UCJ019DVP0BeEY0P18DVD0
2`18DfH0C5QY04eJJP1?FfX0DUe]05ANK`1EGfl0EV1a05APLP1DHG40EF9a0080EF9b00/0EF1b05IP
M01GH7@0F65d05MQM01EH7D0Ef1e05YSMP1KI7H0G6Ae05eTM@0205iVMP0<05iWMP1LI7<0G6Eb05]U
L01MIW40GfQd05mXN01OIg/0GfQm061[OP1PK7`0HVek0P1SKWX02`1UKg`0IVio06Q`PP1YLH@0JG62
06UbP@1[M880K7B206ieP`1`N8D0LGV50080LWV700<0LWV807EmR01eOHP00P1fOHP01P1iOh/0NGn>
07N0SP1hPXd0NHF>07V6S080NHF<00/0NXN>07f:T@1mRi00OXfA082<T022SI40PXnA08:AT`24TY<0
QY:B08VFU00208ZET`0<08VET`2:UY<0RiNE08^FUP2;UYD0RYFE08bFU@2?VID0SiVC08jITP2=VY80
S9Z@0P2=VXh208fJS00908^HRP28UhP0RY^8061[H@0/;S007b4R01LJ6@0A51803A4<00802`h700D0
2Pd400lA200?4P/041<<014C2P02010A2004010B200>4@L03Q47010B1`804A<800`03a8800hA200>
4@P030l600/>1P0;3PD02`h400dB100@50D04AH701PM3P0M8Q<2028W5P0;02<X5`0T:AL08bPH02@X
5`0S:1H08bTG028Y5P0R:1H082HD01hV500O9aD00P0O:1D02`0O9aD07B<D01`Q4P0J7a4061hA01LM
3`0I7`l06b4A01hR4`0S9aL06Q/?00804Q8900H03@d500X80`071`<03@l801<F300F6PlJoooooc80
oh00>0000?m30?n000oooooo000=ooooo`0604I=H@18DFD0BEAY04UEJ@19DfP0BEEX0P19EVP02`1:
EVT0BeMY04iKJ`1AGFh0DUe_05AOL@1FHG40EV9b05ERLP1EHg40EV=b0080EF=`00<0EF9b05IRM@1E
HWD00P1FHW@01P1EHG<0Ef9d05QTM01JI7<0FfEc05aVM080G6Ic00`0G6Ma05YUK`1LJ700G6M`05mY
L`1PJWH0GfUh05iXN@1OJW`0HFao06A_O`1UKgh206E`O`0;06E`OP1UKWl0Ig6206QcQ@1YLX@0JgB4
06aeQP1^MXL0KgN806mhR@1_NXT00P1`NhT02`1`NhP0LWf8079mR@1eOXX0Mh2;07MoS01gP8l0N8:A
07N3T@1iQI80NHJ@0080NXR@00/0NXN@07b8T@1nRi80OhfB082<TP21SY<0PY2D086AU@23TYD0QI>D
08NDU00208REUP0408VFUP2;V9H0RYNF08ZFUP80S9RG00H0S9NE08fHU02=VI80SYZB08fJTP2=W942
08bJSP0;08bJS02<Vhd0S9Z;08ZHR02;VXP0KW]^034d=`0V:2X0720Q01HH6@0B4a<00P0?4@`02`0=
3`L05QT?01TL500F6A@04QD@010C2`0?4PT03Q4800d@1`0=40H041<600804A<600`041<700hB1`0>
4PP03A8600/?100;40<03143014G1P0D6PT051T901HJ2`0J7Pl201hR4P0;020U5@0Q9aL08BPG024X
5P0R:1H092TG028Y600Q:1D082HD020V5@0O9QD00P0N9Q<02`0O9a<07RHD028Z5`0R:AH07RDD01hV
4P0N9A407R<@020U500X;A`08RDG00806a`B00H04a@<00h=20092`P02`d900hC2P0@5@XJoooooc80
oh00>@000?m20?n000oooooo000=ooooo`0304A=HP16D6H0Ae9X0080BEEX00h0BUIX04YFJ@1:EVT0
BUMY04YHJ@1=FF/0DEe^05=OK`1DH740EF5`05IRL@1EHG00EF9a05MTLP80EfEa00<0F6Ec05MTM@1G
I7H00P1FHgD01P1GHg@0F6=c05USM01JIGD0FVEf05YUM@80FFEd00`0FFIb05QWK`1JJ700GFQb05mY
M@1OJ7H0GVQh05iZN`1NJW`0H6]m069]O01SKW`206I^P00;06I_P01VKX00J76306YbQ@1ZLH@0JW>4
06afQP1]MXH0KWN706miRP1_NX/00P1`NhX02`1`NhL0LGj7079nR01dOXX0MX2<07J0S@1gP8l0N86A
07R4T`1iQY@0NHJC0080NhNB00/0OHVB07j9T01nRI00P8^B08:=T`21Si@0PY:E08>CU@24U9@0QYBC
08NDT`0208REU00;08^GUP2<V9P0RYJG08bHUP2;V9D0S9ZF08bJU@2<VI<0S9ZB08bJT02=VXl00`2<
VXh02`2>W900Sif>08nKS02<VHT0SI^:07V6NP0m@DD0<3<g02<W:@0M82806A/L008051HD00/05QPB
04MB?P0U:b804A@B014E4P0>4P`030l800/=1P0<3@H03@h500lA1P0200h@1P0<00hA1`0=4@L03107
00/?10093P802Q0100lF1P0D6`X05ad<01LL300C5PT051H:0P0J70l02`0N8a@07bHG01lV5`0O9QH0
82HG028X6@0S:AT08BPF020W5@0P9Q@08BLF008082HG00/082LD01lW4`0S:aH092`H028Z5`0P:1H0
7bLC01hV4@0N91809RdK02H[6`02020U5`0601/N4P0D5P`03Q4:00hB2P0<4PP02@d46_oooolb0?n0
03T0003o@P3oP00?ooooo`003Oooool01P14CF40Ae1V04QCJ@19E6T0BeIZ04aFJ@80BeIX00X0C5MX
04eHJ01?FFT0Dee/05EPK`1EHG40E65`05ITLP1GIG80EV=a0`1FHg802`1GI7D0Ef=f05MSMP1GHWH0
EV9f05QTMP1II7H0F6=f05YTN@1KI7X0FVAj0080FVEj00`0FFEi05UVM`1IIW@0FfIg05eWM`1MIgP0
GVQj061ZO01OJW`0Gf]l061]O01SKgh206E^P@0;06MaP`1XL8<0JG6306UbP@1YLX00JWB206]eQ01]
MXD0KgR7071iR`1`NXd00P1`Nh`02`1bOH/0Lh6907F3R`1fPX`0MH2>07J1S`1fPY40N8BC07R5U01j
Qi@0NhRD0080NhNB00/0Oh^A082;S`1oRhl0PHfA08B?T`24TI<0QI>C08NDU@27U9<0RIFE08VEUP02
08VFUP0<08bHV02>VI/0SIVJ08jJV02=VIL0SI^G08jLU`2>W9@0SibC092MT`2AWI40T9bA0P2@WI80
2`2BWi80TIf?096MT02>W8l0S9^<08:@P`1;Ce80>3]002`_<`0W:b`09BPW008071lN00/06A`I04YH
@`0R:R404ADA01<G4`0@50l03A4:00`>2@0<3@H030h400d@1@0300dA1P0;00`@1@0=40L02`h600X=
1@0:3P<04QP:01LM3`0I7Q005A/=00lD200A50X00P0G6a00200L8AD07bDH020U6@0R9aT08BHH028W
6@0S:1T08RPG0P0Q:1H03P0R:1H082HG020V5`0P9QH07bDE02<Z6@0U;A`08RXK01lW600N9QH07bPD
01hV4@0R:A@08RTG0P0O9aH01P0N9QD06B0A01<G300@4`T03A4700T=11[ooooo<03oP00k0000od80
oh003oooool000gooooo00H0BDmN04]BI01<EFX0C5I/04]EJ`1;EFX204aFJ@0;04aGI`1=F6D0DE]X
05ENK01HHW00EV9a05ERL@1FI7<0F6Ie05MVL`1FHg800P1FHg<02`1HI7D0FFEe05QUM@1GHgH0Ef9g
05MSN@1HI7X0F6Ej05YTNP1KI7/0FfAl0080FfAm00`0G6Em05aWO01MJ7X0GVUl05iYN`1NJGX0GVYk
061ZO@1OJGd0HVao069^P@1SKh8206A`P`0;06IaQ01WLX@0J7>306QcP01[MX00KGN206ihQ@1_NHH0
KgZ8075lS01aOHh00P1cOXh02`1cOhd0M86;07J3S01gPhd0N8>A07R2T`1gPI@0N8JE07V7U01iQi80
NhVB0080O8ZB00/0OXbA082>T@20SI40PHjB08B?T`24T9<0Q96C08JBU029UID0RYJG08^GV@0208bI
V`0<08fIW02>VI/0S9VJ08jJVP2?W9X0T9fJ092NV@2@WYH0TIjC09:NT@2BWY00TIj@0`2CWi802P2B
WY80TInB092MT02?W8h0RYN805QMG@0j>T40=SHl02d_<P0/<30202HZ:@0;01XN700P9Al082HM01`S
6@0F6Q804AD<00hC2`0=4@/030l700X=0`0;3`<00P0<40@0300<4@D02a0400dA1P0<40H02P`500T;
100=4@L051P<01PL400H71404aH=010C30805QXA00/06b4E01lU5`0Q9QT08BPI020W600O9QL082LG
024X5`0P9aH08bTH02DZ600202<Y600;024V5`0N91L08RTK02H^7P0S;1/07bPH01lW5`0P9aL082LF
02@[5`0R:AL00P0P9aL01P0Q9aP06b4C014F2`0?4`H03A0300X=0Q[ooooo<@3oP00j0000od80oh00
3oooool000gooooo00H0BU9K04eDH01?EfP0CEI[04aFK@1;EV`204YEJ@0;04]GJ01<F6L0D5]Y055M
J`1DGfd0EF5`05APL@1FHWD0EfEi05MUNP1FI7T00P1GIGP205QUM`0905QUN01HI7L0FFEh05USN@1I
HgX0FFAh05]UMP1LIWH0G6Ii0080G6Ek00@0GFIm05eVO01OIg`0GfQk0P1PJGX01P1QJW/0HFUm069[
O`1SKH40HVf206=_P`80I6n300/0IG2306MbPP1YLh<0JWB106afP01^NH80KgZ2071kQ01aO8L0LWb;
07=mS@0207AnSP0;07AmSP1eP8d0MX2>07N1S`1jPi<0NhBF07V4UP1iQYH0NhRE07^8U01lRI@00P1o
S9D02`22SYH0PhnE08>>U@22SY@0QI2F08FAU@24TI@0Qi>F08REU`2:UiP0RiRI0080SIVJ00`0S9RK
08bIV@2<V9P0SYZI08nLVP2AWYX0TYnJ096NV@2AWID0TYbB09:NTP2CWi8209BPT`80Tj2D00T0TInA
08nMS`2?WHh0Sib<06=WH`0j=Sl0>CLo030`=@0];c800P0/;bd02P0P92<071lM01`O6`0M8QX06AdD
01DH400@4`/0418900h@1P0;3`<300`@0`0<00/@0`0:3P<0310600/?1P0930@02Pd400lB200D6@`0
61/?01XM4@0G6Q004A<=0P0E61002`0N8QH08bPJ02<X6@0S:AT08BPH01lW5@0O:1H082TF024X5@0R
:AP08BPH008082LG00/07bHG01lU5`0R:A/09B`L024Z6@0O9aH07bDD01lU5P0O91D07b8E01hR5002
01hS5006020U5P0J8A8041D:00lD1P0=4@<020X16_oooola0?n003X0003o@P3oP00?ooooo`003Ooo
ool01P15CUP0BU9N04iGI`1>EVX0C5IZ04aGJ`80BeMZ00/0CEYZ04iIJP1?FF/0D5Y/05=NK`1DHG40
E61a05EQM`1FHWX0EfAm05MUO00205QUN`0;05MSNP1FHgT0EfAj05QUN01IIGP0FVEh05]TN@1KHgP0
G6Ee05]VM@1LIWL00P1LIWT0201LIgX0GVMk05iWN`1PJG`0HV]k069[O01RJWh0HFYo0P1TKH803`1S
KX<0I72406MbQ@1WLXD0J7:506UcP`1[MH<0JgF206agP@1]N840K7N106mjQ@1bO8X0M7b=07AmT002
07EnTP0;07J0TP1hPI<0N82C07V2U@1lQ9L0O8BH07^4U`1lQiL0O8NF07f8UP1nR9H00P20RYL02`22
S9H0PXfE08>?UP24T9L0QY6G08NCUP27U9L0RIFH08VFV02:UiP0S9RI0080SY^K00`0SIZJ08fIV@2>
VY/0SYbK08jLV@2?W9T0T9fI09:MV@2CWYP0UInG09BOU`2DXIH209>PU@0;09:PUP2BWi@0TIjB092O
T02@WXd0T9n;075jKP13@dD0?cm3034`=P0/;S400P0[;R/02`0R9B807QlL020R7P0S:2007bDK01TO
500D5P`04A8800l@1P0<3P@030l30080310300`02a0300`@100<40P0310800d@200?4PT04AD;01@H
3@0F6@h05QT=01@G300A4`X201HG3@0;028V600U:A/092TJ02<X6@0Q:1P082PG020X5P0Q:QL08BTF
028Z5`0P:1L00P0N9QH02P0N9QL07bHH020X6P0Q:A/07bLH01dS4`0J8A006Al?01PM3`0G6`l301DH
3@805AX>00@04QH<00hB200;3`@01`/16_ooool^0?n003h0003o@@3oP00?ooooo`003Oooool01P16
CeT0BE=P04eHI`1@Ff/0D5Y/04iIK080BeM[00/0CUU]04mKKP1BGG00DUi`05=PL01BH700Df5a05AR
L`1EHW@0EVAg05MUN00205IUN00;05MUN01HIGL0F6Ih05UVN@1HIGP0FVEj05eVO01NIWd0GFEj05eV
N@1MIWP00P1OJ7P0301OJGT0H6]k061YN`1PJGd0HVYn06=/O`1SK800H6Z106=]Q01UKhD0IG6706Mb
Q`80JG>600/0JW>506YcQ01]MhD0KGN506ehQP1_NHP0KgV:071jS01cO8h0M7fA07EnU00207IoU008
07EoU01fOi<0N86C07Z2U01kPiH0O8FE07f5U`1oR9P20829VP0>086:V021S9P0PHbH08>=V025SYP0
QI2I08J@V@26TIT0R9BI08VFV`2:UYP0RYNI08^HV@2=VY/208nMW@80SYfM00X0SYbM08jMW@2@WY`0
T9jJ096OVP2CWi`0U9nK09FPVP2EX9P0U:6H0P2BX9P02`2BX9L0T:2E092OT`2@X940TJ2=09>SS@1i
QGH0BDa;04I9A`0a<S@0:bh^0080:c0Z00/09B/T024U7@0V:R009bdR020V6`0G6a404QD:010B1`0@
4@H03a4700dA1P0200hC1@0<00dB100=4PD03Q<800dA2P0?4`/04QH<018F2`0C5`/04QH;018G2P0A
5PX041@90P0B5@T02`0N8A408RLG02DY6@0T:QT09BXI02@Z6@0R:QT092/J028Y600T:QH092TG0080
8BLG00/07bDH01hU600L91L06b8E01XQ4`0G7A0051X<018H2P0A5@T03a<900hA200200d@200600dB
200?50T04A@;014C2P0=40L020/36_ooool]0?n003l0003o@@3oP00?ooooo`003Oooool01P17DUh0
BEER04aHJ01>FFX0Ce]/04iJK@80CEQ^00/0CEU_04iJL01AGG80D5ab051LL01AGW00DV5b055PL01D
HW40EF=b05ITL`0205QVM@0705UWM01JIg@0FVId05]WM`1JIWL0FVIi05]VN`0205eVO00@05eWO01L
Ig`0G6Ml05aWO01NJW`0Gf]l065[O@1QJWd0HFYn06E^P@1TKH<0Hfb506A]Q@1UKhH0IW:706QbQ`80
J7:500H0JgB506egQ`1_N8P0KgN806mhR@1aNH/2075jS@03079kS`1dOI40MWnB0080MX2C00/0MGjB
07N0T@1hPY00NXBA07f5T`1nQYD0OXJF0869V021RYT0PXZJ08>:V@0208B<V@0;08B>V@27T9X0R8nJ
08VAW028TY`0R9>M08VDW02;UIX0RiNJ08bIV`2>WIl00P2>WYl0302>WYh0SIjM08fMW@2>WYh0TZ2O
09>QWP2CX9d0TYnL09>OW02DX9d0U:2K09>PV080TInG00/0Tj6I09:RU`2@XI80TJ:A092QS`2BXY00
Ohen055ED`1=DTh0<S<e02X/;00202T/:P0;02L[9P0S9b008BHN02@Y800R9Ql07AlH01PI400D5``0
4Q<9018C200@4PH00P0<4@@0300;40<0314400dA1P0=40P03Q4900lB2P0?4PT03a<9018F300D6@d0
4QL;010D2@804QD900/06ah?028V5P0T:1P09BXH02H/5`0T:aH092/G02L]6@0T:aP08RPF028W5@02
020T5@0;01dP4`0I7A805Q`@01DK3`0E6Ph04aP;010D2@0@50X03a8:00dA2@0;3`T00P0;3`P01P0;
3PL030l700dA200>4@P03A0700T<11[ooooo;@3oP00o0000od40oh003oooool000gooooo00H0B5=P
04]GI01=FVX0CUY/04iJK@1>Ffh204iLL00;04iJL01?Fg00D5aa051LL@1AG700D5a_059PL@1BGg00
E69a05MTLP1HIG<00P1JIgD01@1IIW@0FFIc05aWM01MJ7H0G6Mg0080FVIi00@0FVIj05]VN`1NJ7`0
GVQm0P1NJ7`0301NJW`0GV]l05m[O01RJg`0Hfam06E_P@1TKX80I6n406A^Q@1TL8H0I76706EbQ`80
J7>600/0JW>606afR01_MhT0L7N9071iRP1aNHX0L7V:075kS01cOHh0MGn@07J1T@0207N1T@0;07J0
T@1gP940N8:A07b4T`1mQI<0OXJD07n8U@20RYH0P8VE08:;U`24S9T00P23RiT02`25SIT0QXnI08J?
V029TY/0RI>L08RCV`29U9X0RiJK08fHW@2>VIh0SY^O0080SI^N00`0SYbN08jMW@2AWih0TYnN09>P
WP2EX9l0U:2M09>OV`2CWi`0U:2N09BQWP2BWiX2096OV00;09:QV@2AXIP0TJ6F096QU02@Wi80TJ6A
082=P@1@E580E5eD038f=00V:BP00P0U9bD02@0T9bD08bHT02@X9@0X;bP0:c0X02<V7P0I6a@051D?
010@200200l@1@803@h400`02`h200`A0`0=4@@03Q8700`?2P0:30T02`d900d@2`0A5@l04aP@018G
3`0>4`/200hC2@0;01LK3P0O91D08bPH02DZ600U;1H08b/D02@[5@0S;1L08BTG01hV5P0O9QH00P0O
8aD02`0J71005AP=01<G300C60/04AH900hB1P0=40H03Q89010D3@0<3``02Pd900802Pd700H02P`5
00X=1@0930@02@`300X>10082`<Jooooobh0oh00?P000?m10?n000oooooo000=ooooo`0604MCG@1:
EV40C5UX04iJK01>FVd0CEY^0P1=Ffl02`1>Fg00CeYa051LL@1BGG40DUe_05=OK`1CHG00Df1_05ES
K`1HIW80F6Id0080FFIe00/0F6Ef05YUM`1LIWT0G6Ii05]VN@1JIg/0FfMl05UVN`1JIWX0GFQk05mX
O@02061YOP0<069/P01SKX80I6n206A^P01UKX40I6n206=_PP1RL880Hg2406AaQ01TL8@0IW:40P1X
Lh@02`1ZM8@0KWJ606mgR01bNX/0LW^;071jR`1`NX`0LWf=07=mSP1gOi00NH6@0080NH6?00/0N86@
07Z3TP1kQ9<0OHJD07j7U@1oR9D0P8VE086:UP21RYD0PH^E08>=V00208B>V@0;08J@V`26T9X0QY2I
08NAV@28TYX0R9BK08ZFV`2;Ui`0S9NM08jIW`2>VIh00P2>VYl0302@W9l0T9fO09>PX02DXJ00U:2N
09FPW@2FXYd0UZ>N09JRWP2FXYl0UJ:O09:OW080Tj2J00/0U::J09FSV@2FXiP0U:>F09:RU02CXY80
RIV604a@B`1>ET`0>Chi02PZ:P0202DW9P0;02/^:`0W:RT09b/Z02/b;00[<BP08bLO01/M600E5a40
414:00d?1`0>40L00P0<3`@0300;3`@0310400`@100<40H02`h800X=2@0:3@P03Q@;01@J3`0D6a40
4QT?00hD2P803A<900/05A/?01`S5@0Q:AT08b/I02<[5P0T:aD09B`F02@/5`0S:aP08BTH020X5`02
01`R4`0;01LL400D6@d041D;010E2P0?50P03A4800`?1P0=4@L03Q<900`?2@0:3@H00P0830@01P07
2P4020/100H:00052P001``000L;01[ooooo;P3oP00n0000od40oh003oooool000gooooo00H0Ae=L
04UFH01<FFD0CEYZ04iJK01>FVh204eJKP0;04iJL@1>FW<0Ce]d055LL`1AG740Df1a05ERLP1CGfl0
E61_05ISL@1HIG<00P1HIG@02`1GI7D0F6Ag05YUNP1LIG/0FfIj05YUN`1KIW`0FVIk05YUNP1MIW/0
GVMm0080HFYo00<0Hf^006E]PP1UKH400P1TKH001`1UKh80IFn306=_P`1SKh80I7:206AaP@1WLh40
0P1YM8802`1[MX80L7Z5079jQ`1cNXT0LW^;071jS01aO8l0LWf@07=nT01eOi00Mh2?0080N86>00/0
NXB@07f6TP1nQI80O8BB07j7U@20RIH0PH^G086;UP21S9H0PXbG08><V@0208B>VP0;08B?V`25Si/0
QY6L08NAW027TY/0RIBK08^GW@2=V9d0SiZM096LW`2AVih00P2CWJ002@2CWJ80TYfR09:NX`2CWj@0
UInQ09JPX@2DWj00UJ6P09FRX00209NSX00>09BQW@2EXI`0UJ6L09JQV`2FXYT0Uj>F09JSU02DXY80
Tj6@09:SS@1GG5H0=cTj03a1?P0`<c8202PZ:`0;02/^:`0Y;2X092LW02@Y9P0P9B406AhJ01DH500D
61@03a<?00hA2`0>4@T00P0=4@L0300=40H0310500dA1`0<40H0310700`@200;40P03A<8014H2`0C
6`d04QT;00lD2080310700/061hA01lW5`0R:QT092`J02D/6P0V;1T09bdI02@[5`0T;1P08R/G01hW
4`0201XR400;01HM3`0D6Pd03a@900`@200;40L0310800`@1`0<40H03A4600/>1@0:3@@00P082`80
1P0520001PT000@700021`000PH0004401[ooooo;@3oP00o0000od40oh003oooool000gooooo00H0
Ae=L04UFH01<FFD0CEYZ04iJK01>FVh204eJKP0;04iJL@1>FW<0Ce]d055LL`1AG740Df1a05ERLP1C
Gfl0E61_05ISL@1HIG<00P1HIG@02`1GI7D0F6Ag05YUNP1LIG/0FfIj05YUN`1KIW`0FVIk05YUNP1M
IW/0GVMm0080HFYo00<0Hf^006E]PP1UKH400P1TKH001`1UKh80IFn306=_P`1SKh80I7:206AaP@1W
Lh400P1YM8802`1[MX80L7Z5079jQ`1cNXT0LW^;071jS01aO8l0LWf@07=nT01eOi00Mh2?0080N86>
00/0NXB@07f6TP1nQI80O8BB07j7U@20RIH0PH^G086;UP21S9H0PXbG08><V@0208B>VP0;08B?V`25
Si/0QY6L08NAW027TY/0RIBK08^GW@2=V9d0SiZM096LW`2AVih00P2CWJ002@2CWJ80TYfR09:NX`2C
Wj@0UInQ09JPX@2DWj00UJ6P09FRX00209NSX00>09BQW@2EXI`0UJ6L09JQV`2FXYT0Uj>F09JSU02D
XY80Tj6@09:SS@1GG5H0=cTj03a1?P0`<c8202PZ:`0;02/^:`0Y;2X092LW02@Y9P0P9B406AhJ01DH
500D61@03a<?00hA2`0>4@T00P0=4@L0300=40H0310500dA1`0<40H0310700`@200;40P03A<8014H
2`0C6`d04QT;00lD2080310700/061hA01lW5`0R:QT092`J02D/6P0V;1T09bdI02@[5`0T;1P08R/G
01hW4`0201XR400;01HM3`0D6Pd03a@900`@200;40L0310800`@1`0<40H03A4600/>1@0:3@@00P08
2`801P0520001PT000@700021`000PH0004401[ooooo;@3oP00o0000od40oh003oooool000gooooo
00H0AU5L04UEH01<FFH0C5UZ04iJK@1>FVh204eJKP0;04iKL01?Fg40DEec059ML`1AG740DUia05AO
L@1DGg00E61^05ISK`1FHg000P1GI7801`1HIG80F6Ad05YUN@1LIW/0G6Ek05aTNP1LIGP00P1MIWP0
1`1NIgT0HFUl065ZO@1QJWd0HFUl069/O@1SKGd00P1SK7`01`1TKGd0I6in06E_P@1UL8<0IG6306Eb
P01XMH000P1YMH40201/Mh80KgZ3079nQ`1dOHT0Lgb;075lR`1bOHd0M82?0P1eP900201gPI00Mh6>
07N1SP1jPhl0OHFA07n6U020QYD0PHNF0`22RiP208:<U`0:08>=V@24SYT0Q8jI08F?V@26T9X0Qi6K
08RBW@28Ti`0RiFL08fGV`80TIZM00D0TIZO09>MX@2CWj<0TinS09BOY00309BNY00709FNX`2GX:<0
UYnR09JOXP2GXZ80Uj:P09JRWP0309NSW00;09NSV`2FXYP0Uj>E09FRT`2DXY80Tj6@09FUT@1WL6T0
<C0f03a1?`0e=cH00P0/;B`02`0[;R/0:Rd[02T[:`0X:bX07R4R01PL7@0D5Q@04aD@014D300>4`T0
3Q<700803A8400/03A0200`@0P0<3`8030l300`@1@0=4PL0314800/@1`0<4PL03Q<800hB1`0300`@
1@0;01TP4P0Q:AT08R/J02D^700V;A`09R`K02@Y6@0R:AP08RXF020Y500L91400P0I81002`0F7A00
5A`>010F300<4@P02Pl600`A200;40L02`l400/?0`0:3@<01`X200801PP100H010L000D800041`00
0`L0004500000`0Jooooobd0oh00@0000?m00?n000oooooo000=ooooo`0604IAG019Df80C5MX04]G
K01=FG00CeYa0P1>FW002`1?G780D5ec059NLP1BGG40Deia05EOL`1GHg@0EV5b05EOL01GHW40F6=b
0080Ef=b0P1HIG<02@1KIWH0FfIi05aVN@1MIWX0GVMh05mXM`1PJGP0GfQi065ZO002069ZO@0<065Z
O@1SK7h0I6in06A_O@1TKWd0IVmn06M`O`1XLH00Ig6306QbQ01YLh80JWF10P1/Mh<0101^N8@0L7Z6
07=mR01dOXP207EnR@0507J0SP1fOi00N86@07R1S`1hPY000P1hPi401`1jQI80O8FD07f6UP1oR9P0
PHRI08>9VP23RYT00P24S9T03`25SIT0QXjK08N?W027Si`0R96M08NBW@28TY`0RIBM08VDW02;UiX0
SYVJ096LW02AVid0TIZO09:MXP02096MX`0<09>OY02EX:D0UJ2T09JOX`2FX:<0V:6R09NQX@2GXIl0
Uj:O09NSWP2HY9d0V:BL0`2GY9/02P2FY9T0UZ>H09JSU`2FXiH0U:>D09FVU@1]N6l0<C<h03a2@00h
?3X2030b<@0;034d<P0_<S00;c@`02ld<00L7b006adM01HH5@0A4@`0414800d@1@0<4@<00P0;4040
300<3`403A0300`?100<3`H030l800dB2`0>4P`03A8:00`A1`0<40L03A4600dB1@804AH800/07B@B
02<[600U;A`09BdM02D]7P0T;1h08RXL02<[6`0R:QP07RHC01XR3`0201HM3P0;01@K3P0C6Ph04QT>
00lF3@0=4PT03A<900`A1`0;3P@02Pd400/=10082P800P051P001P031@001PL000@700031P000PD0
004301[ooooo:03oP0150000od00oh003oooool000gooooo00H0BE=O04]FIP1<EfX0C5Q]04iJL01@
G742051KLP80DEad00T0DEed059MM01DGG@0EEif05MPMP1FHGD0F65e05URM@1HHW<00P1JHgD02`1J
I7D0FVEf05YVM`1JIWL0G6Mh05iXN@1OJ7P0H6Yi065[NP1PJW/0HFYn0080HF]n00`0HFao06E_P@1T
KWl0IVmo06M`P@1YLX80JG6006QbP`1YLX@0JG>406YdQ01]MXL206miR@0;075jR01aNXL0Lgf:07Eo
RP1eOhP0Mh6;07R0S`1iOi40NX6B07^2T@1kPi400P1kQ9402`1lQI<0OXJE07n8V@20RIT0PhZJ08B:
W024Ri`0Q8bL08B<V`25S9/0R8nN0080RI2O00/0RY6P08ZCX02<U:00RiFM08bGW@2=UiX0SYVJ09:L
V`2CWIh0UIjP09BNXP0209:MX@0<09BPXP2FXJ<0Uj:S09VSXP2HXZ80V::Q09RRX02GXYh0V:>N09VT
WP2IY:00VZBP0P2IY9d02`2IY9h0VJBL09NSVP2GXYT0Uj>G09NUU02HZ9D0MX9g03Tk@@11B4H0?44n
0080=SXg00/0>Clh03Dj<`0^<R/0<cP`01hO7@0L7AT05aPC014C300?4PT03Q4600`@0`0200`@0P0<
00dA100=4@H03A4800hB300>4Pd03A4<00hB300?50/03Q8800dA1`0>4`H03Q<50P0B5`L02`0L9140
8b/G02P`7@0X<1l09bhP02D/800U;B008R/M024Y6P0N9AH06R4B00805A`>00/04QT<018H300C6Ph0
4AP=00hD2P0<4@P0310700X=100930@02P`400P90P0200H70@0600H5000610000`@0008500011000
0@<06_oooolV0?n004L0003o@03oP00?ooooo`003Oooool01P19EUl0C5UT04eIJ@1?FVh0CUU_04mJ
L080D5Y`00/0DEab059LLP1DGW<0EF1e05ANM@1DGGH0EUig05MNM`1IHGL0FF=f05MRM00205QRM00;
05QRM@1HHgD0FFEg05UUN01LIgT0GFMi05mYN01PJWT0GfUj061ZN`1PJWd00P1QK7h01P1RK7l0IFj2
06I_P@1WL840J72306UaQ080JG:400@0J7:206YdP`1/MX@0KgV70P1`NXL02@1aNhT0LWb9079mR`1b
OH/0Lgj:07F0S01gOhd0NX2@07b2T00207f4T@80OXJB00P0OHJA0829U@20RIP0PHZH0869V@22RIX0
PHZL08>=WP80PhbN00`0QXjN08V@W@29T9d0RY:M08^CW02<UId0SIFL08jGW02?VI`0T9VL09>LWP2D
WIl209FNW`80U9fN00`0UYnP09JPX02GXZ80Uj:R09NRX@2HXZ00V:>P09VTX@2IY:00VJBN09ZTW`2J
Y9h209VSW00;09ZTV`2LYi`0VZBI09RRU`2HXiH0V:FB09NWT@23TH40?d=604A:B00j?cd00P0c=c80
2`0d>S80=3X`02d`:00^<RT07AhI01/L5P0F5a404A<:00hA1`0>4@D031040080310300`02a0400/>
1@0<3`P03A0<00h@300<3@X03@l:00hA2@0>4`T03A4500/@0P0;3P4200`@0`0;01hV4@0S:aH09blJ
02L_700U;Qh092dO02H^800S:ad08BTL01hW6@0I81<00P0D71001`0B6@d03aD;00lE300=4`/03A<:
00/?1P082`<00P082P400`072@401@H000H7000200H7000500H6000310000@@0004300000P006_oo
oolU0?n004P0003o@03oP00?ooooo`003Oooool01P1:F5`0CU]S051LJ`1@Ffh0D5Y`051JLP80DEac
00/0Deeb05=NL01FGg00EUma05IOLP1EH7@0EF1e05IOM`1HHWT0Ef=i05IRN00205EQM@0;05MRM`1G
HgL0F6Ei05QTNP1KIg`0GFUl05eYN01NJgT0GV]k05eZN`1NJg`00P1RKWh01P1RKGl0I6f006M`PP1X
LH<0Ig2306QaP`80JG:500@0JWB506]eP`1]Mh80KgV20P1_NX@02`1aNhL0LGb7075mR@1aOHX0LWj:
07=nS01fP8l0NH6A07^3T@1lQ980O8BA0080OHJ?00/0O8N>07j9T@20RIH0P8ZI082;W021Rid0P8ZM
08:;WP24SIl0QHjO08J@W@0208RBVP0;08^EVP2<UIT0RiJI08^EV02>V9`0SiZL08jHVP2@Vid0TIfN
09:NWP2CWYd00P2DWYd0302FWil0UJ2O09JQXP2FXZ80UZ:Q09NRX02HXj00VjJQ09^WX@2KYZ00VZFO
09ZUW@80VJFK00/0V:>H09VTV02IY9L0V:BF09NSUP2HY9@0UjJB08^JR018Bd`0@4E403Pm>`0202d`
;@0;02X]9P0[;bH0:B/S02`_9@0O8AX06Q`D01DH3`0A4`X03a8700lA100>4@@00P0<40D0300;3PD0
2Pd600/>2@0=3``03Q0=00h@2`0?40`03Q8;010E2`0@5@L03Q@500hB108030l300H072<?02<Z5P0V
:aP09bhJ02H^7@0V;Ql202D^7`03028/7@0N9QP061lD00804aX@00X04AP<010F300=4PT0310700`@
1P093P@020`200P;0009300020X0100620001@06204010H000<400010`000@4001[ooooo903oP019
0000od00oh003oooool000gooooo00H0BUQM04eJH`1?FfX0D5]_051JLP1@Fg@2055KM00;059MLP1D
Gg00EF1_05IQK`1EH6l0E61a05EQLP1FHWH0EF1g05ERN@1EHWL00P1EHWD0201FI7H0FFIi05YVN`1K
Igd0FfQm05eZN`1LJWL0GVah0P1NJWT01`1OJgX0HW1l069`O01RLGd0I75m06QcP01XLh800P1XLX@0
1P1XLHD0JGB606UeQ@1YM8<0KGR3071iQ080L7V600/0L7^7079nR@1bOXP0Lgn907F1S01fOhd0NH6B
07^2U01mQ9<0OHJD07f5T`0207f6TP80OHNA00T0OhVE07n9U`1oRiX0PHbL086<W@23S9d0Q8fM08N?
W`29TYl00P29Til02`2;U9d0RiFL08bFV`2;UY`0S9RM08fIWP2=VId0SY^M096OW`2AWj00Tj6P0080
U:6O00`0UJ:P09FQXP2CX:80UJ:S09JTXP2HYJ80VJJR09ZVXP2KYj40VjFQ09bWX`2LZ:4209^VWP0;
09ZUW02JYYX0VZJI09ZWV02GXiH0V:>E09RTU02EY940DeMF03Tj?P0i?Cd00P0[;Bd02`0U:B@09RXR
02<V800S9Ql082<L01`O5`0H6a805AP?01HG3@0E5`/04aD900803Q8700`0310700`@200<3`X03Q4=
00lC3@0@4`d04A<=018F3`0B5`l04AH;010E2@0A5@P2014D1@0;01@G1`0M810082DC02@Z5`0W;a/0
9blM02L_7P0U;ah092hM024[6`0L91H00P0H7a802`0D6Pl041H;00d@1`0<3`H0310600dA1P0;3`@0
2`h300/?0`0:3@801`T100801@L100H01@H100L:0`072P801@L000<400020P0Jooooob@0oh00B@00
0?m00?n000oooooo000=ooooo`0604]IH@1=Ff@0D5aZ055LKP1BG780DUed0P1AFg<02`1BGG<0DUeb
05APL@1EHg40EF9a05ESLP1EI780EfEe05MSMP1HIGP0EVAe0080EVAb00/0EfEc05UVM01KJ7L0G6Uk
05iYO@1PJgh0H6al061]NP1PK7P0HVaj06A_O00206EbOP0<06McOP1WM7l0Ig>106McP`1XLh<0J7>4
06QbQ01ZM8@0JWB506]dQ@1^N8L0LW^90P1cNhT02`1dOHT0M7n;07=nR`1eP8/0N8:<07R1S@1jPHl0
O8>B07b4TP1mQI<0O8FC0080OHJE00/0OHNE07b7U01oR9H0OhVF082;V023SI`0Q8jL08>=VP26T9`0
R92N08^CXP0208bDY00;08bEX`2<UZ40S9NO08fHX@2<V9l0SYZO08nKWP2@W9h0TYnO09>QX02EXZ40
0P2EXZ00302EXj40UZ>S09NRX`2GY:@0V:FS09RUX@2JYj40VZJP09^WX02KYZ00W:NP09bXX080W:RN
00D0WJRM09fXV`2LYiX0VjNI09VUUP0209VTUP0409NTT`1HFUX0?Ce203Tl?@80;C0a00/0:2/Z02HZ
:00T:2@07b<N01lT6`0O9QX07B<G01/P5@0M81<06Qd>01DH2`02010D2@0<00hB200=4@P02`l700`@
2P0?4Pd04AD@01<G4@0C5`l04AH<00lD2P0>4PL031430P0<40802`0<3@40720@028W5P0U:QP09blI
02P`6P0W<1X09S0K02H_7@0U;Qd082PH00806b4C00L05adB014F300>4PT03A4700dB1`0>4`P03Q87
00803Q4700X02`h500L90P0620401PP100D60@0620801`X300D70@0210000@806_oooolR0?n004/0
003o@03oP00?ooooo`003Oooool01P1:EV@0CEUX051LK@1AG6h0DE]a05=MM080Deee00@0EF1h05AO
M`1CGWD0E65c0P1EHg801@1FIG<0FFMf05UVM`1HIGL0F6Ee0080FFIe00/0FVMe05YXMP1KJGL0G6Uj
05iZOP1PJWl0H6an065]O@1RKW/0I6mm06IaO`0206IaOP0<06IbO`1WLX40IW6206IaPP1XLh80JGF2
06YeP`1[Mh@0K7J606efQ`1^MhT0LGZ;0P1cNh/02`1eO8/0M7f<07AnS@1ePHd0Mh:;07R2R`1iPX`0
NX>>07^5T01kQ940O8FC0080OHRE00<0OXRE07n7UP21RIT00P22RiX01P24SI`0Q8jL08F?V`27TI`0
R96M08ZBWP80RiBP00/0RiFQ08bFX@2<V:40SIVQ08fHX@2?VZ80T9bQ096MW`2CWil0UJ6Q09JQXP02
09NRX`0<09NSY02HY:@0VJFT09ZWY@2JYj@0VJJR09ZWW`2KZ9h0VjVO09bXX02NZIl0WZZM0P2NZY/0
102LZIT0VjNI09ZXV@2IYiP209ZWU`0509ZVUP2JYiD0HF=P03/i?`0i=cX00P0/:bd02`0V9RL08b@V
02DZ:@0M8Al092XQ02L]8@0P9QX07B8F01`O4`0H6Pd05AL;00804Q@900`04A<900h@1`0<3PH030l8
00dA2P0@50h04AH?014F3@0>4PP02`l600P<0P072P4200L9000;00X:0@0N8Q0092TF02L]600W;QP0
:30H02Pa6@0V<1T09c4K02L`700S:aT00P0O9AD02`0J7a404QL<010D2P0?50T03Q<800dB1P0=4@H0
310600d@1P0;3@@02@/300801`T200H01@L000@60@041P000`D0008300010`0Jooooob<0oh0000<0
003o0?n0003oP000A`000?m00?n000oooooo000=ooooo`0604YEI`1=F6/0DEa`059MLP1BG7@0DUed
0P1DGgD02`1EH7L0E61f05EPM`1FHWH0EfAd05IUM@1GIGH0F6If05UVM`1IIgL0FfQh0080FfUh00/0
FfQh05aYNP1MJW`0GFYl05m[O@1RKGh0Hfio06=]P01VKh40Ig6006UcP@0206QcP@0<06QbPP1XLX<0
JG>406]eQ@1[MHH0JWF506]gQ@1^NHH0KGN706iiR@1_NX/0L7Z=0P1bNh`02`1eOXd0M7n>07J1T01f
PY40MX:@07R4T@1hQI40NHF@07Z5T@1jQi80O8VB0080OH^B00/0OhbE08:=U`22S9T0Q8fJ08><VP24
SI/0Q8fL08F?W@28TIl0RYBQ08^DX00208ZDWP0;08^FX02>Uj80SYRQ08fIX02?VZ40TI^S09:MX`2C
Wj80UZ6R09RSX`2JY:D00P2HXZD0302IXjD0VZFV09bXY@2KZ:@0WJZU09bYY02KZ:40VZNP09bXXP2O
ZJ<0WZRP09jYW`80WZ^M00<0WJZJ09f[VP2KZIT00P2IYiP01P2JZ9P0VJJF09bZV01gPGH0>SPl03Ld
=`80;2X/00/09R@V02<S9@0_<c409BPX02DW900U:2<07QlK028U7P0S9Qd07R4F01TK3`0201@E2P04
018C2@0?4@P03@l700`?1`<03A8800D03Q<900lB2@0=4@P02@`300H80@0200H7000800/<0`0M8Q00
9B/G02T_700[<Ad0:c8L02/c7@0X<A`202H_6P0>02@/6@0P9QL082HG01`R500I7Q8051T>014F2`0@
5@X041D9014E2@0>4PL03A0600`?1@0<3@@200/>100400P:0`072P801PP100@600800`@06_oooolN
0?n00500003o?`3oP00?ooooo`003Oooool01P1;F6X0Ce]^059NM01CGg@0Deie055ML`80DEea00/0
Df1b05APLP1FHW@0F6Ee05MTMP1GIGP0EV=f05MUMP1HIgL0F6Mh05]XNP0205UWN00;05YXN01LJGX0
G6Ul05i[O@1PKGd0HFel06A_OP1UL800IW2106IaP01VLGl00P1XLX401@1YLh@0JG:406UcQ@1ZM8H0
JWF60080JgF700D0K7J906iiRP1_NHX0L7V=079kS`0207=lSP0;07EnSP1dOhl0Lgn?07F0T@1fPY<0
N8BC07R5T`1hQI80NXJB07b9T`1lRI800P1lRY82082=U008082;UP23SIT0PhfJ08>=W@26T9l0Qi2N
08RBX029U:0308ZEW`0408bGX@2=V:40SiRP092IX080TYbR00D0TibR09FNY02FX:<0Uj6R09RRX`02
09RSX`80VZFT00X0WJRV09bXY02LZ:@0WJVV09bXY@2KYjD0WJVV09jYY@2NZZ<0WZZQ0P2OZj000`2N
ZYh0WZ^L09bYVP0309^XVP0509VYU`2IZIP0QIB403do@00b<SD00P0];Rh02`0X9bL08R<R02X/:P0Z
;B`092@V024S900O8240@DXm030f:`0O8AP071lC00805QP<00`04a@8014C200?4PP0310500dA1@0=
4PL03A0800dA2@0?4`X0310800P;0`06204200D7000500/>1@0M91808bXF02L_6@0Y<Q`00P0Z=1`0
100X<A/092dG028Z5@0O9Q@201`R4`0;01dR4`0L8A@06alB01PM4@0D60d04QH;01<E2P0A50P041@8
00lB200=40D00P0:3P801P0:3P<02`h500/?1@082P801PH100D50A[ooooo803oP01>0000ocl0oh00
3oooool000gooooo00H0C5UW04mKK@1BGg<0DUic059OM@1BGW82059NL@0;055NK`1BGfl0E65`05ER
L@1EI7<0EFAf05ITMP1FIWL0EFEi05QWNP1HIGX00P1IIWX02`1KJGT0G6Uj05aYO01OJgh0Gf]k069^
O01TL7d0IG5n06A_OP1VLGl0J7:10080J7>000`0JWF106]eP`1ZM8<0JWB506UdQ01ZMHD0JgJ606ag
R01^N8X0KWR906igR@1`NH`2079lS@05079mS`1cOhl0M82@07J2T@1gPi800P1gPi<00`1iQY<0NhND
07j9U00307j9U00;086;UP20RiH0Oh^H086;VP22Ri/0Q8fM08N?W`29T9h0R92M08RAW`29TYl00P2<
UJ802`2<UZ40SINR08jGX@2@Uj80TIVR09>KX@2CVj00U9bR09NNY@2FWj@0V:6S00<0Uj:R00/0VJBT
09bVYP2MYjL0WJRV09fXY`2NZJP0W:RW09bWYP2NZJD0WZVT09nYX`020:2[XP0;09nZX02NZYh0WJVL
09bWV`2LZ9`0VjVL09NVU`2GZ9L0RYV803m1@@0_<3400P0^;bl02`0Z:bX09RPU02LY9@0Z;BT08R@S
01dQ800b>C80>T@g02/b9@0M81D06QdA008051H:00`04Q<7018D200@5@P03A8500`A1P0<40L02a08
00`@200<40L02Pd500H90@082@4200H8000;00X>100L8a407bLD02@^6@0W<A`0:38K02Tb6P0Y<AX0
9RhG024W400N8`l00P0K7`l02`0M818082<E01hQ500M81<071lC01XL400F5``04a<9018C2@0F6@`0
5AX:00804AH600H04aP801@J2`0B5`T03A8600X<10051P4Joooooal0oh00C`000?lo0?n000oooooo
000=ooooo`0604eHIP1?FVd0DUmd05=PMP1DHGH0EF9e0P1DHG8205=QK`0905ASK`1EHg40EF=d05ET
MP1FIGP0EfIi05MVN01IIgP0FVMh0080FVQi00/0G6Yi05eZN@1NJg`0H6am065]N`1RKW`0HVmk06=_
O01SKgd0IG5o06MaPP0206UdP`0<06]fPP1ZMX<0JWB306]eQ01ZMH@0IgB306YgQP1[N8P0KGV906mj
RP1`NX/0KgV;0P1aO8l02`1cOY40LgnA07F1T@1ePY40Mh>B07R5T`1hQ9<0NHBC07b6U01nQiD0OhVF
0080PHZH00/0PHZI082:V@1oRYX0P8VK086:W024S9`0QhjM08R?W@29TId0Ri:N08^CWP0208fEW`0;
08jFX02?Uj40T9RR09:JXP2AVJ40U9bP09BNX02FWj80Uj2S09NQX`2HXJ@00P2HXj<0302HY:D0W:NX
09bVY`2LYZL0WJNW09jYZ02NZJL0WJRU09fXYP2NZJ<0WjRS09nWXP80XJVQ00/0XJZP0:2ZX@2OZ9h0
WZRL09fYW02LZi/0UjRG09NZU`2>Wh`0ADY603Lk=`0203Lk=@0;030c;`0Z;2L09bXT02da:@0R91l0
7AhJ03Y2<`0lAC<0=3`X028V5@0K70d00P0E50T02`0A4@L04A@900hB1`0=4@D0314500/A1`0;3`H0
2`h600X>1@082P<01`L100<020P000/01`P101TM300R:AH09RhL02Pa7P0X<A`0:c@L02/c6`0W;QT0
92TD028V4P0201hQ400;01lR4`0S9QL09BPJ02@Y6@0U:aX08bHG01lP500I6@l05QL=020T5@0U:AP0
0P0Q9AD01P0Q9Q807RDA01dS400G7@`03a<600H90A[ooooo7`3oP01?0000ocl0oh003oooool000go
oooo00H0CEQW04mJKP1CGW@0E61g05ARM`1EHWD205=PLP0;05=QK`1CHFh0E6=_05ETLP1DHW<0EVAe
05UWN01JJ7X0FFMh05UWMP1KJGH00P1LJGD02`1MJWL0GVYg05eZN01NJWT0H6ai065^N@1QKWX0Hfmk
06EaO01WLWh0J7>10080J7:300H0JGB506YeQP1YMHH0JWF606UfQ`1XMXP206YhR@0406ejRP1^NXT0
KgZ:071jR`80L7^>00/0LWf?07=oT01dP8l0MX:A07R3U01iQI@0NHNE07V4U01lQiH0OXZG07n:U`02
082:V@0;086<V`20Ri`0Oh^L082;W021Ri`0Q8bM08N>W`27Sil0R92N08V@W@2<Til00P2=UIh02`2?
Uil0T9RQ096IXP2BVZ80TIVQ09BLY02EWZD0U9nU09FPY@2FXZ@0VJBV0080V:>V00`0VJBW09ZVY`2L
YjH0WJRW09jWZ02OZJT0WZZX09fXY@2NZJD0WjVT0:2ZY02OZJ<20:2YX`0;0:6[XP2QZZ<0WjRQ09nY
X02NZId0W:ZK09VZVP2GZ9L0U:JA059HDP0e=cL00P0g>SH02`0^;b`092DR01hO700a=B/0:RhS020R
6@0R9AX0@ddd04MC=@0N80l07Ah?008061L<00<051@;01<D2P0A4`T00P0>4PD01@0<4@H02`d500X=
1@0:30@020T2008020H00P081`402`061P0061`?02<Y5`0X;a`0:C8N02Tc7@0Z<QX0:C8I02D^5P0R
:QD08BTD00807R<C00/08BDE02DZ6@0X;Ad0:S0O02/b7`0/<Ql0:BdM02DY6P0Q9AT0:30P030h9002
02hd8@0602T`6`0X;AP09R/F024W500F6P`01`P16_oooolN0?n00500003o?`3oP00?ooooo`003Ooo
ool01P1=F6L0CeY^05=NM01DH7L0E69g05ERM@80Df1b00/0Df5_05=QKP1DHfl0EFAb05ARL`1FI7D0
FFMh05YXNP1IIgP0FFMf05]YMP0205aYM@0;05eZM`1NJWL0GFYh05iZN@1PK7T0HFii065^NP1SKg/0
IG5l06MbOP1XLh400P1XLX<01P1YM8D0JWF606UeQP1ZMHH0JGJ706QfR080JWR900@0KGZ:06ijR@1_
NXX0L7Z;0P1`Nhh02`1bOHl0Lgn@07B0S`1fPY40N8>D07V5U01iQiD0NHBD07b7UP1nRYL0OhZG0080
P8ZI00/0PHbK082;W01oRi`0P8^L086;W024S9d0QhjO08N?W`28T9h0RI2M08bCW`0208fEWP0;08nG
W`2@V:40TIVR09:JXP2AVJ40U9bT09FNY@2DWjD0UJ2U09JRY02IY:H00P2HXjH0302IY:L0VZJW09bW
YP2MZ:L0WZNX09nYZ@2NZZP0WJRU09jYY@2OZJ@0X:ZT09nYX`80X:VS00/0XJ^R0:6ZX`2OZ:40WjVP
09jYW@2LZY/0VJZJ09NXU`2DYY40DUQB03Dg=`0203Lj=P0;02h_;00T9B807QlL034e:`0Z;R<0828I
028U6P13CC@0Ae<e01hP3`0M7Pl00P0H5``00`0D50/04a@:014C2@0200hB1@0500`A1P0;3@D02Pd5
00X<10082@800P081P0200P70@0;00H6000H70l08bTG02P_700Y<Qh0:C<M02Xb6P0Y<QT09BhF028Z
5@0Q:A@00P0N8a<02`0Q9AD09BXI02P]7@0Z<1l0:c8O02`b7`0Y;Ad09BTJ024U6@0X<200<3PT0080
;S@Q00H0:C0K02P]600V:aH08BLD01HJ3007204Joooooah0oh00D0000?lo0?n000oooooo000=oooo
o`0604]HI@1>FV/0DUib05=PM01DH7D0E65d0P1CGg402`1BGfl0DV9_059RL@1FI7@0EVEg05MUN@1I
Ig/0FVQj05YWNP1KJ7T0FfMf0080G6Qe00/0GVQg061ZN@1OK7/0GVak05m]N`1QKg/0HG1k06=`O01W
LWl0JG>106QcP@0206MbQ00606QbQ@1XLhH0J7>706UeR01YMXX0JWN<0P1]NHd0101^NXh0L7b=071l
S01`O8`2075mS@0:075nSP1cOhl0M82?07J1T01iPY40NX>B07Z6T`1jQI@0O8JF07j8U`<0Oh^H00/0
P8ZK086;W021S9/0PXfK08B=W025SYh0Q8jO08F?X027TJ40RI:Q08bEXP0208jFX@0;08nFX@2AV:<0
TYZS09>KXP2CVj<0U9fU09FMYP2DWZH0UJ2X09NSZ02GY:P00P2GY:T02`2GXjX0VJFX09^VZ02MZ:P0
WjZY0:6[Z`2PZZT0X:ZX0:6YY@2PZJ@0X:ZV00<0X:ZW00/0XJ^U0:6[Y02OZZ80WjZQ09j[WP2NZi/0
VjZI09VYU`2IZiL0H6UR03Dg>P0203<f>00;02PX:@0P8Ah061HE02T]8`0a=RP0;C8S028T600i@2/0
DV10020R5@0M7Q800P0I6100300D5@d051@<018C2P0@4PL041<600hB1`0>4@L03@l500X;0`0:2P<0
30X300d<0`8030/400/020T201LK3@0S:1D0:BlJ02/a700Z<A/09blH02D_5P0Q:Q4072D@01TQ3P02
01XQ400;020W5P0U;1/0:RlO02`c8@0^=R80<CTT02hf8@0/=1l0;SDQ034j9P0h@2`00P0f?BP01P0^
=Al0:RlJ02P/600W:aP07B4A010A1Q[ooooo7@3oP01A0000ocl0oh003oooool000gooooo00H0CEYU
051MJP1BH6h0E65a05EPM01FHGD205EQL`0;05AQL@1FI780EfId05QUM`1HIWT0F6Ij05YWN@1JJ7X0
G6Uj05]XN@1KIgP00P1MJ7P02`1OJ7/0HFYl065[O@1QJgd0HFeo06=_O`1RL7h0IG6006MaP@1XLh80
Ig>20080IgB400`0Ig>506QbQ`1YLXT0JGB:06UdR`1/MXd0KWN>06ihSP1`NXl0L7Z=071kS01aO8`2
079nSP0607AoS`1ePI00MX:@07N3T01iPXl0NhF?0P1nQi400`1nQi<0OXNE086:U`0208::V@0508>;
V`24S9X0QXnK08J>W026Sid00`26T9l00`28TZ80RI>T08bEYP0208jFYP0;08nFY@2@V:<0TIVR09:J
X@2CW:80U9fS09FMY02EWZD0UYnW09NRZ@2HYJP00P2HY:L01P2JYZT0WJVZ09fXY`2NZZL0Wj^X0:2[
Z080X:ZU00@0XJZS0:6[X`2PZZ<0X:ZU0P2QZjH02`2R[:D0X:^S09jZX@2NZYl0WZ^N09j/W02LZiX0
VZZH09Z[V01YLf`0=cPn0080<38e00/08R@T01hP7@0G61<07b8G02LZ7@0^=2<09BTK04M@>@2=YWT0
=3/Z018B300201PI4P0<01<C300A40T04107018B200A4`L04A@701@F2@0D5PP04A<8014B200F60/0
6Ad>0P0F6@/00`0B50H07b<A02L/5`0202X`6@0602H[5@0R:1<07bPA01/R3@0H7``05ad;0P0N9180
1P0W;Q/0:C0P02/b8@0]=280<3LT034i9080;cHQ00<0<STS03@i9@0f?BP00P0d>bL01P0_=B00:S0L
02L[6@0Y;AT09b/H01`O3a[ooooo7@3oP01B0000o`/0oh0000<0003o0?n0003oP000<03oP00?oooo
o`003Oooool01P1:F680CUaW059OKP1DH7<0EV5g05IQN080EF1f00/0E61d05IRL`1HIG@0FFEe05UV
MP1JIgX0FfQl05]YO01LJW/0GVYh05eYN00205eXNP0;05mYOP1PJGh0HV^0065ZP01RKH<0Hfj306A_
P`1TL880IG6106McP@1VM8<00P1VM8@01P1WM8H0Ig>706UdR@1[MH/0JgF<06aeS080KWN<00@0KgR=
06mjS@1`Nh`0LG^;0P1aO8`02`1dOXh0MH2A07F2T@1eP900Mh:@07V4T@1jQ940O8JB07f7U@1oRIL0
P8ZH0080PX^J00D0Ph^J08B=V`25SY/0Q8fK08B>W00208B@X00408B@W`27Tj40RYBS08fFYP80SIFV
00/0SiNV096IYP2AVZD0SiZS096MY02BWZ@0U9nT09BOY@2EWZH0UJ2V09JRYP0209RTYP0409ZVZ02K
YjT0W:RX09jZY`80WZbW00H0WZbV09n/Y02Q[J@0X:bS09n/XP2PZj<20:>/Y@0;0:B]Y@2Q[:@0WjbS
09n[X@2O[:00WjbO09j[WP2LZY`0WJbK07J1M`0h>3d00P0c=SD02`0W:bP082@N01dO5`0L71807AlC
03Lo:P0oBC80C5Tn09FaP@14DCX0414:00806ahB00`05AD:014B100B4P@04a<5018C1P0D5PT05AL:
01TK300I6`h061T>028X5P0T;1P2024Y5@0;020V4P0W;AT0:S4L02P_6P0T:Q@07R@>01/Q3@0M90l0
7RDA01lU400R9a<00P0W;1T02`0[;ad0;34P02`b8P0_=RD0<SPV034i9@0`=b<0<3HS038h900d>BH0
>3hY0080=SdY00H0<CLU02dc8P0Y;ah09blL02P^6`0T:1LJoooooah0oh0000@0003o0?n0003oP000
oh00C@000?l;0?n000030000o`3oP000oh000300oh003oooool000gooooo00H0C5QU04mLJ`1BGg40
E5mf05AOM`1EGgL205ANMP0;05EOMP1GHWH0F6Ag05QTM`1IIGP0FVIj05aYO01MJGd0GFYl05i[N`1L
JGT00P1LJ7X02`1NJGh0GfUn061ZO`1RK840Hfj206=^P`1SKh@0Hfn306=aPP1TLH40IG>20080IgF5
00`0IgF806IcQP1WM8L0JGF906egRP1^N8X0KGN;06igS@1_N8h0L7Z=075lS@1bOH`2079nR`0;07B0
S@1fPI00MX:B07F1T@1fPXl0N8B@07V5T`1jQID0O8NH07f8V01oRYT00P1oRYX02`21Ri/0PhjL08>=
W023SY`0PXjM08:?WP23T9l0Q96Q08JCX`29UJ@0RiFU0080SIJU00/0SiRU08nIY02?VJ<0SIVS092L
Y02AWZ@0TinT09BPY@2DX:H0UJ6W09JQZ00209NSZP0<09^V[@2LYZd0W:RY09fXZ02NZjT0WZbY09f[
Y`2NZjL0XJbU0:6/X`2Q[:80XZfS0P2T[Z@02`2T[Z<0XjfT0:6/YP2PZjD0Wj^S09nZXP2PZZ00WZVN
09j/WP1mQgh0?Ca20080>3Tj00/0:2TX028T7`0N81P071dA01lP4`1;Ec`0Df13059O@`25Wg80AU8h
01LI300201hN400<01TH200E5@@05aL6020Q400W:AX06a`B01/M4`0S9aT08bXJ020W5P0V;QX0:C4K
0P0X<AX02`0Z<Qd0:c@M02Xc7P0X<1/08RTD01`S3P0N9Q008b`E02H_5`0Z<QX0;3<L0080;C<P00/0
;C8P02db8@0_=BH0<SPZ03<i:@0e?2T0<cTW030f900b=bD0>3h[03i5<00203Y2;00603Dl:@0_=BH0
:S0R02L]7P0V;1/09BTJ6_oooolP0?n000<0003o00<0oh000000o`000?l0B@000?l;0?n000030000
o`3oP000oh000300oh003oooool000gooooo00H0CUUY051LK@1CH7<0Deme05AOM@1BGG@205ANM@0;
05EPMP1FHWL0F6Eh05MTN01IIGT0FfIk05aXO01LJGd0GVYo05i[OP1LJG`00P1KIg`0201MJ7d0GVUn
061[O`1QK800Hfn106A_P@1SL880I7:40P1ULh<0301ULX80IW>306IcP`1XM8D0IgF506MdQ01XLhH0
K7N906mjR`1_NH`0KgV>071jS@80LG^=0`1bOXd02`1dP8l0MX:@07R4TP1hPi80N8>?07V5T@1jQiD0
O8NF07j8V@1nRI/0P8ZK00<0PH^K00X0PXfK08:=W023SYl0Pi2O08>@WP25TIl0Qi>S08RDY@2:U:D0
S9JV0P2@V:P02`2@VJH0TIZV096JYP2BWJH0TIjS09:PX@2CX:<0U:2S09FQY02GXjL0V:>Y0080VJ>Z
00`0VjF]09jW[`2NZ:`0WjZZ0:2[ZP2PZjT0WjZX0:2[Z02Q[:D0XJ^S0::/X`2S[:<20::/X`0;0::/
XP2S[J80XZbT0::/YP2QZZ@0XJZR0:6[X@2OZYl0X:fP08:9P@10?TH00P0h>3`02`0];Bd08B8Q01hO
6`0J6Q<0:RdO05UWB01CH480BeHk06=dD01?FCX0@TL[0080<S8L00`0:2HB024N3@0f>2@0E5a304mH
@P0O81P0828I02/`8`0[<R80:S8P02Xa7P0/<ah202`d7`0;02df800[=Ah0:S8M02df7`0]=Ad0:C0I
02Ta6P0Z<a`0:c<L02hf7P0^=B000P0^=2802`0]<R40;S@R030f9@0c>BP0=3/Y03Ln:P0f?2P0=S/W
03Dk9P0nAc00@4Xb0080>48[00H0<cdX02`e8`0V;Ah092XL02@X6`0R9APJooooob80oh00C@000?ln
0?n000oooooo000=ooooo`0604iHJP1@G700DUmd059NL`1CGW@0Deee0P1DGWL02`1FHGT0EF5g05MS
N01HI7T0F6Ei05UUNP1KIg`0G6Qk05YWNP1LJG/0GF]l0080GFYl00X0GFYm05iZOP1NJWl0GFYn065^
P01SKh00I72006AbP@1ULX40IW>30`1WM8<0301XLh<0IgF406UeQP1[MXP0KGN906ihR@1_N8X0L7V;
071jRP1`Nh/0LGb=079mSP80Lgj@00/0LgjA07J1U01gPY<0NHFB07R4T01jQY40NhNE07f7U@1oR9L0
P8ZJ086:W00308>;WP0708:;W@23SIh0PhfO08B@X@24TJ00QY>Q08VEX`0208^EYP0>08jGZ02@UjP0
T9NX09:IZ02BVZL0TYZU09>LY02DWj<0U:6Q09FRX@2GXj80VJBU09RRY@2IXjP209^UZP0509bVZ`2M
YZd0WZR]09n[Z`2QZjT00P2RZjT01@2RZjP0XJbW0:2[Y@2PZjD0XJ^T0080XjbV00/0XZbU0:>/Y02R
[:@0XjbT0:6ZX@2OZZ00WjZQ09fZW`2MZY/0SIR;04M8C00203Pi?@0;02h`<@0S9B@071dK01HF4`0f
?B`0EVE805ARAP1=FSl0@dde04]E>P1SL4`00P1MI4@0301EF3`0?CTZ08:>KP28VGT0Be9302d_9P0W
:1l0;S8U02ld9@0_=B@0;3<S02/c8`80;3DT00/0;cTU02lj9@0^>2<0<3XQ030i800]=1d0;38K02dd
7@0]=1`0;3<L02dd7P0202dc8080;C8Q00T0;S@S034h9P0c>BP0=3/X03Hm:@0f?BP0=S`W0459<P0n
Ac000P0e?RP01P0b?2H0:S<P02@/6`0T:A/09BPM028T6a[ooooo7`3oP01@0000oa80oh000P000?lZ
0?n000oooooo000=ooooo`0604aGJ01@G6h0Deic059MM01DGWH0EUeg0P1FGWP02`1GH7T0F69h05QT
M`1HIGL0FFEf05UVM`1LJGX0GFYi05aZN01MJgT0G6Yi0080G6Uj00/0GV]m05i[OP1NJgl0Gfb1061/
P@1QKX80HVj106A`PP1VLH<0Ig6306MbQ@0206QdQP0<06McQ@1XMHL0JGJ:06]gRP1]N8X0KGN:06ih
RP1`NXX0L7Z;071jS@1bO900LWfA0P1eP9<02`1fOi80N86C07V3TP1iQI00NHB>07Z5T01kQI@0OXNG
07j8V@21Rid0PHZL0080PX^M00/0PhfN08B=WP23SIh0QHjO08F?X025TJ40QYBS08NDX`29UJ<0RiNV
08nHY`02092IYP0;09:JY`2DVjL0U9fV09FOYP2DWjD0U:2Q09FRX@2GXZ80VJBU09VSYP2JY:P00P2L
YZX0102MYj`0WJN]0:2X[P2PZJ`20:6[[0060:6[ZP2Q[:X0XJbZ09n/Z02OZjH0XJfW0P2R[:P02`2R
ZjP0Xj^Y0::/Y`2Q[:D0X:bS09n/X@2NZZ00WJZN09j/V`2CXHl0CTm@0080>SXm00/0;S0a01lP8@0G
6AP04A8A03<k;@1CH4L0Df5804iMA016Dc`0EfE:06YkF`02071nG@0<08bKL`1LGdX0]<ZN08RHN`12
Ac`0?44d03Lj;00g>BX0=SXY03Dl:P0d?2X0<3TW0P0]=bH02`0^>BL0;CPV02hh900a>bD0<3XS02hf
800/<Q/0;C@L02/b6`0Z;a/0;C<O00<0;S<Q00X0;C8R02he9@0`=bL0<c`Z03Dn:`0f?R/0=SlZ03Hn
:00nAbh0?4D]0P0e?BL01P0a>RD0:C<O02@/6`0S:AT092PK02@V71[ooooo7P3oP01A0000o`d0oh00
10000?l00`3oP000003o0000o`0Z0?n000oooooo000=ooooo`0604aII`1@G6d0Deme05=PM`1EHGP0
EV1h0P1FH7H02`1GH7D0FFAe05YWMP1HIWD0FFMf05]XM`1LJgP0GFaj05a/NP1LK7T0FfYh0080G6Yi
00/0Gfen061/O`1OJh00H6b1061/PP1QKHD0HFf406A`Q01ULH@0IW6406IbQP0206IcQ`80J7F600X0
JGF706agR`1^N8d0KWR=06iiS01`NX`0LG^>075kT01cO9<0M7jD0P1fPI@02`1gPI<0N8>B07Z5T`1j
QI40NhJA07^5TP1nQiL0OXNJ07f8V`1nRY`0PH^K0080PX^L00/0PhbN08F>X026Sj40QhnQ08J?XP25
Sj<0QI6S08JCY028UJ@0RIJT08jIY`02096JYP0;09:KY02CW:D0U9nX09FPZ@2EX:P0U:6V09BQY02E
XJ@0V:>V09^UZ@2LYZ`00P2MYjd0302OZZh0X:Z^0::Y[P2QZJ`0XZZ/0::[Z`2Q[:/0XJfZ0:6]Z@2R
[ZP0XJfX0:6^Z080XJfX00/0XJbX0::[Y`2S[JH0XZfT0:>^X`2R[J00XJbO09n]W`2O[Yd0V:NC055D
D`0203De>00;02l_<00U9RD07b4P01PG600_<b/0CUU6059NBP1@FdL0@d`k05=OB@1YN5`00P1YMU/0
302Q^900QYEj0;gH[@1bOfL0BE0n0498=@0g>RT0=3DU03<e9@0e>BL0=3`X02lg9080;3HT00H0;CLV
02dg9@0_>2@0<C/V038l9`0_>2<202dc800302T_700W;A/0:S0O0080;C@Q00/0;cHS02he900a>2P0
<cXY03Do:P0f@2/0=3lZ03I0:P0e@2T0?TT]03M09@02038k8@0602df7P0Y<Q`09bhJ02L]6@0V:aT0
9bXL6_oooolR0?n004d0003o3@3oP0070000obX0oh003oooool000gooooo00H0C5QW051MK@1CHG@0
Df1g05EQN@1DH7L205EPM@0;05IQM`1HIGT0FFMj05QWN@1JJ7X0FVQg05]YM`1KJgL0FfYj05][NP1K
JWX00P1KJGT02P1MJW/0Gfam05m/O`1OJgl0GVV0065/Q01QK8D0Hg2706AaQP1VLhH306EcQ@0<06Md
P`1WMH80JGF306]fQ`1^MhT0KGR906ikS01_O8d0L7b>079lS`1cOI40MGnD0P1fPI802`1fPY40N8BB
07V5T@1iQY40NhRA07^8T`1mR9L0OhVJ07n9V`20RYd0PX^M0080Ph^N00/0Ph^P08J>XP26Sj80QXnR
08JAX`25T:80QI:R08JEX`28Uj<0RIRR08bIX`02092KY@0;096LX`2CWJ@0U9jW09FOZ@2FXJT0UZ:W
09FRYP2EXZL0UZ>X09VVZ`2KYjd00P2LZ:h0102MZZh0WjZ]09jXZP2NZJT20:6ZZP060::/ZP2T[Z/0
Y:n[0:B^Z`2S[Z/0XZfY0P2Q[JT02`2R[ZP0XjfV0:F^Y@2T[j<0XjfR0:>]WP2S[Yl0XJbO09n]WP2K
ZY/0FEeN0080;b`g00/0<Bld02PW:`0Q8B<071/M02h_:`1CG4`0F65A04M<@P0`<B/0?3lc06McF@02
05iXD`0<09faS@2/`Yd0Z/:K05UTCP0h?R`0=3PU02DU5`0U9AP0:R`O02hb8`0]<R<0:RlP0P0X;R00
2`0Z<R80;3DR030i8`0b?2@0<S/U02lg8`0]=B80:c<P02P`7P0W;ah0:34O0080:c@P00/0;CHR02hf
8`0a>2D0=C`Y03Hm:P0f?B/0=CdZ03@l:00c?BP0>dD]03@o9`02030j8P0602`e700X<QX09RhH02D/
5P0U:QH09RXI6_oooolR0?n004d0003o3@3oP0000`000?l0oh000?n000030000ob/0oh003oooool0
00gooooo00H0CU]W055NK01DHG40E61d05EPMP1EGgL205=NM@0;05IQN@1HIG/0FFIl05YWO01JJ7X0
FFMf05]XMP1LJWP0FfUj05aYO01NJgd00P1MJG`02P1LJG`0GFYn05m/P01NJgl0GV^005m[PP1PK880
HVn306A`Q@1WLhD306McQ00<06MdP`1YMH@0JGB206]eP`1]MhL0KGR806ijS01_OHh0LGf?075mS@1a
OHl0M7nB0P1fPY802`1gPi40N8F@07R5S`1iQhl0NhRA07j8U01nR9D0OhRF07n9V@20RI`0PHVM0080
PX^O00/0PhbP08J?XP27T:80QY2R08JBXP25TJ40QI>O08NFX028Uj40RYRR08^IX`0208jJY@0308nJ
Y@2BVjH0U9fX0080U9nX00D0UJ6Y09JRZ`2FXj`0V:F/09VV[00309^X[@0709bY[02MZZd0WJRZ09jZ
Z@2PZjP0XJ^W0:B]Z@020:F^ZP030:F^[02T[Z`0Xjj[0080Xjn/00/0XJjX0:6]Y02S[Z<0XjnS0:B^
X`2R[J40XjfQ0:6]W`2O[Yd0WJfL05eRH@02030]>00;02d/<`0S8BP081dQ020O800e>380GfYG0761
J013Acl0<2l]030`;@1NJE<00P1JHdl0301gQFL0SZ9l086EL@1>FT80=Sd[02X_7P0O8QD07AlE02<U
6`0V:Ah0:2`O02L[7@809BTM00/09b`N02Xa7`0]=B00;cLO02`b7@0Y;ah0:c8P02Xc800W<1h09blN
02H`7@0202Pb7P0;02/f800]>240<3PP038i8P0c>BD0=3/W03Dl9`0a>2@0<3LT03Y2:`0d?BP00P0]
=R801P0Z<Qh0:30K02H]6@0S:QL092TG02H[6Q[ooooo7P3oP01A0000o`T0oh0000<0003o0?n0003o
P000103oP0030000ob/0oh003oooool000gooooo00H0CU]X055NK@1DH740E5mb05AOM01FHGL205EO
N00;05MRO01IIGl0FFIm05UVN`1JJ7X0G6Ui05aZN01MJgT0G6Uj05aYO@1MJWh00P1MJGd02`1LJG`0
GFYm05i/O`1MJWh0GF]n05i[O`1QKX40Hfn206I`Q@1WL8H0JG:60080JWF600P0JgF706afR01/MXL0
K7J606egR01_NX/0KgZ=071kSP<0LWj?00h0M86@07F2T@1ePY40MX>A07N4T@1hQ900NXN@07^8T01m
RI40OHRB07n8U01oR9D0P8VH07n:VP80PH^L00/0Q8fM08B>W`25Sj00QY2P08NAX@27TZ40QYBP08NE
X02:Uj<0SY^V08nKZ002092KZ`0;092KZP2CWZ`0U9j[09BOZ@2DX:P0UZ:Z09JTZ`2FXj/0V:F[09VW
ZP2IYj/00P2LZZ`0302LZZ/0WZZ[09n[Z`2NZjT0WjbW0:6]Y@2T[ZP0YJjX0:B^Y`2U[jT0YJjY0:B^
Z`80Y:j/00/0Xjj[0:>^Y`2S[Z@0Y:nT0::_XP2Q[Z80XJjQ0:2^X02N[Yd0WJjK06M_J`0203i1AP0;
030a=`0T92T08R0R01`J6`0g>c<0EV9?065`FP1EH4l0@4Dk03Lj<`1FHDh00P1LJ580301DGdT0F6E;
05MVBP1?G440=cl]02T`8@0Q9QX07B4E024T5`0T:1X09b`L02DZ6`808B@F00/08RDG02@Z6P0W;A`0
9B`K020T600V;B00:30Q02Ta800X<Ql0:34L02Pa6`0202Tb6`0502`f7P0^=ad0;cLL02lf700_=Qh0
0P0b>R<0100]<b00<CPT03U1:P0d?2H2030g8`0602`c800[<Qh0:S0N02L]700U:aX09bhN6_oooolN
0?n00580003o?@3oP00?ooooo`003Oooool0101=FfL0DUi^05=OM01CGWH205AOM`80EF1j00/0Ef9m
05YUP01JIH00FVIl05aYO01MJW/0G6Uk05eZN`1LJGT0GFYm05aXOP0205e[OP0;05e/OP1LK7`0GFek
05i^NP1OKgd0HG2106=bPP1SLH<0I76406IaQ@1WLHD00P1YLhH0301[MXL0JgF706egR@1/MhP0KWR:
06mjR`1_NXd0L7^>079mSP1cOhl0Lh2>07B2S@80MX>@00/0MX>A07N4TP1hQ980NXRC07^9T`1mRi80
OHVD07n9U@21RiD0PXbH08:=V@0208:<V`0;08>=V`25SY/0QI2L08JAW028Til0R9>N08RDWP2:UZ40
S9RT08jIY`2?VJP00P2AVZ/02`2AVj/0TIf[09>NZ`2BWZP0U:2Y09BQZ02EXjP0UZBX09RUZ@2KZ:X0
W:V/0080WJV/00/0WZV]0:2Z[@2QZZl0XJ^]0:6[ZP2T[ZT0YJnY0:F^Z@2U[ZL0YJjV0:F_Z0040:J`
ZP0:0:F_Y`2T[j<0Y;2S0:B`X@2R[il0XJfN0:2^W`2M[9l0WJjM07V5O080ADY=00/0=SXm02`^;P0W
:2D08R4M034b:P17C3l0BU95051LB`14CSl0>D4c05MVC@02061_E00<04eI@@1;Ecl0B5<k04E>=`0e
>bX0;C8T02DX7@0O8QP08RDI02@Y700R:1X07bDF0P0M8A<02`0P9AH08bTI02DZ700U:ad06A`D02@X
700W;Ah09blN02Tb7P0[=1h0;3@M0080;CDM00/0;SDN02lf7`0`=b00;SDO030g7`0`=R40;S@P02/`
7P0`=R40>40X03<j8@0202lg7`0602/c7`0Z<Al0:30N02T^7@0W;Ah0:c4S6_oooolO0?n00540003o
?@3oP00?ooooo`003Oooool0101<FVT0DEe`05=OM`1EGg/405EPN`0;05MPO01JHgh0FVEm05eXO@1L
JG/0GVYl05i[O01NJWd0GFYm05i[OP1NJWl00`1NK8002P1MK7l0GFin05e^O01NKgd0H71o06=aP@1Q
Kh00HW2206AaP`1VLXD206QbQP0<06YeQ`1/MhP0JgN906agR@1_NHX0KgZ;071kS@1bOHh0Lgj>07B0
SP1ePHd0MX>?0P1gPi802`1gPi<0Mh:C07R4U01jQiD0O8RE07n;U`20RiL0P8VF082:U@21RiL0PXfJ
0080PXfL00/0PhjL08B>V`24SY/0QY:M08RCW`28TYl0RIBP08bFX`2?VJL0SiVX092IZ@02096IZP0;
096JZP2AW:X0TYjY09:OY`2DXZT0UJ:Y09JSZP2GYJT0VJJW09fXZP2NZJ`00P2PZZl02P2PZK00XZZa
0:>//P2T[K80Xj^^0:B][02U[JT0YZfX0:R_YP2W[jH20:J`Y`80Y[2V00/0Yk6U0:FaXP2U/J40Y;2O
0:JaW`2U/9h0Y:jN0:6^WP2O[Ih0WJfM08:@P`0204Q<C@0;03Tk?00_<C00:R/X02PW8P0Y:280>3P_
04U>?`18DT00?dPh03Lo;P1DHdL00P1TMUD0301?G400BUHk04UC>013BC40=STW02la8P0X:Qh08B<I
024U6P0T:al08RXN01lW6P807bHH00/08RXJ02@[6P0R:QT08RPI01HJ3`0J7A40828D028W5P0W;Q/0
:S8M02`d7@0202hf7P0;02lg800a>2<0<cTU02lf8`0`=R<0;S@R02db800Z;ah0<CLT03a4;00c>R80
0P0_=ah01P0[<ad0:C8N02P_7P0Y;Qh0:RlP02dc8a[ooooo803oP01@0000ocd0oh003oooool000go
oooo00H0CEY[055NLP1CGWH0E5mj05APO01EHGd205EQN`0305IRNP1IHgX0FVAk0080GFQm00H0GFUl
05eYNP1MJG/0GFYm05iZO`1LJGh205eZP00;05m/PP1MJh00GF^005e[O`1MK7d0Gfim069aO`1QL7h0
Hg9o06EcP01VLh800P1YMHH0301ZMHP0JgR906]hR@1/NXX0KWZ<071kS@1aO8l0LWj>079oS@1cOh/0
Lh2;07>1S@80MH>B00/0Mh>C07N3U01hQ9D0NhNF07f8UP20RYH0P8VF0828U@21R9H0P8VI08><W003
08:=W00:08B>W`25Sj00QY6P08JBX027TZ00RYBS08fHY`2?VZT0SiVY092JZ080T9ZV00/0T9ZU09:M
YP2BWZH0Tj2V09FSYP2EXjL0Uj>Z09VUZ`2JYJX0W:N[09nY[@020:6Z[`0<0:6Y/02PZK00XZZ`0:>[
/02SZjl0Xjb/0:F/Z@2V[ZT0Z:jW0:N^YP2W/:L0YjnY0P2V[ZL02`2W/JH0Y[:T0:JaXP2T/:00YK6Q
0:JaXP2U[j40XjjP0:2/W@2N[I`0RiN:0080B4Y>00/0=cHk038a<P0^;B`0;2`Z02`/9`0b=2/0CEI3
04YD@00lAC<0<cX[04QC?P0206UjF`0<055M@`19DcX0BE4h04E;<P0j?RL0<3@O02TZ6P0S91L08B<G
028V6P0S:1/092TM0P0T:A`02`0S:Q/09R`K028W5`0L81805QP=018D2P0E5P`06A`>02P]6P0/<Al0
;S@P0080<3LS00/0<STU038i9`0d>bL0=C`X038h900_=280;S<Q02X_7P0a=b@0>d<]03<k9@0202lh
8@0602/d7@0[<al0:c8P02T_7`0W;Qd0:S4O6_oooolP0?n00500003o3@3oP0020000obh0oh003ooo
ool000gooooo00H0CEY[055NLP1CGWH0E5mj05APO01EHGd205EQN`0305IRNP1IHgX0FVAk0080GFQm
00H0GFUl05eYNP1MJG/0GFYm05iZO`1LJGh205eZP00;05m/PP1MJh00GF^005e[O`1MK7d0Gfim069a
O`1QL7h0Hg9o06EcP01VLh800P1YMHH0301ZMHP0JgR906]hR@1/NXX0KWZ<071kS@1aO8l0LWj>079o
S@1cOh/0Lh2;07>1S@80MH>B00/0Mh>C07N3U01hQ9D0NhNF07f8UP20RYH0P8VF0828U@21R9H0P8VI
08><W00308:=W00:08B>W`25Sj00QY6P08JBX027TZ00RYBS08fHY`2?VZT0SiVY092JZ080T9ZV00/0
T9ZU09:MYP2BWZH0Tj2V09FSYP2EXjL0Uj>Z09VUZ`2JYJX0W:N[09nY[@020:6Z[`0<0:6Y/02PZK00
XZZ`0:>[/02SZjl0Xjb/0:F/Z@2V[ZT0Z:jW0:N^YP2W/:L0YjnY0P2V[ZL02`2W/JH0Y[:T0:JaXP2T
/:00YK6Q0:JaXP2U[j40XjjP0:2/W@2N[I`0RiN:0080B4Y>00/0=cHk038a<P0^;B`0;2`Z02`/9`0b
=2/0CEI304YD@00lAC<0<cX[04QC?P0206UjF`0<055M@`19DcX0BE4h04E;<P0j?RL0<3@O02TZ6P0S
91L08B<G028V6P0S:1/092TM0P0T:A`02`0S:Q/09R`K028W5`0L81805QP=018D2P0E5P`06A`>02P]
6P0/<Al0;S@P0080<3LS00/0<STU038i9`0d>bL0=C`X038h900_=280;S<Q02X_7P0a=b@0>d<]03<k
9@0202lh8@0602/d7@0[<al0:c8P02T_7`0W;Qd0:S4O6_oooolP0?n00500003o3@3oP0020000obh0
oh003oooool000gooooo00H0CUU^059MM01CGgP0E5ii05IQO@1EGgd205AON`0;05IRN`1HIG`0FVIm
05YVO01KIgd0FfQl05YWO01LJ7`0G6Um05iYP01MJ8000`1MJX402P1LJX00GV^105m/P@1PKH00H6io
069`OP1SLWd0IGAn06EdO@1VLgl206UdP`0:06]fQ`1/MXT0JgJ906ahRP1^NXd0LGZ@079lT@1dOI00
MGn@07B0SP80MH6=0P1ePHl02`1gPi<0N8BG07R3UP1lQYP0OXNI07n8V020R9T0P8VH0869V021RYX0
Ph^K0080PhbK00/0Q8jL08B>W`26T:40QY6Q08NBX@27Tj00RIBS08bGYP2=V:T0SYRZ08nJZ003092K
YP0:09:MY`2BWJD0TinV09>QYP2EXZL0UZ:W09VSY`2JY:T0WJJ/09nV[@80X:N^00P0WjN`09nX/02P
ZK00XZZ`0:>[/02SZjl0Y:b]0:B/Z`80YZf[00l0Yjj[0:N]Z`2V[JT0YZfY0:B^YP2T[Z@0Y:nS0:>^
X@2U[j80YJnS0:B^X`2S[J80XZfO0:2]WP2<V8`00P19BU002`0l?D40>S/k03Ph=00b<Bd0;R`X038c
;01BFdP0DUe804=<>@0d>b/0@T`g0080JG]J00`0Dem404YC>`17CcH0AD/c0497;`0g>RL0;blO02XZ
700X9a`0:2XN02HW7@0T9Qh202<U7@0;020S6@0O8QL07B4D01PK3P0C5PX03a<700d?1P0?4PL09blJ
02`c7P0`=R800P0b>2D02`0c>BH0<SPW038i9`0b>BH0<3HS02hd8@0]<R00:c0N02dd8P0a?2H0;CLQ
0080:cDN00H0:38L02Pa700Z<Ah0:BlO02H[7@0Z<R0Jooooob00oh00D0000?l=0?n00080003o;P3o
P00?ooooo`003Oooool01P1>FFd0DEYb05=NN01DGW/0EUml05IQO@80Ef9m00<0F6=m05UUO@1KJ7d0
0P1KJ7d01P1KIgd0FVMm05aXOP1MJWl0GVV005aVP080G6Mo00/0FfQn05aZO`1NJgl0Gff105m/P@1O
K7l0HFio069`O@1SLG`0Hg5m06IbP@0206QbQ@0<06YcQ`1ZLhP0K7F:06igR`1`NHd0LGZ@07AlT@1d
OI00MGj@07J0T@1ePI00MX:@0P1ePY402`1gPi@0N8>H07V3V01jQ9P0NhFI07j7VP21RYd0P8ZM082:
W022S9`0PXbM0080PhbM00H0PhfN08B>X025Sj00QY2Q08N@XP27TJ@208VDY@0308ZEYP2<UjP0S9JY
0080SIRY00/0Si^X08nKYP2@WJH0Tj2W09BPZ02FXJT0Uj6Y09ZSZ@2LY:/0WZF/09nW[`0209nX[`07
0:2W[`2QZ;40XZV`0::Y/02RZk40Xj^`0:>/[P020:B/[P030:F][P2U[:d0YJb[0080YJfZ00/0Y:fX
0:B/Y`2T[ZD0Y:jT0:F_X`2V/:@0XjfS0::/XP2QZj00X:bO096NTP0204e>E00;0494B013Ad<0?3lh
030`:P0];2D0<30Y04eCA01<Dd80?TDf02ld:00lA3400P1^PUd0301FIDL0Ae4h04QB>@16CSD0AD/d
04=7<P0l?B`0=cP[038c:P0`<2X0:RXT02@T8080824L00/07R4I01hQ5`0M8AD061/?01<G2`0@50L0
3Q4600X<100Q:1P0;cPS02lh8P02034i9080<3TU00T0<3TT02hf8`0^=R40;SHO02dc7`0Z;ah0;3@R
02lj9@0[=Al00P0Y<a`01P0Z<a`0:c4L02/a7P0[;ah0:2/L02T^7Q[ooooo803oP01@0000o`d0oh00
0P000?l^0?n000oooooo000=ooooo`0604eIJP1@FW00EEmg05IPNP1EGgX0Ef=m0P1HHgh02@1II7l0
FFEo05YUOP1KIg`0GFQm05]XO01MJ7h0GFQo05eXP00205iYP@80GFR000<0GFUo05iZP01NJh000P1P
KH001P1QKH40HVn106AaP@1VLh80IW6306MbQ@80JG>900`0JWF:06YdR@1]MX`0KgR>071iT01bNi40
M7bB07=lT01dOI40MGnC07F1T`1fPI<207N2U00;07R3UP1iQ9P0NXFI07Z6V@1jQIP0O8NJ082:W@21
RYd0P8VN086:WP23Ril00P23S9l02`24SJ00QHjP08F>W`27TJ40R96R08RBY02:U:H0RYFU08^GY`2<
V:P0S9NZ0080SIRZ00/0SiZZ092MZ@2BWZP0U9jW09JQZP2IXZ/0VJ:Z09^UZ`2LY:/0WZJ/0:2X[`02
0:2Y/0070:2Y/P2PZ[@0XJZc0:2Y/@2PZk40XJ^`0::[[`020:F][`030:F][P2V[Jd0YZf/0080YJj[
00/0YJjY0:F^Z02T[ZH0YK2W0:F_Y@2U[j@0Y:fT0:>]X`2R[:<0X:^Q09JRV002059CF00;03`l@`11
@T40?Cdh038a:P0_;RD0<S0W04Y@@019CSh0?d<e03<f:`0j?c400P1`PEl0301IId`0ADhj04YD?P18
DC/0AThh04]?>P17B3L0ADDg03hn=@0i>380<c<^02XY9`809BHR00/082<J01dP500J6a005QH=01<E
2`0A50T03a8800T<100M9AH0;cTU02lh9@02030i9P0;02hg9@0]>2@0;CPS02dh8`0/=R40;CLP02/c
7`0Z<Al0:S<P02`f8P0Z=1l00P0Y=1h01P0[=1l0:c<N02/a700Y;Q`0:bhM02db81[ooooo7`3oP01A
0000o`d0oh000P000?l^0?n000oooooo000=ooooo`0604eHJ@1@Fg00E5me05IPM`1GHGT0FFAl0P1J
Hgh02`1JI800FfF105YTP01KIgl0G6Qm05]XN`1LJG`0GFUo05eXP01PJX80H6Z300<0GfR200X0H6V3
061ZPP1PJh00HFf1069]P@1QKX40Hg2306IbQP1XLhH0JG>70P1ZM8X0301/MX/0K7F;06aeS01^Mi00
KgVB075kT`1cOI<0M7jC07F0T`1dP980MH2B07N3T`80N8>C00/0NH:C07Z3U01kQ9L0OXJH07j8V01o
R9T0PHZK086:W@21RIh0PHZO08:;W`0208><W`0;08B=W`25Sj00R92Q08VAX@29TJ80RY>U08ZCY02;
U:H0S9NX08fGZP2>V:/00P2>VJ/02`2?VJX0TYf/09BNZ`2DWZT0UYnZ09RQZP2IXJX0VJ>[09ZTZP2L
YZ/0WjR^0080WjR_00`0WZVa09jX/P2NZ[80WjZa09nZ[`2Q[:l0XZb^0:B][02T[J/0YJj[0:N]Z`2X
[ZX20:N_Z@030:J_Y`2W/:D0YZnS0080YJnT0P2V[jD0102T[Z@0XZbR0:2ZX@2KZ9`2065UI@0;03hm
@`10@D80?Shj03He<00c<B/0<c4Z04Q;?01;DD00@DDg034c:@0f>R/00P1]OE/0301VMEH0AD/j04YA
?`18D3h0AD`j055F@@1MHd/0EEU504a=?P12@SL0@TDk02TX9P809RLR00/08B<L01`N500I6@d05QH9
01<D2@0B50X0418800h@1P0G6P`0:2lL02T`6`0202T`7P0;02H]7@0U;Ad0:34P02`g8`0Z=B80:34N
02Pa7@0Y<Q`0:C<M02dh7P0]>1d00P0[=1`01P0[<ad0:c8M02X`7@0Y;ah0:blO02hc8A[ooooo7P3o
P01B0000o`d0oh000P000?l^0?n000oooooo000=ooooo`0604eFJ@1@FFl0Deed05IOMP1HH7L0FV=j
0P1JHg`01`1JHgl0FVB005YUP@1KIX00FfMn05YWN`1LJG`00P1MJ7h01P1OJH00H6V105iVO`1NIWl0
GfN0069ZP@80HFZ000L0HFf206=^P@1TL880I72306IaQ@1XLXD0JG:60080JW>800L0K7>906edR@1]
M8X0KWN=06miS`1bO980MGjD0080MGjE00<0MGnE07EoU01fP9@00P1gPY<02`1hPi@0NH>C07Z4T`1l
QI@0OHJE0828UP20R9T0OhRJ0829W@1oRih0OhZM0080OhZK00/0PHfL08B>W@26Sih0R92N08RAW`28
TJ00RI>Q08^EY02<UJL0S9JW08jHZ00208nJZ@0;092KZ@2BW:X0TifZ09FNZ@2FWZT0Uj2Y09RRZ@2I
XjX0VjF[09bVZ`2NYj`00P2NZ:d0302NZ:l0W:R`09bY/02MZjl0Wj^/0:2[ZP2Q[:X0Y:fZ0:F^ZP2U
[JT0Z:jZ0:V`Z@80Z:nW00/0YZjU0:J_X`2V[Yl0YZjP0:N_X`2W[j@0Yk2T0:F_X`2S[J80XJbQ0:2^
X00206Q]K00;03Tg@010@480>SXh03ho>P12A3`0Ad/o04]@@@1:Cd00@DLh03<g;00b=bX00P1VMeL0
301`PF00A4Xi04M>?P16CCh0@DHh05AKAP29VWH0JW9J06=ZEP1PJ5H0CE=802/[:@809bTU00H0824K
01PI4@0C4`X04A06010?1@0@40H2018C2@0301@F2@0S:1@08bPB00808BDB00/07B4@01hS4`0V;1/0
:S8O02D]700O9AH08RTH02H_700Y<Q`0;CPN02dg7@0202hf700602dd700]<a`0:S0K02X_7@0/<B40
;C<R6_oooolN0?n005@0003o3@3oP0000`000?l0oh000?n000030?n00080003o9P3oP00?ooooo`00
3Oooool01P1@FFT0E5a^05MOMP1GH7H0FF9i05UTNP80FFEj00T0FVIm05]WOP1KJ7h0GFQo05eXOP1K
Ig`0G6Ml05aWO@1MJ7d00P1MJGh205iYO`0;065[P01QJgl0Hff0069^P@1SL880Hfn106McP`1XLX<0
J76406QbQP1YLXH00P1ZM8L0301[MHP0KgJ8071gR01bNXX0LW^=07AlT01gOI@0MgfF07EmU`1dOYH0
MGnE07N0U@80N8:F00/0N8>F07R4U01hQ9<0NHBD07b6U@1oRIH0PHVJ0829V`20RY`0OhZL07n:W@02
082;W00;086<V`23SY`0Q8jK08N@W029TYd0RI:N08^EX02=UZ80SYJS08nGY@2AVZP00P2BW:P02`2C
WJP0U9jX09FNZ02EWJL0UIjV09NPYP2JXjL0VJ>W09fVZP2MYj/0WZV/0080WjV/00`0WZV]09jY[P2M
ZZh0WZZ/09n[ZP2PZjP0XjfY0:F]Z`2W[Z`0Z:j[0:R^Z@2X[jL20:N_Y@80YJjS00T0YZnR0:J_X@2V
[j80ZK2T0:R_X`2U[Z80Y:jS0:6/XP2Q[j<00P1[L7802`0e<ch0?clo03Lf<`1AEDH0DeQ605iTC`1J
H4/0CeA304eD@`0l@SD0>D0c0080H71F00`0JgaO04YC@@19DT00@DLi03Hj;P1>ET@0Ujb808^LOP27
UGX0QYAj05QODP0Y:2P202HX8`0;01hP600J71805AH;014B1P0?3P@040l501@C2@0F5``061X=01dR
400N90h00P0K8Pd02`0I7`d06Ad=02H[6@0^=B807b<G01@F3P0P9QP09BdL02Xc7`0_=b40;cHN0080
<3HP00H0<CLQ02le800/<Qh0;38O02dc8`0`=bHJoooooa/0oh00E`000?l=0?n000030000o`3oP000
oh0000<0oh0010000?lT0?n000oooooo000=ooooo`0604iHJ@1CGVl0FF9h05YSN`1IHg/0F6Ak0P1G
HgX01`1IIG/0FfIk05]VO01NJ7h0GfUo05eXO@1KIg`00P1LIg`03P1MJ7`0GfYn05eXOP1MJ7h0GVUo
05mZO`1PJWl0HFf0065^P01RKX00IG6206QbP`1XLX@0JG:70`1ZM8H0201ZM8D0KGN806mhR@1aNXX0
LW^=07AlS`1eO980MWjE0P1eOYL03`1fOiH0NH6G07V1V01iPIP0NX6G07V1UP1kQ9D0OXNI07n9V@1o
R9T0PHVL0828W@1oQid0P8RM086:W`0208><X00;08:;WP22S9l0PhfN08J?W@28TIh0RY:O08^DW`2=
UZ00SYNQ092HXP2BVJ@00P2CVjH02`2DVjP0U9fW09BLZ02DVjP0UIfX09NPZ@2IXjP0VZ>W09fVZ@2N
YZX0WZRY0080WjZ[00`0WjV[09jYZ`2MZZX0WJZX09nZZP2QZj/0XZ^[0:>[ZP2U[:/0YZf[0:R]Z@2Y
/:L20:R`YP<0YZnT00P0YZnS0:NaX`2X/:80YjnS0:F]X`2S[J<0X:^S0:2^Y080LgYj00/0?Si703i0
@@0f>3H0DEU904mE@`1RJU40HFUA055GA@1BFdT0@DXk03]3=@0205YXC`0<06UjG01?FD<0C5E00415
=00c=2T0D5I4096TP`2=Wh40TJ:409V[S01/Mf<08QhO0P0T8b002`0P8QT06Q/A01DE2`0B4PL04@l6
014@1P0H6`/071l>01hQ4@0N91807B@B00806R4A00X05ad?01HI3`0b>BT0?DDb01DG4P092PP07R@H
02df8`0`=b80<STR0`0`=Ql01P0b=R80;c@R02db8P0]<b80;S@S02lf9A[ooooo703oP01F0000o`d0
oh0000<0003o0?n0003oP0000`3oP0050000ob<0oh003oooool000gooooo00@0C5Q[055ML@1EHGH0
EF1i0P1GHW`205QRNP0;05USNP1JI7X0FfAk05]TO01KIg`0FVMk05aYN`1MJG/0G6Qj05aYNP1MJG`0
0P1MIgd02`1PJWl0HF]o05mZO`1PKH40HFf1069^P@1TKh<0IG6406MbQ01XLXH0JGB60080JWB600`0
JWB706efR`1_Mh`0L7R=075kS`1bO940LgfC07AoU@1eOiL0MgjH07QnV01jP9T207Z0V00;07V0UP1i
P9@0O8:F07n4U`20QIT0P8JJ0828V`20Qi/0OhJK0827W020RIh00P21Rj402`21S:40PhbQ08B=X@25
SIh0R92N08RBX02:Tj00S9BP08^EX@2<UJ40SiJS0080TIVU00/0TYZV09>KZ02AVJP0TYZY09BMZ@2F
WZT0UinY09NOZ02HXJP0VJ>W09^UZ00209bWZ00<09fXZ@2NZ:X0WJRY09fXY`2NZJT0XJV[0:6ZZ`2R
Zj`0Xj^/0:B/Z`2V[JX0Z:jY0P2V[jD02`2V/:D0YJnT0:B^X`2U/:@0Y:nS0:F^X@2U[Z<0YZjS0:B]
X`2Q[:40X:jR0080OhR200/0AdQ=0495A@0j?SX0@4Dl04M>?`1HH4/0J7AJ04mFA@1CFTP0ADdm03U0
<@02055NAP0<06YmFP1EHdL0CUU004YB>`0j?Rl0C59108jQP02:Vgh0S9b109JVR@21SgD0;RdY0P0U
8Ql02`0R8Q`071`F01LF3P0C4PT04A47018B1P0H6`/06b4>01`Q400O9A<07R@D00807B<D00/06A`?
01<D300Z;R@0?TLh01XM6P0;3@`061hD030j9@0^=b40<cXS034g7`02030f8006034g8`0^=2<0;C8S
02hc9@0a=bD0<SPU6_oooolM0?n005D0003o1P3oP0000`000?l0oh000?n000040?n000030000o`3o
P000oh0000<0oh001@000?lS0?n000oooooo000=ooooo`0604]GJP1?Fg40E61g05AOM`1GHWX0F6=l
0P1HHgT02`1II7P0FVIi05aWN`1LIg`0FfIj05YWN@1LJ7/0GVYk05eYN@1NJW/0GVYl0080GFQn00/0
GfUm061[O`1OJWl0HFf1061]P@1QKX40I6n306I`Q01WL8@0Ig:506UcQ`0206YdR00906YcR@1/M8/0
LGN>07=jS`1dO940M7jB07F0T`1fP9D0MWnG0080MgnH00X0N82H07R1U`1hPIL0NH6F07^3U@1mPiD0
Oh>E07f1U01nQ9P0OhJJ0P1oQi/03`1oRId0OhZN07j:W`1nRYl0Oh^N086=X023SJ00QHfP08J?X028
TJ40R9:R08^DY02;UJD0RYFU08bFY@0208jGYP07096JZ02BVjT0TIZX09:KY`2BWJL0U9fY09NPZ`02
09RQ[00@09NPZP2JXj/0VjF[09^UZ`2LYZ`0WJR]09fY[02MZ:X0WZV/0:6Z[P2RZjh0XZZ_0:B//02U
[K40Y:b_0:F/Z`80YJjX00D0YZnV0:J`Y@2T[j<0YK6T0:>^X`030:B^X`030:B]X`2Q[:80XJnT0080
RiJ>00/0AdQ=03m0@@0i>cP0?d8k04]AA@1=DdH0JgUR04]BA@1?EdT0Ae1103Hl<@0204]GA00<06f1
G`1HIdX0CEU004]G?P14CST0B50n08^MN`2<WGl0RYYm08jMPP2?WH80CE160P0X9B@02`0U92807ahL
01TI500E50l051@=01DF300J7Pl0724C01dR4`0P9AD08BHF00807b8D00/06QX>01HE300N7aL0;C4X
03i7>@0?4A403a<?02Tb8@0]=B80<3HS02le8P0202he8@0602lf8`0_=240;S8P034d8`0d>2L0=CXX
6_oooolM0?n005D0003o1P3oP0000`000?l0oh000?n000040?n000030000o`3oP000oh0000<0oh00
1@000?lS0?n000oooooo000=ooooo`0604iIK01@Fg80DUig055MMP1CGWL0E61f0P1EHGD01P1GHg@0
F6Ed05]WN01MJG`0FfIk05YWN`<0FfQl00D0GFUm05iZOP1MJWh0GFYn05i[O`0205m[P008061/P@1Q
KH80H6f206=_PP1UL8<0IVn406I`Q01XLHL306YcQ`0;06egRP1_NHX0L7V:079kS01cOHd0M7j>07En
T@1fP9@0MH2F07EoUP1eP9L00P1gPYT02P1iPYP0Mh6F07Z2U@1lPiH0Nh6E07^2UP1mQ9P0OHFH07j8
VP1oRId3082;X@0;07n<X020SJ00PHfP08>=W`26T:40Qi6R08N@XP28TZD0RIBW08RDYP2:UJH00P2;
UjH02`2=V:H0SiZU08nKX`2@Vj@0TIfV09:NZ02EX:X0UZ2[09NQ[02HXJ`0VJ:]0080VJB^00`0VZJ_
09bW/02LZ;00WJR_09fX[P2NZJd0XJZ]0::[[P2TZk00Xj^`0:B/[`2S[:/20:B/Z00;0:B]Y`2S[jL0
XZnU0::_X`2R[J80XjfS0:B^Y02S[J80XZfR0:2[XP2P[J<00P2?W9<02`1:BU40?Si403Tj?@17CDL0
FV=E051FC01XMF80BE5804aFB`15Cd@0=C`e0080AE1200`0JGeP05UYC`1<F480C5M204MA?`17D400
Oi1b08ZLOP28Ugd0RIQo08VGP@1YLf@203i1?00;02HW9`0Q8R@07QlO01TJ6@0H61@06Q`C01dP5@0Q
8aP08R@H02@W6@0U9aT00P0P8QD02`0K6@l06QP@055LA00oAcP0FFE@014B4@0B51409B/O02Xa8@0/
<R40;C8P0080;S<Q00@0;C<Q02ld8@0_=1l0<cLS0P0f>BLJoooooal0oh00D`000?l60?n000030000
o`3oP000oh0000@0oh0000<0003o0?n0003oP0000`3oP0060000ob80oh003oooool000gooooo00H0
CUY/051MLP1CGgL0Demg05=PM`1EHWH205ARL`0;05ISL`1GI7@0FFIf05UVN01IIWT0FVIj05]XO01J
Ig/0FVQi05YWM`1LJGT00P1LJG`02`1NJGh0GfYo05m[O`1OJh00Gf^105i[P01QKX40HVn206=`PP1U
LHD0IW6600<0JG>700/0K7N906mjR`1`NX/0LWf=075lS@1bOHh0Lgn?07F0TP1ePI<0MH6D07F0T`02
07N0U@0;07N0UP1iPIH0NX:G07V2U`1jPYL0NX>G07Z4UP1lQYP0OXNJ07n9W@21RYh00P21RZ002`20
Rj40P8bR086=X`22SJ80Q92R08F@XP26TJ80Qi:T08RBY028TjD0RYBV0080RiJU00/0S9NT08nIY02A
Vj<0TYfS09>NY02BWJH0U9jX09JPZ@2FXJT0V::[09RR[00209VS[@0<09^W/02LYk40W:N`09fX[P2M
Yj`0WZR[0:2ZZ`2QZjX0Y:^/0:B[[@2T[:d0Y:b[0P2S[:T01@2S[:L0XZbW0:6]YP2P[J@0XJfS0080
XjjT00@0XZfR0:6]XP2NZZ40W:VN0P2>Vi002`1=D5@0@dE:0414A@1=E4d0HfeN059HCP1KIEP0C5A;
04]DB014CD40=C/c0080Ae5100`0HG5F05a[D@1?FdD0CEM404UA@P19D4<0P8md08VJOP28UWh0RIN0
08BAO@25Tgd2079mJP0;020N8@0O72406aTM01HD5`0E4a<06AXE01dP5P0P8QL08R@H02LZ6`0Z;1h0
0P0R8QH02`0L6A406AHA06=`E`1WMeh0Ae54010@4`0E61P0;cP]02lh;00_>2P0;3@R0080;C@Q00H0
;3@Q02dc8@0]=240<3HR03<i9@0f>RLJooooob00oh00DP000?lC0?n000P0003o403oP0000`000?l0
oh000?n0000=0?n000oooooo000=ooooo`0604YHJP1=Fg00D5id055OMP1BGgL0E69g0P1EHgD01P1F
I7D0EfEd05QUM@1IIWH0FVMg05]XN080FfQi00<0G6Yi05YWM`1KIgP00P1MJGd02`1PJH00HF^4061[
PP1QK8<0HFf105m/O`1QKWl0HW2106AaP`1ULXD0J7>80080K7J;00<0KGJ;06ihS@1bO9000P1cOI40
1`1aO940LWfB07AoTP1fPI<0MX:B07J2T`1hPYH00`1gPID02P1hPYP0NX>K07Z3V`1kQ9/0NhNK07b6
VP1oRI`0P8RK082:WP20RYd2082;X00;082;X@21S:<0PXfV08:?YP23T:D0PhnS08>?X@26TJ80R9>T
08^FZ02=UjL00P2=UZD02`2>V:H0T9RU09:JYP2CVj@0TifT09BNY@2FWjD0Uj2W09NQY`2HXZL0V::X
0080VZB[00`0VjJ^09^V[`2KYZl0W:J^09fW[P2NZ:h0WZR]09nY[@2RZjd0Y:b]0:>/[02R[:/20:>]
ZP0;0::]Z@2R[JP0XZfY0:6]Z@2S[jX0XJfV0:6]Y@2OZj@0WJVP09^XWP2IYi/00P2=Vi002`1GG5h0
ADQ>04YADP1QK600G6EG055GBP1BFD/0C5A704QAA00oASX0<cP^0080?THf00`0I7AG065aEP1BGTP0
C5I304Q?@015BCh0NXQ`08fOPP29V800RiZ308JCO`2<Vh<208FDO@0;02@R8`0K5Q/07AXL01LD5P0D
4140518@01TI4`0Q8aP0<C@T03Lj:@0c=RL00P0T9QX02`0L7A<05a@?05ALB01nT6l0EF1?01`M7P0D
5AT0<S`d03<m<P0]=bT0:C<R0080:S<Q00H0:S8P02Xc800Y<Al0:c<Q02lh900c>RLJoooooal0oh00
D`000?lC0?n000P0003o403oP0000`000?l0oh000?n0000=0?n000oooooo000=ooooo`0604QFJ01;
FF`0Ceia051MM01AGG@0Demf0P1EHgH02`1GIGL0F6Ee05UVM@1JIWL0G6Qh05YVN@1KIgX0FfMk05]X
O01IIWX0FFIk0080G6Qn00/0GfV105mZPP1PJh<0HFf3065^P01QKWh0HVmn06=aO`1ULX<0J7>606Yf
R@0206agS@0606mhS`1`NI00LGZ@07=lT@1bOI40LgjB0P1dP9@0101dP9<0MH2C07J1U@1hPiL207N1
UP0;07N2V@1hPiX0NH>K07V3V`1jQI/0NhJL07b7V`1nR9`0OhNL0829WP1oRYl00P1oRZ40101oRj80
PHbS086=Y@21SZD208B@YP0508>?Y@26TJ@0R9:U08ZEY`2<UZL00P2=UjL02`2@V:P0T9RY096JZ@2B
VjL0TYbU09BNYP2FX:H0UZ2W09JPYP2IXjP0VJ>Y0080VZB/00@0VjB]09^U[`2KYJh0W:N^0P2MYjl0
1P2NZ:l0WjV_0::[/02RZjd0Xjb[0:B^Z`80XjfZ00/0XZbZ0::]ZP2Q[:T0XZfZ0:B`[02R[Z/0XZjZ
0:2ZY`2OZZ@0WJVQ09bZX00209JTVP0;06I/K015Ad`0C4m=08RGO@1IGe00E5U:05YRDP1<E4P0?dHn
03@h=00Z;BX00P0e>S402P1SLeP0I7AG05IRBP1@FD@0Be9104=8>`1cP6L0TZF408^LP02=WX<208VH
O`80Ri^000/0<C4^01/G6P0S8Ah06aTG010=3@0=2@X040d<03@h:P1KId`0H6aC04YB@@0202P[900;
02@V7`0R8Ql0FVAB07Z;L01^OFH0<SLa01@C5P0lAc/0<SX`02Ta9P0V;R000P0V;Ql01P0W;ah0:C8N
02Pc7P0Z<al0;SHQ038h91[ooooo7P3oP01D0000o`<0oh0000<0003o0?n0003oP0003@3oP0080000
oa00oh000P000?l>0?n000oooooo000=ooooo`0604QFJ01;FF`0Ceia051MM01AGG@0Demf0P1EHgH0
2`1GIGL0F6Ee05UVM@1JIWL0G6Qh05YVN@1KIgX0FfMk05]XO01IIWX0FFIk0080G6Qn00/0GfV105mZ
PP1PJh<0HFf3065^P01QKWh0HVmn06=aO`1ULX<0J7>606YfR@0206agS@0606mhS`1`NI00LGZ@07=l
T@1bOI40LgjB0P1dP9@0101dP9<0MH2C07J1U@1hPiL207N1UP0;07N2V@1hPiX0NH>K07V3V`1jQI/0
NhJL07b7V`1nR9`0OhNL0829WP1oRYl00P1oRZ40101oRj80PHbS086=Y@21SZD208B@YP0508>?Y@26
TJ@0R9:U08ZEY`2<UZL00P2=UjL02`2@V:P0T9RY096JZ@2BVjL0TYbU09BNYP2FX:H0UZ2W09JPYP2I
XjP0VJ>Y0080VZB/00@0VjB]09^U[`2KYJh0W:N^0P2MYjl01P2NZ:l0WjV_0::[/02RZjd0Xjb[0:B^
Z`80XjfZ00/0XZbZ0::]ZP2Q[:T0XZfZ0:B`[02R[Z/0XZjZ0:2ZY`2OZZ@0WJVQ09bZX00209JTVP0;
06I/K015Ad`0C4m=08RGO@1IGe00E5U:05YRDP1<E4P0?dHn03@h=00Z;BX00P0e>S402P1SLeP0I7AG
05IRBP1@FD@0Be9104=8>`1cP6L0TZF408^LP02=WX<208VHO`80Ri^000/0<C4^01/G6P0S8Ah06aTG
010=3@0=2@X040d<03@h:P1KId`0H6aC04YB@@0202P[900;02@V7`0R8Ql0FVAB07Z;L01^OFH0<SLa
01@C5P0lAc/0<SX`02Ta9P0V;R000P0V;Ql01P0W;ah0:C8N02Pc7P0Z<al0;SHQ038h91[ooooo7P3o
P01D0000o`<0oh0000<0003o0?n0003oP0003@3oP0080000oa00oh000P000?l>0?n000oooooo000=
ooooo`0604UEJ01;F6/0Ce]a051MM01@G7D0DUig0P1DH7H02`1EHgH0EV=e05QUN01KIG/0G6Ek05UT
O01JIGh0FfIn05aXO`1KJ7d0FfMm0080G6Qo00/0GFR005iZP01NJWl0GV^005m]P01QKWl0HVmm069`
O`1TLX<0J7F706]jR`0206ahR`0<06eiS01_NXd0L7^?071kS`1bOI00Lgn@07B0TP1cOY<0LgjD07Ao
U01eOiD0MX2F0P1fP9L01@1fPIP0MH2H07N1V@1hPiP0N8BH0080NXFJ00@0NhJJ07^5V@1mQih0OHVQ
0P1mRJ80101lRJ40OX^Q07n<XP21SZ@208B@YP0508>>YP24SjH0QY2V08NAY@2:UJL00P2=UjT02`2=
UjP0SYRY092JZP2@VZT0T9^X096LZ02CWZT0TijZ09>NZ@2EX:/0V::/0080VJ>^00`0V::^09ZT/02H
Xjl0VZFa09^V[`2MYjl0WjV`0:2Y[`2RZJl0XZ^]0:>]Z`2T[ZX20:>]ZP0;0:>/ZP2R[:X0XZbZ0:6/
ZP2Q[J/0XZj]0:>^Z`2QZjP0XJ^V0:2[Y@2NZZD00P2KZZ@02`1[LWD0BD]A04E7AP1IH540CeA704]@
A01OJEP0DU]?04A;A00j@3d0;C4`0080<3Ha00`0EfMA05m^D`1FHTX0De]704eC@`11ASX0J7EO096U
Q029VWd0SIb208bIP@2;V80208nNQ00;0410>@0M5aP09B8O01/H5@0=2PP02@L500/92@15CSh0Q9Yh
07jBM01fQfd00P0j?c/02`13BTD0CUI?06AbH@1cQ6d0Kh1Y04UBA@0K7A/0BEE3038g;@0[<RH09bdP
00809B`N00H092dN02D_7@0V<A`0:S<N02he800`=B4Joooooah0oh00E@000?lB0?n000P0003o203o
P0030000o`D0oh000P000?l>0?n000oooooo000=ooooo`0404IBI`19EV`0CEYb04mJM080DEeg0P1C
GgL0201DH7P0EV9h05MRN@1II7X0FV=k05URO@1II7h0FFEm0P1IIG`03P1KIgd0FfMo05]WO`1LIh40
GVV205aYP01MJWl0GV]n05i[O@1PKGd0HFmn06EcPP1XMXD0JWR70P1ZNHT0201/NHX0KgZ;071kSP1`
O900LGbA079mS`1bOXl0LWf@0P1bO9800`1dOY80MGnD07EoU@0207EoU@0:07F0U`1fP9P0Mh6H07R2
V@1iQ9T0NHFI07V5V01jQIP0NhJJ07b7W080OHNM00D0OHVM07j;W`1nRih0Oh^P08:>X`02086>Y004
08:?X`25TJ@0Qi>T08ZDY`80RiFY00X0RYFX08bHZ@2>VZX0SiZZ08jIZ@2?VZT0TIfZ096MZ@2AWJX0
TYn[0`2DX:d0302DXJd0Uj>^09RT[`2JYK00VZF_09bV[P2NZK00WjN^09nW[02QZJd0XJZ[0::/Z@80
XjfZ00/0XZ^Y0:6ZZP2QZZX0XJ^Z09n[Z@2OZZX0XJ^Z0::[Z@2PZZL0WjVV09fXY@0209f[Y00;06ee
M`14Adh0@dM703i3?P12Acl0@DLo06ajI`1CGU@0BE5<04=;AP0b=cD00P0a>3<03017DT80Dem:051J
A`1?EDH0BDm403m2>`1XMV<0T:B708RHP02<Vh@0S9V408^HPP80Sij500/0@44k01dH700U8R4071/H
01<C3`0>3`/03Pl<02T_9@1XNE`0Nhe]08>DM00205mXF00;06]fIP1aOVh0LH1^075oK@1aPFd0HFiL
03m6?@1@FdX0=3``02/b9P0W;Al00P0S:Q`01P0S:a`09RlM02H_700X<Ad0;CDP034h91[ooooo7P3o
P01E0000o`D0oh0000<0003o0?n0003oP0002P3oP0080000o`P0oh000`000?l20?n000D0003o3P3o
P00?ooooo`003Oooool01017EfT0BU]^04iNL`1AGG@2055MM@80Demf00/0E5mh05APNP1EHG/0EV5i
05MRN@1HHgT0FFEj05QUN`1KIgd0G6Mo05aXO`0205]WO`0;05aXP@1NJH<0GFZ105i[O`1PKH00H6b0
065]P01RL840IG>106UhQ01/NhH00P1]NhP02P1]NXX0KgZ;075kSP1aOI00LWb@075lT@1bOI40LWjA
079lTP1cOY<407EoU00;07N1UP1iPiP0N8:I07N1V01gPYT0N8FK07Z6VP1iQYP0NXJG07b8V@1lR9X0
0P1mRI/02`1nRid0OX^N07n<WP1oS9l0PHfP082=X@21SZ80PhnS08BAXP27Tj@0RIBU0080RYFV00/0
RiJW08bHZ@2<VJP0SIZW08fIYP2=VZL0SYZW092LY`2AWZP0TZ2X09BQZP0209BPZ`0<09FQ[02FXJ`0
V::^09VS[P2JY:h0W:J^09fW[P2NZ:l0X:V^0:2Z[02QZZ/0XZ^Z0P2SZjX0102SZj/0Xjb^0::[[P2Q
Zjd20:2/Z`050:6[Z`2PZZT0WjZW09jZY@2LZ:000P2N[:402`1fOgh0@D9;03a0@`0h?C/0?dHo04UA
A`21U7T0GVYJ04M@AP15CD@0<SHb0080<cP`00`0A4`n04]CA01?EdL0D5M804aAA@0l?ST0I6iO09BW
RP2:VX00SIf308^KP`2:VH42096RQP0504Q;@`0H4QD081hL01XJ600F5Q@00P0B50l0100F5a409RXN
059LA022UG42075oIP0;07J3K@1hQg40MhIa07F3K`1eQ700KgiZ06=`H01SLUh0>D0e02H[8@0V;Qh0
0P0S:aX01P0T;1T0:34L02Tb7@0/=R00<3PT03<i9Q[ooooo7P3oP01E0000o`D0oh0000<0003o0?n0
003oP0002`3oP0070000o`X0oh002@000?l=0?n000oooooo000=ooooo`0604UGJP1;Ffh0CUib04mM
LP1@G740DEeb0P1DH7H02P1EHGP0EV9j05EQN@1FHWP0EF5f05QTM`1HIWX0FFEk05YUO01MIgh305iX
P00;05iXPP1PJX<0H6b405m[PP1OJgl0H6b1069^PP1TLH<0J7F406aiQ01^O8D00P1_O8P00`1_Nh/0
L7^<075lSP02075lS`07075lT@1bOI<0L7fD079mU@1cOI@0LgjC07AoU00207F1UP0;07J0U@1gPYH0
N8>H07V3V@1hPYT0NHBK07R4V`1kR9/0NXJI07Z6VP1lR9/00P1mRY`02`1nRid0Oh^M082=WP21SIh0
PXjN08:>X022SJ40PhnS08>@XP24TJ80QiBT0080RYNT00/0S9RU08ZGY02;V:@0S9ZS08fKY02?VjH0
Si^W092LZ02AWJP0TZ2W09BRZ@0209FRZ`0309JQ[02GXJ`0VJ:]0080VJ>_00L0WJJ`09fV[P2OYjh0
X:V/0:2Z[02PZj/0XJ^/0080XZ^]00D0XZf/0:B/[@2RZjh0Xjb_0::/[@020::/[00409n[Z@2OZjP0
WjZV09fXX`80WZbQ00/0PHf504A7C00k@480=CLg03Xm>01@F4/0OHab06QdH018D4D0ATi3034e<002
02h_:P0<04E:?01=E4<0DEU7059JB@1?EDL0@48j05iVE`2EZ8T0RYZ008fMQ@2;Vh@0RYV20P2CYXT0
1@1HHE405Q4A01hL5`0H5Q<05ADC00804a@A00@051@A01XJ500e>b`0KWiO0P1GHD`02`1/NF00LX1W
07>0J@1dPF/0N8I`07J6L@1^Of/0KWmZ03Y1>00Y;R@0:c8S00809bhL00H09bhJ02Tb7@0[<al0;cHR
03@i9@0c>BHJoooooad0oh00EP000?l50?n00080003o303oP0070000o`X0oh0000<0003o0?n0003o
P00020000?l;0?n000oooooo000=ooooo`0604UDIP1<FFX0CE]^04aIK@1@G700Deic0P1DGgH02`1D
H7P0EV5i05IRN@1FHWP0EV5g05QTN@1IIG/0FVIl05]VO01MIgl0GFN00080GFIo00/0GFJ005iXPP1P
JX<0GVV105iZP01PKH40HVn206IcP@1]NH<0KgZ3071jP`02071jQP0<075kR`1bO8l0LGbA079mTP1c
OY<0LWfC07=oU@1bOYD0LgjG079lU@1bOID0MGjG0P1fP9L00`1eOiD0MGnC07J0T`0207N1U@0607V3
V01iQ9`0NhFL07^6V`1jQI/0OHJN0P1mR9d02`1nRY`0Oh^M082<W022SI`0PhnL08:=V`23SI`0Q8nN
08>@X024TJ80QiBT0080RYJT00/0RYJS08^HXP2<V:<0S9VS08fJX`2>VZ@0T9bU092LYP2@W:L0T9fV
096OY`0209BQZ@0:09JPZ@2GXJX0VJ6[09VR[02KXjd0WJF_09jV[`2MYZh0WJN]09nY[0@0WZZY00<0
Wj^X09nZY`2QZjL00P2RZjP01P2S[:P0XjbW0::]YP2P[:D0WZZT09fXXP80WZfR00/0QY>;04M:C`11
ADD0=SLg03Pi=P1BF4`0J7AO065[F@1EGTl0@DLo02lb;`0202`]:@0<0413=P1=Dd40DUU505=JA`1>
E4@0ATXl05YQC`2FYhL0S9^108fKQ@2;VhH0RYZ40P2>XHL02`1KI5D06ADF024P6`0N6aP071XH01DD
4P0B4@h04Q8>01HE3`0f?2X0C5Ln0080=CPZ00/0>cha06]gG`1^NfD0LGmX07R8L01iRg00LhI/0721
I`0e>c00;34V02`a900202L]7`0602H/700Y<1h0:S4N02`b800`=R@0<cPW6_oooolM0?n005H0003o
1@3oP0000`000?l0oh000?n0000;0?n000L0003o3P3oP0070000o`/0oh003oooool000gooooo00H0
Ae5W04UEJ@1<FF`0Ce]^055KL@1DGWH305=NNP0:05=ONP1DHGT0EF9h05ISN@1GI7X0F6Ek05UVO01J
Igd0GFR005aWO`80G6Eo00/0FfEo05eVP01OJ840GVR105aXP@1PK840Hg2206QePP1_NhD0L7^6071j
Q`02075kR@0<075kR`1cOHl0LWbA07=nTP1dOi<0LWjB07=nT`1bOI<0LWbD07=lU@1cOIH0M7jF0P1d
OiD02`1dOY@0MWnD07F0TP1gPY@0Mh:C07N2U01hQ9P0N8>I07Z3U`1mQIX0OHFL0080OHJL00H0OHRL
07j9V`1oRYX0PHfK08>>V`25SY`208F?WP0308J@W`25Sj40R9:R0080RYFR00<0RYJQ08^GX@2<Uj80
0P2=V:801P2=VJ<0SibS092LX`2BWZ@0TIjU096OY@80TZ2V00`0UJ6W09NPYP2HX:L0V:6W09ZSZP2L
Y:/0W:F/09^T[02LYZ`0WJR/09jYZ@2NZZT209jZZP0;09nZZP2PZjP0X:^W0:6[Y02PZZ80XJ^S0::[
X`2Q[:80X:^Q09fYW`2KZ9h00P2N[J402`29UHd0B4Y@0494A`0f=CL0>3Xi05QRE@1IHU@0FVAC05AN
C`1=ETT0>Cdi0080<3<_00`0?T@g04]D@P1AFDH0DEQ504]@?P16BS/0DUU808nRP@2=WH00S9b408fM
QP2<WXH208nRR00;05aUE`0I5AP08AlM01dK6@0J6QL051@A010B3@0A4P`04Q8;03@k:@1=FCd00P0_
<B402`0L61<0J7=L07B3J`1_Of/0MXQa07V<LP1fRVd0LhMX03Hm<00Y;BD0:BdS00809bXQ00H09RXN
02P]7P0Z<1d0;34M02ld800a=R@Joooooa`0oh00E`000?lC0?n000L0003o3P3oP0070000o`/0oh00
3oooool000gooooo00H0BUAV04eGJP1?FVh0CeYa051KL`1AG7D2059MN00405AON`1DHG/0Demi05EQ
NP80EV=k00D0EfAk05QUN`1IIG`0FfMn05]VOP0205]VP00;05]UPP1MIh<0GVR305eXP`1MJH80HFf4
06EaQ@1YMHD0KWV7079mRP1aO8X00P1aNh/01@1`Nh`0LGf>075mS`1cOY80LWfC00<0LGfB00@0LGfC
07=nU@1cOYH0MH2F0P1ePIH02`1ePID0MH6C07J1TP1gPi<0N8BD07R3U@1iPiT0NH>K07^3V`1nQY/0
OHFJ0080OXJK00/0OhNK07n9W020S9`0PHjK086>VP23Si`0Q8nN08J?X027T:80Qi2Q08RBX@0208ZC
W`0;08ZFX02;Uj00RiNO08^GW`2<VJ00SI^Q08fLX02>W:40T9jS096OY@2BX:P00P2AWjL0302EXZP0
Uj:W09RRY`2IXZP0VJ>Z09ZTZ`2KYJ`0W:N]09bXZ`2LZJX0WJZ[09jZZP80WZVX00/0X:^Y0::[Z02R
ZjD0XJbT0:2/Y02P[J@0WZ^T09j[X`2O[:80WJZP09f[WP0209f]W`0;08fKT01:CE80@4A703Lh>P0g
=cP0D5I<04iDB@1EGU00C5I804aGB@15CT<00P0e>c@03010AcX0BE=104eG@`1?F4@0Be500454>011
A3T0Rien08bNP@2:Vh40Rib408JIPP80RYj400/0HFaL01dJ7P0R82007AdL01XJ5`0G5a<05QHA01@E
3P0D5Ph09b/N05e[B`0203i2;P0;02@R701VLed0M8E^06inKP1dQG@0NHae07Z=L`1hRfl0?dHl02T]
9`0`<RP00P0];R@01P0Z;240:RhN02/`7@0]<ah0<3HQ03<g8a[ooooo703oP01G0000oa<0oh001`00
0?l?0?n000H0003o2`3oP00?ooooo`003Oooool01P18DF<0C5EX051JK`1@Fg80DE]e055LM`80DUah
00/0E5ij05AONP1EHG`0EV9k05ISN`1FI7/0F6Ak05UUO01IIW`0FfMn05]WO@0205YUO`0;05]VPP1M
Ih<0GfR405mYQ01PJX@0Hfj606MbQP1ZM8L0KgZ:07=nS01cOh`00P1cOX`02P1bOHd0LGf=071mS`1a
OI40LgjB079nTP1`OI00Kgb@075oTP1bOY<207AoU@80LgnC00X0MH:C07F1TP1ePI80MX:B07N3U@1i
PiT0NX>L07Z3WP1mPih0OhJM0`20Qi`02020RI`0P8ZL082:W020S9/0P8jK08:?W024Si/0Q8jK0P27
T9h03P28TYh0RYFP08ZEX02;UZ40S9RR08^HX02:Uid0S9VM08fLX02>Vj40Si^S08nLY@2AWZL0TYnY
0P2AWjP0102CXJT0U::Y09RTZP2IY:/209RSZ`0609VT[02KYZd0W:R[09bXZ@2NZZX0WZVX0P2NZJL0
2`2PZjH0XJ^S0::/X`2R[:<0XZfS0:6]Y02O[:<0WZ^R09f[X@2NZj00WJ^M0080WJbL00/0TZ6D04a>
DP0n@DH0=SPm034a<`1?EDX0BTm504U>A@16CT80BeI804MB@`0203@k<00<03Y3=@18Dch0BUDn04]F
?@17CST0>cd`03<d:`20TG@0SJ2208ZKP@2:W8D0QIR30P28W8D02`1[NVT07alS02@S8`0Q81h07QhH
01/K500J6Q<05aTA01TJ4`0P91X0;cDW0080;c8X00/0@4Pj0763J01eQfh0LH9^07B5L@1iS7D0O8if
07f?M@18D4D0:bdX03@g;@0202la9P0602/]8P0Y;1h0:2dM02`a800_=2<0<CLU6_oooolK0?n005P0
003o4`3oP0080000o`d0oh001`000?l;0?n000oooooo000=ooooo`0604UAI01;DfL0CUQ/04mIL01@
FW<0DE]f0P1AFgL02`1CGGX0EV5l05IRO@1FHWd0EF9k05IRO01HI7`0FFIl05YVO@1JIG`0FfQm0080
G6Qn00/0GVV0061YP@1PJ800Hf^406A/Q@1TKXD0Ig:606QcQ`1]N8X0LWj=07J2S`0207R4T00<07J1
S`1dP900M7nB07=oT@1cOi80LgfB071kT@1bO980LgnC079oTP1bOY80M82D0P1cOi802`1eP980M82A
07F0TP1gPi@0MX:D07N2U`1hPYT0NX>K07b4W@1nQYh0OhRN0080OhRM00P0OhVM086;W`21S9l0PHfO
082=W`21SYd0Q92M08F@W@80Qi6O00h0R9:P08VDXP29U:80RYJS08^GY02;V:<0S9RR08bIX02>Vj80
Si^S092KY@2AW:P0TYjZ09>OZ`80Tj2[00`0UJ2/09FQZ`2GXj`0V:B/09ZT[02JYJ/0VJBZ09ZUZ`2L
Z:/0WJVY09nZZ@2PZjP20::/Y`0;0::[YP2RZj<0X:^Q0::/X02S[Z40XJfQ0:6]XP2R[J80X:^Q0:2[
XP2P[:000P2OZi`02`2JZ9P0EEMI0452AP0k?T00<S8d04U>A01>DdH0BDi304Q>@`1?FT/0@d`o0080
<CH/00`0=C/^055NA@1>FT40CEHn04Q>>@0n@C<0<2lZ07R6KP2?XHD0RY^308fNR029VXD208^MQ`0;
07n?O00Y:Bd08R0R024O7@0Q81P07QdC01TI3P0D5@`05QL>020T600Q91X00P0O81X02`0Q8ah0K7eR
07J9K@1aPFX0N8Q`07f=M01nT7H0Q9Eh05INCP0_<2T0>3Xa0080<SH^00H0;C4Y02X]900W;1l0;34Q
02le9@0b=bPJoooooa/0oh00F0000?lC0?n000P0003o3@3oP0070000o`/0oh003oooool000gooooo
00H0Ae5U04UCJ01<F6/0CUU]04mJL01@FW<2055KMP0:059LN01CGGT0EF1k05IQO01EHG/0EV9k05QT
N`1HIG/0FFEj05UVNP<0FVMj00/0FfMl05eXO@1NJGd0HVb206=]P`1TL8<0IW>506IcQ01YMHH0L7j<
07J5T00207R7T`0<07N4TP1ePi80M82B07=oT`1bOY@0LgfE075mU01aO9<0LGnD071nT`1`OY80LWjB
0P1bOY4307F0T@0807N3T@1hQI80N8BD07R3UP1jQIT0OHJK07Z4V`1kQYh207Z4W@0;07^6W@1nRJ00
P8ZO082:X021RZ00PhbQ08B>X024Sj00QXnP08F@WP25TIl00P26TZ002`27Tj40R9BQ08ZFX`2<V:D0
SIZT08fKY@2?W:H0T9fV096MZ02BWJX0TYj[0080Tin[00`0UJ2]09JP[02EX:`0V:>^09ZT[P2JYJh0
VZF/09ZV[02LZ:/0WJVY0:2ZZ02QZjP20::ZZ00;0::[Z02RZjD0XJ^S0:6[X`2P[:80WjbS0:6/Y02R
[JD0X:bT09n[Y02OZj<00P2LZYh02`2L[9`0GV9Q04A5B@15ATH0=SDg03m1?017Bd00C59404eFA`1B
GDd0BeI80080=Shd00`0=cla05YYC@1GIDX0D5]404eD@016BS`0=SLc071lJP2DYhh0RYV408bKQ`29
V8H208bKR00;08FCP00/:S408AhS02<R7`0P81L07AhB01/K3P0C50X04aD;01lR5`0Q9Q`00P0S:Ah0
2`0E5A40GVaD07J8J`1]OVH0N8Q_07j?M021TWL0PI=f05=JB`0d=Bl0>Sdd0080=S/`00H0<3DY02/`
8`0Z;R00;S8Q03<g9P0c=RHJoooooad0oh00EP000?lC0?n000P0003o3P3oP0060000o`/0oh003ooo
ool000gooooo00H0ATmU04UCJP1<F6h0CEU_04iIL@1@FW<2055LM@0;05=MM`1CGWL0EF1i05MTN`1F
HWX0EfAk05UUN`1HIGX0F6Ai05UVNP1JIgX00P1KIgX02`1JIg/0G6Ql05iYOP1PJX40I6n606EbQP1V
M8<0IWB106MeP`1/NhL0LH:=0080M8FA00`0M8BA07>1T01bOhl0LGf@075lT`1bOYD0LWjF071mU@1b
OiH0LWnE079nU@1cOi@207=oT`0;07F1TP1fPY40MhBA07N4T@1iQY40N8B@07R3T@1jQID0O8JH07^6
VP1kR9d00P1kQYh0101lR:40OXVR07j9X@1oRZ4208><Y00508B=Y026Sj@0QXnS08JAX@26TZ000P27
Tj402P28UJ<0RYJS08^GY02;V:@0S9VV08ZHYP2:VJD0SI^U08nMY`2AWJT3096NZ`0<09:NZ`2CWj/0
UJ6]09JR[P2HY;00VZF`09ZV/02LYk00W:J]09bWZ`2OZJ/0WZRZ0P2OZJT02`2PZZT0XZ^X0:>/Z@2R
ZjX0XJbY0:2/Z@2Q[:T0X:bX09n[Z02PZjT0WZZV0080VZRQ00/0Vj^O06E/JP11@TL0@TE303@d=00n
@C`0AD]204eFBP1AG4h0Dem@04iKC00203e:?00<03Y6=@1JK500FFQ<05=PAP1<ET00@TLj03Xk=`1e
Pfl0UJR=08^KQP2;VXP0R9J50P2;VXH02`24Th00;R/b020K8`0S8B407QhG01XJ400H6@d051H;01TK
400W;240;cL/0080;SDZ00/0:BhU05aZE01cQF`0KWmX07B5K@1kS7<0Oi1g082CN01?F4`0=CTb03Y1
=@0203Dk;@06030f9P0]<R80:c0O02ld8P0c=RD0<cLU6_oooolM0?n005H0003o4`3oP0080000o`h0
oh001P000?l;0?n000oooooo000=ooooo`0604MAIP19E6X0BeI]04eGL01?FW<0DEaf0P1BG7L01`1C
GGP0E5ii05EON@1FH7P0EV5i05IQNP1GHW`00P1HI7h03`1HIGd0FFIl05YWO01JIg`0FVEl05aWO`1N
JH40Gf^306A_Q`1ULXP0IWB706IdQP1WMHH0J7J706]jR@0206inS00<071oS`1bOi00LWnA079nTP1b
O9<0LGbD079mU01aO9D0LgjF07AmU`1bO9H0LgjF0P1cOiD02`1dP9D0MH6C07R5T`1iQI<0N8BC07N4
TP1gPi80N8BD07V5UP1kQiT0NhRL0080O8RM00@0O8RN07^7W`1lQZ00OXVQ0P21Rj<01@23S:@0QXnU
08J?X`27T:00R9>P0080RI>Q00X0RIBQ08RDX@29UJ<0RIFR08ZFX@2:UZ80RiNT08jIY@2@VZH0TYfX
0`2CWJT0302BWJT0TinY09JQZP2FX:/0Uj2^09RR[`2IXk40VjFb09fV/02NZ;00WjV_09jX[@80WZV[
00/0X:ZZ0::[Z`2R[:`0XZb[0:2/ZP2P[:P0WjZW09jYYP2NZZL0WZ^W09bYY00209VWW`0;09b]W`1a
Ng<0?3i003e1?@0_<Bl0@dU004]DB@1<ET/0EF=D04mMC`0oBSh00P0e@3@0300b>bl0FF]@05Y[CP1B
H4H0BeM003Lm<00c=Bl0MXI]09F[S02:VXD0RiV808ZGQ`80RiZ800/0Pi6003<b=P0K5Qd07a`O01/J
600K6A@06QTC01LH400L7Q@0;C<V04A??@0203Ho<P0;04YGA`1PL5`0KX1Y0763J`1cQFl0MXQd07Z<
MP1kSWL0DUiA03Lm=@0i@3<00P0d?2h01P0`=RH0;S@R02`b8P0]<b80<SPV034g9A[ooooo7@3oP01G
0000oa80oh0020000?l>0?n000H0003o2`3oP00?ooooo`003Oooool01P19DfL0BUI[04aHKP1>Efl0
CeUb059MMP80E5ih00X0Deai05EMN`1FGgX0F61i05MQN@1HH7T0Ef1j05URO@1HHWd0F6An0`1IIGl0
2`1KIX40GFN305iXQ@1OJXH0HVj906AaRP1XMH`0J7J<06UfS@1YMX/0JgR;0080KW^=00P0L7b?075n
TP1`OI80LGfA075lT01aNi80LWbC07=lUP<0M7fI00h0LgfI07AmU`1dOIL0MWnG07J0UP1eP9@0Mh:E
07J1U@1gPiH0N8BF07V4U`1iQIL0NXJI07^8V`80O8RM0P1nRYl02@1nRJ00OhZR07n:X@20Rj40PXfQ
08>?X025Sj00Qi6N08RAWP0208VDX00;08VDX@28Tj00RIBQ08ZFXP2;UZ40S9JR08jHXP2?VZ<0TI^T
09BMY@2DW:H00P2EWJL0302EWZX0U9j[09BPZP2EX:/0V::]09VQ[P2JY;00VjBb09^T/02NZ;40WjV`
09jZ[P80WZZ/00/0WjV[0:6[Z`2PZZX0X:ZX0:2[Z@2R[ZT0X:fV09n/Y@2OZj@0Wj^S09fZX@0209^Z
W@0;09b]W01cOW<0>cdn03e2?P0`<C00@dPn04iHBP1AG4d0Df1@0459?`0c>S400P0X;bP0300W;RH0
FFYA05]_D`19FD<0BEI0034f:P0];bP0L7eW09FYR`2:VH<0SI^808fIR080S9^900/0Q9B303Hg>P0H
4aX081dN01hL600O7AL071/F01HF4P0H6140;c@W05m]E00205UUD@0;04YDA`1HIEL0LHE_0763KP1b
Q6l0LH9_06j0K01bQfh0Df1>03Dj<00h?S000P0e>bh01P0a=bT0;cDU02hd900^=B@0<STV034h91[o
oooo6`3oP01I0000oa80oh0020000?l>0?n000H0003o2`3oP00?ooooo`003Oooool01P19DfL0BUI[
04aHKP1>Efl0CeUb059MMP80E5ih00X0Deai05EMN`1FGgX0F61i05MQN@1HH7T0Ef1j05URO@1HHWd0
F6An0`1IIGl02`1KIX40GFN305iXQ@1OJXH0HVj906AaRP1XMH`0J7J<06UfS@1YMX/0JgR;0080KW^=
00P0L7b?075nTP1`OI80LGfA075lT01aNi80LWbC07=lUP<0M7fI00h0LgfI07AmU`1dOIL0MWnG07J0
UP1eP9@0Mh:E07J1U@1gPiH0N8BF07V4U`1iQIL0NXJI07^8V`80O8RM0P1nRYl02@1nRJ00OhZR07n:
X@20Rj40PXfQ08>?X025Sj00Qi6N08RAWP0208VDX00;08VDX@28Tj00RIBQ08ZFXP2;UZ40S9JR08jH
XP2?VZ<0TI^T09BMY@2DW:H00P2EWJL0302EWZX0U9j[09BPZP2EX:/0V::]09VQ[P2JY;00VjBb09^T
/02NZ;40WjV`09jZ[P80WZZ/00/0WjV[0:6[Z`2PZZX0X:ZX0:2[Z@2R[ZT0X:fV09n/Y@2OZj@0Wj^S
09fZX@0209^ZW@0;09b]W01cOW<0>cdn03e2?P0`<C00@dPn04iHBP1AG4d0Df1@0459?`0c>S400P0X
;bP0300W;RH0FFYA05]_D`19FD<0BEI0034f:P0];bP0L7eW09FYR`2:VH<0SI^808fIR080S9^900/0
Q9B303Hg>P0H4aX081dN01hL600O7AL071/F01HF4P0H6140;c@W05m]E00205UUD@0;04YDA`1HIEL0
LHE_0763KP1bQ6l0LH9_06j0K01bQfh0Df1>03Dj<00h?S000P0e>bh01P0a=bT0;cDU02hd900^=B@0
<STV034h91[ooooo6`3oP01I0000oa80oh0020000?l>0?n000H0003o2`3oP00?ooooo`003Oooool0
1P17DFP0B5E]04aJL@1=FVl0CUY`04mJL@80D5]c00/0Deeg05ANN01CGGH0EEmf05IQM`1GHWP0Ef5h
05USN`1II7`0FFEm05YVP@0205UUP00;05]UP@1LIh@0GVR6061[R01SKXX0I76;06MdS@1YMXl0JGJ>
06UfS@1[Mh`00P1]NXd0301_Nhh0KgfA06mlTP1`O940L7b?079nTP1bOI<0LWfE07=mV@1bO9P0LgfH
07AoV080LgfG00/0MGjF07N0U@1dOY@0MGnD07F0U01gPYD0N8JH07R5V01kQY/0O8NM07f8WP0207^8
WP0307j:W`1oS9l0OX^N0080Oh^P00H0P8bO082>W`21SYl0Q8nO08J@WP28TIl208RBX080RIFP00T0
RIFR08^HY02<VZD0S9VT08fJX`2?W:<0T9bS09:MX`2CWZD00P2DWjP0302DWZ/0Tin/09BQ[@2EXJh0
Uj:_09RS[`2IYJl0VZ>`09ZT/02MZ;00WJR^09fZ[@80WZZ^00/0XJ^_0:6Z[P2QZZ`0X:ZZ09n[Z@2P
[:T0X:fX09n]YP2P[:D0WjbS09j[X@0209^[W@0;09^/VP1dP7@0?dA30497@`0f>CL0@4Ln04mJC01@
G4h0DemA0419?`0h@3D00P0a>Bh0300]=2T0CE]505IWC016DSh0B5E003<i;00_<BX0KGUU09:SR029
V840SIf708nNRP80SYf900/0QIJ203Li>`0J5ad08R0Q01`K6@0K6QH06ATE01DF4P0J7QL0:C4T0725
I@0206]nHP0;06MhH`15CTL0Ni5i07:8L`1RM680?d]2045>@`1[PFD0EfI>034g:P0h?Rh00P0f>b/0
1P0c>2P0<CLU034g900c>BH0=3`W038k9Q[ooooo6`3oP01I0000oa80oh0020000?l90?n000@0003o
00<0oh000000o`000?l00`3oP0000`000?l0oh000?n000090?n000oooooo000=ooooo`0604ECJ016
EF/0B5Q^04UIK`1;FVh0CEY`0P1?G7802`1AGG@0DEie059NM01CH7@0E61d05EQM@1FHWP0Ef=j05MT
O01HIGh0FVN10080F6J100L0FVJ105YWP@1LJ880GVV4069_R@1TLXX0IG>;0080IgF<0100IW>:06Yg
R`1/NH/0K7V;06ilS@1]Nhh0L7fA075mT`1_OI<0LX2E079nU01`OI@0L7fF071lUP1`OID0LGfD0P1b
OY@02`1cOI@0MH2D07F1U@1cOi<0Lgn@07F3T`1fQIL0MhFH07R6VP1jQid0O8VO0080NhNO00/0NXNN
07j:W`1nRid0OX^M07j;WP1nRil0OhfO082=WP23SYl0QY2P08F@X00208FBX00;08JDX@26UJ40QiJS
08VHY029VJ@0RiZU08bJY@2=Vj<0T9^T092LY02AWZH00P2AWjP0302BX:`0TZ2]09>Q[P2DX[00U:6_
09JS[P2HYJh0VJF^09^W[P2KZ:h0VZR]09ZX[080W:R[00H0WZZ]09nZ[P2PZjd0Wj^[09n[ZP2NZjT2
09j[Z00309f[Y`2LZj@0W:^Q0080V:RO00/0VZbN07^9P014BT`0?dA503Tl?P0k@Cl0ATm704]HC@1E
He@0BeM903a7>`0203Lo=@0<03@h;P0h?c00@D/g03Y2<00oB3H0>3ha02l`:`1PJET0TZB808RFPP2<
W8T0SYn>0P2=Wh`02`27VHL0>Cdo01@@6@0M71h05aDF01DD4P0E5Q404Q@@02DZ8P0_=b/0GW1F0080
KhEW00/0HgAO04E>A`1jSWT0MXaf05UYF`0F6Qd06QhM03a6=P19E3l0=3T[03Ll;P0203Hk:`0603@j
:00b=bD0=3XU03Hk9`0f?BP0=3/X6_oooolL0?n00080003o00<0oh000000o`000?l0D`000?lC0?n0
00L0003o2P3oP0020000o`80oh000P000?l?0?n000oooooo000=ooooo`0604QFIP19EfX0BeU`04YH
L@1<FG80C5Yc0P1>Fg800`1@G7@0D5if059NM@02059NL`0605=NL`1EHGH0EV9i05MTO01GI7d0FFEo
0P1IIH002`1HIGl0FFIn05UWO@1LJGl0H6j406=aQP1SLXL0IGB906MeR`1XMX/0JWN;0080JgN<0P1]
Nhh02P1`OI40LGjC071nU01_OI<0L7jB06imT01^O940KgfB075nT`1aOY820760TP0;07:0T`1dPI@0
Lh2E07:0U01bP980M8BD07J5U@1gQYT0MhJK07R5W01hQY/00P1kQid01@1jQid0O8RN07f9W`1lRIh0
OH^N0080OHZM00@0OhbM086>W@23Sil0PhnP0P24TJ4208BCX@0908FEXP27Uj<0RIRT08ZJY`2=VZP0
SY^V092KYP2?VjL0TIfZ0080T9j[00X0TIj]092P[P2@X:h0TZ6^09>R[@2CXjd0Tj>/09JT[02HYjd0
VJR]0P2JZJd209b[[@0;09bY[02NZJd0WjZ]09jZZ`2NZZP0WZ^X09jZY`2MZjL0VjZW09ZZY@2JZZ@0
0P2HZ:402`2JZj40NXJ204]?E00l@4H0ADa:04I=A`10Ad40D5a@05ERD`18DT@0=S`c0080<cL_00`0
;c<Y02/`900[<240:c0O034f9@0h?Bd0<C<Z069/F@2@XXD0QiF108ZIQ`2:W8X208VLR`0;08:DQ@0a
=3T05Q<L01XI7@0E51@0518?01DC3@0C4Ph09b/R030c:@1OK5D00P1gRVh02`1XMf<0Hg1S0720L@1g
RgT0DV1D00h@5@0F5aX04Q4A02DX800_=2H0<SHY0080<cTY00H0<STW038h9P0d>RH0=S`Y03Ll;00e
>B/Joooooad0oh00E`000?lC0?n000L0003o2P3oP0030000o`030?n000000?l0003o00l0oh003ooo
ool000gooooo00H0Ae5S04UDJ@1;EW00C5Mc04aFL`1;EW4204eIL`0;04mKM@1@G7D0DUef05=OMP1C
GWD0DUid05=OMP1DGgL0E65j05ESO01HI7h00P1II8002`1HI7l0FFIo05UWOP1KJgl0Gff2065`PP1T
LhD0I7>606MeR01XMXX0JGN;0080JWN;00`0KW^>075oT@1cP9<0Lh2E071nU01^OI<0KWfA06elS`1^
O8l0L7b@075lT01aOI4207>0T`0;07:1T`1aP980LX2D07>0U@1dPID0MX>E07N5UP1hQIT0NHFL07R3
V`1hQ9T00P1jQiX02`1lR9`0OHVM07j:WP1nRIh0OHVN07n;WP20SIh0P8fM086?W`22T:00PY2Q0080
Pi6R00/0PY6Q08>CX@25U:80QIBR08NEX`2:V:H0SI^V08jLYP2?VjH0T9bX08nLZP0208nM[00<08nN
[P2>W[00Sin`092O[P2DXjh0UJB/09JS[02EXj`0V:J]09VX[@2LZJh0WJV]0P2NZZd209fY[00909fX
[02NZJ`0WZVY09jZY`2MZZL0WJZX09bZY`2JZJD0VJVS0080UjRP00/0VZ^R07^6P`19C5<0@4A80416
A00m@c`0<SH_04QB@`1JIe<0Dei<03Y0=`02038g<00<02lc:`0^<bH0:S0P02H[6P0Z;A/0=cTW03@d
:P1PJEL0UZV;08ZJPP2<WHL0Rib70P28VHD02`23UH80=3Pi01DC6P0K6Q`061LG01LG500G5Q805A@@
020Q6@0X:Al0HFeC0080MXMZ00/0KgiV07>2K01bPVh0NXeh05QTF@0A4AT04@hD00l:3@0P7QP0;c8U
034d9002038f900603@j9P0d>BH0=3XV03Dl9`0f?B/0=S`^6_oooolM0?n005L0003o4`3oP0070000
o`X0oh001P000?l?0?n000oooooo000=ooooo`0404I?I019DVT0BeE_04aELP@0CEIc00/0D5Yf04mK
MP1AGGH0Deif05=OMP1CGWH0DUeg05=ON@1DHG/0Df5k05QTO`0205QUO`0;05UVO`1IIX00FFJ005]X
P01NJh00H6eo069`PP1ULhD0IWB506MeQ@1XMXL00P1`Ohh02@1kRYP0OXfM07b:W01fPiT0L7fF071m
U@1^OI<0KGbB06mlT@02075lT@0407=mTP1cOi<0LgnC07=oTP80Lh2A00P0M82D07F1U01gPID0Mh:E
07N3U@1hQ9L0NHBH07V5V@80NXJJ00/0NhNL07b8W@1lR9l0OHRO07n:WP1oRih0P8bL082=W@22SZ00
PhjQ08B?X@0208FAXP<0QI:R00P0QYBS08RFX`2;Uj<0SIVS08fKY02>VjD0SibW096MZP80T9f/00`0
Sif^08nM/@2@Wk40TZ2_09FR[P2EXjl0UZB_09NU[P2HYJh0VZN]09bX[@2NZ:`209nYZ`0609jYZ@2N
ZZP0WZVY09jXZ`2NZ:X0WJVY0P2NZZT00`2MZZT0W:ZV09ZZY00209RXX00;09VZW`25ThX0ADQ=0415
AP0d>3P0;S8`02@U8`0k@SL0GfeG05UUD01;ETH00P0oASX02@0h?C80<cP/02hd9P0]<R<0CePo0454
=00g>340DeU>09BWS00208ZLQ@0>08^LQP28V880R9R208NFP@15B4D05Q8J020O800M7Q/071hI01XK
5`0G5a<05QH@02@W6P1GHTP207^>J`0;0721I@1dQ6/0MXE]07N7L@1eQ740=STi01`J7@0O71`08R0J
030a8`0a<b800P0c=b@01P0c>2D0=3XV03Dk9`0e?2P0>3h/03Ll;A[ooooo7P3oP01F0000oa<0oh00
1`000?l:0?n000L0003o3P3oP00?ooooo`003Oooool01P18D6<0BU=Y04]EK`1<EG40CEIe04mHM`80
CeQe00/0Ce]f055LM`1AG7H0Deef05=NM`1CGWP0Df1j05EQO@1FHGh0Ef9o05QUP00205MTP00;05QV
O`1IIWl0EfAn05YWP@1LJ800H6b1061]P@1SL8@0IG:606IdQP1/NXd00P1iRY/02`22U:<0QYNW082>
X`1hQ9d0LGjH071lU01_O940KG^@06ikT01^Nhl0Kgb@00<0LgjB00/0LgnA07B0T`1dP9<0MH2D07B0
U01fPID0MX:E07N3U@1iQIL0NHFH07^8V`0207^7W00;07^8W01lR9`0O8RO07f8X@1mRZ80OX^Q07j;
WP20SIl0PHfP08B?X@24Sj<00P25Sj<02`26TJ80R9>R08RCX@29U:00RYJQ08bJX`2=VJ80S9VS08fK
Y02?W:H0TIfY0080T9b[00`0Si^/096M[`2BWk00U:6_09FQ[@2FXjd0UjB]09RU[@2IYZd0VZN]09bX
ZP2LZ:T209jYZP0;09nZY`2NZZD0WZZW09nZZP2OZZ`0WZZ/09j[[02MZjX0WJ^X09b[Y@2LZj@00P2J
Zj802`2JZil0Sj2B04M;C`0k?d00;c4b02X];@0T9BH0=3Td05i/F@1HIE80EfAB0080CUY900`0?DDg
03Dk;P0^<bL0;30V06akGP13B3X0>S`f04a@B02>WhH0SYn808bMQ`2>X8T208ZKP`0;08VJP01AETh0
6aDL02<Q8`0M71`071/J01PI5`0G5aD05aPC028U6`1@G4D00P1oU7402`1bPfP0M8E/07J6K`1eQW00
MHQa06emJ01EHE40FFIA04UD@@0d>2X0>ch[0080>3/Y00H0<CDU038g9P0c>RT0=3`Z03Lo;@0g?RhJ
oooooal0oh00E@000?l?0?n000040000o`3oP000oh000?n000L0003o2P3oP0080000o`d0oh003ooo
ool000gooooo00H0A4iM04M@I01:DV/0BU=_04aEM01>EWH204iHMP0;04iIM`1@FgP0D5]h051LN01A
GGP0D5ai055LN@1DH7/0E5ml05MRO`1II8000`1HIGl02P1HIWl0F6In05]XP@1MJH<0GVZ305m/Q01S
L8L0I72806I`R@1_OI<207b<X080P96T00X0O8^P07N3VP1dP9P0LWfD075lT01_Nhh0KWZ>06ajSP1/
NXl0Kgb@0P1aOI002`1bOI40LWjB07=oU@1eP9L0MX6H07F1U`1gPiL0MX:G07J1U`1fPYP0N8BI0080
NHFL00@0NHJM07^8WP1lR9h0O8VO0P1mRJ401@1oRil0OhfP082=X022SYl0PhfP0080QI2S0P27T:D0
2@27TJ<0R9>Q08RCX029UZ80RYNR08^GX@2<V:80SY^T08nKYP0208jJY`0:08nKZP2?Vj/0TIf]09>O
[@2CWjX0TYnY09>QZ@2DXjX0V:J[09VWZP80VJNY0P2KZJT02`2MZJL0WJVV09bYYP2NZjP0Wj^Z09fY
Z@2KZZT0Vj^X09ZZYP2JZZ80VZZQ0080VJVN00/0VJ^L092ST`1>EeH0?D91034d<P0/;B`0:b/[03@g
<P1KJ5H0F6ED05IRDP02059NC00<04E??`0h@340;cHX02``900d>2X0<c@Y03Dd;P19Bd@0T::8096R
R`2>WhT0T::;0P2;WHH02`2;W8<0G6AG01XD6P0T8B807Q/L01XI600G5QD05aLD01XI5P0Q81/0ATdm
0080Q9Uf00/0M8I/07B6L01dQG<0M8Ab07>5K`1eRFl0MHU^07J9K01ULe/0>Cd`03m3<@0203Pk:`06
02lc9@0^<bD0<CLX03<k:00f?bX0=3/X6_oooolO0?n005D0003o4`3oP0070000o`X0oh002P000?l;
0?n000oooooo000=ooooo`0504A?G@17DF<0BUEZ04]EL01=EgD00`1<EgD02`1;EgD0C5Ug04iKN@1>
FgP0Ceeh04iLM`1AGGP0DUii05AONP1EHG/0EfAm0080EVAk00/0EF=l05IUOP1GIGl0F6N205YXP`1K
J8<0GVZ4069^Q`1SKhP0IG2:06]fT@0207F1VP0907R6WP1hQid0M8>H07:0U@1aOI@0L7^B06mkT@1_
Ni80KGZA0080KGZ@00<0KWZ@071lT@1`O9400P1bOI<02@1cOi@0M7nF07AoV01eP9P0MH2G07B0V01e
PIT0MhBK07R4V`0207R5V`0;07R7WP1jRJ00NhVP07Z9X@1kRJ00O8ZO07j<W@1oSId0P8fN08:?W`24
Sj000P26T:@02`27T:H0QI2W08F@YP26TjH0Qi>T08NDY028UjD0RINU08VHY02;VjD0S9ZW0080S9ZX
00`0S9ZY08jJZP2@Vj/0TYj/09:OZ`2BX:X0T:6Y096RZP2CXjT0UJJX09NVZ@2IYjX209^YZP0;09bY
Z02KZ:H0W:RW09jZY`2N[:T0W:^Y09ZZY`2KZjL0Vj^U09VYXP2IZIl00P2GZI`02`2GZIT0TjNF05MQ
G`15C4`0=CTj030b<@0f>CD0?44j05MSD`1GIE@0EV=A0080DEa;00`0B5A303U3=P0/=2T0;34V02/^
900Y:B40:2DQ03ln>@2HZHh0VZbC08nOR`2>X8/208bORP0;08fNRP1[MVP07AXO028S8P0L71/071`H
01TJ4`0I6Q405aD?01lN5`12B3P00P29WW`02`1dQVh0LhAb07:2MP1cQ7L0LXEb07:9K`1bRF`0MH]/
05e[E@10ASX0?dHi0080>3ha00H0<cT/030e:P0a=bX0=C`/03Lo:`0e?2XJoooooal0oh00E@000?lC
0?n000P0003o2@3oP00:0000o`/0oh003oooool000gooooo00D0@diP04MAIP19E6`0BeA`04]FM003
04UFL`0;04aIM01<FGD0CEUf04aIMP1=FgH0Ceaf051LM`1BG7T0Deij05AQNP1DHW/00P1EHW/02`1D
H7X0EF=l05ETO`1GIX40FFN205]WPP1MJH<0GV^4061]QP1RKXP0IG2:0080JGJ=00`0KW^B06mmT`1^
OI<0KG^C06ejT@1^Ni<0K7VB06]hT`1ZMY80JgN@06eiT@1^NY4206eiT@0606ijTP1`Ni<0LGfD075n
U@1bOYL0LgjH0P1dOiT00`1ePIT0MX:J07N4VP0207N4V@0307R6V`1jRIl0NXVQ0080NHVO00H0NXZM
07b:W01lRi/0O8ZL082<WP23Sj0208B?XP80Q96U00D0Pi6T08FCY@26U:D0QiBT08NEY@0208VGYP0@
08^IY`2<VJL0RiVX08^IZ02=VJT0SiZ[092KZ`2CWJd0UIn]09FQ[@2DXZ/0Tj:[09:QZ@2EY:/0UjJ/
09VV[@80VZN/0P2LZ:/02@2NZ:X0WjVX09fZYP2LZZH0VZZU09ZYYP2IZ:<0VZVS09ZZX@0209RXW@0;
09JWV@2DYiH0FVEQ04I=C00`<SH0;c8b03]1?010B440FFEF05UVEP1GI5@00P1AG4d0301?Fd/0ADm3
02da;00`<bh0;2dX02LT8@0S71h0>3@c09f]T@2R]9T0TZ6<092PS080Sij:00/0SYn:06ahJ@0M7200
8b<S01dN6P0M7QL06AXA01LG3`0F50l08b8J04aB@@0208nUP00;07>7KP1`QG40Kh=h06YoM`1gTX40
FG1O05mfH@1[PFT0F6EF03m8@00nAC/00P0g?S<01P0b>Bd0<3L/030e:`0d>Rd0=cd]03<k:A[ooooo
803oP01D0000oa<0oh0020000?l90?n000L0003o0P3oP0000`000?l0oh000?n000090?n000oooooo
000=ooooo`06049>H`15D6L0AU9/04YDL01:E7<0B59c0P17DW<01@18Dg<0B5Ac04]FM01=FG@0CUYe
0080CeYe00@0CeYg055LN@1CGg/0Df1k0P1DH7X02`1CGgT0EF5k05IROP1GIH00FFJ005]WP@1KIX00
G6R105iZP`1PK8@0HVn50080I7:700`0IgF906UgR`1ZNHh0JgZA06]iTP1/N9D0JWFD06UeU01[MYD0
JgJB06]fT01/Mhl206ehT00806miTP1aNY<0LG^C07=mU@1cOi@0LWjF07:0V01cP9L207F1U`0>07J1
V01fPIT0MX6I07J2VP1hQ9`0N8FK07V6VP1jQi/0NhNK07b8V`1mRY/0OHZL07j;W`21SJ42086>X@0;
08:?X`23T:<0Pi2S08>@X@24TZ80QI>S08JCX`29UZH0RYNW08ZFZ02:UjP00P2;V:T02`2<VJT0SIVY
08nJZP2CWJ/0UIjZ09BPZ@2CWjP0U:6[09FQ[P2GXjl0UjB^00<0VJF^00/0VZF/09^V[02MYj/0WJNX
09bWY@2KZ:@0VjRU09ZVY02KYj<0VjVQ09ZXWP0209RWW00;09JVV@2BY9@0E5eK03Xn@@0^<3@0;C0`
03To>00nAS`0G6YH05YVEP1HHU<00P1BFdl0301?Ed`0CeM;03m3?00f=c@0:bPX02HP8P0S6Ql0=c8c
0:2`U02T]IX0Tj>=092PS@80SYj900/0SIn706McI@0H5a`0824Q01`N6`0I6aD061T@01LH3`0F5Pl0
7R0G04A>?@0207jELP0;06Z0I01ZP6L0LHMb05QXH01aR7P0JGi/03m;A01[OVX0Df1D03e4?P0l@cX0
0P0e?C801P0b>Bl0<cX^03<i;@0e>Rd0=S`]03@j:1[ooooo8P3oP01B0000oa<0oh0020000?l90?n0
00D0003o00D0oh000000o`000?l0oh000000o`0;0?n000oooooo000=ooooo`06041<I@12CfP0AE5]
04QCL01:Dg<0BU=d0P19Dg@02`18E7<0B5Aa04YDK`1;EVh0CEU`04mKL01>FG00D5]d051KM`1AG7T0
DUij0080Demj00/0E5mj05IRO01GHgd0F6Ao05UUP01JI840FfJ305eXP`1NJH<0HFf5069^Q002069_
Q@0<06AbR01VM8T0IWB;06MfSP1XM900J7BA06UeTP1ZMI<0K7JD06egT`1[MY80JgNA0P1^N9402`1^
N900L7ZA075kTP1bOI@0LWfC079nU01bOYD0LgnE07J2U`1gPiL0NH:G0080NhBK00@0NH>M07N2V`1g
PYX0NXFJ0P1lQiX01@1lQYX0OhVL07n:W@1oRYh0PH^P0080P8^P0P22SZ402@23T:40Q92P08BBX024
TZ00QI:Q08RDX`2:UZD0RIJW08VFZ00208^HZP0508^IZP2<VZX0T9^[096LZ`2CW:X00P2CWJT01@2F
X:/0Uj6]09RR[@2IXjd0VZB]0080W:F]00/0VjB/09^VZP2KYZT0VZJW09ZXY@2KZ:@0VZNT09VUXP2J
Yj40VZJO09VUW00209RVV`0;09JVV@2AXI<0DUQH030b>@0d=cT0;c8a034d;@11B3X0GV]D05USC`1B
FDX00P1:CD@0301:C4@0E5Q>04U:A00o?Sd0=S<e03@^<@0`:Bd0@clo09JTS@2O[YH0UJF@092PSP80
S9f:00/0RYj806MeI`0J6R008B<T01TJ6P0I6Q@061L?01PG3P0G60h08bLJ030i:`0204IC@00;05a^
EP1VO600FFaD05QZD`1SMUh0TJ^805ITE@1CH5@0D5mB02`b;P0f>c<00P0f?3001P0e>Rl0=C/`03Lm
<00h?Bl0=c`_03<i:a[ooooo9@3oP01?0000oa<0oh0020000?l@0?n000030000o`3oP000oh0000/0
oh003oooool000gooooo00H0@D]T04==J018DVd0BUA`04YDL`1:Dg<204YDLP0;04]FLP1;EG00BeE_
04]FK`1<F6h0CeY_04mJL01AG7@0D5ae051KMP1?FgL00P1@FgH02`1BGGL0Deii05IQNP1GHWd0FF>1
05YSP`1LIXD0GVR505iZQ01PK8D0HVj60080HVj700`0Hg2906=aRP1TLH`0IG>>06IbS`1WMI40J7FA
06UeTP1ZMY80K7NC06]gT`1/NY<206]hT@0;06YgT01]NI40KWVB071lT`1_Ni<0L7fE079nU`1aOYD0
M7nG07J0V01hPYP00P1kPiX02`1kPi`0N8:M07R3V`1iQIT0NhFI07b6V@1mQYX0OhRL07n:WP20Rih0
PX^O0080PXbO00/0Q8jR08>?X`25TJ<0Q96P08BCWP25U:00Q9>O08FCWP27UJ40QiFT08VGY`0208ZG
Z00<08ZGZP2<V:/0SiZ]096K[@2BW:d0TYf/09>O[@2DWjd0Uj2]09NQZ`2IXZ/0VjB/0P2KY:X02`2L
YJT0VZFW09ZUY`2JYZL0VjRV09ZXYP2KZ:H0VZNU09ZVX`2JYj80VJNP0080UjJM00/0UJFJ09JWV@1L
HV80<C4f03Hj=`0b=300<C4Y0414=P1MITh0EUi:04E8?P0203Th=`0<04Q8A`1MHE/0HFIN04a=C017
B4P0ADA204E3@01=CDX0R9B009RVT02FYI40T:2>0P28VXP02`28VhP0K7a^01/K800P8B407AdI01`M
5@0H5Pd05aD;01DD2P0S9aP0;SDU0080=3d]00/0?d`i04mOA`0Z=2L0;c`/02H`9@24X7/0LXUZ02D[
9015DT806A/I02P[8`0202da9`06030d:P0d>2h0=c`_03Pn;P0g?bh0<STY6_oooolW0?n004d0003o
4`3oP0080000oa00oh000P000?l<0?n000oooooo000=ooooo`06045:H@13CFL0ATm/04QAKP18DG00
B59`0P19DW002`19DVh0B59_04YDL@1<EG80BeEa04aGL01=F700CeYc04mJM@1@FgP0CeYh0080D5]h
00/0DEah059MM`1DH7T0EV5k05QSOP1IHh40FVB405]VQ@1MJ8<0GVV2061/Q002061/Q@0<065^Q`1S
L8X0Hfn>06AbT01TLI40IG:B06IbT@1VLY80IgBC06UdU01ZMI@0JgND0P1[Mi<02`1[MY80K7RC06ei
U01^NYH0KGZF06ikU`1_OIP0LWnH07AoV01dOYP0M7nI0080Mh:J00X0Mh2I07IoV@1fPIT0Mh>H07V4
V01jQYP0NhJJ07f6V`1nR9`0OhZM0`22Rid01022S9h0PhfP08>>X@22T9l208>BW@0508BCW@24Til0
Q9>R08FDX`27UZH00P28UZL0302:UjT0S9N[08jI[02>VJd0SiZ]096L[@2BWZd0Tin^09BP[@2EX:/0
Uj:Z09VTZP80VZFY00/0VjFX09ZTYP2KYZL0VZJV09ZVY@2JZ:H0VJRW09RVYP2HYJD0UjBS09JTXP02
09JUW`0;09FTVP2HZ9T0IVmZ03@c>@0m@3d0>C/f03De;`0m?cH0Eem<05MNCP1<DDH00P0k?ST0301H
HEH0HFaR08:CP@1PJF00FEmH04A5A01;BdP0BdY907j7N@2AWh`0TJ2?092PS`80R9N700/0QYN40760
L00N7b@08B8R01dL6@0L71D061P?01@C2`0C4P/07b8F02de9@0203Q3<@0;034l;00P9a`06b8H01XQ
5P0?50`0H7IE06EkF00E6Q80;SLZ01@F4P0O8AT00P0W:R401P0]<BL0=3L/03Pl;P0e>b`0=3X[02lf
9a[ooooo:P3oP01:0000o`d0oh0000<0003o0?n0003oP0000`3oP0080000oah0oh003oooool000go
oooo00H0@DYO04=<I@15CVX0Ae1]04QBK`18DG0204UCLP0;04UBL018DFh0BeAb04aDL`1<EG<0BeEd
04aFL`1>F7D0CUUe051IM`1?FGL00P1@FWP02`1AFgT0DUai059MM`1DGWT0EV5k05MRO@1IHh<0FVB5
05YTP`1LIh80GVV30080H6^500`0HFf6069^R01SKh/0Hfn=06=_T01SKY00HfjA06A`T`1ULYD0IW:E
06QcU@1WLi@206UdU@0;06]fU@1/NI@0K7VE06eiU@1^NY<0Kg^E071lU`1bOIL0M7jF07AnV01eOYX0
0P1eOiX0101gPY/0MX6K07F1V@1gPi/207N3V@0507R4V`1kQY`0O8NN07f9W`1oRIl00P21RYd02`23
SIl0PHbN086=W`22T:00PY2N086@W@22TI`0Pi:P08BBXP26UJH0QYBX0080R9FY00`0RIBZ08^FZ`2:
UZX0RiN/08fI[@2?Vj`0TIb[09:N[02BWZ/0TinZ09BQZ02FXjP209NSYP0;09RRY@2JY:L0VJBV09ZU
YP2IYJH0VZRX09VWZ@2GYJL0UJ>U09FSX`2DXj400P2EY:002`2DY9/0V:VJ06]dK`0g=ch0@49103Xl
>@0b=340ADY0059IC01EGDl0CeU<0080@4Lo00`0DeiA06=_H@24UX00PI1l07b5M@0n>ch0B4E703dh
@01gOgH0TYn?08^HR@2DXi4208fLRP0;08VHQ@1iQgL081lV01hM8@0L6aX061PC01DE3P0D5@d05QL?
02DZ700V;1h00P0T:ah02`0R:1`06AlF01HL500F71404QL<02/f8`0hABl04QP@01`R6P0D61<04aH@
00809B/O00H0;cHW03<k:P0g?R`0=Sh[03<j:@0^<b@Jooooob`0oh00B@000?l<0?n000<0003o0`3o
P0080000oah0oh003oooool000gooooo00H0@DYO04=<I@15CVX0Ae1]04QBK`18DG0204UCLP0;04UB
L018DFh0BeAb04aDL`1<EG<0BeEd04aFL`1>F7D0CUUe051IM`1?FGL00P1@FWP02`1AFgT0DUai059M
M`1DGWT0EV5k05MRO@1IHh<0FVB505YTP`1LIh80GVV30080H6^500`0HFf6069^R01SKh/0Hfn=06=_
T01SKY00HfjA06A`T`1ULYD0IW:E06QcU@1WLi@206UdU@0;06]fU@1/NI@0K7VE06eiU@1^NY<0Kg^E
071lU`1bOIL0M7jF07AnV01eOYX00P1eOiX0101gPY/0MX6K07F1V@1gPi/207N3V@0507R4V`1kQY`0
O8NN07f9W`1oRIl00P21RYd02`23SIl0PHbN086=W`22T:00PY2N086@W@22TI`0Pi:P08BBXP26UJH0
QYBX0080R9FY00`0RIBZ08^FZ`2:UZX0RiN/08fI[@2?Vj`0TIb[09:N[02BWZ/0TinZ09BQZ02FXjP2
09NSYP0;09RRY@2JY:L0VJBV09ZUYP2IYJH0VZRX09VWZ@2GYJL0UJ>U09FSX`2DXj400P2EY:002`2D
Y9/0V:VJ06]dK`0g=ch0@49103Xl>@0b=340ADY0059IC01EGDl0CeU<0080@4Lo00`0DeiA06=_H@24
UX00PI1l07b5M@0n>ch0B4E703dh@01gOgH0TYn?08^HR@2DXi4208fLRP0;08VHQ@1iQgL081lV01hM
8@0L6aX061PC01DE3P0D5@d05QL?02DZ700V;1h00P0T:ah02`0R:1`06AlF01HL500F71404QL<02/f
8`0hABl04QP@01`R6P0D61<04aH@00809B/O00H0;cHW03<k:P0g?R`0=Sh[03<j:@0^<b@Jooooob`0
oh00B@000?l<0?n000<0003o0`3oP0080000oah0oh003oooool000gooooo00H0@DYM04A=HP16CfT0
BE9^04QBK`18D70204YCL`0604]DM019DG40BU=b04]CL`1;DW80BeAd0`1=EWD03`1>F7H0CUQg04mI
M`1?FGL0D5]g059NN@1AGGP0Deij05EQO@1FHH00F6>305QTQ@1JI8@0G6J305mYQ002061YQ00<061Z
Q01QK8L0HVj9069]R`1RKHd0HVn?06=_T01RKi00Hg6A06EcTP1VLi80IW:B0P1YM9@02`1[MY@0JWFD
06]fU01]NI<0KWZA071jTP1aNi@0LW^C07=mT`1dOYD0MWjG0080MgnH00@0Mh6I07J1VP1dP9X0Mh:K
0P1hPiX01@1hPYT0NH>J07b6W01oQih0PHRO0080PhZO00/0QHfO08:<W`21S9l0PhjP08BAX@25Tj80
QI:Q08FAXP27TZ<0R9BU08VFYP0208VFY`0<08VFZ02;UjX0RiJZ08^GZ`2>VJd0Si^]092KZ`2AWJ`0
TYj/09:NZP2CXJT0UJ6Y0P2GXZH02@2GXJD0V::W09RSY`2IY:L0V:BV09VVYP2IYjP0UjBV09JTX`02
09JTXP80UZFQ00/0UZFM09RXW01cOGH0?3e20455A00j?Sd0<cLe03Tn>@16CT80Dei<04E=@P02038f
=00<051HD@1SKF<0QYF108fMQ`2JZY40BdY:03dh?P0e<3X0KGA_092PT027U8L0Sin>0P2@XHd02`2:
W8L0NHUg01lO900I61/05aHF01<B3`0A40X04A4801@E2P0P9AL08BLH00807b<G00/07R4F01TN4`0G
71<051XA018G3P0B5Pl04AD@01<H4P0E6A<04QHA010D3P02020W6P0602df900a>RL0=3hZ03<m:00c
?2H0;cLS6_ooool^0?n004L0003o303oP0030000o`<0oh0020000?lN0?n000oooooo000=ooooo`06
0419F`13CF80AU1Y04QAKP17DFh0B55_0P19DW802`1;E7@0BU=b04UBLP1;E7<0BU9b04]CLP1<EG@0
CEIe04eGMP1<EgH0C5Qg0080CUUg00/0D5ei05=NNP1BGGX0Deil05EPO`1HHX<0F6:505QSP`1IHh40
FVF205iXP`02061YQ@09065YQP1PJhP0Hff:069]R`1PK8/0H6f;065^S01SLHl0I7:A0080IgBB00h0
Ig>B06YeT`1ZMI<0JgFB06egU01]Mi<0KgVA06mjT@1`NY00LG^@079lT@1dOi<0M7nD07IoUP<0Mh6I
00H0Mh:K07J1VP1fPIP0Mh>G07V3U`1kQ9P207b4V00;07j6VP21RI`0Q8^N08B;WP25S:00PhbO08><
X022S:40PXbP08B?X@26TJ<00P27TZ@04027TZ<0R9BS08REX`28UJ<0QiFS08VGY`2:VJP0S9V[08jI
[@2?VZh0Si^/092M[02BWZX0TijY09FOZP2GXJ/209JQZ00;09NRZ@2GXJP0Uj>W09RTZ02HYJP0VJJW
09NUY@2FY:@0V:FT09RSX`2GXj800P2HY:402`2GY9d0V:NL07^6O`0i>440@D=503e0?`0g>CX0<cHg
03e2?@1BGDh0BeA80080>3/h00`0D5I?06A[HP24T800T:2=0:BhW`1SJV<0>CLm03Xi?`1TKFD0TJ>?
08JEQ02;W8T208bPR`0:08RMQ`1kSW`08RDZ01<D6@0H6AT05QHC01@C3P0C4P/04Q<:01LI3P<06QlB
00/06b0C01TM4@0G6Q4051PA018H4P0B5Q<03a8C018E5@0D61H04aLD018F3`0201lV600602Xc7`0_
=bD0<S`Y034m:@0b?BL0<3XS6_ooool[0?n004X0003o303oP0030000o`@0oh001`000?lN0?n000oo
oooo000=ooooo`0603i8GP10C680@dmX04E?JP17D6`0Ae1_0P18DG0204QBL@0904UCLP1:E7<0BeAd
04YCL`1<EGD0BeAe04aEMP1<EWH0C5Qg0080CUYh00/0CU]i051KN@1AG7X0DUel05AOOP1GHX40F6>2
05QTPP1HHh40FFB105aWP`0205mYQ00<05mYQP1PJhT0GfZ9061/R@1PK8P0H6f;065_S01SLHh0Hg2@
06IcTP1XM940IW>B0P1VLY401P1YMI40JWJA06]gS`1]N8l0KgR?071jTP80LG^C00<0LWfD07=nUP1c
OIH00P1eOiX02`1ePI`0MH2K07J1V@1gPiP0Mh>F07N2U@1jQ9D0NhFF07^5U`1lQYX0OhVL0080P8ZM
00/0Ph^O08::W`23SJ40PhjQ08:=W`24SIl0QHnQ08F@XP27TJ@0Qi>T08VDX`0208VEX`0<08NDXP28
UZ@0RYVW08^IZP2<V:`0SYZ^08jJZ`2?Vj/0TYfZ09FNZP2FWj/0Uj2[0P2EX:T02`2FXjX0UZ>X09NT
YP2FXjH0UjFV09RWYP2FYJ@0UZBS09VUX`2HXj40UZ6O0080Uj:M00/0UZ6J09VVVP1hP7/0>3<o040n
A011@T@0@dI503i0?`0k?c`0E5mB059LC`0204U?A`0<04eBBP1RJel0Pi:008^KR@2HZiD0O8Qj0411
A@0l?D<0HfeW09Z_V@27VXP0RIf;0P28WH/02`2:WX/0PIB302P/<`0D5Ad06A`N01TJ6@0F5a804a<=
014A2`0D5Ph061`B008061dB00/06alC01hR5@0M7aH071dG01/M6P0J7Ah06Q/Q01TI8@0H6Ql05ALH
010D3P02020X6@0602/d800a>BD0<c`Y03<m:P0b?2X0<SXW6_ooool/0?n000040000o`3oP000oh00
0?n004D0003o303oP0040000o`<0oh001`000?lN0?n000oooooo000=ooooo`0603i8G`10C6D0@TiX
04A?J014CVT0ADm/0P16Cfh02`16DFl0Ae5`04UAL@18DG00BE9b04YCL`1:DW<0Be=d04eGM`1=F7L0
CEUg0080CUYh00P0CEUh04iIN@1@FWT0DUam05=MP01FGh40F6:205MSPP80Ef>100l0FVJ305aWQ01L
Ih@0GFV505m[R@1OJX/0GfZ:05iZR@1PKHX0HFj:065^R`1RKH`0Hfn>06EaSP1ULI000P1TL9002@1Y
M980JGFA06YfS`1/MXh0KWN?06mjTP1_NYD0KWVF06ijU@02079nV080M7nK00T0MH2M07F1V`1eP9T0
MX6G07N3U`1hPYL0NH>H07Z3V01kQI/00P1lR9h207f9W`80Oh^P00T0PHfP086<WP20S9h0PHbN08><
WP25Sj00QHnQ08JAX`27TZ<00P25TZ803025Tj<0QYFU08RFY@29V:H0RiVY08nJZ`2AVj`0TIZ[09>L
[02EWJd0Uin]09NOZP80UJ2X00X0UJ:X09BRYP2CXZ<0Tj>R09BTXP2FY:<0UJBS09FTXP2GYJ<0UjBR
0`2FXZ002`2EXI`0VJNL06ecL00e;SX0?CQ00450A@1:CTd0@DI403Tm>P1AG4l0D5Y>0080DEU>00`0
Bdm805aSFP24TX00RYV508^KQ029V880ADE7030]>01TKV/0V[2M08JIRP2;WH`208JGQ`0;08ZKR020
TGl092@/01XI800M7Qh06ATG01DE4P0B4Ph04a8=01PJ4P0L7Q@00P0L7AD02`0[<B80:2dO020S5`0W
9b009bDU0495A00b=3T09bL]02HX:@0H6AT04a@?008092XJ00H0:S8N02hf8`0b>RD0<c/W03<m:00`
>B@Joooooc00oh00A@000?l<0?n000@0003o0`3oP0070000oah0oh003oooool000gooooo00H0@4UQ
045;I@12CFT0@di/04=>JP14CV/204A=J`0504A=K017D6h0Ae1_04I?KP17Cfh00P19DG40101:Dg80
Be=b04aEM01<EWD204eGM@0;04iHM`1?F7P0D5Uh055JN`1AFWd0E5f005MPP@1FHX40F6=o05MSOP1I
IH000P1JIH002`1KIX80G6J605iXR01OJXT0GfV905m[R@1QK8T0HVj:06=_R`1TKh`0I72>00<0I6n>
00/0Ig6?06QbSP1ZM8l0K7F?06efS`1_NI40KWZC06mkU01_O9D0LGfE079lUP0207AnV@0;07AnV`1d
OY`0M7nK07AoV01gPIL0NH:I07Z3V@1iPiT0NX>K07^6WP1lQil00P1lRJ402`1nRZ80Oh^R07n<X01o
Rih0OhfN082<WP22S9h0Q8jO08F?X@26T:80QY6R0080QI:Q00`0QY>S08NEY@27UJD0R9JV08ZFYP2=
V:X0T9V/096JZP2BVjX0U9b[09FMZ`2FWZP209FNY`0309FPZ02CXJD0Tj6S0080U:>S00H0UJ>R09BS
XP2CXZ40UJ:R09FRX@2GXZ8209JRX@0;09BPW@2HYYd0LWUf02dV=014@DL0A4=904A7B`0j?T80=c`l
04aGC@1=FDd00P1@FU003013Ad@0JgEX092QR`1hQ7D0QiJ108>BO@11@D<0:B@b069YI`2H[9X0RY^;
08fNS080RIN500H0S9^708fNQP0Y9b/07Q/L01`K5`0G5Q4201@D3P0301DE3P0K7A<07b8H00806ATD
00/0@4Tg03Y2=00^<RX0F65B03`o?@1IHU/0?T9502TZ;`0Y:bX051@D01TL500202P]7@0602T_700[
<Ql0;cHT038i9P0c?2L0;STU6_ooool`0?n004D0003o2`3oP0050000o`<0oh001`000?lN0?n000oo
oooo000=ooooo`060458G`10B680@T]X049;J`12C6/0@D][0P12C6/204A=K080ADi^00L0Adm^04I?
KP18D6h0BE9]04UBK`1:Dg40C5Ac0080C5Ab00/0CEEd04iFM`1@F7L0CeYg051KN01CGG/0E5mm05EQ
O@1EHG/0Ef9j05QSO00205UTO@0<05UTP01KIX<0GVV5061YQ@1QJHL0H6Z7069/R01RK8T0HVf9065]
R`1SKhh0I72>0P1ULXl02`1WLXl0J7>?06YdS`1ZM8h0JgF>06egSP1^N8l0KWV@071jTP1`O9@0L7bF
0080LGbG00/0LWfH079lV01cOIX0M82I07IoV@1hPIP0NH:G07R2U`1iPYP0NH>I07^6V`0207f9WP0;
07j:W`1nRZ00OX^N07f:W@1oS9d0P8fN086=W`22SZ40PhjP08F@X026TZ000P27TZ80302:UJ@0RYFU
08VCY02:U:D0RiFV08jGZP2?UZX0T9VY09>LZ@2CW:P0U9fX09JOZ080UZ2W00@0UZ6W09FRY@2FXjD0
UZ>T0P2FXZ<01@2EXZ<0UJ6S09FQX`2EXJ<0UZ6R0080UJ6O00/0UJ6K09JTW01oR8@0:bPe06M_J@1<
CU40BTe>03i2A@0`<cP0CeQB04mHD@0204mGDP0<03e1@P1VLVH0W[JI079oL@25UH40MX=d03/k@@0a
;c/0Ff5R086AQP26UXP0SYj;0P29Uh802`27UWl0SIj302l^;00O71X07adF01/K400H6@h05aP=01LI
3P0K7A406alD00805ATB00/08RLO04eHA`1JIUH0KWeZ06A]H`1^NFd0G6EM04Q>B00f?3L06a`L024S
7@0202HZ7`0602T_800]<R<0;c@U03<i9`0e?BT0<3TV6_ooool`0?n004D0003o00<0oh000000o`3o
P0002@3oP0040000o`<0oh001`000?l>0?n000030000o`3oP000003o00d0oh003oooool000gooooo
00H0@DQN049;H`13C6L0@T]Y049:J`12BV`204A=K`0604A=KP14C6d0ADi^04I?K017Cf`0B55]0P17
D6/00`19DVd0BE9_04aEL`0204eFM@0;04eFMP1>EWP0D5Qk04mIN@1@G7T0DUej05EPO@1EGg/0EEmj
05QRN`1HHg/00P1IHgd0101KI800FfF105eUPP1OIh<2065XQ@06069ZQ01QJX@0HF^5069/Q`1TKXX0
I6n<0P1ULHd02`1ULXd0IW><06QdS01YMH`0JGF906afR`1^N8d0KgV@071iTP1aNi@0LG^F00<0L7bG
00X0LGbH079lV@1dOiX0MH2I07J1V01eP9H0NH:G07^2V01kPiT0O8FJ0P1mR9`207n:W@0907j:W01n
RYd0Oh^N086<WP22SJ00PhnR08B?X025T:00Qi:R0080RI>S00`0RIBR08RCX@29U:80RIBR08bFYP2>
UZT0SYJZ092JZP2BW:P0TYbV09BMYP2FX:L209JQYP0409FQY@2FXJH0UZ:U09JRY@80V:>V00D0Uj>V
09NRY@2GXZ<0UZ:R09JRX@0209FQW@0;09BPV@2FY9T0QY6902l/>01@E5@0CE5@04mED@0n@d80;Bld
051ID`1>EU800P1>EU003015BdP0D5UC09B/T@24V880RIj607R8N01FGE`0@45;05mVJ`1VKW40QIB:
08nPSP80RY^400/0QYAk07j>LP0Z:RD06aPE01hL5@0I6@l061T>01PJ3P0H6`d06Qd?01`O4P0201`O
5@0;018B3@1:DT40NhYa06mjJ@1cOg00MX=e071oK`1XMfH0@4Lo02@V900Z;BH00P0[;b<01P0[<B80
;C<S02ld900`=RH0=3XX034g9a[ooooo<P3oP0130000o``0oh0010000?l40?n000H0003o3@3oP006
0000o`/0oh003oooool000gooooo00H0@dUR04A:IP13BVT0@TYZ0499JP13BF/204=9K@0504A;K014
BV/0A4]Z04E>JP17CfX00P16CFT01018D6X0BE9/04YCKP1<Dg0204eDM00;04aDM01;E7D0CeMi051I
N`1@Fgd0DE]l05=MO@1DGWd0E5il05IQO@1HHW`00P1JHg`0301LHgh0GFB005iTP@1NI840H6R2065Z
Q01QJX<0H6Z1069[PP1TKHD0IVj706I`R@80I72;00/0IG:<06EbRP1VLhX0IgF806QdQP1ZMHL0JgF9
06efS01_N8h0KgZ@071jT@02075kTP0;071lU01bO9D0LgbG07AnV01eOiL0M7nE07AoU01gPI@0NX:F
07b3V01lQ9T00P1mQIT02`1mQYT0OXRK07n:W01nQi`0P8ZO08::X022Rj00Q8bP08B>W`27Sil0Qi2O
0080Qi:P00`0R9:P08RBX@28Tj<0RYBU08^EYP2<UJL0SYJX08nIZ@2AVJP0Ti^U09JNY02EWZ8209FO
X@0809FNX@2DWZ80UJ6U09FQY@2GXjH0V::U09NRY@2EXJ@209JSXP0>09FRX02CX9d0Tj2M09>PVP2B
XIL0S9^>03Xi@012A4H0Ff=L04UAC00j?c`09RTZ04eGC@1=EDd204iFCP0<04aBB@1OJE/0TJJ;07J6
MP1oT7l0PY>307^9O01LH640C4]E06mdM@1lQ800SI^=0P2:VXH02`26UGh0OHid02PY9P0L6aT071`G
01LI400G6@h05a/?01DJ300H6``09RXG0080:R`N00/05a@@03m1=`1oSgD0KGMY079nL01dPg@0L85`
06UjIP0lAC`071lL02/`9`0202`b9`0602`c9@0/=2@0;CDU02hg9`0`>2T0;cLY6_oooolc0?n00480
003o303oP0050000o`80oh001`000?l=0?n000H0003o2`3oP00?ooooo`003Oooool01P13AUl0ADQU
04E9J@14BFX0ADY/04E9K080A4Q[00/0A4U[04A:J@14BVP0ADaX04E<J@16CFX0ADe[04I>K@19DVh0
BeA_04aCKP0204aCK`0;04aEL01;E740C5=c04mFM`1@FW/0DE]l05=LO@1DGWh0EV1m05IQO01GHW/0
0P1IHWX0301KHW/0GF=m05mTO`1MHh00GVF1069ZQ01RJh@0HF^306=/Q01TKHH0IFj806M_R@80Ig2:
00/0J72;06QbS01XLh/0JWB906YeQ`1[MHL0JgB906aeR`1_N8`0KgV=06igS00206mhSP0;071jT01a
Ni40LW^B07EnU@1fOYH0MgnF07MoU@1hPI@0Nh>E07b4U01kPiD00`1mQIL0201nQYT0OhNK0828WP21
RJ40P8RQ086:XP22Rj00PhfN0P26Sih208R@W`0<08VAX02:TZ<0Ri>U08fEZ02>UJT0SIBZ08jFZ@2@
V:T0TIVW09BKYP2FWJ@0UYjR0P2FWj802P2EWj40U9jQ09BOX`2FXJD0UJ2W09FOY@2EX:D0U:2V09FR
YP2EXZ@309BQX@0;096OW@2?WIL0TJ6E04I8B`10A4D0Lh5b04]BC@0l@Ch09bT[04]EB`1<ET`00P1=
Ed`03017CD@0D5E:07j=MP1gQG80NhQf08NFP`23TH00NH5e03hi@@1TIVH0MWeh08^GRP80R9J600/0
QIF107^=M`0`=2l06ATH01hO6P0G6A<051H?01DI3`0C5`d04AD:03M3:@0204eI?@0;01HD401>E4L0
NXQc06ahJ`1aOW40Lh9d0763L`1YNfP0@Te102de;@0a>bl00P0^=R/01P0/<bL0;3DV02`f9@0^>BL0
;STX02dg9a[ooooo;@3oP0180000o`80oh0000<0003o0?n0003oP0001`3oP0060000o`80oh001P00
0?l=0?n000H0003o2`3oP00?ooooo`003Oooool01P13AV00A4QU04E9I`15BFL0ATUX04I8J@80AdYY
00/0ATYY04E:J015BVT0AD]Z04E;J`14C6/0ADe/04I=KP19D740BE5`04YBK`0204YCKP0;04]EKP1<
EVh0CEI`04iGM01@FGP0DEYj05=KO@1EGgl0EF1m05AON`1FH7/00P1IHG/01P1HGgT0FV5j05eSO01N
HWl0GfB1061UP`80H6N500@0HFV406A/QP1TJhL0IFb70P1VKXP0101WKX/0J6n;06Q`R@1YLXT206Ub
R00506YcR@1[M8X0K7J906iiS01^NH/00P1]MhX02`1_NH/0LG^=079kSP1dO8l0MWfA07MoTP1gOY80
NH6C07Z2TP1kQI<0NXBB0080NhBE00/0NhBG07f5V@1oQi`0P8NP0868XP21R:<0PHVQ086:X021RYd0
PhbM08J?W@0208R@W@0<08N@W`28TJ40RI6R08bDY02>UjL0SiNY08nFZ02@UZL0TIRV09:IYP2DVj@0
UIfT0P2EWZD02`2DWZ<0TifQ09>MX@2EX:@0UInV09BOY@2DX:L0U:6X09>PZ02BX:H0TYnR0080TYnO
00/0SifK08jKU`2BXYT0H6MW02`Y=P1WLFP0De]D0416@@0];bl0CUQ<04eGB`0204UAA`0<03`o>P11
A3d0Ff=D07F2J`24U7T0RY^208JEO`23Sgd0>SLn05]MGP1hP7X0QI660P24TH@02`24UH@0MhQf034e
=00K6a`07b0M01XK5`0E5a804QD=014D300>40/0=D0/0080BePo00/04Q0;04E:?01ePV`0KGQ[06ml
L01bPG@0LX=c0722K`16DDL0;SD^038j;00202de9@0302`b8`0^=2@0;C@S00<0;SLT6_ooool`0?n0
04D0003o0P3oP0000`000?l0oh000?n000080?n000D0003o0P3oP0060000o`d0oh001P000?l;0?n0
00oooooo000=ooooo`060455G`12AV80A4MT04I8IP16B6P0ATQZ0P16BFX204E9J@0404A:J@13BfT0
@d]X04=;J@80A4aZ00<0ATi/04UAK`1:DW400P1:DW402`1:E700C5I`04aFL01=EW40CeMd051GM@1A
FGT0Deam05AMO@1DGW/0EEmk0080FF5l00`0FF1j05YRN@1LHWX0GF5l05mSO`1OI840GfF2061WP`1S
Jh80Hf^106EZP`1WJhH206Q[Q`0306M/RP1WKHT0Ifj80080Ig2900H0JG::06YcRP1YLX/0J76:06Yd
R`1YM8P206YdQP0;06egQ`1]MhH0KWR7079kR`1eOHd0MWn?07R0T@1iPI40NH:@07V4TP1hPi800P1i
Pi<02`1kQID0OXJG07n7VP1oQYd0OhJN07n7W`21Rj40PH^O08:;WP24SIh0QHjM00<0Qi2M00/0R96O
08RAX02:Tj40SIFS08nGY02@UZ@0TYNV09:IYP2BVJD0TYZS09BMY00209>OX`07096NX@2AWZ00TIjO
09>OX@2EX:80UInR09JQY@0209>PX`0?09>OX`2CWj40TYjN09:NWP2AWI`0TIjI09>RVP1_MgH0:BDc
04E9B012B4<0=c/g03Pk=P1=EDT0C5A70080CEI900`0@TPo03Pl=P0o@c/0IG1L08RHOP2BXh/0RIJ3
08F@PP10?4H0KGA`07V3O026TXP208FBQ@0;08FDQ@1iQgL0;2d_01`L7P0O7ah06AXF01@F400A50/0
418900l>2@0nAC@00P1FHd/02`0A3`l0<38^07:1K@1[NFX0KG]^0721LP1aPg80L89_05MVE@0b>2h0
:BdQ0080:c0O00H0;38O02dc800^=240;CDR02`e8`0/=28Jooooobd0oh00B@000?l=0?n000@0003o
00<0oh000000o`000?l01@000?l=0?n000H0003o2`3oP00?ooooo`003Oooool01P0nAE`0@4IN04E9
HP17B6H0AdQX04I7J080A4IX00/0A4MX04A8J012B6D0@TYT049;I@13C6D0A4iV04A=IP13C6H0ATmY
04M?K00204Q@K`0904Q@KP1;Dg00C5A`04aFL@1>Eg<0CeQe051JN01BG7/0E5al0080E5il0P1GH7d0
301IHW`0FV9k05aSN`1MI7`0GFAm05iUO`1PIh40HFN1069[P@1QJGh0HVUo06M/PP80J6^300/0J6^5
06Q]R01VKHP0IVj906I_RP1UL8T0Ig::06MaRP1VKXL0Ifn506I^P`0206A/P@0;06E]P@1WKh80IFj1
06MaPP1[M8@0KGF606mhR01aNhP0LGb707B0RP1gPhh00P1iQI402@1kQi@0OHRF07n9V@1oR9T0OhVJ
07n:VP21S9X0PXfI08>=VP0208F>W@80QHnL00`0Qi6M08ZBX02;TZ40S9>S08bCY@2>U:H0T9JU092G
Y02BVJD0TiZU09>KY02BW:42092MW`0;092NX02AWYl0T9jO09>PW`2EXIl0UJ2P09FQXP2DX:80U:2S
09>OX@2CWil00P2AWYd02`2?WIX0SYbG096QV01]MW@0;2Pf03Dd=`0];Bh08b8T04aDA@1AFdT0CeM6
0080CUI400`0?dDf03Tn<P0e=c00EeiA0:>iVP2BXXh0RiV808RDQ017A4T0Phb008F?Q02:UHP208RD
QP0;08BBP01nS7L0<C8_01LF5`0N7a/06QXE01HG3P0D50X04Q8900h<1@12BSH00P1IIDh02`0F4Q<0
=SXg06MfJ@1TLfP0IgQ/06YmKP1/P6h0J7aW05EUD@0^=BT08BHI0080:BlN0P0/<Al0100[<b00;CHR
02`e8`0Z<b8Jooooobd0oh001@000?l40?n00080003o00<0oh000000o`3oP0000`3oP0000`000?l0
oh000000o`0e0000o`d0oh0010000?l00`3oP000003o0000o`050000o`d0oh0000<0003o0?n00000
0?l00`000?l;0?n000oooooo000=ooooo`0603e4G@0oAV00@dQU04E8I`15AfP0ADIX0`13AVL01012
B6H0@TUU0499I013BV@204A=I@0404A=IP15CFL0ATmY04UAK@80BU5_00T0Be1`04aBLP1>EG@0CEEd
04eEM@1>F7P0D5Uj051IN`1BFW`00P1DGG`205EMO00<05QPOP1IHGd0FV9l05YSN`1LIW`0GFEm05mV
O`1PIh40HFN1065XP01SJX80IFf30P1UK8@02`1VK8@0Ifj706M]RP1WKX`0IFn=06E`S01WLH/0J7:9
06I`Q`1WL8H0IVj40080IFf100/0IVb106I/P`1RJX80HV^106A/P@1SKGl0Hf]n06E^O`1VLGl0J7B0
06ahP`0206mkR00;07>0S@1ePY40NHJC07Z8U01lRID0OHZE07n<U@1oSI<0P8fD08>?V@24SYX00P24
SYP03027TId0RI:P08ZAX02:T:00Ri6T08fBYP2=TZ@0SiBT09:GY02DVZ@0TiZU09:KXP80TIbO00/0
TIbN096MWP2BWYl0U:6P09FQX02DWj00U9nR09>NX`2BWZD0TIjR092MWP02092NWP0;08nNW02:VYH0
SZ2F079oN00_;CH0=38c02d[:`0O71`0Eem=05YUD01@FDD00P1<E440300a<bT0<S@Z03Xm<P12AC/0
VZj>09NZTP2@Whl0S9Z:055BD@2<UhH0Tij@08fHS080RYR800/0Q9F108:ENP0oAST05A@B01lP6@0M
7AD07A`C01TI3`0G5Pd04@h803e2<P02065]EP0;020M7`1<Ddd0IWA[065`J`1OLFX0Gg5V065dH`1Q
M5l0=3hd02Xb:00W;b800P0X;al01P0Z<B00;38Q02dd8@0/=280:c<R02Tb8Q[ooooo<@3oP0030000
o`80oh000P000?l00`3oP000003o0?n0000;0?n00300003o3@3oP0040000o`030?n000000?l0003o
00D0003o7P3oP00?ooooo`003Oooool01P0mA5d0?dIP04=8I@15B6L0ADMX04E6J0<0@dIW00@0@TQV
0499I@12BF@0@dYT0P14CFD01014CFH0ADeW04I?J@19DFd204YAK`0904]@L01<DW80CUEd04eEM01=
EGD0CUQh051INP1@FG/0DUYl0080E5el0P1EGG`0301HH7h0FF5m05YRO01JHg/0G6Il05eUO@1OIWl0
H6N1065WP@1QJ800HfZ206E]P`80IFb400/0IVb406M^Q`1WKHX0Ifj<06E_S@1UL8`0Ig6;06QbR@1V
L8L0Ig2606I^Q00206E]P@0;06I/P@1VK8<0HVZ2069[P@1TK840Hfeo06=[OP1UKWl0IW5o06QdP01/
N8<00P1_NhP02`1cP8d0MH:A07V6T`1jR9@0O8VE07f:U@1oS9D0OhfC082=U023SiT0Q8jJ0080Q8jH
00`0Qi6M08VBX02:TJ00RY2P08^AY02=TZH0SI:T08nDY02BUj@0U9ZT09>JY@2BVj82096LW`0;096L
WP2AWIh0TYjO09BQX02EXJ00U9nP09BOXP2CWZ<0TYjU096NXP2@WIh00P2@WYh02`2?WY`0RYZF08jP
UP1bOgP0;bdf03@b<`0]:b/07a`L05MOC@1JIE00D5U50080C5A100`0<C<Y038d:P0j?C80@TDk09Z^
SP2GZY80T9n?08bJRP1ADU40S9N609>NT02=V8`208ZHR00;08BEP@22UGX0?dHi01DD4P0O81T07AdE
01dL4`0I6@l05aH=014>200m@S800P1QKEH02`0P7Al0C5==06IdJ`1QL6/0Gg5Z05maIP1QM6<0HGAO
03@n=00Z<RP09blR0080:2lO00H0:S4P02`b8@0]=240;3@R02/c8P0Y<R8Joooooc40oh000`000?l2
0?n00080003o00<0oh000000o`3oP0002`3oP00`0000o`d0oh0010000?l00`3oP000003o0000o`05
0000oah0oh003oooool000gooooo00H0?T=M0416HP12BFH0@dUW04A8J014AfP204=6I`0:04=7I`12
AfH0@dMV04A8IP14BFH0A4]W04A<I`15CFP0ATe[04I>K@<0B51^00X0BU1_04YAL@1<Dg<0CE=c04iC
M@1AEgT0DUQi05=JNP1DFg/0EUek0`1GGW`0301HGgh0Eemm05MPO01IHW/0FfAk05aTO01NIGh0GfIo
061VP@1PIX80HVR306A[Q080I6b500L0I6b606I]Q`1XKXX0Iff<06I]S@1WKhd0JG2=00<0JW:<00h0
K7:;06abR@1/LXT0K7:906aaRP1ZL8X0Ig2906I]Q`1TK8D0HfZ106A/P@1UKH80HV^006=[P080Hfb0
00/0IVn106QaPP1/MH@0KgR5075kQP1dOhT0MH:;07R6S@1kR8h0OhbA086=T`0208B>U00<08NAV@29
TId0RY:N08ZAW@2;TYl0S9BS08fDXP2>U:40TINR096HX@2BVJ00Ti^O0P2AVY/02`2AVi`0TY^L09:L
W@2DWIl0UYfQ09FLX@2DWJ80U9jR09:NX@2AWj40T9nO0080T9jM00/0SifJ08bKUP2=WiD0OHb203m2
A00g=c@0;bdX02DQ7P1LHTl0Ff=@04mEA@0204YB@@0<03Pn<@0e>bd0?D@e03Li<@1kRG80VjjC092P
T02<Vhh0JG5^082<PP1nRH@0PHj80P2<WY002`24UhD0PIAl03e3=`0F514081lI01dL5`0N71L06aXD
01PF400F4`l0@THh0080K7YR00/0AD]4061[GP1TLFD0Hg5W04=<B`0c>C/0BUQ<06MkH@0a>Rl09blT
02Xc9@0202T`8@0602T`7P0Z<R00:c<S02`c8P0/<b40:C0O6_oooolb0?n00080003o00<0oh000000
o`000?l02P000?l:0?n002/0003o3@3oP00<0000o`T0oh000P000?l70?n000030000o`3oP000oh00
00T0oh003oooool000gooooo00H0>d5J03i5G`10Af40?dEQ0455H`13AVD20455I00;0457I@12AVD0
A4MV04E7I`16B6P0ADUX04E;J@14BVT0A4Y[04E<KP16CFd00P15CF/02`16CV/0Adi]04U?KP1<D700
CU9c04mCM01@E7D0DUMh05=IN@1DFWT0EE]i0080EUei00`0Eeii05UONP1IH7/0FV5k05]RNP1LHg/0
GVAm05iSOP1PI840HfJ406=VP`1SIH<206AWQ00;06AXQ@1VJXL0J6b906Y]R`1YK8/0J6j<06Q`S01Y
L8`0JW6;06Y`RP1]LX/00P1_MHd02`1`MXd0LGJ=071gSP1_MXh0KWJ?06efSP1/MH/0Jg>906]cR01Z
L8L0Jg660080JFn200/0Ifio06M^O@1XKGd0JVmo06Y_P01[L840JW2106YbP01/MX00KWV107EnQP02
07V2R@0<07n7S@23RY80QHbD08N?U@28T9T0S9>M08fDW@2=U9`0SiNN092HWP2AVIh0TIZK0P2AVYP0
2`2BVi/0TY^L09>KWP2EW9h0UifP09JMX@2DW:00TifN09:NW@2CX9h0TYnM0080TYjM00/0T9bI08jL
U@2AWi@0OXUo04M7BP0i=cP0;2DU04E2>@1oR6h0EeY>055FB`0204iEB00<04A;?@0oAcL0@4Dh0454
>`1bO6P0UZF<09:QS`2:Uh/0Phj708:?R01NIV/0KWag0P2=XXl02`1oTWl0P9=k03e2>@0K5aH08B0L
01`J600I61D061HC01DC400H5Q@0Addo0080JGQR00/0H6eL06IeH`1VM6<0JGUW03Lk?00J6RD0:2ha
05EWE@0b?C409blU02Xc9`0202Xa900602Ta8P0Y<R80:c@T02/c8@0Z<Ql0:S4M6_oooolb0?n004@0
003o103oP0000`000?l0oh000?n000060?n000H0003o00<0oh000000o`000?l00`000?l90?n00080
003o0`3oP0000`000?l0oh000?n0000=0?n000oooooo000=ooooo`0503a1FP0m@ed0@4IP0415G`11
AV000`12Af402`10AV80@4IS0457I@14AfP0ADQY04=6J@13B6/0A4]/04E=KP16CVl0A4a^0080A4a/
00/0ADe[04I=J`1:D6h0C55`04eBL@1=DW80CE9c04mDMP1AEWH0DUQg05AJN00205MMN00405MNM`1H
GWL0FEih05YPNP80G6=l00H0GF9n05eQP01PHh<0HFB506=VQ@1TIhD206AXP`0306=WP`1VJHH0IfZ6
0080JFb600H0JFf706U_R01XL8T0Ig2906Q`R@1ZLHX206]bR`0;06edS01`Mh`0LGR<079hS`1aN900
KgR?071iS`1bNhl0M7f?07EmSP1gOXl00P1gOXh02`1dO8X0LWZ6075hQ01bMhH0LGB706iaQ`1ZKX@0
J6f206M^P01VKWd0JW1o0080KG>100/0KgF3079gQ@1fNXP0NGj<07b3S`20R980Ph^C08J>T`29TiL0
RiJH08jIVP03092KV`0;09>LW@2AVY/0Ti^L09FMW02FWY/0UYjL09>MW02BWI/0TYbK096MV`2BW9/0
0P2CW9/02`2BVi/0TI^G096MT`26THH0@T1603Ld>@0]:2d0I6YK0:BfTP1<CD80Bdm40080Be1500`0
AD`o0458>@0n@C@0@D4f06Y`GP2AWHD0UJ:?08fHR`2:UH/0O8F205MJHP1VLG0208VLS00;07f?O`1m
T7h0?dI301DC600O7b006QXJ01LG5P0G5Q@05Q@C01HC5019D4800P1^OVL02`1TLF00J7MU06]iI`1`
OV`0@TQ501PG8`0i@T80;3@c02Pa:`0X<BL0:34V0080:C4V00H0:34U02Tc900]=B<0;3DQ02Xa7`0Y
;adJoooooc80oh008@000?l00`3oP000003o0000o`0P0000o`@0oh0000<0003o0?n0003oP0001P3o
P0060000o`80oh0010000?l90?n00080003o00@0oh000000o`000?l0003o3`3oP00?ooooo`003Ooo
ool01P0m@EX0@4=N0496H@12AV40@DIP0497G`80@TMP00X0@TMQ04=7HP13AVD0@dIV04A6I`13AfP0
@TMY04=7JP14Bf`0ATi]0`15C6/02`16C6d0Ade^04Y@L01:DG40C59b04iBLP1@E7@0DEIe059GM@1C
Eg@0EEYe0080EUag00`0EE]g05EKM@1GGGH0FV1i05]QN@1MHg/0GF9l05iQO`1PHX<0H6:2069TP`1U
J8D206EXPP0;06EXO`1XJX40J6Z306Y/Q01[KHD0Jfn806Y^Q`1YKXH0J6j706U`Q`1ZL8L00P1/LHT0
2`1^M8`0KgF<071eR`1bMhd0LgV?07=hSP1dNY00MG^A07IkTP1hOi80NH2B0080N7n@00/0Mgj?07V0
S`1kPhl0OH:?07aoS`1kOY40N7b?07EjSP1cMhX0LGJ8071dQ`0206ibQ`0<06icQ`1]LHH0KW66071c
QP1cMXL0MWZ:07IlR@1iOhT0O8>:07n7S023S900R92C0P2:TY@02`2:Ti<0SIJE092HU`2CViT0UIbJ
09JNV`2DW9T0U9jI09BMV@2CWIX0TYbJ0080TIZI00/0TIZK09:KV@2BWY@0QY6504A1AP0b;S@0<Rla
07N3J`23TG<0D5A504Q=@@0204Y?A00<04=8?@0g>Rl0=CHZ03Db9`1IFDP0Uj:708fDQP2>UHd0S9B=
07b1O`1bMg@0I6UZ0P29VH/02`1nSh40O8mo03m6A00F51/07alQ01/K6`0J6QT06ATF01DC4@0D4Q40
D5Y70080KgiR00/0GFMD05URD`1LIUH0K7QU04eEB`0I61d0BE=901hQ8P0Q9R<09RhU02L`9@0202P`
8`0602P`8@0X<1l0;3@P02dd800/<Al0:RhM6_oooola0?n004D0003o0`3oP0020000o`T0oh001P00
0?l00`3oP000003o0000o`020000o`T0oh000P000?l30?n000030000o`3oP000oh0000d0oh003ooo
ool000gooooo00H0?d9G0413F@11A5d0@TAP0495H014Ael304=6GP0:04=7H012AF80@TAS0456H`11
Af80@TQS04=9I@14BFH0AD]X04M;J080Ade[00/0BDi^04Y>L01:Cg40BTmb04a@LP1=DG40Ce=`051E
K`1BEW00DeM`05AJL@0205ILLP0<05EKL`1FFg<0EUad05QNMP1JH7L0G61i05eQNP1NHW`0Gf9n065R
O`1RHX40IFJ30P1UJ8802`1WJWl0JFf006M[O`1XK840JFb306]]Q01ZKH@0Jfj506]_QP1[KXD0K6n5
0080KW6700/0Kg>:06mdRP1_M8X0LGJ;075gS01cMh`0MWZ>07MjT01gNi40N7f@07Z0T00207Z0SP0;
07UoSP1jP8h0Nh:>07f3S@1mPXl0OX>A07j4T`1oQYD0OhBD07n3U@1oQIH00P1nPiD0301kPI@0N7jA
07MlS`1gNX/0N7^:07IjR@1fNXP0MGV507MkQ@1hO8<0O7j507j1Q`80OX>800L0P8J908B;S@26SHl0
R8n@08jEU@2@UiD0TYVF0080U9bG00l0U9fI09:LV`2AVYX0TIZJ092HU`2AVIH0TYbC08ZCQP12?T<0
;bP^04mAB01YLEh0DE=704i>AP19BT<00P1;CdD03018CD40>cha03Pj:`0n?Bd0DU5009RQP`2@UXH0
VZ6F09>ITP25RH<0MGMd06a^JP80Sif;00/0PI1o07b=NP0g?3X05aHH020P7@0L71T06Q/G01TK5@0C
51005QLC05ERBP0205eZD00;03Lk;P0c=Rd0CE=306E`F@1?ETD081lL03@h;P0M7Q/08BLP02<Z8@0V
;R800P0W;b800`0W;b40:2lO02/a800202dc8@0302/`7_oooooooooo01Sooooo<03oP0160000o`<0
oh0000<0003o0?n0003oP000203oP00;0000oah0oh003oooool000gooooo00D0?d1D03m1EP10@eX0
@TEM04A6GP0304=5G00704=6G011AEd0@TEO0495H@11B680?dIP0498H@0204A:HP0504E;I016BVD0
ATYW04I:I`18CF/00P1:Cfh0201:CVh0Bdm_04aAL01=DVd0CUA^051EK`1AEfl0DeY^0P1EG6d0301E
G6l0EUaa05MLL`1GG7@0F5if05QNM`1LH7T0GF1h05mRN`1QHgh0Hf=o06EUP@80I6J000/0IFMn06M[
OP1VJg`0IV]m06AYO@1VJWh0JF^106Y]P`1ZKX@0JFb306a_P`0206i`QP0;06maR01`M8X0Kg>806md
RP1aMHX0LgV:07AhR`1fNHh0Mg^?07QlSP1jP8l00P1kPHl02`1jOhd0Nh2=07b0S@1lPHh0OH:@07j4
TP1mQ9<0OHFC07n6U@20QiH0Ph^J0080Q8bJ00`0Q8^J08>;V@24RiP0PhNF0865T`1nPi00Nh2<07Um
R01iOHH0NGb407]mP`1kOH8207anP`0;07f1QP1oQ8P0P8F80867R@25Rh`0R8f<08^@S`2>U9<0T9RF
09>JV02CWIX00P2BW9T02`2?V9@0SYRB08nISP2<UhH0@Ci102PM901[L5h0MGiX05]ND@1:B4@0BTY5
0080CE9800`0BU5404A9>`10A3@0@TDb04a=>`2>V7T0Tib60:bjY@2MYiT0RY6507n3N@1[KFD208ZG
P@0;08>AN`1iRG<0>3dh01@B500N7QT06QXE01LJ500E6A<04QH@01LL4`0g@Rh00P12CCL02`0_=2D0
:R`Q04YA?P1WMUT0DEa501`M600S9Qd08RLN02<Y800U:R009RdP00809bhQ00H09bdR02T`8P0/<R<0
;S@R02`b800Z;adJoooooc40oh0000<0003o0?n0003oP0000P3oP0100000o`80oh000P000?l:0?n0
00/0003o3P3oP0000`000?l0oh000?n0000=0?n000oooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {299, 0}} -> {-0.0508884, -0.0375078, \
0.00526762, 0.00526762}, {{9.625, 190.438}, {291.875, 156.25}} -> {-12.9439, \
-9.62807, 0.929149, 0.929149}, {{208.5, 389.312}, {291.875, 156.25}} -> \
{-197.728, -9.62807, 0.929149, 0.929149}, {{9.625, 190.438}, {142.688, \
7.0625}} -> {-12.9439, -148.245, 0.929149, 0.929149}, {{208.5, 389.312}, \
{142.688, 7.0625}} -> {-197.728, -148.245, 0.929149, 0.929149}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Two-channel classification experiments", "Section"],

Cell[CellGroupData[{

Cell["Show training and test images", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{trn, tst}, {s2, s1}}], \ 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
%%ImageSize: 400 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0178571 0.47619 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0178571 0.477324 0.357993 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
D6DBD8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
6E8279687C71B2BCB8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7D918983969084989080928CA2AFABBFC8C6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
83968C8798938B9C9A8B9B9D89999D86969A869798A6B3B3E1E5E6FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
82978F8A9C978C9D9D8D9DA08E9DA38C9CA48A999E8B9B9E8B9C9E8C9E9EC5D0D0E3E9E8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7F948D899E9A8A9E9D8DA0A190A2A58EA0A58DA0A08EA09E8D9F9D8EA19F8EA39F8DA49D
8EA69BC8D4CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
859C928AA19B8DA39F8DA3A18DA2A08DA2A08DA29F8EA29D8CA09B8DA19C8EA29A8FA49B
90A79B90A79B94AB9DAFBFB3CAD5CDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
82978F89A1988AA39A8AA19B8AA19B8BA29B899F988A9D958DA19891A59C92A69D93A79F
93A79D93A69C95A79D94A69C97A99E90A297C5CECAE1E5E2FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
859B93879F9887A09986A09A879F978AA1978BA0978DA1998DA19A8FA29D90A49D92A59D
94A79E95A79E96A69F99A9A197A89F96A79E94A59B94A69A76857FB8BFBCD1D3D4FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
81948D899E968BA29B8BA29C899F9C869C99899E9B8CA09E8EA19F8EA1A090A4A090A39D
92A59E96A79F95A49E99A9A297A6A099A9A197A89E95A79E97ABA08EA195728177838A86
AAAFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
8294898BA0988CA49D889E9D889F9E879DA0889DA0899FA08DA1A08FA2A191A3A393A6A4
94A7A497A8A397A9A198AAA098A8A098A8A19BACA49AACA398ACA296ABA195AA9E8CA195
7E90846A7B6C78817AA2A5A2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
879B918EA39D8EA5A38BA4A48AA2A68BA1A5899FA1889EA08BA0A08DA2A292A6A493A6A4
93A6A394A7A396A9A196AAA099ABA19BACA39AAAA699AEA799ADA798ACA498ADA499AEA5
97ADA395AA9D8CA0906370685C6760B8C0BACFD1D2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
889E968DA49E8EA5A48DA4A68DA3A78CA2A78BA0A68A9FA38CA1A28EA3A390A5A491A6A3
93A8A295AAA296AAA294A7A098AAA39BACA69BADAA9AAEAB99ADAA9BAFAC99ADAA99ADAA
9AAFAA9AAFA79CB1A698AC9F87978E7887805D656852575EC0C6C2E0E3E0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
849A938BA19B8BA29E8CA1A0899EA08A9FA38CA1A58BA0A38CA1A38DA3A28FA6A591A9A7
92AAA595ACA596ACA395A9A598ABA997AAA998ABA89AACAB9AADAB9AAEAB9BAEAC9CB0AD
A0B3AEA0B4AD9FB0A7A0B3A67C8B83626B6A666F6E727B7999A89B94A397B1BDB4CFD8D1
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
8698958C9F9F8EA2A58B9FA5889DA2889DA18BA0A28CA1A18CA1A090A4A490A4A790A5AA
93A9AC92A8A993A9A697ABA89AAEAD98ACAD99ACAC9BADAC9CADAB9CADAAA0B1AFA2B2B0
A1B2ADA0B1ABA1B1ABA2B5AC899992656D6F666D6E8F9D949BAAA09FACA3A4B3A7A6B5A9
A7B6ABB8C2BCCCD1D0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
8899998D9FA58FA1AA8C9EA88B9EA78DA0A88FA2A78FA1A390A3A491A3A690A3A891A5A9
91A6A991A8A991A7A894A8A998ACAE96ABAF97ACAD9BAFAD9EB0AC9EADAC9FAEAFA1B0B0
A3B3B2A3B4B2A5B5AFA5B5AF9CACA895A3A08F9B9797A69EA3B2A7A5B2AAA7B5AEAAB6AF
AAB5B0ABB5B0A8B2ADA9B3ACD4DAD5EAEEEBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
849697899BA28DA0AA8D9FAB8B9DA98C9CA68D9DA68E9FA491A2A792A3A88FA1A693A6A8
93A8A992A7A892A7A994A8A99AAEAF9CB0B19AAEAD9AADAE9AAEAD9CAEAD9EAEACA0AFAE
A1B1AFA2B3AFA1B2ACA5B5AEA5B5ADA4B3AAA1AFA7A3B2A9A6B5ABA8B4ADA8B5B0ACB8B4
ADB7B3AFBAB6AEB8B3ADB9B2AAB4ACACB9ABABB9A4D5DBD1EAECE7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
819899889EA08BA0A58C9FA88B9DA88B9CA48C9DA38C9CA38E9FA590A2A790A3A792A4A5
92A5A693A6A992A7AA93A7A997ABAB98ACAC9CAFAE9AADAE9DB0B09AADAE9EB0B0A0B1B3
A2B1B5A2B2B4A1B1B1A4B5B2A6B5B0A6B3AEA6B4AEA5B3ADA5B3AEA8B5AEAAB7B1ABB8B3
ACB7B4ADBAB6ADBBB5AEBCB5ACBAB0AABAACAEBEABADBDAAADB9A8C2CCBFD8DFD6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
809697889FA28CA2A88CA1A9889DA68A9DA58C9DA58E9FA88E9FA98E9FA890A2A993A5AB
92A4AA93A6AD94A7AD94A7AC95A6AB96A7AC99ABAF9AABB19CADB29DADB49FAFB5A2B3B8
A2B1B7A2B0B5A2B0B5A2B1B4A6B4B6A6B2B3A8B5B5AAB7B6A9B6B4A9B5B0AAB6B0ACB9B5
AFBBB8AEBBB8ADBBB6ADBBB4ADBCB1ADBCADB1BFADB1BFADB1BFAEB2BFAFB0BDAFB2BDB1
C2CAC2D7DFD8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
839699899EA38DA2A98B9FA9899EA78A9EA68B9CA48DA0A68FA1A98D9EA793A4AB93A3AB
94A6AD93A4AC94A6AD94A4AC95A4AC95A3AC95A4AC96A6AD9AA9B09BA9B09EACB3A2B1B7
A3B2B8A4B1B6A4B0B5A6B2B6A4B1B5A7B3B4A8B3B3A8B4B3A9B5B2ADB8B4ACB8B6ACB8B6
AEB9B7AFBAB8ADBAB7AEBDB5AEBDB3AEBDAFB1BFB0B3C0B0B2BFAEB3BFAEB3BEAEB6C0B1
B4BFB0B1BFB0ADBBADD2D9D1E5EAE5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
76868C8C9FA1899DA48599A48497A3869BA4889BA38D9FA68EA0A88FA0A98E9FA791A2A9
92A3AB92A4AB93A5AB93A4AA96A6AD99A7AE99A8AF97A7AE97A7AE9AA8AF9AA8AF9BA9AF
9DACAFA1AFAEA3AFAEA7B3B3A6B2B5A6B1B4A6B2B1A7B3AFA9B3B0ACB7B4ADB8B7A9B4B3
AAB6B6ABB8B6ABB9B4ABBAB2ABB9B0B0BFB2B0BFB0B0BDADB0BDACB3BFADB3C0ADB5BEAC
B4BFACB5C1AFB4C0B0B1BEADAFBDAA97A491BEC0BADCDDDAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7C8E90839899879CA1879BA48497A38497A48496A38B9BA78E9EAB8E9FAC8D9FA98C9FA8
8FA3AB8DA1A890A4A891A4A894A6AA95A8AB96A9AA96A9AA98ABAB98AAAC98A8AB9CAAAE
9DACAE9FB0ACA3B2AEA4B1ADA7B4B0A9B5B1AAB6B1A9B6B1A9B5AFA8B4AFAAB7B3A8B4B3
A9B6B6A9B6B5AAB7B3ACB9B4AFBBB5AEBBB1B0BEB1B2BFB1B1BEAFB2BEAEB3BFACB5C0AC
B4BEACB6C0AFB5BFB0B5C0AFB6C0AEB4BDACABB4A3A7B09EBDC3B7CBCEC8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
819591899B9A8B9EA2889BA38496A28597A2879AA38A9BA28C9CA38C9DA58D9EA68D9FA6
8DA1A88EA3A88FA2A590A4A692A5A991A5A790A5A693A7A795A7A797A8A99AA8AB9DABAC
9DAAAB9FACACA2AEAFA3AFB0A4AFAFA7B2AFA7B2AFA9B5B1AAB6B1AAB5B0A9B4B1AAB8B4
A8B5B4AAB8B4A9B6B0ACB9B2AFBAB2AEB9AFB0BCB1B3BFB2B3BFB2B3BFB1B5BFB0B4BFAD
B5BEADB7C1AFB8C3B1B6C2B0B7C2AEB6C0ABB6BEACB5BDACB4BEAAB3BDA8ACB8A2BEC7B7
A4A1A3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
768886869B9A889DA1879CA3879AA48699A6889CA8899DA68B9EA68C9FA58C9FA58B9EA5
8A9FA68DA2A68FA3A592A5A791A5A892A8AC90A7A894AAA995A8A699A9A89BABA99FAEAC
A1ADAEA2AEAEA6B0B2A8B1B2A5AEB0A9B3B2A9B3B0ABB5B2AAB4B0ABB5B2ABB5B2ADB8B5
ADB9B4ABB7B1ADBAB2AEB9B2AEBAB2AFB9B0B1BCB2B2BDB2B3BFB3B5BEB3B4BFB0B6BFAF
B6BFADB8C2AEB7C1AEB7C1AEB6C0AFB5C0AEBAC4B1B9C2AEB9C2ADBAC3ADBAC4ACBDCAAD
7D7F73494343A8A7A3E2E5DEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
748886809597869AA1889DA7889BA8899CAA889AA9899DAA8B9EAA8A9EA78DA1A890A2A9
8FA1A991A3AB91A4AA91A4A893A7AA96A9AE94A7AD95A9AE99ACAF9AABAE9CABAE9EABAE
9EADAFA1AEB0A4B1B2A7B2B2A5B0B1A5B1B2A8B6B4A9B5B2ABB7B4ACB6B7ACB7B8ADB8B9
AFBBB8B0BBB7B1BDB6B1BCB7B2BBB6B1BAB5B3BEB7B3BFB7B4BEB5B3BFB3B5C1B3B6C1B0
B8C1AEB9C1ADBDC5B1BBC2B2BBC2B4BBC3B6BBC2B5BDC3B6BEC5B4BDC6B1BCC6ADBECAAC
B7C3A47D816F5E5A55B1BCA1989E8CD4D9CEE8EBE5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
71848582959B8599A3869AA68497A58599A58598A5869AA5889DA68BA0A88DA1A78C9FA7
8C9EA98EA2AB8FA5AB8BA0A68DA3A691A6A995A9AE96AAB197A9B397A9B29BABB29CABB0
9BAAAF9EADB19DADB09FADB1A0ADB2A3B0B3A6B3B4A6B4B4A8B5B7A7B3B7A8B2B6ABB5B8
ACB6BAACB5B8AEB8B7ACB5B4AFB6B5B0B8B5B1BCB9B0BCB8B3BFB8B2BDB5B3BEB5B5BEB2
B6BFB3B7BFB2BAC0B1BAC0B4BCC2B8BAC2B9B9C1B7B9C2B4B9C3B4BBC4B2BAC4ACB8C3A9
B8C2AAB5BEA9AFB4A3B4BAA7B6BDABB5BFAAB2BDA6C4CCBAB0B0AEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
79898C81939D8093A18093A28195A28598A38599A28498A1879BA4899DA58BA0A88A9FA8
8B9FA98B9FA78AA0A88BA0A88C9FA690A2A995A7AE94A5B095A6B297A6B298A5AF9AA9B1
9CABB29CAAB19CAAB29DABB3A0AEB4A3AEB3A4AEB3A4AFB4ABB4B8AAB3B7A9B2B7AAB3B9
ACB3BBACB4B9ADB7B8ADB6B6AFB6B4AFB6B3B2BAB6B2BBB7B3BCB6B3BDB6B4BFB4B3BEB2
B2BDB0B4BEB0B5BEB0B6BFB2B9C2B6B8C2B6B7C4B6B5C2B5B5C2B2B6C3AFB7C3AEB9C4AE
BAC3ADBCC3AEBAC1ABBBC1ADB9C0ACBBC3ADBDC4ABBAC3A9ACB19DA9AD9AC1C6B5EDEFE8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7B8A9081949E8498A48398A38296A28396A18497A28699A48699A6879AA68B9DAB8A9CA9
8B9EA88EA1A98CA0A88CA0A88EA1A990A3AA93A4AC94A7AD95A4AE96A4B19AA8B49AA7B5
9CAAB69FABB49FACB5A0ACB7A3B0B9A4AFB7A6B2B6A6B1B4A8B2B3A8B1B3A8B1B4ACB6B7
AEB7B9B0B9B9B0B9B8B0B9B7B0B8B3B1B9B3B4BDB5B4BDB4B5BDB5B4BDB3B4BDB2B3BDAF
B4BFAFB4BFAFB4BEAEB5BEB0B6BFB0B4BEB0B6C1B2B8C4B4B8C3B3BAC5B3B9C4B3BAC3B2
B9C3ADBAC3ACBDC6ACBFC6ADBFC6ACBEC5ACBEC5A9BEC6A9BFC7A9BCC3A8BBC2A6BBC3A5
BAC3A3DDE3D2EEF0E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
76878C80949A83979E849AA08397A08699A48597A38597A68699A6899BA78998A58C9CAA
8C9DAA8E9FA88FA2A991A4AA8FA1A990A1AA90A1AE94A4B098A6B097A4B198A5B39BA7B5
9CAAB69CABB49CAAB39EADB6A0AFB7A0ADB4A1AFB2A4B1B2A7B1B1A9B2B1ABB4B4ACB6B6
ACB4B6ADB7B7ADB6B6AEB9B6AEB9B4AFBBB2B0BCB1B2BEB1B3BDB3B2BCB2B2BDB3B3BEB3
B2BCB1B8C2B4B8C2B3B8C1B3B9C2B3B9C3B0B9C4B1BAC4B2BCC5B4BBC3B4BCC6B7BBC4B6
BCC5B4B8C2AEBAC3ADBDC5ACBFC7ABBFC8AAC0C7A8C1C8A7BEC5A6BFC7A8BFC7A6C0C8A5
BEC8A3BBC6A1BAC69EB6C19ADCE3CEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7081887E929883969E85979F84969E8598A08697A18798A28698A28697A08899A28C9CA5
8C9BA78D9CAA8F9FAB8F9FA890A1AA94A2AC95A3AE95A3AE96A3AE9BA7B19BA7B39AA6B2
9AA7B39CA9B39CAAB29BA9B29CA9B39EACB3A2AFB4A4B0B3A6B0B1A8B2B0ABB3B2ACB6B6
ACB5B8ACB5B7ACB5B8ADB6B7ADB8B5B0BBB4B0BBB3B0BBB2B4BDB3B4BDB4B4BCB5B6BDB5
B8BFB5B9BEB4BBC1B5BBC0B6B9BFB5BAC2B4B8C0AFBAC2AFBDC3B3BDC4B5BAC1B4BEC5B6
BEC6B3BDC6B0BCC6AEBEC9ADBEC9ABBDC7A6BFC8A4C1C8A5BEC5A5C1C7A8BFC6A6C0C5A5
C1C7A5BEC8A3BCC6A2BBC6A1BCC7A0BCC89FC0C7ADD0D2C3FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
73848C80929A8397A08597A18496A08496A38396A2879BA4879BA2879BA18C9EA58D9FA7
8E9EA98E9CA8909FAD93A3AF95A2AE96A4AF97A4AF96A4AE99A6AE9AA8AE9AA8B19CAAB5
9BA9B59DA9B49DABB5A0AEB79EADB49DABB1A1AFB1A2B2B0A5B3B0AAB6B2A9B3B0ADB5B3
ABB3B4ADB6B8AEB7BBAEB9BBAFBABBB0BBBAB0BBB7B2BEB8B4BEB6B4BCB3B4BCB3B6BFB8
BAC3BBBABFB7BDC3B9BABFB7BABFB4B9C0B3BAC3B3BAC2B1BFC6B4BFC5B4BEC3B4C1C7B5
C1C8B2BFC7AEC0C8B0BFC8AFBEC8ABBEC7A8C0CAA7C1CBA7BDC7A5BFC8A8BEC7A7BEC6A7
C0C9A9C0C9A6BDC7A2C1CCA5C1CBA5BFC9A4BEC7A2BDC7A2B9C3A0CED5BCEFF2E9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7A8F8E869B9C899EA38899A48594A38696A78596A78698A7879BA8879BA4889BA48D9EA8
8D9EAB8EA0AB8DA1AD8FA2AD90A1AD93A3AF94A4AD93A4AC97A7AE99A7AF9AA7B09BA9B3
9FABB49EAAB29FABB39FADB3A0AEB4A1AFB1A1B0B1A3B2B4A3B3B2A5B3B0A6B1AFAAB4B0
AEB7B4AFB7B6AEB7B7AFB8B7AFB9B7AEB7B5B0BBB7B0BBB7B0BCB7B0BBB6B2BBB6B5BDB8
B8C0BBB6BCB8B7BFBABBC1BBBBC2B8B9C2B6B9C1B4BAC3B3BBC4B3BEC5B5C0C7B7BCC4B2
BDC4B0C1C9B2C0C7B0BFC7AFBBC5ABBBC5AABFC8AABEC9A9BCC7A8BDC6A8BDC5A7BEC7A8
C1CAA9C1CBA8C1CBA6C2CCA8C1CBA6C0CAA6BEC7A3C0C9A5BFC8A7BEC7A7BDC6A6BAC5A4
D7DCCCE6E8E1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7D909284969E8799A38796A48793A78996AC8999AE879AAC899DA9889DA4899CA38A9EA4
8A9EA78C9FA88DA1A98EA1AA91A2AC91A2AE92A3AD92A4AC96A8AF97A6AE9AA7AF9AA7B1
99A6B09DAAB29EABB1A0ACB2A1ACB19FAAAFA1AFB1A4B2B4A5B2B4A4B2B4A5B0B2A8B2B2
ABB4B5ACB4B6ADB6B6AEB8B6ACB6B5ABB5B4AEB8B6B1BCBAB0BBB9B0BBB8B1BAB7B3BDBA
B3BCB9B5BDB9B6BEB9BAC0B9BBC2B9BABFB6BABEB8BBC0B8BBC1B8BBC2B8B9C1B7BAC2B6
BBC4B3BDC7B3BDC6B1BEC8B1BEC8AFBEC6ADBFC7AEBFC6ADBFC7AEBFC7AFC1C9B0C0C6AD
BEC3ABC0C6AAC0C9AAC1CCA8C1CBA7C0C9A8BEC8A7BFC8A9BEC7AABFC8AAC0C8A9BDC5A8
BBC4A7B6BFA4B8C1A6DCE1D3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
8291958695A08998A88797AA8896AC8695AC8392A98395A9879BA9899DA88A9EA78C9FA9
8DA0AA8EA1AB8EA2AC92A3AD91A0AB94A2AE94A3B096A6B295A5AE9AA8AF99A7AD9BA7AD
99A5AE97A4AD9CA9B09EABB1A1ACB1A2AEB3A1AEB1A3B1B3A3B0B0A4B0B2A6AFB2A7AFB2
A9B2B4AAB4B4AAB3B3AEB8B6B0BABBAFB8BAAEB7B8ADB7B7AEB9B9B1BABBB3BCBCB5BCBC
B5BCBDB7BCBDB8BDBCBBBFBDBBBFBDBCC0BCBBBFBABCC1BBBAC0BABCC4BCBCC4BABBC4B7
B9C3B2BBC5B3BCC5B2BDC7B3BDC7B3C0C8B6C1C8B5C0C6B4BFC6B4BEC5B2C1C7B2C3C8B2
C3C7B0C3C7B0C1C7ACC3CAADC1C7A9C2CAACC2CAAEC1C9AFC0C8ADC0C8ACBFC6AAC1C9AC
C0C7ACBDC5AABBC2A8BBC4A8B8C3A6C8D0B9D7DDCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7E8F958495A18698A78495AA8395AC8495AB8396AA8598A9869CAA869CA8889BA88B9DAA
8E9FAC92A3AF91A0AD92A0AD94A1AD97A4B199A4B398A5B398A6B398A8B09AA8AF9AA8AE
9EACB19CA8B09BA8AF9DAAB0A0ADB2A0AEB29FACB2A0ADB3A3B0B5A4B0B5A7B1B6A8B2B5
AAB3B7ABB5B7AAB6B5ADB8B6ADB7B7B0B8BAB1BBBEB0BABCAFBAB7B1BCB8B5BCBBB7BDBC
B7BBBBBABEBEBBBFC1BDC1C3BCC0C3BCC0C1BCC0C0BCC0BFBABFBCBBC2BDBAC2BBBDC6BA
BFC8B9BEC5B6BEC5B5C0C6B7C0C6B7BFC5B6C0C6B7C1C8B8C1C9B9BFC8B8C0C8B7C1C8B6
C3C8B4C5C9B4C3C8B1C5CAAFC2C8ADC2C9AFC3C9B1C3CBB1C3CBB2C1C8AFC1C9ADC1CAAD
C1C9AEC1C9B0C0C9AFBEC7ACBEC9ADBCC7ABBBC7AAB7C3A6C6CFB9ECEFE8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7A8D948295A1879BA98698A98394AB8293AA8496AA8698AB8699AC889BAD8A9DAF8D9DAF
8EA0B091A2AF92A1AE95A1AF949FAF96A2B196A2B196A3B199A7B298A6AF99A7AF9BA8AF
9EACB19CAAB0A0ADB29EAAB1A2ADB4A3AFB6A6B1B7A3AFB7A4AFBBA5B0BDA5B1BAA4AFB7
A6B2B8A7B3B8A9B6B9ABB8BAACB7B8AFB9BAADB6BAB0B9BEB0B9BCB1BBBCB4BBBDB6BBBE
B6BABDB7BCBEB8BEC1BBBFC2BDC2C2BBC1C0BBC2C0BAC1BEBAC1BCBDC3BCBCC2B9BFC6B9
C2CABABDC5B5BEC4B3BEC5B3BDC4B2BEC6B4BEC4B6C0C7B8C0C8B9C1C9B9C1C9B6BEC6B3
C1C7B3C5C8B2C5C9AFC4C7ACC4C8ACC5C9B0C4C8B1C5C9B3C4C9B2C3C9B0C2C9AEC3C9AD
C4C9AEC3C8AEC3C9AFBEC5AEBDC4ADBFC7AEBEC6ACBDC6AABBC5AABAC4A8B9C3A6DBE1D2
ECEFE8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7D8E9181939B8598A38697A78394A68898AA8897AA8999AE8596AE8697AE8899B08A9CB2
8C9EAF91A3B092A3AF92A0AE94A1B094A2B294A3B195A4B297A5B39BA8B59DA9B69DABB7
9BA8B59CAAB4A0ACB2A1ACB2A2ADB3A3AEB4A3AEB6A3ADB7A2ACB9A4AEBDA4AFBDA5B0BC
A6B1BCA8B5BDA7B4BCA9B4BDACB5BDADB5BDAEB6BEADB5BEB0B8C1B1B8C0B3B9BEB5BCBF
B5BCC0B8BFC2B6BEC2B8C0C1B4BCBDB6C0BFBAC3C1B9C2BFB8C0BDBDC4BEB9BFB9BBBFB8
BEC4B8BEC5B7BFC8B8C1C8B6BFC5B4C0C7B6BEC4B6BFC6B7C0C8B8C1C8BAC1C8BAC2C9B6
C4C9B2C4C9B0C5CAAFC5C9ADC6CBAEC3C7ADC5C8B1C6CAB5C5C9B5C6C9B4C5C9B1C4C8AF
C5C9AFC6C9B1C6CAB3C3C8B3C2C8B4C0C6B1C0C8B0BFC6ADBEC4A9BEC7A9BEC7A7BAC6A6
B6C3A6A8B29AD7DDD0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7A8C8F82939B8395A18596A68596A58796A68999A78797A88596AA8699AB899CAE8A9DAF
8B9FAD8C9FAD8DA0AD8FA1AE90A0AE91A0B291A0B191A1B198A6B49AA7B599A5B59AA5B6
9AA5B89DAAB89EACB6A0ACB5A1ADB4A0ADB6A0AEB6A2AFB5A3AFB8A6B1BDA6B0BDA5B1BE
A5B1BFA6B2BFA6B2BFAAB3C0ACB5BFAFB7C0AFB7C0B2B9C2B0B7C2B2BAC3B0B9C0B3BDC1
B5BFC2B6BEC2B5BFC1B6BFC0B8C1BFB6BEBCB4BCBAB6BEBCB5BEBBB8C1BDB9C1BBBBC2B9
BEC4B9BEC3B9C0C6BDC1C6BEBEC3BABFC3B9BEC4BABEC3B9C1C7BBC0C6BAC0C5BAC3C9B9
C7CBB9C4CAB3C2C8B0C5CCAFC5CAACC6CAAEC5C9B1C5C8B2C5C8B2C2C6B2C6CAB4C3C7B2
C3C6B2C2C6B1C4C7B1C3C5B2C5C9B6C2C6B3C2C6B0C1C5AEC0C6ACBFC6A9C0C8A9BDC5A9
BBC4AAB9C3A9B5C0A7B3BFA8C5CEBDCCD1C8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
788A928397A08699A78497A78597A88597A68696A68698A88496AA879AAC889DAB899DAB
899EAC8A9EAC8A9CAA8B9EAA8D9EAC90A0B191A0B393A2B696A3B698A6B69BA8B799A5B5
9BA7B79CA9B79CABB69DABB69EADB79EADB7A0AEB8A2AEB8A6B2BAA7B2BBA6B1BBA5B0BA
A6B1BDA5B2BDA7B3BDA9B3BEAAB2BEADB6C0AEB7BFAEB7BEAEB6BEAFB9C0AEB8BEAFB8BF
B0B9C0B1BAC0B3BBC0B4BABEB5BCBFB6BEBFB6BEBFB6BEBEB6BDBDB8C0BBB9C1BBBBC1BA
BBBFB9BBBFBABEC3BDBFC4BEC0C6BEC1C8BEC0C7BEBEC3BDBDC3BBC0C6BCBFC5B9BFC5B6
BDC2B1C0C6B2C0C7B2C0C8B0C3C9AFC3C7AFC4C7B1C1C5B1C3C7B3C1C7B3C2C9B4C3C8B3
C1C7B3C2C6B2C4C9B4C1C6B3C4C9B6C3C6B4C1C4B1C2C5B1C0C5B1BEC5ADBEC5ACBDC4AA
BEC7AEBCC7ADB6C1A8B5C0A9B6BFA9B5BFA8B3BFA6BFC7B7EAECE7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7F93998396A0869AA68598A8879AAB879AAB8395A88599AB869AAA869AA98699A7879BA8
8A9FAC8CA0AD8EA2AF8FA2AF91A3B191A1B293A1B595A1B795A2B696A3B598A5B59CA8BA
9AA7B89BAAB79CACB69EADB6A2AFB7A2AEB6A3AFB9A4AFBAA5AFBBA8B3BBA9B4BBA8B4BB
A8B4BBA8B4BCA7B2BCACB5BFACB4BEADB6BFACB6C3ACB6C2ADB7BFADB7BEAFB9C0B1B9C2
B2B9C0B1B8BFB4BBC0B5BBC0B6BCC1B6BEC2B4BEC1B4BEC0B6BDC0BAC2C2BAC0C0BBBFBF
BCC1BFBCC1BDBDC3BDBCC3BCBBC3BCBBC4BCB9C1BCBEC4C0BEC4BEBDC3BDBCC2BCBFC4BC
BFC5B8BEC4B5BDC3B5C0C6B6C0C6B1C2CAB3C1C8B1C0C7B1C2C8B3C3C7B3C2C7B3C4C9B4
C6CAB6C5C9B6C1C6B4C2C6B4C4C8B5C4C7B6C2C6B4C1C6B4BFC5B2C1C7B0BFC6B0BFC6AF
BEC6AEBEC7AEBDC6ADBBC2ABBBC2ABBBC2ABBAC2ACB5BDA9B5BEAAB1BDA4D4D9CEE6E7E3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7A8C978396A18599A88598AD8698AD869AAE869AAD889DAC859AA8899DAB899DAD899DAB
8BA0AC8EA3AD90A4B08FA3AF90A3B193A3B494A4B794A4B894A4B697A7B697A7B59AA9B8
9CABB99DACB79FAEB89FAEB7A3B0B8A6B3BAA6B0BBA4AEBAA7B1BCA9B4BDA9B4BBAAB6BD
ABB6C0ABB7C0AAB7BFABB9C0ACB9C0ADBBC2AAB6BFADB9C4AFBAC4AEBAC2AFB8C0B2BAC3
B3B9C1B4B9C0B5BBC2B6BCC2B9C0C5B7BDC5B7BEC5B9C2C7B9C1C4BCC4C4B9C2C0B8C0C0
B8C0BEBAC2BDBBC4BDBBC4BCBBC4BABBC3BCBDC4BDBFC7C0C0C5C2C1C6C2C1C6C2C3C8C5
BFC4BFC1C7BDC3CABEC2C9BEC1C8B9C3CCBAC3CBB6C4CCB5C5CDB6C4CCB5C3CAB5C2CAB6
C2C8B7C3C9BAC1C8B9C2C9B9C2C8B8C2C9B9BFC5B7C1C6B7C0C6B6C3C8B5C3C9B5C2C8B5
C1C8B6C0C6B3C2C8B2C2C8B1C1C7B1BFC6AFBFC6AFBEC4AEBDC5B1BBC3B0B7BFADB4BCAA
AAB39FD3D9CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
788A968092A28496AA8496AD8395AE879AB18599AC8698A98598A78799A88C9EAC8C9EAB
8C9FAA8EA2AB92A4B091A3B08F9FB08F9FB28FA0B391A3B493A4B395A6B298A8B498A7B2
9BABB69BABB69CACB59FADB5A1AFB7A2AFBAA6B0BBA2ACB7A5B0B9A8B2BBA9B3BBAAB5BC
AAB5BDACB6BFACB6C0ABB8C1ACB9BFAAB7BCAAB7BDADB7BFB1B9C1B2BAC3B4BBC4B5BAC3
B4BAC3B5BBC3B7BCC3B7BAC2B8BBC4B6BAC3B8BCC4BAC0C3BAC0C3BBC1C2BBC0C0BBC1C0
BBC1C1BBC2C1BCC5C1BDC5C0BAC2BABFC5BBBDC2B9C0C5BDBFC4BDBFC3BDBFC3BFC0C5C1
BFC4BFC3C7BEC1C6BCC0C5BAC1C8BAC0C7B6C1C8B5C4C9B4C5C9B6C6CBB9C3C8B8C2C8B8
C1C7BAC1C7BCC1C9BDC1C8BCC1C8BAC3CABAC1C7B8C1C7B6C3C7B3C4C8B3C5C9B6C5C8B7
C3C7B8C3C7B7C4C8B5C2C6B2C1C7B2C0C6B0C0C6B0BFC4B1BEC4B3BCC2B1BBC1B0B8BEAE
B6BCAEB5BDADA8B0A0B8BEB2C6C9C4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
798B968192A28696A88696AD8091AA8192AA8094A68396A68699A5899BA68999A7899AA8
899BA98A9DAB8D9EAC8F9EAD93A0B08F9DB0909FB290A1B393A5B495A7B295A5B098A7B4
98A7B797A7B59BABB69FADB7A0ADB8A0ABB7A1ABB8A1ABB7A4AFB8A6B0B9A8B0BAA9B1BA
A8B1BCA7B1BEA7B1BDAAB5BFAAB5BFABB6BFADB8BFAEB7BDB1B7BDB1B8BCB3B9C1B4BAC2
B3B9C1B4BAC2B6BBC2B7BDC0B8BDC3B6BBC2B5BBC0B5BBBEB7BDBFB8C0BFB8C0BEB9C0BF
B7BEBDB7BEBEBAC1C1BABDBEBABEBCBBBFBBBCC1BBBDC2BBBEC3BDC0C5BFBFC3BFC1C3BE
C3C5BFC2C5BDC1C3BBC3C6BDC1C6BBC1C7B8C2C7B6C2C6B3C3C8B5C3C9B6C0C7B4C1C8B8
BEC4B8BEC3BABEC3B9C0C8B9C1C7B9BFC5B7C0C7B7BFC5B5BFC5B2C3C8B2C3C6B0C2C4B1
C2C6B2C1C6B1C1C5B0C1C5B0C0C5B2BCC2B0BDC2B1B9BEAFB8BDAEBCC1B1BAC0B1BAC0B2
B9BEB2B8BDB0B6BAACB3B8AAB1B7AAA0A699B4BBAFE7EAE5FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
758A927E929D8294A38393A78293AA7F90A98094AA7F94A78497A68497A78799AB8899AC
879AAB889CAB8A9BAA8C9CA98E9EAD8F9DAE91A0B28E9EB18FA0B492A3B592A0B396A4B5
96A4B597A5B49AA8B69DABB89FABB7A0AAB8A1AAB9A2ABB9A2ACB7A2ACB4A6ADB5A8AFB8
A9B1BBA9B3BEAAB4C0ABB4C1ACB4C4AAB2C1ACB4C2ADB4C3B2B8C3B0B7BFB3B9C1B3B9C2
B3B9C2B4BAC3B4B9C1B5BAC1B8BDC5B8BCC6B6BBC4B4B8C0B4B9C1B5BBC1B6BCC1B5BCC0
B5BDC0B6BCBFB7BBBEBABDC0BCC0C2B9BCBDBABDBCBCBFBEBEC1BEBFC2C1BFBFC1BFBFC0
BFBFBFC2C1C0C0BFBFC1C2BFC0C2BFBEC1BDC0C5BEC3C7BDC1C7BCC1C6BCBEC3B9BEC4B9
BEC4B9BEC3B8BFC3B6C0C5B6C4C6B8C3C5B8C1C5B6BFC3B4BFC5B3BFC5B2C4C7B3C3C4B3
C1C3B4C1C5B8BEC2B5BDC3B5BBC1B4BAC0B4BEC4B5BBC0B2BABEB1BABFB1BBBFB3BBC1B5
B8BCB2B8BCB1B6BBAFB4BAAEB4BBB0B1B9B0AEB6ABABB4A8A7B3A2D2D7D0D7D6D8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
788E937C929B8296A18295A48092A58092A88093A98396AB8396AA8597AA8899AE8C9DB2
8B9BB18D9FB18B9BAD8D9BAE8F9EB0919EB092A0B193A1B495A3B695A4B797A5B695A3B4
95A4B496A3B49AA7B89DAAB99FACBAA0ABBAA0A8BBA3A9BBA4AAB9A5ABB9A4AAB6AAB0BB
ACB4BFACB2C1ABB2C0ABB3C2ADB5C3ADB4C2ADB3C5B1B6C7AFB5C5B1B6C4B3B8C3B4B8C3
B4B7C4B4B8C4B5B9C3B7BAC3B6B8C1B9BDC6B6BCC5B5BAC3B6BCC5B4B8C2B7BBC3B8BEC6
B9C0C8B6BCC4B7BDC3B7BDC1BABFC2BCC0C3BBC0C1BCC0BFBDBFBDBFC0BFC1C1C2C0C0C2
C0C0C3C2C0C2C2C1C4C1C0C3C2C1C3C1C1C1BFC0C0C0C3C2C1C4C2C0C5C0BDC2BDBEC3BD
BEC3B9C1C3B9C0C2B7C1C3B7C3C4B7C4C6B8C3C5B6C2C5B5C3C6B6C2C4B5C3C5B6C3C5B5
C2C3B7C1C2BABDC0BBBDC2BBBDC2BBBCC1B8BBC1B6BBC0B3BCC1B4BAC0B2BAC0B0B9BFAF
BAC0B2B9BEB1B8BDB1B5BAAFB4BAB0B5BAB1B3B9B0B0B7ADAEB7ACAEB7AF929797919995
9C99A2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7587948094A08195A38397A77F93A38092A38091A58395A88494AA8394AB8796AE8997B0
8998AF8C9AB08C9CB18C9BB08E9AB0909AB1929DB395A1B497A3B696A1B597A3B697A4B5
99A7B59AA6B59BA7B79BA7B69BA5B69DA8B99DA5B9A2A7BBA5A9BDA6A9BCA7A9BEA9ACBF
ABAEC0ACB0C2ADB1C3B0B6C4AFB6C3AFB5C3B0B6C6B2B7C7B0B4C4B1B5C3B1B5C2B3B7C2
B4B7C0B4B7C0B5B8C2B4B7C0B5B9C0B5B9C1B6BAC1B4B9C1B6BBC2B9BCC3B7B9C1B9BCC3
BABEC4BABDC3B9BBC2B9BBC2B9BCBFBABEBFBCBFBEBCC1BCBCC1BBBEC2BBBEC2BABFC0BB
BEBEBBBBB9B7C0C0BCC1C0BEC0BFBDBFBEBDC0C0BEC0C1C1BFC0BFBDC0BEBDC1BCBDC1BA
BEC3B8BCC0B4C0C2B6C2C2B6C1C2B6C0C1B6C0C3B6C0C4B5C1C3B3C0C2B1C0C1B0BFC0AE
BEBFB0BFC0B3BDBFB5BABEB7BAC1B8BBC2B8BDC3B7BBC1B2BBBFB1BABFAFBABFADBAC0AC
BBC2AEBBC0ACBBC0ADB9BEAFB8BCB0B7BBAFB5BAACB4B8ABB2B7ADAFB7ADACB6AAAAB4A7
91998D5C5C5885837D948E90FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7586927B8E9E7E90A37E90A67D8FA57C8EA37F90A78092A88294AA8394AD8697AF8897B0
8896B18D9CB48C9CB28E9DB58F9DB5919EB5929EB692A0B795A2B896A2B898A3BA96A2B9
99A4B99AA7B89AA7B798A4B49BA7B79DA8B9A0A9BCA1AABEA4ABBFA6AABFA8ADC2A6AAC1
A6AAC1A8ACC1A9AEC2AAB0C2AAB1C2ACB4C4AEB5C4AFB5C5B0B7C7AFB7C4AFB7C2AFB8C2
B1BAC3B2BAC2B2B9C1B2B8C1B2B8C0B4BBC1B4BBC0B3B9C1B5BCC4B7BCC3B8B9C3B9BAC3
BABBC4B9BAC2BABCC3B8BAC0B9BCBFBABFC0BAC1BFBAC1BBBABFB9BBC1BABBC1B9BDC3B9
BBC0BABDC1BCBDC1BCBEC3BFBCC1BCBDBFBBBDC1BDBEC2C0BDC3C1BDC3C0BDC3BEBABFB9
BCC1BABEC4BAC0C4BAC0C2BAC1C1BBC2C4BDBCBFB9BEC3BABDC2B7C0C5B6C1C4B5BFC2B3
BEC2B4BDC0B6BEC2BBBEC4BDBAC0BBB9C1B8B9C2B8B8BFB6B9BEB6B8BBB4B7BAB1B6BAB0
B8BDAFB8BEAFB7BBAEB7BCB1B7BDB3B5BBB1B4BAAFB4B9AFB3B8B1B2B8B1AFB6AFACB4AB
ADB7A8A8B2A292998931252B3A3132999595CBC9CAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7A8B988092A38093A98092AA7E8FA97C8DA68194A98193A88294A88293AA8695AD8694AD
8A98AF8B9AB08897AD8C9AB18F9CB3919FB5909FB5909FB590A0B693A2B894A1B994A1B8
94A2B896A1B897A4B798A5B69BA7B89BA7B89AA5B99CA6BAA1AABDA2AABCA5ABBDA6ACC0
A6ACC2A7ACC1A6ABC0A8AFC2A8B0C2A9B1C2ABB3C4AEB5C6ACB3C4ACB4C4ACB4C1AFB9C5
B2BBC6B2BBC4B1B9BFB3BABFB4BAC0B4BBC0B3BAC0B1BAC0B2B9BFB3BAC3B4BAC3B6BBC4
B7BCC4B6BBC3B8BBC3B9BDC4B6BCC2B4BBBEB8C0C0B7BEBCB6BDBBB6BDBAB7BEBBB7BFBC
B7BEBCB9BDBCBABFBDBABFBEBBC1BEBBBFBDBBC0BDBBC0C0BCC2C3BAC1C2BAC3BFB8C1BC
B9C0BBBAC0BABBC0BBBBBEBBBFC0BFBDBEC0BCBFC2BBBFC0BBBFBDBBBFBABABEB8BABEB8
BBBFB8BBBFBCBBC0BCBBC2BEBBC2BFBBC2BEB8C1BAB8BEB9B9BDB8B9BDB8B9BEB8B8BEB7
B7BEB4B7BEB4B5BCB2B4BCB2B5BEB6B4BCB5B2B9B3B2B9B2AEB5B1ACB5B0ABB4AFA9B3AC
A8B2AAA7B1A8A9B4A771726F4D494B383033352D2E31282C979396C9C7C9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7888997D8EA37D8EA87F90AC7E8EAB7C8CAB7E90A98193AB8091A98392A98796AD8C9AB1
8A98B08C9BB18C9BB08D9BAF8E9CB18F9EB4909FB692A1B790A0B593A3B795A5B995A3B9
95A2BB94A0BA95A0B897A2B79AA5B99CA9BB99A5BA98A4BA9CA7BB9FA9BBA1A9BAA3AABE
A5AAC1A6ACC4A6AEC6A4ADC4A6AEC1A5AEC0A7AFC0AAB2C2AAB2C2ABB5C3ABB6C4ADB8C3
ACB4BFAFB7C1B1B8C0B3B9BFB5B8BFB3B6BFB2B7BFB1B9C2B0B9C3B2BBC5B1B9C2B3B9C3
B3BAC5B1B9C5B2B8C2B4BAC2B6BBC5B5BCC4B6BCC3B6BEC1B6BDC0B7BEC1BAC1C3B9C0C4
B7BFC2B8BEBFB9BDBEB9BCBCBABFBCBBBFBEBABEBDBCBDBCBCBEBFBCC0C1B9BFC1B9C1C0
B8C0BDB8C0BDB9C0BDBABEBEBABDBFBBBEBFBCC0C0BABDBEBABDBFBABDBDBBBFBEB8BCB9
BBBEBABCBFBCB9BDBCB8BDBEB7BCBDB8BDBCBABEBCB9BEB8B8BCB6B9BEB5B6BDB3B3BCB1
B4BEB3B5BFB6B2BDB4B2BCB3B1BCB2B1BAB2B1B9B4B4BCB7B1B9B3AEB7B0ACB4ADABB3AF
AAB4AFA9B3AFA9B4AEA4AFA88D948F514F524743444441413B363B332F375C5962959599
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
74849B7A89A57D8EAB7F8FAE7F8EAD7F8EAD7E8FA97E8EA58091A58292A58593A78B99AE
8A97AE8796AA8B9AAB909FAF929EB08F9BB18E9CB5909EB7909FB6909FB492A0B494A0B6
96A1B995A0B897A1B798A2B69CA6B799A4B79CA6BA9FA8BDA0AABD9FA8BAA3A9BBA2A8BB
A5ABBFA7ADC3A4ACC3A4ADC2A5AFC3A4AEBFA7B0C0A8B0C0AAB3C2AAB2C0ABB4BFAEB6C0
AFB6BFB2B8C1B1B7C0B2B5BEB2B3BCB4B5BFB5B8C1B4B9C2B2B9C3B3B9C3B5BAC4B5B8C4
B5B9C5B3B9C5B1B9C5B1B7C0B2B8C1B3B9C2B4BCC3B4BAC2B4BAC0B6BDC1B5BDC1B5BCC0
B5B9BDB7BBBAB9BCB9BBBCB8BCBDB9BBBDBCBBBCBBBCBCBBBBBBBBBABDBEBBBFC1B8BCBD
B6BCB9B7BEBAB7BCBBB9BCBEBABDBFBBC0BFBABDBDBBBFBFB8BBBBBABBBBBBBEBBB9BDB8
BABEB8B9BCB7BABCB8B9BAB9B9BBB9B9BCBAB7BAB8B7BBB6B6BAB4B5BAB2B3BBB2B1B9B0
B2BAB1B3BCB4B3BCB3B3BCB1B3BCB0B1BAAEB1B9AEB2B8B0B1B9B0B0B8B0AEB6AEABB2AC
AAB1AEA8B1ADA8B1ABA7B2A9A8B3AA98A09B7B7C827C808373787A3838432F323825282D
23262B58595D8F9191FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7484997A8BA47D8DA87B8BAA7E8DAC7E8FAC7D8FA97F91A77E90A47F91A38495A48695A5
8896A98897A88896A78A99AC8B99AD8997B08C9AB38E9DB48F9FB391A1B494A1B494A0B3
98A1B79AA3BA9BA5B99BA5B69AA3B59AA2B69AA3B99EA9BD9DA8BB9EA9BBA0A9BBA4ABBC
A3AABEA2AABFA1A9C0A2AAC2A1AAC1A5ADC1A5AEC0A5AFC0A7B2C1A7B0BDA9B3BEACB5C0
AEB7C0B0B8C0B1B7C0B3B7C0B3B6C0B6B8C1B4B6C0B3B7C0B3B7C0B3B7C1B5B8C2B7B8C4
B8B9C5B4B8C4B3B9C6B0B8C4B1BAC4B1B8C2B3BCC3B3BBC3B4BCC2B4BBBFB5BDC0B6BDC0
B7BABEB7BABCB8BABCBABDBEBABCBFB8B9BFBAB9BFBDBCBFBBBBBDB9BCBDB8BCBDB8BCBC
B5BBBBB4BABCB5BDBEB5BBBEB6BCC0B7BBC0B9BDC0B8BDBEB9BCBDB7BBBCB6BABBB7BAB9
B8BCBAB8BBB8B9BBB8BABAB9B9B9B9B9BBB9B6B7B5B6B8B5B5B8B5B6BBB8B3BBB6B1B8B4
B2BAB4B0B9B2B0B9B2B2BBB1B0B9AFB0B8ADB0B6ADB1B8B3AFB5B5AEB4B3ADB4B1ACB3B0
ABB3B0A8B0AEA7B0AFA6AFACA5AEACA5ADADA5ADB0A1ABAE9CAAA981928F272939292F37
25292F2024291E232320231B92938CC8C9C5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7486967A8DA37C8DA87A8BA97D8EAA7C8DA87D8EA87D8DA78091AA8293AA8496A88597A8
8596A78896A98997AB8997AB8897AB8A98AE8D9AB08F9DB18E9EB18F9EB0909DB1949FB4
97A2B79AA4B899A3B799A2B89CA5BA9DA6BC99A3BC9BA6BC9BA6BB9BA7BA9FA8BAA1ABBB
A1AABDA0A8BFA1A9BFA3ABC2A6AEC3A5ACC2A7AEC3AAB2C6ABB2C5ACB3C4AAB1C2ABB2C1
ABB2C1AEB5C3B0B5C2B1B7C1B1B7C0B0B7C0AFB7BFB1B8C0B3B7BFB2B6BEB3B9C1B5B9C0
B4B8BFB2B8C0B2B7BFB2B9BFAEB6BDAEB7BFB0B9C0B1B9BFB2BAC0B3BABEB3BABCB5BDC0
B7BEC1B7BCC0B6BABEB7BBBFB6BBBFB4B8BFB5B7BEB8B9BFB8BBBEB7BCBFB5BCBFB6BCBE
B5BBBEB4B9BDB6BABFB8BBC0B9BCBEB7BBBDB8BBBEB6BBBDB4BABBB3BABBB2B9B9B4BBBA
B6BEBCBAC0BDBABDBCBBBDBDBABBBAB8BAB9B7B8B7B4B6B6B4B6B7B4B8B8B3BABAB1B9B8
B0BBB7B0BBB6AEB9B4AEB7B3AFB8B4AFB6B3AFB4B1B0B7B6AEB3B5AFB6B7AAB2B4AAB2B4
A9B2B4A7B1B3A6B0B2A5AFAEA5ADADA3AAACA5AEAEA0ACAC9EABAC9CAEAB6D787E505762
383D49303440272A342A2E31343A35485143282A25959596C8C8C9FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
768A987B90A37E91A97E8FA97C8DA87D8DA7808FA88391AA8492AC8493AD8596AE8395AA
8495A88795A98896AD8A99AF8A9AAF899AAF899AAF8C9CB08E9EB38D9CB48F9EB5909FB6
929FB595A2B797A4B996A2B999A4BC98A4BC98A3BC99A5BC99A5BA9BA7BA9EA9B9A0AABA
A1AABBA0A8BAA1AABCA3ABC1A5ACC4A6ACC6A5ACC5A6AEC5A8AFC4A9B1C4A9B1C4ABB3C5
ACB5C5ABB3C3ADB5C4AFB6C3AFB6C4AFB7C4AEB7BFAFB7BDB1B8BDB1B7BCB3B9BFB2B8C0
B2B7BFB1B7BCAFB3BCB1B5BEB1B7C0B1B8C1B0B8C1B1B9C2B1B8C1B2B9C1B3BBC1B1B9BE
B2B9BDB3BABEB2BABFB1B8BDB1B9BFB2BABFB4BABFB6BBC1B6BBC2B6BBC3B4BAC0B4BBC0
B5BABEB7BBBFB6B9BEB5B8BCB5B9BCB5BBBDB5BBBEB6BCBFB3B9BAB1B8B7B3BBB8B5BBBA
B7BCBDB7BBBCB8BCBEB6BCBFB4BABCB7BCBCB5B8BAB5B8BAB4B8BCB1B5BAB0B7BAB1B8BB
B0B8B9AEB6B7B0B8B8B0B8B9B0B6B8B0B6B9AFB6B7ADB5B4ABB3B2AAB2B1A9B2B2A7B0B0
A7B0B2A6B1B2A7B3B2A8B3B2A4AFAFA1ABACA2AEACA1ADAC9FADAD9CABAA9AA8A798A6A3
727A8061667248475D4A4A5E93A39D84908B51565B515A571D1A23544F578D8A8FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
7484977B8CA37E8FA87D8FAA7D8EAA7C8BA8818EA9838FAB8490AD8390AC8391AD818FAA
8390A98593AD8693B18695B28899B48899B4899AB28D9DB38E9CB58C99B68F9CB88F9CB7
909EB6919FB694A0B698A4BB97A3BE98A4BE99A5BE9BA6BE9AA5BB9BA4B99CA5BC9FA8BC
A1A9BCA1A9BFA2A9BFA2ACC2A1A9C4A3ACC7A3ACC6A4ADC4A3ACC2A7B0C4A6AFC5AAB1C6
A7B0C5A7B0C5ABB3C7ADB4C6AFB6C6AFB7C4AEB8C1AFB9BFADB6BBAFB7BFAEB6BFB0B7C0
AFB6BFADB5BEB0B5BEB1B6C0B2B7C3B2B7C1B1B7C0B3B7BFB2B6BEB4B7BFB4B8C0B2B7BE
B0B9BEB0B9BDB1B9BFB1B8BDB1B9BDB0B9BCB2BABEB6BDC0B5BBC0B5BBC2B4B9C0B3B8C0
B6B9C0B4B6BDB6B7BEB5B8BDB6BCBDB6BBBCB7BBBCB7BABBB5B9BCB6BCBDB7BDBBB6BBBA
B6BABCB6BBBFB4B8BDB5BABEB4B9BCB6BABBB5B7BBB5B7BCB5B8BDB4B8BDB0B4BCAEB3BB
ADB4BAAEB7B9B0B9B7B2BAB7B2B9B7B1B7B4B0B6B4ACB4B2A7B0AFA9B2B1AAB3B4A9B1B5
A8B1B5A9B2B5AAB4B5A6B1B3A4AEB2A2ABAFA1ABAEA2ADB1A1AEB19FACAF9DA8AC9CA7AC
9BA4AB98A2A88E979E8B949A8F999C929E9C8E9B9893A2964C4E5116101F1B162318141D
504D53868588FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
6C78917B8AA57D8CA97C8CAA7C8BAB7C8CA9808EAA818EA9828EAA838FAA828EA9838FAA
8592AB8592AB8693AD8694AE8797B28799B28697AF889AB08C9DB38D9DB38F9BB4909AB3
919BB4929CB6939DB9959EBB969FBE97A1BE99A4BF9CA6BF9BA6BE9CA5BD9EA8BC9DA6B9
A2A9BEA2A8C0A2A9C1A5ADC5A3ABC4A2AAC4A4ACC5A3ACC4A5AEC2A6AEC1A6ADC1A9AFC4
A8AEC3A9B0C2ABB3C3ABB3C1ACB4C0ABB3BEADB5BFACB4BDACB6BEAEB7BFACB3BEACB3BE
AEB4BFB0B5BFB2B7C0B2B7C3B0B4C3B1B7C3B0B7C2B1B6C0B2B6BFB3B7BEB6B9C0B0B4BB
B1B5BDB4B9C0B4B8C0B3B8BEB2B8BDB1B6BBB3B7BDB3B9BEB4BABEB3B8BBB3B9BEB1B6BD
B1B6BDB3B7BDB3B5BDB5B6BDB4B6BAB5B8BAB3B7B9B3B7BBB4B9BCB4BBBDB6BDBDB5BDBD
B6BBBDB6B9BCB5B6BCB3B5BDB4B6BDB3B6BCB5B7BDB4B6BCB3B6BDB2B5BBB1B5BAB2B8BA
B1B8B9AFB7B7AEB7B3ADB6B0AEB6AFAEB5AEAFB4B1AEB4B2ABB4B4A9B2B2A9B1B2AAB2B5
A8B0B5A8B0B6A7ADB4A8AEB4A7AEB3A5ADB2A2AAB0A2ACB39FAAB19DA7AE9BA5AC9DA7AE
9DA5AD9FA7AE9BA4AA99A3A898A1A697A1A4969FA28F9B9C87948F4B50552F2F3725252B
1D1B2216131A1E1D209A9A99C9C8C9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
707E927A89A17F8DA97F8DAC7C8BAB7B8AA97D8DA78090A68493A78290A58291A8818FA8
8291AB8493AC8493AC8696AE8797B08393AE8495AF8695AE8694AC8A98AE8C99AD8F9AAE
8F99B0909BB3919EB7929DB695A0B899A2BC98A1BB99A2BB9AA4B89AA4B59CA6B59DA5B7
A0A7BAA0A6BC9EA5BDA0A8BFA2A9BFA1AAC0A3ACC2A3ADC2A3ACC0A2AABCA7AEBEA7ACBD
AAB0BFA8AEBFA8AFBEA9B1BCA9B1B9ACB3BBAAB1BBABB2BDAAB1BCABB3BEADB1BCADB2BC
AFB5BEAEB4BEB1B6C1B0B3C1AEB2C1ADB1C0B0B5C1AFB4C0ADB2BEAEB4BDB0B4BCB3B6BD
B2B6BEB0B3BDB1B5BDB1B5BDB1B6BDB0B4BDB3B7BEB2B7BDB1B7BCB1B6BCB0B6BBB0B5BD
AFB4BCB2B6BEB3B5BEB4B5BDB4B6BBB5B7BCB3B6BCB3B7BBB2B7BBB2B8BBB1B6BAB1B5BB
B2B7BDB0B4BCB2B5BCB2B5BBB1B5BBAEB4BAADB3B8ADB2B8AEB4BAAEB2BAADB3B9ADB4B7
ABB3B4ACB3B4AEB7B4ACB5AFADB7AEABB3AFAEB5B2ADB4B3AAB3B4A7B1B2A7B0B1A5AEAF
A7AFB3A8ACB4A6A8B4A7A9B4A7ABB2A6AAB2A7ABB5A3A8B4A0A8B49EA8B39FA8B09CA5AD
9CA3AC9BA3AB98A1A998A0A997A0A8989FA8979FA8939BA3909D9F8B989686948C68716E
35333E33313A29262E3332353637382C2C31929296C8C8CAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
74829078889C7C8CA57D8CA87E8DA97A8AA57B8CA3808EA3808CA17F8CA27D8BA17D8DA5
7D8DA67F90A88192AA8393AC8596AF8593AD8694AD8796AD8794AB8895AB8D98AE8F99B0
8F99B18D97AF8D96AF909AB2949DB4979FB6979EB599A1B7969EB499A2B49DA7B69CA5B6
9AA3B79BA2B89BA4B9A0A8BC9DA6BA9FA9BC9FA9BF9FA8BEA4ADBFA3ACBDA5ABBAA7AFBC
A7ACBCA6ACBBA5ACB9A8AEBAAAB0B9ACB2BAACB2BAAAB1BBA8AFBBA8AFBDA9AFBCAAB0BC
ABB1BCABAFBDAAAEBDABB1BFAAAEBBABAEBDADB1BEADB2BDAFB2BFAFB3BFADB2BCADB2BC
ADB2BCACB0BAADB2BAAFB3BAAFB2B8AEB2B9AEB3B9B1B6BBB0B4BCB1B4BCAFB1BAADB0B9
B0B4BAAFB4BAB0B5BBAFB0B8AFB1B8B0B1B9B2B2BAB2B3B9AEB3B7B0B6BAB0B5BAB0B4BC
ADB2BBAEB3BDAEB4BCADB3B9ACB3B7ABB1B6ABB1B6ABB2B7ABB2B8ACB0B9AEB3BBABB0B7
ACB3B7ADB3B7ABB1B4ABB2B3ACB2B2AAB1B0A9AFAEA6ADACA7AFAFA6B0AFA4AEAEA3ABAE
A5ACB1A5AAB1A6A9B2A6A8B1A2A4ADA3A6AFA2A6AFA1A6B09EA4AF9EA5AC9AA3A898A0A8
989FA8979EA7979EA7979DA6969DA4949BA090989F8F97A08F999F8B969A8B95988B9596
7B8487747F806770745D666A40434D3334433E424D515A5B6A6D7089888EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
6B7C86798B9A7C8DA37D8EA67A8AA57C8DA57A8BA27B8CA17C8BA1808EA67F8EA77D8DA7
7C8CA77E8FA78091A88292AA8593AD8593AE8695AE8595AC8896AC8A97AD8E9AB18D97B0
8E99B18D97B18E99B38D98B28F9BB3949FB5959FB6979FB797A0B6949EB494A0B495A1B5
96A0B698A2B79AA5BA9BA7BA9CA9BA9CA9BB9FA9BD9CA6BE9EA8BFA2ABC0A3ABBEA5ACBD
A7ADBEA7ADBEA5ABBCA6ADBCA5ACBAA6ACB9A7AEBCA8AFBFA7AFBEA7AFBEA7AEBCA9B0BD
A8B0BDA7AEBCA6ADBDA9AFBFA9B0BFAAB1C0ABB2BFABB2BFA9ADBEABAEBDAAADBCAAAFBD
A9B0BBABAFBAABAFBAADB1BCAEB2BCAEB3BCACB1BAADB3BAADB2BBAEB3BCADB1BBAEB3BA
AEB3BAADB2B9AEB3BAADB1BCADB0BCAEB1BBB0B2BCADB1BAABB0B8ABB1B9ADB4BCB0B5BF
ADB3BDADB2C0ADB3BEA9B0BAA9B1B7ABB4B8ACB4BAABB2BBA9B1BBAAB1BBAAB0B9A9AFB6
A9AEB5AAAFB5ACB1B8ABB1B7A9ADB3ABB0B4A9AEB3A5ACB2A4ACB2A7AFB2A6ADAFA4ACAF
A4AAB0A2A8B0A3A9B2A2A8B1A0A6B0A1A7B19FA6B19BA3AD9BA3AC9BA4AC9BA4AC98A2AA
98A2AA98A3AA98A3A9979FA7959DA5959FA5939DA2949DA0929B9E8F999C8F989C8C959B
8A949A879096848F94818D9279868C78848C78858E7A888F68757A25283A343D42474954
83858AFFFFFFFFFFFFFFFFFF
6C7C86748695798C9D7C8EA3798AA57A8BA77B8CA77B8CA77B8CA67B8CA57C8CA57B8CA6
7C8DA87D8DA77F92A88091A88393AA8695AC8495AD8395AC8596AC8796AC8997AE8A95AE
8995B08995B18A97B38996B48C9AB48E9CB5909CB5919BB9929DB98F9CB7909EB9919FB7
909EB693A0B894A0BA95A2BD96A4BD95A4BB9AA7BD9BA6BE9BA6BF9DA7BEA1ABBFA1A9BA
A3AABDA5ACBFA5ACBFA4ABBEA4ABBDA5ACBEA6ACBFA4ABBEA5ADBFA5AEBEA4AEBEA5ADBD
A6AFBEA6AEC0A6ACC1A8AEC2A8AFC2A8AFC1A7AFC1A7AFBFA8B0BFAAB0BFACAFBDAAAEBA
A9AFB9AAAFBAAEB2BDADB3BDADB2BEACAFBFACB1C2ABB2C2ABB2C1ABB2C0A8AFBBA8AFB9
AAB1BBA9B1BAA9B0B9AAB0BCA9ADBDABB1BFACB2C1ABB2C0ABB1BFA9AFBCA7AEBAA9B1BB
A9B0BBAAB1BCACB2BCAAB1BBA9AFBBA9B0BBAAB1BDAAB1BDAAB1BFA7AEBBA8AFBAA8AFB8
A6ADB5A8AEB5A7ADB6A9AEB7A9B0B7A9B0B8A7ADB8A5AAB5A4AAB4A3A9B3A3A9B2A3AAB1
A1A7B2A3A9B6A3A8B7A0A8B6A0A9B69FA9B59BA5B398A2B099A4AF99A1AD97A1AC96A1AC
94A1A993A0A9939DA8939CAA929BA8929CA6919DA5909BA28E999E8E999C8F9A9E8D989D
8B969A869295839093829093818F927E8B927D8A947B87927A89916F7D856E8181334048
131A270C1219808285C0C0C1
6A7C83788A957B8B9C7B8BA0798AA57888A67383A47385A67588A7798CA7798BA47B8CA5
7B8BA77D8DA77E8FA67F90A48393A38594A48491A58493AB8293AB8494AC8796AD8896AE
8995B08995B38793B38995B58996B28A98B28E9AB48F99B6909BB98F9AB9909BBB919DBA
909DB5919EB694A0B993A0BA92A0B992A1B996A4BA9BA7BE9BA6BD9DA7BDA0A9BDA2AABD
A2A9BCA3A9BCA4AABEA5AAC0A3A8BFA4A9C0A6ABC1A2A8BEA5A9C1A6ACC1A5ACC1A3ACBF
A3ADBCA3ACBEA4AABFA4AAC0A6ACBFA6ACBEA6ACBCA7ADBFA6ABBDA7ACBCA9ADBBA8AEB9
A9B0B8AAB1BBA8ACB8A9ADBCAAAEC1ACAFC4ABAEC3ABAEC3A9ACC1A7ABC0A5AABEA6ACBB
A7AEBBA9AFBCA9ADB9A8ACB9AAADBAA9ABBBA9ACBEAAAEBDA9ADBCA7ADBBA6ACB9A7ADBA
A8AFBBA7AEB9A9AFBAA8AEBBA4ABB7A7AEB9A8AEBAA7AEBAA6ACB9A5ABB8A7AEB8A6ACB6
A6ADB6A7ACB5A5ABB5A3A9B6A2A9B6A2A8B3A5ABB5A4AAB6A0A6B49FA4B39FA5AF9FA6AE
9FA6AEA1A6B3A1A6B79CA1B59DA4B699A1B298A0AF9CA4B499A2B297A2B196A2AF94A1AB
93A0A8939EA7949CA9939DA98F9AA78F9BA48F9CA08D9A9C8C999B8E989E8C97A08A969D
89959B828E93839195839195849097828C96828D957F8D937C8A8E7A888B7582857B8C88
3741470A0C1808091106050C
6B7C88798A987C8D9F7B8BA57A8AAA7788A97485A67487A57588A47689A37B8CA57D8CA6
7C8CA97E8FAB8294AC8092A68294A68393A58391A78495AD8394B08394B08596AF8593AC
8895B08792B38894B68796B58998B28D9AB1929DB58E96B1919AB7919BB9919AB9929CB8
929CB4939EB4949FB4939EB395A2B596A2B697A3B79BA5B99CA6BB9BA3B99EA7BCA0AABA
A2AAB9A4A9BBA2A7BCA3A7BEA5A9C1A5AAC0A0A7BDA0A8BDA2A8BCA5AAC0A5AAC2A4ABC1
A4ADBFA6ACBEA5AABFA7ACC0A6ACBDA4ABBBA7AEBCA7ADBCA7ACBCA6ACBAA6ABB7A6ADB5
A7AEB6A6ACB7A7ADBAA8ADBEA8ADC1A6ABC0A7ABC1A8ACC3A6AAC1A6ABC1A8ACC0A7ACBC
A9AEBCA9AEBAA8ABB9A7A9B8A9ADB9A9ADB9AAACBCA8ABBAA8ACBAA8AEBBA6ACBAA6ACBA
A7ADB9A7ADB9A6ABBAA8AEBBA8AEBAA8AEB9A7ADB7A9AEB7A8ACB9A8ADB9A9ADB8A8ADB7
A9AEB7A7ACB5A5ABB6A2A8B4A2AAB4A0AAB4A0A8B49FA7B59FA6B49FA6B4A1A7B49EA4B1
9EA3B0A1A6B39EA2B59FA4B99CA3B79AA2B39AA1B19BA3B29BA3B3979FAE95A0AE94A0AD
919CAA939EAC939EAB919DAC8D9BA98C9BA58B9AA18A9A9F8A989D8C989F88949E87949E
87969D829095838F93859095848E97828B97818B967C89907A868A7B878A7982867A8487
7784842F3244252638201F2F
6A7A8B798B9E7E8FA57C8BA67B8AA97887A97788A8788BA77A8FA67D90A57D8DA67E8DA8
7F8EA98091AB8192AA8293A88395A78595AA8592AB8593AE8594B18394B18395AF8696AE
8896AE8A97B28997B28895B08B98B08F9CB1909AAF9198AF929AB3929AB5939BB7919AB4
969DB5959DB5969EB5959FB697A3B797A3B39BA5B39CA5B69EA7BB9EA7BE9EA7BD9EA7BB
A1A9BCA5ADC0A4A8BEA4A9C0A5A9BFA4AABFA4ACC0A3ACBFA6ADC0A5ABC1A4A9C2A3A9C1
A5AAC0A5AABDA4AABBA7ADBCA8AFBFA6ADBDA5ACBCA7ACBDA7ADBEA3A9BBA4ABBAA4ABB8
A6AEB8A4AAB7A6ADB9A8AEBEA8AFC1A6ABC0A6ABC1A5A9C0A7ACC1A8ADC4A7ACC3A8ADC0
A8ADBDA9AFBEABAEBFACAEC0ACB0C0ABAFBFAAADBDABAEBBAAAFBAA9ACBAA9ADBBA7ACBB
A7ADBAA6ACBAA8AEBEA6ACBBA6ADBAA7ADBBABB1BFACB0BEADB1BEAAAEBDA9AEBCA9AEBA
A7ACB6A5ABB5A6ADB7A4ADB7A2ABB5A1ABB69FA9B49CA5B29DA6B39EA8B49FA8B49FA7B4
9EA5B2A0A8B59CA4B59CA4B899A1B59AA3B49BA5B49AA3B19AA2B298A2B494A0B193A0AF
939FAD929DAB939FAC929EAD909CAC8C9CA88A9AA28B9BA08A999B8D9C9D8B9A9E899A9D
8A999A86959586949487919586909687929A838E9A7E8B987B88957D89937E888F7D858C
7A838A74818766737B617174
68778B76899E7B8CA4798AA47C8CA87A8BA87789A6788BA47689A37A8BA57D8CA67E8EA6
7E8EA87F8FA98090A9818EA68594A88694AB8592AC838FAC8290AC8391AD8696B28795B3
8796B28997B38895B28C99B28F9CB38E9AB18E99B18F99B3919AB3919AB4929AB5949CB5
989FB7969EB7949CB6949EB595A0B496A2B399A5B49BA5B49CA6B99AA4BB9BA6BC9FA8BD
9DA6BB9CA4BB9CA4BC9FA7BEA0A9BFA0A9C0A0A8C0A0A8C2A0A8C4A2AAC5A1A9C5A2A8C3
A3A9C3A4AAC0A4ABBFA6AEC0A4ACBCA5ABBCA6ABBDA5ABBFA5ACC1A2A8C0A1A9BFA2AABE
A4ACBCA5AEBCA4ACB9A4ADBCA3AABDA3AABFA4AABFA5ABBFA6ABBFA7ABC2A8ACC5A8ACC3
A7ACC0A5ABC0A5AAC0A8ABC1A9ACC2A8ABC2A9ACC1A8ABBDA7AABCA5A8BDA6AABDA5A9BC
A7ACBDA5AABCA7ADC0A7ADC1A7ADC0A6ACBEA6ABBDA6AABFA7ABBFA5ABBFA5ABBEA3A9BA
A5ABB9A5ADBAA3ABBBA3ACBBA1AAB8A0A9B6A0A8B7A0A8B79FA8B69FA8B79EA7B59CA5B3
9CA6B39CA6B49BA5B299A4B197A3B395A1B298A2B397A1B3949EB097A3B497A3B493A0B2
909EAE919DAD8F9BA78D99A68E9AA78D9AA78D9CA68B9AA28A999D8B9B9B89999C85969A
859598859497849396849095828E95838F98818E99808E997E8B977E8B957F8C977B8792
78858C76848A7282856A7C7B
6271897589A1768BA6778AA5788AA7798AA67889A67788A57586A57889A67C8BA87B8BA6
7C8CA68090A98491AA8491A98693AA8996AD8592AA8491AA8492AA8491AA8491AE8793B3
8794B38894B48894B38995B48B97B58A95B28D97B28F98B48F94B29198B5929AB6939CB8
939CB6929CB6919BB6939DB6939EB695A0B695A3B594A3B498A4B997A2BA98A5BC9AA5BF
9BA5BC9CA4BB9FA7BF9EA7C19DA6C19EA6C09EA6C0A1A9C29FA7C39EA7C39EA7C3A0A7C3
A1A8C49FA7C0A4AAC1A5ACC0A4ABBDA5AABCA5ABBDA2A8BDA4AAC2A4A9C4A0A6C39FA7C2
A2AAC0A3ABBFA2ABBEA2AABFA2A9BEA1A8BEA2A8BFA6ABC1A6AAC0A7ABC1A5A9C3A5A8C3
A6AAC4A4A8C3A4A7C3A6A9C5A7AAC6A5A8C6A6AAC6A4A8C3A5A8C3A5A9C3A5AAC3A2A8C1
A3AAC0A4ACC0A4ABC0A4ABC1A4ADC2A5ADC2A2A9BEA3AABEA4AABDA3A9BDA2A8BDA2A8BD
A3ABBDA3AABCA3A9BBA3AABBA2A9BCA1A8B9A0A5B7A1A7B9A0A7B99EA6B89DA5B799A2B3
9AA4B39CA5B49BA4B398A2B197A2B198A3B197A0B198A0B397A0B0949FAE949EAF919DAD
919EAE919FAD8F9CAA8C98A68B98A58C98A58C98A38B97A18B97A089959E87949D84919C
84939D84949B839298839096818E96818F99818E997D8B967C8A947B889479869278848E
75848C7483897180826E807D
68778B72859F758AA7788AAC778AAC7789AB7385A77485A77587A77A8CA8798AA57C8CA6
7E8EA77D8CA6828FA88490A88591A98893AE828DAB8490AB8591AB8591AB8491AB8994B0
8892B18A91B28A93B38893B28C96B38E97B39199B49298B69499B99196B79297B99299B9
929AB7929BB6929CB9929CB8939FB8919DB794A1B694A1B594A0B696A1B897A2BC98A2BE
96A0BB9DA6BF9DA4BD9DA4BE9CA3C09DA5C19BA5C19DA7C29EA7C2A0A7C19FA7C09EA6C0
9FA7C19FA6BFA1A8BFA3A9BEA3A9BEA3A9BEA2A8BDA2A8BDA2A8BEA3A8BFA4A9C2A4A8C1
A3A8C0A2A8C0A2A8BFA2A8C0A1A6C1A2A7C3A2A7C1A6ABC3A4A9C0A3A8C0A5AAC1A4A8C0
A4A8C3A6AAC6A7ABC8A7AAC6A7AAC6A5AAC5A5A9C3A5A9C3A4A8C3A7ACC5A5A9C3A3A7C3
A2A9C4A1A9C3A3ABC3A3AAC1A4ABC0A4ABC0A1A8BEA3AABDA4ABBCA3AABDA2A8BCA4AABF
A4AABEA2A9BCA2A6BAA2A7BBA2A8BBA1A6B89EA4B69FA6B79EA3B5A0A6B79CA4B59BA3B5
9BA3B49BA4B49AA3B498A2B3979FB098A0AF99A1B1979FB199A2B397A0B0959EAD939CAC
919CAD8F9AAB919CAC929DAB8F9BA78E9BA78B98A48B97A48C97A58B96A38892A08692A1
8693A085939D86959C86919C85909D818C9E7D889D7A869A798697788795798893788891
77888E74868A7385846E817C
65758A72859D7388A4758AA87486A97184A86F82A67488AA7387A87588A8778AA77789A6
7888A47D8DA77D89A8818DAB8290AB8491AC8491AC8491AB8693AB8795AD8795AD8896AC
8894AB8995AD8792AD8995AF8A94AF8C96AF8E97B08E97B29198B69199B89097B89099B9
8F98B8919AB6909AB4919CB6939DB9929DB8939EB7939EB4929DB3949EB598A3BA98A3BC
97A1BA97A0BC99A2BE98A1BD98A2BE9AA5C29BA7C39AA6C299A4C09CA8C09AA6BE9DA7BF
9CA5BD9FA8BEA0A9BDA0A7BB9EA6BA9FA6BCA1A8BD9FA6BCA1A7BDA0A5BCA1A6BEA0A4BD
A2A8C0A1A8BF9FA6BD9FA7BE9EA6BF9FA6C1A1A9C5A2AAC5A2A9C2A2AAC1A1A9C0A0A8C0
A2A9C0A3AAC3A5ABC5A3A7C3A4A9C1A2A9BFA2A9C1A1A6C0A0A5BFA3A7C0A2A7C2A4A9C3
A3A9C3A1A9C2A1A9C19FA8C0A1A8BFA1AABEA1A9BE9FA8BB9FA9BB9FA6BBA0A8BDA4ABC0
A4ABC1A2AABE9FA6BB9DA5B99DA6B8A0A7B89EA5B59DA6B59FA8B79DA5B99AA1B79AA2B6
9AA2B599A2B198A1B096A1AF969FAF979EAF989FB0959DB0969FB0939BB0939DB1929CAF
909BAC8D98A88C98A78F9AAA8D98A78F99A78D98A68A96A48A94A48791A1858F9F85919F
84909D82919A819099818F98828E99838C9D828DA07C8A9D78899977899676879374858D
74868A7285866F82806F847C
69778C6F809B6F84A17085A37286A67487A87286A77186A86E82A57286A8758AA97587A6
798BA87C8CA87C8BA8808FA9808EA8818EA97F8CA87F8FA87F8FA88191AA8292AA8291A9
8392A98593AB8894AD8993AF8A94B18B96B18993AE8993B08D96B3909AB68F99B88D98B7
909CB88F9AB3919CB38E98B28E99B78E99B78D99B48F9CB4909CB4939EB5949FB6959FB7
97A0B9939CB8949CBB959CBA959FBA96A0BB95A0BB94A0BC93A2BD95A2BD95A0BA949FBA
99A3BF97A1BD98A3BA9CA5BB9CA4BA9CA4BA9CA5BB9DA6BD9CA4BA9CA5BA9BA3B99DA4BA
9DA5BC9EA7BC9CA6B99DA6BB9FA7BF9FA6C19EA6C09FA8C39FA8C3A1A9C39EA6C0A0A8C0
9FA7BE9EA5BF9FA5BE9EA5BC9EA6BC9DA5BB9FA7BE9EA7BD9CA4BA9EA4BDA0A7C09EA6C0
9FA7C09DA6BF9DA6BF9DA6BD9CA6BA9EA7B9A0AABA9EA9BB9DA7BA9CA3B89CA5B89DA5BA
9DA5B99EA6BA9EA5BA9CA4B79BA2B69BA3B79BA3B69BA4B89BA5B899A2B896A0B6959EB4
979FB4969FB196A1AF949FAD939DAD949CAD919AAD909CAD8E99AA8E99AA8F9AAC909CAF
8E9AAD8E9AAB8C97A98A94A68991A48A93A58992A58792A38691A28591A2818E9F808D9F
8190A07F8F9E7D8E9B7F8F9B80909C7E8C987D8B98798697768796788A9773849172838D
7184897083836E817F697D77
6673906B7D9D6E84A56F85A67184A67687A97485A97386AB7287AA748AAA758BA8788CA8
788BA87A8CA87B8CA87E8EA97F90A98091A98291A97E8DA77F8EA88191AA8191AB8293AB
8192AA8291A88794AD8895B18794B28895B18C99B18C99B18C98B08D97B38E98B88C97B8
8B97B88D99B98F9AB7909CB98F9CBB8D9BBA8D9AB78E9CB58F9DB5919DB5949EB7949DB9
979FBB969EBB959DBA959DBB969EBB939CB994A1BC95A2BD94A1BD97A2BE9AA5C098A1BF
98A1BF97A0BD9AA1BD99A0BC9AA2BF9DA5C19EA7C09CA6BE9AA5BC9DA7BC9DA7BB9CA4B9
9DA6BB9EA7BE9EA8BC9CA6B99FA7BD9EA6C29FA7C3A0A8C4A0A8C4A1A8C4A1A7C4A1A8C4
9FA8C49FA8C3A0A9C2A0A9C19EA9BF9CA7BD9BA7BF9DA9C19CA7BF9CA5BD9DA4BD9DA5C0
9BA4C09EA8C29DA9C19EA9BF9EA9BC9FABBBA0ACB9A1ACB9A2ABB9A1ABBAA1AABCA0A8BD
A0A8BEA1A9BE9FA7BC9DA4BA9FA5BA9DA4BA9FA8BE9EA8BC9EA8BC9CA5B99BA5BA9AA3B8
9AA3B897A1B697A0B696A1B695A0B5929EB2919DB2919EB1919FAE929EAF929CAD929CB0
909AB18E99AE8D98AD8E99AE8C97AA8E9AAC8B98A98896A68796A68694A68390A38492A7
8491A88493A77F90A37D8DA27C8EA17D8F9E7D8E9C79889B78879C7A8B9D768796768993
74888D72868671868170857B
6A75947585A77688AB7586AA7383A77586A97788AD7787AE7587AB7387A9778AA87B8BAA
7A8AA97D8CAA7E8FAA7F8FA98090A7828FA7848FA98691AC8591AD848FAF8490B08490B0
8693B28693B28793B28892B28991B08A94B18A95B08C98B2909BB48D97B38F99B98F99BC
8D97BA8C95B68C95B69099BB919BBB8F9ABB8D99B8909CB5939EB5949CB4969DB6989EB7
989FB6979DB4989EB6979CB79BA0B9979CB8989FB99AA3BC9AA2BC989EBB9AA0BD9CA4BE
9CA3BC9AA1BB9CA2BB9CA1BD9C9FBE9EA1C09EA3C19EA3C09FA5C29EA3C0A0A6BE9DA4BA
9BA1B79FA6BBA1A8BD9EA4BAA0A5BBA2A7BFA1A5C2A1A6C4A1A7C4A3A8C3A3A8C3A2A8C3
9FA4C29FA6C29FA6C39DA5C19EA6C09DA6C09DA6C29EA8C29CA5BFA1A8BDA1A7BCA0A5BC
9DA3BD9DA4BF9DA3BE9FA7BFA0A7BFA1A7BE9EA6B99FA7B8A0A5B7A0A6B7A0A7B9A0A8B9
A1A8BC9FA6BCA0A6BBA0A5BA9DA1B69DA1B59CA1B69EA3B89EA3B89CA1B59AA1B599A1B4
99A0B59AA0B5999FB5979DB6959DB6939CB5939DB2949EB1949DAF939BB09197AE8F95AB
8F96AB8F97AC8B93A98C93AB8B93A78B96A78A95A58894A28692A28693A5848FA4848FA5
8590A9808CA67B88A17C8BA17B8B9F7A8A9B788698788497798699778598758293778691
75848E7484887081806A7C77
656D8A707E9D7281A57080A47483A77381A87381A87685A97786A97787A97787A87987A9
7B8AA97C8CA97C8CA77E8DA6808DA68491AA828DA88690AC848EAE848FB18491B5828FB4
828FB48491B38593B38694B28894B18993B28B94B38C94B48D98B68C98B78E98B99099BA
8C96B68B96B78D98B8919BB98F99B68D96B38F98B48F99B4929CB5939DB5939CB4949DB4
959DB3969DB299A0B4979DB4999EB6989DB5989EB7989EB8989EB99AA0BB9CA1BE9BA0BE
9AA0BA9BA1BB9DA2BC9EA2BD9EA1BF9EA2C09CA1BF9BA1BE9DA3C09CA3BE9CA2BB9EA5BA
9EA5BA9EA6BAA0A5B8A1A6B9A1A5BAA1A3BA9EA0B99FA2BCA0A4BFA2A6C0A0A4BEA1A5C1
A1A4C2A1A4C3A0A3C2A1A5C3A0A4C0A0A4C0A1A6C0A1A7BEA2A8BCA2A8BA9FA3B79EA2B8
A1A5BCA0A5BD9CA2BC9DA5BDA0A5BFA1A6BE9EA1B99FA2B9A0A4B99FA1B7A2A4B9A1A4B8
9EA2B79DA3B79BA1B79DA3B89DA2B6999EB29BA2B49BA1B69AA0B699A0B599A1B6989FB4
989FB1999FAF999CAF9A9FB3959CB3949BB1939BB09097AD949BB0959BB19296AD8E93A9
9096A98E94A78E96AA8C93A88891A48994A387929E86919D87939F838D9E858FA0848DA1
848CA48189A47D88A37E8AA1818EA07C889B7B879A778396758193788496778295758192
73808F7180896F8181697C76
656F8B6F7C9B7383A47484A87282A67482A67382A67887AA7989AB7B8BAC798AAA798BA8
7A8BA67C8DA57D8DA47F8FA6808DA7828EAA7F8BA9818DAD838EAF848EB0828FB08290B2
8190B08091AE8192AD8393AD8695AE8794AE8794B08A94B38995B38995B38A95B28B95B1
8F98B68F98B78E99B6919DB8909BB3909AB38E97B2909AB5909AB4929DB5909CB3919CB3
8F99B2949DB4979FB5979DB6969CB8969DB9979CB9999EBA999DB9979CB99A9FBC9CA2BE
9CA3BD9CA3BB9CA1B99BA0BA9CA3BE9BA1BD9AA1BC99A2BA9BA3BA9BA3B99AA2B69BA6B7
9AA6B69AA4B49BA2B29FA4B5A0A5B9A0A4B99EA3B7A1A6B9A0A4BAA2A6BEA2A6BEA1A5C0
A1A4C3A0A4C2A2A6C4A0A4C29FA3C19EA3BF9EA6BD9CA4B89DA4B69DA4B79DA3B69DA3B6
9DA4BA9DA5BD9DA4BD9EA5BC9DA1B89FA3B89FA3B89C9FB69FA1B99FA2B99FA2B8A0A4BA
9EA4B99CA3B9989EB5989EB59AA2B7999FB499A0B399A1B599A2B7969EB6949CB4959EB3
97A0B3979FB1959DAF959DB0959CB3929AB19099AF8E95AA9099AC9097AB8F95A98D93A6
8C92A78890A48890A38992A38790A28793A48593A184929E83919B808F9A83919F808D9F
828DA0818CA27F8BA17D899F7D899D7B87997A8495798393758092758194768397718091
6F7F8C6E80876A7D7F677C76
636F8A6F7D9B7480A37481A67381A67380A47683A47A88A87C8AAB7A89AB7989AA788AA6
7689A5798AA57B8BA47F8DA5828EA9828DAD808CAD818EAD808CA88490AB8592AE8391AF
8190AF8190AD8091AA8292A98392A88491AB8590B08893B48C98B68D98B38E98B18E96B0
9098B48F98B7909BBA8E99B88E9AB68D97B29098B19097B09298B29098B18D97B08F99B1
919BB39299B3949CB7969BB99399B8959CBA969DBA989EBA989CBB979CBC999EBC989EB9
99A0B7989FB59BA1B69DA3B89CA1B99BA3BB9BA4BC979FB7989FB59AA2B49BA2B39BA3B3
98A2B299A4B39AA4B39AA3B39DA5B69FA6B9A0A7BBA0A6B89FA5B59FA4B59FA2B6A1A3B9
A0A4BCA0A5BDA0A6BE9DA2BB9C9FBB9DA2BD9CA2BD99A0B89BA3B79CA4B79DA4B89EA5BA
9CA1BA9AA0BB9CA3BB9DA5B99BA1B69EA3B59FA4B79FA3B99C9FB69B9FB49A9EB29DA0B4
9FA4B69CA2B4989EB3979DB5979FB498A1B1979EB0959CB1969EB5969EB5939DB3939DB3
939CB1949CB19199AF9099B18D97AE8D95A98C96A78E98A78E96A68D95A68E95A58C92A4
8A91A18B94A38891A18A92A18A91A38890A28591A282909D808F9A808E99818F9C818C9D
828BA080899F7E889F7C88A17D899F7B86997982937A8395778196747F967381986E7E91
70808C6A7C826B7E7E687C77
626D856E7B98727E9F7380A4717DA37380A47683A27582A37885A77A88AA7988A8798AA7
788AA7798BA6798AA57B8BA57D8BA67F8CA8808CAA808CA9808CA5808DA38490A68490A8
8590AB8392AB8392AA8493A98694A98594A98693AC8692AE8892AE8B95AE8A93AB8D96AD
9096B09297B49096B69197B79096B48F95B19298B19198B19195AE9298AF9399B2929AB0
8F96AC9398B09398B19399B4949ABA9299BB939AB9949BB6949BB6949AB69499B7969DB9
98A0B8989FB5999FB3999EB4999DB7969AB8979EB7979FB4989FB0999FAF9B9FAF9A9EB1
999FB299A1B2979EAF99A1B0989FB099A0B599A0B798A0B698A1B29BA3B19EA4B1A0A5B3
9FA3B59FA3B7A0A5B99EA3B79CA1B69AA0B59AA1B8979EB4969FB497A0B5999EB59DA2B9
9EA3BB999FB79AA1B99AA0B7989FB39AA0B39CA1B29EA2B69EA2B69C9FB49A9EB2999DB1
9C9FB49A9EB29B9FB5989FB6969DB3969CAF949BAD959CAF939AB0949BB3959CB2959EB1
929BAD8F96AA9098AD9099AF8B95AC8A93A68C96A48F97A39096A18E95A18E95A38C92A2
8C93A38B92A188909E888F9D898F9E8A92A3858EA1818C9E7E8B9B7D8A97818D9A80899A
828B9D838A9E80879F7C839E7B829E7B839B7A8198797E97787D99767E98737F966E7E90
6C7D876C7E836C807E6A7D77
626D896D7B9971809F7380A1727EA37380A47583A67380A47784A87886A97683A77786A8
7A8AA97C8CAA7C8CAA7C8BA97D8CA87F8FA9808EA87F8CA6828EA7838DA6838EA7838EA9
828DA8828EA8818EA88290AA8391A98593AB8594AC8895AE8895AD8A95AC8B95AA8F97AD
8F96AD8F95AC8E95AE8F96AF9198B18F96B08E95B09098B39096B0919AB0929AAF9299B0
9399B09399B29499B4959AB6949ABA949BBB959CBC949BBA929AB9939AB99299B7949CB6
979EB6979DB4969BB39A9EB6999DB6959BB7979EB9989FB7989FB49A9FB59CA0B69A9FB3
9AA1B199A1B099A0AF989EAE969EAE969EB2959DB497A1B596A0B39BA4B49AA1B29DA2B5
9DA2B59EA3B89EA2B99DA2B89DA4BA9CA3B99BA1B79BA1B89BA3B899A0B7989DB5989DB5
989FB6989FB7979FB799A0B8979DB59AA0B69BA0B59BA1B69BA1B59B9FB49CA0B49D9EB4
9C9CB59B9BB69A9CB6999EB5989EB0979DAE959CAC959CAC959CAE939AAE939AAE929AAE
929AAF929BAE8E97AB8D96AA8D97AA8B94A58E97A58E94A28E93A09095A38A90A08A919F
8A949F8C95A0878F9C868D9E868B9F888EA1868EA1838BA0838AA082899E80889C80879C
82869E81859E7F849D7C839D7C829E7B829D787E9A787F9B757E9A757F99737F946C7A8C
6C7B8A6A7B8367797D667978
656F886F7D9B71809F7482A27481A1737FA27481A47480A57684A77683A57885A77D8BAB
7B8AAB7D8CAC7B8AAA7C8BAB7D8CAB8291AE808DAA808CAB818DAA848FAA828EA9818EA9
818EAA838FAA838FA98390A98593AB8491A98692AB8792AC8893AC8B95AD8D98AF8B95AA
8D98AB8D95A98C94AC8C93AD8C93AD8F97B28F95B28F96B28D94AE8E96AF9095B09095AF
8F95AF9197B39298B59096B59197B69298B7959BBB939BBB939BBB939ABA949CBA949CB8
979EB7989FB6979EB4969DB2969DB3959CB4959CB6959CB7989EB9979DB8969BB5999FB5
989FB3979EB0959CAD959CAD959FAF949CB0989FB69AA2B899A2B899A0B7999FB59CA1B6
9CA0B59B9FB79C9FB89EA2BD9EA4BD9EA4BCA0A5BA9DA1B49DA1B39B9FB29A9FB49AA0B6
999FB699A0B799A0B79AA0BA999FB9999EB79C9FB89A9DB79A9DB8999BB69A9DB49C9EB5
9D9DB59B9CB69A9DB6969BB0959CAD969DAF959CAF929AAC929BAC929AAD8F97AB9199AD
8D95AB8D96AA8E97AA8E98AB8E97AB8E96A78D93A48D93A48C91A28A90A28C92A4868F9F
88929D868F9A88909E878E9F838C9E838A9E868EA1838B9F828A9F81889E7F869F80859F
8084A08084A17B819F7A819E79819D767F9B757E98727C95737D96747F96727E906F7B8C
6D798A6A788768788264767B
636D876B78966E7D9D707FA17380A4737FA3737FA37380A37582A57582A37886A57C88A9
7D8BAA7B8BA77C8BA77F8DA97F8CA8828FAC818FAD7E8DAE7F8BAC7E8AA98490AD838FAC
8591AE8490AE8490AC8590AC8592AE858FAC8691AE8995B18792AE8893AF8793AD8896AD
8A97AE8A94AD8C95AE8A92AC8B94AD8B93AF8D95B18C93AE8F96B09095B29096B29096B2
9197B29398B1949AB29599B49399B4949AB59499B79398B89398B9949AB9939AB7959DB8
989FB8969CB6959BB59399B3979DB4969CB4979EB6989EB8989DB9989DB59BA0B49A9DB1
989CB2999DB3979EB2969DB1979EB1959CB1969DB3989FB699A0B99AA0B999A0B99A9FB8
9B9FB79C9FB79B9FB8999DB89A9EB89BA0B69C9FB49B9FB29C9EB19EA1B49DA1B89C9FB8
9C9FB8999DB79A9FB89C9FB9999CB69A9EB79A9CB99A9DB89B9EB7999CB5989BB3999CB2
9B9DB3979AB2969AB2949AAF959CAE949AB0949BB29299B09099B09099AF929AAD9198AC
8F95AA8E94AC8F96AE8C92A88F95AA9095A98D92A88A8FA58B91A6898FA4878EA3868EA3
858EA2838B9F888EA3868CA1858BA1858AA38389A28187A28087A17E859F7F839F7C809C
7D819E7B7F9D7C829E797F9A777E97757C95737B9270798E707A8E717990727B9070798F
6D768C6A768867768262737A
65728B6D7A98707E9F717EA3737FA5727DA4727DA37380A47783A67884A47884A27985A6
7987A87A89A87B8BA67B8CA67F8FA97F8DA87E8DAC7F8DAF818FAF7F8EA98290A8828EA7
8390A8838FAA848EAC848EAC8590AE8590AB838FA98691AD8792AE8690AC848FAA8794AC
8896AD8A96AD8D96AF8E97B08D96B08E99B58B94B08D97B18C96AE9198B19094B19298B4
9199B2949CB2969CB1959BB09397B09599B49398B59399B69299B6939AB5949CB5949AB3
969BB4959BB49297B39399B5939AB4959BB5969CB6959BB7969BB8989CB59A9EB5989DB3
9A9EB4979CB2969DB3949AB0939CB0939DAF969EB0969EB2989FB5979EB5979EB69A9FB6
979CB3979CB29A9DB59B9EB7999DB5989DB3979CB0999EB19A9FB49D9FB59B9DB69C9FB8
999CB6989DB59BA0B69BA0B4999CB1999DB2999CB3979AB2989CB2989DB2979CB1989DB3
989CB3959BB3949AB39298B09396AD9396AE9498B18F95B18C95AF8C95AD8B94A88E96A9
8E94A89095AC8F94AE8D93AC8B92AA878FA48C93A68C90A68A8EA68B8EA88B91AA888DA8
878EA7848BA3838AA1848BA18488A28588A48387A48288A67C84A179819C7D849B7D829A
7C819B7A7F9C79809B77819B727C97727D95737D95717B93707B906F78906D768E6A748D
68748B677487657481627179
636F896B7794717E9D7480A5747DA5757EA5747CA3767DA37981A47B83A47A82A37C86A8
7A86A67A88A77C8BA87D8DA87B8AA67E8DA87D8EA77E8EA88090A9818FA77F8EA37E8FA2
8493A48590A48992A88891A7868FA88793AB8591A98791A88992AB8891AB8790AD8992AF
8992AF8B94AF8F97B28E96B48E97B58C95B28C94B28D96B48D96B38C96AF8E96B18E98B2
8D98B0919AB0939BB09198AD9299AD9398B09398B29399B4939AB29398B0959AB29399B2
9499B39196B09096B19096B49095B39198B4939AB7929AB8949AB5949AB3959CB3959CB2
969CB4989EB6959BB4949AB1959EAF959FAE969FAE969EB1969EB4949CB4989FB6979DB5
989DB3979BAF999CB39B9EB7989CB4979DB3969DB1969CAE989DB1999DB2989BB2999CB7
979BB5959AB3969CB0949AAC969CAD979CAC969BAE9499B09499B19398B19498B1949AB3
9498B49397B39196B19297B09398B09195AC9195AD9095AD8E95AE8B94AB8B95AB8C95AA
8A92A68B93A98C92AA8B91A98C94AA8991A68992A28A8F9F8A8DA18A8EA5888CA5878CA7
838BA57F899E808B9D7F879A81899D81879F7F859F7F88A37C85A079849C798399788096
797F98797E99777C9A757D9C727B997079966E76926E77916D748F6A728F6A729069718D
636F886572886271815F6F75
666F856973926F7B9B727D9F757FA1777EA2767AA3767AA27A7FA57880A37A83A47D87A4
7C88A37C89A37E8AA37F8CA47F8DA7808EA8808EA67F8DA4818EA47D89A17F8CA27E8CA2
8290A4828FA18690A2848DA1878FA7888FAB8991AE8A92AE8A93AD8991AB8A91AD8A8FAE
8E92B48B8FB28C91B28F95B38C93AD8890AB8E94AF8E95B18D94B28991AE8893AE8794AD
8895AC8D99AB919AAC8F96AB9197AC9197AB9198AC9299AC9197AA939AAC939AAC9598AD
9296AE9298AF949BB19399AF9399AF9399B08F95AF9097B19199B09197AE9198AB9297AA
9296A99398AC9399AE939AAD949BAC929AA8949CAA949BAC959AAF9499B0959AB1979BB1
9699AF979AB09799B0979AB1969AB0949AAE969CAC959BA89599A8989BAF989BB2989AB3
9799B09598AD969AAD9599AB969AAA959AAA9699AA9495AB9496AE9495B09697B39597B3
9397B29397B29495B09497B09295AE9296AE9195AD8E94AA8D93A98E95AC8D93AA898FA5
8B91A6898FA58A91A88A90A58A91A38C93A48A91A1898F9F8B8DA08B8FA2888BA18688A4
868AA68287A180899F7D859A7D84987C83987E849A7E849B7C8299798099777F99757C96
767C97777E98757A987279987078977078966E75936C73926C749468708F666D8B666F8B
65708A636D85616F805E6D76
696D826F7490747A98757C9A777D9D777A9D777AA1787BA47B7FA67D83A57E88A37C87A1
7B83A07D86A17C86A07C87A07F8CA5808EA6828FA4828EA2808CA3828CA6838DA77F8BA6
8390A88692A68891A58890A5898EA88C90AE8D92B18A90AE8A92AD8A91AB8A8FAD8D92B0
9094B48E92B48B8FAF8B91AF8B93AC8E94AB8C91AA8C91A98A8FAB888DA9848BA7848DA6
848CA2848A9F888CA38B8DA68C90A68B91A58991A48C95A48E96A48F96A49096A69298A8
949BAC9097A9929AAB929AAB949BAB949BAB9399AD949BB09097AC9197A9939AAA9397A7
9498A89599AA989DAD9599AA9498A8969BA9969BAA969AAB979AAE9597AD969AB09497AE
9599AF9698AF989AB0999BB29A9CB29699AE969AAC969AA99699A89899AA9797AB9798AE
9698AD979AAE9598AB9699AA9699AB9698AA9598AB9294AA9394AC9496AE9293AC9294AE
9597B09597B09293AD9395AE9293AD9092A99194A99193A69093A58D91A58C91A48B90A2
8C92A28D93A4878EA1878DA2898EA3898FA3888DA1878B9D888C9D8B8E9F88889E8687A1
8486A38085A27E849F7D859A7D85977E84967E83978085997D81977C7F997B809A797E99
787D96777B947478937378957178976D74976A72946C75936C75916C748F68718A68708A
686E88656B8360697C5F6B76
6B6E82767B937A819B7A809D7C809E7A7D9C7A7B9E7D7FA37D81A57D82A47F86A181889E
7F859C8288A08289A28089A37F8BA4828FA48290A2848FA1848EA0868EA3858CA68188A5
818AA4848EA38791A28990A28A8FA58D90AB8B8FAE8B90AE8B90AE8A8FAB8C91AB8C90AB
8F92AE8D91B08C90AD8B90AB8E94A99096A98E93A68D92A58B8FA68A8EA9888DA9858CA4
848A9E84879B86879D85839D85839F82829D7E81997F86997F8795838996858A98888E9B
8A909E88919F8C95A28F9AA6929DA8919BA7949BA9939BAB8F96A9929AAA939BA7939BA5
959BA6969AA9979CAC969CAD9297A8959BA8979CA7969AA79698A99799AD969AAE9399AD
9197AB9599AD979BAE9698AB9696AD9495AC9598AB9599A99598A9989AAB9898A99797AB
9697AB9598AB9496A99395A7979AAA9799AB979AAF9295AB9194A89294A79294A89395A8
9595A99494AA9292AB9596AD9395A89295A59193A58F91A38F91A38C90A18A90A08C91A0
8C929F8E93A08E91A18C8DA28A8CA386899F888DA1878B9F888D9F8A8D9D898A9D88889F
8686A18285A17F849E7B83977D84957D82957D81957F82987F819A7C7F997A7E96797E95
797C927A7C92797B927678927477947074946B71926A718F6B748B697386696F856A6E85
666981676A8365697D5C6270
6B6E82777C91777D95787C96797B967B7E987B7D997C7F9C7D7F9E7F839F80859F80849A
81869B81879E848BA2828AA1828CA1838FA1848F9D85909D848D9D8890A2858DA1868DA3
868EA28A90A18B92A28B90A48B90A68C8FA88C8EA88C90A98B8FA88B90A88A8FA68D92A7
8F93A88D91AA8D92AC8E93AA8F96A98F95A59195A48F91A39092A68F93A88F93A88F94A8
8D91A58E91A48C8DA18B8BA287849F86859D8282998082947F818F80818E80808F7E7F90
7C7E90787D8E797F8F797F8F79808F818893878D968B929B8D949D9099A0929A9F939B9F
929AA19399A59197A5939BA69098A3939CA6929AA2949BA1969BA3989BA69496A59296A5
9498A6959AA99698A99899A99697A99394A79295A69296A59497A59497A49294A29695A6
9697A89396A79497A89599A8969AA89496A79698AB9497AB9195A79194A69598A79395A3
9595A39292A29596A59192A291949F91949D91949D8E929C8C909B8C919D8A8F9D8A909B
888E988B91978D91988B8E998A8B9D8989A087889D898A9D8B8D9D898A9989889889889B
83829981819A81849C7E82987B81947C82927D82927E80947F81957C7E93787A8E797C8F
787A8E77778B77768B76768D72738D72748E6D718C686E87686F846970836A6F816A6D7E
66677B65687A646877606771
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0178571 0.97619 0.357993 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
101008100F07100F0911100B11100D12110E12110D15130D14130C15140D16130E13120D
14130C13140C11120B11120D11130C13140D14150D11120B11120B10120B0E100A0E100B
10130D10140F11130F10120F12140F13140F15140F14140E14140D13130C15160F161710
16171014160E14160D15180F14160E14150D12140E13161114171013160F13150D13140C
14150D15150D17170F17170F171610181814161713171915171914161713141512141612
14161212141011140E12150D12150D12130C14150E141610151711151713151713171914
17191414151014151113131014141116171317191317191115170F161812151811151811
15181215181117191116150E16160F161611161510171610161610161612151612161714
14151314151313141113121016151114140F13130D13130E12120C13130D10110D11120F
12130D11120D14130F13130F12120E11110D12120F11110E110F0C0E0C090F0E090E0E0A
0E0F0A0F110A10130C0E120C0D100B0C0F090B0D070A0D060C0E080B0D080B0B060B0A07
0E0F0B0C0E0D0B0E110B0C110D0B110C090E0C0A0A0B0D0A090A0A090B0B090C0D0C0F12
010207010204020203010204020106020107020108030208030206030205020106010105
020104040204040204050203
1619161B1F1B1E211E1E211F1D1F211E22251F24211E231C1B20171A1F151C21141E2415
2025161F24151F23141E21131F22141E20141E22141F24151F24161E24151A1F131C2115
1B21141A21141B21151D231820241A21241C20231B21251B22261A2227192126191E2419
20261A222A1B232C1A252D1C232B1A252A1B23261923271B262A1C242A1A23281A242B1B
262C1C272D1C2A2F1E282C1E282B2124271F25291F262C21232B1D262F1F262E1D272D1D
282F1F262B1E282C1F272B1D262B1C252B1B262D1C262C1D272D1E262E21222A1D242B1B
262D1C252C1C272F1E262C1C252B1C2B3220262C1B262D1A282F1D2C3121242919292E1D
262A1C282C1E292E1F2D31202D31212C2F202C2F222C2F212D3125292D21272B1D252A1A
262C1B252C1C282D1D2A2F1D2A2F1D2A2E1E2A2B1F282A1F292D202A2D2323251E22241C
2123181F211721221822241A20211B20221B22231B2023191F20161B1D12242718212316
2224162225162124141C20121B20111D20111D20111B1E101A1D111B1E12191C111B1E12
191F13171E15171F161E27210C0E160D0C130D0D0D090B08090B07141A100D110B010201
020201020401010201010201020203020204010204010404010403010301010301010301
010401020401040301050301
97AE989CB49F9FB9A29FBAA17D917F20242B191B1F191D1B1114110F120C0F120913180B
181C0E191D0E1A1E0F1B1D0E1C1F0F1B1F0F1C200F1D20101A1D101C20131C20141F2216
1E23171D23171F251A1E23191E23191F241B20241B21251B2125192127182025171E2215
1F25171C24151E26142227162327182427182224162326182426191F2114202215212416
222819222719252A1A262A1E262921242620262922242A20252B1D272D1C282E1B292E19
292D192A2E1F292A1F292C1E292D1D292E1D272C1B2A301D292F1D272D1D272D1D292E1D
2A2F1D292F1B29301E252B1A282D1A292E192B301A2A2F19292E18272C19252A17262B19
262B1B25281A27291B282A1E2B2E222C2F222E31222F32232D31232A2F202B30202C3220
2A321E2F36213036233035232E32223136263135282E32242F34252F32262D2F252B2E23
282B202A2F222B2E222E30242D2F25272B20272A1E26281C24261A26291C25291A242717
252715272918252817252A172528162326152529182428182226172328191F2316202416
2024152124141B1F0F1C22101B200D171B0C171C12171B14151914181E151A1F14161B0D
15190C15190E13160D12150D171A0F181B10171B12141711141912131710141813141814
151A13161C12151A11161A12
97AE9C9DB7A5A1BBA59FB9A199B29A414B49121418191E1B161A17131712151A10161C0E
1A200F1A210E181F0E191E0E1B210F1E24121F23111F22111F21141F1F151F211920221B
21231B21241B20241C1B20181D241A1E251B1F261B1F271A1F26181F27181F2515212616
242A1A242B19212917222917252A17252A18252917242618252719242618222417242719
23261B22281A242A1B282D21262B2224282023281E262C1E272E1B292E182B30182A2D17
2C301B3234223030212D2E213232242F31222E30202E3020282A1D25271C25291C262B1C
3039232A331E252F1A262D1A272E18292F19272D17272D17282D18292E1A262B17252817
26291B26291D27281D2929212929212B2E242D30252E32252C32232C3221272E1C28311C
2B331C2D331D2E341E2F351F2B311E2E34222F34232E32212E32233335263134252C3023
2C2F252B2F252B2F232E31232D31232A2E21282C1C272B1B27291B26291A272B1A272C1A
282B1A272A1A27291A25261825271827291B26271B23241B22241A22251A2024191F2417
2024172026181F26171F25172126181D2215181D12181F15171C15161B14151912171B10
181C10191B1117180E181A101A1A12191A14191915151715151714151815171A16161915
171B15181D16171C15151912
94AD9B9FBBA8A2C0A99FBAA29DB9A06D81721F24271C2120171B18131813141911151B10
171D101A21111D24121E24151E211321241622251623231623231922231C21221C1F201B
1E20191C20191F251D1C231A1D25191D25181E26181F28181F27151F27141F2613222916
252A17232714242915262B1926291A252819242819262A1A272C1C262C1B262A19262A1A
24291925291A25291A272B1F252A2022281F21271D262E1E29331D2D341A2C311A2E301C
2E2F1D2E2E1E3231232F2F223031233031243031233133242C2F21292C202A2D22282C1F
262C1A262F1A262F1A242C17273018282E182A2F192B311A2B2F1C2B2E1E292B1C282C1C
25291C26281F26271F2A2D24282B222A2D242D32252E33252B31222A32212B331F2D341D
2E351D3137202F34202B2F1E2D32222D32232F33262F34272F33252F3324313526313526
3034262F35272E34242E33222D321F2E34202E331F2D311F2B2E1E292C1D292E1D2A2F1F
2A2E1F282C2026291E282B1E26291C25271B25261C23241B23251B24271B202718202718
202717242A182228142228172025171E23161B2216191F16171D14171D13181F13192010
1B1F0F1B1D0F1B1A101B1B111D1F151C1E141C1D171A1D19171B17181B16191D17171B15
181D151A2014171B10181A0F
74827097AE929AB5999EBB9F9EBC9F90AC8E435146111615191E1910140F0F130C12160D
151910181E111A21131C22161E221621251A22261B252A1C23271A23251C21241A212419
2124181F23151D22151E23161F25171D23141F26151F2715232918262B1A252A1A202718
252C1C252A1A242A1A282D1E282C1D282C1C282C1C282C1C25291A282C1A282C19272A1B
2326172226171F251820261B21271E212920252B21292F22272F1E29301C2D331E2E341F
2E33212E30203033222D30202F34232F34262F33243133223031202F301F2F3021292C1D
282E1B282F1B262D18262C16282D172B301B2B311C2C331E29301E292E1E282D20272D1F
252B1C252B1B252918292D1E2B2F202C2E212C30212C30202B30202E35232D3422303724
333A263237263135282F322930342B2D31282D33282D33262E34262F35272D34262E3423
2E34222E34222D33202F362030361F3135213233223132243032262D30252A2E23272D21
2A3023262D20262E20272E1D282D1C272B1C242719242618232618232618222516232815
2328142328132125131E21141F22171D20171A1F171A2017191F13171D11171D10181E0C
171D0A181D0B181C0D181C0F1B20141C2015191F141B21151B21161A2015191F15181E13
171E10181E10181D1015180C
282D22424C3B57644F798E6D859F7A95B48A63795A0F120D12160F0F140C0D100C0E100D
131710161C10181E121A21131C221520261720271923271722261621251623251925291B
24281B25291B22251723261724281823271623281622281725291A23261A22271C22291D
22291B22291A242B1B232A1B252A1B262C1B2A2F1D2B301C282D1A252919272A1B26291A
24281A23291A23291D22291D262E22232A1E242C1D252C1E28301F28321C2730192C331B
2D331C2C311E2D33202D32202E35232E33243237293336273334223333212E2E1C30321E
2C311E292F1C262C19242D19262E1A242C1B262F1C252E1928311C272E1D282E1E282D1D
282E1C272C1A2628172B2C1B2E2F1E2C2D1D2D2E202E30212B2F202C32222C33222E3422
31372431362534372932352A31362B2F34292D31252C31222E33232C32232D3325313826
3137242F35222C311F3036223236223435213334223031212A2E1E2D3221272C1D282D1D
282E1D252C1C252D1B232B17252B16282D18272B1A252718242617252819232616242816
2226152125131C22101D23141E23161B20161A2017192015181D11181C1013170C171D0F
14190A131809131608171B0D181D10191E11191F111D24161B22151A2114191F12191E11
161B0B16190817190A14160A
191F1320261A1F241822291A38432A5465434D5D3E22261823281D1D2218171C14141810
181E13181E12181F141C23161F271720261823281A23281A23281A23261A24251D27271E
27291E272A1E25291B25261924251620241323271423261523261724291B24281C262A21
252B2023291E252C20272E21282E20272E1E262E1B29301C2A2F1B272B19282B1B2B2F1F
292D202B2E202A2F202A3020282E1E282E1C292F19262F1827301B242C172930192C321B
2C301A2E301B2F321D2F331F2D32212E34233136273132243233243031222F31202E311E
2A2E1B2A301B29311C272F1D252D1B202818202817242C19252C1C292F1E292D1D292D1E
282C1D272B1C262A1A2B2E1B2D311D2C301C2B2E1D2D301F2C301F2D321F2D331F2E3321
2E3321323725343A2A32362A31362B3137292F36252D34212D34212F36233139262F3825
2F37243139252F35242F332233362235372333342131321E2E301C2D301B2B2F1A2C311D
2C311D292E1D2A2F1E2A2F1D282D1A292E1A2C311E292E1D292F1E242A1B242819242918
2125151F21142124152025151E22131E22151C21151A2013191F0F191F0E191B0C191B0F
1A1B0F181A0D17190C191B0C1C1F111B1F10161B0F1A1F121B20141A1F14181B1115190F
15190D14180A1315090F1005
0F130B1318111519111619131D211821271B21291B1E23171D23151B2112192010171E0D
161D0C181F101A2013171D111B22141E2516232718252A1A24291A222618232619262A1C
272B1D272A1D262A1C262819272B1A262B19232817232618242819262B1B24281D262A20
272C21272C21272D22282C21252A1F23281C282D1D2A2F1C2B311D292E1C2A2E1E2A2C21
2C2F242A2D232A2D222B30222C30212B301E292E18262B17272E1A2A301D2A311B2F351E
2F341F3034203233212F301F3031213235253437283234253537272F31222D2F202F3322
2D32202D321F2B321E2A321E29321E262E1B232C1A242C1A272E1D262B1B272C1C292E1E
2A2F20262C1E23291B262D1B2A321D2A2F1B2C311F2D32202E32212D33202D311F2E3320
2F3421303722323724343828353A2C32392A2E34252C32202D341F2F36212F3623303725
3138263137263235263132233232223234223132213233203435212E301D2C2F1D2C301F
2B301E2C301E2A2E1D282D1C2D311E2A301B2A2F1C2B30202B3222272E1E232B1B242818
2529182225162224172123162224162123162023151E21141E21131D20101D22101A1C0D
181A0D191A0D18190D181A0D1B1D0E1B1D0D1A1C0D1C1F12191C0F181B0F181A10181A10
15180E12160A101106111307
0E120B11140C11120A16180F1719121B20181C22181B22171A21151B21141B22141A2113
1A20121A2111191F12171E0F1C23111E24121F2513222616202414232617232618232618
252718252819262A1C25291B272D1E262C1F252C1D252B1C23291C22281C262B2026291F
282D20272B1F262A1C282D1E272C1C272A1C2B2E1F2A2E1F2C31202B301E2C31202A2F1F
2A2F1F2B30212C3222292E1E292E1E2B3020292E1E272E1C2B301E2C321D2C311F2D331F
2F33203135212D2F1E2F312031332233372733372733372735392B3439293136272F3525
2F35232E34222E36202C351D2D341D2A321B2B341E2E35202C321D2A2F1C282D1B2B301C
2B301F2A30202A311F29331C29341B27301828311B2B341E2E34212E34222F3321303523
2F34212E341F2E311F343625353828363B2A343A283239263037222F361F303720313822
343B26343A273137243236233537243132212F2F212E2E1F3032213031202F30212D3121
2D31212E33222D33212D33222C30222A2F1F2C31212D31232A2F222A3222283020232A1A
222A192127162227162427172529192224172225172123161F21152022152124141E2110
1E1D0F1E1E101C1E121C1E111A1C0D1B1D0D1C1F0F1B1E11171C0F171B0F171B0F191E11
111509111509101408121609
080A040B0E050C0F0514150B181A13181C16181D15181D141C211A1F231A1C21151F2316
1D2114191F12181D101A20121C23111E26121E2712212916212715222817262A1B252819
272A1B27291B282C1D282D20272D22252C21262D21262F21262E23252B20262D21262D1F
2A2F1F282C1C26291B282B1B272B1B282A1C2D2E1E2C2E1E2B30202C301F2E3421303623
2F35222B302028301F2930212B30202B31202C32232A32222A311F2A311F282F1D2C321F
2C311E2C31202D32212C30212D312330352532392833392833392A32382A30362A32382C
2D33262C32232A321F2B341F2B341C2B341B2B341A2F381F2F36203136222F33212E2F1F
2C2F202C30202B311F2A321D29331A29331929331B2C341E2E3321303523313624333926
33382531362231362030351E3135203439243036223034233237243136213138212F361F
3138222F36213036233137243237243235233031232F2F212D2D1E2D2E1F2A2C1D2A2E1E
2A2F1F292E202C31222D32212C2F202B2E20292C222C30232C3023292E2129301F1F2616
2028161F27131E2611202712232816252A192227161E22141B1F131C20142124161E2013
1D1F131E21151D1F151D1F151D20141E20121C1F0F1B1D0E1C1F0F1A1C0E1A1D0E1A1E0F
191C0E141A0C14190E13170D
070A030A0D04111609171C0F1D23151B1F1415160F151511191B14161811171A12181E13
1A20141C23151C23131C24111B230F1E27111E28111F28131F2715202718252A1A262A1A
25291A272C1C2B2F1F2A2E20292F23262C22262E23272F24283026293025282F22252C1D
282F1E282D1C282D1B2A2F1B2A2F1B282C192A2E1B2D311F2F34202E321E2C311D2E3320
2D31202D31212B30222C31242D32252C31242A2F232B31222C33222D36232B34212A3321
28301E2A321F2D34202C331F2D33202E3420313824313826323A28303927343B2B343A2C
323A2B2E38272D37242D36212C351D2B351A2E371B2D361D2F351F2F36212F35212F3321
2D31202E32212F34222D33202D341F2C341E2A321E2C321F303622303623313725303623
32382232371F32361E343820323621333822343923333824333926323724313522303522
3137223136243238263339263239253036232F34232C30212A2C1E2B2D212C2D212D2F22
2A2E202C30202D32212D32212B2F1F2D30222C3023292D202A302029301F292F1E252D1A
262F1A222B16212914202713252A18252A1A2428172428182126161E24141E24141C2012
1B1F121A1D13191C14181A121A1D132024161D1F13191A1019190D1C1C0D1C1C0C1B1C0B
1B1E0E16190B15190B111609
090B040D10060E11060E120812170A15190B16180A11140B0E110B090B070D110913170D
171E10181D101920111D24121D25121D25121F27141E2616202819212819242A1B252B1B
242A1929301C2B331D2B321E2B311F293020252C20272F22272E22262D21283023283023
2932232A31202D34222C301F2B2F1E292E1D2A2E1D2B301D2E331E2E321D30351F30341E
30321C30331D2C2F1E292C1E2B2F202D32232D32252D32262B30242D33252E35262D3424
29311F272F1C29311D2B331D2E371E2F361E323922333A25313A252E3823333B26333C27
313C28303B26313C27323D262F39212F3A21313C21313920333A2130361E31371F313522
3335253235263034262F34243137242E351F2D341D2D351D2E331C2F331E323722323922
31371F33381E32341A35381F3439223238223138223037223239243238223037222E3420
3238223338253439273339263239263137253036242E33232A2E22292D232A2B222B2E22
2C30232C30232C30212A2F202C31222C31232C32242A2F21262D1D272F1D262D19262E19
252E18262E18242B1621271323281624281623271823291B222A1C20281A2026181D2215
1B2013191D101B1F131A1E121E21162022171E20161B1C111B1B101B1C0F1C1D0C1A1C0A
1A1C0A191B09161909131508
060804070904060902090D030B0F040F1305151B0A1318091013070A0C040C0F060F1409
0D10070C100612180C191F121D24151E2415222A1921291B21291C232B1D222B1B232B1B
212A18242D18263019262F1928311B29321E28301F262D1E292F202A2E202E34242C3121
2E33222F33222D32202E32212E33222F35232E33212D32212E3521313622323723313621
3035202F35212E31202C2E1E2B2D1E2B2F212B2F212D32242E33252E33262E34262E3524
2D36242E37242C35212B341E29311A2B341D2D35202E37222F3823303A23323C25323C25
343C25353D27353E27343C25353D24323A21343B23333A22323723323822333A22323721
3336223436243335253034233036233036232E351F2D331D2E331C2F341D32382031371F
31371F33371E33381E363B223A3E27373B273135232E3520303721303721313822313923
313923333B243238233036212D331F2F35222E34213036232D32222C2E222C2F242E3125
2D31242E32242D31232C30222B30212C30212C31222C31202B311F2B311E272C16282D16
282D16292E1A2A2E1B22261522271823271822271921271921281A212A1B202619212517
2022152123162326171D20121E22122125151F21141D21131D21131B1D101B1D0F1C1D10
1C1E101C1E1018190E14160B
0406060608050507020609010609010C10030E13030F14041015030F1103101105101207
1012090D0E060D0E070D0F0714180D1A1E101E2310222716232A19242D1A252E1A232C18
222B19232C19232C17262F1927301B28311E28301F29311E2C331F2D321F2F33222F3322
2F33233034243235253337253236243136243136242E34232D35222E37242E37232F3522
3036233137243134233132202D2E1C2D301F2C2D1F2D30202D31203034242F36262F3727
2D35252C35232C35232D36242933202C37212B36202C37202E3820313A24323C23323C22
353E23363E24373E26343B24333A23353B24353A24363A27363C28353B28363C28333824
3437223536223335233235223035232F35222D32202C331E2C331D2D331D30381F2F371F
323923333923343B22343C22363E26373D27373E273239232F3520323722353C25353D25
343B23343B232F36202F37202E361E2C331C2E351F3037212E33202D33212D31232E3225
2E32253033233032222D30232D2F242E31242D32222C32202A301D272D18242B14262D14
242913272A172B2E1D292C1D24281B25281C23271A2025181F261920281A1F27191C2215
1E22151E22142025161D22131B200E2023101F23122023121D2011191B0F16190E1B1E13
181C12191D1316181014170E
040907060B05070A02060A0204070105080107090105080109090110110315150A1A1B0E
16170C1112090D0F060A0C05080C040E13061318071B210D1F2611232C1627311C26301A
27311E262F1E28311E28321E262F1D252E1A27311A29331B2931192C321B3036202E311F
2F33222F332331352733392A3238283339283137272E35242E36252F3824303824333A25
333A243238253338253133202E2E1C2E2F1D313221303222303523313624323825323926
2E38252D36242E38242F3925303A242F3820323B212E361F2D351D2E3520303621313822
343C24353D24343B24323922323821353A23333821363B25383C28383D2A373C29343A26
353A24373A243537253335243237262E34232C32202C331D2C331D2C351E2D361F313B21
323A202F371F333A21333B22323923363C25373D283339253136242E32202F3421333926
363E29333A26353C27333C25313A22313921323A20333B212D351D2E341E2F3521303423
3136263036273034272F33272E31272D30262B2F232C30222A2F1D283019272F17242C14
262B16262B182A2E1D292D1E292E20272B1F24281C24291E1F231A1E21191D21181F2517
1F26161F25171E26171D24171D22151A1F111A20101D22131E21121E21121B1F10191E11
191D13191E13151A0F11160B
050A06050903070B02080C02070B010307010205010407010909010A0701151406191A0B
18190B1315090C0E040C0D020B0C02080901090C021115061C200F222717262C1D293021
2B35272B35282C372729332228331F26311A242F162631152A34182C341A2F341D333521
33352434362832342A31352D30352C31372D2F372B2E372A303927313B26333C27343A25
373C2536392235382234362035362137392536382634362833362A34392B303627323926
303A262D36242C36222E3723313A23343C22323A20333920333921333722333722323722
323825333925323824353C27383E28353B24383F25363D2439412A383E283B432A3A3F26
373A243739253738263437253135252F36262C33232A34202A331F2B35212B351E303C21
303C1E303B1D2F371B313A1E323A20353C24373F26353C27323826353A2B313629303629
333A2A353D2C363E29353E29343E28323D24323B2132392031381F2F3620313723323624
30352531352831362A3035292E33292D30272E3227282D212A301F29311D28311B2A301A
2A2F192B301C2D311D2E301D2C2D1E2B2C1D2C2E20292A1E232419212218202217202318
20251A20261B21271C23281F23281E20271A1D24161E25161E22121E22101E22101B1F0E
1B2010191C0D18190A131607
070C03090C050B0E050D10040B0D030A0C01080A010A0D020B0B010A09010D0D010E0D02
1010040F0F021110020E0E020D0B020C08020905010A0702100E091C1D172729232B3029
2C342D2A352D2C382C2A382629372229341D2A361A2A35162B37162E35172D311830321D
34362534352734362A30342C30352F2D352F2E372E2E372C313B2A343D28363D27363B23
373B22383A213D3E253A3C263B3C273A3C2A383A2E35362E34362E34392F343B2C333D29
313D262F3B242E3721313A21343C22383E23383D233C3F273C3E293A3B293A3B2A37392C
35382B3A3F2E373E2B363F2A39412B384128363F25343C22373E243A40253B41263C4129
3A3C2A3A3C2C3637293335293235293037282B34252C36252C36242B35212A361D2D391C
2F3C1A313E19323D16333C19373F22363C23373F2739412D393F2F383E30343C2F32392E
2D35282F3826323B26343E25354025343E22333C2032391F353B22353923353A25353626
36382B33372D31352D32372E30352C2D32282D32272B32242A33222A332129321D2B341D
2C321B2C2F1C2D2F1C2F301D2E2C1C302E202F2E222C2B2129282024251E23241D21241D
22271E21261E21281F22291F22291F20271B1F27181F26152027131D240F1E260F1F2710
1F260F1E250E1E220C171808
0A0C050D0E061212081011060D0E050A0A030809010B0C020A0B010C0D020A0C01070801
0B0A010E0E020F0E040F0D040F0E060E0A060B06060A05080804091413151B1C1D232827
28302B2A352C2936282A392529392028371C2A361A2C3818303A1930381C31361E333722
34382735382B33382B32372C32382F323B30323C2E313B2B333F2A323C27373E273D432A
3C41283E3F263F3E283F3E2C3E3E2F3A3A2F3A3C32383C33383D34373E32353E2F333D2C
353F2B343F28343C24373E24383F243D40263D3E28403F2C3E3E2F3B3A2F393A323A3C33
383D32353B2F383F2F363F2C39442C3A44283A42283940263A3F263A3D253D412A3C3F2C
3D3F313C3F33383D31343A2E353D2D313B2A2E38262F3A262D37222E381F2B351A2A3315
2B35152E3715313A16343D1A363A20363B23373E2937402B36412E35413036412F333F2C
323C27303A212F381A313A19333B1A323B1B343B1E373A21393A26383726353428333329
31322830352C3139312C342C2C352A2931262A33242A31212C34222E37242C34212D341F
2E331E2F301F313120323122333125312F262D2A232C2C25282B25272B252227211D231D
1F261E1E261C20291D212A1C232B1C222A191F28142029132029121F280F1E250B20260C
1F240B20240D1F210E1D1C0D
0F120A0E10090E11090C0E060709030507030608020C0E050E11060C0F020B0F02090B01
0B0C010C0E031011060F0E050B0A040806020704020A07080C090B0B080C100F14181B1E
222926262F282833292735252835222C38202D391F2D381E30381E2F361C303720303423
353828373A2D33372D34392F373C33343B31323C2E303B2A313D28313C24364025384026
3940273A3F273A3D283A3B283D3F2D3A3C2F3B3E30393D30383D32363C30353B2E373E2F
38402E37402C363E28383D26393C243B3D253D3D283E3D2B3C392E3B39303B3D35373935
353933383F3536403237422E39442B3B452A3A4227383F25383E27393C293D402C3D3F2E
3F41323E42333A4134363E31353E2F343D2B333E29303B232E38202F381C2D35182B3217
2A32162B32162C34162F371730361C30361E333A24333A26323929333B2D343E2C333C28
323B25303A202E371C31381A333A1B34381B363A1E373A2138392438392737372B323228
2E31272B3128282F272A322B2B33282C34262E36262E35232C311F2E34223034232F3320
31331F30311E323120312F20302D213332272E2E262E30282B2E29262B2622282120261E
1F271D1E251B20281B2029191F2817212A172029172127142027121E250F1A200B1F240C
20240F20220F1F210E1D1F0E
10150E0D100D0B0D0A0A0C080B0D0A070A060608030709020A0D04080902070902090A01
090B010B0D020A0A020A09020908020605010502010F0E0817161218171617161A19191E
1C1E2522262A252E2D27322D26332A2A35282C35252E3823303821303720313821333823
3539263A3B2C3A3B2E37392E383A30353930353B2F353E30323D2B333E2A35412A364127
3A4328394227394126393F253C40283B3F2A3C402D3C41313A3E32393F33393E33373E32
353D3136413236412F343E28353C23383E243A3E243A3C253C3D283D3C2B3C3C2F393C32
363931353A31363D3138433039442F3B472E3F492C3E482A3D462B3D432B3E422C40442F
3F422E4042313F43333B40333C433338413035402E333D2A2F38242E35202D321C292F19
2B321B2C331B2B31192D341A2D331A2F351F313622353A25373C28363B29383D2B343A27
343A26323925333C25333C2231391E31391D333A1E353B1F373B21393C253A3C28353626
3133252F33282D30282C2F272D31272E34272F35252F35252E34233036252F3523303623
2E33202F321F30321F323321302E20302D22312F232E2D232D2E232C2F24292C2125281E
23291D20251B20251A20271A1E25191F26182129192227192227182226161F24131E2311
1F23111F22111E21121D1F12
0C110B0C0F0C090C080A0D080B0E08080A06060904070A05070703080904090B04080A03
080A02090B0207090106080105070105050104030105050111130C1F221A2E322B333732
3033332C30302B31312C34322E38332A332E29322827312328312028301F2B311E2B311D
2F342031372335382834372B35382D363A2E33382D363D302F382A313A2A313B26353F28
343C26353E25353D24343C22373E25373E2639402B3A422D383E2B363C2B383F2F373D30
39413236403236413135402E37402B373F27373F26353C23383D24373C233A3E273B3F2A
3B3E2C3A3D2C373D2B373F2C3C46303D482E3D472C3C452A3D462C3B432B3D432D393E29
3B402B3D412C3D422E3D43313C43333B42323A4231363E2C2F36242D34212B311F2A311E
2A311E2B311D2C311D2D341E2B301D2A2F1B2D321C2E331E313421323722313722333924
343A25353C26353E28374229364027333E22333C20323A1F2F351C34381E393E243A3C26
3738253436273133282E2F252E30252E32263035292F35282B33262B33262A33242B3321
2C311F2D321F2F341E32331E302F1D2E2B1C2F2D1E2F2E1D302F1C2B28182E2D1C2B2C1E
27291E25271F22251D22261D20251F1F241D1F241D1E251B1F25181C22161D22151F2416
2226162024141F21141C1E13
080C04090C050A0D060A0A040809030909040C0D060F110B10110B0E0E0910110A0D0F06
0B0E03090C02070A0105070105070103050103050103050102030112160E394532394233
343A31343B33333A33333932374136333D33272F2821281F1F271B1F2516202514232815
242A16252A162A2F1A2E342231362734392A373D2C3A42303A422F363F2B37402A394029
363D2739402A383E2839402A383F29383F2A383F2939412A39412B383F2A38402B383F2A
393F2C3B42303A3F313940303941303A412E3A412C353D25373E25373F24374024394124
383F25394028383F29373F273B43293A43273C432A3D432D3C422F3C4332393F2F373E2C
373E2B393F2B3A412B3B422C3B412C3C432D3D452F373E293339252E35212C33202C3220
2B311D2D341F2D331F2C321D292F1B2A2E1C2B301D2B311D2D321D2D331D2D341D323920
363C22373E25373D2738402B38412B37402A353E263239222F351E323920343B2231381F
3338213339232F34222E33222F32212C3020292D1E2D30202E34252D34262C32252D3325
2D32242C31212E34203035212E301E2E2F1E2B2A1B2A29192C2D19292915272814252716
27291A26271B21231A23251D21231E22261F21271F20271E1D231A1C221A1F251B1C2218
1D231921241B21221B1D1E17
060B03060A010B0E030E0E040B0A030C0C0511130A14180F171A11141711161A1314180E
1216090C0F05080B03050702070802070803040601030401050803040702161C101D2315
2E342447523B323928313728384230333D2E191E17161A1411150E12160C13190B1A1E0D
1E210F1F20102427152C301E323826363C2B38402E3B432F39412C3A432C3B432A3D462A
3E452941462C41462E40442E3F432E3C422D3B412D3C432D3C432E3D43303F463039412C
3B432D3B422E3E42313D42313D42323F44313E442D3B402A3A40283B42283E472A3C4529
3C46293A43283B44293C45293B45283C452840482B4248304449334247363E44333B4132
393E2E373D2B39402C3A432C3940293C442C3B432D3B432E39402C353C282E35222E3322
2E34212D331F2F35203138222F35202D32202D32212E331F2D331D2D331F2C321D2E361F
2F3620313821333B23353D25353C2738412B38432B384129343B24343C24313823323825
303724333B26333A26323A262E35232F36222F37212E341F2F3523333928333A29303626
2F35242B2F222F35242E34222F35222F35212D32202C2F1E2C311D292E1A282D17272B18
282C1B262B1B262A1B24271B25291F252A1F23291E20261B1F271B1E251A1E24181E2518
1F26191F241A21241A1E2018
070A060A0E07090C04080A03090B03080A030B0F090E110C141910171D13181D15192015
161C110E13090A0E04060A02070A02040602050803020502030602070B030B10050C1003
0F1305272C19282D1C2A2E1E3E47323D4734272E221C221B1114110F100C10100A12120A
15160D19190F2427192C301F343B27363D293B43303B442F3A442D39422B3C442D3C452B
3F462C41462E4348314147313E432D3E442F3D422E3E432F4147324147334047323E4630
3D45323D45333E45314146314044324045313D422D3D432E3B412D3E462E3D462E3E482F
3C462F3E472E3D472B3D462A3F492C3F472B434C31444933434835444A38434A38434A38
3E44323A402D39402B373F29373F283A422A3B422D3D44323F47353A4231333B2C31392B
2F37292E37253039253139253139222F371F2E341D2E341C2E351C2D331B2D311B2D311C
2D321F2B301F2C34212D3723323B26313C2632402836422A343E26343E26343E26333D27
323923303721303723333B253139252F37233036232D33212E33223036243037252B3221
2D32232F35252D31222C301F2B301E2C321F2E35222D341F2C321C2A2F192A2F18282D18
282D19272C1C272C1E23271E24291F23281E232A1E21291C2128191F26171F27161F2717
21291A232A1924291B212417
090C0B080B090C0F09080B05050702040502050702090C080B0E0B10130F141812151A13
1419110F130B0B0E04080B01060802050602040502040603040604090C07080C05080C03
080A02080B030D100711130A242B1B303A28262F1F22291C1F23171D1F15191A13151511
15161216161120231A272B212F352833392A3941303A433139422F38412D39402B3A422C
3C432D3E462F3E452F4049323E462F3D432F404632414834414934434B36404833424A34
434C35414A35414A334047304146304348313F43303F45333E44343E45333D4531404932
414B33404A313E482C3F4B2C404B2C3E482C3E472E414831424A36434839474C3D44493A
444B394148354249383B433338403038402E38402D3C432F3F47323F47313B432F373E2D
373E2F373E2D363E2C323B29323B26303A2330382030371E30371E2D341B2E341C2F351D
3035202E311F2E331F2D341F2F3724333E28313D27333F2A35422B334029333F27323C24
2E38212D37212E3721313A23323B253139253238252E33212F3321313321303220313422
3034232F33233035252D31242C32252A32242A31232B33212D34212D331F2B321B292F19
2B301A292E19282C1C262A1C272C2024291E23291D232B1D262C1F23281B2126181F2517
1F26171F26172027191E2318
14191B0F13150C0E0F080A08050804050702030501080B0410140911160A0F140811140A
11140B0E11080B0E060B0E040709030709030506020606030809060B0B05080A03040502
0606020708030708040A0B050B0F0712170C13180D14180F171A0F171B0E1A1E11222619
23261A1F23171F241A23291F2A30262F372A343D2D38412F38422D37402B3A432D39422C
383F2C39402E3D46313E4A323F4B33404932444D34414A32414931424B34444C35474E36
444C35404934414934404931424A32434A3240452F4046303F46323F4732414932414A32
424B33434D36414C33404B30404C30434D33424C34414B34414B35434B36464B36464B36
464B35444A334146344349383E44343D44323A422E3A402B3F442C3E432B40452E404631
4247353D4331393E2D353B2B313929353E2B353D28323A22313821303720323921303721
3135233034233036232D32212F36252E35242E37242E38252F3A252F3B24303B23343F26
333D24333C243139232F37232E3724333B273137242E33212B2F1E3034222E3220303222
2F31212D30202D31222F33232D32232D31262B2E232D32242B32222C32202B311E2A301B
292F1B2A301D2A2E1E272B1E262A1D25291D24281D23261B24281C23271A2024171F2617
1F25171E25161E24171B2214
171D24161D23151B2111141B0C0F130B0F10090B0C0E120E11150F0E11080B0E040D1005
10140911140B1012090F10070C0D050B0A030C0B060A09050A0907090807060504040402
0302020404030709050C0F080E11090C0F070A0E080D10090D10070A0D030E1207171D10
242D1B28321E2B36222C36242F3929303B2C313C2B313B28343E2A343E2A333C27353D27
363E2A37412B39432D39462E39462D3C4930404C32424B33444D34454D37464D39474D3A
454C37454D37454E37464F37464F36474E35464D36454C374149343F48323F4831424D32
424D34445036424E343F4B343F4C343F4B32404B31424E33404D31414C2F414A30444A32
424730454A324449324446334448344348333F462F3E462C3F452A3F43283F442845492F
454A324348334145333E44323A422F3A412C374027353C25343C24323922313621333824
3136212F35202E351F2D33212D32222E33263037272E38252F3825303A262E3A22323E23
364124374023374025343C233138223137243238263137252F34222D32202D311F2E3320
2E32212E31202D2E1E2E31212E33232E31252D30243036272B3223282F202B321F2A2F1D
2B2E1E2B2F1F272B1C272B1C262A1B26291C24271C20251A20241920261C1E251B1E241A
1E25191A20141C23151B2013
242C31232A2F21272B1E24291B2125151A1E1114171316171113120B0B0B0B0D090E1109
0F140A10140911130A0E10070B0E050D0D050D0C060D0D08100F0D0F0F100A0B0C050506
0404040507050E110E12161011140D0E120B0D11090C0F080C0F0A080B06080B040A0D05
0F14091A21132D3623353F2A3B452E3A4530373F2E363E2B353D2A333B2A333A292F3726
2F372A2E3628313A2A333E2B36422D3A462F3C48313F4931434C36454C39444C39454D3C
474F3C48523C47513A48543B465037454F37454F37464F38434C36434D35414A31424D31
424C33454F36414C353F4A35404C333E4A2E3E4D2E3F4D30404E30404C2F404A2F424B31
434831454A3444473544473542473542473440473041472F40472B3D432642472A43482B
42462D4348314347334044334347354249333C452F3A422A383F27363C26343926303623
2E33213136233135222E321E2F33202E3321313826303827303A26313C292F3A27303B25
313D23344024374025353D243138242E34222E34233137272F35242F34222E35202D331F
2D321F2E33222C2E202D2F222C2E222E31252E32222D33212C32222A2F1F2B301E2C321D
2B2F1D2B2E1D292D1E272C1F24271A22251922271C20261C21281E1F251C1F261B1C2317
1B22151B23141D23131B1F10
23282F262D30242B2B232A29242A292329272026252025251518191012130E10100F120E
11160E11160C11150A0E12060B0E040A0C040E11080E110811130D0F110E0F11100D0F0E
0607080708081014101519141216110C0E0A080A05070A04080A04090B04090C04090B03
080A030F14091A1E10232717282C1C3137263A41313C44333A4332384132353E3130382D
2C332A272F26242B22232B1F2D3727343F2B39452E3E4930434D34454D37444C38434C3A
434B39414A37444D384650394751394650394A553C49543A475037454D34454D34444B32
444B32465036444D36454F39454F38424E34404D30434E30444F30454F31424A2F454A32
434733444838454839434738434837414835414932434E33454F32444C2F454C2E454B2D
464A2D40442C3F432F3E43344148363E46303D462E3E472D3D462C393F28353B252F3520
3035232E32212E33203033203033212F3322303727323A292E37262F3A28303B29303B27
2E39242F3A23353F25363F25353D25333925313726313726313725333927323826303624
2C31202A2F212A2E23282C212A2F222D32232D33232C33202C301F2B301D2C331C2C341B
2D341B282B18292A1B28291E24261B25281C22261C1F241B23291E21271C20261C1E2519
1F24141E23121E21111B1F0D
292F322B3035272C2E242A2B252A29282E2B272E2D242A2D23282A1E2225181C1D141917
161A1312170C0D12050C10020B0F030C10050F14071015080F12090E100B0D0E0C0F100E
0D0E0C10110C151812161A1112160D10140B0C0F04060901070A01080A02090A04090C04
090B050A0C0910140F141713191C17191B172F362A3F4938434E3A424D39404A39353E30
2D3528242B201C2119171A161A1F18252D212E362836412E3E4A33444E36434C34404934
414936404935424A36444A38464D3B48503D48523D475239465137444F35465137465034
485033464E34485036474F38454D36444E37444E36434E34424C32424C32434B34474D35
464C37464B39464A39474B3A484D3D484E3B474F3A454E37454E37464F36464F33444D30
454C3141462D3E422D3D43303B42313D44343D44313F48323C442F3A412D3C442F38402C
353A293034242F3422323824313722303623303624343B282F3826303A27323D27323E27
313D252E3821303A22323C24353C26363C28353B292F35242E33232E3423323826323826
3339262F34232E34232D32222B30212C33252E34242E35222C311F2A2F1D2E34212C321E
2B2F1C2C2F1C2D2F1F2A2C1F272A2025281F23261D21251B22271D21241A2024171E2315
2024152024142124131E2111
2A2E2C2B2F302A2C2F282B2B262928262B28272C2B282E30272C31262D30252C2D222927
1E241F151A120F130B0D100811130A0E0F090E0D0A100F0D10100C070505050606060707
0708060F110A15180D191F10171D0E11170A0D11040A0D010B0D03080A030D0F070D100A
0C0E090A0B090A0A0B0F0E1012121314141419191624282033392C3C4434464F3C343B2D
292F2321271A1B1F14191B13171912181D1523291F2D3628343F2C3B46303C48303E4930
414A32404933404834414937424837434B39434D39414D37424F37425036444F35445032
444E2F464F30475031464E32454E34414A33414A33414B33414C33404B32424C34444D37
464C38464B37454937474B3B464A3B484B3D464C3A414934434C35424C32444E32424B2F
42492D42492D3E422C3B3F2B3A3E2E393E303B42323C43323A42333A423139412F38412B
373F29333923323922343A222F36202E35212D35232F3826303825303B26303C222F3B21
303C20303C202E391F303A21313C22343D243137243137253036232F36212F361F323923
363C26333A233137242F35222C322029301E282E1C2B311D2A301B2B311C2A2D1D2C2F21
2D2F212C2F202B2E21292A2026271F24261E22251C21231A2022171F22162023161D2013
1F23142225162023161C2114
242C272A31292E322B2F322B2F302C2C2E2B2F312F2C2E302A2B322E30372F3237303436
272C2B191D1C171816141212131111120F120F0C120D0B110A090F06060B050508060707
0405030A0C04171D0D1C2210171C0C1114080D0F050A0C030B0D060B0D070F120B12150B
0F100A100F0C0D0C0A0F0D0D1715131A18151615131818151B1B1722231C2B2E24282C23
1F231B181C130F1009191D141F251A232A1D252D1F262F202A34212D3924323E2836432B
3D4830424C34444E37424B38424C38444F3A445039445138465438495639485438485336
485336485334465134444E33434E31455036445037445036424E35424E34414B33434D35
464F39474F39494E3A494E3A4A4E3C4C503E4C523E4A503C464E38474F37444D32434C31
454E33454E354249324247334044323D43323F46344049354049353E47323C463039442E
3D4A2F374228384227353F24323A20323A223038232F3825333B27313B26323E26323D23
323C22323D24333C24363F26374026384029363D29353B28303624313723313821343A22
393E26383F26373E28333A242E36202B331F2B331E2B331E2C321E2E331F2B301E2C301F
2C31202D32222E3323282D1E25291B282C1E282B2125281D24281C24291C22271A222718
222817202717202618212618
18201F1E251D242A1F292B232B2D262D2F292F322E2F31303032342F323731383B37403F
3038362227271F22231E1E2217151D11111A0E0F190D0E1806061105040F04040A020405
0305030608021217091A2011191D1016160D11110A0D0D070C0D090F120E151714181A15
1618151012110D0D0E101213141314181717141113131212151413151413191A151C1F17
16191112150C1010080D0C051C1F11252B1C252B1F1D231A1B23181A21161E2618252E1D
2E392436422B3B48303F4B33414E34424E33445234455536455235495439485238475038
495339495339485338475237455036444F36444F36475138444E36454F36424B34424C36
444D37464D39484E39494E3A4B4F3A4B4F394D513B5458425256424D523D4A503A494F39
474D38454C38454C37454C35454D35434932434A32434C33424B334149333F48313D4730
3D49323B472F39462C374327354122323E22313A1F323A21333E25343E25373F27363E29
353F29333D28343B26363C28353B27383F2A373F2A37402B353E2B343D27333C222E361D
30351E333920333A21343C22313A202D361D2C331B2A321A282D19292E1A292D1C2B2F1F
2E32212C32222A2F212C3121282C1D23281B262A1D25281B25291C24271C22291D21291D
222B1C242C1D21281A232819
1B20221B201D181D171B1E171F221D2628222E322B30332F3237343137362E35372F3739
3139392E3635282E2E272C2F22262E21242E20222E1B1E291517210E0F19090A1306070D
05070905060511160E181D11171C1015160E13130D14130F131311151413191B181E221E
2026231F2521181C1B171B1C191D1C14171A1111150F0F110F10100E100E0F110C14170F
11140B0F13080D10050B0C03252C192F37222D36231B2216181F1413170E13180E14190E
191E121E2516262E1C2E3722343F263B462B414E30444F3347533548523849523949543A
4A553A475335465435475439485539465238465239454F37465038475038484F39495038
494F39494E3B494F3B474C39494E3B4B4F3B4D513D50533D51543C4F523B4C513C4C513C
494F3A454E3A465039424C34434D3340482E414730434931434833444936434936404834
3F48343C453138422D374228354022333D1F333C20313A20323B22344025384327333E25
343F27323C25363E29363C2A383D2C383E2E38402E353C2A373F2A37402A363E27313823
2D351E2C351C2D361C2D351C31391F2E361C2B32192A2F172C311B2D331F2A2E1E2B3021
2A3022292F202B30202A3120293120262E1C232B19212816202716242919242A1A202819
1F251822281C202519202517
2024241C1F20191D1B171B16171C151D201821231924271F2A2D272D312F2F3533303837
363F3B2E37342B33312C34332E343630353730343930333B2C2E372528321E212A11131D
0B0E1508090E0D100F141711161B1214181114140D13130E14140E1819121E211A1D201C
222724232A27252C28242B27272D281A1E1D1315170E0F120E0E100E0F0F101110121411
1115100F120D0E110B0C0F07191F111D25142028151E26151C2313171C1014160C14150D
15170E14170D14170D191E112229162B341D364025404A2D434D31465134475136495236
49543449553848543849553A4B573C49543B49543C48543B465239454E37464E364C523A
4B523B4A523D494E3B494E3A494F394A503B4A4F3A4F543C4D51394E523A4F543D4D553C
4C533B475138465138444F35475236485338454F36444C34444C35444B37444936414735
4149353C44313B432E3C452B384226343D20343D20353F21343D22353E23374024363F24
353E25363E26353C27343B27373E2B373D2A373F2B363D29363D29373E29353C28323B26
313C242F3A212E39202B361E2D361E3038202D331F2B311D2A2E1E2D32222C3122293021
2931212A3121282F1F29311E28311C232C17252E18252E18232C17242C18242C18202917
202818242B1A23291A1F2517
1D23211F22211C1D1E181A19191C171B1C161B1B151C1D181C1C191F1F1D232522272D2A
2F3732313A333039312F38332D34322E333432353932353C3437403237402E343C272D35
1D232A181D2114191B161B17191E17161B1314181014180F1719101A1D14171912141712
181B161E231E282E272C322A2F362D2C342C1C201D181A18151315110F110F0D11101013
11121313161510141210171012190F171F0F18200D181F0C181F0C161B0B141809141809
131609111508111508121609191E0E191B0A232713343B213D4529444E304852334B5436
4A55374854394853384753394A563B4A563C4A563E49553E48553D46513A47503A47503B
49533F49543E47513A474F384850384A4F384B51394C4F384D513A4C513A4B513D4B523E
4A533E47513B444F37444F36454F36454F37444F36444E36465038475038454B37454B37
444B363F46333D44313B432E3B442B363F27394326394424384223373F243841253A4227
3A4228394029373E29333A27333926303624333927363D29363D28353D28323A25353D27
353C25353D25343D24353D242F371F30361E2F35212F35232E33222E33242E33262D3325
2C32222B311F272C1A272D182A311B272F1926301A262F1A252D19262E1A232B17222A17
2129151F2813222918212618
131617282B272120231D1B1F19171C18171A181718191818161515141412131613171C16
20271F262E232B3527333C303138303136302F323130333632343C343840343A40323A3E
2F373B283134222B2B2027241C231E161A17171B17171B15171B14191D151518110F120C
0F110D1216101F241B272B202D322630352A30352B2C302A262A271E202217191F15161D
111419111417171C1A1B221B1A21181A221418200E1A210E171E0C141A091319090F1506
0F150511140512160614170716190A1214061616081D1E0B2E2F19383C26434A33485239
49543A4B573D4B573B4A583949583949563949543B4A563C49553D47513B46503D46503D
49533F4A543E4A553C465035465032474F33474D34484D35494C35474B36494F3C484F3E
464F3C46503A465037455036444E35444D35444D35434C34434C35474E37444933454936
474D39444B383E45363C4335394231363F2D36412C3642283540243640243841243A4327
363D23353C24373C263339263339273035272E3426313827323A26323925313924313A23
31382132392131382031381F2E351C2E321C2E331F2E32212E32232D30252E33252D3322
2F34232E33222A2E1E262C1B282D1C262C19252C1A252C1A282C1B282F1C282F1E242B1C
2027171E25141E25131F2314
70787139413830342F2A2B2B27282A2323261E1C201C1A1D191818171814131611131711
131810151A10222719292D1E2F332935383033373033363335373B393C41383C43353C43
32393F313A3D2D3537262E2F2026281E23251E20221E1F1E1C1E1C1719191315150F1011
0D0D0D1619161F231B1E22191D1F151E2117282C232C312A2E332E2D3331292F2F1E2324
191E1F171C1D1B211C1C231C1D251B1B21161A1F111B21101B1F1115180B13150B111309
10120A10120812140917180C17180E15150B1615091715051D1B0A1E1D0D363B253F4730
4750364B53384E573B4D58394B583A4B573A4A553A4A563B4A563B4C583E4A553D47523C
4751394A533A495339464F35475135465035464F35474E36464C34474D35494E38495038
454C38454C37454E36444D36444C35444D34454C34444B34464C36474E36484F36474D36
464B38454A3942493A3F463A3C43363A4233363E2E323D2A333F28323E24353F24353F24
353E25333C27353C273339262F35232F35243036242C31212F3622333925333B26313925
323A253139243038222F37202C341E2C341E2E341F2C311F2B2F1F2B2F202E32232C3121
2B30202C31202B3222282F20252D1D232B19222917252A19292E1C262C1C262D1D252B1B
23291A232A1A2128161F2310
FFFFFFFFFFFFA2A7A54E5A53474F4B3F44423639392D302E2427211F22181D21171C2017
1E21182123181F2015201E172725242D2D2C2E2E2D2F2F3136393A393D403A3F453B4448
384146343E422F383B2F38392B31332C3432303835292C2C25272C1F1E2615131D100D17
0E0C1517171C1C2021181B1B1214120E100D131712181C18222823282F2A2B332C222923
1E261F242C23222B211F281E1D251A181E14171D101C21121B1F10191A0C14150A15150B
13130C10100911100A12120B13130C17170F18180E202111232412242715292F1A353B22
3F4529464C314B52384F563B4F583F4E59414B56414B57424A563E4A553B4A54394D573A
4E553A4B51384D5239494E37494E3949503A474F38495138485035495136474D33464B31
454A32474C33484F37484F39494F3A484E39474B39474B39444B39434B36454F35454D33
474F34444A344549364347373E43353E4435393E2F353C2C323B29333F28323F24323E23
313D22333C22363F24343B22323920313820353D25333923313621313623323824323825
333928313928303A272E38252E37242E38232D37222C36202C321E2D31202C2E1F2E3121
2E31212E32252D32262C3226272E22232B1F242C1E242B1C272D1D252C1E222A1C21291C
22291B232A1A2229161F2611
FFFFFFFFFFFFFFFFFFFFFFFFDCDFDFB2B8B870807C5F6E6C444F4F404A4848514B4C554A
4A51453739342D2D2C2D2C302D2C322B2A302422272320242B2A2B2E303235393C383D41
394142363F412F373B2C34382E3738323A39363F3D363E3D393F4034373C2929341F1E2C
1B1A271E1F281E212613151A1012130F0F0E0E0E0D111210141512171A171D221E1F2722
28312929342A29342A26312720281D1C24161B22121B21121D21121A1C0E17170B17180D
16170D13130A13120B12120B14140D0F0F0C1212103C463544523D495940435238414D33
3F482C3E462B43492F464C344A513B4B533F4B55414B57404A573E4B553B4A52394E553B
50563C525A3F50563D50543C4C503B4A503C4C523B4B52394B52364A5135474E33474D33
484D354A4E354B4F37484D394C513D4A503E464C39444A37444E39444E37444E35434D34
454F35454D35464D35464B35464A37454A364146333C4031393F2F36402B343E27343E24
353E23363E25363E25363E25363E25363D25353C26343A26353C273238252F36222F3623
2E37242D37262F39262F39262F39272E38262F3A272E38262E36262C31232B2F212C3123
2E32252D30252B2F252A2E25282E25252C22262D22242B1E262D1E242B1C23281B22271A
2128192129182027171F2616
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0E5E59EABAE7A8B8F7D908E81958F
7F93896C79735F6A6665726D484F532727321F1E271A181E18161B1C1C1F2627272D312E
353A37373E3D363F4031393D3943443C47473E48483D46493E454A3B4047393E46333A44
2F353F2C313A1D212C15172112131A111013131312131311100F0E10100C10120F141713
2831282831292D372C283126242C2320281E1E261B1D23191C2117191E15171B12171B11
15180D16170C15160B19191115140F1818121D1E1834392E525F4B57675057694F556649
4C5B3F455339444F35434C33454F354750384A533B4F573F4C553D4D563D50593E4F583E
4D563E4F584050573D50583C4E563A4E55394E543A4E543B4D533B4B523B4D533C4B513C
4A4F3A494E36494E35494E36484E37494F39484E36474D35485037474F38464F38455037
475238475037464D36464D36464C35464B344247314148333E45303B422E3A412C353B27
343B27333B2736402A363F2A343F2A323D28333E28323B28333C2A323D28313C28313B27
303926313B26303A252F38252F3827343D2D333C2F30392E323B2F2F35292D32262C3125
2D31252B30242B3124293023292E222B30232A2F23282C22282C2025291B22251922261A
21261A25291B24291B21241A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC4CFCFA8B9B5
8AA2988BA2948A9E918CA0926E7C76201F2C1F1E271B191F17151A1412151514161F201F
2427242A2F2B343D38363F3B434F4845524B404B47404A4A3C44483C444A394149394149
3A434E38424B363E46262B361B1E291619201313191312160E0D10110F0F12100F191C16
2A3228242C24252C24282F25282F24232B212329201E231D1E231F1F241F1F261E1C2119
1A1E151A1E14191D121D1F141A19111D1D162A2A2026241C494E3E55614B4D5C46495743
4E5E475162464E5F404758384654334752344851334A52384B523A4A51394C543B4D5A3E
4A563C4D5A3E4F5C3F4B573B4D563C4E553B4E553B4E523C4F533E4E53404D5140494F3F
49504048513E485139485038474F37485037474F34494F35484C35484C38474C3A444C39
46503C434C3A444D3A434C38424A33424931414A31424A31454A314247313E45303B4230
383E2F343A2A333C2B313A2C303A2C303C2A2F3C26313E26323F26344026323D25323B26
343B263239253239263036243037252F35252F3729313A2D2F3A2B2E38282D36252A3222
2931212931212A33212C35222D33212B2E1F2F31232C2F23292D1F26291B22251822251A
21231C25281F23251E21231D
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC7D2CB91A79792A896899E8D515C582021292122261C1C1D161516161415151313
1716141C1D19222521272C28323A3339423B3D433D3E45413F45473E45493E454A3E474B
40474E3F464C3E464E3F484F3A424831383D23252A1D1D221A191F16141B110E15222525
2227251D221F1B201B22291F272F22252B1E22261B23291F222820242B2222281E232A1F
20271D20271B2025191B1E151A1A141616131B1B171C1C175D6B525E6F5644513F2F382C
313A2D35402D4F62424F623F51623E4F5F3B4855364751374A523A4A523D48523C46513A
46543B49573D4E5B404B573D4D573F4C563E4D543C4C523D494F3B4A513E4B52404A5241
49514047503F47503E46503C47513A4A5339485035474E34494F36484D37474E37474F3A
464D3C454D3A464F3B444C38424B35424A32434B32464E33454B32434831444833424933
3E4533383F2E333D2C2E3828313B2B303A28313D26323E23313B20323B21343B24333A25
333A253037223239233239243138252C34222D37233139263039263038293138252C3220
2D3321292E1D292F1E28301E28301D2A311D2D31202D31222A2E2025291E21251A1E2117
23251A24281E21241E20231E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE4EAE5CAD6CC7C8F7F414A472E32302729281D1C1F1A181B171616
161514171815191A15171A141D201A23262030342C3C4039404540434844454D4A454D4D
474F51444E52424C50414D4E404A4B4148493E4344393C3F35373C282731211E2A2B2C2F
21222614151A131517181B17181D161C21191F241B20251C21281C1F271A20261922291A
232A1A242A1B2225191F21171C1D181A1A191F201F1B1E1D3640353C4739272D252C3228
2529201D2016252D1C3D4B31556847596D4C56684B505F454A563F49543F46503E404B3A
3F4C3A424F3C47543F4A58424C58434C57424B564049553B4A553B4D563B4A553949523A
4B533C48503D474F3F49523F49543C49543B465035475135475035485036464D36474F36
495039464D38464D3B454D3A454E38454E38424A34434C34434D33434C3141482E424A31
4048313D46313B4330394030343B2D343A2A323A27313A26333C25333C24323A242E3621
2C35222D37222D3722313A252E36233038252E35232E35232F36242F3625323826323924
3037222D34202B322028301F2831222A32222B31212A322128301F252C1D22281C22281B
242A1A23271922261A20241B
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBBC4BF848F8B3F45462F323626252C222026
201F201C1B191B1B161918141818141818151715122828202F2F29393C353F453F424945
454E4C465251404B4C3E484A414C4B424A4D444A4D464C4E44484D4144493C3E47373A42
23242F17162211111B1012170E10140F11131215131A1F191D231A1F251B1E2318202719
232A1A262C1D24271B25271F26282227292826282A202527191C1F191D1E1A1D1D21231F
1F201C1C1E1A191C18191D18313B2C414F3B4F6048586B4F596C504B58433640312F382B
2E382A323C2E364132414D3A44513C4A574048563E49573F4B583C4E5C3B4A56364C5636
4B543749513949523C48503A46513848543A475237465136475136465134475135474F35
474D33464A33464B34494F39474E38485038475037454D35454D34444D333F482F404831
3F4731424A34424A343D45303A412F383D2D343A2933392A343A2A363D2B363E2A343E2A
2D37262A33222D34212E33202E33202F35212E34202E3420303823323923313822303822
2F37212E37232D34232A3121282F22262F20293321262F1E242C1C272F1E22291A1D2316
1F2616222615232716212316
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA5A8A9696B6E313336
2C2E2C2425211E1F1B1C1B191A1917171513171211171211181412221F1B33322C3F433C
3F4641434D49434E4B444E4D414C4C434D4E454D4D444A4C44494B494C50494B53464853
3C3E4A3134401F222D13132013131C1111171112151415161A1E1B1E231E1F241F20261C
232A1F262B1F26291F25271F34373034373531343723242A1E1E2417171D17171C1B1D1D
1C201C1A1D191B211B1B211B181F181F271A242D1D313D2954674A5062472B3525232B1E
1C22171A21151A20142F392539432D444E3649543C4A56404A553F4C583E4B573B4B573A
4955384853374B55384B5237484F36464E37495239454F37444E36444E36455038444D34
444C3042492F454B32464C33464B32484D35474D35484D38474C3A4449384148363F4634
3D45323E46313F48313F48303F47303F46303C422D3B3E2B38392B36392B34392C32392B
2E36272D35242D34222C341E2D341D2D351D2A341B2831192C341B2F371E2D361E303722
2E34222D34262C3329252B23232A22232B20252D21262E21272F1F252E1D232B19202816
222916222613212412202311
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCECFCF
9FA29E3A4037272C2422271F1B1D191919171814131A14131812111A14141E1917252320
2E302D363B383D4540404945444E4A47514D49514D474F4B474C4A47494B45464D454650
454852454A5440454E31373E1D1F291B1D2516191E11121915181E1D2224202625212824
232A25242B252429232225203437303F453D424843363B382B2E2F2223261B1A1F1C1D20
1A1D1F1A1D1C1A1E1B161B17131713181E131D2415181F0F252E1D2A342221291A1B2214
1B21141B2114171D11232A1B2B32203C462F404A32444E37444E394C573E4C593D4D593C
4C58394954374E57394B5135494F364A5138484F38464F39454E39454F3A46503B46503B
454D35424A313D442D3E432B3F432A42462E454B33454A35474C38474D3A444A39404739
4046383E46343D45303C442F3D44303D432E41452F3D402C3B3D2E3C3F30373B2F33382E
31372C32372B2E35242C34212E37222F39212F381E2C351E2C321D2D341F2B321D2F3521
2D34232D35272D362A2A3127252D23262F24232A1F242D1E262F1F262F1D242D18252E17
272E16272D1322260F20240F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCED0CE979A98292A2A2323261F1D201C19191D1A191D1B1A1D1B1A1F1E1B
1F1D1B2121202628253033303F453F474F474C544D4D55514C5252494C51464951454851
4146514B565B424C524853533D46453A41403134391F202B1A1B27292D35272D3321282B
1F27262029251F272220262020211E2D302B383E393D453E3C433D39413B313532262B2B
2025261C1F21171B1A1215130E110F171C141A20151A1F131D2216232A1C262D201D2418
1B22151C23171E2519293324333E2A38452E3E4931424C30434C304952354951334A5335
4D55394D54394F573B4B53394B53394A54394953374A553949543A4A533A4B543B4D543E
4E523D4A4F3A464A38434835414631404730404730404730414731444C34424B34424935
4249374047363C44333F47363F47363C45323E46313C44303B42313C42323A4031394031
39412F3A422E363F2A343C27363D29363C29333A26323A273038282C35272A3225293224
2A33242A34242B35252E38282B34252933232B3422292F1E2B301F2A301E2C321D2B311A
2B3018282E16282C17262915
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FA2A16262672A2B312D2F333235372B2C2D272828
25262522242124262226282330342D34383241463D494D464F514F4F52534E53584A5157
434B52414C4F424E4E46524E4B57534A525249505344484F383C46353C442125311B2028
161D20141B1C161B18171B171414141715182120223437333C423C40473F4149403E4840
2E3633252C2D1E2326171C1C10141210141114161215191221281D252D1F2A3223252D1E
242C1C222A1A1E2416262D1F2B3121323925353C273C43293D4429444A30484D33484D33
494F334C51364C52394D543A4B533A4953394954384B56394953384951384A503B4C513F
4E53414D513F4A4F3D464B3A434A36424A34434D353F49333F4A343E48313D462F3E4830
3F47313E46313A42303C45323C453239422F37412E36402D37422F36402D38412E35402D
39422E38412D37412B363F2B38402D38412E383F2D363C2D323B2E30392E2F392D2B352A
2A33272831232730202832202933202B341F2C36202B331C2A2F192A2F1A262A1A282C1B
272C19252A17282A1B27291B
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFADB2B1888F8D4F54574C5452
444B44383D3634372E31312A302F29302E2C3533313836344343404849484D52514F5756
4C585549565047524C47524D4E58554E55574E535B4D555E4C555D475358343E472C353D
1A23291C2324171A1B131317110E141A15181A14143C3C323B3A343938353739363A3E3B
3F45413E474339443F27302D12181612171310141012150F262E20262D1F292F1F2A301D
29301D29321E2B311E272C1A2326172223151F20122629182F311F3F432C474E33475036
4A5337495235495137484E37474D36474E3749513A48523947513847523949533E49533F
4D574249523E46503A454F38444E36444E36434E35434F37414C353F4B333D49313C4A30
3D482E3D462F3D462F3B452E3A43303B443139433037412E3944303A453137422E34402B
34402B35402A353F2B343F2B38422D38412B39412C373F2D353B2C343C2D333C2D313A2D
2F382B2C36272831212933212B35212C36212C34202B331E2B311C2C331E2A2F1B292F19
282E18262B17282C1B282D1C
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3E7E4C5CDC6
8B9D8C545F594B534C474D4644444043423E3F3F3A3635323433323736374141424A4D4D
4A524F4E58504F5A4E535F52535D554F57564B52584D535D5058614F5A634C586149555C
3D484D364041252A2E2323271D171D1E161A27222146453D2C2728282527231F23232023
2F3230373F3A3C473F3D4C3F232E25151D1511170D0D100714180E161B0F191D0D212513
242918282F1E272D1C24291B212519282D2021251A1F21181E1F163D45315C6A4C586548
586547535C434E553F49503D474D3A454C38454C38424B36424B37444D38454F3C47523D
48523B49553C48523B454F37434D35414C34424E35435136414F34445034404D313F4A30
3E482E4048314148313D44313D43343B43343942323A43323B473337422E37442E37442C
37432A374228384128363E27363D27363C28373E2A363D2B353D2D343D2B333C2A2E3727
2E37282D36272A34242A34222933212B33202C321F2C301E2B2F1D2B2F1D292E1A252A16
232716272B1A262A19262C1A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFDEE1E0BCC3C0727A797D887E86937F46484245474041413B3D3A383E3A3A3C393A
3E3D3F4244424B514950594E535E52535D564E57554E545854575D52575E4D535E4E5660
4D585F4D5B5D485454404A4A3335362824283937353F3F392520232320241B171E161219
1615181B1D1D2328232931282731251A2319171D12171E1112180C14190D14180D14170C
181C101A1F131C2014171C1313161121281E252C20282D22282C213136274D58405F6B52
6270566371595C6953505A48494F3F4246353D41313A3F303B41303E4233414736444C38
47513B48513E454F3E444F3D3F4B38414E37404F34415032414F32424D30424D32424C31
444C324147324248353E44353D45373C463938433537423039463037442D38442C37432A
3B452C3A422A383E2A373E2B323928303827303927323B28313C29313C28313C27303B25
2F39232E37212C351F2B341D29301C2B301E2D301F2C2D1D2D2F1E2D2F1F2B2C1D282A1B
272A1B282B1D282C1E25291E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFD0D5D1B9C4B7828F7D75816D53584D56594E5152494B4B45
45444140403B3E3F3941433B484D434D534A525953545C58585D5E565B5E52575D50575D
4E565B4B585A4E5C5C525F5B525C574C504F494A4B3B3A3D221E291E1D281A192414121C
14141A121417111513131813141B13131C13141C111921121C23131A1F12181C0F191B0F
16180E191C1115150C11120910100A11110D161712191A121B1C152A2E2332362C485141
525E4B5D6D5762745E6678605865513E44352E2F2227261B27251A302E2135352839392B
404432444A37434D3B434F3D3F4C383F4D3440503041502D414F2D434F2C404A2941472A
42482F4348333F45353F46373B42353B443738433536403035412C3542293541273A4428
3940283B4129383C283A3E2B383C2D363C2E323A2C313B2E2D362A2B35282C37242E3A23
2F3A212F3A1F2E391D2C361C2D361C2D331C2F331D2F301F3132212F2F1F2E2D202C2C21
2B2D242B2E2525292022251E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0D6CAABB1A4919A89858D7E7B8273
666D5E4E534346493A4042353A3A313D3E363E403B4649464E5252545B5B545D5E525D5C
4E5A594C58574B5756525D5B58625D5C625F595D5F555A603839472D303F222532181B27
15182313171C1016170D13100B100B12190F1A22131F2814232C17232B172126141F2313
1E22131A1C0E161809110F05110E0714110D16141019171516131314131618161A262826
313632414C424F5F4D5A6C535061485A6B4B4148323738282F2B232E28262721222B2825
33332A393E323D45363F49343C47303C482C3B4828404B2A3E482A3D45293C42273C4228
3C432D3B422F394030394133374033343E30363F2F38402D38412A3741273A42273E452A
3D442B3D432C3D422D393D2B373C2C363E2F343C30313A2D2C35282C35282B34262B3523
2C37232E38212F3A222E3A212C371F2C351F2F36202D311F2B2E1E2A2D1F2B2E212A2D23
282C23282C2325291F22261C
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBEEEAD4D9D1A5B1A2
909B8C86937E5156493D4137363A322F312B2C2D282C2B293636334B4F494E5550535C59
56605C545F5C505B5B505B5B545D5C59615E5A615D5D63625C6263555C603E444B333A40
252B33191E2411161A0C12120A100B121A0E1B2311252F182D37212F3A222B341C212914
1D220F191B0A14160613140512110716130B1B180F1F1C12201D18211F1C221E1C1E1C1B
23222233363140483D515E4923281E272F202A332344513959664B575E48525645494B3C
3F40343B3E333D42353F45363F45343C432F3C442B3C43283C4529394028383F27383F29
373D29353C28363D29383F2E383F30353C2E343A2B343A29393E2B3B412F39402D383F2C
39412D393F2D38402E38402B363D28363E29363D2A3139272D35262D34262C33252C3325
2B33262B34272B34272B35262C36242C35232C342129311E2A301F2A2F1D2A301C272C1A
2A2F1D2B2F1F2A2E1C272C1B
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EAEDEAD0D8D07B877C474E4D3E443F373C3430332A2C2D232A28202C28233B3B34434540
4A4F4B505853545E5A58645D5D696159635C565E575A615A585F5A59625E57615F535F5C
4A57553742421E24271418180F130F171D111D2616222B1828321B2E38212B341D242B15
1D200F16160A1010060E0E0711120A13130E282B202122181D1C1250593D474D34282720
444B403D4239363B342F342D26292118191313130D0F0F093A43307F94708194737D9072
565F51515A4E4D544A494F43474B3E4247384147323D462D3E492C3D472B3C442A3A4329
373F25373F26353C27363B28393E2B373C2C32372934382935392B34382C343A2E343B2E
353D30333C2E323C2B333D28333F26323E24313C222E381F2E36212E35222D33212D3322
2A32242931262831272A34282A35252A35242B36212B361F29331E29321C2A3118293017
292E18282D19292C19282B19
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBCC2BD8A928A474E47383D34363B2C31332635352A32312B32302F
3230303433334348424F574E5761555963575B6557586255545D53555F5558655956635B
52615B55655C3A45401A1F1F1A1F1A181D15181E141A20121C22121E2413212516242918
1E221314150D13110E11100F0F0E0E12101023241F1513132F332EABC89EA8C5A06A7C6A
4752494650452123201E1F1B16161318181313120F12100E141211788C6D95AD8A8BA082
84987F6B7A6C67766864726162705C5C675655614D515E464D584047523A454F38434B36
3F47323D432F3A3F2B393C2B393B2C373A2A34372B33362A32352933372A3135282F3429
2F36292C35272933242D37262B35242C35242D38242D38212C371F2B341E2B331F2A3220
2A32212931212A34252B34252B35242932202B34202A321C29321D29321B2B321A272E18
272B17262C1A262C1D242A1B
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA2A3A184887F5D63574B4E4640403D3D3B39
3633312E2B282926232C2A25404437494E4159604E5A63515A65534C56495662504E5948
4A57484857484D5D4C384437252C211F26181D2114181C0E191B0E191A0D1D1D12202118
1F201718191214130D14130D14131012100F1615141C1C1B1D1D1F6371607B8F78B1D3AA
697D6533392C262A1D1E1F1516150D120E0B14100E141010100E0E363D3395B18E889F82
869C817A8D75545F535A6655606D5B6D7B687D8F7980947B7D8F7677876D68745C606753
5B6051565B514F544A474E433E44383A4035393C34363931353930373B2E33382B323829
3138282F37292D35292C33282E35292C33272A33252D36232D361F2A311A2E341D2B311C
2A301E29301F28301F283122262E1F28301F262C1B282E1B262B19272C1A262A1B242919
212718242C1E232B2021291E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE8EBE6BCBFBA676962595A54
373032352F2E2E29282824222A2822303027393C2E474C3A464D3A353A2E383F30323A2A
2C35253039283B4631424D342B31202D31212428191F2115191A1018180F1D1D1522231C
20221C1616131315101316101316101414101E1F1B202221232623222624313833677864
6576613E47391E1F1725251A130E0B110C0A0F080B0E060C0F0B1147504881988188A089
7F967F869C80798B726B77635B62555D66588A9C8286987E8A9C8092A3858595785E6555
646A5E6C74696D776C687368626D5F5B6558535D5249524A454C4740473F3E463B3D4438
3B4335384034323A312F332C2E332A2D32272C30232C301E2D321D2E301B31321C31341D
2E331F272C1B1F27161A2013171D10191F121B21141E2315242919282C1C272A1D24271B
25281D22281D20271E21291F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD9D9D8
9E9A9C3A34343B373337342E34322A3534283435263030212E2E1E2B291C252519202215
222616252918303520373C263135232C2F2024261C1E1F191B1C181A1C171F201D242522
1E211D1B1E19171915181B14181B1214171014151122241D2C3126343A2D373F32434C3C
485240434B3A1D1E1721231C1B1917171214140E14110B130F0B1338393A6D7B6E718474
7C927B82977C899C7F8A9C7F8091787C8B737D8F7582957985967B84947A93A58A84937F
555C57585F5851565174806E85957D5E675D59625B5A655E616D64637066647166616F61
5E69595962524F5648454A3F393A3234352C3436293134232D2F1E30311E32321F2F301F
2C2F20222518191C100F1308090C04060802090B05090C05171C0F1D2314222718242719
24261C24271D20241B1E2319
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA6A6A28C91814D5040494D3B4447353F3F2F3230232F2D222A291E28271B
262818272A192F31203B3D2C393B2D31312828282222231E1D1E1A1E201C252724282B27
2527222226201E211C1B1D1A1B1E1712140E11110D14130E191B12272D1F343B2947523A
454F37373E2A2C322225281D20211B1D1D191C1B1B1918181A1A1A181919292D2940483D
4C55485D66549AAD8D93A48993A58992A4878FA0838D9F828C9E83899982889984899B86
7989796E7A6D656E62636D5FA0B6978EA3895B665C5B675D545E56535C546E7E6D788A76
7C8F787D9078798B736C7A66636E5C5E6756555C4B4D5241484D3B4447343D3F2C35382A
30352A282C23181B120D1109090C05050701050702030501020401090B050E110616190B
1E2113232717232919252D1D
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFC4BA989E8F595C4C4343344244323B3E2B3C3F2A
373A233639223537263C3B2D3E3C3038372D2D2D2526261F1F1F191F1F1923241E282922
2B2E282E312A2B2F2A2023231B1D1B1112100F120E0E110D12150F161A13252A1D282F1F
2A301F2D3220262A192122151E1E181B19191F1F201B1B1E3B433D383E3A3F4840454F45
49524640433C62685C9AAB9288978392A38B89998290A1898EA1898C9F898DA18B8CA08A
869B858598808093797C8F767A8D737F93787B8E777A8D7570826C6D7D6A6C7C6B738572
7788767A8C787B8E787C8D777B8D767E8F767D8C74778371717D6D6D7A6A6572635B675B
4B564B272D291E231D171A140B0C07070803040502020301020301010301010301040401
161809212512242915252A19
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1E3DEA09F9E5F61566F7761707960
5B614C515643474B3C45473A43433737342C312F272B2A2126251E20201920201924251C
2727202B2D252C2F282325221E1E1D171717141414121513121613171C171C221A232B1F
282F2029311F2126161E20141C1A161A18171816192020253E444467776B647769657868
697A655D6958454742C0D9B47786767788785B675D5F6A5E7C8F79859780899C848CA18A
889D878CA389556357657662829578788B70788A747C917B8096808097807F967D778B74
778875758475768376738276748475758673788673778473788572778573778574778673
7B8E773A413D1315180D0E0D0202020102010102010102010102010103010306010B0D03
101305181C0B242915272B18
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7E9E4C0C7B3
9EA68F8A917C777C6957574C52504546423739362C3333292A2B2226271F28281E2A2C21
2A2C23282A2122231E1E1F1B1A19191A191A141517171A191D221C232A20252C212B3125
2C32262E36282B312025291B24251E20211C1E1D1C1A191D515E54A7C7A2768D73556653
55634E40473B464C42889B81718370758B756071605B6A5872846C7F937A83987F869B84
889C868DA48A4047434C544CA4BD993D403C5C675E98AF967082736C8071738977798C7A
758576728074748178727E7974827A74837774847474827174826F6F7C686F7B676E7B65
6C7A643336320F0C11070306050304030202020203010102010201020401090B031A1C0F
1E2112222717232A17242A17
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFDBE0CFC0C5AD91957B8488725554484647363F422F373D2B3034263031242F2E21
2C2D2028291E22221B1F201A1C1E181A1B18191B181D1F1C2326212D32272E3327303629
30342A3034283035282E32262D31262729201B1C15191A131618113E493655654A383F2F
393F2F2E33282C31272B3028252A2372896A64775C64755C6E7F6775866F778A73798D78
7C907D8096816B7B6C72826E95AB8C3C403F4A514FA0BA9F8BA08A68776A849882778676
444646575D5A7A847D717C786C79736F7E7371817172806F75856E6F80686D7C6564705B
4E58482F342D1312130E0C0D0B080A070406070505030202030402090B0710130D222619
282E1D2930202A32212A3321
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFD5DBC8949E7B51503A5759404F513C494B3A464637403F32
39372D302E2527271E23251C21231A1E21191E201822231B282C2131352837392B393B2E
36382C37382D33342A2F30262C2D242F32292729211E20191B1D171718141719131D1E17
1C1C161B1C1720231D22261F1A1E193B46365C6C50657559869D786B7D6255624E465045
56635B63756B718777728775788E796A7D70697C707A917D94AE9289A085899C84666F63
28232E2E2D3891A692535C5C41454A63716775897457635650594C616F5967776064745D
4C5A48272D27191C1A1110100A080A0806080705050504030302021D23172930212B3221
2C33212B3123282C21272C20
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFE0D9BAB9AE909378949C7B7F84685D5C4B
4440383C3B322E2F252A2E21282C1F272A1F28291D29281E2B2C2435372C3E4132414436
3D4035373A3230332B2C2E28282A25242622262A2222261D1F2319191D141E20181A1B14
1616101B1C141F211822251D1F221D181C17242A212B332843513C44523B44513B303528
2D33262D322A4754465768546477605363514A584C718770738973788E777C917C738273
2E2D3634393E758B797C937E424C476A7A6872846E3F463D16131631342E6E7F674E5A4A
353E363039301C201C181C180D0F0D0709070709050508020608032A35214050353F4C34
323C292C3524282E2026291F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF2E9C8D1B89BA286
453F3B4F4F4542443A3D40333A3F2F3B402F3C3E303C3E30393A2F3C4033494F3E4D5442
3D42383A3E37373C352E322D2A2D2B282B282A2E28292D2525292122271D24271E1F211A
18181221241824281C272A2022241C1E211B1A1D18181B1621271D272B20282A2026291F
24271C22261A25291D293023697F5E4C5A42353B2C2A2E26505B4A535E515C695F758778
798F7E5969615E7162697C696D816A70826C6E7F6D515A542C2D324F564E576055586357
4149411B1F1F1C211D151A130E110C0A0C08070905090C070E120A13190D405035495B40
3C48363540332B3328222920
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CDD0C2999A8D8C937C787D68696F5A6569555F62505A5D4D4E5144474D3F46483C44473A
4043383C3D363839363638353538343638363134322E322D2F332D2D322B2B302922251E
1B1B171C1C1820221A23261B20221B1C1E1816181321231C30352A2E3227292D2320201A
1E1E171C1E151E24181C2115282F1E323B27353D28303623282D1E23251C22242030342F
62725F4651483E48414852485D6C5A667866697C6D6A7C6D6371656A786A555C56464D4A
4F5C4F1B201E181D1A0E120D0B0E07090B040A0A0612130F11120F0E0F0F141716181D19
1F251E374234333D31282F27
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFD1D6C9A6B092888E757D826A656855585B4C5355474B4B4148483D
4242384040383D3C354D51444D5348484E4441453C373A3232362E2D31292C3029272A25
20231C1C1D1621241A24281C23261B1E21171A1B142628212B2E262B2F252A2C23272821
21221C20221A1B1E151B1D1314140B18180E1C1E12232517202215191A10161811151511
39413353614E202422252C28252B2B2F39345262546173606475626372635F7062343E3A
39463B3744351A201911151012160F12130C12100C12100E110E0E0D0A0C0C090B0B090B
0B090C1717171D1E1C262A24
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAEDE4CED4C595A0837377616F735D63635657554E
4E4D474A4A4442423B5A645168785F697A5E6472563335282C2C2327261F22221D232321
2323212223212628232629222227221E221F202321373F36383F352F332A2C2E25272920
28281F2A2D2325271E1B1C1415150B1110061A1B0D2020101A190C1210080E0D080D0C08
1A1C1555644C29302728302A1F25231A201E171B1A2C372A36412E2D3324363E2E404C3A
50604B47543F0D0E091618121B1E17181B151B1C17171614110E110B060D0C070E0B050B
0D060D0D08110E0A121B1C1D
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAECE5B5BBA89FA78E6C6B61
5F5F5858585053544A45463D464B3D525C46454E3D34392D2E34282A2E2523241F212220
2323232A2D2A2B302C2B302D2B302D23272725292A4B574C424E44364037323A3031372C
2F342A2F342A2426201A1A17110F0D121209191A0E1E1F111D1F1216170D11100B0C0B09
0B0A09171813191C18181B18141817131816141A171C231C1C23171A2112191E0F161A0E
25291A292D1E1E201624281C22261D21241B363C2D2B2F24262821201F1D201C1C1C1718
181215130C13100A14130F17
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD5DACE
A2A59A67675F67695E52524A4D4E4648493F3F4238383D332F322D292B27272926222423
272B282D322C31372F2F342C2E322A2D2E2A2D2D2C34373434393533393132393031392E
333C302F372E252B252224221C1C1A191A161C1F171F24181B1F14171C1110130C11150B
0F110813140D171A12191D18151916111511121610171D14171C10151A0E16190E16190E
13150C191B13191D151C2119191D181A1D18252B1F343B28343B25292C193435213B3A29
2F2B212C29222725221E1D1C
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCD1C5838A776A6D60616357505147494A40393934343330302E2E2A2B2B
29292A2A2D2B2F332F30342E2F332C31342B32342B2B2B25292924252822272A232D3127
31382C2C31282B3028292E28232622272C242C3428232B211C221915191211140E0D100B
0C0F0A141812161B141A1F19161B1512161111160F161C1215190F12160C10130B0E120A
0E120A0D100810130B15161013140F1C201822271B282E1D2C301A1D1D0936371F211B12
35322B2925242F332B323A2F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEAEEE7BDBFB97F86796A6D644A47464A48453B3738353132
332F2F312D2D2F2B2D302E2E2D2B2A2C2B272F302A2C2D2627282225262022251F23261F
22251E242620242A23282F26252C24273026384531252E1F1B221713171211120F10120D
10130D1417101A1E161B1F181A2016181E121920141D2416191F12181D1111160E0F130E
0F150F0D120B080B040B0D060B0C060D0D050F0F0715150B1D1E121A180F4C533B110D0B
67715D5D6A551012101E241C
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7EAE49DA0967B816F57584A525243
4B493B443F353F39333F3A332E29282E2A272D28252B2724262320262521282C24252B22
20261C1F261C232A1F21291F222B1E242E1D232F1D242E1D1E2516181F12171C1015190E
15180E191C11181C101B1F141C2116191F141B21181D24191D23181C2318121B110D130D
0F150F0C120C0A0E06090C04090A050808040A08070907050A0A05090B030D1004161A0B
1B200F232915212714191C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC4C8BC989A8D
6A6B5C575549524F424B483D4442373B392F33322A2A282324221E23231F212320222721
21281E1D2419191F15191F1421291B1A21121C22111F27141F25151F24161E23171C2217
1A2017191E15161911191C141B1F151D23171F26191E26191C26181A2518182215151F10
111A0D0F150A0D13070C10050D10070C0D050B0A05080804070904070A03070A010C0F02
111406181B0A1213050D0D03
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFBCBEB66C6D605B5D4E5154444A4B3E3E3F3737373235352F32312C2C2C2A262827
2326251F23211C211D191E181D231A1A20171A2014202619232A1D22281C20271D20271D
22291F1F261B1C23171F2717222B17232C1827301A212B15222C151F29151F27171C2314
1C23131B2210161C0D181C0D14160B13130914160C11120C0D0F090C0F080C11070C1006
0C100712150A1011090C0A05
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFDEDFDCB7BAB46667634F4E4C48494542443C3B3C3332312C2B2929
2523272120231C1D201E21211C211D171A17131512121612141813161B15151B13171C14
191E15191F141B2216182010171E0D1A210F1C24101B230F1B220F191F0D19200E19200F
181E0C171E0B1A210E1A1F0E191B0F16160D15160D10120B0E100B0B0E0C0C0F0C0D110C
0C100B0D0F0C0E0E0C0B0A08
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0E1DE989C917179643E3C343C3936322C30
271F28211B251F1B242020252020251D1E221415190F11150F11130D0F0E0B0D0810140C
10150B0D13090E150B0E1407121A09141B08151E09131A05121902171E051A2008161A07
13160510130312150713140912140A11120D1114100D0F0D0A0C0B0708070B0D0A0E110D
0C0E0D0C0F0D0E100C0C0B09
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB0B0AE736D7449424E
2F2738282030221B29201A241C172017141D17141C14151A1013150F131111151011160F
10150E0D130C0A1009070D06111A0D17210D131D08151D06141D03161F05181F07141805
151706121306131507100F0710100A13130D13140F10120C0C0F0A0B0E080A0E0811150F
0C0E0D0C0E0D0F100F0F0F0C
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
938E9B36313E3631372C2428231A1F1E171B1D191A19171818191A181919161917111413
1418160E10100B0D0D0B0D0C0D110C13190D141B0C151E0D111B09101906131A07161E0A
151B0A161C0E181A0F16160B14140C13130B13130C14150C0F12080E11080E10070F120B
11130E12131112131111120F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCFCDCD9B96963127282A2022241B1E1E17191C16181C18181B1818181417
1410141512151310120D0A0C121311181C17191E15161C11161E11151C0E171E0D151C0B
151B0D151B0E151A0F14190D14160D12140D11130E13160E14170C0F13060B0D030C0C04
0F0F080E0D080D0D080E0E08
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9792935F5858251C1C241D1E201B1C1D18181A1415
181214171417161414100F0E0E0F0B13160D171C101A21131C24141C25131C2311171E0E
161B0F151B0F151B0F14190E11150D0E110A10140E12161011160B1014090F1307101106
0E10040E0E03121408101408
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9591935B555C1F1922221D25
231F261B192115151A1012110C0E0C0E110D12160F171D141A21161E24171C2115171C12
171C13151B141015100F120D10140E11150F14181111160F0E130A0E12090E11090F120A
0F13091114090E0F05080902
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC6C5C89FA2A2
282A301F21291A1D231417191012110E120F1115101519131A1F1A1F231D1C1E18191913
191A131A1D18141714141713141712151A11151911161A1312150F0F110C0F120D0F130F
1216100E110B080B05060702
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC7C8C98F90921E211C22271C1B1F151A1B121718101A1B151D1C181E1C181D1B18
20201D1F201D1C1E1B1B1C18191C17131611181C14171B141418131013110C0F0E111413
1217140E110E080A07020302
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF979A91595B502123151F21151C1B161C18161E1A17201E1B
20201C20221E1D201D1D201C1B1F1B181B17191E17191F171519131418121014100C0F0D
0C0F0C0A0C09060705020301
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF92938F5958571B161A1D191B20201D
23241E22271E1F251E1E241D191F19181D18191E181A1F17191F161318120E100C080A08
080A08060604050302040301
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC5C4C68A888C151317
151413191A15181C1614171415191515171417191415171013160C0E10080807040B0A08
0E0D0A090706080504080503
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C3C3C488878815141319171616151314140F15160D16170D13130B0C0C070B0A050C0B06
0F0E080C0A05090703090704
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF9495935958561E1E1B16161015140E1514131312120E0E0F0E0F0E
0F110D0F110A080703080601
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8E8E8E5555562123231B1B1E15161C0F1016
0B0D0F090B0A070904060602
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3C2C58B8A8E111018080811
04040B030305020302040403
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3C3C6
83848905070B040506030303
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF818384414144
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.392007 0.477324 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
10110910110811110A11110B10100E13131115161217181216170F16170F181810171810
181A10171B1014170D14170E15170E16180F18190F17190E15180E14180D13160D11140D
13170F131810141810131811151812181A13181913191913191A12191B11191B12191C13
191D14191D13191E121A1F13191E12191D11171A11171B131A1E141A1E13181B11181B10
191B111A1C111D1F131C1F131C1D151C1E171B1D161C20191C20191B1F171A1E16191C15
1A1E15181C14171B13181C12191C11181B111A1C121A1D131B1E151B1F181A1F181B1F17
1D20181B1E151A1D14191C14181A141B1E171C1F161C20141A1E131D20161B1E141B1F15
1C20161C1F161E20161D1F131C1D131D1E151D1E161D1E151D1E161B1D161A1D151A1D16
181B15181B15181B14191B131B1C141A1B13191B12181911181A111A1C13161711151611
15161015160E17171017171215151114140F16171216161215141011100B13130B13140D
13140C13150D15190D12170D10150C11140C0F12090E11080E10090E11090E0F070E0E07
0F110B0E13100E12140D10170E0E180F0C150E0C0E0D0E0B0A0C090C0E0C0C100E080B0D
010205000002000101000001000003010005000006000006000004000003000003000002
000001020001030101030000
3940383D453D404941414B4339403D23282B1B1F201C211C171B15161B12171B0F191F10
1C21121C20121D21121D20111D20121C1F111D20121D21121C21121C22131A1F131B2013
1C21141A20131B22151C22171E231820231A1F231A20231A2024182125172024171D2215
1D23171E2518202816232A19232A1923281922251822261924281A222718212617222718
242A19252A1A272C1C262B1D262A2024271F24271E242A20232A1D242C1C252E1C262D1B
282E1C262C1D262A1E272B1D262B1C252B1B262C1B272C1C272D1D262D1F232B1D232A19
252C1A242B1A262C1B262B1B252B1A292F1C282E1B282D19282F1B292F1D252A19262B1A
262A1B25291B272B1C2A2E1F2C30202B2F202C2F212D2F212C30222A2F22272C1E272C1B
272D1B282F1C292F1E2C301E2A2F1D2C30202C2E20292B1F2A2D202A2E2226292024261D
23261A22251923251926261C25261D22241C22241B2123191E21161F2115222516212416
2224152225152125151F22131D21121D20111D21111C20101C1F111C20131B1F121B1E12
1B1F12191F111920111F29190D100D0C0E0C0C0E0B0B0D0B0A0C0911150E13180F070905
060702060803050703040603060704060705060805050805050805050804050704050805
050804060903060803080803
94AA9699B19D9CB6A09DB8A08FA69040494812141A191D1C1316140F120E0E120911150A
151A0C171C0C171C0D181C0C191E0D1A1F0E1B1F0D1B1F0E1A1D0F1A1D111B1E121D2015
1E22171D22161D23181D22181D22191D23191D23191E23191F24181F25161F25161D2215
1E24161E25151D25131F26142126162226162225152124162224172022151E20131F2215
21251720261822271824291C25292023261F22261E24291F23291B262B1A272D19272C17
282C182B2F1D292B1E282B1D2A2C1E292D1D282C1B282D1B282C1C252A1A252A1A262B1B
282F1C2A311C262E1B242B1A252A18272D18282D17282E17282D17272C17242915242816
25291923271825271927291C292A1F2A2D212C2E212E31232C31222A2F20282D1D29301E
29311D2C331F2E34202E33202D31212E33232F34252D31222E31222E32242E30242B2D22
282A20282C21292E212C2F222C2F24272B2026291C25281B23251925271A242819232717
2426162527172427172327162426162325152427172326172024162125171F23171E2215
2023151F23131C21121C21111B1F10181C0E151A0F151911151813151A13161B1115190D
14190C14180D13160C11140B14170E171910161811131611121510121611121611131613
141912151B12141911131710
97B09E9BB5A49FBAA59DB8A19BB59D627367191D22151919161A17121612131810151A0E
171E0E19200D181F0E181E0E1A200F1C21111F22111E20101F21131F1F151E20181E2019
1F211A1F221A1E231B1A20181B21181C23191C23191E25181D25171D25151D24131F2514
222716222916222915222815232817242817232716232617242718232717222516222617
222618222619232719262B1E262A2023271E21261C232B1C252D1A282E172A2E16292C16
2B2D192F301E302F202C2C1F3030222E2F212D2F202E2F1F292C1E25271B25281C25291C
282F1C2A341E232C18242C18252C17272D17272D16272C15282D17292E1A262A18252817
25281925271B25261D27271F272720282A222B2E242D30242B31222A3120272E1D272F1A
2A311A2B321B2D331C2C321C2A301D2B301E2D32212D32222D30222F31233033242D3122
2C30242B2F242A2F222B30222C30212A2E1F282D1C272B1B27291A262919252A19272C1A
272B1A272A1A25271A24261824261824251925251B22231A21221922241A1F24181E2316
1D22151F25161E25151E25161F25171D2215181E12171D13161A14151A13151A11151A0F
181C0F171A0F17170E17180F191911191A13181A13161815141714131613161915151814
151913171C14161B13151810
8FA6949BB5A0A0BDA59FBBA39EBBA0849D88394540181C1D191E1A13191311150E13180F
141A0E171D0F1A21111C22131C20131F231521241722231622231721221B20221B1E2019
1D1F181B1F171C22191B21181C24171C23161C24151D26151E26142027141F2513202715
23291722261523271525291825291925281924271824281924291A252B1A252A18252919
23271822261822271823281B23281E20261E20261D242C1D27301D2A311A2B311A2D301B
2D2F1C2C2D1D2F2F212F2F212E30212F31242F30232F31222D2F21292B1E2A2C20282C1F
252B1A252E19252D18242B16262D16272D17282E182A30192B2F1B292C1C272A1B262B1C
23291B24271C23261C282A20282C21292D222B2F222C32222A30202931202A321F2C331E
2F351E30361F2F34212C2F202C30222B30232C32242E32252D32242E34242F33242E3323
2E33232E33242C32222D33212C321F2D321E2D321E2D31202B2E1F2A2D1F272C1D272C1E
282C1F282C1F252A1E262A1D272A1C24271A23251A2224192224192326192025161F2616
2026152228152127131F24141F23161D22151A2015181E15161D13161C11161D11181E0F
191E0C191C0C191A0D19190F1B1D121B1E13191C141A1D16171B15161A15181D16171B14
161B12171E12161B0F15180D
5D6959798B738DA58894AE929AB79897B5955F745E1A201C1014110F140E0C100A0E110B
11150D151B0F181E11191F131A1F141E231720251922271A222618212519202317202317
2023172023151D21141E22141F24161E23141E24131F261421271623281824291A202618
22291A222919212718242A1B252A1B262B1A272C1B272B1A252A19252918252A18252919
2326172025161F25171F251A20261D20271F232A1F262C20262E1E272F1B2A311C2B311C
2D321E2C301F2D31202C2F1E2D31202E33232F33242F31213031202E2F1E2D2E1E2A2C1B
292D1B272D1A242B17242B16262C17282E19292F1B28301B282F1C272D1C272D1E262B1D
252B1B242A19242816272A1A2A2C1D2A2C1E2B2D1F2C2F1F2A2F1F2B31212C33212D3422
3037243137253034262F32282F33292C31282B30262B31242C32232C32242C32242C3322
2D33212E33212B311E2D331F2F351E30341F3032202F31212D30222B2F23292E21262B1F
272D20242B1D232C1D242C1A252B18252A19242718232517222416222517212315212513
2226132126112024101C20111E21161B1F15191D16181F16171E12161C10141A0E151B0C
141A09151A09151A0A15190B181D10191E12191F121A20141B2114191F14171E13171D10
161C0E161C0C171B0D15180C
22281C2F3628424C3A5463496B815F839F75728B64242A1E10130E12180F0F120D0D100C
12160F151B10161D10191F121B22141D24161F251721261721251621241721241723251A
23271B24281B23261822241622251620241421261422271522261722251822251A21271C
21291B21281A22291A23291B242A1A252B1B272D1A292F1A282D1A252918252819252819
24281A242A1A242A1C22291C232B1E232A1D232A1B242C1B252D1C252F1A262E18293119
2A30192A2F1A2C301D2B311E2C321F2C32212F34263134263132223132212E2E1D2E2F1C
2B2F1B292E1B252C18242C18232C18222918232B1A242C18262E1A272E1C272C1C272C1C
272C1B262B19252817282A182C2E1C2B2D1C2B2C1D2C2D1E2A2E1F2A2F1F2B31202C3220
2E342130352332362731342930352A2E34282D32252B31212C31212C31212C32232E3624
2F36232F35222C321F2D332031352132341F3233202F301F2B2E1D2B2F1E282C1B272C1B
272D1B252B1A242B1A232B18232B16262C16272C19252918232617232717232616222615
2124151F23121D21111B21111D22141B2015191E14171E13171C10171C0F13170B15190C
15190B13170913160815180A171C0E181C0F171D0F191F111A2013191F13171D11161C0F
14190B141707141608121408
14190F191E131B20151B2115282F1E3C472E414F34262C1C2126191C2116171C1213190E
151B0F161D10171E11191F131C23151E241621261822261922271922251822241A24261B
25271C25281B24281A24261824251620241221251221251422251624271923271B24281F
242A1F22281D232A1E252C20252C1F242A1C242B1A272D1A292E1A272B19272A19292D1D
292D20292C20292D1F282E1F292E1E282D1B272D18262D16262E18252D18262D172B311A
2C311B2C2E1B2E301D2E311D2D311E2D33223035253033243132242E30212D2F1E2D301E
2A2E1C292E1A28301A272F1C262E1B2129181E2616212818232A1A262B1B272C1C272B1D
272B1D262A1B242719272B192A2E1B2B2F1B2A2E1C2B2F1D2B2E1E2B301D2C311D2C311E
2C321F2F34223238263237283036293036282D34242B311F2C321F2E34212F37242E3623
2D35222F36232F35232E312230322032342132332130311E2F301C2D2F1A2A2D192A2E1B
2A2F1B2A2F1C292E1C282D1C282D1A282E19292E1B292E1D292F1D242C1B222818232817
2125151F21131F22131F23141E22131E21131D20141A1F121A1F10181E0D181C0B181A0C
18190D17180C16170B16180A191B0D1A1D0E171C0E181D10191F12181D12161A1014170E
14160C1216091113070E1004
0E120A10140D12150E14160F171A131B21171E25191D23171B20141A1F12181E0F171F0E
161C0C161D0D181F11161C10181F111B22131F2515222717222617212517212517242719
25281A25281A25291B242719252919262B1A24291822271722271823281A23281B24281E
262A1F262A20262B1F272B1F25291E23281C262B1C282D1C2A2F1D292E1C282D1C282B1E
292C21292D21282C20292E1F2A2E1F2A2E1E282D1A252A16252B18292E1B292F1B2C321C
2E331E2F331F2F321F2E2F1E2E2F1F3133233236263134253335263133242E31202E3221
2D33212C311F2B321D2A321D29311C272F1B242D1A252D1A272D1B262B1B262A1A282D1C
292E1E272C1E242A1B252D1B28301B282F1A282F1C2A311F2C311F2C311F2C301E2D311F
2E331F2E341F2E33203236253338293238292F35252C32212C331F2C341E2C34202F3623
3038263137263034243032223132213132212F2F202E2F1E32331F30301E2C2F1D2B2E1E
2A2E1D2C301E2A2E1C292D1C2A2E1D292E1B282D1B2A2F1E2A2F20262E1F242B1B222919
2328172225162124152123162124162022151E20141D21131D20131D1F101D200F1B1E0D
181A0C18190C18190D18190C191B0B191C0B191C0B1A1D0F171A0E15190D16190E171A0F
14170C1115080F12050F1105
0B0F070E11090E100712130A15170F171C151A1F16191F15191F151B20151A20131A2113
1A2012181F10161C0F161C0F1A210F1C23101D23111F25131F2413212414232616222416
23251724261725281A24281C252B1D242B1E242B1D232B1C22291C21271C23291D25291E
262A1D272B1E25281B262A1B262A1B26291A2A2C1C282C1D2A2F1F2A2F1D2B311F2B301F
2A2F1F2A2F1F29301F282F1E282D1E292E1E292E1E272E1D282F1D2A301C292F1D2A301E
2C311F2E321F2B2E1D2B2E1E2E31213033243237273237273337283136283035272F3325
2D33232C32212C331E2A341C2B331B29321A29321B2B341D2B321D2B301C292D1C2A2E1C
2A2E1D292E1E282F1D28321C27321926301726301829321C2B321F2D33212F3321303522
2F34212D321F2D321E3034203236233539263339263036232E35212D341F2F361E2F361E
3138223137233036233035223236233032212E2E202D2D1F2D2E1E2D2E1E2C2D1E2A2E1E
2B2F1F2B2F1F2B30202C31212B2F21292D1F2A2E202B2F22292E22282F2028301F22291A
1F27161F26141F25132025142227162125162123162022151D1F131D1F131F21121E2111
1D1D0E1D1E101C1D121B1D12191B0E1A1C0D1B1D0D1A1C0E181B0E161B0E161B0E171B0E
13170B101409101409111409
060902070B020B0E04111409181B11181C141619131619121A1E171C1F181B1F141C2014
1B2013191F12181E10181F1019210F1C24111D25111F28131F27141F2615242919242819
25281926281A272B1C272B1E272C20242A20242B21262D22262D22252C21252C20252C1E
272C1C272C1B252919262918272B1A272A192A2C1B2B2E1D2B301F2B2F1D2C311E2E3420
2D32202A301F272E1F282F202A2F202A301F2A2F21292F2029301E29301E272F1D29301E
2A301D292F1E2C311F2B301F2B30202D322230362531372632382831382830362931372B
2F35272B32242A322029321E29321B2933192B34192D351C2E351E2E34202F34212D301F
2C2E1F2B2F1F2B301E2A311D29311A29331A28311A2A311C2C321F2F3322303523313624
31372430362130351E30351E2F341E3137213036203035213035233035213036202E341F
2F361F2E34202F35223137233036223034222E31212E2F202B2C1D2B2C1D2A2C1D292C1D
292D1D292D1E2B2F202C31202B2F1E2A2D1E292C20292D212A2F22292E1F282E1D212818
2029151F28131E26111E26112127142329172327161F23141C20131B20131E22141D2013
1C1E121C1E131B1E141A1C131B1D121D1F111C1F0F191A0D191B0D191B0D191B0C191C0C
181B0C15190B13180B11160B
070A02090C030D110512170B181D10191D1115170E12120C13161011140E12150D14190F
171D111920121B22121B22101B230F1C240F1D260F1D26111E26141E2416212617242918
242718252A1A292F1D292F1E282E20262C20242B21252C22262D23272E23262D21252C1E
262D1E272D1D282D1C292E1B292E1A272B19272B192A2F1C2C311D2D311D2C311C2D321D
2C301D2C2F1E2A2E1F292E202B30222B30232A2E222A2F222B30212C33222B34212A3221
27301D262E1C29311D2A311D2B311D2C331E2F36213138243038262E3724313927333A29
3139292E38262C37242C36222C361E2A341A2C361A2C351B2D341D2E341E2E341F2E3220
2D30202D31212D32222C32212C33202B331E29311C2A311C2D331E2F34202F35222F3522
30362031371E30341B32351D31351F3136203137213136213137243036222F33212E3320
2F34202F34213136243238253137243036232E34222C3020292C1E292B1F2A2B202B2D20
2A2E1F2A2F1F2A2F1F2B301F2A2E1F2A2E1F2B2F21282C1F272C1D272E1D272D1C242C1A
242D18232C161F28131E26122228152429172327162227172127171D23141C22131B1F12
191D11181B10171B11171A11181B121D21141D1F14191A1017170C1A1A0C1B1C0B1A1B0A
191C0A16190A131708111407
060903090B040A0D040B0F050D12061115071417081215090D1109080B05090C060F1409
12180C13180C161C0E1A21111C23121C24121D25131E26161F261820281922281A23291A
222918252D1928311B28301B28301C282F1E242C1E252D1F252D20262C20282E21282F21
2930212A301F2B321F2B311F2A2F1D2A2F1E2A2F1E2A2F1D2C311D2D321D2F341D2F341D
2E321C2F311C2C301D282B1C282C1D2B2F202B30212B30242B30242B31242D33242C3323
2A322028301D28311C29311B2B331B2C341C2F361F3037222F37222D3722303923323B24
313B26303B26303A25313C26303A222E381F313A203139203137202F351E30361E313520
3134223134243033242F33232F35232E35202C331D2C331B2C321B2D311B30351F303620
30361D31351C31351A33361D3539223338223037212F36212F37213037213036212E3520
3037213137223238253137242F35222F36232F34222D32212A2F21292B212A2C222A2C22
2A2E222B2F222A2F21292E1F2A2F202B2F222B3023292E20262C1C272E1C252B18252B15
252C15262D17252C162126122126142225152125162126182027191F27191F26181D2315
1B20131A1D111C1F121B1F121C20131F22161E20151B1D111A1B0F1A1B0D1A1C0C191A09
191B0A191B0A17190B131508
040503050703040701060900080B010B10021217061218081014050A0D020A0D040D1006
0C10060B0D050D110713180C191E111C21131F261521291921281A222A1B212A1A222A19
202817222B17232C17242D17262F1927311C262F1D252C1C282F1F2A2F202B30212D3222
2D31212E32212E31212D31202D32202E33222E33212C31202C33202E35212F3521303521
2F34202E34202D31202C2E1D2B2C1D2B2E1F2A2D1F2B2F212D31222D32242D32252D3424
2C35232C35222B34212A331F28311B2A331C2A341E2C351F2C36202F3922313B24303B22
323B23343C25353D25333B24333A23323921323922323922323722313722323922313621
3135203335213233222F32222E33222F35222C331E2B311D2C311B2C311B30361D2F361E
30361F30361E32371E343920373D24373B263237242F35202E351F2F351F313721313821
3038213239223037212E351F2C331D2B321E2C321F2E35212D33212B2E202A2D212C2F23
2C2F232D30222D30212A2E202A2D202B2E202B30212B301F2A2F1E292F1C272C16272C14
252B13272B16282D1A2427172125172226182125172026181F26182028191F26181D2315
1D21131F22152124151E20121C20101F23121E21121C20111C20121A1C0F181A0D1A1C0F
1A1C101A1C0F17180E13150B
030606040705040701040700030600070A000B0E010B0E010C0F010E1102101104101106
1012080E0E060C0D060A0C050E100814190C191D0C1E2411212715222A17242C18232B17
212A17212A18222B17252E18262F1A262F1C272F1C27301C29311C2B301C2D311F2D311F
2D31202E31213033233135243135243135243035232D33222C33222D35222C35212D3521
2E35223036223135232F311F2C2D1A2B2D1B2C2D1D2B2E1F2C311F2E33222F34242E3625
2C35242A34222B34212C35222B34202A341F2C361F2B351E2B351E2D36202F3821313A21
333B21353D23353C24333A22313821333923323822343924363B27353B28353B27323724
3236213336213335223134212F33222E33212B311F2B311D2B331C2B321B2D351D2E361E
313820303721323920333A21333B23343B24353C263239232E341F2F341F313721333A24
333B243239223037212F37202E361D2C331C2E351E2F361F2D331D2B311E2D31212D3122
2E32242E32222F31222C30222C2E232D30232B30212B2F1F292E1C272C18242B14232B12
232912242914282C1B282C1C25291C24281C2326192025191D23181E24181D23181C2216
1B21131C22141D23141C21121A1F0E1B200E1C200F1C21101C20101A1C0F16190D181C10
171B11171B1215180F11150C
0308050309030509010509000307000205000306000406000606000B0A01131207181A0C
17180C1212080D0F06090C03070A02090D030D1203141A071C220E212914252E19252F1A
26301D272F2027311F27311E26301D242D18232D162630182831182A31192D341D2E321E
2E31202F32233033263035293035283137293036282E35262D35242E36232E3823323925
3339233238233136233033202E2F1D2F301D30311F3132222F3323303524303524303725
2F37252C36232C36232D37232E38222F381F30391F2F371E2D341C2D341E2E341F2E3520
313722333B23323922323922313821333921323820343922373C26363B27373C27353B26
3439223639233537243235223135232E34232B32202A311D2A311B2B331D2A341D2E391F
30391F2F371E30381E31381F303820343A23363C26333A253036232F34222D3220303624
343C28333B27333B27333C25313A2330382131391F32391F2E351C2D331D2E341F2F3421
2F34242F34262F34262E32252D31262B2F252B2E242A2E21292E1D282F19262E17242B14
252A14262B17292D1B282C1C292D1E272B1D25291C24271C20231A1D20171D20171E2216
1E24161E24161D24171D24171D23171B21131A20101B20111D21121C20101B1F0F191D0E
171C10171B1015190D101409
040904040903060A01070B01070A000508000205000306000708000806000F0E02151406
1516081213060D0E020B0B000B0B010809000607000C0E021416091D211324281B292F21
2A33272A34292B362828332327331F25301A242F162530142833152B34172C321930331D
31342133342532342830342C2E332C2E352C2D352B2C35292E3727313A26313A25323823
353A2134382035382135372035362036382435372634352831332833372B313628303725
2F39242C36232B34212C35202F3821333B2132391F32381F343921343822333622323623
313624333826333824343B26353D27353C25353D23343C22353E25373E263A4128393F26
373A243638243637253335243134252E34252A332329322029331F29331F29341D2C381E
2F3C1D2F3B1A2F391930381A31391D343B21353C24353C2732392634392A32372A2F3428
2F3628313829343C28343D27323D26313C2330392030371E30371E30371F303621313522
3034243035272F34293035292E33292C30262C3126292E21282D1E28301D28301B283019
292E18292E192B2F1B2C2E1B2C2C1B2B2B1C2B2D1E292B1E2424192121171F20161F2218
1F23191E241A1F251B21271D21271E1F251A1D25171D23151E23131C210F1C210E1B200E
1A200E191E0C181B09131606
070B03080C040B0D040C0F030C0D030A0B01080A00090B00090A000909000A0B000A0A00
0C0C010C0C000E0D010E0D010C0B010C09020905020805020A070515151221221E272A26
29312B29332C29362B29372728372127341C2734182935162A35152D35162D32182F311C
32352333362733352930332A2F342D2D352E2D372D2D372A303A29323C27353C26363C24
373C23383A213B3C243A3B263B3B283A3A2A38392E36372E34362F33382E333A2D323B29
313C272F3B242E3821303920333C21373D22383C223B3E263C3E29393A2938392A37392C
35382C363B2D363D2C353D29373F29374128363F25343D22353D22383E23393E243B3F27
3A3D2A393B2B37392B3335293135282F36282B34252B35242B35232A352029341C2A3519
2C38172E3A17303A15323B17363D1F363C22363C25373F2A373F2D363E2E343D2E323B2D
2F37282D36242F3721313A20333D21333C1F313A1E31381E343920353823343724343626
33342832362B30352C2F352D2E342B2B31272A312529312229312129322028311D29321C
2B321B2B2F1B2D2E1B2E2F1D2E2D1D2F2D202E2C212C2B2128281F25261F21241C1F221C
1F251D1F251C1F261C20281D21291E1F271A1E26161E25141E26121C240E1C240C1D250E
1E250D1E240C1D210C191A09
0A0C050C0D050F10060E10060A0B03070801050700090A010B0C010A0C01090B00070800
0809000C0C000E0E040D0C040D0B030B09030905030904070803080C090E1515181D2121
242B2727322A28342827362428372027351C29351A2B36192E38182F361A2E351D303520
32362433372932362A30362B32372D313A2F303A2D2F3A2A313C27303B25333C243A4027
3A40273B3E263C3D263D3D2A3D3D2D38392D383A2F373B30363B32363C31343C2E333C2B
343D2A343E28333C25353C23373D233A3E243C3D273E3D2A3D3C2D3A392F393931383A32
353A31353B30363E2F353F2C37422A3943283A4227373E24373C24383C253A3C273B3D2B
3C3E2F3C3F32383D31333A2E323A2B313B292F39272E38242C36202C361D2B3519293315
2A32132B33142E3714313A1733391C33371F343B25353C28343E2B333E2D333E2D323E2B
313B262F39202E371A2E3717323B1931391933391C36391F373923373725353427323127
2F30272D31292E352D2A322C2A32292932262A33232A32212A31202D35222D34212C321E
2E321D2E2F1D30301F313021312F23312E252D2A232B2A24282B262529252127211D231D
1D241C1C241A1F271C1F281A20291A2029181F28141E27121F28111E270E1C230A1D2409
1E220A1F230C1E210D1C1C0C
0E120A0D100A0C0F080A0D05070904050703040601070A020B0E030A0D02080B00080A00
080A000A0C010D0E030D0C030A08020604010402000805040D0A0A0C0A0D0D0C11131519
1B1F21222927252F282532262633232935212B37202C371F2F371D2F361C2F361E2F3521
32352437392B35372D33372E353930343930323A2D303B2B303B27313D25333E25363F25
373F25383F25393E25383B253B3D293A3C2C3A3C2E393C2E373C30363C30343A2E353C2E
353D2E353E2D353E2A353C26353B23383B233A3B253B3B273B392A3B392D393930373933
333732353B32353D3135402E37432B3943293A4327384025383E26383D283A3E2A3D402D
3E3F2F3E40313B4132373E31353E2F343D2C333D29313B252D37202D361C2C3319293016
282F162A31162A30152C33152D34192F351D313721323825323927323929343C2A333B27
313A242F38202E371E30371B30371A30361932381C35391E363821363824363728323227
2D2F252B3026282E26282F272930262B33262C34252D34222C311F2D32202E33212E3220
2E321E2F2F1C2F2F1E2F2F1F2F2C1F302E222E2D242C2C252B2D27272B2523282120251D
1F261C1D251A1E25191F27181E26171E26151F27162026152026131E24101B200C1C220B
1E220D1E210E1E210E1C1E0D
0D120D0C100C0A0C09080A060A0C08070A07050703050801070901070901060801070901
080A01090B0108090008080007060005040004020008060315150E1818151A1A1B1D1D21
1F202622262A242C2C262F2D26322B2732292933252A34222C35202D351F2D341E2F3620
323723353827383A2B37382D35372D34382E33382D343B2E313B2B303B28323D28343F26
363F25363F24373F24363D23393E253A3E283A3E2B3B3F2E383E2F373D2F373D30363C31
353D30343E3135402F333E29333C24353C22373C23383B22393B243A3B273A3B2A393B2E
373A2F35392F353B2E37402F37422E39452D3D482C3D47293C46293C432A3D412B3D412B
3D402C3E402E3E42303B40313B4232384130353F2E333C2B2F37252C331F2B311C282E19
292F1A2A311A2A301A2B321A2B311A2C311C2E331F313621343925353926353A27323825
313724313824323A24323D23323B2030391C31391C32381D34391E353920383A24363826
3334253033272D30272B2E252B2F252C31252E34262F35252C33232D33242C33232D3321
2D321F2D311E2E311D30311E302E1E2E2B1E302D202E2D212C2B1F2B2C1F2B2C1F272A1F
23261C20241B1F23191F24191D24191C24181F26191F25182025172024161E22121D2211
1F23111E22101D20101B1D10
0A0E080A0D09080B07080A05090B06070904050803070A05070904070803090A04070902
060900070900050800040600030500030400020200030300080904171A132E3429353B31
3135312C302E2A302F2B32312F38332C3630283129252E23252E1F252D1C262C1B282E1A
2A301B2C321D2F342131352733362A35382B33382C353B2E323A2B303929303A27343D27
333A25343C25343C24333B22343C23353C25363D28383F29363E29353C29363D2B363C2C
373D2E373F30363F30353E2D363E2B363E28363E27343B23353B22363B22373C23383D26
393D28393D29363C29353D2938422C3B452B3C452A3A432A3B432B3A422C39402B373D29
383E293A3F2A3B402B3B412D3B42303A412F3A4230363E2B3037242C33202B311E29301E
292F1C2A311D2A301B2B311C292F1B272D192A2F1A2C311C2E311E2F331E2E341F303620
333922343B25343C26363F28364028333E23323C2130371D2E341C30361C353A20363A22
3537223335243033252D2F232D2F232B2F222B30242D32252B3224293124283023293120
2A311F2B301E2D321D2F321D2F2E1B2D2B1B2B291A2C2A1A2E2D1A2B28162B291729291A
26281B24261C22241C21231C20241D1E221C1E231C1D231B1D23181B21161C21161D2215
1E23152023151F21151B1D13
060A01070A02080B030A0B040908020808020B0D050E110A10120B0F0F0A0F110A0D1007
0B0E03090B01060900040600040600030500020300020400010300070A06273021323C2B
333A2D373F33343B3131372E353D31353F33242A241D231C1A20161A1F131B21101E2311
2126122226132529142B301D2E3423323828353B2A39412D39412D353F2A363F28384028
373F27393F28393E29393F29383E29383E2A373E29383F2938402A383F2A383F2A373F29
383F2A3A402D393F2F383E2F393F303A402E3A412C363C26363C24363D23384124384123
384024383F25384027373F273841263942263B42283B422B3D432E3C42313A4030373C2C
363C2A363C2A373F2A39412B393F2A3A412B3B432D383F2A343A263037212C321F2A301F
2A301D2B321D2C321E2C321D2A301C282D1B2A2F1C2A2F1C2B301C2B311C2B321C2E351D
333A20343B22353B24363E27373E29363F29353F28333B2430371F30371F31392030371F
2F35203238223136232E33212E32212C311F2A2F1D2B2F1E2C32212E35252D33252C3224
2D32242B2F212C32202E34202E321F2C2F1D2B2B1B2929192A2C19282915262713242614
25271724261822241921231A21241D21251E22271E1F251C1D231A1B21181D22191B2117
1C21171E21181F21191D1E17
050A02060A01080B010A0B020A0A01090A020D100811150C151910151810151911161A10
13180B0C1006080B030508010507000507010405000204000305010306010B100614190C
1F24153B452F373F2B303625373F2D3741301D231A171C1510140F0E120A0F1308141709
191C0B1C1D0E202111292D1B2F3522343A28373F2C39422D38412C38412A3A432A3B4429
3C44283F442A41452C40452D3E432D3B412B3A402C3B412C3C422D3E432F3E442F3B432C
39412B39412D3B412F3D422F3C41303D422F3C422C3B4029393F283A41273C45293C4529
3A44283942283A43293B43283B44283B45283F472B41482E4248324147343F45343C4332
3A3F2F363C2A373E2A383F2A373F273A412939412B3A412E3A412E363D2A2F37252E3423
2C33222B331F2C331E3036203036202D331F2C311E2C311C2C321B2C321C2B311B2B321C
2C331E2D341E2F3720313923323A25343D27354028374028333C24323A22313823313723
3037233038233138233139242E36232D35212E35202D331E2D331F2F36253138262D3423
2C32212A30212C31212C32202C311E2C331E2D331F2B2F1E2A2F1C282D18272C17272B17
272B19262B1B25291A23271A22271D23281D22291D1F261A1E25191E25171D24161D2416
1F26182025192024191E2017
050805070A06080C040709020608010608010709040A0D080F130C12170F151A13171D14
151B110F140A0A0E04060900040801040601030501010501010401040902080D030A0E02
0A0E02161B0C1E2213202415333A273D48332C362721281D15181311130F100F0B10100A
12130C15160E1E2015272B1C303623343A28383F2C3A432F39422D38402B39412B3A422B
3C442A3F452C41472F3F46303C422C3C412D3C422F3D43303F45314047323E45303E4631
3D45313C45323D46313F45303F432F4044303D412E3C412E3B412E3C432F3B442D3C472E
3D472F3D462E3D462B3C46293E472A3E472A3F482D414830424734424836424937424938
3F45343C432F3A402D373E2A353D29373F2A39402B3B432F3E46323B4331363D2D31392A
2F372A2F37273039252F38253038222E371F2E351D2D331B2E351B2C321A2B31192C311B
2C311C2B301D2B301D2C34202F3823313C26313E27333F28333E28333D26333E25313B25
2F38222E36202F37213139223139232F36222E35222D33202C31202E33212F35222C3321
2C31212E33242C31222B2F1F2A2F1E29301E2B311F2B331E2B321C2A2F19292E18282D17
272C17262B18262A1B24281C23281D22281D21291D20291B20281A1F26171E26151E2516
1F2617202717212818202417
0B0E0E090C0B0A0D09070A040406010304000204000608030A0C070D110B10140E12170F
1317100E130A0A0E04070B00040700040501030401020401030503070905080B04060901
050701060701080B030B0E05151A0F232C1C212A1B1E25181D21141D20141A1C12171912
1718131617101B1D1522271D2B3025303629353D2D39413038402E373F2B373F2A39402B
39412B3A412D3C442E3E47303E47303D442E3E45304048333F4731404933404933414933
424B344048333F48323E462F3F452E4147303E432F3D43303E44323C43323D44303E4730
404A323F49313D482D3E492C3E4A2B3E482C3D462E3F472F414934414836454939444938
444A374148344048363D4535384030373E2D373F2C39402C3C432E3E452F3B422D393F2D
383F2E373E2D363D2B323A28303825303A242F38212F371E2F361D2D331C2D341C2E341D
2F331E2E321F2C311E2C321D2C34202F39242F3B252F3B26323F28313E28313D25323B24
2E39222E37202C351F2E36212E38233038243037242D33202C301E2E321F2F311F2F3120
2F32212D30202E32232D31232B30222A30242930222931212C32202C321E2B311C292F19
292F18282D17272C1B25291B252A1D24291C22271B22281B23291D23271A2025171E2416
1D24151D24141E25161D2316
13171C0F14180C1113080B0C0608070407040305020608030E12081014080D12060D1105
0F12090D10080B0E060A0E04080B02070902060702050501060604080905070802030400
030300050502060702080A04090B040D11080F140B10140B12150B12160A14180B1D2214
23281A22281921271A232A1E272F242C3428303A2A343D2C353E2B353F2A37402A363F29
363D2A373F2B3A432E3C462F3C48303D4830404A32414A32404930414A32434B34454C35
444C35414833404833414931414A32424A324147304046303E45313D45313E46303F4931
404A31424D34414C333E49303F4B313F4B31414A32414A333F4A33414B33424933444A34
4349324348314147324146343F44333D43313A422D39402A3D42293D42293E432A3F442E
4247323F44313B3F2F363C2C323A29343D29343D27333A233038202F361F30371F30361F
3035202E33202E34202C321F2D33222C33232C35232D36232C37232D38232E3921313C23
333E23333C23323A223038222F37223038243238252F34222B301E2D311F2D311F2E3120
2D30202B2E1E2B2D1F2D30202C30212C31242B2E232C30242A3122282F1E29301D282E1B
282D1A292E1C292E1D272B1C25291B24271B23261B21251A2125192125191E23171D2216
1E24161C23151C22151A2114
192026192026181D251418201013190C1013090C0E0C0F0E1014100D0F090A0C040C0F05
0E11070F12081012090E0F060C0D040B0A030A09030A09050A08060A0909050505030302
0201010202010708050B0E080E11090C0F07090C050A0D060B0F06080B03090D040F1409
1A2112232C1A2A34202E3724303B28323D2C313B2B303927313A27323C28313A26323925
333B27343D2936402B37422B37442B39462D3D49303F4830424B33444D36444C37454C39
444B37454C37444E37454E36454F36464D35444C35444B364149343F48323D4730404B30
414B31424D34414C343D4A323D4B323D4A303E492F3F4B303E4C2F3E4A2D3F492D414830
40462E4348304348324346324246324247333F462F3E462D3E45293B40243D422641462B
43482F4347314044313E44313C42303B422E384029353D25343B24333923303521313622
2F33202F34202E341F2C321E2B30202C32222F35252E36242D37242E38252E39232F3B21
323E22353F22363E23343B223037212E34212F35243036252E33212C311F2C311D2C311D
2C311E2D311F2C2D1E2C2E1F2D30212D2F232C2F232D33232B3222282F2029301E2A2F1C
292D1C2A2D1D282B1C26291C24281A24271923271C1F241A1E24191E241A1E241B1C2219
1C2318191F131A20131A2013
232A2F232A2E21282B1F25281D2326181E2015191B1418181113130B0C0C0A0A090C0F09
0E13090F13090F12090D0F06090C040A0C040B0B040C0D060F0E0B0F0E0F0C0D0D070809
0404050304040B0E0B10141010140E0C100A0B0E07090C060B0E07070A04060902080B03
0A0D0413180C2229182E3622343D2739422D38402E363E2D353D2B333B2A333A2A2F3627
2D34272B32272B35272E3928313D2A36422C3A462F3D4730414A33434A36434A38434B3A
444C3A454F3A455038465138455037454E36444E36454F37444D35434B33414931404A30
414A30434C34424B35404A35414B333E4A2F3D4B2D3F4D2E404D2F404D2F3F4A2E414A30
4147304347334347344144334045334046333E452F40482E3F482C3E452841462942472A
42462B41452D4145303F43324145334147323D452D3A422A384027373D263439242F3521
2C311F2D32202F34202D311D2C311E2C311F2E35232F37252E37262E39272E39272E3924
2E3A22313C22343E23353D233239232F35222D33212F35242F34232E34222E34212D3320
2C311F2B301F2A2D202A2C1F2A2D202C2E222C31212B31202B3120292E1D292F1C2B311B
2B301B292C1A272A1B262A1D23261A21241820251A1F251A1F261C1F261C1E251A1C2317
1B22141A21121B20111A1E0E
23292E262C30242B2C222928232927242A27212726202626191D1F1316180F11120E110F
10140E11160B1014080D11050A0E02090C030C0E050E11060E11090E100C0D0F0D0D0F0E
0909090709070E120D14171211160F0C100B080B04050701060801070902070902070A02
0608010B0F0613170C1C1F13212417272A1E343B2B3C44333D47343B4433374031323B2E
2B3329252C2321281E1D231B232B1F2D3927343F2B3A452E404A32434D35434C36414936
414A37404936414A36434C37454F38454F3947523C48533A465036444C33444C33444C32
434A30454D34444D35444D37444E37424C35414C32414C30424C2F424D2F41492F434830
434733434736444838434738434838424836414934424C32434D32434C30444C2E444B2C
45492D41452C3D422D3D42323D44343D45313C452E3C452D3C442B384028363D26323823
3035232E32212D31202E32202F33212F33222F35243139272E38262C37252F3A272F3A27
2F39242D3822303B22343D24333B243338243338262F35252E3424303625313726303624
2D33212B30202A2F22282D21282D212A30232C32222C32202B301F292E1C2A311B2B331B
2B321A292D18292A1A27291D24261B24261C23261C1F231A20261C21261C1E25191D2417
1E23141D22111D21101B1E0D
282D30292E32262B2E242929232827262B29262B2A242A2C242A2C2026281C2122171C1B
161B1512170D0D11060B0E020B0F030B0E040C10050F12070F11080C0D08090B070A0B0A
0B0C0A0D0F0A11140D14180F12170C10140A0B1004070A00060900070901080903080B04
080B050809060B0D0A10131014161315181521251E343D2F3C4634404B37414C39384231
2C3426262D201E241A171B151519131D231A262D21303A2A38442F3F4A33404B333F4832
3F48333F4733404833414835434A38454C3A454E3A444F38444F36424E34434E34434E32
444D30444D30464E33464D34444C34414A34414B34424C33414B31404A31414B32444B34
454B36444937444836454938464B3A464B3A454C38434B36424B35434C34444E32434C2F
42492E41452C3C412A3B3F2C393F2E3A41303A41303C44313B432F38402D39412E38402C
353B293136242E33212F35212F36202F35212E34223037242F37252E3824303B252F3C23
303C232D381F2D371F2F3921323B23333A253238253035242D33212D33212F3622313724
3137243035232D34212D32212A30202A30212B31212C33202A2F1C292E1B2A301D2B311E
2A2E1C2A2D1C2B2E1E292C1F26281E24271E21241B20231A2024191F22181F22171C2113
1E22141F23131F22131D2011
272C2A2A2E2C2A2D2D292B2B282A28272A27282C29282C2E262A30272B31272C2F262B2B
212723181C1710140E0E100A0F100A0F0F0B0D0C0A0E0D0C0E0D0C070607030304040505
040504090C0612170C181D0F171D0E11160A0C1003090C01090C02080A020A0C050D0F08
0B0D080A0B070909080C0B0B1110111413121616131C1D18272A2133382B3D4434363D2F
272D2120261916190F171A11171A13181E151F251B2730232E392635412B38452C3A462D
3E482F3F4932404933404835404736414937414B37404D36414F36435036444F35444F31
445030444F2F454F30444D31444D32414A32404A323F4A323F4B323F4B31404A32424B34
444C36454B36454A37454A39464A3A474B3B474C3B424935424A34424B32424C30414B2E
41492D42492E3F442D3C402C393D2D383D2F3A40313B42313A423239423039412E37402B
374129343C25323921333A212F361F2D341F2D34212D36242F37242E38242F3B232E3A1F
2F3B1F2F3B1F2E391F2F3A20313B21333C243138233137242E34222E35212E351F313721
353A24353B243238242F35212B311F282F1D282E1C292F1C2A301A2A2F1B292E1C292C1E
2B2E1F2A2D1F2A2E20272A1F25271D23251C22251C21231A2022171F22161F22151E2113
1D21121F23131F23151C2114
202723252C242A2F262D30282E2F292C2D292D2F2C2C2E2E2A2B302C2E352F3238313639
2B31301C2120181A19151415131013110F130D0B110B091007060E05040B030307040505
0305030507011218081A200F171C0C1215080C0F05090B020A0C040A0D070F110B12140C
10110C0E0F0B0C0C0A0D0C0C1311111715141614131413121818141B1B1722241D24271F
1D221916191210110A12140C1B1F1421281B242B1E232B1D242D1D26311E2A3621303B26
37432B3D4830404C34414B36414B36424D37424E36435136435235475437475237465135
465135465133465034444E33424D31434D33434F35434F35424E34414D34414B33414B33
434D36444D37474D38484E38494E394A4E3A4A503B4B523C494F3A474E37444C33434C32
434B33444C34424A334248324146333F44313E45323F49333F49333D46313C453039442D
39472D38452B374227364024323C203039203039212F3722313A25323B26323C26323C23
313C23313C24313A23343C25353E26363E28353C27353C2831382530362330372030371F
353A22363C23353C24333B232F37202C341E2A321C29321C2A311C2B311D2A2F1C292E1C
2C311F2B30202C3221292E1F25291B25291C262A1F25281D24281C23271C21261A212619
2027182027171F2617202517
171E1E1A211C1E241B22251C262821292B252D312B2E312E2E31312E32342E3437323A3B
313938272D2D2025251F212419192114141E11111C0F101B0A0A1506051003030B010205
0103030305010D1106161C0E181D0F16170D11120A0E0E080D0D090E0F0C131412171915
171A171216140E10100E1011121313151516131113110F1112121111110F131410171912
15190F11130A0F10070B0B0216190C252B1A262C1E1D2319191F16161C13181E131C2416
242D1C2C362234402A39442D3C482F3E4A2F414F31435233445033465136475138464F37
485238475237455135455136445035424E34434E35444E36434D35434D34434C34424B35
424B36444B37464C38474B38484C39494D384B4E3950543F5155404D513C4A4F3A484E39
464C38444B37444B37434B34434B334148304048304149314149324147324047313D462F
3C47303B462F38442B364227344022313D2030391F30391F303A21323C23343F25343D26
333C26313C26323B25343B27353A26363D29373F2A363E2A343E2A333D27333C232E351E
2C321C30361D30371E30381F30381E2D351C2B3219293018282D17272C19282C1B292D1D
2B301F2A2F20292F202A2F20272D1D232A1A24291B23281A21261822261921261A20281B
1F281A21291B202719202517
1B20221A1E1E171C18171B141A1D1720221C282B232C2F282F332E3036332E35342D3436
3038382E3735282F2E272D2E252A2F24292F24263122242F1C1E281415200E0E18080911
04060B0305060B0F0A14180E161A1012150D12130C12110D12110E1413111A1B171D211C
2025221F25231C221F1A1F1E1A1F1E15181A0F11140D0D110D0D0E0C0E0C0D0F0B10130D
10140C0E11080C0F050A0C021A201029321E29331F1F2719191F1414180F12160C12160C
15190F181D101E2415242C1A2C36203440253C482B414D30455033465135475037475238
485336475235455334465437475539465238455138454F38444E37454E37464D36484F37
4A5038484E3A484E3A464C38474C39484D3A4A4F3B4E523C4E523A4E513A4C513A4B513B
4A4F39454E38454F38434D34434D33414B304047304147304147324248344248353F4634
3E46343B443138412C374229353F23313C1D313A1D313A1F313B20323D23364025343E24
323C24313C24323B25343B27353A29353B2B363E2C343B29353C28353E28353D27313924
2D351F2B341C2B351C2A331B2C351C2D361C2B321A292F182A2E192B311E2A2E1E292E1F
292F20272D1F292F1F29301F272F1E252D1A232B182029151F27142128162329181F2717
1D24161F25191F25181E2415
1F22221D2020181C1B161A17161A14191D151C1E151F2119232520282A272B2F2C2C3432
313A38313A362B34302B32302C33332E33343033373033392E31392B2E37232730181C25
10131B0B0D120B0E10101410151A1115191113150E12130D13130D1617101A1B151A1C18
1D211E202724252C27252C27272E282026221519181011130F0E100D0C0E0E0D0E101110
0F13100F120F0D100C0C100911170B181F0F1A22101B221119200F161B0E13160A12150A
13150B12140A12150B13170C1B22112229142C331B3942273F482C434D31465033485134
48523347533647523747533849553A49543A48543B47533B465239454F37444D35485038
49513A48503B474E3B474D38474D38484E39494F394C523A4C50384B50384C523B4C533C
4B523B465038444F36434E34434E34465136444F36434C34434B34434B35434934414735
4048343C44313B422E3B442C384227353F22343D20353E20343E21343D21353D22363E23
363E24353E26343B26323825353C28343A27343B28343C28353C28353C27343B26323B25
313B242F3A222E3A202D381F2C351E2E361E2D331F2C321F292E1D2B30202B3022292F21
282F20282F1E272D1D262D1B272F1A232C17232C16232D16232C16232B16222A16202815
1F2715212917232A181F2516
181D1C1E21201C1C1E17181A171816181A16181914191A151919161918171B1C1A202521
28302A2D362F2E372E2F38312D35312D33312F333430333831333C31353F2F353E2B3239
232A301D2227171D1F171D19181E17151A1413171012160E15180F171B1216191011140E
121510171C1721261F292F252E342A2E352B242A241C1F1C1819191311140E0E12100F13
0F1113101313111413111712121910161D0F171F0C171E0B171E0B151A09131708111506
1115061014050F140510140615190A1518081A1D0A292E17373C2240482B465032495235
49533647533847533746533848553A49553A49553C47533C47533C455139444E38454E3A
47513D49533D47523A454E36464E35474E35484E36484D364A4E37494E374A4F3B484F3C
48513D46503A444E36434E35434E35434D35434D34434D34444E36464E38434A35434835
444A364047333B43303A422E39422C353F28354026374224364022363F23373F23394125
384024373E26363C263339253138252F3523303625333B28343B27333A26303824313923
323A23333B23323A22333B212F361E2D341B2E331E2E33222D32212C31222C31242C3224
2C32222B311F272C1B252B18272E19252D18252E19242D19242C18252C19232B18212916
2028151E26121E26141F2415
1B201F292D282526251F1D201A191D19181C181619171618151314131211111311131712
181E171E251B272F212E362830372C31362E2F332F2F323231333834363E34393F32383F
2F373C2B3436252F2F2028271B2220161B1A161A18171A16161A15161A141418120E110C
0D0F0B10130E1B1F1722261C262A1E2B2E222D32282D312A292E292427261D1F2317191F
12151A1114181519181A201A1A21181A2115171F0F181F0D171D0C1319081217080F1406
0E13050E110310150513170715170912130712120519180722210E2C2D193B412B444D34
47513749553B4A563A49563849573747543647533848533949553B47513A46503B454E3C
47513C47523C48533A455034444E31454E32464D33464C33474B33464B34474C38474E3B
444C3A444D38444E36444F35434D33414A32424B33424B32424933444B34444A33444934
454B37434A373F47373C433539413236402E343F2B344029333E25333E22363F22374024
353E23343B23353B253338253137252E34252D32242D33242E3623303824313823303822
2F382130372030371F2F361E2D341C2C321A2D311D2C301F2B2F202B2F222C30232C3121
2C31202C3120292F1F262B1B252B1A242B18222A17232A17262B1A262D1B262E1C242B1A
2127171E25151E24131D2211
53635749554B353C363136322C2E2E28292B2221241E1C1F1B1A1A18191414171012160F
1318101519101C1F132224172A2B2230332C31342E303331333638373A3E373B41373D44
333B41313A3E2E3739293132232A2B2127282125271F21221C1F1E18191B1314170E0E12
0B0B0E1012121C201B1C201A181B13181A121F221A252A22292E292B322E2A312E212726
191F1E181E1C1B211C1B221A1C241A1A2016171C10191E0F191E0F16180B121409101208
1011090E0F0810110813140A15150C15160C1414091715061B19081C1B0A292C19393F28
4148304850344C54384D56394B573A4B573B49553B49543B48543A49553B49543A47523A
485138485038485037464E34454D34464F35454E35464E35454C33464C34464C34474D35
444A34434934444C34434B35444B35444C35444B34444A33444A35444B35464E34454C34
454B354449364248373F45383C4235394132363E2E323B2A303B26313D24323E23333D23
323C23313A24333B253339242E35212E34202F36222D33202D33202F3522313824313823
3038243038242F37232D35202B331E2B341E2C341E2B321E2A2F1D2B2E1E2C2E202C2F20
2A2F1E2A2F1F2A3020282F20252C1D222A1A212918222917252B1A242A1B222A1B232A1B
22281A2228192128171E2310
71867D72867C65776F5E6D6557625D4C5452454C4A3A413F282C2923282022271D22261D
24281E24261C2222191F1E182320202B2A2B2A2A2B2A2A2C31323335393A373B41394044
384145343D422F383B2C35382B32342C34332F38342D33322A2E3024252C1A192313101B
100D1715131B1B1D20161A1C1113130D0E0C0E110E1316131A1E1A212723252C27232A24
1F2720232C23242E24202A201E261B192014171D10191E101A1E10191A0C14150913130A
14140B1010080F0F08100F0911110A13130C14140D212315282C1A292F1B2C341E343C23
3A412541472A464C314B52384D543B4D563F4B554149554049563E48543B4953384B5538
4D55394C53394D52394A4E38494D38484E39464E38485037484F35484F34464E32444B30
444A31454A32484E35474D37484E3A474D3A464B38454A38434A38414936424C33434C32
444C32444A324348334247354045353F44343C4131373C2D323A2A323D28313D24313C22
313C21323B21343D22343B22323920313820333A22333923323722303622303522303623
3037252F38272E38262E38242D37242D37232C37222B35212A321E2C311F2B2D1D2C2F20
2D31212C30232C30242B3024282F23232B20232B1E232A1B242B1B252C1D22281B1F2719
21271A2128182028161E2612
7E928983968E85989283959081928F7A898877878470807E596768515D5D55615D5A675E
5A665A484F4834373636383B33343B2C2C332221271E1C2122202328282A303234343839
363D3D363F4031393C2B33382D3538313A3B353E3E363F3F384041373A3F2F313A252633
20202D20212B1E202714151C1012150E0E0F0D0D0C0F0F0E11110F131411171B171A1F1B
242C25283229293429263127212A1F1C23171A21131A20121A1F12191C0F16160C16160C
15170C13130912120912120B13130C100F0B100F0E30362A4A58434D5E464B5C4246543A
414C313E472C3F472D434A31464D3647503A4A533E4A553E4A563D4A543B4A53394B5339
4D543A50573E4F563D4E533B4C503A4A50394B513A4A5139495036495034484E34474D34
474C34484C33494D35484D37484D39494E3B464C38444A35444C36444D36434D34434D33
444E34444D34454C34464C34454A354549344145323D42303A402F363F2B343E28333C24
333C23343C23343C24353D25353D25333C24333B25333925333A263139252E36232D3522
2C35232C36232D38242E37242D37252D38262E38272D37272D36272B32242A2E212A2F22
2C30232C2F232A2E23282E23262C23252B22252B21242A1E242B1D242A1C22271A212519
2026182128182027171F2415
82968C8698918A9B988A9A9C8A9A9E88979D86979A8697988495987F90947F9292829793
82978E798B826C7B746F7E775C67652C2E381B19241A191F1513191614191D1D1E262826
2F3330343938353E3C323B3C3943423F4A493F4A493C46483B44483A4147383F46353C45
3239432E353F242934191C2713141E1010161111131111110F0E0D0E0D0C0F0F0C11140F
232A22262E26293127293227242C232129201E261B1C22191B20181A1F17181C14171B12
15180F14170C15160C18190F1716101616101F20182A2B23464E3E515F4A53654C53644A
50614549583E455337434E33434E32444F344750374C543B4B533C4B533B4D563B4D573C
4B553C4C573E4E573D4D563B4D56394D54384D53384C523A4C513A4B503B4B503C4A503C
484E3A474D38474D35474D35464C35474D37474D35474D34474D34454D36444D37434D36
454F37454E37444B36434B35434A334349314148313F47313F46303C432D3A412C353D28
333A27323A26333C29343D2A323C2A313C29303B27303B26313B27313C27303C262F3A25
2F39252F38242F39242E36232D3625323A2A313A2C30382E30392D2D35282C32252A3023
2A30232A3022293022293022282E20292E212A2E21292C21262A1E24291A212417202418
20241923261A24271B202319
80948E869A948A9B9A8B9C9E8C9DA18C9CA38A9A9F8A9A9C8A9B9C8B9D9D8A9F9E8BA19D
8AA2998BA3968AA1928CA1927E90843E43481A19241C1B2117151A141115131113171616
1D1F1D2225222C332E323B363B453F404C443F4A443E47463D45473B4348384048384047
3A434C3A434B3740483036402327311D202815171D121217100F130F0D100F0E0E141614
252B24222922202720252B22272E22242B2022281E1F251D1E241E1F241F1F251E1D231B
1B20171A1F15191E131A1D1319191118181223231B23231A3F433456624C505F493E4B3A
43523E495A414D5F414A5C3B47573547543345503147503449503849503848513849553A
48563A4A573B4D5A3D4B573B4A553A4C553A4C543A4C523B4B503B4B503E4B513F4A503E
484F3F474F3E464F3A464F37464E36474F36464F34474D32474C34464B35464B38444B38
444C3A434B39434C3A424B37414933424830414930424B304349304247303F45303C4330
393F2F343B2B313A2A2F392A2E392A2F3A292F3B26303C24303C23323D23323C24323B25
3239243137243037233036232F36242D33222C342530382A2E38292E37282D36242B3221
282F1E272E1E29311F29321F2B321F2A2F1D2D2F1F2C2F21282D1F25291C212417202217
20221A23261D22251D20211C
7F958D879D968A9F9C8B9F9F8DA0A28D9FA28C9F9F8DA09D8C9E9B8C9F9C8DA19C8CA29B
8CA49A8DA59890A79891A8958FA5926C7C712E3235222426202020181718151314141212
1413111818151C1E1A1E231E282F28303830373D363B413C3D43423E45473E46493F474A
40474C3F464C3E464D3F484E3C454A373F422C303424252A1F1F251A182014121A1E1E21
2327261A1E1E171B181B211A22291D22281C2025191F251B21271E21281E20271C21281B
20281B20281A1F25171C1F1419191216151318181519191645503E5E6F5544513F2D352A
2C34282B34253E4B324C5F3D50623E51623F4C5B3B47533847503848513B47513D454F3A
43503A44523A4A573D4B573E4A563E4B553F4B533B4A513A474F3948503B49523D49513D
48513E474F3E454E3D46503C46503A475138464F35464E34474F35464D35464D35464D37
454D39444B39454D3A434B39414935414A33414931434B31434A3142482F414730414832
3E453139402E343D2B30392930392A2F3827303A25303B22303A2030391F313821303822
2F36222F37222E36213038232F37232D35222B35212E36232E36242F37262F37252D3320
2D32202A301D272E1C252E1C252E1D282E1D2A2F1E2B301F292E1F252A1D2025191E2317
20241722261B20241B1F221C
849B9189A0988AA29C8BA29E8BA09E8BA09E8BA09C8A9F9A8B9F998DA09A8DA1998FA39A
90A59B90A69B92A89B92A79994A999889C8C5D6B63383F3D3034322021231C1B1E191719
161515171614181913161712191A151D1F1925272134362F3B3E383F443F424844434A49
454E4E444E50414B4E3F4A4C3F4A4A4047494046473D4144393C40313139282731292A30
24252A14141B101117121515141814151915191E171C21191E241A1E25191D2417202617
212918232A192226181F22171E1E181C1C1A1E201F1D2120242A262E372D252C24262A22
23271F1C1F171B20152C362446563B536749576A4C54654A4E5C4349553F424D3B3C4636
3A46363D4938424E3B46533F4855414A574249554048553C49553A4C563A4A5437495237
4A5238484F3B464E3C47503D47513A47533A454F35444F33464F34464E33454E34454C34
474D35464C36454B37454C38444C37444D36424B34414A33414B32424A3040482E40482F
3F47303E46313D45313A412F353C2D33392A323927303726313926333B25323A24303824
2B34212B34212B33202E36212D35212E35222D34212D34212E35222F35232F3623303722
2F36212D341F2B321F29301F272F20283020293020293120262E1D252C1C21281A1F2518
2127172126162125171F2318
81988F879F9588A09888A099879E9889A098889E97889C948A9F968EA29990A39B91A59D
92A69D92A59B93A49B95A59C96A79D93A59B899B91798A8057625F383C402E303524242A
2221231D1C1A1B1A161818151615121615121513111D1A1525231D2F302A393D36404640
424B47454F4C404B4B3D48493E494A40494B43494C44494C43484C43464B41434B3C3F48
2C2E391E1E2A1416200F10180E0E150E0F131012121519151A1F191E221B1D23191E2418
212819242A1B24281B24261D262822282929282A2C212527191C2017191C17191C1D1F1D
1E201B1B1C19181B17171B1721281E323D2D3E4C374D5E4457694D52624A3641312A3326
262F232831242C35283743313E4B3545523B47543D48543D49553B4B593A4A5637495435
495335475037485139485039454F36465038465037465035454F34444E33454F34454E33
464C31444830444A32474C36464C36474E35464E35454D35444B34434B333F48303E462F
3D452F3F47314048323E46303A422E39402E363C2A343929333828343A29333A29323B29
2D37262A33232B32202B321E2C321D2D331E2C331E2B331E2D341F3038213037202F3720
2E35202D35222B3423282F22252C20232C1F273020262F1E232B1A242C1B232B1A1D2415
1D2415202514212514202314
839890869D95879E97869F99869D97879D95899E968A9E978CA0998DA19C8DA19C8FA39B
91A49C93A59C94A49D97A79F96A69F95A59D94A59B93A59A86988E6F7D7750595835393C
313432292B2521221D1C1D19191A1617151416121116110F1711101B1714282420353630
383E393E4642414C47424D4A414C4B424D4C444C4C444B4A44494945494B47484F454651
41434E383B472B2F39181A2614141F1111190F10151112151619191B1F1D1D221E1E241D
21271E23291F24281E24251E2F322B363A35363A3A292C301F1F2518181F15151A17181B
1A1C1B191D19191F191A201A161C161920161E2718242F1C3E4D3448593E2E3926222A1B
1C2316181F13161C0F242C1C323B273E473045503848523C48523D49553C4A563B4A5639
4954384753364953364A5136474E34464D35474F37454E37434C36424C36434D37434C35
424B3140482E41482E42482F43482E454A31464B33464B35464A384449384147363E4534
3C44333C44303C452E3D452E3D452E3D452E3D422C3B3E2B383A2A36382A34382C32382B
2D35272C34242B32212A321E2A331C2C351D2A341A2831182831182B341B2B341B2D351F
2D34212C33242B3328262D25222921222920232A20232B20242D1E242D1C232B18202815
2129142328122024101E210E
81938B879C938AA09989A09B889E9B869B9A869C9A899E9D8CA09E8EA09F8FA2A08FA29E
91A39E94A59F95A49E96A59E96A69F96A69F97A89E95A79E96AA9F92A69B82938868766E
58635A4A54482C322B262C251D201C1919181715151813131712111812121A1514201D1A
2626232C2F2D343A363A413D40494447504B48514C48504B464C4A46494A44454C44454D
43464F444A544248513A4046282C3422252B1B1E2413141B12141C1B1F24202628202726
222926222A24212823212520292C26383D363E443E3B413D3034332A2D2D1F20231C1D20
1B1E20191C1C171B191518161015101419111A2114181F0F1D2415262F1D232B1B192013
181E11192013191F131D2417293120353F283C472E404A32424C354852394A563A4B5639
4B56394953374C55374B5336494F35484F36484F36464E37454F38454F39465039464F39
474E37444C343E452F3C422B3D422A3E432B41462F424731444834454B37444A37404737
3F46373D45353B43303B432F3B42303B422F3E452F3C412C3A3E2C3A3E2E383B2E33392D
32382C33392B3037262D35222E35212F38222F371F2D361F2B331E2B321F2A311E2A311F
2B32212B34242B3426293226272F24252D22242C20232B1D262E1D252E1C252E19242D17
272E15262C1323281021250F
83958B8B9F968CA39D889F9C859D9D869D9F869C9E879D9F8A9F9F8CA0A08FA2A191A4A3
92A5A394A6A295A8A095A89F96A79E98A8A198A9A298AAA397ABA295AAA095AA9F91A69A
899D907A8D7E5F6F6249524A3437352C2D2E2525271E1B1D1D1A1B1F1E1E1F1E1D1F1E1C
1D1D1A1E1E1C212220282A27363C3640473F474E464C534D4D53514A4E51474A51444852
404650454E55444E53455051434D4B3F4745393F412C2F3720212D272B35262C341E252A
1C23241B24211C231F1C221C1B1D1A2123202E312E373D383B433C3B433C363D372E3431
242A291D2122171C1C1215150E110F111510161B13171D121A1F1421281B252C1E21281B
1C24161C23171C2317252D1F313B2937422C3B462E3E482D40492C454D31484F32484F32
4A51344C52374C53394B52384951384852384852374954374853374750374A513A4B513C
4C503C4A4E3B464B394348374147333F46304047303E472F3D462F3F48303F48313F4731
3F47333F46333B42313C44333E46353942303A432F39422F37402E39412F394030373F2E
37402E39412D373F2A343C27363D29353C293339263239273038282D3528293225283124
2831242831222832222A34232933232932212A332029301E292E1C292F1C282E1B282D19
282D17272C16262A16252816
879C928DA39B8CA4A08CA3A38AA2A68AA1A5899FA2879D9F899E9F8BA1A18FA3A291A4A2
92A5A292A6A194A7A094A79E97A99F99AAA29AAAA599ACA798ACA697ABA597ACA497ADA5
97ADA496ACA093A8997A8A806C797067746B454B4D32343C373B3F3D41433133362C2E2F
292B2A2729252628222729232B2E2730322D383A3441433D4A4C484D4F4F4E52554B5356
454E52424C4E414C4C434E4B4954504A53524A5154474E543E444C3A4149272D381C222C
141B21131A1C141A181317151110121311141A17192D2C293B3F393C423B3E453D3C453D
363E392D3434252C2D1B21211115140F13101013101216101E251A252C1F293021272E1F
232C1B232B1B20271722281925291A2A2F1D2D321F343923383E253E442A454A2F474C32
474D32494E334A50364A5138495138475037475037485337485237475036484F394A503D
4C52404B513E484E3C444B38424935414A33414B333F4A333D48333D48313C462F3C462E
3D462F3D452F39422E39422E3B433038412F36402D343E2C353F2D36402D353F2C333E2B
353F2C363F2B353F2A343D2A353E2B37402D373F2C363C2C333B2D30392C2F392C2D362A
2A3327283123252E1F262F1E28311E2A341F2A341E29321C293019292E19262B19262B19
262B1824281626281826291A
879E968CA39C8BA29F8CA3A28BA1A48AA0A4899EA4899EA38A9FA18CA1A28DA3A28FA4A2
90A6A192A8A094A9A092A69F95A8A298AAA499AAA698ACA998ACA999ADAA98ACAA98ACA9
9AAEAA9AAFA99AAFA59AAEA28A9B9175827C656F6E596064727C7778847C666E6C606A66
576259414840363A3234352E31302B302D2C34312F3533313A39383F3F3F474A4A4C5352
4C57544A565049554D49544D4C56524D55564C52584C515B4C545D49545B3F4A52354048
242E3520282B171B1E141418120F151711151A141535332B3A393233322F313030323432
393E3A3D45403B4640323E3818211D1117130F130F0E100B1C2317212719232919272D19
282F1B28301D2A301C272D1A2226162123151D1F111E2012252718363B27495237495237
4A54394A5337495136464D35464C35464D36464D37465038444E3745503747513B47513D
48533D48523C465039444E37434D35424C34414C34424E35404C343F4B323D4A303C482F
3B462D3D462D3D452E3B432D3A432F3A423038413037402E38422F38432F36422D34402A
333F29343F29343E28333D29353F2A363F29373F2A363D2B353B2B333A2B323B2C2F382A
2D36292C35262832222831202A34202A342029321E2A311D2A301C2B311C292E1A262C17
242B15252A16252A17262B1A
849A9389A0998BA19D899E9E879C9F879DA0899FA2899FA2899FA08BA1A08DA4A48FA6A6
91A9A692AAA594ABA395A9A497AAA896A9A896AAA898AAA999ABA999ACA99AADAB9CAFAC
9EB0AB9FB1AA9EB0A79FB2A6899A90626C6A626A6A737D7992A09596A59998A89C9AAA9D
95A79773807758615C535B554D524C52564D45443E3937343534323634343C3A3B424344
454A4948504B4D574C515C4F525D535058554C53564A50584F555E5058614C56604A555E
4450553D484B323A3C292C302220241E181C2520204140392F2A2A252124211C211D191E
2323242D312F343E373844392B382C161F1713190F0D120810150B13180C14180B181D0D
1E24142128182329191F26171C2116262B1F252A1E21251B1F21182F34265563465B684B
5B684B576349515A4449513E464C3A434A37434A364047353F4734404936424B38454F3B
46513B48523B46503B444E38424C35404C343F4C33414F34404F33414D31404C313F4A30
3F492E3F472F4047313D43303C42333A423438413238423039443136422D36412C36422B
364229374127373F27353D27343B26323925343B27343B28333B29323C29323C282F3826
2D36252C352529332229322027301E28301E2A301E2A2D1D2A2D1B2A2E1C282C1B252A17
222616252919252A19252A1A
8597948A9E9D8DA0A38B9EA4899CA3899DA28A9FA18BA0A08CA09F8EA1A18FA2A68FA3A8
91A6AA91A8A991A7A694A8A798ACAB97ABAC97ABAB99ABAB9CADAB9CACAA9EAEADA0B0AF
A0B1AEA0B0ACA0B1ABA1B3AC95A59F747F7F6E7777838F8A9DACA19EACA2A3B0A7A6B4AA
A7B5AAA1ADA6949F9A87908D828C868D9B8A646C5F4B504645484040403B3F3C3A3D3A3A
3C3A3C3E3E3D4347414A50474F584D505A514F58534E555653575C53575D4E525B4D535D
4C565D4C585C4B58584652503D434231313434323340403B272326201D221B181F151219
1312161516181A1E1C20261F222A20192319151C11161D0F141A0D13180C13180C14170B
15180D171B10181C1115190F10130D161B141E231A22271C23271C2B31233E4634555F48
5C68506270586070585865514D5544414636363A2C333628353829383B2C3C40303F4533
434B37464E3A444E3C424E3D3F4B383F4D363F4E333F4E30404E2F414D2E404C2E41492E
424A2F4147314045333D44343C43353B443737423435402F35432D35422B35422A364228
384329394229373E28373C2A3439293037272F37263038272E39282D38262E3A252F3A23
2E38212E371F2B341D2B331C2A311B2A301C2B2F1D2B2C1C2D2E1D2D2D1D2B2B1E28291B
27291B272A1D262B1D24281D
8697988B9CA08C9EA78B9DA88A9CA78B9DA68C9EA68EA0A48EA1A38FA1A490A2A690A3A7
8FA4A790A6A78FA6A792A6A796AAAC95ABAE96AAAC98ACAB9BAEAB9BADAA9DACAB9FAEAE
A0B0AFA2B2B0A2B3ADA4B4ADA1B1AB9AA9A495A29D97A59DA1B1A6A3B1A9A7B4ADA8B5AF
A9B4AFABB5B0A9B2AEA9B3ADA7B1A9A5B3A595A49186927D686F616166595E605654554D
4C4D4742423C3E40373E3F3742453C474C434C514B4F5552535959555A5C52595C50575B
4C55584A56574B59594F5C59535E595157544D505145474925222E201F2C1A1A2615131E
12111A1012170F13130F15100F160F111910121A101720101C24121B2211191D0F181B0E
171A0E181B0F15150B1111080E0D070F0E0A13130F1616101617121D1F19292C25373D32
48524452604F596A5660735B5D6E554B5641373A2A28271B26231929251C2D2B21323026
383A2C3F4533414A37414C393D4A353C4A313D4C2D404E2B404D2B404B2A3E48273E4527
3F452B4045303D43323B433339403337403336403235403034402B344128344025384226
394127394028393D28383A28373B2C343A2D32392C2F382C2C362A2933262A35242C3722
2C38202E391E2C381C2C371C2C361B2B331B2D321C2D301E2E2F1F2D2E1E2D2C202A2A20
292B22282B2324282021241D
839797869A9E8A9EA58C9EA98B9CA88A9BA58B9BA38C9DA38E9FA490A1A68EA0A58FA3A5
91A4A691A5A790A5A791A5A697ABAB99ADAE9AADAD99ACAD99ADAD9AACAB9CADAC9EAEAD
9FAFAEA1B1AFA0B1ADA2B3ACA4B4ACA3B2AAA2B0A8A0AFA7A3B2A9A5B2ABA7B4AEA9B5B0
ACB6B2AEB9B5ADB7B3ADB8B2ABB6AEA9B6AAABB9A7A8B6A19FAA979AA593939D8C899283
777F6F5E64544A4F3E3F4234393B303738303738323B3D3A4649484E5453525A5A525C5B
505B5A4C58574A56554D5858545E5B59605D5A5F5E585C60484C543C414C292D3A1E222D
181B2613171E1015180B1210090E0A0E140B1820111E2713232D17252E18232A15202513
1D21111A1E0D161808121105110E05120F0916130D1916111714131512151613171C1A1B
262927353D3647544555664E46563F46553B4551373B402D3D403037352D2F2B292E2A26
313028363A2E393F323C45333B45303B462C3A44283C47273C46283A42273A40263A4027
393F29383F2B373E2D373F30363F31343D30333C2D353D2B373E293840283841273A4228
3B422A3A412A3A402B393E2B363B2A353B2B343C2C30382C2C34272B34262A32252A3323
2B34232B36222C37212D38212B351F2A341F2C341F2B311E292D1C292D1D282C1E272B1F
272B20282C21262B1F23271B
7E9597849B9D899FA38A9EA6889CA5899BA38B9BA18B9CA38C9DA38D9FA58EA0A690A2A5
91A3A591A4A792A6AA91A6A895A8A996A9AA99ACAC99ACAE9AACAF99ACAE9CAEAF9EAFB2
A0B0B49FAFB3A0AFB1A1B1B0A4B3B0A4B2AFA5B3AEA5B3AFA5B3AFA6B3AEA7B5AEA9B7B1
AAB6B3ACB8B4ACB9B4ACB9B3ABB9B0AAB9ABACBCAAADBCAAADBBA9ADBAA9AEBAA9AAB6A7
9BA69992A08D67706140443C3538322F332C2B2D272A2A252D2C283C3D38464A444E5550
525A57535D5A515C5A505B5A545E5C57615C585F5A5A605D5B61605860604A51543E464A
31393E1F252B151B1F0E14140A0F0B0E140B1921111F291429341D2E39212B351C222A14
1D210E181A091113040F11031010051211081A190F1E1D121E1C1326241B28261D221F1B
26252431332E393E36464F3F3036291C211722291B2B34234A573D606C505E6750565C49
474B3D3F43373F43374045373F45353C42313C422C3B43283B4428394127373E26373F26
353C26343B25343B26353C29363C2C353B2D323829333928363A29383C2C373D2D363D2C
373F2C363E2D363E2C363E2A353E27343D27343C263038242D34232C33232B31222B3223
2A31242931252931262933262A34242B34222A332029311E292F1D282F1C282E19262C18
272C19292E1C282C19272B18
809697859C9F8AA0A58A9FA8889DA6879CA38A9BA38C9CA68D9EA78C9DA68FA0A891A3AA
91A3A991A3AB93A5AB92A5AA93A4AA94A4AB95A6AC97A8AE9AAAB09BABB29EADB4A0B0B6
A2B1B7A1AFB5A1AEB4A2AFB4A3B1B4A6B2B3A7B4B3A8B4B3A8B4B3A8B4B1A9B4B0AAB6B2
ADB8B6ADBAB7ADB9B6ACB9B4ACBBB1ACBBADAFBDACB0BEADB0BDADB0BDAEB0BDAEB2BDB0
AFBBAFABBAAC92A094626C66474F4A3A403831362D2D2F242A2A1F2B2921312F2A3B3B37
3F413F474C495059535560595A665E5A655C565F56565E56555D57565E5956615C55605D
4E5B5943504D2C343413171811151213180F1A21131E2615232C1727301B28311B252B16
1E221016170A100F070E0D080E0F0810100B23261C1F20181C1C155661466D7C5A34382D
3D443B41483E3238312A2E2922231E18191312110D0E0E082023196E80618BA17D849878
6D7B67556054555F5450584C4C5345474E3F434A373F48303E482D3E482C3C452A3B442A
384026363E26353B26353A26373B29363B2A32372831362732362833362A31372A31382B
323A2D30392B2E37282F39262F3B242F3A222F39212D371E2C351F2C34202C33202A3120
29312128302327302528322629342429332129342029341E28331D28321A293118282F16
272D16272C18262B18272B19
7E9195879C9F8B9FA5899CA6869BA5879CA4899BA28C9EA48D9FA78D9EA68FA0A791A1A9
93A3AB92A3AB92A4AB92A3AA93A3AB95A3AB95A3AB94A4AC96A5AD99A7AE9BA9B09EACB3
A0AFB4A1AFB3A3AEB2A3B0B3A4AFB3A4B0B3A5B1B1A6B1B0A7B3B0AAB6B2ACB7B6ABB6B4
AAB6B4ACB8B6ABB7B4ACBAB3ABBBB1ADBCAFAEBDAEB0BDAEB0BDACB2BEACB2BDACB3BDAD
B3BEAEB2BEAFAFBDAEA0AE9F8A9888626C6141453E3B4034383B2E38392D34342D33312F
312E2E2F2E2E35363341453E4E564A555E51596355596355566053525C51576356566357
515F5651615747564C252D291D241D191E17181D13171C10191E0F1A1F0F1D2012202416
1F231516170E13120D11100D0F0E0D0F0D0D1919171716141E1F1E7F9377A6C29E94AF90
5F705F3D453B2B2F271B1C1716161215140F13110F11100E0E0C0C47514194AD88899F80
889C8170816F62716361705F63715D626F5D5E6B595D6B5558664E505D454C564048513C
444B384146353D42313A3E2E383C2D373A2B33352A32352A3134283236293035282E3327
2E34272C34262932242A34242A34232A33232B35232C37212C361F29321C29321C29311D
29301E27301F28312128322228322228311F28311D28301A272F1A272E19282E19262C18
242916242A19242A1C22291B
76888D84989A879BA28598A28295A28497A28498A1899CA48D9EA78E9FA88D9EA78E9FA7
90A1A98FA1A991A3A991A3A893A5AA97A7AC97A7AC95A6AD95A7AC98A8AD98A7AD9AA8AD
9BAAAD9EADACA1AFACA4B1AFA6B2B2A6B1B3A6B2B1A6B3AEA8B3AEA9B3AFABB6B4A8B4B2
A7B3B3A9B6B5A9B7B3A9B8B2AAB8B0ADBBB0AEBDAFAFBDAEAFBBABB0BCABB2BEABB2BDAB
B3BDABB4BFADB3BFAFB2BEAEB1BEACA5B19F82897C72786C71776B60655B47494442423E
363332302B2A2A262326241F3132293F43364C5242545B4957614E4A52444C5646485342
424F3E404E3E465543424F3D2A34252026191F24151A1D0F17190C17180C1A1A101E1F16
1E1F1818181212120C11120B12110D12100E1615131B1A1A1B1B1C3B413B5D6D5D92AE8E
7D95783A4435282C1F1E1E1417150D100D080F0B09100B0C0E0B0D2529257C94788EA78A
839A7F80957B63715F586453596453636E5E7D8E7883977D83967C819276758368646D57
6167565E645959605650584E464F4340473B3C4238393D35373B33353A3034392D32382A
3239292F38292E36292A31272C32282B32262930232A32202C331D2A311A2C321A2C321B
2B311D282F1D252D1B242C1D232B1C232B1B242A19242A19252A19262B1A26291A232719
21261821291B21281D20281D
7C8F8F829595869A9D879AA28496A28395A28395A18899A38B9BA68C9DA88C9DA78B9DA6
8CA0A88CA0A78DA1A68FA2A591A3A792A5A893A6A894A7A795A7A796A8A996A7AA9AA9AC
9BAAAB9DACABA0AFACA2AFACA4B0ADA6B2AEA7B3AFA8B4AFA8B4AEA7B2AEA8B4B0A7B4B2
A6B2B2A7B3B3A7B4B1A9B6B1ADB9B3ADB9B1AEBBB0B1BEB0B0BDB0B1BDAEB2BEACB3BDAA
B3BDABB3BDADB4BFAFB4BFAEB4BFADB4BEABB0B9A7ABB3A2A9B2A09CA5957C807673786C
3C353736302F302A2A2A26242825202D2D243334273B3E2E3E44313235272F34262B3122
272F1F29301F323B273B452D3036232A2E1E2528191E2015191A1116170F1A1B1420211B
20211B18191513151113160F13160F12130E181A161E201D2529232529242B312B4D5A4B
5968564A564522251D1D1D15191611110D0C0E090C0D050B0C070E353836738673839A85
7D957F83997F81947974826B677260616A5A7B8B7483957A86977C8C9D808C9E806D7864
5B615762685F646D64697368697565616B5D596358515A524D56504A534B475046444C41
41493C3D4438383F3532372F2F322A2C30262B2F232B2F1E2A2F1B2C2F1B2E301A2E311B
2D301C252A191E2414161C0F12170B11160B14190D161A0F1E221425291A25291A24271A
24261B22261C1F241C1E251B
7D918C859895899C9E879AA18497A18496A18598A28799A18A9BA28B9CA38B9CA48B9EA4
8BA0A68CA1A68DA1A48EA2A490A3A68FA4A78FA4A591A5A592A5A596A8A799A8A99BA9AA
9DAAAA9EAAABA0ABAEA2ADAFA3ADAEA5B0AEA6B1AEA8B3AFA8B4B0A9B4AFA9B3AFA9B6B2
A9B5B3A8B5B1A9B5AFABB7B0ADB8B0ADB7AEAEBAAFB0BCAFB1BDB0B3BEB0B3BDAFB4BEAE
B4BEADB5BFADB6C1AEB5C1AEB5C1ADB5BFAAB5BFABB4BDAAB3BDAAB4BFA9B1BCA6A9B59E
63625C3B3436403C383D3C333A392E37372A3738283233232C2C1D2A281C252419202115
2023142325152B2F1C3539253538262C2F2226281E1F201A1B1C181A1B171E201C222421
20221E1B1E1A171A16171914181B1314160E11130D191A1525291E2D3326363E2F444D3B
48533E424C38262A1F20221A1D1D19181515151114130D13110D13211F234E564F5E6D60
70836E798C73899C7E8B9D8087987E82937980917782957985977B84947B8A9B828B9B85
6670665C655D545A54626B5E8B9D83768371555E57555F595B665F5D6A61647266697867
67756364715E5C665550574945483E3C3E34383B2F35382831332231322032321E30311F
2C2E2025291C191C100F1208080B030407000608020508020C0F0615190D1B2012202315
21241722251A21251A1F2418
7588867F9493859A9E869BA28699A48699A6879AA7879BA6899CA68B9EA58A9DA48B9EA5
8A9EA58B9FA68DA1A590A3A591A5A891A6AA90A5A892A8A994A7A796A7A699A9A89CABAA
9FACACA1ADAEA4AFB0A6AFB0A5AEAFA5AFB0A7B2B0A9B3B0A9B3B0AAB3B1AAB4B3ABB7B4
ACB8B4ABB7B2ADBAB2ADB9B2ADB9B1AEB8B0B0BBB1B2BDB3B2BDB2B3BEB1B3BEB0B4BEAE
B4BEABB6BFABB8C1ADB7C0ADB6C0AEB5C0AFB8C2B1B9C2B0B9C1AEB9C2ACB9C3ABBCC9AC
9EA7905B58524A474279816B6B715D5459485257444345353736283131232D2D1F2A2B1D
282919282A182C2E1D3839293A3A2D3233292A2A2323241E1D1E191C1D18222420262924
2629242528222125201C1F1C1A1D1812140F0F100C10110C15170F1C20152B31213A422D
3B442E363E292B312024271A1F20181C1C181B1A1A1A1A1A1D1F1D1D201E252925363D34
434B3F484E427E8C7397A98C8FA18792A48890A1858EA0848D9F858A9B84889984889B86
8193807584736E7A69697564889A808FA5896B7A6A616F615B685B555F55626F62758774
798C767C8F777B8E7673836D6C7B66697561646D5A58604E535A494E5442464C393C4132
363C30282E251C221811150D0A0D06060801040600010300000100030501070A030D0F05
181A0D212414222716232A19
7387857D929384989F869AA48699A68699A78698A78699A7889CA8899DA78A9FA68DA0A7
8D9FA88FA2AA90A4AA8EA2A790A5A894A7AB94A7AD93A7AC96A9AF97AAAE9AAAAE9BAAAD
9BAAAD9EADAFA0AFB0A2AFB1A3AFB1A3AFB1A6B3B3A7B5B2A8B5B2A9B4B5AAB4B6ABB6B8
ACB7B7AEB9B7AFBAB5AEB9B5B0B9B5B0B8B4B0BBB6B1BDB6B2BDB5B1BDB2B2BEB2B5C0B0
B6C0AFB7BFAEBAC1AFBBC1B1BAC0B3BAC2B6B9C1B5BBC1B4BCC4B4BBC4B0BAC4ACBCC7AB
B9C6A89CA48D75746A9FA692A9B19C9DA79295A089777E6A49493D444636434734434731
3F432B3C4028383B283B3B2D3D3C3039382D2D2D2527271F21211A1E1E1720201A24241D
282A232C2F272C30292325241D1E1D1213120F100E0D100D0F120D1317111D2319242B1D
272D1D29301D252A182022141C1C161918171B1A1B1B1A1D303534444D47434E464E5C50
505B4E4C53474D504993A38A8A998484938080907B808F7A899C84899C858A9D878B9F89
879C858599817D9077778A72798B727C90757B8F767B8F76778A73738670738570738571
7486737788767889767889767889757A8B747C8B73798673748070717E6E6E7C6C677466
5C6A5C363F381C201D171B16090A06040501020300010200000100000100000200020400
0C0E031A1D0C222713252A17
7284857D90958295A08396A48296A38396A38497A38497A2859AA3889EA58A9FA58A9EA5
899DA68A9FA88CA2A88A9FA68A9FA58EA3A792A5AB94A7AF94A7B196A7B197A8B099A8AE
9AA9AF9BAAAF9BAAAF9CAAB09EACB1A0ACB1A3AFB1A4B2B3A7B3B5A7B2B5A6B1B4A8B2B6
A9B2B8ABB4B8ACB6B6ABB4B4ACB3B3AEB5B3AFB9B5AFB9B7B1BCB6B1BCB5B2BDB4B3BDB2
B3BDB0B4BDB0B6BEB0B8BEB2BAC0B6B9C2B8B8C1B7B7C0B4B6C1B3B7C3B0B7C2ACB7C1A9
B6C1A9B6C0AAB3B8A6B2B8A6B6BDABB6BEABB5C0A9AEB9A1787A706D6F647C836F818A71
7279635B614F525747484B3D4444393D3A313230272D2C2327261E21201A20201823241B
26261F282A22292B242224201D1D1C181718141315111413121713171D171B211A21291D
272E20293120252B1A1F22141B1C151B19171815171C1A1F373D3E7588776D8270617464
6476625A67544A4F4698AB908EA28B718373647365515B5271816D82957D849880899E86
889D878AA1885F6F60485349859A7C72836A6F7E6B7B8D797D917C7A907B7A907A778B75
76897575847474827572807572817573837374837174827175827074816E74816F74826F
788A734F5B501212170B0B0C010101000000000000000000000100000100020400090B02
121406171A0A1F2411232814
79898E7E91998093A07F93A08094A18194A08397A08397A08498A1869AA3899DA6889DA7
899DA68A9EA68A9EA68A9EA68B9EA68DA0A691A3AB92A4AD93A4AF95A3B096A4AF98A7B0
9AA9B19BA9B19CA9B19CA9B29EACB3A2ADB3A3AEB2A3ADB2A7B0B5A9B1B5A8B0B5A9B2B6
ABB4B9ACB4B8ACB5B7ADB5B5ADB5B3AEB5B2B0B8B4B1BAB5B2BAB5B2BBB4B2BCB2B2BCB0
B1BCAEB2BCAEB3BDAEB3BCAFB5BEB2B5BFB3B4C1B3B4C1B2B3C0B1B5C2AFB6C2AEB8C2AE
B8C2ACB9C1ABBBC1ABBBC2ABB9C0AABAC1AABCC3A9BBC3A8B4BBA2AEB39DADB39CB0B99F
ABB4999CA38A8D937B696A5A5C5A4E4B483D3D3B2F3535292D3024262A2027271E292A1F
2A2B2125281D20221B1D1D191A1A171817171515161618171B1F1B242920272D21293023
2B31252C32262B3122262B1D25281E22231D1D1C191818183036317B927688A48052624D
4D5A463F4839393E3464715E5F6D5D6A7F69697D675A6A566A7B647A8D747E927A82967F
849882899F86616F614045419AB18F51594E4248468FA48D7F948066786B7185747A8E7B
6D7B6D6C786D717C74727D7871807972817672827373817174826F707E696E7A656A7761
616D5A3F453D14121509050805030403010202010201000100010001030005070216180D
202314222717232A19242C18
7A898F7F929A8195A08297A18195A18296A18397A28497A38497A48698A5899AA7899BA8
8A9CA88C9EA88DA0A88C9FA78DA0A78EA1A890A1AB93A5AD94A4AD94A2AF97A5B199A6B3
9AA8B49CA9B39DAAB39EABB5A0ADB6A1ADB6A2AFB4A4B0B2A6B0B1A7B0B1A7B0B3AAB3B5
ABB4B6ADB6B7AEB7B7AEB7B5AEB7B3AEB8B1B1BAB2B2BCB1B2BBB3B2BBB2B2BCB2B2BCAF
B1BCAEB3BEAEB3BEAEB4BDAFB5BFAFB4BFAEB5C0AFB7C2B2B8C3B3B8C2B1B9C3B3B9C2B2
B8C2AEB8C2ACBAC2ABBCC4ABBDC5ABBEC6AABDC4A8BDC4A6BEC6A6BCC4A6BBC3A6BBC4A4
BAC3A2BAC5A1B4BE9AA2A98A93997E71745F4948374447323C422F353A2A333427313124
2F2E222A2A1F24241B1F20191C1E171A1C16191B161C1E1921241E2D31272F3327303528
3134293033283034282E31252C30252B2E241E1F17191A1216181024291D3A4532313829
2E3225282C22272B22272C2420251E4E5D496B7F6162735873866A71836A70816B6D7E6B
718574778C7B7387756E806D889E835E6A5F42494A8AA08B92AB92798C7A7C8F7B7F917D
3D3F404345487581786F79755F686668766E6E7D6E6E7D6C6D7D686C7C656B7B6467765F
515C4A363E33191B190D0C0D0B080A080507060404030202020101080A061417101F2318
272C1C292F20282F20293020
74868A7D919581959B83979E82969E8396A08496A18395A38596A38697A38797A28A99A6
8B9BA78C9CA78D9FA88EA1A78EA0A78F9FA890A0AB91A1AD95A3AD96A4AF97A5B199A5B2
9AA7B39BA9B29AA8B19CAAB39DABB49DABB39FACB0A2AFB1A4AFB0A7B0AEA9B2B1ABB3B4
AAB3B5ABB5B5ABB5B5ACB6B4ACB7B3AEB9B1AFBAB0AFBBAFB1BCB1B1BBB1B1BBB2B1BBB1
B2BCB1B5BDB2B8C0B2B8C0B3B8C0B2B8C1B0B8C2AFB9C2AFBAC3B1BAC2B3B9C2B3BAC3B4
BBC3B3B9C3AFB8C1ABBBC4ABBDC6AABEC6A8BEC6A6BFC7A5BDC4A4BDC4A5BDC4A5BEC6A4
BEC5A2BBC6A1BAC59EB7C29BB5C19AA8B48D6F71575E60485B5D46575A45525441464537
3E3C3133312829292024261C22241A1F21191E1F1720221924271D2F322635372A383A2D
383A2D36372C3233292D2E25292A222A2C23282B2220221B1C1E171517121516111A1B14
1919131819141B1E1820231C1C1F1A24292047543E505E46738866697C5E58674F3C4538
434D444E5B5465786A6B806E6F846F6A7E6D627568728876849D83879F84859A81707D6D
2E2B332B29346E7E737282763C414555605A7487725A67593A40394C564665755D61705A
4A564530392F1C201D12131209090A060506050404040301020200171C122B34222C3523
2D35232B3121272C2025291E
6F8088798C9380949C83969E83959E84959F8495A08597A18598A084979F8799A08A9AA3
8B9AA68C9AA78E9DAA8E9EA9909EA993A1AB95A2AD95A2AD96A3AD98A4AE98A6B098A5B1
99A7B29AA8B29AA7B19BA9B29BA9B19BAAB19FAEB1A2AFB2A4AFB0A6B1AFA8B2B0AAB3B3
ABB3B5ABB4B6ABB4B8ACB6B7ACB6B6AEB9B5AFBAB4AFBAB1B1BBB1B3BBB2B3BBB2B5BCB4
B7BEB5B8BEB4B9BFB4BABFB5B8BDB3B8BFB3B8C0AFB8C0AEBBC1B1BCC2B3BBC1B3BCC2B4
BEC5B2BDC6AFBBC4ADBCC7ACBCC8AABBC6A6BDC6A3C0C8A4BEC5A3BEC6A6BEC5A6BEC4A5
BFC6A4BDC6A2BBC5A0BCC7A1BBC6A0BCC7A0AFB8949EA3859BA183A2AA8997A080747761
45413A3F3D3533332A2C2F23292E20292D202A2B1F2B2B202B2C2332332A3F4233434738
3E4337373A3231362D2C2F29282A2624262224282123271E20231A1B1F151C1F161C1D16
1615101A1B1220221723261C21231D1B1D191A1F1823281F313A2B37412F38412F303628
2A2F22272B21343D3045524162765D556550424E415363536B7E69728771748976768778
515A573F48495D6E637C937C56655763736171836D4F594D1C1A1D292A285F6C59546050
3942392A322C1F2420181B170F120F080A08050804050802060902181F113F4F33445439
38442F2D3626282F2224281E
75878C7F929883979F8497A08394A08294A18294A28497A3859AA38599A0889BA28B9DA5
8D9DA88E9CA88E9EAB8FA0AD92A1AE94A2AE95A2AD94A3AC96A4AC98A5AD99A7AF9AA8B3
9BA8B49BA8B39CA9B39EACB59EADB49CABB09EADAFA1B0B0A3B2AFA6B4B0A7B1AEAAB3AF
ABB3B2ACB4B5ADB5B8ADB7B8AEB9B8AEB8B8AFB9B6AFBBB5B1BCB5B1BAB3B2BAB3B4BCB6
B7BFB9B8BDB7B9BFB7BABFB8BABFB5B9C0B3B8C0B2B9C1B0BDC4B2BDC4B3BDC3B3BEC3B2
BFC5B0BEC7AEBFC6AEBEC7AEBCC6AABBC6A8BEC7A6BFCAA6BCC6A5BCC6A6BDC5A6BDC5A5
BFC8A7BFC8A6BDC7A2BFC9A4C0CAA4BFC9A3BEC8A2BEC7A2BBC5A1BCC5A4BAC5A3AAB494
7172625250465355494B4F41454A394449374346364345363F42353D413544493A494F3F
41473A383C34373B353034302C2F2C292C2B2A2E29292D26272B2324282024281E22241C
1919131B1C1521231A24271D21241C1D1F1A181B1617191521261D272B2126291F23251D
2022191F221721261923281C48563E505F4438412E2F3427373E3140483C4751485C6A5F
7387765E6E635464595F71606779646C7E696D7D6C5F6C61414745494F4B5D665B4D534D
616F5E1B1F1F1B201D1116100C100A070A05050804090B060D100A0F130B2833223B4A34
3845333641332F382D242C22
7A8E8E83979986999F8698A28493A28594A68595A88597A88599A7869AA48599A2899BA4
8B9CA78B9DA88C9FAA8DA0AB8E9FAA90A1AD92A2AC90A2A993A5AB96A6AD99A6AE99A7B0
9BA8B29DA9B19DAAB19DAAB19FACB29FACB09FAEAFA2B0B2A2B0B2A3B2B1A4B0AFA7B2AF
AAB4B2ADB5B4ADB5B6ADB7B6ACB7B4ACB6B4ADB7B4AFB9B6AFBAB6AEB9B4AFB9B5B2BBB6
B5BDB8B4BBB7B5BDB8B9BFB9BAC1B7B8BFB5B8BFB4B9C0B3B9C1B2BBC3B4BDC3B5BBC2B3
BBC3B0BDC6B0BEC6B0BDC6AEBCC5ACBBC4A9BCC6A9BDC7A9BCC6A9BCC4A9BCC5A8BDC5A7
BEC6A8BFC8A7BFC9A6C1CBA6BFCAA5BEC8A4BDC7A3BDC7A4BDC6A5BDC6A6BDC5A5BBC6A5
B0BB9B959A82979F868D957C777D676F745E6669566062505154464A4E4145483C434538
3F41353B3C34393935383935373A35383A373437342F322E2F332D2D322B2B3029252922
1B1D18191A151D201821241A21231A1C1E161719121D1F182B2F262D3227292D2221221C
1E1F181B1C15191E141B1F141C2013282E1D2C321F2C3220262A1B2022181D1F19212420
4550434C584B343C38363E38475347576758627564677A6A657567687769626E64323638
48544A242B251F251F0D110D0C10090A0C050A0A040F0F0B0F100D0D0D0C0E0F0F111412
14181528302631392E272E26
7E909384969C8697A28696A58693A68693A98695AB8596AA869AA8879CA4889CA2899DA3
8A9DA58A9EA68CA0A88EA1AA8E9FAA90A0AD91A2AD91A3AB93A5AC96A6AD98A5AD98A5AE
98A4AE98A5AE9CA9B09EAAB09FABB09FAAAF9FABAFA2AFB2A3B0B2A3B0B3A3AEB1A5AFB0
A8B1B2AAB2B4AAB3B3ACB6B4ACB6B5ABB5B5ABB5B4AEB8B6AEB9B7AEB9B7AFB9B7B1BAB8
B2BBB9B3BAB8B4BCB8B8BDB8BAC0B9B9BEB7B9BDB7B9BEB7B9C0B7B9C0B7B8C0B6B8C1B4
B9C2B1BAC4B0BBC4B0BCC7B0BBC6AEBCC6AEBEC6AEBEC4AEBEC4AEBFC6AFC0C7AFC1C6AE
BEC3ACBFC4ABBFC6A9C0C9A8BFC9A6BFC8A7BEC7A8BEC7A9BCC5A8BEC6A8BFC7A9BEC6A8
BCC5A8B8C0A4B7C0A4B5BEA2ADB69A9AA286888F75767B645B5D4D585A4A5051454B4B41
45453C4141393E3C364C5043586150515A4B4C5446393D3230322A2B2D26282A24272924
21231E1C1D181F211923261B21261B1E20181A1B1624261F2A2E262C2F262A2C2225271F
22231C20221A1E21181B1D1314140B13130918190D1F20121E1E1217170E13140D11110C
23261D56664F2F372E242A25212727232B2936413A5262515D6E59576454576556435045
3E4C403F4D3C1E241C0D110C11150F12130C12120D13110F100D0D0C080B0A070A090609
0A060A0E0D10151516202320
80909485949D8595A48596A88595AA8494AB8192A98294A88498A7879CA7879BA5899DA7
8B9EA98DA0AB8DA0AB90A1AB91A0AB93A1AD94A2AF94A4B195A4AF97A6AE98A6AC99A5AC
99A6AD97A4AC9AA7AE9CA9AF9EAAB0A0ACB19FACB1A0ADB1A1AEB0A2AFB1A4AFB2A5AEB1
A7B0B3A8B2B3A9B3B3ACB6B4ADB7B6AEB8BAAEB7B9ADB7B8ADB7B7AFB9B8B2BBBBB3BABA
B4BABBB6BBBCB7BCBCB9BDBDBBBEBEBABEBCBABFBBBABFBBB9BFB9BAC1BBBAC3BABAC3B7
BAC3B4BAC4B3BBC4B3BDC5B3BDC6B3BEC6B4BFC6B5BFC6B5BEC5B4BDC5B2BFC5B2C0C7B1
C2C6B0C2C6B0C0C5ADC2C8ADC0C6A9C1C8ABC1C9ADC1C9AEC0C8AEBFC7ACBEC6AABFC7AA
BEC6ABBEC5ABBCC4A9BBC4A8B9C4A7B5C1A3AEBA9DA4B0938990777D836B7072605F5D53
524F4A4E4D4747483F4B4F425C695366775B6373563A3F2E2D2F2428282022221D20211E
2222202323222628242629242329241E23211D21203740373D473C31372F2C3127292B22
282A202A2D232629201C1D1613130C10100616170A1D1D0E1B1B0C1211090D0C070A0905
0F0F0B3740312B33292127221B211F171E1C1419181E261E293323252C1C272E1E303928
3F4A3847543D1C1F1615171021251B191B151F211A1D1D191412130F0B100D080F0D060D
0D060C0C050E0C0610141217
7C8E9483959E8597A58395A88293AA8293AA8395A98396A88499A8869AA8879BA9899BA9
8C9DAC8FA0AD8F9EAC919FAC92A0AC95A1AF96A2B195A2B196A4B196A5AF97A6AD99A7AD
9BAAAF9BA8AE9CA8AF9BA8AF9EABB19FACB19FACB29FACB2A0ADB4A2AFB6A4AFB5A4AFB4
A8B1B5A8B3B6A8B4B4AAB6B5ACB6B6AEB7B8AFB8BBAEB8BAAFB9B8AFBAB7B2BAB9B5BBBA
B6BBBAB7BBBBB9BCBEBBBFC1BCC0C2BBC0C0BBBFBFBABFBEB9BEBBBAC0BBB9C0BABBC3B8
BFC8B8BCC4B4BCC3B2BDC3B3BDC4B4BDC4B4BDC4B5C0C6B7BFC7B7BEC8B7BEC7B6BEC6B4
C0C6B3C3C8B3C2C6B0C3C7AEC1C7ABC1C8ADC2C8AFC2C9B0C2C9B1C0C7AEBFC7ACC0C8AB
C0C8ACC0C7AEBFC6ADBDC5ABBDC6ACBCC6ABBAC5A9B9C5A7B4BFA3ADB69BA6AF958B907D
6C6D6358575155554D494A4242453B494E3F454C3C353A2E2E3429282C232426201F211E
202220272A272B2F2A2B302B2A2F2B2629282427283B443D434E44353E36333B3230372D
2F352B2E342A2528221C1D1A12111010100A15160D1B1D101C1E1017190E10100A0D0C07
0C0B0711100C161913161A16141816111513111612171E16192015171E10171D0E161A0D
1A1C112225181C1F151D221721261C1B1E162E34273136282B2F2325271E26241F26231E
1F1919191316140F15110D15
7A8D9381959D8396A48598A88394A88293A88495A98597AA8496AB8598AC889AAE8A9BAF
8C9DAF8FA0AE91A1AE929FAD939FAE94A0AF95A1B195A2B096A4B097A5B098A5AF99A7AF
9BA9B09BA9AF9EABB09EAAB0A0ABB2A1ADB3A3AFB6A2ADB6A2ADB9A3AEBBA3AEBAA3AEB7
A4B1B8A5B2B8A6B4B8A8B6B8AAB5B8ACB5B9ACB5BAADB5BBAFB7BDAFB7BBB1B9BCB4BABD
B5B9BCB5BABDB6BCC0B8BEC0B9BEBFB9BFBFB9C0BFB8C0BDB8BFBBBCC2BBBBC0B8BCC2B7
BFC6B7BDC5B5BDC4B4BEC5B2BCC4B1BDC5B2BDC3B4BEC4B5BFC7B7BFC7B8BFC7B7BEC6B3
C0C6B1C3C7B0C3C7ADC3C6ABC3C7ABC3C7ADC2C7AFC4C8B2C3C8B2C3C8B1C2C8AEC1C6AB
C3C8ACC3C8ADC2C7AEBFC5AFBDC4ADBDC5ADBDC5ABBCC5AABAC3A9BAC3A8B9C3A6B5C0A3
A4AE957F837575796A61635752534B4E4F4544463C3B3E3533362F2B2D29292927232524
2527262B2F2B2E342D2F352C2D322A2E30292E2E2A2F302D2F322F2E332D2E332B2F352B
31392D2E362C282E272326231E1F1D1B1D181E211A1F241A1B2115161B1110130D0E1109
0D100811120B151811181C161519150F13100F130E131810151A1013180C13160B12140B
10120912140C141810181C15171B15181B161E23192C3322303720282D162B2C1732301F
302D212A261F2C2C26282A24
7C8E9081939882959F8495A48293A48595A68796A88797AA8595AB8495AC8597AD8899AF
899CAE8DA0AD8FA1AD8F9FAD909FAD91A0B092A0B092A0AF95A3B299A5B39AA6B59CA7B6
9AA7B69AA8B49DAAB29FABB1A1ABB2A1ACB3A1ADB4A2ACB5A1ABB6A2ACBAA3ACBBA3AEBB
A4B0BCA5B1BCA5B1BBA7B2BCAAB4BDABB4BCACB4BDAEB5BEAEB5BFAFB7BFB1B8BFB3BBBF
B4BCBEB5BDC0B6BDC1B6BEBFB5BDBDB4BDBCB6C0BDB6BFBDB6BEBCB9C1BDB8BFB9B9BEB7
BCC2B6BCC3B6BDC5B7BFC5B7BDC3B4BEC4B5BCC2B5BCC3B5BFC6B8C0C6B9C0C6B9C1C7B7
C3C9B3C3C8B0C3C8AFC4C9ADC4C8ACC3C7ABC3C7AEC4C8B1C4C8B2C3C6B2C4C7B0C2C6AE
C3C7AFC3C7B0C3C7B0C2C6B1C2C6B2C0C5B1BFC6AFBFC5ACBEC3A9BDC5A8BDC6A6BAC5A6
B7C2A5B0BBA0AAB49B9AA38D80867570746557595051544A3E3E393736333230312C2B2C
292829292A2A2C2E2C2D302D2D302B2E302931332A2B2C2427282124261F24261F272B22
2B3026292E25282D25272C252529232429222E3729262F231C241915191210120E0C0F0A
0B0E0910130E151913181D17171C1513181112170F161C11151B1013170C0F130A0E110A
0D120A0C0F070B0F0710120B0F100B1619111B1E14202516272B181E1E0D40442A211C13
38352E44473E2324212A3128
788B8F8092998293A08395A48395A48495A48696A58697A78495A78497AA879AAB899CAC
889CAC899EAB8A9DAA8C9EAB8D9EAC8FA0AF8F9FB090A0B194A2B397A5B399A5B598A3B4
98A3B59AA7B69CAAB59DAAB39EABB39EABB59EACB5A0ADB5A2AEB6A4AFBAA5B0BBA4AFBB
A4B0BDA5B1BDA5B1BDA7B2BDA9B2BDACB4BEADB5BEAFB7BFAFB6BFB0B8C1AEB7BFAFB9BF
B2BBC0B3BCC0B3BCC0B4BCBEB5BDBEB4BDBCB4BCBAB5BDBBB4BDBBB6BFBBB7C0B9B8C0B8
BBC2B7BDC2B8BEC3BBC0C5BDBFC4BCBDC2B9BEC4BABDC2B9BEC3B9BFC4B9BEC3B8BFC5B6
C2C7B5C2C8B3C0C7AFC2C9AEC3C9ACC3C8ACC4C7AFC2C6B0C3C7B1C1C5B1C3C8B2C2C6B2
C1C6B2C0C5B1C2C5B0C2C6B1C3C6B4C2C5B3C1C4B0C0C4AEBFC5ACBDC4AABEC6A9BCC4A7
BBC3A9B9C3A9B5C0A7B3BFA7B1BCA5A0AA968E96857E84765F605852504B43413E3B3835
38343035302E312D2C312D2C2D2A292927242B2A252B2B2527272124241F23251F22271E
20231C20231C232820252D24232B21232C212F3B292934231B2317141A1111150E10120D
10120B12160E171B12191E14191E14181D12171E121B2215191F13181E1212170F0D120C
0D120D0C100B070B04080B04090A040A09040B09040E0D0614150B14130A2D31201A1910
363A2E5C6A51171A131A1F16
798C9381959E8497A48396A58497A88496A68395A58495A78396A88598A98699A8879CA9
889CAA899DAB899CAA8A9CAA8C9EAC8E9FAF909EB192A0B493A0B496A3B497A5B498A5B5
98A5B59AA7B59BA9B49BAAB49DABB59EABB59EABB6A1ADB8A3B0B9A4B0B9A5B0B9A4AFB8
A4B0BAA3AFBAA5B0BAA8B2BCA8B1BCABB3BDADB6C0ACB5BEACB5BCACB6BDACB6BCAEB7BE
AFB7BEAFB8BDB1B9BEB3B9BDB3B9BDB4BCBEB4BCBEB5BDBDB4BBBCB6BEBCB8BFBBB9BFBA
BABEBABABEB9BBC0BBBCC2BBBDC3BCBEC5BDBDC5BCBCC2BCBDC2BBBCC2BABDC3B9BDC3B6
BBC1B1BDC3B0BDC4B1BEC5B1C0C6AEC1C6AEC1C6AEC0C4AFC0C5B1BFC5B2C0C6B1C1C6B1
C1C7B2C1C5B1C1C6B2C0C5B2C2C6B4C3C6B3C0C3AFBFC2B0BFC3B1BDC3ADBCC3ABBBC3A9
BCC4ACBBC6ACB7C2A8B5BFA8B6BFA8B6BFA8B5C0A7ACB7A09DA5928E97826F7361595B4B
535242474338423D35403B3437332D302D272D2A2629252224211E22211D242721232821
20261C1E24191D25191E251A212A1C212A1A1F2917212A181D2414191F11171D10151A0E
14190E171A10171A0F191C121A1E14181E14191F151C23181C23171A2217141E130E160D
0D140C0C120B0A0F06080B040809040808030707030705030607020608010709000E1205
161A0A1E24101E230F181B0B
7D919882969F8498A48497A78597AA8598AA8396A88497A98499A8869AA88699A7869AA7
889DAA8A9FAC8CA1AD8DA0AD8FA2AF90A0B092A0B393A1B693A1B594A2B495A3B399A7B7
9AA7B89AA8B69CABB69DACB5A0AEB6A2AFB6A2ADB7A2ADB8A3ADB9A6B1BAA8B3BAA7B3BA
A8B3BCA7B2BBA7B2BBA9B4BDAAB4BDABB6BEAAB4BFAAB5C1ABB6C0ACB6BEADB7BFB0B8C0
B1B8C0B1B7BFB2B9BFB4B9C0B5BBC1B5BCC1B3BDC0B3BDC0B4BCBFB8C0C1B8BFBFB8BDBE
B9BFBDB9BFBCBAC1BBBBC2BBBAC2BAB9C2BAB9C1BABBC1BDBEC4BEBDC3BDBCC2BDBEC3BD
BEC3B9BDC3B6BDC3B5BFC5B7BFC6B4C0C8B3C0C8B1BFC7B0C1C8B2C1C7B2C1C6B1C2C7B3
C3C8B4C4C8B5C0C5B4C0C5B4C2C6B4C2C7B5C0C4B3C0C5B4BFC4B3C0C5B0BFC5B0BFC7B0
BEC6AFBDC6AEBCC4ACBBC2ABBBC2ABBBC1AABAC2AAB7BFAAB7BFACB3BEA8A7B19B919885
8085736666595755494F4C404746393E3D3237362D2D2B25282621252521222320212420
20261F1C231A191F15171D131B23171A2113181E0F1E24131F25161F24171E23171C2318
1B2218191F16161B12171B111A20141C23151F26171E26161D27161B2515192214161F11
131D0E11180B0F15070C11050D0F060C0D040B0B040A0A05070904060902060901080C00
0C10021216061113050B0A01
798B957F929E8396A58497AB8395AC8599AE8599AC859AAA8498A7869AA9899CAB889CAA
8A9EAB8CA0AA8FA3AE8FA2AE8EA0AF90A0B291A2B492A3B593A3B494A5B496A6B498A7B4
9AA9B69BAAB69DACB69EADB5A0AEB6A4B0B9A4B0B9A3ADB9A4AFBAA7B2BBA8B3BAA8B4BB
A9B5BDAAB5BEABB6BFAAB6BFABB8BFABB9BFA9B6BDAAB6C0AEB9C3AEB9C2AEB7C0B0B8C1
B2B9C1B3B8BFB3B9C0B5BAC1B7BDC3B6BCC4B5BBC4B8BFC5B8C1C4BAC2C2B9C1BFB8BFBF
B8BFBEB8C0BDBAC3BDBBC4BDB9C2BABAC3BABCC2BBBEC5BEBEC4BFBFC4C0BFC4C0C1C5C3
BFC4C0BFC5BCC2C8BDC1C7BCC0C7B9C0C8B8C1CAB6C3CAB4C4CBB5C4CBB6C2C9B5C1C8B5
C1C7B6C1C7B8C0C7B8C0C7B9C0C7B8C1C8B8BFC5B6BFC5B5C0C6B5C1C6B3C3C8B5C2C7B5
C0C6B5C1C6B5C1C6B2C1C6B0C1C6B1BFC5AFBEC5ADBDC4AEBDC4B0BBC2AFB9C0ADB5BCAA
AFB8A6A1A997858A7A696D5E5C605050524643443D3A3A3537383234342E2F2F2B282927
2425252023221B201E191D191B2019191F18171D141A20151E251920261A1D241A1D231A
1E251B1E261A1C24171D25161F2715212A15232C17212A152029131E26121D25141C2314
1B22121A210E181E0D181C0D15190C13140A13140A11120A0D0F090B0F080B0F080C1008
0B0F070E12080F10090C0B05
7789957E909E8294A78394AC8192AC8495AD8296A98396A78397A58698A6899AA88A9CA9
899BA88B9DA88FA1AD90A1AE8E9EAE8D9DB08E9EB18FA1B291A3B192A4B095A5B196A5B0
98A8B398A9B499AAB49CABB49FADB5A0ACB7A2ADB8A1ACB6A3ADB7A6B0B9A8B1BAA8B1BA
A9B3BBA8B2BCA9B3BDA9B5BFAAB6BDA9B6BBA9B5BAACB6BCAEB7BEB0B8BFB2B9C1B3B9C1
B2B9C1B3B8C0B5BAC1B6B9C0B7BAC1B5B8C1B6B9C1B7BDC1B8BEC0B9BFC0B9BFBEB9BFBE
B9BFBEB9C0BEBAC2BFBAC1BDBAC0BABBC1B9BCC1B8BDC2B9BDC2BBBDC1BBBDC1BCBFC2BE
BFC3BDC1C4BCC0C4BAC0C4BAC0C6B9BFC5B6BFC6B3C1C7B2C3C6B4C3C8B6C2C7B6C0C6B7
BFC5B8BEC4BABFC5BBBFC7BABFC6B8BFC6B7C0C6B7BFC5B5BFC5B2C1C6B1C3C7B2C3C6B4
C1C4B4C1C5B4C1C6B2C1C5B0C0C5B0BEC4AFBEC3AEBCC1AEBBC1B0BAC1B0B9BFAFB8BEAE
B6BDAEB6BDADAFB5A7A3AA9C90968B7A7D7662645F54554F494A413E3F3534332E2C2A29
252125201D221B1A1F1D1F211D211F181C1A1114120F12100F131011151010150E12160F
14191013190E151B11141B0D131A0A141B09161E0B171E0A161D0A161C08161C09161C0B
141A08131807161D0A171C0C16190C14150B13140C0F100A0C0E0A090C09090C0A0B0F0B
0B0E0A0B0D0B0B0D0B0A0A07
7689947E909D8293A38494A98192AA7E8FA87F92A78094A58396A48598A58799A68798A7
8698A8879AA88A9CA98C9CAA909EAD8E9CAD8E9DB08D9EB190A1B293A4B293A3B095A4B1
96A5B595A5B498A8B49DABB69EABB69EA9B79FA8B7A0A9B6A1ABB6A2ADB5A5ADB7A7AEB7
A7B0BAA7B1BCA6B0BCA8B2BDA9B3BEA9B4BEABB5BEACB4BDAFB6BDB1B7BCB1B7BEB2B9C0
B2B8C0B3B9C1B4B9C1B4B9BEB7BCC1B6BAC2B4B9C0B3B9BEB4BABEB6BCBFB6BDBDB6BDBE
B6BDBDB5BCBCB7BCBEB8BCBEB9BDBCBABDBAB9BEB9BBC0BBBCC1BCBEC2BDBEC1BEBFC0BD
C0C1BDC0C2BDBFC1BBC0C3BCBFC3BABEC3B8C1C6B7C1C5B4C1C5B4C1C6B5BFC5B4BEC5B5
BEC4B6BCC2B8BCC2B8BEC5B7C1C6B8BFC4B6BFC4B6BEC4B4BDC3B1BFC5B0C1C5AFC0C2AF
BFC2B0C0C5B2BFC3B1BFC3B0BEC2B1BBC1B0BBC0B0BABFAFB8BDADB9BDAEB9BEAFB9BEB2
B8BCB1B6BBAEB5B9ACB3B7AAB1B7AAA8AFA39FA799939B8B858E7B585A4E3D3938373235
2B232D231B281D18241E1B241E1C241B1C2015161B1012170E11130C0F0E0A0D090E120A
10140B0C12090C13090B12070E1608131C09131C07131B04111801141C03181F06151A06
1315040F110210120411120610110810100B0F110D0E100D0A0C0A070906080A070D100C
0B0E0C0A0C0B0C0E0C0C0C09
748A917A8F987F929F8192A48091A77E8FA87E91A97E91A68195A58396A68597AA8799AC
8799AC879AAB899AAA8A9AA98C9CAB8D9CAD8F9EAF8E9FB18E9FB391A1B591A1B394A1B3
94A1B395A3B498A5B59BA9B79EAAB79EA9B69FA8B7A0A9B8A0A9B6A1AAB4A3ABB3A6AEB6
A8B0BAA8B1BCA8B1BDAAB2C0AAB3C2A9B1C1AAB2C1ACB2C2AFB5C2AFB5C0B1B7BFB2B8C1
B2B8C1B3B8C2B2B8C1B3B8C0B6BAC2B7BBC4B4BAC3B3B8C0B2B8C0B2B7BFB4B9BFB4BAC0
B5BCC1B4BBBFB5BABEB6BBBFB9BEC1B8BDBEB8BCBCB9BCBCBCBEBCBDBFBEBFBFC0BEBDC0
BFBEBFC0BFC0C0BFC0C0C0C0C0C1BFBEC0BDBEC1BDC0C3BDC0C5BDBFC5BCBDC2BABDC2BA
BCC2B7BEC3B7BDC0B5BEC2B5C2C5B7C2C5B7C0C3B5BFC2B4BEC3B3BEC3B2C2C5B3C2C4B4
C0C3B5BFC3B6BDC1B6BBC1B5BBC1B5BABFB4BAC0B4BAC0B2B9BEB1B8BDB0B9BDB1BABFB3
B7BDB2B7BCB1B6BBB0B3B8AEB2B9AFB2B9B0AFB7ADADB5AAA8B3A59AA29768666C534F5A
383042282032261F2C211B251D171F17131A1713191414181114161013121114110F140F
0F130E0D120D090E09060C060A1108131C0C121C08121C06121B03121C03141C05141A05
1216051214071214071111060F0F0811110A12120C10120B0C0E080A0D060A0C060D110B
0D100C0C0E0C0E0F0E0F0F0D
768C937C929A7F949F8194A27F91A37F91A47E90A58193A88395A98294A88595AB8999AF
8A99B08B9BB08A9AAD8A98AC8C9AAE8F9CAF909DAF929FB293A1B495A2B595A3B594A2B3
94A2B295A3B397A4B49AA7B69CA9B79DA8B89EA7B9A0A6BAA2A8B9A4A9B9A3A8B7A7ACB9
ABB0BEABB1C0AAB1C0ABB2C0ADB4C1ACB3C1ADB3C4AFB5C6AFB4C4AEB3C2B1B5C1B3B7C2
B3B6C1B3B6C1B3B7C1B4B8C1B5B7C0B6BAC2B5BAC2B3B9C1B4BAC2B5B9C2B5B9C1B6BBC3
B8BEC5B7BCC4B6BAC2B6BAC0B8BDC0BABEC0BBBFBFBBBEBDBBBFBBBCBEBCBFC0BEBFBEBE
BEBEBFBEBCBEC0BFC0C0BEC1C0BEC0C0BFBFBEBFBFBFC0BFBFC1C0BFC2BFBCC1BCBCC1BB
BCC1B9BDC0B6BFC0B6C0C1B6C1C2B5C1C3B5C1C3B5C1C4B5C1C4B3C0C3B2C2C3B3C0C2B1
BFC0B2BFC0B6BDBFB8BABEB7BBC1B9BBC0B7BABFB5BABFB1BABFB1B9BEB0B8BEAEB8BEAC
B9BEAEB8BEAFB8BDAEB6BAAEB3B8ADB4B9B0B2B8AEAFB6ABAEB5ABADB6ADA2AAA498A19A
616268332E3B3B363B31292B271E2222191D1E181A191518181718181819171817121313
1214141012120C0C0D0B0B0B0D100D12170F141A0E141B0D121B0B0F1807101806141C08
131A09151A0C15190D15170C12130A12120A11110A12130B1012090D10060C0F050D0F07
0F100B10100D0F100E0F100D
7487937D919D7E91A08094A57E91A47D8FA17E90A38092A68193A88293A98494AC8796AF
8795AF8A98AF8B9AB18B9BB08D9AB08F9AB1919CB2929EB395A1B596A1B595A1B595A2B4
98A5B698A4B49AA6B599A5B499A4B49BA6B79DA6B99FA6BAA2A7BBA5A8BCA6A9BDA7AABE
A8ABBEA9ADC0ABAFC2ACB1C2ADB4C1ADB4C2AEB4C3AFB4C4AEB4C4AFB5C3AEB4C1B0B5C1
B1B6BFB2B6BFB3B7BFB2B5BFB2B6BEB4B8C0B4B9C0B2B8C0B4B9C1B6BAC1B7B9C1B7B9C1
B8BBC1B8BBC1B7BAC0B7B9C0B7BABEB8BCBEBABEBDBABEBABABFB9BCC0BABCC0B9BDBFB9
BCBEB9B9B9B6BEBEBABEBFBBBEBEBBBDBDBBBEBFBDBEC0BEBDBFBEBCBFBDBCC0BBBBBFB9
BBC0B7BCC0B4BEC1B5BFC0B4C0C0B6C0C1B7BEC1B6BDC2B4BFC2B3BFC2B1BFC1AFBDBFAD
BCBEAEBDBEB1BCBEB5BABFB7B9C0B7B9C0B7BAC1B5BAC0B3B9BEB1B8BCAFB7BCADB8BDAC
B8BFACB9BFABB9BEABB7BDADB7BCAFB6BAAEB4BAACB3B7AAB2B7ACAFB5ACADB5ABABB4A8
A0AA9D7C80766C6D6233292B3127282C2123251D1E1F17191C16171B17171B1716181414
151012141012130F110D0B0C0E0E0D141611171D13171D11171E11161D0E171E0D161D0C
13190B141A0D14190E13180C12150C0F120B0F110C11140D12150B0F13070B0E030B0B02
0C0C040D0D050C0D060E1008
7586937A8C9C7D8FA27D8FA57C8DA47B8CA27D8FA57F91A78092A88192AA8494AC8695AD
8795AF8A99B18998AF8B9AB28E9CB48F9DB4909DB4909DB4929FB694A1B795A1B994A0B7
96A1B797A3B698A4B697A3B399A5B59AA7B79DA8BA9EA7BCA1A9BDA3A8BDA5ABBFA5A9BF
A5A9C0A5AAC0A6ABC0A8ADC0A9AFC1AAB2C2ABB2C2ACB4C4ADB4C4AEB5C3ACB5C1AEB7C1
B0B9C3B0B9C1B0B8C0B1B8C0B1B7BFB2B9BEB2B9BDB2B9BFB3B9C1B4BAC2B5B8C1B6B9C2
B8BAC3B7B9C2B8BAC1B8BAC0B7BABFB7BCBEB8BFBEB8C0BBB7BEB8B8BEB9B8BEB8B9BFB7
B9BFB8BABEBABBBFBBBAC0BCBBC0BDBBBEBABBBFBABBC1BEBCC1C1BBC1BFBAC1BCB9BFB9
B9BFB8BBC1B9BCC2B9BDC0B9BFC0BABFC0BCBCBEBABBBFBABBC0B8BDC2B6BEC1B4BDC0B4
BCC1B4BBBFB5BCC0B9BCC2BBB9C0BBB8C0B9B7C0B7B6BEB6B7BCB5B7BBB4B6B9B2B6BAB1
B6BAAFB7BCAFB6BBAEB5B9AFB4BBB1B4BAB1B2B9AFB2B7AEB1B6AFAFB5B0ADB4AEABB2AB
AAB4A8A9B3A4A0A999534D4D382F31332B2C2E2526271E1F251D1E221A1D1E171A1A1517
191316171419161315100F0F0C0D0B0F120B13180D171D111A21131C23131B2111171D0D
141A0D141A0F12180E11160C10140C0D110A0F140C11150F0F140A0F13080E11060E1005
0E10050E0F040E10040F1105
7889967C8E9E7E91A67D8FA87D8FA87B8CA77E90A78092A78092A68091A78494AB8694AC
8795AC8A99AF8897AD8998AD8C9AB08E9DB38F9EB48E9EB48F9EB491A0B692A0B7929FB7
93A0B8939FB794A0B695A2B599A5B69AA6B798A3B897A3B79CA6BAA0A9BBA1A9BBA3AABD
A4A9BFA4AAC0A4AAC0A5ACC0A6ADC0A6AFC0A8B0C2ABB3C3AAB2C3ABB2C2AAB3C1ACB5C1
AEB7C3B0B8C2AFB8BEB1B8BDB2B8BEB2B9BFB1B8BDB0B8BEB0B8BEB1B9C1B1B9C1B2B9C2
B4BAC3B3B9C3B4B9C1B6BAC2B5BAC2B3B9BFB5BCBFB5BDBDB5BCBBB5BBBAB6BDBCB6BEBD
B6BEBDB6BCBBB7BDBBB8BDBCB9BFBDB9BEBCBABEBDB9BEBDBABFC0BABFC1B8BFBEB8C0BC
B7BFBAB8BFBAB8BDB9B9BDBABCBDBDBBBCBEBABDBFBABDBFB9BDBDB9BDBAB9BDB8B8BCB7
B9BCB7B9BDBAB9BDBAB8BFBCB9BFBEBAC0BDB8BFBAB6BDB8B7BBB6B8BCB6B7BCB5B6BDB6
B5BCB3B5BDB3B4BCB2B3BBB2B3BCB3B2BBB3B1B9B3B1B8B2AEB5B0ABB3AFAAB2AEA8B1AC
A8B2ABA6B0A9A7B2A88F958E6564653C353B3A3233352E2F2F282C272028201B24252229
28262B1A192215161D0F11130B0D0D0B0D0B0E120C141811181E161B21171B2016171B11
161A11161A141015100E120D0F130D10140D11160F12160F0F130B0D11080D10090D1009
0E12090E12080C0E04070801
7686997A8BA07C8DA77D8EAA7D8DAB7B8AAA7C8DA87E8FA87E8FA78190A78492A98A97AE
8A97AF8997AE8B9AAF8D9BAF8E9CAF8E9BB08E9CB3909FB68F9FB58FA0B492A1B694A2B8
94A1B9939FB8939EB795A0B598A3B79AA5B99AA5B998A4B99BA6BB9DA7BAA0A7B9A1A8BB
A2A7BEA6ABC2A4ACC4A3ABC2A3ACC0A3ACBEA5AEBEA7AFBFA8B0C0A9B2C0A9B4C1ABB6C1
ACB4BEADB4BEB0B6BEB2B7BFB2B6BCB2B5BDB2B6BEB1B7C0B0B7C2B0B8C3B0B9C2B1B7C2
B2B8C3B0B7C3B0B6C1B1B8C0B4B9C2B3BAC3B4BAC2B4BBC0B4BCBFB5BCC0B6BEC1B6BEC2
B5BCC0B6BCBDB7BCBBB8BBB9B9BCB9B9BDBBB9BCBBBABCBABBBCBCBABEBEB9BEC0B7BEBF
B6BEBCB6BEBAB7BDBBB9BDBCB9BCBDB9BDBEBABDBDB9BDBDB8BBBDB8BBBBBABDBCB8BBB9
B8BCB7BABDB9B9BCBAB7BBBAB6BABBB7BBBBB8BCBAB7BBB7B7BBB4B7BBB3B4BBB1B2BBB0
B2BBB1B3BCB3B2BCB4B1BBB1B1BBB1B0B8AFB0B8B1B1B9B3B1B9B1AEB7AFADB4ACAAB1AC
A9B2ADA8B2ADA7B1ACA6B0A99BA59D6F7271504D514D4B4D48454935313A28252F2A2B31
2B2D321E20271B1E24181B1C13161410141011140F141711171B151D1F191C1D19191914
1919131A1D1816191615181314171214180F1419101519111215100E110C0C0F0B0F120F
1115100D110C080B06040501
7282997787A17C8CA87C8CAB7D8CAB7D8DAB7D8EA87C8DA47D8EA38090A28391A38795A9
8996AC8694A88796A78B9BAB8E9BAD8C99AF8C99B28D9CB58E9DB48F9EB2919EB3939FB4
95A0B6959FB7959FB697A1B599A3B498A1B599A3B79DA7BC9EA8BC9DA7B9A0A8BAA1A7B9
A2A8BBA4AABFA3ABC1A2ABC1A2ABC1A2ACBEA5AEBEA6AFBFA8B1C0A8B0BEA9B2BDACB4BE
ADB5BEAFB6BFB0B6BFB1B4BEB1B3BCB2B3BDB4B5BFB2B6C0B1B7C0B2B7C1B3B9C2B4B8C3
B5B7C4B3B7C4B0B8C5AFB6C1B0B7C0B1B7C0B2BBC3B2B9C1B2B9C0B3BBC0B4BBBFB4BBBF
B4B8BCB5B8BAB7BAB8B9BAB8BABBB9BABABBBABABBBBBBBBBABABAB9BABCB9BCBFB6BABC
B4B9B8B4BBB8B6BCBBB6BBBCB7BBBEB8BDBFB8BCBDB9BDBDB8BABBB7B9B9B8BBB9B8BAB7
B8BBB7B8BBB6B8BAB6B8B9B7B8B9B8B8BAB9B6B8B6B6B9B5B5B8B3B4B9B3B2B9B2B0B8B0
B1B8B0B1B9B1B1B9B1B1BAAFB1B9AEB0B8ADAFB7ACB0B6ADB0B6B0AEB5B0ADB5ADAAB1AC
A9B0ADA7B0ACA6AFAAA6B0AAA7B1AAA0A9A48C9094898E92838B8C575D6230333B252A2E
22262A1F21261D1F221D201C24281C1D20141A1B1117180F1818121A18141C1A161D1A17
1D1C191E1F1C1B1D1A1A1C18191B17151813151811171C141317111114100D0F0E0D1110
0F13110D100D070906010201
7384977889A07A8BA67A8AA87B8BAA7C8DAA7C8DA87C8EA67E8EA57E8FA38192A38495A4
8595A68695A78594A68896A98998AC8896AE8A98B18C9AB18D9DB18E9EB1919FB2939EB2
959FB498A1B79AA4B899A3B69AA2B59AA2B799A1B89AA5BB9BA7BA9BA6B99EA6BAA1A9BA
A2A9BCA1A8BEA0A8BFA1A9C0A1A9C0A3ABC0A4ACBFA5AEC0A7B0C0A6B0BDA7B1BDAAB2BE
ACB4BEADB5BFAFB5BEB1B6BFB1B5BEB2B6BFB1B5BEB1B6BFB2B5BFB2B6BFB2B6C0B5B7C2
B6B8C2B3B7C2B2B8C3AFB7C1AFB7C0AFB6C0B0B9C0B0B9C0B2BAC0B2BABEB3BABDB4BCBE
B5BBBFB6B9BDB6B9BBB8BABDB8BABDB6B8BDB7B7BDB9B9BDB9B9BCB8BABBB6BBBCB6BBBB
B4B9BAB3B9BBB3BABCB4BBBDB5BABDB5BABEB7BBBEB7BBBDB6BBBBB5B9BBB3B8BAB4B8B8
B5BAB8B7BBB9B8BBB8B8BAB8B8B8B7B8B9B8B5B6B5B5B6B4B4B5B4B4B8B6B2BAB6B0B7B4
B0B8B2AFB9B2AEB8B1AFB8B1AEB7AFAFB6AEAEB4ADAFB6B1AEB4B4ADB3B4ABB3B2AAB2B0
A9B1B0A7B0AFA5AEAEA5AEACA4ACABA3ABABA4ACAEA1ABAE9DAAAB91A3A04C545D262A37
292E3623282E1F23261E231E23271B25281B2427192022161C1D171B17161C18161F1E1A
1F201C1F211C1D211D1D211B1A1E1A171C18171C16191E17161B141318110F120E0A0D0B
0A0D09080A07040503010201
748796788C9F7B8CA67A8BA77B8CA87B8CA77C8DA67D8DA77F8EA88192A98294A88395A7
8495A68594A78795A98896AB8796A98896AB8A98AD8C9AAF8D9CB08D9CAF8E9CB0919DB2
939FB597A2B797A1B697A1B798A2B89BA4BA97A1BA98A3BA99A4BA9AA5B99CA7B89EA8B9
A0A9BB9EA6BBA0A8BCA1A9BFA4ABC1A5ABC2A4ABC1A7AEC3A9B0C4A9B0C3A9B1C2A9B1C1
AAB1C0ACB3C2ADB4C1AFB4C0B0B5BFAFB6BFAEB5BDAEB6BDB0B6BDB1B5BDB1B6BEB3B7BF
B2B6BEB1B6BCB0B5BCB0B6BCAEB5BCADB6BEAEB7BFAFB8BFAFB8BFB0B7BDB2BABCB2BBBD
B4BBBEB5BBBFB4B9BDB4B9BEB4B9BEB2B7BEB3B6BDB5B7BEB6B9BEB6BABEB4BABEB4BBBD
B4BABDB4B9BEB4B8BCB5B9BDB7BABDB6B9BCB5B9BDB5B9BCB2B8BAB1B8B8B1B8B7B2B9B9
B5BBBAB7BDBBB8BDBCB8BBBCB7BABAB7B9B9B5B7B7B3B5B5B2B5B6B2B6B7B0B7B9B0B8B8
AFB8B6AFB9B6AEB8B4AEB6B3AEB5B3AFB5B4AEB4B2AEB5B2ACB3B3ACB3B4A9B1B2A7AFB1
A6B0B1A5AFB2A4AFB1A4AEAEA3ACACA1AAABA3ACACA0ACAA9DAAAA9BAAA9879697697379
4A505A393D492D2F3D2B2E38484F4D5964583539362C2E2D2121231A161B1813181C1B1A
1E1F1A1F221B1C221A1A2019181E18161B17171B16171C14161B1212160F0B0E0A080907
080806060504040201040100
7589977A8FA07C8FA67D8FA97C8CA77B8BA67E8DA6828FA98390AB8290AB8293AC8191A9
8292A78492A88694AC8796AE8898B08899B08798AF8A9AB08C9CB28C9AB28D9BB48E9DB5
8F9DB4929FB594A1B695A2B896A2BA97A3BB96A2BB98A4BB98A4B998A4B89BA7B89EA8B9
9FA9BA9FA8B99FA8BAA1AABEA1AAC2A3AAC4A4ABC5A4ABC3A5ADC2A7AFC3A7AEC2A9B0C3
A9B1C4A9B1C3AAB3C3ACB3C3AEB5C3AEB5C3ADB6BFADB6BCAEB6BBAFB6BBAFB6BDB1B7BE
B0B6BEAFB6BBAEB3BBAFB3BCB0B5BEAFB6BFAFB6BFB0B6C0B0B6C0B0B6BFB1B8BFB0B8BE
AFB7BBB0B8BCAFB7BCAFB6BCAFB7BCAFB8BDB1B9BEB4BABFB4B9C0B5BAC2B3B9C0B2B9BF
B4B9BEB5B8BDB4B7BCB4B7BBB4B8BAB4BABBB4B9BCB5BABCB2B8BAB1B7B8B2B8B7B4BAB8
B4BABAB5B9BCB6BABCB4B9BCB3B9BBB5B9BAB5B8BAB3B7B9B3B7BBB1B5BAAFB4B9AFB4B9
AEB5B8ACB5B7AEB6B7AFB8B8AFB5B7AFB5B6AEB5B5ABB3B3A9B1B1A8B1AFA7B0B0A7B0B1
A5AFB0A6B0B2A7B2B2A6B1B1A4AFAFA0ABACA0ABABA0ABAB9FADAD9CABAB9BA8A899A6A5
879295767E865E617157596B848F918A97936B747568736E36373A150E1A18131D141218
12101314131215161214151213161313141014151014160E12150A0E0F07070703090705
0C0B070A0806070503070403
718095798AA17B8CA67C8DA87B8CA87A8AA77E8CA8808DA9818DAB828EAA828FAB818EA9
818EA88390AA8492AE8493B08596B28697B38798B08A9AB08C9CB38B99B38D9AB68E9AB5
8F9BB5909CB5929DB595A0B996A1BC96A1BD98A3BD99A4BD99A4BB99A3B99AA4BA9DA6BA
9FA7BBA0A8BDA1A8BFA2AAC19FA8C2A0A8C4A1ABC4A1ABC3A2ABC1A5ADC2A5AEC3A7AFC4
A7AEC4A6AEC3A9B1C4ABB2C4ADB4C4ACB4C1ADB6C0ADB6BEACB5BBAEB6BDACB4BDADB5BE
ACB4BDADB3BDAFB4BDB0B5BFB0B5C0B0B5C0B0B5BFB1B6BEB1B5BDB2B5BDB3B7BEB1B5BD
AFB6BCAFB7BCB0B8BEB0B7BDB0B7BBAFB8BBB1B8BBB3BABDB3B9BDB4B9BFB3B8BFB2B7BF
B3B7BFB3B5BCB3B4BCB3B5BBB3B7BAB4B9BAB5B9BAB5B8BAB4B7BAB4B9BCB5BCBAB5BAB8
B5BABAB5B9BCB3B7BBB3B7BCB3B7BBB4B7BAB3B6BAB3B4BAB4B6BCB1B5BAB0B4BBAFB4BB
ADB4B9ACB5B7AEB6B5B0B8B4B0B7B3B0B6B1AEB4B1ACB3B1A8B1AFA8B1AFA8B1B1A8B1B4
A7AFB3A8B0B4A8B0B4A5AFB2A4ADB1A2AAAFA0A9ADA0ABAF9FABAF9EAAAE9BA6AB9BA6AB
9AA4AB9AA4AA949CA38F989E919A9E929D9D919D9B92A09970797424212D1D192618141F
15131A0F0C121311131D1C1A19171616161114150C15150C12120B0E0D090A09060A0A06
0D0D080C0C06070501080501
6D7A917988A07B8AA77B8AA97B8AAA7A8AA87C8BA77F8CA7808DA7828EA8818DA7818DA8
828FA98490AA8491AB8592AC8695B08496AF8395AC8597AD8899AF8B9AB08C99B08E98B0
8F99B2909AB4909BB6929DB8939EBA96A0BC97A1BD99A3BD9AA5BC99A3BA9CA5B99CA4B7
9FA7BBA0A6BD9FA5BDA2AAC1A2AAC1A1A9C2A2ABC3A2ACC3A3ACC1A2ABBEA4ABBEA6ADC0
A8AEC1A8AEC0A9B0C0A9B2BFAAB2BDAAB2BBABB3BCAAB3BCAAB3BCACB4BDABB2BDABB1BC
ACB3BDAEB3BEAFB5BFB0B5C1AFB3C2AFB3C1AFB5C1AFB4BFAFB4BDB0B4BDB2B6BEB2B4BB
B0B3BBB1B6BEB1B6BEB2B6BDB0B6BCAFB4BAB2B6BCB1B6BCB2B8BCB1B7BAB1B6BBAFB5BB
AFB4BBB0B4BBB2B4BCB3B5BCB4B5BAB4B6BAB1B5B8B2B7B9B2B7BAB2B9BBB3B9BBB3BABB
B4B9BCB3B6BBB3B5BBB2B4BBB2B5BCB0B4BAB1B5BBB1B4BBB1B5BCAFB3BAAFB4B9AFB5B8
AEB5B6ADB5B5ACB5B3ACB5AFACB4ADABB3ACADB4AFADB3B1AAB2B2A7B0B1A6AFB0A7AFB1
A7AFB2A6ADB3A5ABB3A6ABB2A7ACB2A5ABB1A2A9B0A1A9B19FA8B19EA8AF9AA4AC9CA5AC
9CA3AB9DA4AC9AA3AA98A2A897A0A697A0A5969EA4919B9E8C98966973734F545634363A
2220271A171F19151B2C2C2B2826262222201718141514101514121414141010120D0F10
0C0E0D0C0F0A080904060500
71809178879D7C8BA57E8CA97C8AAA7988A77B8BA67E8EA48190A4818EA37F8DA37E8DA5
7E8DA78090A98191AA8393AB8594AD8393AD8392AC8494AC8492AA8795AB8B97AC8C97AB
8E98AE8E98B08E9AB3909BB3929DB5969FB8979FB897A0B897A1B698A2B49BA5B49BA4B5
9DA5B79DA4B99DA4BB9EA6BC9FA6BD9EA6BDA1A9BFA1AABFA2AABEA1A9BBA4AABAA6ACBA
A7ADBCA7ADBDA5ACBBA7AEBAA8AFB8AAB1B9AAB0B9A9B0BBA8AFBAA8AFBCAAB0BBAAAFBA
ACB2BCADB3BDADB2BEADB1BEACAFBEABAFBEADB0BEADB1BEADB2BDAEB2BCADB2BBAFB3BB
AFB3BBAEB2BBAEB2BBAFB3BAB0B4BAAEB2BAAFB3BBB0B5BCB0B6BBAFB4BAAEB3BAAEB3BB
AEB3BAAFB3BAB1B4BBB1B2B9B2B3B9B2B3B9B1B4B9B1B4B9B0B4B8B0B5B9AFB5B9AFB3BA
AFB3BAAEB3BBAFB3BAAFB4B9AFB3B9ABB1B7ACB2B7ABB0B6ABB1B7ABB0B7ACB1B9AAB1B6
A9B1B4AAB1B3ABB3B2ABB3AFABB4ADAAB2ADAAB1AEAAB1AFA8B1B1A6B0B0A4AEB0A4ACAE
A5ACB0A6ABB2A6A8B3A5A7B2A4A7AFA4A7AFA4A8B1A2A7B29FA5B29DA5B09CA5AD9AA3AB
9AA1AA99A0A8979FA7969EA7969DA6959DA5949CA4919AA28F999F8B97998895927A8581
54575C40424A3A3B4237373D3B3D3F29293125262D24252A24272818181C14141A0C0E14
08090E070808040603040501
70808D778798798AA07B8BA57B8BA67A8AA4798AA17C8BA07D8BA07E8BA17D8AA17B8BA3
7B8BA47D8EA67F90A88091A98392AC8392AC8592AC8694AC8593AA8794AB8B97AD8D97AE
8D97AF8B95AE8C95AE8D97AF909AB2949DB4969DB4979EB5979FB4969EB298A2B398A3B4
98A1B598A1B69AA3B99CA5BA9DA6B99CA7B99EA8BC9DA7BCA0A8BDA2AABDA3AABBA5ACBB
A6ACBCA5ABBAA3AAB8A6ACB9A7ADB7A8AFB8A9AFB8A8AEB9A7AEBAA6ADBBA7ADBBA8AEBA
A9AFBBA8AEBAA8ADBBA9AEBDA9ADBBA9AEBCABB0BDACB0BCACAFBCACB0BDABB0BBABB0BB
ABB0BAAAAEB8AAAFB8ADB1B9ADB0B8ADB1B7ACB1B7AEB3B8AFB3BAAEB2BAAEB1BAACB0B8
AEB1B9AEB1B9AFB3BAADB0B8ADAEB7AEB0B8B0B1BAB0B1B8ADB1B6ADB3B7AEB4B9AFB4BB
ADB1BBABB0BBADB2BCAAB1B8AAB1B6A9B0B4AAB1B6AAB1B6A9B0B7A9AFB8ABB0B8AAAFB6
AAAFB5ABB1B5AAB0B4A9B0B3AAAFB1A9AEB0A7AEAEA5ACACA4ACADA6AFAFA4ADADA2ABAD
A3AAAFA2A8AFA3A8AFA4A7AFA1A4ADA1A5ADA0A5AE9EA4AE9CA2AC9CA3AB9BA3A996A0A7
979FA8969EA6979EA6969CA5959CA3939BA090989E8F989E8F989D8B959A8B94988B9597
848E907A8488737E816770765B646A4042514C525E5A65694A52541615221717200A0B14
04050D020306010201020201
6B7C86748693798A9E7B8CA3798AA47A8AA4798AA3798AA17A8AA17C8CA37D8CA57C8CA6
7B8BA67C8CA57E90A67F90A88291A98392AC8393AC8394AB8594AB8694AA8A96AD8B96AE
8C97AF8A95B08B96B18B97B18C98B2909CB4929CB4939CB5959DB5919BB4919DB4929EB4
929EB4949FB596A1B897A3B999A6BA9AA7BA9BA7BA9BA5BC9BA5BD9DA7BEA0A9BDA1A9BB
A4AABCA6ABBDA4AABCA4AABBA4ABBAA4AAB9A5ABBBA5ADBDA5ADBEA5ADBDA4ACBCA5ADBB
A6AEBCA5ADBCA5ABBCA7ADBEA7AEBEA8AFBFA8AFBFA8B0BDA8AEBDA8ADBCA8ACBAA8ADBB
A8AEB9A9ADB8AAAEB9ACB0BBACB0BBACB1BBABB0BAABB1BBACB1BCACB2BBABAFB9ABB0B8
AAB1B8AAB0B7ABB1B7ABB0BAAAAEBBABAFBBACB0BBACAFBAA9AEB8A8AEB8A9B0BAACB2BC
ACB1BCABB0BCACB2BDA8AFB9A7AFB7A9B1B7AAB2B9AAB2BBA9B0BBA8AFBAA8AEB8A7AEB6
A7ADB4A8ADB4A9AEB5AAB0B7A8AEB4A9AEB3A7ADB4A5ABB3A2A9B1A4ABB1A4ABAFA3AAAF
A2A8AFA1A7AFA1A7B1A0A7B19FA6B09FA7B09DA4B099A1AD98A1AA98A0AA98A2A996A1A9
96A1A995A0A995A0A8959DA7939BA4939CA4919BA2919B9F909A9D8E989B8E979A8C959A
899399869095838E92818D917C898F79858C79868F7A8790728087434A593F4A501B212C
070B17060A10030507020203
6B7B8372839077899A7A8B9F798AA37889A47889A67788A57889A6798AA57A8BA47A8AA4
7A8BA67B8BA57D8FA67E8FA68191A68493A88493A98293AA8294AA8495AB8795AC8995AD
8793AE8693B08794B18895B38996B28B99B28D99B38E99B68F9AB78D9AB68E9BB78F9DB8
8E9CB5909DB6929EB893A0BA93A1BB92A1B996A4BA99A5BC9AA6BD9AA5BD9FA9BD9FA8BA
A0A7BBA3A8BCA4AABDA3A8BDA3A9BDA3AABDA5ABBEA3AABDA3A9BEA4ACBEA3ACBEA3ABBD
A4ACBCA3ACBDA3AABEA4AABFA7ADC1A6ACBFA5ACBEA5ADBEA5ACBDA7AEBDAAAEBCA9ADB9
A8ADB8A8AEB9AAAEBAABB0BBABB0BDABAEBFABAFC0AAB0C1AAB0C0A8AFBFA7ADBBA6ADB9
A7AEB9A8AFB9A7AEB7A8AEBAA8ADBCA8ADBDA9AEBFAAB0BFA9AFBDA7AEBBA6ADB9A6ADB9
A7AEB9A7AEBAA9AFBAA8AEBAA7ADB9A7AEBAA7AFBBA8AEBBA7AEBBA6ACBAA7AEB9A6ACB6
A5ACB5A6ACB4A5ABB4A5ABB5A6ACB5A6ACB5A5ABB5A4AAB5A2A8B3A1A7B2A1A7B0A1A7AF
A0A6B0A0A6B3A1A7B69EA5B59EA6B59DA6B49AA4B298A1B098A2AF97A1AE969FAC94A0AA
93A0A8929EA7929CA6919AA7919AA7909AA58F9BA38E9AA08D999D8C979B8C979C8B969B
89959A869194838F93818F92808E927E8B917D89937B88927A8890748289708083566768
242E37090E1803070D010206
697B82758791798A9A798A9E7989A47686A57382A37183A37285A47588A4778AA3798AA3
7989A57B8CA77D8FA77E8FA48091A28292A28391A48190A78192AB8192AB8493AB8694AC
8794AE8793B18592B28693B48795B18996B08C98B38D97B38F99B78F99B88F9AB9909BB9
909BB4909CB3929EB6929EB6919FB7919FB793A1B898A4BA9AA5BB9AA4BA9DA6BBA0A9BC
A1A8BAA1A7B9A2A8BBA3A8BDA3A8BFA2A7BEA3A8BEA1A7BDA1A7BEA4A9C0A3AAC0A2AABF
A2ABBCA2ABBCA3A9BEA4A9BFA4AABDA3AABCA6ABBBA6ACBCA4AABBA5AABBA6ABB9A7ADB7
A7ADB6A8AEB8A7ABB8A7ABBAA7ACBFA9ADC1A9ABC1A9ABC2A7AAC0A5A9BFA4A9BDA5AABB
A5ABBAA7ADBAA7ABB8A6A9B7A7AAB8A7AAB8A7AABBA8ABBBA7ABBBA5ABBAA4AAB9A5ABB8
A6ADB8A6ACB8A6ACB8A7ACB9A5AAB7A5ABB7A6ABB7A6ACB7A5ABB7A4AAB6A5ABB6A6ABB5
A5ABB5A6AAB4A4A9B4A1A7B4A1A8B49FA7B2A2A8B2A2A8B49EA5B29EA4B19EA4B09DA3AD
9DA3AD9FA5B0A0A4B49CA1B49AA1B4989FB2979EAF99A1B098A0B1969FAF95A1AE939FAB
919EA8929DA7929BA8919BA88E99A68C98A38D9A9F8B989B8A989A8B969C8A959D88939C
88959B828E94818D92818F93828E95808B95808A947D8A917B898D798689768185788685
5A67681619270C0D17090712
6C7D8A7587967B8C9E7B8AA37989A87787A87385A67487A57488A3778AA2788AA37B8BA5
7C8CA77C8DA98092AA8092A78092A48192A58290A68392AB8393AE8192AE8293AD8392AB
8694AD8693B18693B38694B28796B08B99B0909AB18F97B09098B38F99B58F99B6909AB5
919BB3939CB2939DB2939DB394A0B494A1B495A1B498A3B69BA4B99AA3B99BA4BA9DA7B9
9FA8B8A2A9BBA2A7BBA1A6BDA4A7BFA3A8BEA1A8BDA0A8BCA1A8BBA3A9BEA4A8C0A3AAC0
A3AABEA4ABBEA3A8BCA5AABDA6ACBDA3ABBAA5ACBBA5ABBAA5ABBAA4A9B8A3A9B6A4AAB4
A4ACB4A4ABB5A5ABB7A6ABBBA6ABBEA5AABFA5A9BFA6AAC1A5AAC0A4A9C0A5AAC0A6AABD
A6ABBBA8ADBAA8ABB9A7A9B9A8ABBAA9ACB9A9ACBAA8AAB9A8ACB9A7ACB9A6ABB8A5AAB8
A5ABB7A6ACB8A5ABB9A5ABB9A6ACB8A7ADB8A7ADB7A8ADB7A8ADB8A8ACB8A8ACB8A8ABB6
A7ACB5A6ABB4A4AAB4A2A8B4A0A9B39FA9B49EA7B39DA5B29DA5B29DA6B39EA6B39DA4B0
9DA2B09FA5B19DA3B49CA2B69BA2B699A1B399A1B099A1B099A1B197A0AF949FAD929FAC
909BAA909CAA919DAB909CAB8D9AAA8A9AA58999A089999F88979C8A989D89959D87949C
86959B829195828F92848F93848E95828B96818B967D889279868D7A868A798388798286
788486545C66373B4B2F3242
69798B7485987B8CA27A8BA47A89A77987A87686A67689A5788CA47B8DA47B8CA57D8CA6
7D8DA77E8EA97F8FA98090A78192A58494A88390A98391AB8392AD8292AE8394AF8494AE
8695AE8895B08895B08894AF8A97AF8D99AF8E98AE8E97AF9098B19198B39199B59199B3
949BB3959CB4949CB4949DB495A0B595A1B298A3B29BA4B59CA4B89CA5BC9CA5BC9DA5BA
9EA7BBA1A9BDA1A7BCA1A7BDA2A8BEA2A9BEA1A9BEA1AABEA2AABFA3AAC1A3A8C1A2A7C0
A3A8BFA3A9BDA3A8BAA5ABBBA5ACBCA4ABBBA4AABBA4AABBA5ABBDA2A9BBA1A8B9A3AAB8
A4ABB7A4ABB7A4ABB7A5ACBBA5ACBEA4ABBFA4AAC0A4A8BFA5AABFA5AAC1A6ABC3A6ABC0
A6ABBDA7ACBDA8ACBEA9ACBFAAADC0AAADBFA9ACBDA9ACBAA9ACB9A8ABB9A7ABBAA5AAB9
A5AAB9A5ABB9A5ACBDA6ABBCA5ABBAA5ABBAA7ADBCAAAEBEAAADBDA8ACBDA7ACBCA6ABB9
A5AAB6A4AAB5A4AAB6A3ABB7A1AAB59FA9B49EA7B39DA5B39CA5B29DA7B39EA7B39DA6B3
9CA4B29DA6B39BA4B39AA3B498A0B497A1B299A3B299A2B197A0B097A0B295A1B2929FAF
909DAD909CAA919CA9909CA98F9AAA8C9BA88A9AA489999F88989B8B9A9B8A9A9C88999B
879899859595859394859194848E94848F97828D987F8B987B89957C88937D89917C858D
79838A7682886C7980647478
6574897183997789A27789A37889A5798AA57688A57688A47487A27788A37B8AA57B8BA4
7C8CA67D8EA77F8FA8808DA68391A78693AA8491AA828EAA818EA9818FAA8492AE8593B1
8694B18795B28794B28996B18C98B18C97B08C97B08C96B18F97B18F98B29199B49299B4
949CB4949DB6929BB5929BB3939EB394A0B295A1B297A2B29AA4B698A3B999A4BA9BA5BB
9BA5BA9AA4B99BA3BB9DA6BE9EA7BE9DA6BE9EA5BF9FA6C09EA6C2A0A7C39FA8C3A0A6C2
9FA6C1A1A7BFA3AABEA4ACBFA3ABBBA4AABAA4AABBA3AABDA4AAC0A2A8C19FA6BF9FA7BE
A0A9BCA2ABBBA2ABB9A2ABBBA2A9BCA1A8BDA1A7BDA3A8BDA5A9BEA5A9BFA6AAC3A5A9C2
A5AAC0A4A9C0A3A8C0A5A9C0A6AAC1A5A8C1A6A9C1A6A9BEA5A8BDA4A7BDA4A8BDA3A8BC
A3A9BCA4A9BBA4AABEA5ABBFA4ABBFA4ACBEA3A9BDA4A9BDA5A9BEA3A9BCA3A9BDA2A8BA
A3A9B9A4ABBAA3AABAA1A9B9A0A9B89FA7B59FA6B5A0A7B79EA6B69EA7B69CA5B59AA2B2
9AA4B19AA4B299A3B197A3B095A1B095A1B196A0B1969FB1949DAF949EB096A1B2929FAF
909DAD909DAB8F9AA88C97A48B97A48B97A48B98A48998A188979D89979B87969A849399
829297829296829195828F94818D93818D96808D977E8B957C8A947C8A947C89947A8691
76838C7583897181856C7E7D
6372896F829A7489A3768AA77689A77789A67687A57585A47485A47687A57989A57A89A5
7B8BA57D8DA68290A88390A78491A78794AB8591AA8390A98390A98290A8828FAB8591B0
8691B28792B38791B28792B18A95B48A94B28C96B18E96B39095B49096B49197B59299B7
929AB5919AB5909AB5919BB5929DB5929DB493A1B493A1B396A3B695A1B896A2BB97A3BD
98A2BB9AA4BB9CA4BC9DA4BE9CA4C09BA4BE9CA4BE9DA6BF9EA6C19DA6C19DA5C19EA6C2
9FA6C29FA6C0A1A7BEA3A9BEA2AABDA3A8BBA3A8BBA1A7BCA2A8BEA3A8C2A1A6C2A0A6C1
A1A8BFA1A9BFA1A9BEA1A8BDA1A7BEA0A7BEA0A6BEA4A9C0A4A9BFA5A9BFA4A8C1A4A7C1
A3A7C2A4A8C3A3A6C2A4A7C3A6A9C5A4A7C4A4A8C4A4A7C3A3A7C2A4A9C3A4A9C2A2A7C1
A0A7C0A1A9C0A2AAC0A2AAC0A2ABC1A3ABC0A1A8BDA1A9BCA2A8BCA1A8BBA1A6BCA1A7BB
A2A8BBA2A9BBA2A7BAA2A7BAA2A8BBA0A6B89FA4B79FA5B79FA4B79EA5B79CA5B699A2B3
99A2B29BA3B39AA2B298A1B196A0AF96A1AF969FB0969FB1969FB0959EAE939DAD919CAC
8F9CAC8F9CAB8E9CAA8D98A78B97A48B97A48A96A28A95A18A95A089949F87929D85919D
83929D84939C839299829097818E967F8C987E8C997C89967A87947A879378859277848F
74838C7382897182846D7F7D
67778B70829A7286A27588A87588AA7386A97183A67183A67486A77789A8788AA5798AA5
7B8BA47C8CA57E8BA5818EA78390A98591AB828EAA818EA9838FA98491AA8491AA8794AD
8792AD8890AF8890B08791B08993B08C95B18E97B19097B39197B69096B69095B69197B8
9098B68F98B59099B6919BB6919DB7909CB7929EB5929EB3929DB3929EB596A1B996A2BC
959FBA99A2BC9BA3BC9BA2BC99A0BE9BA4C09AA4C09AA5C19CA6C09DA6BF9DA6BE9DA6BE
9DA5BE9EA6BE9FA6BDA1A7BCA1A7BCA1A6BCA1A7BCA1A7BCA0A6BCA1A6BDA2A7BFA1A6BF
A2A6BFA1A6BF9FA5BE9FA6BE9FA4BE9FA5C09FA5C1A2A9C2A2A8C0A2A7BFA2A8BFA2A7BF
A2A7C0A3A8C3A5A9C6A5A8C5A4A8C4A3A8C2A3A7C1A3A8C2A3A7C1A3A7C2A4A8C2A2A7C1
A1A7C29FA7C2A1A9C2A1A9C0A2AABFA2A9BEA1A8BDA1A8BBA2A9BBA1A8BBA1A7BCA3A9BD
A3AABEA2A8BCA0A5B99FA5B99FA6B99FA5B79EA3B49DA4B59DA4B59DA3B59AA2B499A1B4
9AA1B39AA2B298A1B196A0B1959EAF969DAD979EAE969EAF969FB1969EB0949DAD929BAC
909BAB8E98AA8E99A98F9BAA8E99A78D99A68C98A58995A28A95A38994A287919F85909F
84919E83919B84929A839099838E9A818B9C7E8A9E7A869B778596778695778793768690
75868D7385897183836F827D
6575896F819870849F7287A47286A67183A66E81A47084A77184A57285A57386A57587A5
7687A47B8AA67B88A67E8BA8808EA9828FAA828EA98290A98290A98391AA8492AB8593AA
8592A88692AA8691AC8793AD8892AE8A94AE8A94AD8B94AF8D95B28F97B58E97B68E97B7
8E98B68E98B38F99B28E98B28F9AB6909BB7909BB4909CB3909BB2929CB4949FB795A0B8
969FB8959DB8969EBB969FBB959FBB97A1BE99A4C097A3BF95A2BE97A3BD97A2BB97A3BB
99A4BC9BA5BD9CA5BB9CA4B99CA3B89CA3B99EA5BA9DA4BA9EA4BA9EA4BA9EA4BB9EA2BB
9EA4BD9FA6BD9DA5BA9DA5BB9EA6BD9EA5BF9FA7C29FA8C3A0A8C19FA8C09EA7BE9EA7BE
9FA7BFA0A7C0A1A7C1A0A5C0A0A6BEA0A7BDA0A7BF9FA5BF9EA3BCA0A5BEA1A6C0A0A6C1
A1A8C09FA7BF9FA8BF9DA6BD9DA6BC9FA8BCA0A8BC9DA6BA9CA6B99DA5BA9DA5B99FA7BC
A0A8BD9FA7BB9EA5BA9CA3B89BA3B69DA5B69CA3B49BA3B39CA5B69BA3B798A0B6979FB4
97A0B397A0B096A0AD949EAC959EAD949CAD959CAE939BAD919AAC919AAD8F99AE909BAD
8E9AAB8C98A88B96A68B96A68A95A58B95A58A95A58893A38792A28690A1828D9E828D9D
828E9C808E9A7E8E977F8D97808D97808B997F8B9C7B879A77879776889574859172838D
7183897083846D817F6C807A
67758C6A7B966D819F6D84A26F84A47386A77285A77185A76E83A57084A67388A87488A6
7689A6798BA77A8AA67D8CA67E8DA77F8DA77E8CA67E8DA67E8DA67F8FA88090A98090A8
8191A88191A78693AA8792AD8893AF8894B08894AE8894AE8B95B08D97B38D98B68B95B5
8D98B68D9AB58E9AB38D99B28C98B68C97B68B97B58C99B28D9BB2909CB3939DB4939DB6
959EB8939CB8919AB9939BB9939CB8939DB8939EBA93A0BB91A0BB93A1BC95A1BB949EBA
95A0BC959FBC96A0BA99A2BA9BA3BA9BA3BB9BA4BB9AA4BB9AA3B99AA3B99AA3B89AA2B8
9BA3BA9CA5BB9CA6B99CA5B99CA6BC9DA5BF9DA5C09DA5C09EA7C29EA6C29EA6C19EA6C0
9DA5BE9DA5BF9DA4BE9DA5BC9CA5BC9CA5BA9CA6BC9CA6BD9BA4BB9BA3BB9DA4BD9DA4BE
9DA5BF9CA5BF9CA5BE9AA5BC9BA5BA9CA7B89FA9B99EA9B99DA8B99CA5B89CA4B79CA4B9
9DA5B99DA6B99DA5B99BA3B79AA1B599A1B69BA3B79AA4B89AA5B899A3B897A0B5959EB4
969EB4959FB2959FB0939EAE929DAD929CAC909AAC8F9AAC8D99A98E9AAA8E99AA909AAD
8E99AD8D98AB8B97A98B95A78892A48992A58993A58692A38591A28491A2808D9E808D9F
808EA1808FA07C8D9C7C8D9C7D8D9C7D8C9A7C8B9879869676859677889774859371828E
7083896F83836E82806B7F79
6774906C7C9C6E82A46F85A67083A57284A77486AA7385AA7186AA7287A97489A6778AA7
778AA7798AA77B8CA87C8DA87E8FA87F8FA7818FA77F8DA77E8CA77F8EA9818FAB8191AB
8192AB8190A98592AC8692AF8691B08792AF8996AF8996AF8B96AF8B96B18D96B58C96B8
8A95B78A96B78C98B68E99B88E9BBA8C99B98B98B68B99B38E9CB4909BB3939CB5939CB6
969EB8959CB8949CB8959BB9959CB9939BB7949EBA95A1BB94A0BB949FBB98A2BE99A2BE
98A0BD97A0BB99A0BB989FBB999FBC9CA2C09DA4C09CA4BE9BA4BD9CA5BC9CA6BB9BA3B9
9BA3B89CA5BB9DA7BC9BA4B89CA5BA9EA5BF9EA5C29EA6C29FA7C3A0A7C3A0A6C29FA5C2
9EA5C29EA6C29EA7C19EA7C09DA7BE9BA6BD9AA6BF9AA6BF9BA6BF9BA5BC9DA4BC9CA3BD
9AA2BE9BA5BF9BA6BF9CA6BD9DA7BC9EA8BB9DA8B89FAAB7A0AAB79FA8B79FA8B89EA7BA
9FA7BB9FA7BC9EA6BB9DA5B99DA3B89CA2B89CA4BA9DA5BA9CA6B99BA3B798A1B699A1B6
98A1B6979FB5959EB4949DB5939EB5929CB3909CB1909DB0909DAD919CAE919AAD9099AD
8E98AE8D97AC8B95AA8B96AB8B96AA8C97A98B97A88795A58694A48593A58390A3828FA4
8290A78290A67E8EA27B8BA17B8B9F7B8C9C7A8B9978879877859A78879B758596758692
74868D7285877084816D827A
6873917381A17484A77384A77282A67282A67584AA7483AA7485AA7386A87587A67888A8
7988A87A89A87C8CA87E8DA77F8DA6818EA6828DA7848FAA848EAC838EAE838FB0828EB0
8390B18591B18592B18591B18890B08992B08993B08B95B08E98B38D97B38C97B68E97BA
8C96B88A94B58A93B48D96B78F99B98E99B98D99B78E99B4919CB3929CB3939BB3959CB4
969DB4969CB2969DB3979DB5999EB6969CB6969CB798A0B999A0BA979EBA999EBB9AA0BC
99A0BA99A0B99A9FB99CA0BB9B9EBD9C9FBD9DA0BE9CA1BF9CA1BF9CA2BF9EA4BD9DA3B9
9BA1B79DA4B89FA6BB9EA4B99FA3B9A0A4BBA0A3BE9FA3C09FA5C1A1A6C1A1A5C0A1A5C0
9FA3C09FA4C19EA4C19DA3C09DA4BE9CA3BE9DA5C09DA5C09DA6BE9FA6BBA0A4B99EA3B9
9DA2BB9CA2BC9BA1BC9CA4BC9FA6BE9FA5BD9EA5BA9EA4B79EA3B69FA3B6A0A5B79EA5B7
9FA5B99EA4BA9DA3B99DA3B89CA1B59CA0B39B9FB39BA0B59DA2B69BA0B499A0B3979EB2
979EB2989EB2989EB2979CB3959CB4939BB3929BB0929AAF939BAE939AAF9096AC8F95AB
8E94A98E95A98C94A98B93A98990A58993A48892A186919F8591A08490A1838EA2838DA2
838DA6808BA57B88A17B89A07B8A9E79879A788698768396768296768396758193758290
74828D7282896F80816A7C78
646D8A6A7796707FA16F7FA37281A57281A67280A57584A87685A87687A87686A87887A8
7A89A77B8AA67B8BA57D8DA57E8BA5818EA7808CA7828DA9848DAD828DAF818EB1818EB2
818EB2818FB08291B08392B08592AF8792B08992B18A93B28A94B38A94B48B96B68D96B7
8D96B68B96B68B96B68E99B78F9AB58D96B28C96B18E97B2909AB3919BB4919BB3929CB2
919AB1939BB1969EB2969CB3969BB4969BB5969CB6979DB7979DB7979EB89AA0BB9AA1BD
9AA0BA9AA1BA9BA0B99CA0BB9CA0BE9CA1BE9AA0BD9AA1BC9AA1BD9BA2BD9AA0B99BA2B8
9CA4B89CA4B89DA3B69FA4B79FA4B89FA2B89DA0B89CA0B89EA2BBA0A5BDA0A4BDA0A4BF
9FA2C09FA2C19FA3C19FA3C19FA3BF9EA3BD9FA4BE9EA5BC9FA5B8A0A6B89EA3B69CA1B6
9EA2B99EA5BC9BA2BB9BA2BB9DA3BB9FA3BB9EA2B99D9FB69EA1B89EA0B79FA1B79FA2B7
9EA2B79BA2B699A0B699A0B69BA1B6989EB299A0B2999FB4989FB5979FB4969EB4969EB3
979FB1979EAE979CAD979CB0959BB1929AB09199AF8F96AC9097AC9299AE9095AA8D93A8
8D94A88B91A68B92A68A91A6878FA38791A286929F85909B85919D828D9C828D9D828D9F
828BA08088A27D88A27C879F7D8A9D7B889A7A8598778295748091758193768294748091
707E8D6E7E896D7E81687B77
636E8A6C79967180A07382A57381A57180A47281A47584A77887A97989AB7889AA7688A7
7789A4798AA37A8BA27D8DA47F8CA6808CA97F8AA97F8AAB818BAC828DAD818DAE818FB0
808EAF7F8EAC7F90AB8091AB8392AB8491AB8591AE8792B18894B28995B28A95B18A93AE
8C95B28D97B58E99B68D99B68E9AB38D99B18D97B18D97B18F98B28F99B28E99B18E9AB1
8E98B1919AB2949CB4959CB6949BB7949BB7959BB7979CB9979CB9969AB8979CBA999FBB
99A0BA99A1B99AA0B79A9FB79AA0BA9AA1BC99A1BB979FB897A0B79AA2B798A1B499A3B4
98A3B398A3B298A0B09BA2B29DA3B69EA4B79EA3B79EA3B69FA4B79FA3B9A0A4BBA0A3BC
A0A3BF9EA3BF9FA4C09EA2C09DA1BE9DA2BE9DA3BC9AA2B79BA2B49BA3B59CA2B59CA2B6
9BA1B69BA2BB9BA3BB9CA3BA9BA0B79CA1B59DA1B69C9FB69C9EB69DA0B69C9FB59DA1B6
9DA3B79BA2B7989EB4969CB3969EB4979FB2979FB1979EB3969FB5959DB5939BB3939CB2
949DB2949DB0939BAE939BAF9199B08F97AE8E97AC8C95A98D96A98F96A98D94A78C92A4
8A90A48890A3868FA18790A2868FA1858FA18491A183919D808F9A7F8E99808E9B808D9D
808B9E808AA07D889F7C889E7C889D7A8698798394788293758091737F92738195707F91
6E7E8C6C7D856A7C7F677A77
616D886A7794717D9E727EA3717EA3717FA37481A27785A47887A77986A97887A97789A6
7588A47789A57888A37B8BA37F8CA67F8BA97F8BAB7E8BAA7F8AA7818EA78390AA8390AB
818FAC808FAC7F90A98090A88290A68390A88490AC8590B08793B28B96B18B95AE8D95AE
8F96B18F97B58F98B88E97B78E98B68C96B18E97B08E95AE8F96AF9097B08F97AF8E98AF
8E97AF9198B09299B39399B59398B79299B9939AB9959CB8959AB79499B8969BB9969CB8
969EB7969EB498A0B49AA0B59A9FB699A0B999A1BA979FB6969EB398A0B199A0B09AA0B1
98A0B198A1B298A1B198A1B199A1B29BA3B69DA4B99CA3B69CA3B39CA2B29DA2B39FA2B5
9FA3B89EA3B99EA4BA9DA2BA9B9FB99A9FB99AA0BA979EB798A0B69AA1B69AA2B69CA2B8
9CA1B9999FB99AA1B99AA2B89AA1B49AA0B39DA1B49DA1B69C9FB59A9DB3989DB1999DB1
9DA1B39BA0B2989DB2959BB3969DB3959EAF959CAD959BAF939AB1949CB3939CB2929CB1
929BAF9199AE9098AE8F97AF8C96AE8A93A88A94A58B95A38D96A48C94A38C94A38B92A2
8990A18991A087909F88909F8990A0878FA1848FA1808D9D7F8D997D8B977F8D997F8B9A
808A9D80889E7E879E7C86A07A859E798499788294788094777F96747D96727E966E7D91
6C7E8B6B7C83697C7D687C77
606B856976926F7C9C727EA1707CA2717EA37481A27381A27583A57886A87785A67787A6
7889A6788AA67989A57A8AA57B8AA37D8AA57E8BA77E8BA87E8BA47F8BA2818DA4828DA6
838DA8828FA9818FA8808FA78392A88492A88492AA8592AC8691AC8993AC8993AA8B94AA
8D94AC8F95B08E94B28F95B38E95B28D93AF8F96AF8F96AF8F95AE9096AD9198AF9299AF
9097AD9196AE9297AF9297B29398B79198B99198B99399B7929AB59299B69298B5949AB6
969DB6969DB4969CB2989CB3989CB59599B6959BB6969DB4979EB1979DAE999DAF999DAF
989EB0979EAF969EAE979EAE969EAE979EB2969DB4969EB596A0B298A2B09BA2B09DA2B1
9EA2B49DA2B59EA2B79CA1B69BA0B5999FB4989FB5969CB4959DB3969EB4979DB4999DB5
9A9FB7989EB5989EB7989FB6969EB3979EB2999FB19A9FB39CA1B49A9EB3999DB2999CB0
9A9DB2999CB1999DB3979DB5969DB2959BAE9299AB949AAD9399AD9299B0939AB0929BAF
919AAD8F96AA8E96AA8E96AC8B94AB8992A58A94A38D94A28E94A08F94A08C92A18B92A0
8B92A18A919F88909D858D9A868D9C898FA0858DA0808A9D7F8A9B7D89987F8A987F8899
80889A81889C7F859D7C829D79809C79819B787F98777D96767C97757C97727D956E7C90
6A7B886A7C83697C7E687B78
636E896B7895707F9D7180A0727FA1717EA27380A4717EA27481A57685A77583A67685A7
7888A87A8AA97B8AA97A89A97B8BA77F8FA87F8DA77F8BA6808CA6818CA5818CA5818CA7
808CA7818DA7808DA7818FA88290A88391A98492AA8693AC8793AC8994AB8993A98C95AB
8D95AA8D95AA8C93AB8D94AD8D95AE8E96B08D94AF8E95B18D95AF8E97AE8F98AE9096AE
9096AE9197B09197B39197B49297B79299B9939ABA939AB9929AB99198B89198B6919AB5
959DB5969DB4969CB2979CB3979CB3949AB4959BB7959CB6969EB5979DB5989DB5999DB3
999FB1989FAF979FAE959CAC949CAC949DAF949CB2969FB4959FB398A1B399A0B29AA0B3
9C9FB39CA0B69DA0B79CA0B89CA3BA9BA2B99BA1B79BA0B69BA1B599A0B5979DB3979CB3
979DB4979EB5979EB6989FB7969DB6979EB59A9FB5989DB49A9FB5999DB49A9DB39C9DB3
9B9BB49B9BB5999BB6979CB4969CAE959CAD939AAB939BAB939BAC9299AC9097AC9098AC
8F97AC8F98AC8D97A98C96A98B96A98B94A58C93A38D93A28C919F8D92A18A91A1878F9E
87929D88919C878F9B858C9C848B9D858C9F868DA0828A9F828A9E80889D7F879C7F859B
80849D80839D7D829D7B819C7A809D79809C777E99757D99747D99747E98727D936C798B
6A7888697A8566787F647779
636D886977946D7C9B707F9F727F9F727FA1727FA2717EA27380A47481A37683A47B89A8
7B89A97B8AA97A89A87A89A97C8AA97F8DAB7F8DAB7E8AAA7F8BAA818CA9828DAA808CA9
818EAA818EAA828EA9838FA98390AA838FA98591AB8692AB8691AB8893AC8A95AD8994AA
8A95A98A94A98A93AA8A92AB8A91AC8B93AE8D94B08C94AF8C93AD8D94AE8D93AF8E93AE
8D94AE8F95B09197B39096B49095B39196B59298B79299B99198B99199B99299B8929AB7
949CB6969DB4959CB3939AB0959BB1949BB2949CB4959CB6969CB8969BB6969BB4979CB3
979DB1969CB0949BAD949BAC949DAE929BAF949CB298A0B698A0B7979FB7979EB5999FB5
9A9FB5999EB59A9EB79B9FB99BA0BB9BA1B99DA2B89DA1B49B9FB19B9FB19A9EB3999EB5
999EB5979DB5979DB5989EB8989DB8989DB6999DB7999CB7999CB7989AB5989AB3989AB2
9A9CB2999AB3979AB49599B0939AAB949BAD939BAF9199AD9099AC9099AC8F97AB8F97AB
8D95AA8B93A88D95AA8D96AA8D95A98D95A78D92A48B91A38A8FA2898EA1888FA1858E9F
858F9C848E9A858E9C858D9D838B9D828A9D838A9F81899E80889E80879E7E849D7D839D
7D829E7D829E7B809E797F9C777E9B757D99737C95707A91707B92727C92717B8F707A8C
6C77896A768766768263757B
636E876875926C7B9A6F7DA0717FA3727EA3707DA1717EA27481A47481A27683A27986A6
7A88A87989A67989A47B8AA57E8CA77F8CA97E8DAB7D8BAD7E8CAC7D8AA8808CA9818DAA
838FAB838EAB828EAB838EAB8390AC848FAB848FAB8691AE8692AE8691AD8590AB8693AB
8896AC8894AC8B94AD8A93AC8A93AC8B94AF8B93B08B93AD8C94AE8F95B08F94B19095B2
8F95B19197AF9298B09398B19397B19398B39298B59297B69196B69298B6939AB6949BB5
969DB6959CB59399B49298B2949AB2949BB2959BB4959BB5959BB7969BB4999DB2999CB1
989BB0979BB0969CB1949BAF959CB0939BAF949BB0969DB3979EB5979EB6989EB7999EB6
999DB5999DB5999DB6999BB6989CB5989DB3989DB1999DB0999DAF9C9FB39C9FB69B9EB7
9A9DB6989CB6999DB69A9EB7989CB4989CB4989BB5989AB6999CB4989CB3979BB2979BB1
989BB1969AB19498B09299AE9298AC9398AE9398B09197B08E96AE8E97AD8E97AB8E96AA
8F95A98D93AA8E94AD8C92AA8C91A88C92A68C91A6898EA4898EA4888EA4888DA4868DA3
858CA2828AA0838AA0848AA18488A08387A18288A28086A27E84A07C839D7D829D7C809B
7B7F9B7A7D9B797F9B787F99757C96747B94727B9270798E6F798D70788E6F778E6E778D
6A758B69748766748161727A
636F896975926D7B9B6F7CA0717DA3727DA4717BA2717DA27580A37782A37781A17985A4
7885A67887A67A89A57A8AA57C8CA67D8CA77D8CA97D8CAB7E8DAC7F8DA97F8EA6808EA4
8290A5828FA7838EAA848EAB848EAB8490AA838EA8848FA98690AC858FAA838EA88491AA
8693AB8995AC8C95AE8C95AF8B94AF8C96B28A93B08B94B08B95AE8D95AE8E94AF8F96B1
8F97B1929AB0939BAF939AAE9297AD9398B09197B29298B49198B49197B29299B29299B2
9399B19399B29196B29196B39096B39198B3949AB5939AB6949AB7959AB4979CB3969BB2
989CB3979CB3949AB2939AB0929BAE929CAD949DAE949CAF959DB3959CB4959CB4979DB5
969BB3959AB0979AB1999BB4989BB4979CB2969BAF979CAF989DB29A9DB3999CB49A9CB6
989BB5969BB3979CB2989DB2989CAF979CAF979BB19599B19599B0959AB0969BB0959AB1
969AB29499B29297B19197B09196AD9094AB9195AD8F95AF8C94AE8B94AB8A93A98B94A8
8B93A68D93A88D93AC8C91AB8B92AA868FA58890A38A8FA3888DA3898CA5888DA7878CA7
858CA6828AA180899F82899D82899F8287A18186A17F86A37C84A177809B7981997A8197
7A7F99797E99777D99767F9A727C97707A94707A936F79926F798F6D768E6B748E69728C
65718A657287647381607178
636E8667738F6D7B9A717EA1737EA3747DA3747BA2737AA1777EA27880A27880A27B85A6
7986A57986A47B89A57C8BA67C8BA67C8BA67C8CA57D8DA57F8EA77F8CA57E8CA27C8CA0
8190A1828FA1858FA3868EA4858DA58590A88590A9868FA98790A9868FA9868FAA8890AD
8991AF8890AE8C93AF8D94B28C95B28A93B08B93B18C94B18C95B28B94AF8B95AF8B95AF
8B96AD8E98AD9099AD9097AC9096AB9197AD9197AF9297B09198AF9197AD9399AF9297B0
9196AF9095AF9095B09095B18F94B18F95B19097B39097B49198B39298B19299B09399AF
9398AF959AB1949AB19298AF939AAD939CAC949DAC949CAE949CB1939AB2949BB3969BB3
959AB19699AE9699AF999CB4979AB2949AB0959BAF949AAB959AAC979BAF979AB0979AB4
9598B39398B0949AAF9499AB949AAA959BAA9499AB9397AD9296AE9296AF9396B09397B1
9297B29196B29094B19195AF9195AE9195AD9094AC8E94AB8C93AB8B93AA8A93A98A92A8
8990A5888FA68A91A88990A78A91A78891A48890A1898F9E888C9E898DA1878BA38589A4
8289A47F889E7D889C7D869A7E859A7E859B7D839C7D859F7B839E78829B778198757E95
767C96777C98757B98737A997079986E78956D75926B738F6C738F69708E676F8D666E8C
636F89626F876170825E6E76
666E8468718D6C769670799B737C9D757C9F7579A17578A1787CA3777EA27882A17A85A2
7A85A17A85A07B87A07C88A17D8AA47E8CA6808DA57E8CA27E8BA27D89A17E8AA27D8BA2
808EA3828FA2848FA0848DA1858DA5878EA98990AD8991AE8992AC8891AA888FAB898EAD
8D91B28C90B28A8EB08C91B08B92AC8890A98B91AB8C92AD8B91AF878EAC858EAA8490A9
8692A98892A68D95A88E94A98F95AA8E95A88E96A98F97AA9097A99097A99197A99296AA
9297AC9096AC9197AD9299AD9198AC9298AD9095AD8F96AF8F96AE8F96AB9096AA9095A8
9094A79296A99398AB9399AC9399AA9299A7939BA8939AAA9499AC9397AD9497AE9599AF
9497AE9597AE9698AE9699B09698AF9498AD949AAA9399A69397A69699AC9799AF9598AF
9599AF9598AD9498AB9497A99498A99499A99497A89294A89193AB9294AF9495B09395B0
9295B09396B09193AE9294AE9193AD9193AC9093AB8D92A88C92A68C93A98B92A8888EA4
898FA3888EA3888EA3888EA3888FA18A91A2898FA0878D9E888C9D898D9F888A9F8588A2
8386A38186A27E859E7C83997A82967C83967D82977C83987C8197797F97777E98757C95
757B95767C967379957177956F76956E76956C74926C73926B7392697190656D8A656D89
656E88626C845F6B7F5D6C77
696D816D728C737995757C9A777D9C777A9B76799E777AA17A7DA47B80A47C84A17C869F
7B839D7C849F7C86A07C869F7C89A27F8CA5818EA4808DA0808BA0828CA4828BA5808AA5
808CA6838FA58690A3878FA2878DA58A8EAA8B8FAE898FAE8990AC898FAA898EAA8B8FAD
8E92B08D91B18A8EAE898FAC8A91AB8C92A98B91A78B90A7898EA7888DA8858BA6838AA4
828BA082889C83879D8789A2888AA2878BA1858BA0868EA088919F89919E8C93A18E95A4
9197A88E95A68F97A7919AA9929AA9939BAA939AAB9399AE9096AB8F96A89198A89297A5
9397A59498A7969BAB9499AA9396A79498A69599A79498A89698AC9497AC9498AE9397AD
9296AC9497AD9698AE9799AF9899AF9597AD9497AA9599A99497A79698A89697A99596AA
9597AC9598AC9497AA9496A89597A99597A99497AA9193A99092A99294AA9192AA9092AA
9395AD9495AE9192AC9294AD9293AB9092A88F93A68F92A48F91A48C8FA38A8FA2898FA1
8B90A08C91A1898EA1878CA1878CA1878CA1868BA0858A9E868A9C898C9D88899C86869F
8585A18185A27E839F7B83987C84967D83957C81947E82977C80977B7E97797D97787D97
787C95777A927579927377937176956D73956970926A72916B748E6A738B677088676E87
676C86656A8361687D5D6775
696C8073768D777D97787E9A797D9A797C9A797B9B7B7C9E7C7FA17C80A27E84A07F859C
7F849A7F859C8288A18088A17F89A27F8DA1818EA0828E9F838D9E848DA1848CA38188A3
8089A2838CA1868FA1888FA1898EA38A8EA88B8EAB8A8EAB898EAB898EA9898EA88A8FA8
8D91AB8D91AD8C90AD8A90AA8C93A88E94A68E93A58D91A38B8FA48A8EA7898DA7868CA4
858BA084899C85869B85849C83819D81819C7D7F987D81967E83937F8492818594838796
848998828A98848D9B87919E8994A08D96A18F96A29098A59097A69098A69199A4929AA3
9299A39398A69598A8949BAA9298A79299A6949AA59498A49597A59598A89497AB9298AB
9196A99297AA9598AB9598AB9596AA9394AA9294A99295A79396A79597A89596A69494A6
9696AA9395A89295A79295A69497A89597A89697AB9396AB9092A79093A59194A79294A6
9394A69392A69292A89393A99193A69193A29093A18E90A08C8E9E8C8F9F898E9E898F9E
8A8F9C8C919C8C909C8B8D9E8A8BA086889F86899F868A9D878B9D888B9B87889A87879C
84839C80819E7E829D7B81977A81937B81937B80927D80957E80987C7E97787B93787C92
777B9078798E77798F75768F7374907072906B7090686E8C687188687185686E83696D82
65687F64677F64687C5D6271
6A6D8073788C767C93777B95787A94797B967A7C987B7D9A7B7E9C7D819D7F849E7F839A
7F849980859C8289A08189A0818AA0808C9F828D9D848E9C828C9C858D9E848CA1848CA1
848BA1878EA08990A0898FA2898FA48A8DA68B8DA78A8EA88A8EA8898EA7888DA68A8FA6
8E92A78C90A78C91AB8C91A98D94A88E94A48F94A38E91A28D90A38E91A68D92A68E92A6
8C91A48C8FA28B8CA08989A086839E84829D8181997E7F937D7F8F7E808D7E7F8D7C7D8E
7B7D8F787C8D777D8E787F8F777F8E7E8691858B95898F998D939D8E979E919A9E919A9D
90989E9198A39096A49299A59098A39099A39299A29399A09498A09699A49495A59194A4
9296A59397A79497A89698A89495A79393A79193A59094A39295A49296A39193A19293A3
9595A79294A69296A69397A69498A69395A69495A99497AB9093A68F93A59396A59395A3
9393A29291A19393A39192A290929F90939C8F929B8D919B8B8E9A8B909C888E9C898F9B
878E97898F968B90978A8E97898A9B87889D86869D86879B898B9C878998878897888799
8382977F7F987F829A7D81977A80937A80917C80917C7F927E80947C7E9277798D777A8E
77798D76768B75748A75758C72728B70718C6D718C686C87666E84676F82686E80696C7D
64667B64667A6367775F6571
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.392007 0.97619 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
2F3A1A2D3A1A2A391C2A38222A37292A382C2B382D2D39312C38322E3736303938303939
313A3A313B38303B38313D39333D39333D3A323C39333C3A333D3B333D39323C3A333E3C
343E3D36413E35403D35423E35413C36443B36433A37443C38463E39473F3B49413C4B42
3D4B423D4B443E4D463F4E47404F48404E48404E4941504A41504941504841504944534A
44534944544A44554C46574D44554B44544C46564E47574E47584E49594E4A5A4F4B5B4F
4B5C504C5D514D5E514C5C4E4C5D4F4D5D4F4B5D4F4D5E514D5E514D5E514B5C4F4B5C4E
4A5A4D4A5A4B4B5D4842553A15200E1018071016060B1003090D02080C02080C02070700
070600070600030300020300010200000200030400030400030300030300030200050203
0502060604060302050202040404020606010605010909030B0B050E0E080F110912130B
14150D15160D15170D14160D13130D10100A0E0D090B0B080C0C080C0C08090A06070803
060803060701050701030500030300020200010200020300030300050601070802050701
0405000606020A0A040F10080F11090F100A10110B0F110B0F100B0D100A0F130B0B0E09
01020001030002030001030000020001010001020000030000030100020500020900010D
01001002000C050407000100
404D45556756425147364041323842363B4A383F4A3B414D393E4D3C41533E44553E4656
414958434C5A45505C47525D48525D48515C48525C49525E49535F47525F47525F46525F
4853604954604954604B56624B55604E575F4C545D4E57604F59624D58624F5A63515B63
515B64515A67525C69545D6B555F6C555D6A565F6C58616E59636E5A646C5B656B5C666C
5D676E5E69715E6A725E6A705F6B705F6B72606D74616F74637175677477687579687578
66757B66757D68787D68797A697A796C7B7A6C7B7B6C7B7D6C7B7E6D7C7E6E7C7D6E7D7B
707E7B707F78707F776E7F725A685C59685A596759576357556154556054515C51363A38
3337353034322C312C292E28292D28282C29282B29272929262727252726242725131117
0F0C130E0D11090A0D07090A070906080A04090C050A0D04090C030A0D04090D060B0D06
0C0E060C0D060F11090F120A0F130B0F130B0F120C0E110D0E110C0E100A0C0E08090C05
090C03090C010B10020D11040E11060E12080E130A0D110A0D10090E10090E0F080C0E07
090B040A0B050B0E050E11080E11080D10070B0E06090C04080B040A0D05090C04060801
060902060902060803060804090C07080B0603050101050103050A030414020316040418
0807170C080B0B0803060701
32384A353C4E343A4F353950353951353952373C52383D52383D53393E55383D56394057
3B41583940573A40573B42583E455B3F465C41495C424A5C424B5D41495D40485E40495E
414B60444C60434B60424A5F454C5F464B5D464B5E474D624A4F654A4F664A50654B5064
4C51664C51684D526A4C52694D536B4D526B4E53694F546950556A505669525969535A6A
545B6C555C6F565D70565D6F575F6F585F705A62725B65735B65735F6876606978606A78
5F6A7A5E697B616C7A626E79646F7A656F7A66707B66717C66717C66727C68747D69747D
6B767D6C777B6D797B6E7C7C707E7E71807F71807D74827D75827E778280768280737F7F
73807F72807D72817A738178748077747F77758079747F7A737E7A707C76707F74393D40
1B1B211B1C1F1114140D110E0A0D090A0C04090C03090C02080B01060A00030600030400
040500040500040400050601050701040501060703070803060502060502070603060703
0608010609010F1308151A0B181D0E1A20101D23131C22131A20121C1F121C1E13181A10
14150C1111080E0F070C0D060B0D050A0B04070A02060900060800040600030400020400
020400030500030500050702090C060A0D06080B020305000304020505040506040D0F06
14160B191A0D16170B11120A
32384B33384F333853333952333952353B54353B53363C54363C53383E55383F56383E56
3B4358383F543940553A42553D45583E465B40485B414A5D424A5F424A5E43495E43495F
434A5F444B60444C61454C62464D62474D62484C63484D64484D654A4F664C51674E5166
4D51654F54674F54684E53674C54674E556950566A505669505669525A6A515A69535A69
545B6A565D6C565D6E575E6F575F6F5960705A62725C65755D65745F68755F6876616A78
616B79626C7A626C79646E7A676F7A68707B67707B66717B66707969737B6A747D69747E
6A757E6B787E6D797D6D7B7C6E7C7C6F7D7E707D7C717F7C727F7E727E7E727E7E727F7F
72807F74827E75827C75827C75817B75807B75807B77817E757F7E747F7B73827A464D50
20202920222517191A1012100E110A0C0E05080C02080C03090C03090D02050801030500
0304000305000403000504000505000908000C0B030B0A03080602060401080702070802
0607010508010D110614180A181C0D1C20111E23141F23151E22131E22111D20101A1C0E
16170B12130A0D0F080B0C05090B05090C05090C04090C02060A01040700040500030500
040700050801040601040600070A01070A010509000204000203000303000403000A0B00
11110514140913130911120B
353A4C353950343953353A53353B51363C52383D53393E55393E563A4056394055393F56
3B42563B41533A41543D44553F45573F465A40485B40475D42495E434A5E444A5F444860
434861434961444B62444B62464C63454C64474E65474D64484E63494E634B4F644D5064
4E52654F54664E53664E54664D54664E56674F556750556851566A52586B51596A525A6A
535B6A555C6B575E6D585E70585E715961725A63725C64735D65735F6874606974626B76
626C77626C78636D79667079666F79676F7A68707B67717B6670786871776A74786A7479
6B767B6B777D6C787D6D797C6F7B7C737E7E747F8075807F73807D73807C73807E73817F
72817E74817D75827D74827B77837D78837E78837F75807E757F7D747F7C73817A50585A
201F2C1E2026191B1D1314140E0F0D0C0D09090B06070904070A03080C02050900030600
0204000203000404000505000405000808000A09010A0903080704050602090A050A0B03
0A0D02090C010A0C020E10051517091A1C0C1E20111F22132024121F220F1E220F1C1F0E
17180B12150B0E120A0B0E07090B05090C05080B03090C03090C04090D02080A00060900
060900070901060801050700080B00070A00030700010300030300040200040100070600
0D0D0411100612130814150C
343A4B34384C353A50363A51373B50393D503C3F533C3F563B3F57393E56393F543B4054
3D42543E42543F435442465742455A42465D444A60434A60434A60434A60434A60434862
444861444A61454B62444B62464C63474D65484E66454D65474E64484D624A4E624C5064
4E52664E53664D53664F55654F556650556750556852576953586A52586A52596A545C6C
545B6C555C6C585E6F5860725960725961735B63735C64735D66745E68745F6973616B74
616C74626D76646F7864707865717966727B67727A68737A68737A6973786973766B7477
6C76786C77796C78796F7A78707B79727E7D737E7D74807E74817D74817D74837D72817C
72827B72817B72817B74847C77847D78837E78827E76807D76817B7580797480795F6866
2626331E20281C2022181B1A1114120C0F0D0A0C09090C05080B01070A00050800040700
040700030500030400030400040600080901090A020A0C050A0C06090C06090D060B0D03
0D12030D12020B0D010A0C01101406161A091B1F0E1E220F1F25121E23111D21101C1F10
1A1D0F161B1012170C0F13090D0F070B0E050B0E040B0E040A0E020B10020C1101090D01
070B01080A02060801040500060800060900030600010400010200010200010100030400
090C040F110611140712150A
343B49363D4C383E4F383D53383E533A3F523C3F513B3F543A4057393F563B41553C4253
3D44533F4554414755434A5943495E43465F444762454964464C65464B64454B63464B63
474C63474D64484F66464E65474E65484F66485067464F674951674951644B51624E5264
4F52664E53664F556650576750566851566953596A53596B54596C535A6C545A6C545B6D
555B6D575E6E585F6F596070585F705961725C63735D66745D66745E6875606B74626C74
616B73616B73626D7564707864707965717B66727A69737A6B757C6C757B6B75786B7678
6C77786D79786C79766E7C76707D79717E7D727F7E73807D72807D74817D75837E73827D
75837E74837E74827E76847F77827E78837E78827D76817C75807B75807B77827C68726F
2D2E3A24252F2022271F2021191B1811120F0B0D08070802050800070A00060A00040700
040701030500030500040601050701090A020A0C040B0F050C10050D11080D11080C1007
0E13060E13070C1006090C030D110712170B181E101B21121E25131F25151C21131B1F12
1B1F12191F11171D10161C1013180C0F14080B10040B10050A0F040C11040D12030B1002
0B0E030C0D03080A00040500050500060700050700040600020300000200000100000200
0608020C0F050F130812170B
343B4A353B4D363C4F363D50363D51393F523A4052393F533A40553A42583C44583E4557
3F47563F4856404856424A59444B5E43485E444660464865484C69484C68464B65484C64
484D63494F67484F69484F694850684950674A51684951684A51664B51644C52644F5365
51546851546851556751576851566852596A535B6C545B6E53596E535A6D545A6E545B6F
555C6F565E70575F6E585F6E5960705C62745D62745E64755E67765F6977626B79626C78
636D7864707A636E7965707B65717B65727C67737D69747E6D767F6D767D69747B6A767B
6C797A6C7A796E7C796E7D796F7E7B707F7D72807E77848076827F778380798481778380
79848179848178848079848077827F7A83807A837F78817D77817C76827C77847C717B75
3B3D4526263024252A2426261E1F1D17181311120C0B0D06080B02080C00080C00090D03
0B0E05080A04050702040603050603080A040A0D050A0D040C11050B0F050C0F060D1208
0E130A0F140B0F130A0C0F070B0D0611150B181E111C22141F25152026171E24161D2215
1E22131A2013161C1013190D10160B0F15090C11070B10060B11070D12080D11050B1002
0B0E020D0E02090B00060900050800050700040700040600030400010200000100010100
0608020C0F050E120810140A
333B4C353C50363D51353C51383F52383F50383F52393F543A41573B425A3C435A3E455A
3E46583D44563F465741485941495B42495E444962474A67484C69484D68464C67474D66
484E67495067484F694950694A50694A50654C51654B51644D52654C51654D52654E5366
4F546751566851576750576651576751586952586A51586B535A6C555B6C555A6D555A6E
555C6F575F70586071595F705B61715D62725E62745D64755E6776606978626B7A636D7A
626C7A636E7B65707B66717C65707B65717B67737C6B767D6D767E6D757C6A737C6B757C
6C767B6B787A6D7A7B6E7B7B6F7C7B71807E727F7E768380778481788381798381798380
79837F7A84807A83807A838078837F7A837F7A837F7C84807B847E78837C76827A788479
4C4E4F24222C26252923242320221E1D1E1715151010110A0C0F06080B03090C030C0F07
0E110A0C0E09090B080708070606060809070A0C080A0C060A0D06090C040A0D040D1107
0E130A10150C10130A0D0E06080A020D1006161C0F1C22142027172027182025181E2317
1D22141B2113171D1013170C10150A0E13090C10070B0F060A0F060B0F06080C030A0D02
090C000A0B00070800050600040600050700040600030400020300010200010200000200
0305000A0C020D10060E1209
353D4E363F50364050373F50373F503940513841533940563B435A3B425B3D435B3E455A
3F46583F4756414959424A5A424A5C444B5E464C62484D65494E65474D64464E64474F63
484F614951624A52654B53674D53694D52684E53674E52664F52664E52664D53664E5567
505668505668505667515867515867525968525A6B53596B555B6C575C6D585D6E595E71
595F715961735B63745C63745E65745F66745E65755D66755F6777616A78636C79636C78
636E7964707966717A67737B67737A67737B69747C6A767B6A757B6C757B6D767D6E767D
6D777D6C787B6D7B7A717E7A72807B75807E727F7F73807E77837F7883807A85817A8482
7B83817B83807B83817B83807B85807A847F7B857F7A847E7A847E79837C76817978847B
545A59231F2824232721212221221F20221B191A1212130C0F110B0E110B0C10090C0F0A
0D100B0D0F0A0C0D08090A060808050908040A0A070A0B08090C07080A040709020A0E06
0F140A12170D11150B0E10060B0B010E1005161B0E1A21131E25151F26171E24161D2416
1E24161C2215181D1114180D10140A0D12080C10070B10060A0E05080B030709020B0D04
090B000A0C00080900050600040600050700060900040600020400020300010300000200
030400090A010C10040C0F06
3740513740523841543841533941533B44553C44583B445A3C435C3D445D3E475D3F475B
3F495A414A5A404959424B5B444E5D464E5F474D60484E62484E61474F61475061485161
4952614952614A51634D52684E526C4F536D4F546C50546A5055695056694F5468505769
515869505666505765525967525A68535A6A555D6E575E6F585E6F575D6F5960705B6272
5D62735C63755C65765D65765E66735F69745E67755F6875606878626B78646D7965707A
65717966737867747867747868757869757A6A757B6B757C6D777E6D777D6E797D6F797E
6F7B7F707D7E707E7A72807873807A75817D74817E76837F7985807A84807B84817D8784
7E87857D85837E85837D85827C86817B857F7B867E7A857D7B867D7B867E79847B7A887E
606B6523212B2323282324262124221F231D1B1E1616181013140E11130D0F120C0E100A
0D0F080E0F080D0D05090B04080800090A020A0A040A0A06090A07070907060805090C08
0F140C12170E12160C0E10060A09010F0F0517190D1B20121D24161F2617212719202619
1F25191E25181A2015151A0F10150B0D11090B0E070A0D05080B03080A03070802080A02
070900080900060700040600040600040700050800060800040600030400020300000200
0507000C0D020E10040C0E05
373E52373F553840573941573941553A42563A42573C435A3E445D3F455E40485F404960
414A60434D60434D5F444E5E475060464F60474E60484F61485262485161485161485261
4B54644C55664D546750556A4F536C4F546E4F546D4F546C4F556A51576A505669505669
51586A515A6B535B6B555D6B545C6C555C6D575F6E575D6E585D6F585E70596172596272
5C63745D65765D66775E67785D66765D66745E67755F6875626A77646B7A646C7A646E7B
65717B6671796773796875786A767A6A757B6B747B6D767C6E767D6F787C6F797B727B7F
727D80717E7E73807E75817E74827E75817F7782807884817A85817A85807C86827D8783
7D86847C85827D85807F87837F89837F88817F89817F89807D887E7D877D78847B7A877C
6C786F2E2E36292A2F292E2C2229241A1F19161B1413140E12130D12120C11110A100F09
0F0E060F0F050B0B01080B01060900080B00080A02090C050A0C06090B07080A070B0E0A
10150C10140C0F13090F10060A0A010A09011618091D211220261721271822261921261A
1F25191E25191A201413190D0F13080C10060B0E050A0D050A0C04080A03070903070903
040600030500010300020400020500040600050700050700030500020500010300020200
0505000B0B021011060F1007
373D54383F563B42593A42593A42583C44563A41553C435840455D40465F404761414963
434C62454E63444E62454E61464F61464E61484F624A5164495364475062485162495162
4951644B53664E55684F546B4F536C4F536E4E546D4F556E4F566D50566A505769515769
52596C535B6E545C6E565E6F565D6E585D70595E72585D70595D705A5E725A60755A6175
5C64765D65775D66765F68765F67765F67755F6976606976626A78646B7C646C7D666F7E
67717D67717D69737D6A757D6A767D6A757C6C757B70777E71787F70787F707A80717C82
727D82737D80747F807782817682817782817982827A84837B85837A84827C86847C8684
7C86847D87847D86827E88837F8983808A837F8A837F89817E887F7E897E7B867C78847B
778478383A3E27282D2C312D2126201619151114100E110C0E100A0E100A0E10090D0F07
0B0C030A0C020A0C00080B00080C020B0E03090C030A0D040A0C04080B030709030B0C06
0E11081012070E10040C0D020908000908011518091C22131F25182027192026191F2418
1E24171E2416191E1112160B0D11060B0E040B0E040A0D040A0C04070A03060902070902
030500010300000200000100010200020300030500040600030400010300010200030300
0909020D0E05101108101209
3940523A41553B42583D435A3E455B3F465C3F465B3F465C41475D414860424A63414963
424A64444D64444D62444E61464F624851624952644C53654B5265495165485265495267
4953664C55694F566D50556F50546F505570515772525873535972535A70545B6D535A6C
535B6C555C6E575F70585F6F565D6F595F725B60755A60745A61735C61745D62765D6377
5F66785E66765D66755F6975616B76606A76626C78636D79646C7A676E7E687181687280
67717E68737E6A757F6B757E6C767F6E787F707A80727B83727B83737E84727D84727E85
727D83767F827780817881827882827982827983827B85847C85847C85857C86857E8887
7F8A877F8A857F89847F8A84808A84818B83808B82828C83828C83818B817E887E7C877D
7C897D45484B25242B292C2B242722191B171112110F0F0B0E0E090F0F090F10080D0E06
0A0B04090B04080A02070901090B030B0E050B0E060B0E05090B04070A02090B040B0D05
0B0E040B0E020A0D010A0C01090A000C0F03181C0D1D23142027172028192027191F2417
2024161F25161B1F1313170C0F12080B0F050B0E040A0C03080A02060903050701050800
020500020300020300020300010300010300030400050600040500020300010100030401
0C0F0510140A12170C10140B
3B43523C43553E445A40455C41455F41466041485F41495E414A5F434B5F434C62434C63
434C62424C5F434D5F454E5F4850614B53644C54654D54664C53664A53664B55694A546A
4B556B4C566C4F586F525970525972525870525A71525971535A72555C72555C71555C70
565E6F575E70596172586071575E705961745A62735961735A63735D65745E66755F6676
6066775F68775F6976606A76626D76626D77636D77646F7B656E7D68707F697183697283
6A74836C76826C77806D777E6E787F707980707B82707C83727E84747E83747E82747E83
757E837881827982827A83827A84837B84837C86847D87857E88877E88877D88877F8989
7F8B88808B877F89857F8A867F8A85808A85818B84838E86848E86838C84808A807D877D
808C7E54585727242D282A2D2629271D1F1C1515120F0F0B0C0D070D0E060E0F060C0C04
0A09030A08040A0904090902080A020A0C040C0E050B0D060A0D06080B050A0C060A0C06
090A04070A03090B030A0D030A0D01101206191D101F2317212618232819222719212518
2023161F24151B201215190D1014090E12070C10060B0D050A0C05080A04050802030500
010400020400020400030300000200010300040600050600030500030400020300030400
0E110814190D151A0E12160E
3B42533C43563F465A40475C41465D41475E41495F3F475F414860434C61444D62444D63
464F6247516248515F4A515F4D53624E54654E54664E55674D56684C55674C55684D566B
4E576B4F586C515A6C535C6E535B6F535B6F555C70555B70555B70555B6F565B70555C72
565D72565D72565E71575F715960725961725A61715A62715B63725C65745E6576606676
626778626878636B79626B78646E78656F7A656D7A666E7D6A707F6B70816C72846C7386
6F76876E75856F78836F79816E797E6F797F717B81727C82737E82767F83767F82767F84
767F867781847881847B85847B85847D87857F89877F89877F8A89808A897E8989808B8C
818D8B828C89838C88838C88838D89818C87818C86818C85848F85858E84838C817F887E
818C7F5E635E27242E28292E2427251B1F1A14171110130A0D10070C0F060D11070B0E05
0B0C04090803080703080A03090B03090B030A0C030A0C050A0D050A0D050A0D05090C06
080B06070A05080B03090C03080A020C0E05161B101D2216212619242819232719222518
2024162025151D2214191E1015190C0F14080C11060B0E040B0E050A0C05070903040601
030500020400030400040400020300030400040600040700020400020400020200030301
0F120914180E161A12151913
3C43533D45563F475941495C41485C434A5E42495F414863424963444C63464F63454F63
4750634A53634A53624D53624F55654F56665056684F57694F58694E58694F586950586A
51586B52596B535B6C545B6D545B6E555D6F555C6E565C6E575D6F5B5F715A5E72585E74
575E74565E72555E71575F705860705A62725C64735D65745E66755F6677616779626877
646979646A7A666C7B656C7B666E7B666F7B676F7C69707E6C71806C73836C72836D7585
717886707884717984727983727A80727B80747C80757D82777E83787F84777F85788189
78818A7982897B83897D86887C86857E87867F89877F8987808A88818B89808A8A838D8D
848E8D858E8C848D89848E88858E89848E89838D86838E84848F83848E83828C81818A7F
818C7E6870682F2C342F3032282A291D221E14191311160B0F12090C0F070B0E070A0D07
0B0D080B0D080B0D080A0D050A0D040A0D040A0D040B0E050B0D050B0E060B0F06090D05
080C05070B03080C03090E030A0D030B0F0512160C1A1E111F241623271824281923271A
2226172227162126161E2214181C0F13170A0E13070C10050B0E030A0D03090C02090A01
060800050500060500070600050500040300030300020400020400010200000100040502
13170B151B0E171C11151810
3B43533D465640495A41485B40475D41485E424A61424963434C65454E65475064485264
4952654A53654C54664D54654E57674E57674F58694F586A4F596A4F5A69515B69535B6A
535C6B545B6C555C6D565D6E565D6F565E70555B6F565C70575D705A5F725A5F72595E73
5960765962755963735961705A62705B64725D66745F6776616A77616B78616A78626B78
636B78656D79666E79656E7A666F7B66707C67717C68717C6B737F6E74826C74816D7781
707984737C85727B83747B82757C81757E80767E80777F817981847A8186798188788189
79818A7A838A7B848A7D868A7F8888818A88818B89818C88828C89838D8A838D8B838D8B
858F8D868F8C868F8B87918B87908A868F89868E87859085848F84838E82858F83838D81
828E80727B7137363C343639333736222423181A181316110E120B0C0F0A0B0D09080A08
0A0C090B0E0A0C0F090A0C05090B020B0D030D0E030D0F030D0E040B0D050A0E05090E04
0A0F040B10040E14040E1405111707101507101407171A0D1D2214212718222818222618
2126162025152128181F25171B2013161B0F11140A0D11060A0E02080C00090C000B0B01
090901070600070600080700060500040300030300020300020200010100000200020401
0D110613190B181D0F181C0D
3C45533E4856404959424A5E434B60434C60434C61444D61444E62465163475264495466
4A54664B56674E57694D57694E586B4E5A6B4E5A6A4F5A6A4F5A6A505A6B4F5A6A515B6A
525C6A535C6A535D6B565E6D575E6E585E70595F71595F72595F72596072595F72585E73
5960775A62765A63745A63715B63705D65715E6673606876616A77626A77626B78636A79
636A79656C7A666F7B666E7C67707D68717E69737E69747E6D757F6E757F6C757F6D7781
707A83737C85747C85757D85777E85787F857880847A82867B82877C838A7B828B7A828C
7B838D7C848B7C85897F8789818989828A89838C8A838D8A848F8B848E8B848E8B86908D
868F8D868D8B868E8B89908D89908C878F8B878F8A879089859188859085869184849083
8591817985783E3F4336393C353A381F2223191B1A1215130E110D0C0E0B0B0D0A090A09
0A0C090A0D090B0D060A0C030A0D020D0E020E0E030E0E020D0E010C0C010D0D020E1005
1115081117081016061015061015060F12040E0F0314150A1F21142327182227181F2516
1E25141D24132027151F26161B2214191D1014170B0F13080C10030B0F010A0E000B0D01
0A0C01090A00090800090900070800050600030400040500030400040300010200010300
0D0F0615180C181E0F181B0C
3E4753404958414B5A424B5E434B5F444D60444D60444E614650634852654853664A5568
4C57694D57694D58694E596C4F5A6C505C6C505C6B505A6A4F5A6B515C6E505B6E505B6C
525D6D535E6D54606E56606F576070585F70585F71585F725A62725961725A61745A6075
5B62775B63785B63775C64755D66755E6774606875606A76626B77616A78646D7A656C7A
646C7A636C7A666F7B67707C6A727D6B747D6B747C6C757B6E777C6E777D6E767F707782
717984737B87747C86747E85767F87767E88777F8879818A7A828B7B838D7B828D7B838D
7C858C7D878B7D878B80898C828B8E828C8E858E8F848D8E848E8F868F8F869090879191
86909086909186908F88918F88928D88938D88938C88938B87928C869389859187839085
8391847C8D7D3B3F422C2F332A2D2B1C1E1C1316120E110C0C0F090A0C070A0C07090B06
080A050A0D050A0C030C0E030E10020E0F020E0E020D0C020E0E010D0D020F0E03121206
1113090E11070B0E03090B01090B010B0B010E0E0317180C1E2013222516222517202416
1F24162024152226162026171B2213191F11161C0F11160A0E13060C11030C0F020C0F01
0A0C010B0D010B0C000A0C000A0C01080B01060900060800050700030400000200010200
0B0C0513150A15180C15170A
404755424A5B444D5F454E60454D61464E61464F614650624851644954654A55664C5668
4E596A4F596A515C6D515C6E515C6D515C6B505C6A515C6A525C6A535E6D535E70535F70
556172546071556070576171586272575F735961755B64745B64735B64745B64755B6475
5C65765D64765D64775C65775D6778606A78626C78626C78636C79636C7B656E7D666E7C
656F7C65717D67727C69737C6C757E6D757E6E767E70777E70797F727B82727A84727A83
737A84737B85747D87747E8676808878818977808978828A7A848B7B868B7B868B7B868B
7D888C7E8A8C7E8A8C818C8E838E90838D90869092858F92869091889191889292869192
86929388949387939187938F89958E8A968C89958A8A978B8A978C88958A869489849388
8494868091824248482325292023231518160F120D0D0F080C0E05080A01080A02090D03
090B010A0C020B0E020D10040E12051012041212061112061110050F0F040F1006101007
0F10080C0E07090B04070902090B030C0D0411120717190D1D2113212616232718222617
21251821261724291A252B1C2027191E24161B2214181F11151C0E141A0C151A0B111507
0E13050F12050E12040E12061116090F14070E13050D1204090D01050800020500020400
090B0312140715180B17180C
434A59444C5F464E63485066484F654951654751644953664B56674C58664D5967505B6A
535C6C535D6D545E6F535D6F535E6E535E6F535E6E545F6F555E6E555E6E565F71566173
5660755660735860735962735A62745A62745C63765D65775B64745B64735D66735C6573
5C65745E66765F66775E66795E677B606A7A626B78636C79636B79656B7D676D80686F81
6770816871816972816C74806E7580717881717781717883737A84747D85747C85747B84
767C85767C86767E89767E8879828A79848A78838979848A7B868B7E898C7D8A8B7D8A8C
808C8F818C8E808C8C828E8E848F8F85908F889491879290889290899291889290879292
8895928895918A95918A95908B96908A968E8A968C8B988D89978B899689899689879589
8696888698864F595326292A1D201E1417140F120C0C0E080A0C04090B020B0D040B0E04
0C0F040D0E040D0E040C0F050E11061014081112081213081113080E11070E11070D0F06
0B0D050B0E060A0D060A0D050B0D040D100410140714180B1B2012212716232817222817
212617232818232A19242C1A232A192027171D24161D24151D25141E25141E2413181D0E
14180912160812170A10160B14190E151B0E171C0F191E0F1115080B0C03060700040400
07070111130817180D181A0E
454C5D464E614852654953684952684B55694852654853664C58694D5A6A4F5B6A525D6D
545E6F555F6F566071546072546171556271556272556072566074576074586174576174
5560755760755A63765B64765C64755D64755E66765E67765C64735C65725B65705D6671
5F68745F68785F677B5F687D606B7E606C7C626D7B636E7A656F7C666E7F687082697184
6971826972816B74826C74826E7583707885717985727987727988757D88757D88767D88
767D88797F8B797F8E77808E78828D79858E79868C79858C7A878E7D8A917D8B907E8D91
808C90828D91828F918291938492938692928996948A95938995938A96938B97958B9696
8B96958A95958C96958F99958F99938E99928D9A928C9A908D9A8E8D9A8C8D9A8C8B988A
8897888A9B88606B612C2E301F2122171A191114120D110C0B0E070A0D040F11080F120B
10130C11130A1011081011081012080E11070E11071012071113080F12080E11080E1108
0C0F060B0E060B0E050B0E040D1204101405111607181D0E1D2213222716232817242917
2328182428172328162329172229162228162026141E26141F27151F28151F27151D2314
1C21121A1F11181E11171D0F191F0F1B21111E22132327171A1B0F1212090D0D050A0803
0707030D0F0813160C161A0F
464D614851654954694955694953684955684956684A56694B57694E5B6B515D6E525D6F
545F71566171566272556272556371566372556370556272566275556275566274566274
5561735762745864745A64735B65735C66745C66735C67715A656F5C68705C67705F6973
606A765F69785E68795F6A7C616C7F646F7F656F7E65707F65707E656E7F677182687385
6972846B74846C75866E76876F77886F78896F7A89707B89707B88727D88727D89757E8A
77808B777F8C77808F7882917783917985927986907A88907A87907C88917E8B927F8D92
808C92818E938290948191958392958593948794948895968996968B98968A97968A9696
8C98978C98978C97958D98948D99928E9A928D9A928D9C918C9A8E8C9A8C8C9B8D8C9A8B
8A98888B9A886E7B6E31343726282A1C20211618191213130F110C0D0F0716190F191C14
16191412151010130B0F12090E11080D10070D10061013061113061013070E12070E1208
0D12060B0F040B10030C1103111706141A09141909161A0B1A1E0F1E2212202515212717
2128172128162228162429172229182128152026142026151F26151E26131F27131E2614
222A172229161E25141E26121E25111E2310202514282D1C2225171B1C1213140C0E0D08
090B080B0D090E130A10150A
444D624650664752684955684955684A56684A56694A57694A58694D596B515D6E535F6F
546071556170566271556170556271576472576571586573576475576476566375566375
5763745863735963745A65755A65765A657559657459667258676F5A68705D68725F6975
5F68765E68785E6A7B5E6A7C606B7D626D7C636E7C666E80666F80666E806871836A7285
6A71846A73846C76866D76866E77876F798A6F7A8B707B8A707B87717E87727E88747E8A
76808C76808D77808F7881917884937986947986937B87927D89927E89907E8990808B92
828D93818F948292958393958494948694938794938895948B97968C98988A96978C9896
8B98958C9A968C9A958C99938C9A928C9A908D9A8F8C9A8E8C9A8E8E9C908F9D8E8F9B8C
8C99898D9B8A79867A3D41453033372327291D2022191B1C14161416181247523E252B22
1114121115120E120C0C0F080B0D060C0D060D0E050F11060E10060E11070D11070C1007
0B0F04090E020A10010F1606141B0A171D0C171C0C13160914160A1A1C0F1E23141F2617
1F26171F26162026172228192329192128162027152026142127162026172027141F2713
232B16242C18222A172028161F27131E26111E2412262D1B262B1B2025171B1E1214160C
0E110A0E120A0C1208090D04
444D614750664853694954694B566A4C56694B56684C57684D58684F5969535D6C55606F
556171546170566472576572566371566372566372576475576376576376576276566276
5864765964765863765A64795B647A5A647A5A657A5965795966775966745B66775D6777
5D67785E687A606A7C5F6A7C5F6B7C606D7C636F7E656E81677183687083697183697281
6972806A74826B75846D76856F788770798B707A8D707B8C727D8B73818975838B76828C
75808E76818F7682917884937885947A87947B88947B87927F8B91808B8F7F8B8F818D91
848F938491938593938794958794938995958995968996968C98988E999B8D999A8E9A98
8D99978D9B978E9C978E9C948F9C93909D93919D91909C91909D92929F92919D8F919D90
8E9C8F8C9B8C8290834B4F52383B402C2F33272B2C2528271C1F1E191C194A5843222A21
11151113171310140F0D110A0C0E090C0D060C0E040D10050D11060D11060C10050D1007
0B0E060A0D050A0E0312180A171D0F191E10151B0D0F140811140A171B101C21151F2518
2025192227192126182227192328192228172128162128162228162026172026161F2515
232A19252D1C222A1B1F27181E26161F28141E26112229142229171F27161E2615192011
13170C1013090D1107090D04
494F5E4B52644C556A4C566C4B556B4B556A4C56694C57674D5865515B68555E6C586270
566271556271566473586675576673566372566373586475596575586575576376576277
57637958647A58657A5A647A5B647B5B647C5B647D5C657D5C677C5D687A5E697C5E697B
5E697A5E6A7B606A7D5F697D626C7F626E81636F82647083667184677284687383687380
6B76806D77826E78856F79866F7A88717C8C717D8E737E8E737F8D74818B76838C77838D
7883917882937781947886957987947987927B89927C8A927E8C91808E91808D91818E92
848F938490938491938692948995958A96978B97998C999B8D999C8E999B8C999A8E9A9A
8F9C9A909D9A909E99909E96919E93929E91929E90919E90939F92939F92929E92919F92
909D908F9C8E8A9788585D5D3A3A4136363C2D2F322C3030262A291A1E1C20251F20261D
1C2319161A1211150C0E130B0D110B0C0F070A0D030B0F030C10040C11050B10040D1106
0C10060A0C05090B040D110714180C181C10181C1113160D10130C161A111B21151F2517
2126192128192027181F2617202717212817202716232918252A182329182126171E2417
22291B262E1E232C1B1F28181F2717202717202716242B172229172027172127181B2113
11160B0F13060D10030A0D02
4A525B4D54604F57684D566B4C566D4B566C4A55694B57684C5867505B69515D6B545F6D
55617054607156627557657957657A566479576578586577586577586578586477596578
59637959637A5964785B65765C66765C66795C657B5D667D5D667C5F677C5F687B60697A
60697A616A7B61697D626B7F636D81626D82636F83646F836570836772826973836A7481
6C76806E79826F7A82707B84717C87727C8B737D8D747E8E747D8E75808D76808E77818F
7A83937B84967984967986967B88957B88947C89947F8C95828E96838F95838E95828E94
8590968591958491948793968895978A97988B98998D999A8C989B8C99998C98988E9A99
8F9C9A919E9A929F9A919E99919D95929C92929E92939F9294A09393A09493A094919F91
8F9D8F8F9D8E8F9C8C6367633A363F39373F3030352D2F322C2F2D2024231C1F1D1C1F1B
1D221A191D1415181010130B1012090E10060B0F030C10030C10030B10030A0E030C1006
0B0F06090C040A0D040F120814190C181B0F1A1D11171A1011130D1518101E221623281A
2328192329192128181F27151F28162029162128152229182128182027171F26171F2517
22291B252C1C212A191F27161F25141F25161F24151F22151E22141E23142025161A2112
10150A0F14060D1103080A01
454E584A525E4E57674E566A4C566A4C576B4B576A4D5A6A4E596A4F596B505A6C535E6F
54617154607155617756627A57647D57657C58657B57637A56637957647A586578596578
5A65785B64795B63785C65755B66755C66775C66795C677A5E677B5E677B60697C626B7B
626B7C626A7E616A7F646D82646D82636E836470846772856872856973836B75836B7582
6C77816D78816C77816F7A85727C8A747C8D747D90757E92768092788193788093798295
7C84977C84987B84977C87977C87967D88967E8896808A97828C96828D95838F96849097
8691978793968794978995988996988A97988C98998E9B9B8D9A9A8D99998E9A9B8E9C9B
8E9C998F9C99909D99929D99939E98959F97949F9794A19693A09592A096929F94919E92
909F90909E8D909F8B717A6E4343453F3F433130362C2E312B2E2B2225221E1F1C20221E
2328201F251B191F1414160C1112080F10060C0E040C0F030C10030B10030C10040C1008
0C10080D10080F120911150B14180D16190E16190D14170C11130A16170D22261825291B
24291A232819212818202817202816212A17212916222A172028171E26161E26171F2618
20281A21291B1F27181D23131A2110191F0F181D0F171B0F15180D15180D151A0E151A0E
12160C0E12080B0F04070B01
464F594953604D5867505B6B505A6C4E596C4B576B4E596D4F5B6E525D70525E70536070
526070536171546273556274566477576578566578576578586577586678596679586578
5A657A5D667C5E667D5D657A5D66795D66785F68785F6979606B7B60697B60697D626A7E
636C7F636C80606A81636D84656F856571876772876973866A73856A73846D77856D7785
6D78866F79886F798A707A8C737C8E747D91757E94767F94757F94767F937881937A8294
7B83967C85957D85977F889880899A80899A818A98818C98838D98858E98859099869099
86919988949989969B8A96988A97998B98998D9A9B8F9D9D8E9D9D8E9D9D8E9C9D8E9D9D
909E9C909E9A919F9A939F9C949F9B95A09A95A09894A19892A09892A09790A095909F93
90A09191A08D93A38D798576494C4B4649473132342B2E2E2B302A252B2421251D262A20
272D2220261B171B1112150A1012071011060F11070D11060E13050D12040D12050E1308
0D110A0F130B12160C12160B13170B12160B12170A11160A1014091215091E2111222717
252919242A19252A19242A19222A19242B1A222918242A162429172127171F25181E2518
1C24171B22151A2113171D10141A0C12180A1115090F13090E11080D10080D12080F1409
11140B11130A0D1007080B03
47525E4955624C58684E596A4F5B6C4E5A6D4D586E4D596F4E5A70515D72505C72505C70
515E705261725160705462715563725664735866755967745A67745A66745B67775A6677
5A66795B667B5D667C5D667C5D677C5C677C5C677C5E6A7C5F6B7C616B7D616A7D616A7E
656E81646D83636C85646D85656F866672876872876872856B74856D77876F78886F7788
6F788971798B717A8D717A8D727B8F747D91767F92768093757E927780917882907A8491
7D85937E86957E8696818998818A99828A9A838A99848C99848E9987909A888F9A89919C
88929C88939D89949C8B959A8B979A8C999B8E9D9F8E9E9F8E9E9E8D9E9D8D9D9D8E9E9E
92A09F93A19E93A09D929F9C939F9C94A09D94A09B93A098919F9793A19992A29790A192
91A29190A18F92A2907F8D7E5155534D524E3233352A2C2C292C2A272B2623272021261E
24292022261F1D1F1818191014170C1213091213081012060C11040B10030C11040D1106
0D10080E11090F120A0F12090F130912160C14190D12170B1014091215091B1E0F222616
242818252A18262C17242B16242B17272D19242B182228162227152024151D2013191D12
161C10151B0F151A0E13180B10140910140A0F120A0D11090B0F090B0F080B0E070C0F07
0D11080E11080D1007090C04
4853604B57644D5A6A4E5A6C4E5A6D4E5B6E4E5C704E5A704F5B70505C71505C71515C70
505C6F526071525F705462715764725865735A67755966745966735C67745D68765C6777
5A66795A66795A667A5B667B5E687C5E687D5E687C5E6A7C5E6B7C5F6B7C626B7C636C7D
656F81646E82646F84646E856470866471876572876873866A73866C76886F7789707789
70798A71798A70798A717B8C737D8E757F907681917781917680917780917882917C8493
7D85937E86947F8895808A96808995828B97848C99838B99858D99868F99868F9889929B
89939C88939B89949A8B969B8D989D8E999E8E9B9F8D9B9E8E9C9E8E9D9D919F9E929F9E
93A09E95A09F94A09D939F9B939F9C94A09E94A19E929F9A919F9892A19991A19891A196
91A194909F9291A191808D81505452545D54323634262928252725242725232624242825
282F282B302823261E191B1414150F1010080F10050F10050D0E040B0E020C11030D1104
0E12070C0F0A0A0C090B0D090D100B11150F13181012170F0E130B0E1309171B0E1F2415
232818252A18252C16232B14242B15232C172129171E26161F26161F23151A1C1015180D
13170C13180B1116090E12060D10060E120910140D0C0F0C0A0D090A0D070A0C050A0D05
090C04090C030A0E04080B03
47535D4A56614C59684E5A6C4E5A6D4D5A6E4D5B6F4E5B704F5A71505C71525D71525D6F
535F6F53617053606F55636F5866725866745966755865765A65775C66795C66795B6679
5A677B5B677C59667B5A667A5D687B5F687D60697E626C80636E82646F82646E80656E81
646F82636F826270826370846471846470846672846873846A74846E76866F7788727A8B
727B8B707A8B707A8C727D8D737D8E777F9079819079818F7881907A83927B84937D8694
7E87957F8895808995818A96818A95818B95838D98848E9986909B86909A869099879199
88929A88949B8A969B8B979C8C979D8E999F8E999E8E9A9F909C9F909D9F93A0A094A1A0
94A09E95A09D96A29D96A39E96A29E96A29F95A29F929F9C93A09A94A29A95A39996A398
94A39692A29493A2928999864C504B4E564C393E39282A2A2527262B2E2B272A29272B2A
2B322C2B312823271F1B1D1815171110110A0D0F070E10070C0F040B0F040C10040C1004
0C10060B0E080A0D090A0D080E140B141A0F141B1112190F0E140A0D1309151B0F1C2315
212919232B19232B16242B15252C16242C17232B182129182028171C2213171C1014190D
10150B10150A0F14080D11080C0F060D11070E13090C0F090A0D06080C04070A01080B01
060A00050A00070C00070B00
47535C4956604C59654D5A6A4E5A6C4E5A6E4D5A6E4E5A714E5A734F5B74515C73515C71
536071556272535F6F54606F5663715865735865745764755864775A657A5C657B5B667A
5A657B5B667C5A667B5A657A5D667B5E677D616A7F636B80656D82656D81646D80646D80
656F82656F83636F83636F826472826471816773816974826B7682707A85727A87737A89
727B8B707A8C717C8F727D90737E90757F9077808F78818E7A84907D86927E85927C8492
7E8795808996818B97818B96818C96828C97838C99848E9A848F9B858F9B86919C87919C
87929B89949B8B979D8D989D8F9A9D919C9F919B9E939DA0939DA2929DA2929EA3939FA4
959FA196A0A1949FA095A1A095A2A097A3A097A3A094A19D95A19C96A19B96A29997A396
96A39494A29293A19092A38D575C5637393A3C413E303332282A2B2B2E2B292C2A242727
242926202521191E1A1518141418140F130F0E110B0E11090D11070D10060C10050D1107
0C10060C10070C10080B10080D130811180B131B0D12190B0F14080C1007181E111F2717
222A19242C1A252C1A262C19272D19242B17242C18222B171E27131A2210161D0F141A0D
0F14090C10080B10070C10080C10070C10060D11060B0E050A0D04080B02050800060900
040700020700020600010400
46515C4955604C59664C596A4E5A6D4E5A6E4D5A6E4E5B704F5B71515D73525D73515C71
525E71545F71545F7054606E56636F5663705764725865725864745A65795C667B5C657B
5C647A5C65785D66785D66785E677961697C616A7D61697C626C7D636D7D636C7C636C7C
646D7D646E7E656F816570836571836572806875806975816C77826F7A83727E87747D89
737C8B717C8B727D8D74808F75809075809077819077818E7A838F7D85917F8694808695
818796828B98828B98828B98828C97828C97838D99848E99858F9986909A87919B88929D
88939C8B959C8D979B919A9D919A9D919A9F939DA1939FA3949FA4949EA4949EA4949EA4
959EA397A0A3969FA2969FA297A2A297A2A096A29E97A39C97A39C97A39B96A29897A395
95A29394A29293A19095A5916770693130363C413F3537362C2D2C2B2E2B2A2D2B292B2B
282B2A1E2122181C1D14161413151011140C0E13090E13070D12040D10020C10020C0F02
0C0F030C10050D12070C11080B10070C12070E13080E12070C10050C1005192012212919
222B1A252E1C262D1C262C1B242919222918222A162029141C2411192010161D10151C0E
10160C0C11080A0F060C11080B10070B0F040B0F030A0D03070A02060801040700050800
040700030700010500000300
46515C4953624C57684B576C4D59704F5A714E5A704F5C72505D73525E72525D71535E71
555F73576374566172555F705762715863725763725865735865735B66765B66795C6679
5D667A5E67785F68776069785F6879616A7C626A7D616A7D636C7E646E7E646F7D646E7D
666F7E67707F6871806771836872846973826A75816C77836E7884707A86737D88747E88
757E89757E8976808E767F9078819078818F7882907883917A85927C85947D86967F8898
81889983899A838A99848C99848C99858D99868E9B878F9C88919D87929D88929C89949D
89949C8B979A8E999A919C9C919B9D919A9F929DA2919DA3939FA495A0A595A0A4969FA3
96A0A398A1A297A1A197A19F97A29F97A39E98A49D98A49C97A49B97A49B96A49996A398
96A39796A39694A39495A6956D786F3133383C4240383C3A3032313134322F32302F3430
2F34301C1F201B1D1D16181511110C1011080D10050C11030B10010C0F010D10030C0F04
0C0F060C0F080D120B0E120C0D120A0C11070C10070D11060D12051116081D2412232B18
252D1C252D1D252D1E242C1E222A1C232B1B222A181E26131A220F161D0E141B0E131A0E
12190E0F160D0D12090D13090C11070B0E040A0D040B0D04080A02050600030500060700
040700030600020500010300
49535F4B56664C576A4C586D4E5A70505C71505B72515C74515C74515D74525D74545D74
555E765760765661755861755962755862735A63755A64755A65765A66775A66775C6778
5E68795F6878606A79616B7A606A7B616A7E616B7E616C7F656F81646E7F666F7F677081
6972826971806872836972846973846A74846D76876F7989717A88717A87737D8A757F8A
757F8877818B78808F797F917A81927B82917B83917B84917C85937E86957F8899808999
838A9A848A9C848B9C848C9C848C9B858C9B888F9E89909F8A91A08A93A08C94A08B959D
8C979D8D979A8E999A929C9B939D9E959EA0949EA2929DA194A0A296A1A397A2A399A3A2
98A2A298A2A198A2A097A29E98A39E99A49E99A4A09AA4A099A49D99A49E99A49C97A39A
97A29997A39797A59498A895768277393B414148463C413E363A37393F38353A332E322B
3338301E1F1D1C1D1917181311130C0F12090E11060C10030C10020D11040D11060D1108
0E120C0E120D0D110C0E120C0F140B0E12080D11070E13060E13051217071C2411232B17
28301D28301F272E20252C20252D20222B1D21291A1E25161A2112151C0E12190C12180C
131A0E11180D0E140A0C11080C10070A0D04090C040A0C04080902060701060500060400
030400020500010400010300
49565F4C59644D59694F5A6E4E596F4F5A70505A70515C72525C72545E73556075545E75
545D76565E77575E775961775963765762745862745862755863755965775965785C6779
5D67795F6978606A795F697A606A7B606A7D616C7E626C7F656E82666F81677081687083
6971846972846972846872826A74836C76846F7987707A87717B89727C89727D8B727D8B
737E8A75808C777F8D7A80907C82907D84917D84917E86927D8691808995808998818A98
81899982899A818A9C838D9E838C9E838C9E868E9E89909D8A929D8B939C8C959D8D959C
8E979C8F999C90999C939C9E949D9F959E9F959E9F949D9E969FA096A0A097A2A297A2A2
97A2A198A2A098A3A099A4A199A4A099A49E9AA49F9AA49E99A39C9AA49B9CA79C9AA499
98A29798A39698A59297A7918391813F4346444A483A3F3D333732343A32343A302D3028
2E32291D1E191B1C1616171111130A0E11070E11050C10040C10030B10040B0E050C0F08
0D100C0E100C0C0D0A0D0F0A0E11090E13090D11050B10020B0E010C10031E2611232B16
272F1A272F1C252E1E242D1F262E20232B1D21291C1E2719192013141C1012190D0F150B
0F150C0D130B0D130A0B0F06080B03080A01080A01070901050600060700060700060600
030400010400010300000200
4A585C4E5B63505C6B505B6E505A70505A72515C73535D72535E70565F70565F71565F72
556074556075565F7758627957637956627855617557627757637758657958647A5B677C
5D697C5D69785E6B795E6B7B5D6A7B5E6B7C626E7E626D7F646D80677082687183677083
6871836972856972856A74856B75836D77826F79826F7A84717B87717C87717D89717D8A
727E8A737E8C76808F7981917B83917C84927C84917D868F7C878E7E8991808996808A99
808B9C818B9D808A9D828B9E848D9F858E9F86909D88929A8B959A8C95998B96998B9598
8E989C8F9A9C8E989A909B9D919D9E929E9E939E9D949E9D969F9F95A09F96A1A296A2A2
96A2A197A2A098A3A09BA6A19BA7A19BA6A09AA59F9AA59D99A59B98A39899A49899A497
98A49697A39698A49497A6928B9A88484B4C404544383D3B2D302D2A2D262B2F26292B23
2C2F251F211A1A1C1415180F11130A0F12070F11040E11040C10050B0E050A0D060B0E09
0D0F0C0E100D0E100B0F100C0E120B10150B1015070E14050E12040C0F031C230F232A16
262B18272E1A262E1D262E1F252E1F252E1F222C1D1E2618181F14131A1011180C10160C
0D12090C10070C1006090E04080C02080B00090C00080A00060800060800060800060801
040600030400010300010100
4A585D4D5A634F5B6A505B6F505A72505B74515B74525D72545F7055606F56616F55606F
5460715561725662765560775562795562775562755664765966795A667B5B677D5B687D
5D6A7B5C6A775E6C785E6A795E6A795F6B7A62707C62717D64717D687380687382687284
6872846871856974866975856974836D7883707984707986707B87727E89727E88737F89
75818C767F8D7981927B82947D84937D86947D85937D86927D87917D87917F89957F8997
7F8B9A818C9C818C9D838C9D848D9D878F9F89929F89939F8B949D8B959C8C969B8B969C
8C989D8D999E8D999D8E9B9D919F9F919FA093A1A094A19F95A2A095A1A293A0A295A2A3
96A4A298A5A299A6A29AA6A29BA7A19BA5A19CA7A39CA8A19BA69E9AA59C9AA69A9AA699
9AA79897A39698A39598A49495A491535756393A3E393D3D2B2D2D252924262A22232620
23261F20231C1C1F17181B1215180F16170D15170B1315090E12070C10070C10080C0F0A
0E110D0F130D10130D11130D12160F12170F11160B1015091115081114051417071D2010
202513242A17272F1B272F1D272F1E252F1E242E1D212B1B1C2416181F12141A0F10160B
0D10070C0F060C10060D11060B0F040B0E030B0F030A0D02070901050701050601070A03
070A02050700030400020200
4B59614D5B64505C6A515C6E525C72525D74515B73525D73525D72546071556371556271
5563725564725765755763765865785664755664725765735966745B68775C697B5E697D
606B7E606C7C606D7A606C78626C7A646F7C65727E67737E67747F677381677383687383
6873846872846A74846A74856B74856E7887727B89737B89747D89747F8B737E8B75808B
78828C78818D7A818F7C83927C84927D85937C85937D86957D87957C87947F88967F8996
808B98838D9C848E9C838D9A86909C88909E8B93A28C94A48C95A38C96A18C979F8D98A1
8C989F8E9A9F8F9B9E909C9E929F9F93A1A095A2A195A2A095A3A196A3A397A2A397A4A4
98A5A398A5A19AA7A19AA6A09BA7A09BA6A09CA7A09CA8A09CA89E9DA89D9DA89B9CA79A
9BA79999A59699A49699A49697A493585A5A3D3D42393C3D2D3031282B2A262A28242824
1F231E1F241B1F261A1D23171B20151D20131A1D0E15180B1014090E12080D11080B0F07
0C100A0F120D11151013171113170F11160C0F140A0E12070C11030C10020C0D011C2010
222716252A18272F1928301A27301A26301B262F1D252E1D2028181B2113171D1211160C
0E12090D11070D12070E13080E12070E11070E11070B0E05070902060801050601060802
070A03050701020400010200
4A56644D5968505C6D515C6E515B71535D74535D75556078545F77535E75546173556372
5563725665735967765966775865775865755966755A67755A68765B69775C697A5E6A7E
606A7F606C7E616D7D626E7B646F7D66717F66717E66727F677281667182667182687382
6975826A75836B77846C76866D76876E7789717A8B737B8B757C8B747D8C747E8D75818D
77828B78828B79828C7A838E7B85907B84917C85937D88957E88957F8796818999828B9A
828B9A848D9C848E9C858F9B87919C88919D8A929E8B94A08B95A18C96A18C98A18D99A1
8D98A18F9AA2909CA1919D9F939F9F95A1A196A1A297A2A397A3A498A4A499A5A49AA7A5
9AA7A499A6A29AA79F9BA89E9BA99F9CA8A09EA99F9EAA9D9EAA9B9CA9999BA7999AA899
99A7989AA7979AA7979AA6969AA7956163603B393F39373A2C2B2D262627232426252A29
1D211F242A21272D2120261A1D22161C1F13181A0D15170B1214091113090E10070C0E06
0C0F080D110A10140E11160F11160D0E12080B0F06080C02070A010709000A0A011E2210
242916272D18272E1828301828311926301927311B27301C232B191F25151A1F1112170C
10140A0F14090E13080D12060D11060C10060D10060B0D04090B03070902050700040601
040600030500020300010300
4A55674D586B515C70525D72525C74525D74545F75556077546076556077566276576474
5665755765765866765966775967775B68785B69785B68785C697A5D6A7C5D6A7C5F6B7D
626D7E636E7F636D80666F816771806973816873816872826872836973846B75856B7586
6A75856B77856E79866D77876E79896F7A8B707A8D727B8C757E8D747F8E768190768291
7682907884917885917985907A85917A87927C89927D8B927F8C95828D97828C99848D9A
838C9A848D9B848D9C858F9D88919F8A94A18B94A08A949E8B96A08E97A28E98A18D99A0
8F9AA1919BA3929DA3939FA296A1A298A3A39AA4A598A2A599A3A59AA5A69CA8A59BA8A4
9DAAA59CA9A49BA8A19AA7A09CA8A29FA9A39EA8A09EA99F9EAB9D9DAA9A9DAB9A9BA999
99A79899A7989AA89899A6969CAA987781763A383C3734372C2A2C2624262323252F3331
2528282527242528231E1F1B22251E23261D1E2116191B0F14150A1213090F11080D0F07
0C0F070D12080D12080D12080E13090F12090D1108090C030608010607000B0C031D2210
252B17292F1C2B311D2B321C2B331D28311C262F1A262F1A242C192026171C2214191E12
14190E11160B10150A1015091115090E12070D10060C0F050C0D040B0E04080A03070A02
060801040600030400030400
4B586A4F5B6E525E74535F74535E75515D73515D71536072546072566274586575576476
5765785663765765765867775867785B687A5967785A68785C697A5C697C5E6B7D606D7D
616D7C646F7E65708066708166718066717F6872816973846972846973856A74866A7586
6B75876B75876C76896E798A6F798A70798D727B8F737C8E757E8E747F8F737F8F758091
7682937884937885937885927A86927C89937C89927C8A92808D94808D94808B96838D99
838D9A838D9D86909F87909E8892A08994A08A959F8A959F8C97A18D98A18F98A09099A0
929CA2929CA2939CA2959EA496A0A397A1A298A2A398A3A39AA5A49AA5A49DA8A69CA8A4
9CA8A49DA9A69CA8A59BA7A59DA9A69EA9A59EAAA39EAAA19FABA09EAA9E9EAB9C9CA99A
9BA89A9BA89A9BA89A99A99799A9988594843D3F403232352D2E2E2827272223222A2C2A
2A2D2C2424262123241F2021414A3D30362B1F21181C1F1316180C1314081113080F1208
0C10050D11050D12070D10080D11090F130A0C1008080B030608010507000B0E051D2412
232A16272F1929321C2A341C2A341C28311B242D17222A151F26141C22131D22131C2114
1B1F12181D1114180D12160B13150A1114081014080F12080D10050A0E020A0E030B0E05
0B0F05080A02060601050501
4C59674F5B6D525F73525E73525F75525E72525E71515E6F525F6F546170556271556473
55647656647656667755657958677A58657A59667A5B69795C697A5C697C5F6B7E5F6B7B
626E7C64707D65717E646F7E66717F6872816873806A75816B75836A74836A7485697484
6A75856B76866C77886E788A6E78896E778970798C727C8D727D8F737F8F748090768291
7783927783937783937986937B87947E89947E89947E8994818B96808B967F8B98818B9A
828B9B848D9D878F9F89909E88909D88919F89929F8C95A28C96A18D97A28E97A19097A2
9199A2939BA1939BA0949CA2979EA5969FA498A1A397A2A297A2A299A4A49CA6A69DA7A7
9DA8A69DA8A79EA9A89CA8A79CA7A69EA9A59EA9A49FA9A3A0ABA29FAAA09EAA9E9DA99C
9CA79B9CA89C9BA99C97A69797A8978A99883F41412F30312E2F2F2A2B2A262825272925
2A2D292224231D21203239323A44372B32251D20151A1D1114160A121307121408101508
0D12050C11060C10070B10080C10080C10070A0D050609010809010608000A0E041C2311
1F2714242E1927311C28321B29321A29311A262E172127101E230F1B1F0F1D2012202315
1E21141D20131C1F131A1C1016170C13130912130916190C151A0A111606131808141A0B
1217090D12060A0C04050601
4D58664F5A6D525F7453607654617655627554617253616F53616F54636F556371556374
5564765665785766795766785967785A67785A68795C6A795D6A795E6B7C606C7D616D7B
626E7C626F7B636F7C636F7D65717F6771826974836B76826A76836A74836B75846A7584
6774836A77866B78886D79896F7A8A707A8B6F798B717C8F737E91737F91758191758291
7783927885937884937984937C86947E87957F8996818A98818A99808A997F8A9A80899B
818A9C848C9C878E9D888F9D89919D8B929E8B939E8D959F8E96A08F97A19098A2929AA2
9199A1949CA0949EA0969FA297A0A397A1A398A1A498A3A398A4A59CA7A89CA6A79CA6A7
9DA7A79EA9A89EA9A79DA8A59DA8A69EA9A39FA8A39FA7A2A1A9A1A1AAA0A0AAA19FA89E
9EA89C9DA99C9CAB9B97A89797AA978E9F8C454A46373B37373B3530332F2A2C27272A24
2D312922241F1D1E1A3A42333C4533343C282226151B1C0D1514091111071114090E1207
0D11050C11050B11070B0F060B0E060A0E05080A03070701080800080800070801191D0C
222916262E1C28311E28311C2B341C2B331B272E192429142226121E21101F2213232617
25281A242919252B1A2326171F201419190F16170D2024152529182125152126121E2511
1D2310171D0C0F1306060901
4D58674F5A6E535E7454607754627755627553607253616F53616E54636F556472546273
5664755967785A687A5967785967765B69765C69755D6A775E6A775D6A785E6A79606C79
616E79616E7A636F7B65717C67727E6873816872836974856A75866975866A7586697687
6876886A78896A78896D7A8A6E7A896F7A8A707A8B707B8E727D8F737F9074808F768291
7883947985947987957984947C87967E8A977F8A97808A99818C9B808B9C7F8B9C808B9C
818B9C848C9D878E9F878F9F88909E89909D8C939F8D959E8F979F9098A19199A2929AA2
9199A1949CA4959EA5949FA595A0A596A2A499A4A698A3A699A4A79AA6A79CA7A69DA8A7
9EA7A89FA9A99EAAA89DA8A59EA9A59FA9A4A0AAA49FA9A3A0A9A3A1ABA2A1AAA39FA8A1
9FA9A09EA99D9CAA9B99AA9A97A89794A691525852353737373A362E2F2C2425221E1F1C
31352B2A2E2320221922251A434D344753351E200F1D1E0F18170C14140B13140A111309
0E12050E12050C11060B0D050A0D050A0C04080902080600080600080701060600181C0F
232917282F1C29321E29331D2A321A293219252E16222A152129141E2313212515252A19
282D1D2A301F2B321F2C321F292D1D25291A2125192830203038242E342129301B282D18
262B16212714161A0C070801
4B58654E5A6B525E72536074546075546174535F71525F6F52626F526271566474566577
57657959677B5A687A5A677A5B68795B67765C68755E6877606A795F6C7B5E6C7B5F6D7B
616F7B61707B63707C67727F69738168738167728468728568738668738769758869768A
6A778C6D798D6D798D6E7A8E707C8D707C8C707C8C717D8D717E8E737F8F74808F768190
7982917A83927A86937A85947C86967E88977F8B987F8B98808A9B818B9C818C9B828D9B
848D9C858E9E848E9F858FA08791A18992A18C95A28E96A18F96A19198A3929AA3939BA2
939BA3949DA5959DA6949EA695A0A897A3A897A4A897A4A997A3AA99A5A89BA6A89DA8A8
9FAAA9A1ABABA0AAA9A0AAA8A1A9A5A0A9A4A0AAA6A0AAA7A0AAA7A1ABA5A1ABA49FAAA2
9FAAA19EAB9E9EAB9B9BAA9999A99799AB9760696235373A33363828282920211E181615
292D233136282D322322241839402B5260402022151D1E1219181014150D14140C12130A
1012071013060E12070E11070D0F050A0B030A0A030C0A030D0C030C0B04080902171B0D
232815292F1A2B311C2A311B272F18252F16212A111C251019210E1A2110202716252C1B
2A2F1F2C33212E36223139242E36212C341F2E3521313A2638402C363D282E351F2A2F1A
282C18272B181D2111101106
4D5A65505D6A52606E546171556074566175556173546171566472576674586577586679
58667A5A67795A687A5C697A5B68795B67785D68785F687B616A7C616B7D616B7D616D7F
636F7F62707E65718067718168738267738267748467738568728769728969748A69748B
6C768D6E778E6E788E707A8F707A8D707B8C717C8C727E8E747F8F758190768290778390
79828F7B858F7E87917E87917E87937E8795818A97828A99838B9B848C9A868F9B868E9C
868F9D86909F86909F86909F8892A28993A48C95A68E96A68F96A59098A39199A2929AA1
939CA2949DA3959DA4959EA5969FA797A2A998A5A898A4A79AA6A99DA9AA9DA8A79EAAA7
9FABA8A0ABA8A0AAA5A0AAA5A1AAA3A1ABA3A0AAA3A0AAA5A1ABA6A2ACA5A0ABA39EAAA1
9EAA9F9EAB9E9EAC9C9CAB9A9AAA989AAB9869736C37383E3032352224241E201D171813
1F2217272A1D2E342325291B4750398DA679343B2A12120C18191213130C111009101007
12120811130711140714160914160811130811120816180B191D0E16190B1214061F2311
272C172A30192A3019262B152228131F28111B220D181F0C171D0B1E2412272E1B293020
2B32212D34223037243139242F36212F3621323923343925363D28343B272F35202A301C
272B19292D19272B181C1F0F
4A58624E5C67525F6E546073566177566178556076546074566273586574596575596676
5A677A5B687C5B697C5C6A7B5E6A785D69785D687A5F697E60697E626B80616A80626D83
636E83646F836470826571816773816674836674846774866773876974896B758B6B758C
6C758C6E778C6E778C6F788D6F7A8D707B8C717B8B717C8C747E8E758091758291758090
7782907984917A84917C86927D87957F8997808A98828B9A838B9A848D9B858E9B848D9B
848E9C8490A08490A084909F8793A18A94A38D96A68D95A68F97A69199A6919AA58F9AA3
919DA4929EA4949FA4949FA5959EA695A0A696A2A698A4A69AA6A89BA7A99CA8A89EAAA7
9EACA79EACA79EACA69FACA4A1ADA4A0ACA39FACA2A0ABA3A3ACA5A4ADA5A1ACA49FACA3
9FABA19FACA09FAC9F9EAB9E9CAA9C9DAC9B76817738383D333635272B2820241E1D1F17
1C1C121D1F13373F2A3F49324C593E95B18144513A10110A1B1E1215150A111204121204
13130512130614160915170A191B0C191B0E18190E222816242C18212915202612272D19
2A311C282F1A242A141E240E1B210D1D240F1E25111F2510222713272C192B2F1D2C3120
2C32222F3625323826313925303723303623323824343926383E29363D293137252D3322
292F1E272F1C282E1B242817
4C58654F5C6B525F71545F76545F77555F77545E76555F76576276586477586477596578
5A667A5C697C5D697D5D6A7C5E6B7B5C69795C687A5E697E5F697E606A7F626C81636E82
636E83636F84636F836371826471816573826775856775886673866774876975896D778A
6E788A6D778B6E778D6F788E707A8D717C8D727D8C727E8B74808D768190768292758191
76828F7884907985937A85957C87987D88987F8A997F8A9A818B9B838E9C838D9C838E9C
828E9D828F9E83909F8491A18693A38995A48B95A58D96A58F98A58F99A48F99A38D99A3
909CA4919EA4939FA494A0A594A0A695A1A796A1A897A3AA9BA6AD9CA6AD9CA8A99DA8A8
9EABA99EACA99DABA79EABA7A1ACA5A1ACA3A1ACA2A2ADA3A4AEA4A4AEA3A3ADA4A1ACA6
A0ABA59FABA39FAAA2A0AAA09EA99E9EAC9E7D877E3D3C4238393A28292822241F1E2018
1C1D111F20134B573C536043525F43859F7246523817190C1E1E10191808151504171706
20211027291A1B1C121B1D13232719232A1A202716262E1A29311B28311A2A321D2B341D
2A331E28301B2229141C230E1E2610232C15262F172A321A2C331C2D33202D32202D3221
2F352632382A333929353C29333927303624323725383E2B3E45303A422C353C292F3526
2A3022272D1E262C1B25291A
4E5969505C6D536073535F75545F75525D74545E75556076566277586578576478596579
5B667B5C687C5C697D5E6A7F5E6B7E5C697C5B677C5D687D5E697E606B7F616C80636F81
646F816370826472846573836573836572826673836874856775856774846873866C7789
6F7A8B6F798C6F798E707A8D717B8D717B8D727E8D727E8D74808F768290788492788392
78838F7985917A87957C87967E88997E899B808A9B818B9B818B9B828D9B828D9C838E9F
83909F83909E85919F8793A38894A58A94A58C96A69098A89099A6919AA6919AA6929DA6
919EA392A0A193A0A394A0A395A1A497A3A798A3A999A3AA9BA5AD9EA7AF9EA8AC9FAAAA
A0ABAAA0ABA99FAAA8A0ABA8A1ACA5A1ABA3A2ACA3A3ACA3A2ACA3A2ACA2A3ADA2A2ACA4
A2ACA6A1AAA4A1AAA2A1ABA19FAA9FA0ADA0828981403E4638383C2D2D2D2122211E1F1B
1A1A132A2D1F5967485360424B563B6374504F593A42472B32321C282612211E0D363824
545C434F58421F20182022192B30232B32222A32202A311E2C331E2C341F2D36202B351E
2A321D2D361F2D351D29301929311A2A331C2B331C2E361E2E35202E34222D32212E3422
303625333928343B29373E2A363C28363B27353B263E4730404A3238422B333D282C3523
262D1E242A1C24281B222518
4E586A505C70525F74525E73535E74535D75545E77566179556177576378586479586579
59657A5B677C5C687B5A677A5C697B5D6B7C5D6A7C5D6A7D5E6A7E5E6A7F5D6A7E616E80
636F806470806472816572816673836774836774836873836775846975866B76886D7789
6E78896F788A70798B707A8A707B8B717C8D727D8E737E90737E91768194778293798592
7884907A86917B87957D87957F8897808A9A818A9C838B9E838B9E828B9D838D9E838D9F
8490A18491A08693A18995A38B95A68B95A68E97A89097A89299A8929AA7929AA5939CA4
949FA394A1A195A2A197A3A299A4A598A2A599A3A89BA5AA9CA6AB9DA6AD9EA8AD9FABAB
A1ABA9A2ABA9A2ABA9A2ABA8A1ACA7A0ABA5A0ABA5A1ABA4A3ACA6A2ACA5A3ACA4A2ACA4
A3ACA4A1AAA19FAAA09FAAA19DAA9F9DAA9B8D988B47484C38393D2E30312325241C1D1B
161613363D2C5665485462464D5A3F434D354B553A63704C5D644455583C3D392A828E6E
8899794B52432D2F2627281F2E32252F34252F35242C33232B33232C35242F39252F3A25
2E3823303A213039202D341D2C321B2D341D2D341C2C331C2D341E2D33202D32212D3221
2E3423313826333928343B28363D29363D28363C274149323E4730353E28323C262A3320
242C1B24291B25281D22241B
4C5768505C6E535E73525D74545E76565D77565E78576079586278586477586577596576
5966775C697A5D6A795C6A785D6B795C6A795C697A5E6B7D5E6B7E5E6B7F5F6C81606C81
616E82626E8164708266718367718367728568748667738568758769768A6B778A6D788A
6D778A6E788A707A8A707A8B707A8D727C90727D91758093767F92788193798392798590
79848E7A85907B85947E87977E8899818B9D818A9C828B9D838D9E848D9E838D9E858E9F
858FA08591A18694A38794A38995A38B97A68F98A79099A6929AA7949BA7949DA6959FA6
949FA594A0A195A2A197A2A299A4A599A3A69AA4A89CA6AA9DA7AC9DA7ADA0A8AEA0A9AC
A1ABACA1ABACA1ABAAA1ACAAA1ACAA9FACA89FABA6A1ADA7A2ACA8A2ABA8A3ABA9A2ACA7
A1ACA5A0ACA39FACA19EAAA09DAA9E9EAC9B93A18F4E4F503A3A3D2E30311F2021171918
111211333B2D5360475361484E5D4446533C57654A6A7B5B707E5D8C9B735C5F4AB4CA9E
88987B42473C3C4134373A2C37392A363A29353C2A343C2A3039272D37262E39272D3826
2E3824313B25303A232E36202C321B2D341C2B321B2A2F1B2D331F2E33212E33212D3222
2E3525303727333C2A353E2B363E2B363F2A363E283E472E3C452D353D27313A2529331F
242C1B23291924281B24261C
4C5967505C6D535F755360775561785660785660765760755964755A6776586675596776
5B68775C6B785D6C7A5C6C7A5C6C795B6A785C6A795F6D7E606C7F5F6B80606C81606C82
616D85616D846470846571846671846672866673876875866875866975876C778B6E788D
6E788D6E798C707A8C717B8E717B90737C93747E947681947781937883927A85937A8591
7B86917B85927E87977E879A7D889B7E8A9C818B9B828B9C838C9E858EA0868FA1878FA1
868FA2858FA38591A38693A48895A48996A48E99A7919AA6929BA4939CA5949FA895A0A9
95A0A894A1A694A1A495A1A498A3A69BA5A99CA6AC9DA7AD9FAAAEA0AAAEA2A9AEA1A9AC
A2AAACA2ABABA1ACABA1ADAAA1ADA9A2AEA8A1ADA8A1AEA8A1ADA8A1ACA8A2ABA7A3ADA6
A2ADA4A3AEA3A2ADA0A1AC9F9FAD9F9FAE9D98A7935154533535382F2F302526251F2120
1817182F332B4E5946525E4A505B47434C3B535F4969785C69765BA1B89086957ABDD8AD
727F6749503E424835373A29343525333525353927343C282F37242C36242D37262D3725
2F3824313B26323C272F38232D33202D3320292F1C272D1B2A301F2D34212F36232E3524
313828333A29353F2A36402B343F2A36402A3540293E492D374025323B212D361E29321C
272E1A272D19262B19272A1C
4C5867505D6D53617453607755617954607755607556617758657959677A5867795A687A
5A68775B69775B6B775B6A7A5B6B7A5B6A7A5B69795D6A7B5F6C7D5F6C7F5F6B7F5E6980
616C84616C856370876471866673866573856573856774836775826975836B76876E7789
6D78896E7B8C6F7C8D707C8E727C8F737D91757F94768192768291788492798591798691
7B88917B88937D88977F899A7F899B808A9D828B9D838B9E838BA0868EA2868FA2868FA2
8691A38590A28592A28695A38897A38998A28C99A3909BA5919CA3939DA4949EA7959FA9
96A1A996A2A795A2A695A2A796A3A899A6AB9BA7AD9CA8AE9DAAAE9FAAAD9EA8AA9EA9A9
A1AAAAA1AAAAA2ACAAA4AEABA4AFABA4AEABA3AEABA2ADA9A1ADA9A2AEA8A3ADA6A5AEA5
A4AFA3A3ADA2A3AD9EA3AE9FA1AC9F9FAD9E9BAA9B595D5E2F2C37312F3428272B212123
1C1B1D2E2F2B535C4C586151474C4230312B3C3F336773595E68539DB18DACC29DAAC29B
59644E383E2C3438252525172525182A2C1F2E32232D32232A2F20282E202A32222C3522
303923323C24323B252F37232D35222B332028301E272F1E28311F2B34202D36222E3623
313825353C29363D2A363D2B353D2A343C28333D283B452D343F27303A222C351C28321A
262E18252C16252A16262A19
4E5B67515E6C546171546074556076555F77535E7556617958657B59667C5A677C5A687A
5967765B68765C6A785B697A5C697C5E6B7D5D697C5C697C5D6A7E5F6C805E6B7F5E6B80
5F6B82606C82626F836470856773856773846773846774836975846974826B75836D7787
6D78886E7A8C6F7D8E717D8F717D8D717D8F747F9276829277839178859078858F79878F
7B88917E88947E88957F88967F899980899C81899D828B9F838CA0868FA28790A28690A2
8692A28591A185939F8796A08897A18A98A28B99A38E9AA58F9AA5929BA6949DA8949FA8
949FA895A1A996A2AB96A3AC98A5AC99A6AC9BA8AD9BA8AD9CA9AC9DAAAD9DA8AA9EAAA9
A0ABA8A1ABA7A4ADA9A5AEAAA5AEAAA5AEACA4AEACA3AEABA3AFACA1AEA8A1ADA4A3AEA3
A3AFA3A4AEA3A2ADA1A3ADA1A1AD9F9FAE9D9DAD9C5D6261302D382D2C33232128201D21
201F203538325F6A5771816843473F302F2D30302D5E69535A634F7785678EA27C819571
4E5A42363D2B2A2F1E1F22151D1F1523251B26291E282C1F272B1D25291D272C1E2A311F
2D35202F371F2C321D292F1E2B32202A332027301E272F1E26301D28321E2B36202D3821
303820323922333925343B27353C273138243037243A422B343D282D36222A321E28301B
262D19232A17242917262B1A
4E5B68515E6D546071545F72545F74566177555F7857627C59657F59667D59667B5A687A
5C69795C6A785D6B795C697A5C697D5D6A7E5D697D5C697C5D6A7D5E6C7F5D6A7E5D6B7E
5E6B7F616E81636F826670856770866972866A75866B75876C76886C76876C76866D7788
6F7A8B6F7A8D707B8E727E8F727E8F727E8F7481907582917683917784917884907A8790
7B88907D89917D88927F88947F88958089987F8A9A818B9C848D9D848E9F858FA08690A0
8791A18792A18694A08795A08A97A38E9BA68F9BA8909BAB909BAA939EAC949EAB949FA9
94A0A896A2AA96A4AB96A3AB98A5AB99A7AA99A7AB9CAAAC9CAAAB9EAAAB9FABAB9EABA9
9FACA7A1ADA5A4AEA8A5AEA8A4AEA7A5AFA9A5AEA9A4AEABA4AEACA3AEABA3AEA7A3AEA4
A4AFA4A2AFA2A1AEA2A1AEA1A0AEA09EAE9D9DAE9B676F6B3E4146303137242429222022
1C1A1B373B3356624F61705A55604F40453B373A3356614E5C6852545F4958654B57664A
4F5C41373F2D29302121261A1D211521241724281A272C1C252A1B212416222517242A1A
272D1C252C1B202418262D2028302129312028321F28311C28311B29321B2C361E2E371D
2F371C2F361C2F361E323A23323A232D332031382439412A343C263037232C33202B321E
2A301E272D1C252B1A272E1E
4D5B67525E6E535F74535E76545F77545F7755607A57627D5A65805A65805A667C5C697C
5D6A7B5C697B5D6A7B5C69795D6A7D5C687E5D6B7E5D6C7E5C6C7C5D6D7B5E6E7A5F6F7D
6170816372826371836471846671856771856973866B76876B75876D77896C77886E788A
6F7A8B6F7A8D707B8E727D8E737F8F73808E74828D7683907683917784927884927A8893
7B89937D8B927D89947F8995818B95828C98828D99828C9B838D9B858E9B85909C86919C
88939F88939E88949E8A96A18C98A48E99A78F99A8919AAB919BAB919DAB939EAB929EA8
94A0A994A1A895A3A896A4A898A5A99BA8AA9CA9AC9DA9AC9EA9ADA0AAADA1AAAFA1ABAD
A1ABAAA4AEA9A5AFA9A5AEA9A5AEA7A5AEA6A5AFA8A6B0AAA6B0AAA6B0AAA5AFA7A4AFA3
A4B0A3A4B0A1A2AF9FA1AD9EA0AE9F9DAC9F9DAE9D79857C454A4D363A3D2C2E2E272825
22211D31322A474C3F4A5245505C4B444E3F39413357664D606F544D59414B573F48533B
454E37353B2A2D322425281D1F221822251924291C22281A1F25161D2113202516232919
252A1C252B1D191C1424281C272D1E272F1E29321E2B341E2C341D2D351D2E351E2F361F
3037202E351F30371F3036212E34202B301E303621384028333A212F371F2B331F2A311F
28301E292E1D272D1E2B3123
4C5A69515D70535F77555F7B55607B55607B55607B57607C5A637E5A657D5D687D5C697B
5E6A7C5E6B7C5E6A7D5D6A7D5E6B7E5E6A7F5E6C805E6C805D6C7F5D6E7E5D6E7C5E6F7D
60707F637181616F806270826471836672856872866A75876C77886B77896C77896F798A
6F7A8B707B8D727D8E737E8E74808E75818D76838F7783927783937782937884947A8795
7C88957F8B97808B97808996808A95818B97828D9A828D9C838E9C848E9B848E9B86929D
88939F88929F8994A08C96A38F99A78F99A89099A99199AA919AAA919CAA929EA9929FA7
94A2A995A2A996A3AA97A5A999A6A79DA8AA9EA9ACA0AAAFA0A9B0A2AAB1A3ACB2A4ADB2
A3ABAEA4ADACA5ADA9A6ADA8A8AFA6A7AFA6A6B0A7A6B0A7A6B0A6A7B1A5A5B1A2A5B1A1
A4B09FA6B19FA5B09EA4AE9EA1AE9E9FAD9E9DAD9D829083484C4D393B3C2F31302A2B28
28272229282238382F494E3F4852403F4838373F2E5463476476554F5C404A563B495338
4349313639272F3122282A1E21231921251A242B1F222A1E1F271A1F2618222A1A242B1A
222A19222819161A0F1A1D11202214222716272E1B2A321D2C341D2E361E2F3720313823
3339252F36233036232E34222D32202A2F1E3137243C442C333A222F371E2B331D29321E
282F1E292E1E2A2F202D3323
4D5A6B515E72535E76545F7A54607C55617D55617B56627A59637A5A647B5D687D5D687D
5D697C5D697A5D697B5D6A7D5E6A7F5C697E5D6A805F6C825D6B805D6B805D6B7F5D6C7D
5F6E7D62717F61707E63727F6573806673826975866A75886B78896B78896C7A8A6E7A8C
707B8D717C8F727E8E727F8D737F8B73808B73818D7583927783937783947884957B8796
7D8896808A96808996808895818896808999838C9C828D9C828D9C848E9F858FA08691A0
8692A08792A08A94A38D98A78F9AA98F99A9909AA8909AA6909AA5929DA6929EA693A0A6
95A3A695A3A797A3AA99A5AB9AA5AA9CA7AB9FA9ADA1AAAFA1A9B0A0A9B0A2AAB0A3ABB0
A3ABAFA3ACACA5ACA9A6AEA9A8AEA7A7AEA6A7B0A7A7AFA9A6AEA7A7B1A6A6B2A4A6B1A2
A4B0A0A5B1A1A6B1A2A5AFA1A3AEA0A0AC9D9EAD9C8B978A484A4E37363B3231322E2D2C
2C2C2A2C2C2732342B4D56434A54403C4533333A2B48533E697A5B515D4349533A495138
454B323A3E2730341F292A1A23241721231722261A23281B24291D24291C232A1B262C1B
2227171C201216180D12140A15160C191C0E282D1A2C311F2E3420303723323925323927
343B27353C283238242F34222E33212A2F1E3137243B432D333B252F38212B341D2B331F
2B3220292F1F272E1D2A311F
4E596E525D74535F78545E7956617D555F7D545F7B56627B58657C5A667D5A667C5B677D
5B687C5A677C5C687C5C697D5E69805D68805D6A815D6A815C6A805E6B815F6C81606D80
606E7F62707E63727D65747E65747D66737F6974836B76876C76896B76896C788A6E7A8D
717A90727C91747D90757F9074808E75818D75818D75818F7783937884977883967C8698
7E87997F8898808899808998818998818A9A838B9B838C9B848E9C848E9F8690A18691A1
8792A18793A08994A38C97A68D98A98E98AA8F9AA8909BA6909BA6929DA7929DA5939FA6
93A1A695A2A796A2A799A3A79AA4A99DA6AC9FA6ADA0A7AE9FA7B09FA8B0A0A9B0A2AAB0
A3ABB0A3ABAFA4ACADA4ACABA6ADABA6ADABA7AEABA7ADABA6ADA9A4AEA6A4AEA4A4AFA3
A3AEA1A5AFA2A5AFA3A4AEA3A3ADA2A2AD9FA0AD9E8C988C494A503C3D413A3B3B383834
32312D2E2C2832332C525B48525D48434C39343B2B424C37697B5A535F444A533B474F36
454B3342472F373A272F2F1F2A2A1C28271C282A1E26271D24261E23251D2023191F2217
1D2114181B0E13160A0F13070D0F060F1207272F1A2C331E303622323825333926323827
3239273239263036232E34212D32202B301E2D3422313C262D37212B351E28321C28311C
2A311E292F1F262B1D2A3220
4E596D515A72535E78545E7B565F7C56617D57627D58637D59657D5B687D5B687D5B687D
5B677D5A677D5C687E5D6A7F5E69805C66805C677F5B687E5C6A7F5E6B7F5F6D815F6C81
5F6C7F616E7F62707D63717C63717D6672816872856A73876A73886C758A6E778B70798D
717A90747C91747D90757E907680917581907682907582917783947883987983987A8498
7B85997E879A818A9D808A9D808A9C828C9C828C9D838C9D838D9E848EA0858FA08690A1
8790A28791A48994A58994A58A95A68C97A88C96A98D98A98F9BA88F9BA6909DA693A0A7
94A0A896A1A997A1A99AA3A99CA4AB9EA5AC9FA7AF9FA8AFA0A7AFA1A8B1A2A9B0A2A9B0
A2ABB1A3ABB0A3ACAEA4ACAEA4ACAEA5ADAEA5ACADA5ACABA5ADAAA4ADA8A4ACA7A4AEA5
A4AEA4A5AFA3A6B0A4A3ADA3A2ACA2A1ABA0A0AC9F919E924D4E544244484347433C3F38
30302A2D2C253030294D53444C53423E45362F34283C44316E825D566547475138485239
464E35454B344347323C3D2C37382B32332A30302A2A2A2424242020211C1E21191E2117
1D2115181B0F13170B1014070E11060A0C042128182F38232F3822313924303925303925
3039242E36232E36212E361F2D331F2A2F1E2C34222F3A252B351F29331C2A331C2B311C
2B311E2B2F1E282B1C292E1E
4D596A505A70555F7756607A555F7A57637D58637E59647F59657F5A657E5B677C5D687D
5B687C5D687E5D687F5D68805E69815E69815D68805D697F5E6A805E6B80606D80606D80
616D81626F816471816673826671836772856973896A758A6A74896D768C6F788E707990
727B91747C92737C90747D91757F937581937681937782947883967984987A85997A8699
7A85987C879A808A9D818A9D80899E818A9E838B9F838C9F848DA0858EA0858E9F8791A1
8891A28892A48A94A68A95A58B97A78C98A88C97AA8D98AA8F9AAA909DA9929EA8949EA7
96A1AA99A2AB99A2AA9BA5AB9CA4AB9EA6ACA0A8AFA0A9B0A0A9B2A0AAB4A1AAB3A0A9B1
A0ABB1A1ABB0A2ABAFA5ADAFA5ADAFA5ADAEA6ADADA6ADACA5AEABA5AEA9A5AEA8A4AEA6
A5B0A7A5AFA5A5AFA4A4ADA4A3ADA3A2ACA3A0ABA196A2985253583C3C434142413D3D38
32312A2F2E253230274A5040494E3E3F433533362B3A3F3170815F59674C454E3A4A543E
48513B464E384B4F3A4748374545373E3E3539383233332E2A292725262220231A1D2014
1A1B1016160D13150B1114090F1208090C041D25162F39252F38253039262E37252D3824
2D38232D38232C36212D37202B331F2A311F2A33202C36222A341F29341E2B341F2B331E
2B311C292E1C2B2E1D2D3220
4D5869505B70545F7556607757617959647C5A637E5A64805B65815A64805B677F5C687D
5B687B5C697C5D697F5D6880606A82606A835F68825F6882606983606A82606B80616D81
626D81616E816370836672866873866973876A748A6C768B6C758B6C758C6E77906F7992
717B93737D93747E937580937480927580927783937883937982937A83947B84977E8698
7E88987F8899818A9B818A9D81899E818A9F828B9F838C9F848D9F858FA08890A18991A1
8991A28A93A58A93A48B94A68C97A88D97AA8E98AB8E99AB8F99AA929DAC949EAB949EA9
969FAA98A1AA99A1AA99A3AB9AA4AA9CA6AB9FA8AE9FA8AF9EA9B19EA8B29EAAB29FAAB1
9FAAAFA1ACAFA2ACAEA4ADACA4ADABA5AEABA7ADABA8AEAAA7AFA9A6AFA7A7B0A5A6AFA3
A5AFA4A5AFA4A6AFA5A6AFA5A4AEA4A2ACA2A0AAA19BA89C6165653E3D434041423E3E3A
36353033312B33312A484B3C4B5140414537313329363A2B6D7D5B667556454B3A4A513F
48503E454C3A5156415D634B5559454C4D3E42423742453B29282626272221231C1C1E14
19190D16160913140912140A1012080E1006171A0C282F1C29301B29301E262D1D252D1D
2831202C37232A352228311E28311D29321C29331D2D381E2D381D2B341C2B331D2B321D
2A301D292F1E2B2F1F2E3321
4D566950596F535D74565F765860775A637A5A637C5A637F5A64805A65815B66805B677E
5A677B5C697C5D687E5D687E5F69806069815E667F5F6780626A81616A80616A80616D82
636E816470826470836671856872856972866A73886C73896D74896D748A6E778D6F798F
727C92757E94757E95757E95757F95757F947680947782937883947983937A84937C8594
7D86958088968088997F889A80899D7F8B9E7F8A9D7F8A9B818D9C848E9D868F9E88909E
88919F8891A08993A18B95A48C95A78C96A78E98A88F9AA9909BA9929CAA939DAA959EA9
969EA997A0A998A2A999A3AA9BA5AB9CA6AB9EA7AC9EA8AD9EA8AF9CA8B09CA9B09DABAF
9FABACA0ABAAA1ACAAA4ADAAA5AEAAA5ADA9A8AEAAA9B0A9A8AFA7A6AEA5A6AFA3A6AE9F
A6AEA0A7AFA3A7AFA4A7B0A4A5AFA3A3ADA2A1ACA1A0AEA0686D6C3937404040423A3A38
3E3F3A42443C474B3F4B50414A4F4041473833372C32372A667757708160444A39474E3E
464D3E414638545B46899A766A725A636A566068564D53482B2B2927292520211B181911
13130A111006100F051010061213091213091416092328142328122125121D21101E2313
262C1B2A321F252D1C1F2516222918262F1C29321C2D381E2D371D2E361C2D341C2D331C
2A301B2A2F1D2C31212D3322
505969545C6E575F7657607659627959647A59657A5A667D5B677E5B687E5D687F5D687E
5B677C5C677C5C677D5D687D5D697E5D697E5E697F616B80616B7F636D80626E81637082
636F816773836872836871846872866972866A74876B75886F7688707788727A8A727B8D
747C90777D94777D96757D97747E96757F95778095788296788396788494788493798494
7C86957F899681899A80899B808A9C7F8A9C7F8A9D808B9C818C9B838E9C848E9B87909C
89929D89929E8B95A08D96A28E96A38F97A5919AA8929CA8939DA8949EA8959EA8959DA7
959EA697A0A69AA3A799A3A79DA6AA9DA7AB9EA9AC9FA9AC9EA9AD9EA9AE9DAAAE9EAAAC
9FABAAA0ABA8A3ADA9A5ADABA7AEACA8AEABA8AEA9A8AFA7A7AFA5A5AEA3A5AEA3A6AFA2
A6AFA1A6AFA2A9B0A4A8AFA3A5AEA2A4AEA3A1ACA2A1AFA36B707235333E3F3F3F373633
5155465358465E644F5A604B4F54434D54433C42353940336070566B7C5F4A5341495240
414739363A2E4E564497AC888B9C7E87957A86947A585F522928282628231E20181A1C12
15160B1112060F0E04100F0514130916170C181A0D1D22101E240E1B220D191F0D191D0D
262B192E35221F231714160E202618252D1C2A331F2F37212F361E3036203137212F3520
2C321E2C321F2D3323303726
4E5869535E6F5962785A637B59637B58647B57637A59657B5B667B5B667C5E687E5F697F
5D687D5B677C5C677C5C677C5D687C5F6A7E5D687E5E697F5F6A7F606A7F616D80616E80
626E806571826872836872846972876A74866A74866A74856D77886F7889717A8A727B8D
747C8F757C92767E95757E97757E97767F967981977981987A81977981967B84957E8799
7F89997F889981899C80889D7F879D80889D818A9F838CA0828B9E828C9F838D9E868F9D
88919E8A929F8B949F8D96A08E97A19098A29299A4939BA6949BA8949DA7949CA8949BA8
959DA897A0A999A3A89AA3A79DA6A99EA6AA9EA8A99FAAAB9FA9AB9EA9AB9DAAAA9DAAA8
9FAAAAA1ABABA2ABABA3ABAAA5ACABA6ADABA8ADA9A9B0A7A8B0A6A6AFA4A6AFA4A6AFA4
A6AFA3A7B1A3A8B0A2A7AFA3A5ADA3A3ADA3A0ABA3A0AEA4737A7A3E3E473E4041363836
5159494F5543626A51616951515745525B49414A3B3B43355A684F697A5C4F59434C5540
40453433342950564491A4838D9F8191A28499AB8C6C7763221E1F2423202022191A1B11
15150B121207110F06111006181B0B1C1F0E1E21111E24121D24121A2111171D0F16190F
3239293D4532151712090A081E24182D362330372232392230361F30361F3236222F3422
2D32222D33222E34232F3625
4C586B515D7155617655607957627C57627C58627A59637A5A647A5B647B5B647C5B677C
5A677B5C697B5D697B5C687A5C697A5D697C5D677D606A7F616B7F5F6A7F606D81616D81
626E81646F836571846772846872866974866A74866A74876D768B6F778C70788D717B8F
727C91737D93747F95757F97777E98787E987A80997A80987980967980947C82967F8497
80859980869A80889B80879B7F869B80879C80899E818BA1818CA1838CA1848DA1858D9E
88909E8892A08A93A08C94A08B95A18C95A18F96A39199A5929AA6939BA89199A8929AA9
949DA9969EA9979FA9979FA898A1A899A3A79BA5A89CA7A89DA8A99EA8AA9DA8A99DA8A7
9EA9A9A1A9ABA1AAABA2ABACA3ABACA4ACABA6ADAAA8AEA9A6AFA5A6B0A5A5AFA4A4AEA3
A5B0A4A4AFA3A5AEA1A5AEA3A6AEA3A4ADA3A1ACA1A0AEA27F888247484D4245453A3E3A
40453C474E3F58604B68745A4F5645535A48454D3D394031515E466A7D5A5563474E5940
4A523B3A3E2F4C52418EA1808A9B7E8C9C8196A689818F752E2D2925221F22221C1C1C16
17160E131209111107121206181B0B1B210E1C21101F25131E24141D2314191C0F13140C
2A2E243E47381A1D1A0B0D0C181E14303A252E3721333A2331371F3036203137232E3423
2D32232E3325313725323825
4B576A4F5B71546077545F7757627A58637C5863795964785A66795C677B5C677C5B667A
5A67795C687B5E6A7B5D69795E6A7B5E6A7C5D687E5F697D606B7F5F6A7F616D81606D81
616E81646F836670846770846772856973876A74886A73896C748B71778E737A8F747C91
747E92758093768095767F97777F98777F987880987881977981967B83957D83957F8395
7D81947E84987F869A7F879B7F879B7F899D7F8A9E7E8A9F7F8B9E818DA0838DA0858DA0
868FA08891A18892A28B94A48B95A58A95A58C96A58E97A6919AA8929BA9919AA8929BA7
929DA7949DA997A0AB98A1AC98A1AC97A0AA9AA3AB9BA5AB9CA6AC9DA8AD9DA9AC9DA8AA
9EA9ACA1AAAEA2ABAEA2AAAFA4ACB0A5ADB1A4ACAFA5ACABA5AEA8A6AFA6A6B0A5A4AFA3
A5B1A4A3AEA3A4AEA3A4AEA3A4AEA3A4ADA3A1ACA2A1AFA48B968E47484D3F4041393B38
3F423B4B51454D53466B79624B52454F5749475041363C314B57446D815F58674A4D5940
4B573E444E3948503E8B9D7B8C9D7F8A9A7D8E9D828F9D824D50462825242524221F1E1C
19191415140F14140D15160C1A1E0F1C21131D22132025152126161F22141A1A0E16150C
1E1F172D31283E47390F11110F130F2932212D35223036232F35222E35212F36232F3421
2E3220313423343827353A28
4E596C505B72525E77515D76535E775460765561755763745865745B67785D697C5B667B
5A677B5B687C5B687C5B687C5D697D5E6A7E5D6A7E5E6B7F5F6B805F6B80606C81616D82
606D82636F82657083666F846670846871876A73876A73876D778A6F798A70798A727B8C
737D8D747E8E757E91768094758096757F967580977782997982987781967A82957C8396
7B81957B82967D84987D85987E889A7F899D808BA1808BA17F8CA0808DA0818DA0838D9F
8690A18791A28790A28892A58994A78894A68A95A68B97A68D98A68F9AA58F9BA3909BA4
919DA6929EA895A0AA96A0AB97A1AC98A1AC99A2AD99A4AE9AA6AF9CA7B09CA8B09DA8AF
9DA8AE9EA9ADA1AAADA2ABAEA4ABB0A3ABB0A4ACAFA3ACABA4ACA8A4ADA7A3AFA7A2AFA5
A2AFA3A2ADA2A3ADA3A4AEA4A3ADA2A2ADA2A0ABA2A0ADA38F9C934A4A513E3E44393A3D
474D475A635550564C6875624951484C564B454F44353C35455042697D6059694F4C5842
4C574247513F4750407F90728A9C7E88977D89987F8997816973643E413C262727212224
1E1F1F191A191818141A1C131D20152123182224182427192527192022151B190F1A1810
515C443F4738596550111211121411252B1F2A31212C32212D32202E33212D33212F3421
2F341F333723363927363927
4E5A6C505D72535F77535F77536077556276546273566373576474596676596678596679
5A667A5B687C5A677B5A68795A67775C69795C697C5E697E5F6A7F5F6B7F5F6B805F6B81
5E6B80616E81626F826370826571856671866973876973876C77896F7A8B707A8B727D8D
717C8D727D8E737F8F7580927581937581947580937780957780967981967A8297798297
7A82977A83977A84967C86987E879A7F899D818A9E818AA0808BA1808CA2818DA3828DA2
8490A28590A28691A28792A48892A48893A58A94A68B96A58C97A48F99A4919BA3929DA3
939EA4929DA6949EA896A0A996A1A998A2AB98A2AC99A3AD9BA7B09CA7B19CA7B09DA8AE
9DA7AC9EA8ABA0AAABA1ABAAA4ABACA4ABADA4ACADA4ACABA3ACA9A3ACA7A2ACA7A1ADA6
A0ADA4A1ADA3A3AEA4A3AEA4A2ADA2A1ADA29EAAA19CA99E8E9B904D505443454A404445
4D544D636D5E52584E5B65584C544B4B5448444D41353B334751416171565C6B514F5B45
4D5744495142495043808F74899A7E88967E89978084917D85937D727D6A201E211F1C21
1B191D161417151313191A151D2016202217222418272A1B2A2C1E2222161C1911191611
63705767775E4751441010131518182F382D2F382C2F38282C34222D34212C34212D3321
2D3421303622333925363A27
4A586A4D5B70505E74515F76525F775462775563755664755765745865755966765A6777
5B68785B68795B68795C6A795A67775B67785D697D606980616B84606B82616C83616D81
5F6C7F616E7F6270816471836572856873886C768B6D768B6E788D727C90737D91737D91
717C91727D92747F927681937682927682937882967781957781957882987A839B7A839B
7B849B7B879B7C869A7F899C80889B808A9E808A9D808BA0808BA1818CA3828DA6828FA6
8390A5838FA3838FA18691A28893A48B96A88D97A78D96A58E98A69098A5929AA6939BA4
939DA4949EA5969FA597A0A797A1A798A2A798A2A89AA4AB9BA6AE9BA6AF9BA6AF9CA6AE
9DA7AE9EA8AE9EA8AD9FA9ADA2ABADA4ACADA3ACACA2ACABA3ADAAA2ADA9A2ADA8A2ADA9
A1ADA9A3AFAAA1ADA6A1ADA59FABA49DA9A09BA89E99A79B8D9B90575C5E45484E4A5152
616C605C655751574A52594B4C54474851443F463A33382E3E4636647457617156525E48
4C5643484F4045493E7A88708D9F828998808B9A8386937F8C9B8385947D2422231B161B
1D1A1C171416141011141210191913212318313424373A2933362724261A1C1D1317140F
545C487E906F55604F1C1D1E141519323C34333D322D37292933222A33212A32202A3320
29311F2B33212F3824333A27
4856684B596C4F5E71505D74515D74535F765563765765775865755966755A66775C6878
5A66795B677A5B677B5B687C59667A59667B5C687E5F69815F6A82606B83616D83616E80
616E7E626F7E63717F6572836873866A76896C778D6F788F707990717A90737C91727D91
737E9274809474809474809375809376819578839777819677829978839A79839B79839B
7A859B7B869C7C879B7E889C7F879C80899E7F8A9F7F8AA17F8BA2818CA3818DA5818EA5
8490A68490A6838FA58691A48892A58A95A78C96A78D97A79098A89098A9919AA9929BA7
929CA5949EA696A0A696A0A796A0A699A3A899A3A99AA4AC9BA4AD9BA5AF9BA5AE9CA7AE
9DA7AF9DA7AF9EA8AF9FA9AFA2ABB0A2ABADA3ACABA4AEABA3ADAAA2ACAAA2ADAAA1ACA9
A2ADAAA4B0ACA2AEABA2AEAAA0AAA79FAAA49DA9A19CAAA096A49A666C6C45474C4C4F4D
88977D595F5054594A5A62524C54483F463E3438342A2D2A353A3163735864745756624A
5059444B524143483B73806792A5848B9C808D9E8389987F89987F8B9B8031312E1B171A
23211E1B1917100D0D0D090A100D0C34382A5B674C606C534A5241282B2424261F22221F
5A64527A8B706E7D663237311413163C473B323A30293126262E20262E1F272F1E29321E
28331E2A331F2E3621323824
4955684B586B4F5B71505D74505C75525E775460765563765663755865785B657B5C657B
59647C5A657E5B667E5C687F5B687D5B677D5C687F5D68805E6A805E6A7F5E6B805F6D80
616E7F626F7D62707F6472836875876B7A8B6C788B6D798C6F7A8D707B8F707B8F727D90
737F90748092737E93737E94747F94757F95768096768097768198758098778199788398
7884987A859A7A859A7B869A7B85997D879E7D89A17D89A27C89A17E8BA17F8CA2818EA4
8490A68490A6838EA6848FA68690A68791A58A95A78D97A98D97A88E98A9909AAA909AA9
909BA8919CA8939EA9939EAA939EA995A0AB98A2AC99A3AE98A2AE9AA4B098A3AF9AA5B1
9BA6AF9DA7AF9FA9B0A0A9AFA2A9AFA2ABADA3ADABA4AEAAA3ADAAA3ACAAA2ACAAA2ACAA
A1ACAAA1ADABA2AEADA3AEABA1ABA8A1ABA6A0ABA59EAAA59BAAA46B7275494B51454746
5960514F54474B50445F6958525B4F444B443A403D2D31303036315767515F6E5356624A
535B474D534341463A68755F91A584899A7D8D9C828C99818B98808F9E844040391D1718
25221F1B18150D0A080907050B0909454E3E849A787E927476876D3A3F3B434A454E564F
64726173846D6F80694952451B1D1B49554332372D2B3226272D20252C1E242D1E252F1D
26311C2A331E2E3520303521
46526749566C4D5A724F5A74515D77515D77535F7754607856627857627959647A5A637B
59627D59647E59657D59657C59657C5B677D5B677F5C67815E69825C69805D6A7F5E6B7E
5E6B7D606D7D616F7E6573826876856A78876A79896C798A6F7A8B707B8E707C90717C91
727D8F727E8F727D90727C92727C92747E92757F94757F95757F95758097768098778198
7882997984997985997985987A85987B869A7C879C7D879D7D899D7E8B9F7E8B9E7F8BA0
828EA3818EA4818EA4828FA38591A48793A48A94A78B95A98A95A88C98A98E9AAA8F9AAA
8E99A98F9AA9919DAA919DA9919DAA929FAB94A0AD94A0AD94A1AD97A3AE98A4AF9AA5B0
9AA5AF9CA6AE9EA9B09FA7AE9FA7ACA1A9ADA1AAABA2ACA9A3ADAAA2ABA9A1AAAAA1AAAA
A1ABAA9FABA99FAAAAA1ABAAA2ABA9A0AAA79FA9A69DA8A59DABA46D757744474E434747
3E433E42473F41473F6C7A67535E5449514C434B46323735313833475242535F4A505A47
4F5546494F443F423B68766390A4878898808C9B848C99848B98828F9E8540413B1D181C
2522211C1B1813130F0E0F0B0E0F0C292F2568795C7B8D6D8394745F68586B7666717E6E
71806E717F6D71816D616E5C3F463D505B4A343C302B3226272D1F232A1C232B1C262F1D
262F1C28311D2D3520313824
4757694A5B6E4E5E73515D74515D75515D75535F76545F7854607A55617B566179576279
58637959657A58657B5B677D5C677F5C687F5B677F5C68815E69835D6A815E6B7F606D80
606C80616D806270816573816978846C7B866D7B886D7A8A6F7A8B717B8E717D90727C90
717C91727D91727E91727C92737E93757F94757F94757F94778196798398788299778198
77829978859B7A869A7986987A86977C88997C889A7D899B7E8B9D7E8B9E7F8C9E7F8C9F
818DA0808DA1818EA2838FA38491A28793A48994A58A95A68B96A78C98A98C99A88D9AA7
8D99A68D9AA78E9AA7909CA7919EA892A0A894A1AA94A0AB95A1AC96A1AC98A2AE99A3AE
9AA4AE9CA6AE9DA7AE9EA8AFA0A9AEA0AAACA1AAABA2ABAAA3ABAAA3ABABA3ACAEA2ABAE
A1ABADA0ACABA0ACABA1ABABA0AAA99FAAA79EAAA59CA8A09EACA1767F7E41424B3C4043
383D3B3F463F4951478194795E6A5A475046454D44323632333830444C3E4B53444F5747
5057484C51453C3E39646E5F94A78A8A9A808D9D838B9B838A998191A286484B43181215
201E1C1A1A1816161412140F12140F161711262A1E525C44829571717F6676836D788771
77867175836F7584706F7E6A63706063725E394035262B21262E1E232B1A242C1928311C
29321D2C3620303824333926
49576A4B5B6E4E5E724F5D72505C71515D7254607655617856627A556179566278556176
58647758667A59657B5A657C5D677E5E68805E68805E6882606A83606C845F6B825F6B7F
606C81626E826471836875846C79846E7C856F7C886F7B8B707B8C717C8E717C8F717C8F
717C91727D93707D94727D95737D94737E93747F94758196768095778296788398798399
78829979849B78849B7B889B7A86997A869A7C889B7D8A9C7E8B9D7F8B9D808D9E818D9E
828E9E828EA0828DA1838FA38390A28491A28794A48A97A48C98A58A97A48B98A48C9AA3
8D9BA48F9BA68F9BA7909CA8919DA892A0A794A2A995A2AB96A1AC97A1AC99A2AD99A3AF
99A3AF9DA6B09DA6AE9FA7AEA0A9ACA0AAACA0ABABA1ABACA2ABADA2ADACA4ACADA2ABAE
A3ACAFA2ACADA2ACACA2ACAC9FABA99FABA89FAAA69DA8A39EACA1818D8544474C3B4042
3537373A3D3850584B7D8C72687460485045464E433135302E2F2A454A3C4D5443515947
525A494F554740423A5E665795A8898A9A808D9D858B9B848A998293A689586151161111
1E1C171816131515131314111314111414111A1A14353B2C6E7E5F57614C6C7960728067
73806974816B7886707686716E7F6B6E7F6A3A4138292E242B3223272E1C272E1A29321D
2B331F2F3622343925333926
4954664C596A4D5B6E4C596D505C70535E73545F76546078566179566279566278566177
58647959657B5A667C5B667C5D677F5D67805D667F5D66805E6882606A835E69815E6A80
606D81626F826673816D79836F7A83707A83707A86717B8B727C8F717C91727D92737E93
727D93737F95727E95737E97727C95727D95757E97768097757F95757F93768093778195
77819579839879849C7B859C7B869B7A859B7D869E7D889D7E8A9C7F8B9D808C9C828D9C
838F9C828D9B838D9C848F9E8390A08491A28794A48A96A48A96A38B98A28C98A38C99A3
8D9AA38E9AA4909CA5909CA6909CA7909DA6919FA794A1A996A0A997A1AA99A1AB99A2AC
9BA3AD9DA5AF9EA6AF9DA6AE9DA7AD9FA9AC9EAAA99EAAA99EAAA99FABA89FAAA7A1ABA7
A2ABA8A2ABA8A3ACA8A3ACA7A2ADA6A0ACA59EAAA49DA8A29EADA286938B474A4F414545
36373738393652584C68745F616B59555E4F41473F2F322F2C2D294043364D5341525945
535A474E5444464A3C5A614F96A7878C9B818D9B858B9B868A9A848EA1875B6455191516
21201B1E1B181C1A1815141212110E12120E16150F363C2A4C573E35382A3B3E316B775F
6E7B65717F68788870798B7073866C708167353B302C31262C3124272D1F262C1C29301E
2A311E2C3220303624333827
4751674955694C596C4F5B6E515B71545E76535E7A535E7A535F7A546179556278566379
57647A58657B59667C5A677D5D68805C677F5C657F5B657F5D66805F68815E68815C6881
606C816370826875826F7B85707B86707A87717B89717B8B737D8F727C91737E92747F93
727E92737E93727D93727C94737C95737D96747E96747F95747E94767F94758092778294
7782937782947884987883997A83977D859A7D859C7D869C7D889C7E899B7F8A9A818D9B
838E9B858E9C858F9E858F9E86909F858FA18892A28A95A28A96A18B97A18C97A28D98A2
8D98A28D99A38F9CA3909CA3929EA4919EA5919FA592A0A695A1A797A0A698A0A798A1A7
9AA3AA9CA4AB9CA5AC9BA4AC9CA6AC9DA8AC9EA9A99EAAA99EAAAA9FAAAAA0ABA8A0ABA7
A1ABA4A0AAA2A1ABA3A2ABA3A1ACA2A0ABA19DA99F9BA89E9EADA189958D484A50424447
363537383A395862555962545A6453545E4F4D5649393D3930332F3E44374B5442515946
5158454B503E464A3B5259488FA2818D9D808C9C848D9D868C9E868FA2885C6557191518
211F1D1D1B191A1A1714141110120D11120C12120B343B294D593D2F31211C181368735C
74836B6F7F6B768871798C72768A6D738768363D30292D25292D23272A21262A1E282D1E
2A301D2C311D2F3420313624
4A54664D576A4F5A6E4F5A71505B73515C75525D78545F7B54617B535F7955617A56637B
56637B57647B58657B59657C5B677E5B667E5B66805B65825D67835E68835D68835D6982
616D846571856975856E7987727D8A717C8A717B8B707B8C717D8E717D8F737E92727D93
717D92717D92717D92717D93737E95737E96758096758196758195758193768192778393
78849478839579839979839B7B839B7E869B7D859A7E869B7F879B7F899C808C9C818E9B
818E9A838F9C848F9E868FA08790A28790A18892A18A939F8A96A08B97A08B979F8B979F
8C99A08D9BA18D9CA08E9CA1909EA3919FA592A0A8919FA795A2A897A2A798A2A799A2A8
99A3AA9AA4AB9BA5AC9CA7AD9CA8AB9CA9AA9DAAAB9EAAAA9EA9A8A0ABA9A2ABA8A2ABA5
A1ACA4A0ACA4A0ADA49EABA49EABA39FACA29DAAA09DAB9E9DAD9F8D9B904A4D52404447
37383A37373850564C4E5449555E504C56484C5749454E43353B3440473A4953414D5743
4F58444B51404144384144398B9D7E8C9E818A9B818B9C848699828A9E84616C5C1D1A1E
2220201D1D1C1A1A1717171316161114150E14160E272B1E5D6B4B3E422E24221C66735D
74856E6E7E6E748574798C757A8D73788B6F3F463C292D273032282D2E242A2C212A2E1E
2B301D2D331E303621333723
4851634C5568505A6F505B72515B75515C77525C78545E7A545F7A55617C56627B56637B
56647B58647B59657C59667C5B677E5B677D5A657F5B66825D67835F68845F6984606A84
636E866772866A74876F7A8A737E8C737F8C737E8C727D8D717D8D707D8F717D91737E92
727E92707D906F7C90717F92727E93747F95747F95737F93758293758192758192768292
7783957983997A839C7A839E7D839E7F869D80879C80879C80899C808A9C808A9C808C9B
808E9B828F9C848F9B848E9B87909E87909E88929E8A95A08B96A18C98A28B98A08A979D
8C999D8D9CA08E9BA18F9BA38F9CA5919EA7929FA9919FA893A1A994A2A998A4AA99A4AB
98A3AB98A3AB99A4AC9BA6AD9CA8AB9CA8A99EAAAA9EA9A89EA9A7A0ABA6A1ABA3A2ACA3
A2ACA3A2ADA3A1ADA49FACA39EABA29DABA19EABA09DAB9D9DAC9C92A1944C4E523E4146
36383D3131334F554A4A4F45494E45464E424B5648475243343B303A433548533E4A553E
4B563D474E393B3D3033342B8091748DA0828A9B818A9C85859883889C856B7A691F1F23
24232321201E1E1E181B1B141A1A13171911191A1320241A2F35272F322840483A718368
75876E71826E748571798C757C8E767D8F754850452B2D2834372D2F31262B2D22292C1E
282D1D2C31202F3423313725
4951644B53674E586C4F5970505A73515B76515B77535D7A56617C56627D56627D55627B
56627C58647C59667C5A667D5A657C5B687D5C687E5E6980606981606880636B84646C85
646E856772866873876D788A727E8D76828F78849076818F748090747F92737F91737F92
737D92707B91727C92737F93727F92727E92748094737F92758092748091758092778394
7682947782977882997A839B7C849D7E869E7F889E7F889D7F899D818B9F818C9F818D9F
808D9F818E9D84909D85909D87919F87919F8892A08994A28A96A38B97A48B98A38C98A2
8C99A08E9BA28F9BA3909BA5919CA8929EAA939FAB93A0AB95A0AC95A1AB97A3AC98A4AC
9AA4AC9AA5AB99A4AA9AA5AB9CA8AB9DA9A99FAAA9A0ABA8A2ACA7A2ABA6A2ABA3A0ABA1
A2ACA0A3AEA1A1ADA1A1ADA2A2ADA2A0ABA1A0ABA2A0ACA09FAB9C9AA898555759414246
3B3E40323234494E444E5346494E43484E434F5A4B434C3F31362C353B2E515E454E5A41
4D563E484E393E4133302F2A78866E8FA1858A9B838D9E88899A858B9D877F8F7C29292D
222022211F1D2120181E1D1319190E14150C16170E20241821241A1F201A21231E6C7D62
76896D71816A7888707D8D747E9076849578565E4E2F3029383A3132362E2D31292A2D24
272C1F2C31212F3525323728
4751654953684C586B4E596D4F5A70505A73515B76525C78535D7955607B56617C55617B
56627B58647B58657B59657A59667A5A677A5A677A5B677C5D687D5E697D626C82636D83
647083667385667384697586707E8C768590788793778492758392748092737F93727E94
737D95717D94717C93717F94707E93707E92727E92727E91758091758091758091778391
7885927884947883967A85997D869B7A849B7B869E7A849D7B869D7E89A0808A9F808AA0
818AA0838CA1848EA0848FA0868FA085909E85919F8692A08793A18894A18A96A38C98A5
8D9AA48D9BA58F9CA6909DA6919DA8929DAA929EAB939FAB95A0AD96A0AC95A0AC98A3AE
9AA4AE9AA5AE9AA5AC9AA6AC9CA8AB9DA9A9A0AAA8A1ABA8A2AAA8A2ABA8A2ABA5A1ABA3
A1ABA3A0ACA29FACA3A1ACA4A2ADA5A0ACA49FABA49FABA39CAA9E9CAC9C5E6261444549
4546463635373F413C474B404C52444D5647525D4D4B5648363E34373F315A694D57654A
505B444D5440464A3C363733707C6A94A78E8A99848C9B878998868C9B888593802C2A31
211E2323221F2020171D1E121B1B0E13140A13150B1F221721261C23291E1515115E6C54
76886B6D7E6678886F7E8F74819277819376535A4B34352F3A3D34363B303035292B3023
2A2E202E3221333726333626
464F6549536A4C586E4D596F4E5971505A73515C75535D77535E7755607957647B56627A
57647B59657B58657A58647959667A5A677A5B677A5A677B5C687C5E697E606A81646F86
6572866674836674816775836C7B8771828D748591748491738190727F8F717D90717C93
727E95727E96707D95727F96727F95727E95737F94737F93758192768291778491778491
7986917884907883917A85957C86987B869A7B889D7B869E7C88A17E89A27E89A17F8AA1
838CA4838CA4848DA4868FA4868FA38691A18692A08793A18895A38A96A38B97A48B98A4
8C99A68A98A68A99A58D9BA58F9DA7919DA9919EAB919EAB929EAB939FAB95A1AD96A2AE
98A4B09AA5B09AA6B09CA7B09CA6AD9CA7AB9FA9AB9EA8AA9FA9A9A0AAA9A2ABA8A3ACA9
A2ABAAA1ACA9A0ACA9A1ACA9A0ACA89FABA8A0ABA99EAAA69AA8A19BAB9F656C6A414247
4245433434343E413C454B424D564A515C4E535F504E5B4C3D4A3C3A46355A6C5059684C
5360464C564042473A3A3B3775836F95A88D8B9B868B9A888896858B9A868493802E2B32
201B232321211E1E171A1A1018190D14160B191B10272C212F372C2E352A292E255C6A54
73856C6E7F6874856D7B8C737F90778093784F584C3539323A4135353B2D3036262D3222
2B301F2F3422333625333725
47516649546A4B566D4D57704F5A73515C76525C77535D78545E79555F79566078566179
56617A57627C58647E58647E58657D59667C5A677C5A657C5C677F5E69815F6B83646F87
6572886674876674866775866876876B7A896E7E8C707F8F727F90727F91727E92727C93
717C94727D94717C95737E96747D97727C96737E96737F95748095758193788593798593
7884937784927783927884947985967B87997B889C7C889D7C889E7B879F7C86A07E89A1
818BA3818BA3838CA4868FA5868FA38790A08893A08993A18994A18894A18995A38995A2
8A96A18A96A28B97A48E99A5909AA6929DA8939DA9939DA9929DA9939FA996A1AA96A0AB
97A0AE98A2AF99A3B19BA5B29DA6B09EA8B09FA9AF9EA8AD9EA9ABA0AAAAA2ABABA2ACAC
A2ACABA0ACAAA0ACA89FAAA79EA9A69EAAA79EABA79CA9A499A79F9CAD9F717B733C3E40
3D413D2F312F4349404B54494C564B5563544F5D4F3F4A3E354034323B2F596B505A6B4E
5260464B5740373D3033352F76866D95AB8C8A9A858B99888A97878B9A88839180333236
1B161D1F1C1F1B1A181B19141A19131718101C1E142D3326444F3D363F324A574760705C
6E806971836B73856F7688747A8C767B8E77525E51373D35394033343C2E3036262E3422
2C32222D3322323826313725
4953674A566B4C586E4E576F4F5972525D76545E78535C79555D7B565F7A586079576179
58607957607A59627D58627D58647E59657F59657F5B66815D67835E68855F6A86626E89
64718A68758C68768C69768D69768B6B788B6E7B8D707C8F717E92707D92717D91717C90
717B92727C93737C96747D99747D99747D99737D99747D97767F97768096758094778295
7681957783967884967984977985977A86997B889B7C889D7E8A9F7E8A9F7E89A07F8AA2
7F8AA1808BA1828DA1838FA0858FA087919E88919E8994A08994A18893A08994A18A96A2
8B96A18C96A28E98A28F9AA3919BA4949DA5949CA6959DA7959EAA949EAB94A0AA95A0AB
98A2AD99A1AE9AA4B09BA4B29BA4B09EA8B19FA9B09EAAAE9EAAAC9FA9ABA1ABABA0AAAA
A0AAA8A0ABA9A2AEA9A0ADA69FACA59FABA49FABA39DAAA19BAA9D9CAD9C737E733B3D3E
3D423E30313043483E4E584A515C4D53605041493F333A31282F28272E26596A515B6F53
49594349564031362A2D2F28707D6795A98B8A99838D9B888D99888C9B8984948336373A
18131A201D1E1E1C181F1D171C1B161616121818112F34275F6D545965514A5447586557
71856F71836E72846F71826F6E806C72876E53604E353A30383E30353B2E3137292F3525
2E34242E3524323926313824
47516848556D4C5A714D5A6F4E5A704F5A71505B73535D77545E78535D76555F76566177
57627857617859637B59647C59657D5A66815965805B65815C67845E6886606B88636E8A
64718B67748D69768F69768E69768D6B778C6D7A8D6F7B8E6F7D916F7C92707C91707C8F
727E92727D93727D95737D99727C98737D98747F98737D97757E96778095747E94757F94
7580947782957886987885987B869B7C879D7D889E7B889E7E8A9F7F8C9F7E8B9E7F8BA0
7F8BA0808C9F808E9F818E9F848F9F86909E88919F8892A08995A08995A08995A28B98A4
8C9AA58C99A48D9AA38F9CA3909CA3929DA3939EA5949FA8949EAB939FAC94A1AD95A1AE
97A2AF98A3AF99A5AF9AA3B09AA4B09DA8B09DA8AE9DAAAD9EAAAEA1ABAFA1AAAEA1AAAC
A0AAAA9FABA9A0ACA9A0ADA89FADA6A0ACA59FACA39EABA19BAB9D9BAC9A7480743F4443
42474336393740473E4F5A4C505C4E535F5140493F38403531392E2D34294D5B4556674C
46523E48554033392C2F312A6D796592A3888998818D9D878F9E8A8E9D8985968237393B
1A171D2220211C1B191B1A161919151516121A1E172931247085656B7E62677863454E47
7B91797288736274623F4B42414E436B816557664E31372A383E2E363B2B333828313725
313724333926343C27323B26
45536846556B48586E49596F4B5A6E4D5A704F5C72515D74515E75525E74536074546074
55617556627857637A57647C58657E5A67815866815A66815A67815C68825E6984626F89
64728A65738B67758C67758C66738A6A778B6C798B6E7C8D6D7B8E707D91717D936F7D93
728095727E94707D94707D96707C96707D95717D94727E94737D94758094758195737F93
737F9075839376859777859878869A7A879D7C899F7B879F7A879E7E8A9F7E8B9D7E8B9D
7E8B9E7E8B9F7F8D9F808D9E838E9F8690A08590A08592A08694A18695A18796A38998A4
8999A48B9AA58C9AA58D9BA3909BA4909CA4919EA6919FA892A0AC92A0AD93A1AE94A2B0
94A1AF96A3AE98A5AE99A5AE9BA7AE9BA8AE9AA8AD9AA8AC9CA8AB9EAAAD9FAAAEA0ABAD
9FABAB9FABAA9EABA99EABA89EABA89DABA79CABA49CABA198A89F9AAC9E7B8980444A4C
3F4445393C3E3B413F464F474B584D5563544B57493C473B373F3534382E383F30414B37
3A42303F4836383E312F302B60695992A4888896828C9C898E9F8E8D9F8C879987393D3F
1410191D1C1E171516151412151611121410252A222F372B5E70566F856763745F454E47
7A8E79768C7659695B161A1D1A1E1D3C463649543F34392B373C2E363B2B343A28323725
343A25363B27363D28343B28
48566649576A4B59704A58714C59724C5A734E5B72505C74505E76525E75525E73525E73
535E7355617656627957647C57647D59657F59658058657F59667E59677D5C697F606E84
63718663728765748967758B68768B6A778B6B778C6D7B8E6D7B8E707D91717E93707E94
6F7D93707E926E7D906E7C916F7D92717E93717E92718092728093748194738095728094
72809274849476859577869977869B78859C78869B7B879D7A879D7C889E7D899F7C899E
7D8B9E7D8A9D7D8A9D7F8C9D818E9D838F9F838FA08491A18493A18493A18595A28797A3
8998A48A9AA78D9AA88E9BA6909BA68F9BA7919DAA909EAB919EAD90A0AE90A0AE92A1AE
93A2AD93A3AD93A3AC96A4AC98A7AD99A8AD9AA9AD9AA9AD9CABAD9CA9AC9EA9AD9FAAAD
9EAAAB9EAAA89EABA89EAAA79DABA79BAAA79AAAA59AAAA498A8A19AABA17A86824B4F54
3C4046454C4A464D47404741505C50556253485244363C3333372F2F33292B30242B3021
2B301F313625383D2D31332A626C5990A2858795818A99878A9C8A899C8B829485313439
16131C1A191D15141414120F15130D13120E272B223033295F6C55778A6E687763637063
708071778B795260540E101516171A1211112528202F3426323629333929323927323826
343A26363C29373C2C35392B
4751634954694B56704C57734C56734B56714D59734F5B75505C75525D76535F76535E75
525E74535F76545F7754617A55637C58647E59648058647F59667F59677E5B6B7F5F6D82
61708264738564738667758868768A69778B6A778B6E7B8E717F91738093738095707E94
6E7D936E7D916D7C8F6E7C8F707C90717C90717D91738093728193718092728094738095
74819576839577859678859979859C78839B7884997A879A7C889C7D899D7E8A9E7E899E
7D899E7F8B9E808D9E808D9D818F9F8290A08290A18391A28291A18393A18594A28594A2
8795A38A98A68D9BA68E9CA68F9BA6909CA88F9CAA8F9DAC8F9EAE8E9EB08F9FB0909FAE
94A3AE95A4AC96A3AC95A3AC98A6AD99A8AD9CA9AE9DA9AD9EAAAD9DA9AC9DA9AC9DA8AC
9EA9AC9EA9A99EAAA79DAAA79DAAA89CAAA79AA9A599A9A397A8A09AABA27B8683494C53
4044484046443D433C32362F4852435A6753535E4C3A40373237302F332B2E33262A3020
262B1A2A2D1B37392734342A60695796A98B8A9A828C9D878B9C87889985839582343839
15131A1B1A1C18171717171417161215141020211928291F616D5376876A6F7E6673826C
72826E7A8D78586459111119110E140F0A0D201E182F3225313424323624343A26343926
343A26353C27363D2B363C2E
464F644952694B556F4C55724D56734D56734D5673505A764F5B76515D76535E76535F76
535E76525D77535F7954617B53617B58647F58657F59667F5966805966805B68805E6B80
606D7F627082657385667485677585687687707F8E7B8A987E8D9D7C8A9C768399707D96
707D956E7D936D7C926F7C91717C91717C91737D92737F93737F92738091738091748094
7581947781957782957783957884977984987985997A869A7B879C7C889D7C889F7D889F
7F8A9E7F8B9E808C9C808D9D828EA0838EA1848FA18591A28592A28592A28592A28694A3
8896A38B97A38D99A38D9BA48E9BA58F9CA7919DAA909DAC8F9DAE8F9DB1909FB192A0AF
95A2AE95A3AF96A4AF97A5AE98A5AE9AA7AD9CA8AD9EA8AC9FA9AB9EA9A99EAAA89EA9A9
9EA8AB9EA8AA9DA9A99EAAA99EAAA99DAAA99CAAA69AAAA498A8A099AA9F85938A45484D
4045463438382E32302425233B42375F6D575965504B56463F463A383D3233382C2E3426
2D32234F583F41443437383153594E94A78C8A9C858A9C858B9C86889882879681454845
16121A201F201D1E1B1C1E191A1B1717171316161024271A5762487B8E6B70816574846B
76856D7787717584713639391C1A1D1F1C1C22201A303123313322333724333825343A26
353B27353C28383E2C373C2D
4850634A53694B556F4C55714D56754F58774F58754F5B76515C77515C76535D76535E77
535E7853607A55617D56617E57627F58658057648058667F59667F57647E5A67815C6880
606C81606D816370846572866674866C7A8D798A9B8294A38697A7808EA378849D717E98
707C946F7C916D7B906E7B906E7B8F6F7C90737E92737E92737F91748093748093758094
7480947681957682957783957985977985987B889B7B879C7B889C7C889C7C889F7D88A1
7D8AA27E8BA17E8B9E808D9F818DA0848FA1848FA3858FA38691A28893A28893A18994A0
8A96A18C9AA38D99A28C99A38D9BA48F9CA6919DA9909CAB8F9BAC919DAF929FB094A1AF
95A1AD96A3AD97A4AD98A5AD99A6AD9AA7AD9CA8AA9CA8A99EA9AA9FAAA79EAAA59EAAA7
9FAAAA9FAAAC9EAAAC9EABAC9DABAA9DABA89CABA59CABA49AABA29AAB9F8FA092474B4F
3B3F402F31322A2D2D2425263439345E6C595865525764524E5A493D4537353B2E2E3327
2C30266C7B5E43483A3A3C364C50488E9F868E9F888C9D878EA0898A9B83899A8051564E
1B151C2321231D1C1C1C1B1A18191717171517181322251B505C457F947172836874856C
76866F7586707588716D7D6855615159665149544134382A3B3E2B383B29313525323726
333A29343C2A373F2D373E2E
444E5D4750644A526B4A536F4C55744E56764E58764E5977505B78505B78505C78515D78
505C79515C7954607B545F7C57627F59648058657F58657F58667F58667E5B68815D6983
5E6A835F6C846370876470886670896F7D937C8CA08091A48091A47C8BA077839A748098
727D94717C906F7B8E6E7A8E6C7A8E6C7A8F6F7C90717D90727D91727E92737F95758097
76819875819777839776829776819776829878849979859C79869D7B889E7C889E7C899F
7D89A17D89A17F8B9F7F8DA0808DA0828E9F838DA08590A38790A58790A58791A38893A1
8893A08996A28A97A28B97A18C98A28E9BA48F9BA68E9AA78F9BAA8F9BAB919DAD939FAD
939FAA929FA993A1A994A3AA98A6AB99A7AA99A7A999A7A99BA9A99DA9A79DA9A69CA9A6
9EABA89FABAA9DA9A99BAAA99BABA89AAAA69AAAA29AAAA199A99E99AB9C90A3934E5756
3D42413134322C2D2C2B2B2B3437325B6856586554566252525E4C454F3F3840312F3628
2C302434382A33342935342E494B4490A28891A28B8E9F8990A28B8B9D868B9C835C6457
1A141A2421221E1B1C1A19181716151717141A191621201B464D3D84997674866C748670
74857374847273856F75896F75896E76896C65735B393D303F4331383B2B2F33252E3325
313728333B28363F2A343B28
444F5D4751634A556A4B55704D57754C57754C57754B57754C59774E5B794E5B784F5D78
4E5C77515D78525E79545F7A55617B57647D56647B55637C56657E57657F5867825A6883
5B68835E6A84626E87636F8865708A6B769175819A78869E78879D748398728095717D94
707B926F7B916F7B926D7A916D7A906D7A906E7A90707C91727D93727D93737F94747F96
747F9875809875809774809875819977849B78849B78859B78879E7A89A07B89A07A89A1
7B89A07C8A9F7E8C9D7F8D9D808D9E828F9F848FA08690A48790A68590A78590A68693A6
8793A48794A48897A58997A58998A48B9BA58C9AA78C9AA88C9AA98E9AAA909BAB929EAC
929FAB92A0AA90A1A991A2AA93A3A995A6A897A6A999A7AA9BA9AA9CA9A89BA8A69CA8A7
9EAAA79EACA99CABA99AAAA79BABA79BABA599A9A299A99F97A99C97A99993A79657615F
454C4C35393A3032313639353C413A576353576554566351515C4B4854433943362C3429
2C31262B2E242929212825213F3E3998A98E9AAC938F9F8B8EA08B8C9F8A8D9E8A6B7668
1D1A1F2223221C1C1B1C1C18191A13191A1117150F1F1E17424838899E7C74866E738472
72827673847772857272896F72896C758B6C5D6B5540463A3F4639383E3133392C30352A
31372A353C2C373F2B353C2A
434E6047516649546C4B54704B56744956734956734C59744C59754D59764C59764D5B76
4F5C76505C77525C79535E7A54617A54627B55627B54607A55637C55647F576681596782
5B67825D69835E6B84606D86626E8865708A69768D6E7B926F7D936E7D936D7B936D7A91
6E7B936C79926B78936A76926B77906D79916E7A916D79916E7A92707B93717D94717E95
727E97737E98747F99747F9975819976829A77849A77849978869B7A899F7A89A179899F
79899F7A8A9D7C8A9C7C8B9B7C8A9C808C9E838FA0848FA28491A58491A58391A48593A5
8694A58794A48795A58997A68997A68B99A78C99A78B99A88D99A98F9AAB909BAB939DAD
959FAD95A1AD94A2AB93A2AB92A1A995A4AB97A6AC99A6AD9AA7AC9CA8AB9CA8AB9EA8AA
9FA9A89DAAA69CAAA69AAAA59AA9A699A8A39AA9A39AAAA198A89D96A79994A7965A6561
464D4C3032362F32323B413C404841596556596656576454515C4D4F5B4B454F432D312C
30332E2C2D28272421231C1E3834339DAD91A2B49992A18C90A08C8F9E8A8E9F8A6C7869
1D1C202323231D1E1A1D1E17191A1117170F16140F23221A4C52418FA58073876E708571
6F83786A7F7777928159705F5F76616B81695865563F48403E453B373E3332392D30372C
30352B343A2D373D2D333B29
424E6345506746526C4A54704A54734852734752734853734854734B56744D59744E5A75
4F5A754F5A754F5A77515C79535F7B53607B54607A535F7955617B56627E576580596680
5B67815B66805C68815E6A83606C84626F8564728767758969778B6A798E6B7A916B7992
6C78956A75946975946B76956B76926B76906C778F6D78906F7992717A93717B93737D95
737F94727E9672809873809775819775819776819876819976829A78849C78859B79869A
7A879B7B879B7C889B7D8A9B7D8A9C7E8B9F818DA1818EA1828FA38390A38390A38390A1
8492A28593A38693A38996A68A97A78A96A88A97A88B98A98C99A98D99A98F9AAA939DAB
959EAA94A0A9939FA894A1AB95A1AE97A3AF97A4AE99A5AE99A5AE9AA5AC9BA6AC9DA7AB
9DA7A89CA7A59BA8A49BA8A59AA6A49BA7A39BA9A19AA89E98A79C96A69992A494545D5B
3A3E412E30342D3030393F383E463C5C6A585A6656586253525B4F4F574C4F574B3F433C
3637342B2828262022231A1F373233A0B094A4B59A93A38D90A08D8E9E898D9F87677365
18171C2021211C1E1B191B1518191017180F16160F1E2017444E3D7E95726A80646A8067
718772586860718878697E6C3F4B446B7E6A5360543D443E3C433A353D3232392F333A2E
33392D353A2D363C2D343A28
404C65424F6845516D4853704A53734A53744953744854734854714A546F4B566E4D5970
4F5B704E5970505B74505B77515C79525E7A535F7A545F7A56627C57637D58647F596580
5A64815B66835D68835E6983616D85626E84626F8564728866748966748B67768E687490
6874916975926A75936C76946D77936B76926B77916E78916E7890707A91717B92727D94
727D93727E94727E95737F957682977783977982977B849B79839D77829B77829A7A859A
7C879A7C879A7C869A7F899C7F8A9D7F8A9E818BA0808BA0828EA1828EA18390A18490A0
8492A08492A08592A18894A38A96A58996A78996A88B98AA8B99AA8C9AAA909BAB919CAB
939CAA939DA9939DA996A0AB97A1AD98A2AD99A3AD9AA4AD9CA5AD9BA4AC9BA6AA9BA6A9
9AA6A79AA8A59BA8A49AA7A499A5A29AA7A19AA69F99A59C98A69B96A69991A193525858
3032393437392F323131342D41483A5E6B5459634F52594A4A4D444A4C4454584E494A44
3F3E3D363335342E3130292D433F3F96A48D9FAE9695A59090A08E8C9D8A8A9E88677567
1A1A20212324191A1A191A1418170F18170E17180E23271A30392B4653405C6E56667C60
596C54586A5363765E91AB88566455536054505F522C322E363B33363C30353A2F353B30
373D30383D2F373C2F33392B
414B64434D6848526D4A54704A54734A53734A54724B56724B55704B556F4B566F4C586E
4F5A6F4F5A70515C74505C75505B764F5B77505B76525D77535E7956617A57627D596381
5A63835C66855E68855E6A84606C85626E86626E8763708963718A64718C65738E66728F
6775916875916975926A76926C77936B77936C7A936B78916A77906D79916E7992707C93
6F7B93707D95727E97717E95747F977680987882987B839A7B839C78829D78839B798599
7B85997C86997D869A7F889C7F8A9E808B9E828B9F828C9F848EA2838FA38591A38491A0
84939E8594A084939F85939E8795A18795A48997A78A97A88A97AA8C98AB8F9AAD919BAD
929CAD929DAC939FAD949FAD97A0AD97A1AB99A2AB9BA4AC9BA4AA9CA5A99AA5A79AA5A7
9AA6A79BA8A69AA8A69BA8A69AA7A59AA6A39AA7A299A7A097A69D95A59A96A7995C6262
313136363A373234303131294044365D664E565E4A45483E3938374848475D615B61665E
4C4D4C4748484544424543404D4D4A88948098A69096A59190A08E889A88889B886C7C6E
1B1B202021211D1D191C1D1518160D17150B15140A2327182E3525343D2D3F4C394F5F47
2A34272F3C2C26302584A07B72896A252B24455242191B19282B232D312730342A34382E
373C2F383E2E373F2E323929
414A61434D67464F6C48516E48517048527049527049526E48526F4A54714C55724B5571
4C57704D58704F5A734F5A75505B784F5A78505B78515C78525D7754607956617B58637E
5963815A64845B66855D68835E6982606C84606C85616E8763708A636F8E647290647191
6572926672916672926774936974946A75946B77946B77936B76926C78936D79946E7A96
6D7A966E7B976F7D98727F98747F98747E98747F9977829A778099767F99768199778398
7984987A86987B869A7D869B7E889C7F8A9D828B9D828B9D828C9E838DA0838EA182909F
83929D83929D84939D84939F8493A28594A38796A68896A78A97A98C97AB8E99AC8E99AD
8F9AAD919CAD929EAD939FAE94A0AD95A0AB97A2AA99A4AA9AA5A99BA5A89AA4A69BA6A7
9AA6A69AA6A59AA8A699A8A798A6A698A5A597A4A396A4A296A59F95A49A98A899666F6A
3433393D403D393B3635352F3D3F36575F4C575E4E4C51463B3E39586156616C62829381
606960595F584445444B4B484B4A497E8779919F8C91A08F90A08F889787869784718070
1E1F242122221D1C191C1C1518180F14130B13120B1F22162D3525384331313C2C20271C
1B22181A21160F140C607655657B58151A122E372A1416121F2119272A212D312734372C
383C2E353B2C343A2B2F3627
414A5F434C65454E6A47506D48526F48517049537249527048516E4B54724C54734C5573
4B55744C56734E58754E59755059774F5977505A78515B79525C79525D77545E7956617B
57627D5963835A64855A64835C67825E6983606B85616D86626E88636F8B636F8D636F90
636E90636E916470936572956672956873956773946974956B76956C79946C79956D7995
6E7A936F7B95707C97727D97747E96747E98757E9A757F9A77829B76819B75819977839B
77839977839978849B7B869C7C879E7D899F7F899F818A9D838D9F818C9E818D9F8290A0
82909E81909D82919C8392A08492A28695A68694A88895A98994AA8B96AB8A96AA8B97AC
8D99AD8F9BAC919CAB929EAC929EAB939FAA94A1A896A3A897A3A698A2A59AA4A799A4A6
9AA5A699A5A69AA8A899A7A997A5A795A3A595A3A394A3A195A4A094A49B98A99A6B746F
37373E4042413A3C39323431454A4052594C555D4F4F594C40473F535E51636F61849680
81907C7C85753E3B3E4845473D3840777F76929F8F8B988994A3918D9C8A899885798777
201F261E1D211C1B1A18181315150E14150D16170F252A1C262C1E242B1E22281C191F16
161C14161C1112170C2B362338452F1218101C221A141813131610252B1F2F3627333B2A
373E2C363E2B333A292E3324
414A5D444D62464F6949526E48526F4850704A53734B54744951714A53724B53734B5272
4B54744D56754D56754D56754E58764E58774F5977505B77525E79515D78535E7A55617D
5661805863835864855A64845C66835F6984606984606A84616C87626E89626D8B626D8D
626F8F636F90626F906371916573926673926672926974946B76946A75946B76946D7993
6E7A91707A92717B94727B93737D93747E95767E97777F9877819976819A74809A77829B
78839A78839A78829979839A7C869C7F879E81889F838A9F858D9F828C9F818C9F838EA0
8491A18593A28592A18591A28792A38894A58996A68996A78996A88B97AA8B96AA8B97AB
8E99AD8F9BAD909BAB919DAC929EAC929EAA93A1A995A1A997A2A697A1A598A2A798A3A7
99A4A798A4A699A6A699A7A897A4A696A4A396A4A296A4A296A5A196A59D98A89C737D76
3C3D424145443A3E3D333735393E39464E42535E4C454D42323634505851636D63869581
8D9D879AAA914B4A4A3D383E35303A6D746F90A0908794878F9F8E90A18D8A9C87798977
1F1F2419181B17161613120F11100A11110814150A2025172127181F23171E2116191E13
171C13141A1112170E12160F11151013181215191312161110140E20271A2D3624313A27
343E2A333D28333C262F3723
40495B434D6246506948516E47516E48516F4952724B54744A53724952724B54734A5272
4B53724C55744D56754D57764C57764C58774E5977505D79535E7A525D7A535E7C55607F
5862835862855863835963815A65825E6883606985616986606B88636D8A626D8B606C8B
606D8B616E8C63718F6472916774926774926773926A75936B75926D77946D77936F7991
6F7A91707A90717B90727C91747F93747F94767F9677819977819977829B76819A768198
7783977983977B84987C84987C84987E869A81899C848B9E858CA0838C9F838CA0828CA1
828CA0848FA18691A38792A48792A48792A38894A38895A38795A38997A78A99A88C99AB
8E99AD8F9AAE8F9BAC909DAC929EAA939EA9959FAA97A1AB96A1A897A2A997A1A897A3A7
98A4A898A5A899A6A797A5A596A4A498A5A498A3A397A3A298A4A197A49D98A79C7B867F
3938414143453D403F37393A3336373D423D525D4E4B5448383B3850564F646B62849080
90A08DA4B89F636A6339373D3A393F646D6591A38F8695848B9C898CA08B889D877B8E7C
22252A13141918191916161314130E13120B12130A17190E1A1F121A1F121B2013191D11
171A111418111218121216130F121312151514181613171412160F1F26182A331F2F3725
323C29313D29323D27303A23
3E485E404C62434F68454F6A47506C47506F4851704852714852714953724A54734B5474
4A53734C55754B54754C55764C56764C58774E5A784E5B79505B79515C7A525D7C545F7E
5762815863825864825863815964815C67835F69845F6986606B895F6A89606C89606C88
606D8B616F8C63718E6370906673926874916673926672916975916A76916B778F6D788F
6F788F707A92717B93717B93727D94737E96737D96757F9A75819C75809B768199778398
7783967782957A84957B85967B85977C869A7F899C808A9D838B9F828A9F838DA1838EA1
828D9F848D9F858FA18590A28791A48793A48994A38995A38794A28896A48A99A78B99AA
8C98AC8E9AAE8E9AAB8F9BAB929DAA959EAA969FAB97A0AB95A0A996A3AA96A3A897A4A6
96A3A697A5A698A7A696A5A496A4A399A5A398A3A196A19F97A29D96A19A99A69A78807B
38333F403E444142444346453E403F3B3F3C545F52525C4F494F474D524A626B5F839280
8B9B8998AB957C887A4041453C3D43636D679AAF99879A88899D8B889D8B8A9E8B819483
282C3314151D191C1E191A1916171213130D11110B14160E181C12181D121B1F131E2215
1D1F161C1D171B1D1A1A1D1E1A1B21191921181A1F15171810140E2028192B3420313925
333C29333D2A323C2A323A27
3E485F404C65424E68444F68444E69454F6C464F6E46516F475170495171485170495272
4A53734A52734B53744D57774D58774D59774E5A784D59784E5979505A79525C7D535D80
565F815862825763825763815763815A66835C67845D69855F6B895F6A8B5F6A8A5E6A89
606D8A616E8A616E8B626D8C636F8E65718E6571906470906974926975916A768F6C768E
6E778F6F7A926F7A956E79966E7A95727E98727E98747F9B75809D75819B758099768197
7783977882977983987A83987B859B7C889E7C889E7D899F7F8BA07F8BA0818DA0818C9E
808C9E818C9E838C9E858FA0858FA18691A38792A38592A28593A38695A58896A58998A6
8B99A98F9AAB919BAC919AAB939CAC959DAD979FAD979FAA95A0A895A2A894A2A693A2A3
93A3A294A4A296A4A395A4A395A4A297A5A397A4A296A2A096A2A095A19C99A79C6D7370
352E3A3D38404140454A4E4D414644393D3A515C4F505A4E51594E4B4F485C635A849280
8A99858B9B84899882454547302D38646E6B9AB09D86998A8B9D8C8697878A9B8880917F
24242C1A19201D1E1E19191715151212120E13120D181A121C1E141C1D152B3122282D1F
20231727272027252542454432343927272D26282918191913140F242A1A2A321E2E3623
323A25333B27333D28303924
404961414B65424D69434E6C434E6A444E6B444D6B444D6C47506E47506F464F6E474F6E
4951714951714A53724B53724C55744C56754D57754E58774F5878505978515A7B515A7D
545D8057608156628158637F57637E5965805A65805B66825C66865E68885F6A895F6989
5F6B89616C89626E8A636F8B646F8C64708E646F8E646F8E67718F68728E6A748F6C758F
6D768F6F79916E7A936F7B946F7C95717D95727C96747E99747E9B747E9C747F9B747F98
7781977982997A83997983997A839B7B869E7C879F7C89A17E8AA27F8BA27F8CA07F8B9E
7F8D9E808C9E828C9E848E9F858FA18690A28691A28592A18693A38795A58795A58896A6
8A96A68D98AA9099AC919AAA929BAA949CAB959DAB969EA8959EA795A0A893A1A593A1A3
94A3A394A3A395A3A294A3A293A2A195A2A295A2A197A2A296A2A194A09D98A69D727976
2D263444414744434944474B3A3E42373C3C4C574D4D594D505A504347446B756890A18B
78847587968183927D41414329243262696798AC9A8A9B8B8D9E8C8997858C9B878D9E86
29272B1E1B1C1C1B1717161114140E14140E15150E1B1D131F22181919144049373A4234
2E322A5861523C3F3D59625B3E4245292A2F292B2A141414191C14282D1D292F1C2B321F
2F3624323926333C272E3925
41485F404862424B68424B6B424C6B414B6B424C6B444D6C444D6C454E6E454E6E474F6E
464F6E48506E49526D49526F4A53714C54734C54724D55744E56775058774F5A77505B78
535D7B545F7D55617D55617B57627A58637C59647D5964805B66835E6985606985616987
606A87626C88626C89626D89616D8B636F8E64708E65728F67728F68738F6A748F6A748E
6B758E6D778E6E788F6E7990707A92707C94707C96717C97727D98727C98737D9A748099
767F997881987982977882977982987983997B869B7D899E7E8A9F7E8AA07E8B9E7D8A9D
7F8C9D808D9E818D9F828EA1838EA08590A08692A08792A28A95A48A95A58993A48A94A5
8B95A68E97AA8F96AA9099A9939CA9939CA8949DA8969FA896A0A796A1A795A2A596A3A5
96A3A496A2A396A2A395A2A395A1A395A1A395A1A396A1A295A19F95A19B96A49C7F8884
2B2835676F694C4E514A4D4E3E42453033384F58524F58514F57523D41426672669EB699
727F718595817683743B3B41312F3B5B61628191868696888E9E8B89978287967F8D9E83
2F2E2C1F1C1A1F1D161B1B1018190E17180D17190E1B1D111B1F1415191222271F4D5847
5A66566E7D6A646D636E796D5C655D484E48363C371B1C1C21231D262A1F292F202D3223
2F3425333927353D29303926
41485E424B63434C67424B69424A6B424A6C444D6F444D6E444C6D454E6E464F6C474F6C
48516D47506B47506B49526D49526F4C55734D56754D56764E567850587B4F5979505C79
525D7A55607D555F7B555F7A58627B58637B59637D5B64805B65815D65825F6783616885
616885626A84616A84616B85626C87646E8A646F8C65718D65728D66738C68748C69758C
6975896C768B6E788D6F7990707992717B94717B96707C97707C97717C98727C99747F9A
7580997681987580967982977B82987B83997C859A7D889C7F8A9D7F8A9D7E8A9C7E8A9D
7F8B9E818C9E828DA0838FA2848FA08590A08792A28993A38994A28893A18994A28994A2
8C96A68E96A98E96AA909AAA929CA8929CA6949DA696A0A796A1A695A1A596A1A696A2A5
96A2A598A3A698A3A697A3A697A2A597A2A396A2A296A2A195A19D94A09996A499869189
2F2C385054544D51504F55513E43422D2F345059534E56524E5650454B4850595394AC91
849882899E86788878565D5C40414B5F666B666E7185948A8FA08E8A9B8486947B7E8E72
2A2A251B18151E1C1519190F18190E181A0E181B0D1A1D0F1C1F121C1F1512120D4A5241
7B8A716F7A69737F70768375707F6F68776640473F2426242A2D262B2F232B31222D3323
2F3424303626343A28313727
434962444A66434A69424A6A42496A43496B43496D444B6C444A6B444B6A454E6A474F6A
464D69464D6948506A49526C4A536E4C53704D54744C54744B54754F577950597B505B7D
515B7C535D7D545E7D545E7C56617D58627C5A637C5C637E5D64805E64815E6481606882
616A84616A83606A81626B82646D85666E8766708964708B65728C65728A66738A677588
6874866A75876B75896D768C6F788E6F7A90707A91717B92707C94727C95737C97747E98
757F97747F95747F947781947A82967C83987C84997D85997D86997E889B7F8A9C7E879C
808A9F828AA0828BA0848CA0848E9F878F9F87909F8792A08892A08892A18893A38A94A5
8B95A68C95A78E96A88F99A99199A8939BA5969EA4959EA2959FA1959EA1949EA295A1A5
95A1A597A3A698A2A597A2A595A1A496A3A296A3A295A2A093A09D93A09A92A1978C9B8E
3A39404244465B635C49514C3A3F3C26292A4D574D4D554D4E564E4C52495F695B91A68B
7686767F907F8293837B897C5C60614C4B556F74757C84808D9B8D8A9A8686957E7D8E74
2829261C1B191C1C1717191017190E171B0F151A0C181B0C262A172A2C1E1714103F4137
7F8F756D7769727E70748374708170697A663C453C1C1F1C2B30272C32272C33252C3424
2D35252E37273038292F3729
43465F45486545496944496A454A6C45496C44486B44496B444A69444A68454C68454C69
464D6A454D6B464E6D49526E4B546F4C536E4C536F4C55704B54714C53734F5677505A7B
515B7C535C7D545E7E56607D56617C57627B59627A5B627B5D637D5F647F5D63805E6581
626A84626B84616B83636C84646D86656E88676F8967708A68708B68728C68738B6A7489
6A75876B75876B74896C758B6F788C6F798D6E778C6F788E707A90717B91727B92757E95
767E96777F96777F957881947B83957C84947B83957D85977D85977E86997F879B80889E
8189A18088A1818AA2828BA0838D9E868F9E868F9E88909F8991A08A92A38B93A58D95A8
8E95A98D94AA8E96A99098A99199A7949BA6969DA4969EA2969FA2959FA1949EA1949FA3
96A1A595A0A7959FA595A0A594A0A695A2A695A2A494A1A194A1A1919F9D8F9D9791A195
46484B4044457381724B524D3C413E27292B4B554B4C564C4D574C474D4450554A7E8D76
7785727B88768796838391807981753E3941646666767D788B978A8896868595817B8D77
30342F1919181E1F1A17191314160F15190F13170D11150A3743294D593D1614104E5447
7A88736C786B717E71738274718373697B68424D412D352D313B2F2E362B2C33272C3526
2C36252E39272E39282D3727
434660444865454967454967464968464869474A69464A69454A68454A69454B6A454B6B
444C6B454D6C464D6E4950714951704A526F4A536E4B556E4C566E4D56704E5774505978
515A7A535B7D555F7F55607D545F7B56607B59617B585F795A617A5D637C5E627F5F6481
606583606785606785616984646C86646B87656C87666E88676E8B686F8B687089697289
6972886972886A73896B748A6C76896E798C6E798B6D778A6F798B717B8D727B8E747C8F
767D91777F92777E927981937A82927B85937A84927B84957B84977D85997F879C8087A0
8188A28188A38189A1818AA0818A9D838C9D868F9D88909D87909F8891A18991A28C94A4
8E97A78F97A98F96A89096A79198A69299A6949BA4959DA4959EA5949EA3939DA1939DA1
95A0A4959FA6949FA594A0A794A1A893A0A892A0A6929FA2929F9F8F9D9B8E9B9792A299
6067672C2936677168535B544046412D2F2F4E584C4D574B4951473C3F3A41443D5B6354
75826B8494798A9B8286957F838F7D3A373E5B5D5E78807A859186849184849584778876
3135341B1B1C1F201D1A1B1715171212150D11140C0E100B35402C4B583F12100B454A3C
75826C6D786B6F7C7072817472837370826F4651472E352E323A2C2D35252C32232E3424
2D34232E37242E37242E3724
41455F42466244476446486646486846486A46496A454969454969444A69434B69434B68
434B69444C6A444C6A464E6C49516F4A52714A52714A54704C56704C56704D56714F5774
505775515979535C7D545D7D545E7B555F7B59617C59607A5A62795C627A5D617C5F637F
5F64815F6582606783636B82636B81656A83676B86686B87676C8A676D89676E88677089
67708969728A6A738A69728B68718A6A748B6974886A74866D77876D77866E7887727B8B
757D8D767F8F7880917981917982907984927883927983937B85957E86977F879A7F869D
7F869E7F879F818BA1818B9F828B9E848D9E858E9D87909D87909D88919F8891A08A93A1
8D95A38F97A49096A49297A69299A69299A5929AA3949DA4939FA3919EA1919EA0919E9F
939FA195A0A2959FA296A1A593A0A393A0A3939FA3939FA1929E9E919D9C919E9993A29A
6F7776292533454948424843373B37383B364D55494C54474D564942483F383C363F433B
65705C88987E92A38B899683859082403C466D747079837C869288859285859485798777
2C2D2F1C1C1E1F1F1E191A1614161011140B1012090F0E093E453456634B110F0F30322E
72816D6B796A6D7B6E70817271837270826F57665532382E292D212B301F2C321F2D3320
2E34212D35222C35232C3422
3E455C40465E454962474866474868464768444668444768444868424865424A64424B65
434C65444E66444D66434C66464F69474F6C48506F48506E4B53704C54704C56714E5773
4F5875505A78525C7B545C7C545E7C545E7C57607D59627C5A627B5C637B5D647C5D647D
5E657F606781616781626B8161697E62697F676C82686B83686B85686D88666D88666E89
666F8A65708967728A67718A666E87676F85666E83646C81656D81676F82656E81677182
6B74846D75866F7888717B88717C8774808A77838E7985917B87947D88967F89997F8899
7F899A7F8A9A818C9A828D99838D9A858E9D858E9D858F9C87919D8A92A08B92A18C93A3
8C93A58E94A69096A59097A49299A5939AA5939BA4929CA1909D9F909EA0919E9F909E9F
93A09F95A19F95A0A095A1A294A0A294A0A3939FA1939F9F919E9D8F9D9A8E9C9791A198
6D76742C28363534372D2D2E2322244C5445515B494F57464E56443F4536393E32353730
575E51A3B99A92A28E8B9988889484474449838C80858F848A95888894868492807E8C77
31322F1716171E1F1B1A1A1516170E14140A1212090E0C05424A3659654E161213363A37
67766964736867786C6A7D6E6C806E687C675565512E3529212619292F1E2C311F2C311F
2B33202D36222C35232A3322
3D445D3F4660434865454867454768454668434667434667424866424965424964434A64
444D65444D65444D66454D67464F6949516D4A516F4B50704C52724E55744D55744D5575
4E587850597A50597B525A7C545D7C545D7C555D7C58607E59617D5A627C5A637B5C667C
5D657D5F667F606781616781616880636A82656D83656C84666C84676E87676D8A676E8C
656F8D65708C67718B687289667087677086666E84656D81666C81666C83626A82626B81
646C81636D7F636B7E656E7F66717F6874806C78836F7B8873808D7582917986937A8894
7C89957D8A957F8C957F8D93808D94838F99848E9A848E9887919D8992A08A91A08A90A0
8B91A48D92A68D92A48F94A49297A4949AA4939AA5929BA2919C9F919C9E919D9E929E9F
94A1A095A1A0949FA0949FA2939EA3929EA5919EA2909D9E909E9E8F9E9C8A9A968EA096
727F782F2D363432332D2B2B1F1C1C575F4D5A65505059454C544131332932342A3A3D32
42453B9AAE8E97AA92909F8F8C9A8A5152518C9786939E908D988C8A988884958182957A
3F46391514121F20191D1D151D1C1319190F17160D110E083D4232616D56201D1F4C534D
66746B61706B5F716A5F716661746361745F343E342A3228272F22282F1F2A31202C3221
2D34212C34222B3322293222
3E435D404662424966434967444868444768434667434767424766434766444866444966
444B67444C67454D68464D6B464E6D48506E48506E4A506F4A51714C53734D53734E5375
515779525879535A7A545B7B565D7B575E7C575E7C585F7E575F7D57607C59627B5B647B
5C647C5E657E5F667F606681606682626883646B84646C85646C86666D87686E8A676D8C
666D8D676F8D69708D6A728C6A728C6A728C6C728B6C72896C72896C718A6A708A677089
666D87646C85636A81646C81656D82626B80636B80636C80666F816871826C75846F7885
717B86747F8975828B78868D7B888E7F8C91818D93848E9487919989919D8A929E8A919D
8B929F8C94A38D94A28E94A19197A29198A19299A0939B9F919A9B919B9C929B9C929C9D
949D9F969DA1959CA1949DA2949EA2929EA1919FA1909F9F909E9D8F9D9A8C9B968D9F95
7D8C823F42443737342F2D2825211E5C624F5B63504F55454A5241383E31353B2D3D4435
3739317B89729BAE9390A0908C9B8E69716E808C827E8984818E888C9E9084978581947C
3D4337161411201F191D1C171E1C171B1A1418161016130F4246386C7A62454B44606B5E
647165637167434C4B33393B4A584C677B61313A2F272F242A332529302129301E2A3220
2B33232C33222C332129301F
3B415A3E455F4047613F4561414563434665414564414765424665444766454767464868
454968454B69444A69444A6B454C6E464D6D454D6B464E6B474E6D494F6E4C50704E5273
4F5374505475525778535979545A79555B79565D79575E79595F7A59607B5A617B5B627A
5C637B5E647D5E637E606481636684636683636583646784646885666A87686C896A6D8B
696C8B686E8C68708C69708C6A718B6A708A6D728B6F758D70768D71768D70778E6F768E
6E768F6D768E6C758B6B73896B73886A70876B7186696F82676E7F676E7D686D7D6A6F7F
6A6F806B70816A70816A72806C76806E7981757E867982897F878D838A92858C94878F95
8890998C939D8D949D8D949C8F979E90989E91999E919A9B919A98929B9B929B9C939B9E
959C9E979DA0969DA1949CA0939D9E929E9D93A09E929F9D929E9D909C998E9C95919F94
7E897F47474A3937382C25254542397F886E575A4E51564B4E5548444B3D3F4737404538
41443B727C6896A58C92A18F8A978B838E87828F885E666B6E7C778DA28F7F927F80937B
3D42391B171621201C1C1A18191815181613151310181614474D3F697862606D5C667563
667463697967373B3C1A1A25282E31556755323D31272F252A33272A3124293122293222
2B34242B33212A321F2A311D
3C415A3D435D40466040455F414660424761424761404662404663414765444768454869
43466943486B444B6C454D6E464E6F444C6E444C6C454D6B464D6B4A506E4C51704D5271
4D52724D52734F5476515676525877545A78575D78575E77585E77595E785A607A5C637C
5C637C5D627E5D6180606383616485636685646785646883636783666986676A86696C86
696C86696D87696F886870896770896870896A718A6B728B6D748C70778C71788C72788F
7178906F788F70798F727B8F747D8F757D8E777E8F777E8E747C8A727A86717884727786
7174876E71876A6E84686D82676E80666E7D6A707F6D73816F7583727785767A88797E8C
7C838F808892838B93868E938993978B96988E999A909B9B909B9B939C9D919A9B939B9C
959D9C969E9B969E9C939D9C929D9B929C9B919D9B929C9B939C9B929B9B919B97919D93
8691864240463734392D282D646A5BA4B6924C4D424B4F444B5045454C3F4148393E4134
4141366A705E919D8595A28F8D988B8A958B7C8582575A62667170899C8C7D8F7F7D907E
3F46431513181F1F201A1A1A1717161716141614131613144950426E7E67647160687765
6B7967707E6C4248451817233942422C343328312B283127283126293126283125293324
2D35232C35212A311F292F1D
3D415A40435E42466142466141466042475F424760424761434762434665434666444667
43476842476943476A444B6C464E6D454C6B454C6B464C6D474D6E4A50704A51714C5272
4E5272505474515675525775535774555A75565C77555B77555B75575D765A60795B6179
5D637B5D627C5E617F60628360628262648365688565688265687F686A81686A836A6C84
6B6D856B6F886A6E87696E86686E876970876A70876C71896E748C6F758C70758B72778D
73798F73788E747A90757B91767B92787F92798092787F90777E8F79808F7B838F7D828F
7C7F8F7B7E91787C8F757A8E73778A7176887074876E72876E73876D71866E7186707386
737687767A8A767C89797F897C838A7F878C838C908890938A92948A93938D9695909897
939B99959C9A969E9B949C99949E99949D99939D9A929C9A919A99919A9B929B99929E94
869185444146322E34322F3177836B839173505445484D414A4F4443483D373A2F35362A
35322759594897A2878D94868E958D8C948D7C817F72777464696A89998B7E8F817C8F7F
3F464416141B1F1F211B1B1B1A1A19191916151311141211505A476F7E625D6754596253
5C66566C78654D554B19181D4953491E2122212623262E2527302528302328302128301F
2C34202D34202C311F2A2E1D
3F425740435941445D42446042456044475F43465E43465E434760424562424463414663
414762424863434965444966454B68474B68474D6B494E6E4A4E704A4F714A4F724C5072
4D51714F537050556F525670535770545A71565C72555B73565B73565C74585E765A6077
5C60795D617A5E627C5F627E61627F626281656683656882676A7F696D80676B7F686C81
696C836B6D846A6D846B6E856B6F866B6E856C6F856E71876F738A6F748A6F748A71768B
71778C73778C767A8E777A90777B91787D907A80907A808E797F8E7A808E7B828E7D838D
7D828F7E83917E84937F86957F84947F83957F85967E83957B8194787E91777C8F777A8B
787B8A767A89767A88757985777B85787C837C7E857E81877E8388808689848B8D868D8F
888F908E9595909795929996949C97949C97949D99929C9B919A9A909897919996929C93
8A9386423E432F282E4F514869715E5153474E4E46494A434B4F45484D413B3E31383A2B
3E3D2D52514098A1839096869AA1969399928589837577746C6E6A8F9D8B81907F7C8D7A
373C3A17161820201D1C1C191A1B17191B1513141016171355624A5D6A50373B2E33362D
4D53436570594F5645201F1C34382E1D1E1B212720232A21262E22272F22272F21282F1F
2B31202D33212D33212B301E
3F40543F415640435A42455D44465E43455C43455C43465C41455D42455F424561414862
3F4660424861444A62444A62454B64464A65464A67484D6B4A4F6E4A4F6E4A4E6E4B4F6F
4C51704D526D4E546E50556F51576F535A6E555C6D555C6F565C71575C73575C74585E76
585E775C60795D60785F627B61637E63637F65658164668065677E676B7E666B7C666B7D
64697D666A7E696B816A6D836A6E84696C836C6F836E70866F718870748A6F73886F748A
71758A73798A74788B76798E777B8F787C8E7A808F7B818F7A7F8D7B808D7C808D7C818E
7D82907E84927D84937D85937F8695808796838B9A848C9A848B9A838B99848B98838796
8185937E83907B808C797D88797D86797C847B7D837B7D827C7E837D81867F8488808588
818789858B8C888D8C8B908F8E9493909896939A98939D9A929C998F98948E98928F998E
8C9786413E41281D246B705E757E685B5E514A48444A4A454D52484A514444493B404434
4245324C4D3B8E9879939C86ACBAA59DA7998A91857F83796B6D658A978183917B798973
383D381412141E1E191A1A15171A14151913121610171C1337422E424D372F34252A2C21
4A513E677659515C451C1D1823261D22271E232920252A20262D20272E21272D22293022
2C32232E34222C32202A2F1D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 300},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001;2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`003Ooooon]0?oooa[ooooo00H04108010?1`0@3`T04A0;014@3@0B4@h2
018A3@0;01DC3@0D4``05A@=01HC3P0C4Pd051<<01<D300A4P/04A8=014C300C50d00P0D5@d2014B
2`09010B2`0>40X03Q0;010C3@0@50l04A<?010B3`0B50l04a@?00805A@?00@051@>01@D3@0C4``0
5AH?0P0F5a001P0D5Ph051H=01DH3`0D5Ph051D=018D3P804aHA00H051L@01<F3`0C5@d04a@<01@E
3@0E5@d201LG3`0301LF400H61@05QLC00805aTE00<05aTD01HG4`0D5A800P0D5Q801P0B51004A@>
018E3@0B5@d04Q<<01@E3P8051H@00<05ALA01DG4`0E5a<00P0G6A@01P0D5A0051DA01<C400D5140
5QLC01LI4`805aTA00`05AL?01HH4P0E61405APA01DH4P0E61405aTA01HE3P0F5Pl05QHA01HE400G
5Q0201HF400301HF4P0E5Q805QLD008051DC00H04a@A01<B400F5A4051@?01<C3@0C4`h2018B300;
01<C3@0@4@d04A8?018C3@0A4Pd051<?01<C3`0B4Ph04A4=018B3`0A4@h00P0A3``0300>30T03`h9
00h>2P0>3`X03a4:010C300>4P`03A0;00`?2@0;3@L02Pd600`>20802`d800/02`/600/:1`0>3`/0
30h=00/>4@0;31403@/A00`93P0<2PX02`d:00T:2P0200T;2`0;00T<3@0<3a800@87004210020P<0
0@8400811P020@L00P4800<220030PH00P030PD00`020@H00@450081100200@2100300D20ooooooo
oooo00gooooo000=ooooojd0oooo6_ooool01P0F6AH06alK01hQ7P0N8Al07AlQ01hR9@807b@Q00/0
7R<L01/P5`0J7aD0724D01hT5@0P9AH07b@E01lS500N8A<07b8D01hP500201hR500;01lT5@0O91H0
7R@E01XO4`0L8AD06b4D01XQ500K8AD07B<H020T6P0Q91`00P0P8a/0300Q9A/08RHJ028W6@0Q9QT0
7R@I020V6P0R:Q/08b`J02D]700S:aX09BXK02<V6@808bLK00/09RXL02@Z6P0S:1X092/K02H/700W
;A`0:RlN02P/7P0X:b4092LO02DY7`0202H/8@0;02<[7@0V;al09RhM02L]7@0X;al09R/N02P/7`0W
:ad09R/L02D[6`0V;A`00P0V;1d02`0W;Ah09RhQ028Z7@0T:a/09RdL02D/700W;ah09R`L02D[700[
<R009R`K00809RdJ00`0:2lM02`a8@0T:AT0:BhM02HZ700X;1h0:BhO02da800]<B40;2lP02`_8P0/
;b4202da9@0602T]8@0W:ad09BXJ02H/6`0U;1`0:2dM0P0Z;ad00`0Z;Qh0:R/O02PZ7`0202T]800;
02X]8`0S9Ah08R@L024S600O8AL08B8H028T6P0P8A/0828K028S6`0P8aT00P0O81H0200K7A8092LH
024S5P0R91H08RDF024T500L81806b0A0P0M81403`0K7Q006QdA01/N4P0K7Q806A`A01/N4P0I7a<0
5ahE01LO5P0N9b4030hF00d<4`0=3@d02@/800T;1`0201@J400400dA2`010P400P8100840@800@81
00D00P83008210010P@00@@400440`0400430@0400440@02104010<100D30@oooooo000=ooooojd0
oooo6_ooool01P2G[YP0W;BO09niXP2O^Z40OI5o020T:`806A/O00/06AdK014D4@0?4P`03a8901<H
2`0H70h06Ad>01XN3`0K7@h071l?01/O3`0201`P3`0801dP400J7A00720C01`P500O8QH07R<G01dS
5`0O9AX201hS6@0?01lT6`0P91/082@K024U6`0Q9AT08BLH020U5`0N8QD07bDG01`T5@0N9Q@08RLF
02<W600T9aP08R@F00808bHH00/092HI01lQ500P8QD08B@F028X6@0R9aT09BXJ02HZ7P0V:B4092HP
02HY8P0202@Z800;02D[7@0W;A`0:2hK02T^6@0Y;AT0:RhO02TZ7`0Y;1h0:BdM02T^7@0W;1/00P0Z
<1d02`0Y;ad09bdM02L]7@0Y;Qd0:RlM02T_6`0Y<1h09B/J02P]6P0Y;QT0:c0J0080:RlI00`0:BhH
02L/6@0U:QL09R/I02H[6`0U:1X09bTK02PZ7P0[;R80;2lR02ha8P0_<R<202da8`0;02X_800[<200
;38P02Xb7P0_=R40<3HS030e8`0^<R80<CHV034e:00^<R@00P0_=2D02`0_<RH0;BlU02/^8`0X:b00
:RlR02/^8P0^<2@0;BlU02L[800W:Qh09RPL008092HJ00`09RTL02DY6P0T9aL09BLE02LY600U:1L0
9BXG02DX5P0S9QD09BTH02@X600R9QL202<X6@0;01lS5P0P91H082@E024T500K7`l0728@01/P3@0G
6``05a`B01LK500E6A@00P0H7QD02`0J7a@05Q/=01DI300E6@h04aH=018E3@0G6Pl061/@01LK4P0D
5a4051TB00804aL@00H051PC01@H500E6Q<05Q`B01DJ4@0F6Q8?ooooo`003Ooooon]0?oooa[ooooo
00H0UjjL09fgY@2Q^jD0WkVQ09VbVP11BdT2018D600;01TN6`0F6QL04aLB01DJ400F70h06R0?01XQ
3P0H7`h06Ah>01/Q3`0N91800P0O8a402`0O8Q407b4D01lO5@0O8AT0828K024S6`0Q91/082@L01/P
600M91X07RDK00807bHK00`07bLJ01lV600O9aP07bDE024V5P0T:QX092/I024Y5`0R:AL09BXG02DZ
600U:AL202@V600;02DW6@0T9QP08R@G02@W6@0S9Q/08RPJ02@Z6`0X;B409R/R02@X800S:1h00P0V
;1h02P0W;Q/0:BhH02/`600Z;AL0;30K038d8P0`<240;BhQ038b900_<B8302h`800:02PZ7@0U9a`0
9BTL02H[700`>B<0:S<N02D_6P0V;AX09bhH02T_6@<09bdG00L0:2dH02T^6P0V:aL09BPG02HY6`0V
:Ad09bPM0080:BTQ00<0:bhT02d`9@0^<RD00P0/<R<02`0/<R409bhL02Pa700[<a`0;C<M02hd7P0_
=Al0:c4N02hd8P0_=2<0;S8Q0080;S8S00/0<cDV034d9@0/<2<0;2lU02/_9@0[;b<0;S4S02da8`0Z
;R40:2`L02L[6`0202LY6`0<02HY6P0W:aX09b`J02P[6P0W:QX09bTJ02DV600U9aP09bTK02HW6`0S
91/08R@J0P0R9AX02`0P91T07b@G020T5`0P9QP07bHG01lU5`0Q9QP07B8E01PM4P0H7aD05a`E0080
5Q/D00/05ATB01LK400H71006A/A01LH3P0H6Q006QXB01TJ500I6AD05ALE01DG500201DH5@0601LJ
5P0F6AD05a/E01PM5P0G71D05ATB3oooool000gooooo[@3ooolJooooo`0609B]V`2O^jP0X/2Y09nj
XP2M^J00KH5b0P0O92L02`0L8B005a/H01<H4`0D6A405A/@01LM400J8A407B@B01hT5@0N8A<08B@F
00808RDF00/08b<F02<S6@0R8a`08B8L01lP6`0N81T0720I01lU7@0L8aX07BDI01dU600201hV600<
01lX600O9aD07bLD01lV4`0R:AH09BXG02<W500T:AD09R/I02HY6P0U:1T092PI0P0V:QX01@0W;1`0
9R`K02HZ6@0V:QX092TI00809BTJ00@09b/O02DZ800R:1l08BLM0P0V;Qh02`0Y<ad0;C@J02`a6P0^
<1`0;RlM02h^7P0b<B<0;blR030a8`0`<B@0<34S0080<C<T00D0;2lQ02T/800Z;B80:2`O02H/6P02
02H_6P0402@/5`0W<1P0:2hH02X_6@80:c4J00`0:blL02/^7P0Y:a`0:2`L02DY700V:1l09RLO02X]
900X:b80:RdT02db9@0^<bD202/a8P0;02Xb8@0[<al0;C@M02he7@0a=b00;c@P02/_7P0]<R80;C8S
02lc9P0_=2L00P0_<bD02`0_<b@0<CDV034e9P0`=2H0;cDW02hd900^<b80;C8O02hd800^<al0;C4O
0080:bhN00`0:B`M02T^7@0Z;al0:RhO02P/800V:Ah0:2/N02HY700U9a/09BHL02<T6`0S9A/202@W
6`8082LH00T082LG02@Z600R:1@08RPG020U5`0N8aH06b8F01TO5P0G7A@00P0G7A<02`0H7a<06B0@
01/O3`0K7@l06aX@01/K4@0M7aD071hD01`M5`0J7AT05a/G008061/F00H06AdG01LK5@0H7AD06R0D
01LK400H6Pl?ooooo`003Ooooon]0?oooa[ooooo00H0M89`09N^TP2J]IT0W[^O09jlW`2@[8h204=A
AP0;014F5@0I7QT041@?00lC300B5Pd05AT@01PN4@0J8A<0728F01hR5P0Q9AX00P0R9Q/02`0U:Q`0
8bLJ02<U700Q91X08B@I024T600O8aD07B8E01hS5P0O9AL07B<D00807bHE00X07bLE02<Y600V:aX0
9BXJ020W600U;1`09BXJ02@Z6P0X;Ah0:2`M100X;1`02`0U:AX0:2`J02P/6@0W:Q/08bHG028V5`0O
9AP082HK024W7P0Q:B009B/Q0080:BlR00/09blN02T`700]<ah0;S@O02hc8@0^<200<3<R02d`800_
=2<0;c@V02lc9002034c8P0;030a800_<1l0;c0Q02T/7@0X;Q/0:2lK02H]600V;1H0:2dG02/`6`0[
<A`00P0/<ah0300Y<1h0:BhN02P]800W;Al09B/L02D[6`0U:AP0:BdN02/_800/;R40;30Q02``8080
:c0P00/0;SDS02dd8P0`=b@0<cXV038g9P0a=BP0;c8Y030d:`0]<BP0;C<X02dc9P0202hd9P0302le
9`0]=2H0;S@S0080;S@R00H0;C<P02lf800`=Ql0<CDQ038c8P0a<R@2030b9P0;02d`9@0Z;R<09bdQ
02X`8`0V;B009RhP02L^7@0X;A`09b/L02@W6@0T9QP00`0S9QP02`0R9AH08bPE02<X500S:1<08BDC
01hQ500O8QL07B0G01XO5`0J81L06AlC00805adA00/05ad@01PN300G7@X061d;01PL3@0H70l06b0D
01`P5@0I7a@06b4E01/Q5P0201XP5@0601TO5@0H7Q<05ah@01PN400H7A005AP<3oooool000gooooo
[@3ooolJooooo`0602P]8P12C3/0EfA?07V>K@25WgX0UKB:0P1SNEX02`0?4Pd04QH?00lD300=40`0
3Q0=01<G400F710061hB01XQ4`0L8QD082HG008082LI00/08bLG028V5P0Q9AH08bDI02DY6`0T:1/0
9BTK028U5`0S9QL092PH02<W5P0202<X5P0<028X5`0U:AX08bHJ028W700R:Ad08RTK028Y6P0T:a/0
8bXK02DZ6`0V;1/0:RlM0P0[<1`02`0X;AX09BTI02LZ6`0V:AX092PJ02<Y6P0S:Ad08RTM02H^8P0S
:Qh092`M00809B`N00/0:30O02Pb700W<1T0;3<K02dc700/<Ah0;C<P02db800^=B<0;S<T038g:@02
03<f9`0;03<d8P0c<b40;RhL030b7P0/<Ah0:BlL02H/6@0T;AT09RhJ02@/6`0V;a`00P0U;QT0300X
<A`09bhM02P^7P0X;Ad0:2hL02L/6P0V:1L0:b`K02h_7P0/;Ad0;BhP02h`8@80:blP00/0;38R02`c
8P0^=280<CLT034f9@0d=bT0<SDZ034f:`0_=2T0;C4U02`a8P0202hc8`0;02`b8`0]<bD0<CPV034g
900_=B80;34O030f8P0b=R80=3DQ03<d8P0`<B400P0Z;Qh0300]<R409b`M02P]7@0X;Qd09B`L02D]
6`0S:aL09B/F02P]600W:aX09BLH02@V5`809BPI00/08bHF02@X5P0R9QD08BDC01`R400M8a@07R<F
01/P5P0J81L06B0E01PM4@0201PL400;01<G300G7@l051T:01<H2@0C5PP05a/=01PM400I7Q406AlA
01dT5P0K8QD00P0J8A@01P0I7a806AhA01HK2`0F6@P05aT:01@F2Poooooo000=ooooojd0oooo6_oo
ool01P0X;B80@T`k05MTC`1iSVd0QImj09FdRP80HgUJ00/03a8=018F3`0?50`03A0<00h@3@0C5a00
5Q`@01PN4P0J8A<0728E020V5`02020W6@0;02<W5`0R9QH08BDF02<U6@0U:A/092PK02DY6`0R9AL0
8bHG02@X600S9aH00P0S:1H0300R:1L09BTJ02<V6P0R9a`08RTM028Y6`0R:AX092/K02<Z6`0U:Q/0
9R`K02X_7@80:c0L00/0:2dJ02DY6@0W:Q/09RTJ02@X6P0S:AX08bTM028Y7@0V;R808bXN02@/7@02
02D/7P0;02P`7`0X<Q`09c0I02`c6`0]<a`0;34N02dc800]<R00;SDS02hc900b=bT00P0c=RL02`0c
=280<c<Q02h^700`<Qh0;34N02T_700V;1T092dI02H^6P0T;1/09RlL00809BhI00`0:34L02L^7@0X
;Qh0:2dM02P^700W;1X09RPG02//6`0^;ah0;2dM02d^800^<24202/_800;02`b8P0/<b80;S@R034g
900a=RD0=3LY038e:P0a=R/0;c@Y02da9@0/<B800P0^<b<02`0/<R<0;C<U034h9P0a=b@0;cDR02`a
7`0`=R80<SHR03@e8@0c=280<34Q0080:RhN00`0;C8Q02L/7@0X;Ad0:2hM02D/700U;A/08b/G02D[
5P0X;AP09b/J02DW600T9QL202DX6@0;02<V5P0T:1H08RHE024U4`0L8Q007B<D01hS5P0K81H06R0G
01TP5@0H7A400P0H71002`0C5``05ad?01@I2P0C60T04aH801LK3@0H7A006AhA01TO4@0M91H06b8E
00806R4D00H06AlB01TN4@0F6`/05QT801LI2P0D5PX?ooooo`003Ooooon]0?oooa[ooooo00H06AlC
020V6P0O91P08RTJ03Q3:P1DID<204eM?P0;028V600S:1d07B8H01LL500D610061hC01PN4P0H7a@0
72<F01lW5`0P9QP0100S:1X02@0S9QX092DM02LW7P0W:Ah09bXN02DY6`0U9QT092DF020T4`0202<W
500<02<V5@0S9QL092TK02@X700V:R409B/P02<Y7P0U;2009bhQ02P^800W;Qh09RhK0P0Y<1`02`0Z
;a/09b/I02P[6`0[;al0:BdP02/^800Z;b00:S0P02P^7P0X;Q`0:BlI00809RlH00/09c0K02@/5`0Y
<1T0;38K02``6P0^<1/0;c8M02lc7`0]<R40;S@S034f9`02034b900;038c900`<B80;c4P02ha7P0Z
;Q/0:S0K02Ta700W;ad09BdK020X600P:1L00P0T;1T0300U;1`0:BlN02T]7@0Y;Ah0:2`M02L[700V
:QX0:bhK02da7@0/<1`0:bhM02d`7`80;30O00X0;C8O02dc7`0^<b40;S<Q038g9@0d>RX0<SHZ034f
:`0a=bT0;cHU0`0]=2402`0_=R<0<CTV02lh9@0_=b@0<CTU02le900_<b80<cHR03Dg8`0c=240<C8N
0080;S0L00`0;C0K02/_6P0/<Ad0;34M02T^7@0Z;ah0:RlM02P]6P0Y;QX0;34N02T^7@0Y;ah202@Z
6`0;02@X6@0T:AP08BDE01lQ500Q91D082DE01hR4`0N8QD0724E01XP4`0I7`l00P0I7`h02`0I6``0
6A/?01XK3`0H6Pd05aT<01TK300L7a406al@01HK3`0J7a806b0D00806QlD00H061/A01DI3`0E6@d0
51P:01<E2@0?40D?ooooo`003Ooooon]0?oooa[ooooo00H03a<;01<H4@0E6A405QTC01dQ600Q9a/2
024Y6`0;01hS5`0M8aD06b4B01TP400G7Pd05Qd<01PO400J81<05adA01/R500N9AH00P0S9aP02`0U
:QX092TJ028V600S9QT09RXL02L[7@0W:Qd09RXL02HX6@0W:aX09R/I00808bPG00D08bHH02@X6@0V
:a/092PM02HZ800202L/8@0502L]8P0X;2409BXO02<X700X;Ad00P0Z;a`02`0[<Ad0:BhL02X^7P0Z
;240;2lT02X]8`0Z;B80:c0R02``8@0[<1h0:BhH00809R/G00/09bhJ02X`7@0Z<A/0;cDN02ld7`0`
=200<S<Q02l`7`0`<B40<SDU03@g:002038d9@0;03Dg9`0_<B80;BlP02lc8P0]<R00;C8O02/b7P0Z
<Qh0:C8N02H^6`0S;1X00P0T;1X0300W;Qd09R/K02L/700Y;Qh0:RlP02H/7P0S:A/09RdK02Xb7@0Z
;a/0;34O02db8080;S8Q00/0;C<P02da7`0^<b00;c@Q030g8P0b=b@0=3PX03Dj;00b>BX0;S@U02`b
800202dd7`0;02lf8@0_=R<0<3LU034h9P0a=bH0<SDV034b8`0b<R80<S@R034b8@0b<b000P0d=B40
300^<1d0;2lM02``7`0[<1h0;30N02X^7@0X;A`0;C4N02X`6`0Z;a`0:c0P02/b8P809bhN00/08b/K
02@X600U:AP08RDF028T5`0Q8aH08R@F024S5P0P8aD07R4D01hQ4`0201dP400;01dR400J70d061X=
01TJ3@0H6@d061X=01/M3P0K7@d06Q`=01`O4P0I70l00P0H6`l201PJ400401DH3P0B5PX04146014C
1`oooooo000=ooooojd0oooo6_ooool01P0>4P/04A@<014B2P0F60l05aTB01/P6080728H00/06b8G
01XQ5@0K8A@06b8D01XQ4`0J81806R4A01TO4P0G7Pl072<A01hT4P0201lU4`03028V5P0P91@08bHG
00808bHH00H09BLH02DX6@0V:Q`09BTK02L]7P0V;1l202D/7@0<02D[700S:A`08RPL02H[800V:Al0
:2dP02L[7`0V:Q`0:2dN02L/700W:Q`0:bhO0P0Z;Ql00`0/<B00:c0N02`a800202X_7`0602/`8@0/
<R80:BhN02T^7P0[<200:BhN0P0W;Q`02@0[<1h0;38M02`a7`0]<al0;c<P034e8@0];ah0;c4P034c
8P0403<g9`0;03Di:`0d>BT0<CHW02le9@0_=B<0;S@R02hf800/=Ad0;C@M02Xb6`0[=1h00P0^=B00
300/<Qd0:RlL02P]6`0[<1`0:c0O02X`800Z<Al0:C<L02Td6`0W<1P0:34K02/d7P80;S@Q00/0;S@R
02lc8@0`=B<0;c@Q02hd7`0^<Al0=3HU03Dh:00f>bX0=3XX038i9P02030g8P0;02lf7`0`=b00<CPR
03@k9P0d>RL0<CLT038f8`0e=b@0<C8Q02l_8@0^;Ql00P0`<R40300`<B00;c0Q02da8@0]<B40;S<R
02dc8@0]<b80;30R02X_7`0/<B40;C4S02X_8P80:S8R00/0:30P02<Z6P0R:QT08BLF028W5P0T9aL0
9BTI028T5`0R9AL08B<F01lQ5@02020R5@0;024T500N8A007Qd?01hN400L7Q8071hA01XL3@0K7@d0
71l?01/N4@0G70l00`0G6`l01@0I7Q404AD9014E2@0@50P04QH900oooooo000=ooooojd0oooo6_oo
ool01P082P@02`h500`?1@0D5@/061XC01PL5P8061dE00/061dD01`Q6P0O8aX0724E01lS5P0M8A@0
6AlB01PM400J818072<A01hV4P0201hW4P0;024Y5P0Q9aD08RPG02HZ6`0U:1T09bXK02LY6`0X;1d0
:2dP02L]8P0U;2400P0V;B40300V;b409RhS02D[800V;B409RdO02X_7`0X;1`09RTK02P[6`0W:a/0
:2XL02d^7P80;2hN00/0:c0P02``7`0^=240<3HS02le8P0[<200:30O02T`8@0[<200:c4P02`b8`02
02Xb8P80:S4O00T0:2lM02`b7`0/<Ah0;34P02db8@0/<240;C4S030e9@0b>BP00P0c>BP02`0c>BX0
<SPZ030f:P0b>2`0;C<V02`b8`0Z<Ql0:c@O02/d700[=1/0:c@J0080;cPO00`0;cHP034f8P0_<b40
;RlO02`_800/<200:c4O02Xb7@0Y<aX0:C<I02Tc6`0/=1h202hc8@0;030e8`0a=R@0<cTV03<h9@0a
=R80<CHP030e7P0a=B00=3TT030f8P0`=2<00P0b=b@02`0a=R40<CPQ02lf7`0a>280;cHQ030f8`0a
=b@0<SLT038e8`0`<B<0;blQ0080;BdN00X0;BhO02X/7@0Z;Qh0:RlO02T^800/<B80;C8Q02`_800[
;R00:B`R0P0/<2<202T^8@0;02T`7`0O9QH082PF01lW4`0N9Q4082LB02<X5P0U:QT08RLF01hR500K
7a<00P0L81@0100Q91H07R0C01dO4`0N8AD201dO5@0501dP500N818071l?01/M3P0L7`l00P0J70h0
1P0J7@h06Qh?01TL3P0D6P`051T>01<G3@oooooo000=ooooojd0oooo6_ooool01P072P<02Pd4014F
2@0G70l07B<E01/O50805AH?00/05ADA01TK500F61405aXB01PN4`0J81@072<E01`S4`0L91406b<?
01hW4@0201hX4@0;01lX4`0O9aD082LH02DZ6P0V:QX09BTJ02L/700[;al0:RhP02T_8`0V;2800P0V
;R<0200W;b@0:30V02T`9@0X;b809B`M02P_7P0X;A`0:2dK0P0Z;a/03`0X;1T0:RhK02da7`0]<Al0
;c@P02hb7P0/<Ad0;S<P02da800]<B40:c0R02`a900]<RD0;34T02X_8`0202/a8P0;02`c8P0]=R<0
:c@Q02Xc8@0X<1h0:S8O02dd800/<al0;C<P02hd800a>2@00P0a>2H02`0b>RP0<3TW03@k:`0d>R`0
<SX[02hh9`0]=b@0;CHQ02`e7@0[=AX0;SLK0080;CHM00`0;cDO02lf8@0_=B40;c<Q02da800^<R40
;c@R02dc800]=1l0;3@N02Xb7P0/<Ql2030f8P0;030f8`0a=bD0<3HS038h8P0b=al0<SHN03@h800b
=R40<cPR03@i8`0c>2@00P0c>BH02`0b=b@0<CDR030e8P0a=b80<CHT038h9P0c>BH0<STU030f8`0_
=2<0;30Q0080:R`N00D0:bdQ02`]8@0];b80:RhP02``800202db8@0502/_7`0]<280;30S02T]800Z
<2000P0Y<1l02`0Y;ah09BdJ02H_6P0R:aH08BTD020W4`0U:QP09BXJ02@X5`0T:1P08BHF00<07R@D
00X0720B01/O4P0J7A<06A`D01PJ4P0J7A<082@F01dO4`0I6Q006AT=0P0L70d01P0L70`06a`;01/N
3P0F6@/05AT;014F2@oooooo000=ooooojd0oooo6_ooool01P092`@03A0600hA1P0>4PP04QL:01DI
2`805QP:00T04A@;00hA2`092`L03A4901<G3@0G7Q0061d@01TP4@0M91800P0M9A8201lW500;01hV
5P0P:1T08BPI02@Z6`0U:a/092XI02T`700[<ad0:c8N02/a7`0Y<2000P0U;2000`0W;b809bhR02H]
8@0202P`8`0702Tb8`0Z<B00;C@R02``7`0[;ah0:BhM02X^7@0202/`7@0;02hc7P0^<Qd0<3DO030d
7P0`<Q`0<3<M02`_7P0Y;1h0:blP02db8`0]<RD00P0]<RH02`0[<2@0;C<U02he9P0]=2@0:C4O02L_
700Y<Ad0:c<M02hg7P0_=Qh0<STR0080<cXU00/0<CXU02hh8`0c>bH0<c`W034l:00`>bH0<C`W038m
9P0_>B40;cXQ034l8@02034i800<03<j8@0`=Qh0<CLO034e8P0c=BD0<SDV030d9P0_=2@0<CLT02he
7`0]=1d0;CDM0P0^<a`02`0_<ah0<SLR038i8P0a=al0<cPN038d6P0e>1l0=3TR038h8P0a>280<3LR
0080<STT00/0<SPR030g8P0^=200<SPR03<h9@0d>BL0<cTV038i9P0a=bD0<3HT02hc8`0202X^8P03
02T]8`0Z:b80:bhR0080;30S00L0;30Q02X_800/<B80;34S02`b900Z;b409RdM00809blM00/09RdI
02H^6@0U;QP09RhH02@[5P0Q9a<08bPF02@X5P0S9aP08bTK028Z7002020X6P0;020V600M8QD06b0C
01TM400K7a<06QhB01hQ5P0P8QL07R0F01/L4@0K6a000P0K70l01P0L7@`06Q`:01XL2P0I6`T05QT9
01<E20oooooo000=ooooojd0oooo6_ooool01P0620@01`T400H90P093@<02`l400lC1@805A/:00/0
4aP9010C1`0:30@030l600lD2@0=40L03106018H300I7a807B@E01hT5@02028Z6@0;024Y6`0Q:A`0
8b/M028[6`0S:a/08BXH02@]600V<1T09RlI02Pa6`0Y<Qh00P0X<1l0300V;Ah0:BlP02X^800^=2@0
;34Q02hc8P0_<b80;C8P02hb8@0^<b80;cDS02hc8@80;C8Q00T0;SDQ034f8P0b=b<0<CHQ030e800_
=B40;S4P02`^7P0[;Ah00P0[;b4202db900;02hc9@0^<bH0;S@V02he900]=R@0;SLT02`e8@0[=1h0
:C4J02/d7@0]=B000P0^=b802`0_>2<0<3XS038l9@0b?2D0=3`U03Dm9`0e?RL0=3`U03Dm900b>R40
=3/S0080<cXR00P0<SLS038h8P0c>R80<SLQ03<f8P0d=R@0<cDU030d8`80<3HS00H0;SDO02dc7@0^
<a`0;S<L02ld7@0b>202034g7`0703<g7P0c>1h0=S/R03Xn9`0g>bL0<CDS02he8003030g8@0:034h
8P0a>B<0<CTS03<k900b>2<0<3HQ02dc7`0_=B80;S@Q030f8`80;C8R00`0;2hR02`_900^<BD0;C4T
02hb900]<B<0;30R02/`8@0/<240;34R02`a800[<Al202/a7P0;02L/5P0X;AH0:2dF02T^6P0Z;Q/0
8RHE028W600S9aP08RLI024W6@0Q:1X00P0Q:Q/02@0P9QT08BDG020R5@0Q8aH08bHG01dP4P0N8Q80
8BDE01lQ500201dQ4`806ad@00H06ad?01`M400L7Q0071h@01PI3P0D5P/?ooooo`003Ooooon]0?oo
oa[ooooo00<010H600H81@051`800P062@403P0<40<03Q<300hC0`0?50@041D300lA0`0@4@D04187
010B2@0=3PH03@h700d?1`0D60d06Qh@0P0N8a002`0R9aH08bXI02@]6P0U;QX08b`H028[6@0S;1T0
8b`G02H_6@0W<1/0:34N0080:30O00<0:C4N02`c7`0]<Ql00P0_<b801@0_<b<0<3@T038e9@0c=bD0
<SHT0080<CHT0P0^=2<02`0]=B80;SLT02hg8`0_=B80<3HS034g900a=2<0<C8P02d^700]<1l0;2dO
0080;C0P00D0;C4P030d900_=RH0;cLW02de9@0202`e8`0402df900Y<b00;3LQ02/f8080;3LP00/0
;SPP034j900b?2<0<S`R03Dn8`0f?R@0=chV03@k900c>R<0=C/T03Dj900203Hj9`0<03Hl:00e>bP0
=S`X03<h900d=b80=CHR03<e8`0b=B80<3DS02le8P0]<R00;3<N0P0/<ad02`0]<ad0<3PO02lg7`0b
>B<0<cTS03@k8P0d?280=ShV03Lm9`0g?RL0<STS0080;cDP00<0<SLR03Dl9@0e?BD00P0d>b<01P0_
=R00;cLP02hf7P0/<a`0;SDO030g8@80;S<P00`0;C<Q02da8`0^<RD0;S8U030c8`0`<R80;C0S02d_
900^<B@0;C8R02`b800Z<1d202L]600;02@[500V;A@092TC02LZ5`0[;Qd0:B`M02@X6`0U:1`08bLJ
020U600O9QT00P0P:1X02`0O9aT0728E01hR5@0N8Q@082DF01dR4`0K80h082<@01lS4P0P8a807B0A
00806A/?00H05QT>01/N4`0H71806AdC01HH400D5`h?ooooo`003Ooooon]0?oooa[ooooo00H010T7
00H;1@072P801PX200@70@05204200L90@0;00D80@092@40414301DE2P0J6`h05QL<014B2@0=3`H0
2P`500P<100>4`H00P0C60L02`0K8@d07bHA02</5P0W<A`09S0J02La7P0V;ah0:34N02Pb7P0V;ad0
9BhJ00809c4J00`0:C<K02Ta6@0/<Q/0<3HP02ha7`0_<b80;c<S034e9`0c>BX0<SPX03<i:00a=bL2
02he900;02hf9@0_>2@0<3PT03<j9@0c>R@0<SPU03<h9@0a<b00;RhL02h_7@0a<R400P0`<R802`0`
=B<0<CHT038h9@0b>BH0;SPU02df900^>2@0;cTU030j900_>200<S/Q0080;SHO00/0;CDM02he800`
=R40<CPR03@l900e?B@0=3/T038i8P0b>240=CXS03<h8@0203Hk9@0;03Pl:00h?BX0=c`Y03@j9P0e
>R@0=cXT03Dg9@0c=B@0<SLV02hd8`0/<R000`0/<ad02`0/=Ah0;CHO034k8@0b>R00;cLO03<j8@0c
>b80<STS03Hl9@0g?BP0<cTU0080<CHT00/0;S8P02ld8@0c>BH0=ShY03<j9P0e?2L0<c`U034j8P0a
>B40<SXP03<k8@0202de7@0<02hd7P0_=B40<3@S034f9P0`=RL0<3@W02lc9`0^<BL0;C0V02/_8`0/
<280:RlM0P0X<1T02`0W;aL092`D02H[5P0V:aP0:RhM02T]7P0Y;R009b/O02@X700T:Ah07b<J0080
7R4I00X07B4H01lU5`0O9QH07bDG01hV5`0M91L07B8E01XO4@0J81007B8C0`0N8A801P0K7a006AhA
01TM4`0I7Q<05AX?014F2`oooooo000=ooooojd0oooo6_ooool01P052PH01@T300L;0P0830801`/1
00<70@800PD100/010L100T90@0:1`405A@601TJ2`0H6@/04aD900`>100<3@802``200P90@0200T<
0P0;014E1P0L80l08RLG02H/7@0Y<240:cDW02/e:00/=bL0:C<R02Pc7`0V<AX00P0T;aH0300V<AD0
:S@H02`d6P0_=1d0<cDQ03<e900d=RP0<S@Z034e;@0`=B`0<CL]02lg:`80;SLZ00/0<3TW034k9P0c
?2L0=3XU03Ll9@0f>B80=CPR03@f800e=R40=cTU03Hh9P0203@f:00;03<f:P0d>B/0<3HW038i9P0`
>RH0;CHT02`f8P0^=b<0<CXS03@l8P0b>R000P0c>B002`0c>B40<cLR03<g8P0b=b80<SPU03<i9@0b
>2@0=C`W03Pn:00e>b@0>3lU0080=SdT00`0>D4Z03Pn:00k@bX0>SlV03Lj900g>BD0=cPV03@g9@0a
=BD0;cHV02`c8`0Z=20202Xc7`0;02/e8@0[=Ah0<3`Q030l7P0`>ad0;cLK034j7P0b>R00=C`T03Lo
9P0e?2L00P0b>2H02`0e>R/0<CHY030f:@0c>RX0=Cd/03Hn:@0e?RT0=3hX038m900b>b40<STP0080
<CPO00`0;cHP034g8`0b=R@0<3DU034e:00a=RX0<3DY02hc:@0]<2L0;S8W02P]8@0Z<1l202Ta7@0;
02Pa6`0Z<1X0:RlI02/`700]<Ad0;S0M02`]7P0[;1d0;2hP02TZ7P0S91T00P0Q8QP02`0P8QL082<H
020U6P0P9Q/08BLL02<X7`0S:1h082LJ01dT5P0N9AH07R8B00<07R8@00D06al>01/P400I70d061T:
01<F1`0?ooooo`003Ooooon]0?oooa[ooooo00H01``300T<1@0;3PD03A0400/=0`0:304200P:0@0;
00X=0P0;2`402PT100d=0@0>3@80410400l?0P0A40803Ph200d;0P0<20800P091@402`0:1`8040h9
01`M5`0W:B<0:c0Y02`d;@0Z=Bd0;3P/02Xh9P0Y=b80:C@M0080:SHJ00`0:SDF02/g5P0^=AL0;C4H
030b7@0d=RD0=3DW03@f:P0`=2`0<3D_02de;`0^=bh202hg;00;034k:P0d?BP0=SdW03Hk8`0g>b80
>3XQ03dn9@0j?2H0>c`W03Xl:P0h>Rh00P0e=Rh02`0d=Rh0=3T_03@k;00c?BT0<CdV02lk900^=b40
<CXQ03@l8P0h?R<0>3dS0080?3lW00/0?3hY03Xk:@0j>bX0=cT/03Dh:`0j?bh0=ch[03Ho:P0i@B/0
>44X03Ho9@0203@l8P0<03Ln900j@2D0>d4V03a1:@0j?2X0>S`/03Hg:@0c=BT0<SDY030g:00[=2D0
;3HU0P0/=R@02`0[=B40:SHM02di700_?1X0<ChI038m5P0c?1T0=clR03Hl8`0g?bL0>D4]0080>Cl_
00/0>3h`03@l;`0b>Bh0;CDX02lh9P0b>bH0=3hU03E09@0d?R80<c`P038i7`0203Dk8P0<03Di8`0e
>RD0=CHV03Hh:`0c=bd0<CD]038g;P0`=B`0;C8X02db9`0[<R@0:S<R0P0Z<b402`0Y<Qd0:c@M02`b
6`0/;a`0;BlL02l`7@0^;1`0<2hP02l^8P0/:b40:BPP008092DN00D08b@M024T7@0R9ah08BHN024X
7`02028Y7`04020W6`0O9aP07bHE020W4`807B@?00H07RH?01lW400O9Pl07RD>01hR300G60P?oooo
o`003Ooooon]0?oooa[ooooo00H02P`500d>1P0B4PP0414600d>1@0:2P<200P90@0;00/<0P0:2`40
30d200X<0@0720402`X100h>0P0?3P@03`d400l>1P0>2PH00P0;1PH02`0:1@P020@901@C5@0K71d0
8bPW02P`:`0Z=B`0:CHX02Xi9@0Y>B00:3LL0080:SHJ00`0;3PH030j6@0`>1`0<CHN03<g8P0d>2L0
=CP[03<h:`0b=b`0<SP_038k<00b?2h2034k:`0;03<o:P0b?2L0=chW03e3:P0l@BP0?SlV03ln:00o
?R`0?Sh_03Xj;`0j?3800P0h?3<02`0h?C@0=chb03Dn;`0c?B`0=Cl[03@o:00d?2@0=chT03Po900m
@2H0?ChX0080@3l/00/0?Sh_03/j;`0i>S80>S`c03Pm<P0e>bl0>3l_03Ho;00iA2`0>T@X03Y2:002
03U09P0<03Xo9P0j?BD0?D4Z03`o;00m?c40?3lc03Pm<@0d>Rh0=Cd]034k:P0^>2H0;cXV0P0]=b80
2`0^>1l0:cDJ02Xc5@0[=AD0;SLE034j5P0d?AX0=SXP03Hk8`0g?RT0=d0[0080=T4^00/0=D4`03I1
;`0c?b`0<S`W030j8@0_>1X0<CXI03<k6P0b>a/0=3/N03Lj8@0203Tj9P0<03Pg9P0e=2P0<c<Y034b
:00`=B`0<CTa02`d;00/=BX0:C4V02Xc900Z<B40;3@R0P0^=b@02`0/=240;C@O02hc7P0_<1l0<C4P
038a8P0c<BD0<BlV02dZ8`0/;2D0:2/U00809b/U00/08RLQ01dS7@0O9Qh07RHL020Y7@0Q:Q`08b/L
028Z6@0O:1@082TC020Y4P0201lX3`0601hU2`0P9P`07b@;020T3@0O8@h07A`=3oooool000gooooo
[@3ooolJooooo`0600lB2P0>40T03Q4900`>1P072@<01@L30P0620802`0<3PD03Q4600`?0P0;3`80
2@/100/<0@0<3P<0414600l>1@0;2P@020H200801`@200/02PL800`92`0;20`040lD01PK7P0R:BH0
9RlX02Pc:@0W=BD0:3DR02`h800202di7`0<02dh7P0`>1h0;cHL030g800`=2<0=CPX03Lj;@0c=bd0
=3T_03Ll<`0d>c40<S`^0P0`>bX02`0a?BP0<C`T03I09@0h@2H0>D0W03Xo9`0j?BP0>S/X03do;@0j
?2l0>ch`0080>Cd`00/0>3db03Hl<00e>bh0=ch_03Q0;P0g@2`0=ShX03Pm9P0i?2@0>cdU03dm:002
03hm:`0;03`i;P0k>C00>cde03Li=@0e>C<0>3le03I0<P0g@Rh0>D@[03]5:P0j@RL00P0h?bD0300h
?RL0>C`Y03e0;00m?bh0?d4b03i2<`0j@C@0=Sha03Dn;`0d?B/0<chY030k8`80;SPP00/0;cPL02de
600[<QL0:S8F02/b5P0/=1H0;cLG030f700`=Qh0<cXT03<j9P02038i:@0;03<k;@0d?R`0<c`X038k
9@0`>R00;SLL034h6P0c>Q/0=3PK03Hj7P0g>R400P0h>B@0300h>BL0=cL[038b:00^<BL0:c4X02P_
9`0Z<R/0:c<X02`d9P0^=RH0;SDS02`a7`80;S@R00/0<3@S02lc800a<al0<34N038a800a;b00<2dQ
03<b9`0^;RH0;S0X02/^:@0202H[9P0;028X8@0P9Qh07bLM01hU6`0P:1/082TI01lX5`0Q:QL082TG
024W500P9a800P0N9@l01P0J80/07b@<020T3`0P8Pl07b4>01dO3Poooooo000=ooooojd0oooo6_oo
ool01P0@5@h03A0=00/=2P0:30P02`d:00L:1P801PP300/01`T200X=10082@801`T200T:0@092`40
2`d200X:0P0:2@802@P200H50@0200D20@0;00l>200G5Q8061LF01LF6P0I6Ah071hU028V:P0U;Rd0
9c8]02Hc:P0Z=BP00P0/=BD0300^>2<0<3PQ030g800a>240<cPS03Di9P0j>b`0>S/^03Li;P0h>S00
=CT`03Dk;`80=Ch`00/0<Sd[03<n:P0e@BX0=T4W03Y3:00i@RL0>D4V03To9@0l@2P0>clZ03a0;@02
03a1<@0;03Xn<P0i?c<0>Chc03Ln<P0e?C40=T4b03I1;`0d?RP0=C`S03Pn900j?R@00P0j?2D02`0l
?BP0?C`[03`l;`0i?380=STa03Dj<@0f?C40>4<`03U4;`0kAbh0?dT/0080?TPZ00`0?DH[03e3:`0n
@R`0@4@_03m2;P10@S40?d<c03]0<`0l@c<0>44`03E0;P0c?BX202lh900;02he800]<Q`0:BlI02/b
6`0/<a/0:c4I02dd6P0]<aX0;cDO034f8P0e>RD00P0g?2P02`0f>bT0>3d[03@j9`0d>RH0<STU03<l
9@0c?280<CTN034i7@0c>Qh0=C/O0080=c/Q00T0>C`U03Xl:00e=RH0<C<U02lc:00]<2P0;2lW02da
9`0^=2L00P0_=BD03P0^=2<0<3HU030f9@0_=B<0<3HS02hc800_<Ql0<38O038c8@0`;R00<2dR034_
8`0^;B<0;BhS0P0/;b@02`0Y;2409BPN02<Y7@0P9A/082DJ020W6P0N9AT07bHH024Y6@0R9aT08RLH
00808RHF00H07b@C01hS4@0O8a407b8A01hQ4P0M7a8?ooooo`003Ooooon]0?oooa[ooooo00H041D>
00d@3@0;3@X02P`800/=2P072PH200H80`0;00L90P0:3@@020T200L90P092P402@/100/=0P0:2P80
2PT200T80P061@400P050P402`0?3PP05aHB01PG5P0G5QX06ATN01`N9@0R9RX09Bh]02Lb;@0V<bX0
:SDX0080;3DU00`0;SPS030h8@0`=b00<CPQ03<h8`0e>BH0>S//03Xk;P0g>Bh0>3X`03Di<00e>bl2
03Dn<00;038m:`0c?RX0=D4Z03I19`0j@bP0>D8W03U19P0i?bD0?40X03/o:P0l@2d00P0l@C402`0j
?S80>Clc03Tn<`0g?S80=Cda03I1<P0f@Bl0=3hX03Dl8`0h?R@0>ShT0080>S`U00/0?3dX03dl:`0l
?2l0>C`b03Hi<@0e>S40=Sda03Q3<00iA2l0>dL^03m9;00203i8:P0<03e6:`0m@b/0?T8/0414;`0o
@Rh0@48a03m3<`0k@3<0?4<c03Q1<00e@2h0<cdZ0P0_>2@02`0^=B00;C8L02T_6@0[<Q/0;3<K02/a
6@0]=1X0;C<J02le7`0a=R80=CXU0080=c`X00/0=S/Y03Pm:`0d>RL0=3XV038i9@0c?2D0<c`R034i
7P0a>Ad0<cXN03Dk7`0203Lk8@0903Tl9@0j?2P0=CHV034c9@0_<bP0;C0X02`_9`0]<BL0;S@W0080
;cDU00h0;S@S030f9@0`=RD0;cDS030f8`0^<b00;c8O030b7`0b<b40<2hP030]8P0a;b<0;RdS02d^
8`80;2lT00/0:B`Q02DX7P0S:Ad082DK020U6P0P9aX07RDI01lV600Q:AT08RLI028W6002028V5P06
01lT4`0N8a407b<A01lR4@0N8A807AlB3oooool000gooooo[@3ooolJooooo`0600`A2`0<3``02@`8
00X=200;3PP020X60P062@@02`072PD01`L300P910092`@020X300P:0P092`801`T100H80@051`40
1@D1008010<100/01@D1014C300O8QX0;S8[03<g<P0`<c<0;30`02/a<@0/=380;SPc02Xc;P0202Tb
:00<02La8`0X<B00:30O02/a7P0[<Ad0;c@P034g8`0e>2P0=3L[03Dh;@0f>Rh0<cP]0P0f?C002`0_
>2X0<CXZ034k9P0e?bP0=3`V03Dn9@0e?B@0=3`R03Ln9@0g?RH0>D0[0080>T8]00/0>3h[03Hl:`0h
?bl0=cd`03U1<P0f@380=T4a03E0;P0g@2/0=clW03Lo9P0203Dl8`0;03Pm900g?2<0>ShW03/o:P0k
?R`0>Sd/03Lm:`0g?b`0?4H`03e8;P0mAb`00P0lABX0300mAR`0>d<[03e3;@0i?RT0>d0[03e1;00m
@Rh0?D<a03a3<`0k@S80>T8a03Hn;080;cHT00/0;C@Q02/a7`0Z<Ah0:S4N02/a7@0/<Ad0;C@N02/`
7@0Z;a/0;C8L02hc7P02034d8@0;038g8P0a=b80<cTT03@j9@0e?2H0=ChX03M2:@0f@2L0<chR03<l
800b>Ql00P0_=A`02`0d>1h0>ChT03Xl9P0g>2D0=3HW034c:00^;bD0;S0U02hb9P0`=BT0;cDX00<0
:c<V00/0:S<T02/c8@0/<Al0;C8O02ld7P0b<ah0<2lM02h[700_;Ah0;bhM030_700202/X600702h]
700[;1h09bTN02DW7`0R9Ad08RHM020U7`0201lT7@0:01hU6`0O9AP0728F01`R5P0M8QD07b@F028V
5P0P91@07b4D01`N4`oooooo000=ooooojd0oooo6_ooool01P0830@02@`500X=1P0:2P@020T300T9
108030d600P03a4;010A2`0>3PT0414:00d?1P0;3P<02@`200L:0@801@L110031@402P020`404QH>
03U5<P0i@S<0=3Xa03@k<`0c>S<0<cTb03M1=P0c?C<202L_:00<024X7`0O9a/07bDF020U500S:1D0
92XF02DZ5P0Z;aX0;S@R034f9`0d>BX0=cd/0P0j@S002`0j@Rl0=Sl[03M0:P0i@2T0=SdW03U0:P0h
?RP0>D0Z03Po:@0h?bX0>3lY0080>D4Z00/0>D4[03Po:P0h@2/0>3lZ03To;00k@S00>Sla03U0<00i
@C00>T4^03Y1;00203Dm9@0;03Ln9@0g?b@0=d0T03U1900h?bD0>D0X03Po:@0g?bL0>d<Y03Y39`0l
@bX00P0m@bd0300l@Rl0?4<b03To;`0g?R`0=ch[03To:`0j@B/0>d8/03]1;00l@bd0?DD_03Ln:@80
<cTU00/0;SDQ02`c800/<R00:c4M02dd7`0]<al0;38M02T_6`0Z;Q`0:c0M02/a7@0202db7@0;02dc
7@0]=1d0<STP03Hl8P0g?RD0=cdW03Q0:`0h@B/0=d0Z03Dn9P0b>B800P0_=Ah0300b>B00=3/R034h
7`0c>240<cTS02ld8P0^<b80;c8Q02``800Y;Ah0;C0P02hd9@80;C@V00/0;38U02dc9@0]<R@0;34Q
02hd800`=B40;S0N02h_7P0[:Q/0:RTI02`]6@0202TY5@0;02LX500U9aH09bTJ02HW6`0Q8aX08bDM
024S7P0R9Ql08BLO020W7P0M8aX00P0L8QX01P0O9A/0728H01dS6@0Q91/08B8K01dN5`oooooo000=
ooooojd0oooo6_ooool01P062`<01PX100/>0`0>3P@02`X300`<1@804A<:00/051P?01LJ4@0D5a40
5QXC01@H3P0B5PT030l500P;0`051`801`P200L80`0200@60@0;00<40@0520<010L201HL400M8aD0
;S@T04MB>`0b>BP0<CLX03Q2<00c?Bh00P0I7QL0300F6Q@04AD>018F300C6@/06Qh=01hQ3`0O8100
92LE02``7P0b>2H0=S`[03Q0;P80>d<_00/0>D4/03Y3;00k@bX0?DHZ03i5:@11AR`0@DH^0414;P0o
@bh0?48]03]1;@0203a3;@0;03a3;P0m@c00?dH`03U1;00k@bd0>d8^03i2<@0m@S40?D8b03m4<@0n
A2d00P0k@2X02`0j@2P0>d8X03i7:P0lABT0?4HY03Y3:00kA2T0?4DY03]5:00lABP0@4P[0080@TP`
00`0A4Tc0497=P0nA3<0>d4b03Tn;P0g?B/0>D0/03Y3;00i@2T0?4@/03]3;@0k@bh203U0;00;03Dl
:00^=B80;S<R02hd8@0]<al0;cDP034h8P0_=B00;C8P02db8@0^<al00P0]<ad02`0]<al0;38M02hf
7`0_=R00<CPQ03<k8`0e?BD0=C`W03Q1:`0h@b/0>44Y0080=3/T00`0=3`T034h8`0b>2D0<3LT03<k
9P0c>RH0<SXV02he8`0_=R80;cLQ02hd7`0_=B<203<i:00;03<j:@0`=RH0;cDT02/_8P0_=B@0;S@R
02le8P0_=B40;C8P02`_7P0/<Ad00P0Y;QX02`0X;AL09b/H02P/6`0V:a/09RXK02@W6`0U:Al09BXO
02<Y7P0P9Q/07bLK00807RDJ00H07R@H01hU600O9QT07b@J024T6P0N81P?ooooo`003Ooooon]0?oo
oa[ooooo00H01`X600X>1`0930@020X300T;0`082P<200/?2@0;00hA300D6A005adC01PM5@0I81D0
5Q`A00hC2@0:3P@01PX200L:0P041P800P0520<02`021@800`H200L;0`0;40D0310300lC1@0W;1T0
:2dL02X^7P0nAc80?DLd00809bhR00`0728K014D4@0?40`0410:018B2P0E5Pd06AT?02@W6@0/<1l0
=3/W03Hm:@0k@c0203]4;`0;03Y4;@0i@R/0?4@]03a5:`0oAR`0@DH^04=8<@11Ac40?T<]03i4;`0m
@Rh00P0n@bl02`11Ac80@DLc0417<P0nAS00?DDb03e5<`0nAC40@DHa0414<P10AC40?D8]0080?D<^
00/0>d4]03i6;P0mARh0?TP_03a6;`0nAbh0?DL[03e6:P0oBB`0?dL[04=<<@0204A9<`0<04=8=@14
BSP0@dXh04=:>00nA380>T0]03U0:`0g?bT0=clX03Y2:P0k@Rd0?D@b0P0oAcD02`0j@S40<c//034i
:`0_=bT0;SLU030i9@0a>BD0<CTR02lg7`0^=1d0;S@L0080;SDL00/0;C<K02da6`0]<A`0;C8O02/`
7`0/=240;CLS038k9P0a?2H0<T0X03I2:P0403@n9P0:03<m9`0b>B<0<3LQ030g8`0c>bD0<CTU02lg
8`0`=R<0;C<Q02hc8P80<3HT00/0<3LU02/b8@0]<R<0;cDU02da8P0/<1l0:c0N02`b7`0^=B80;C@O
02`b700202X_6@0;02X_600X;AP0:2dI02L/700W;1h08bLN02@Y7`0S:1h08bXN024Y700Q:1T00P0O
9QL01P0O9aH07bLG024Y6P0S:QT092TK024T5`oooooo000=ooooojd0oooo6_ooool01P0930/020/9
00`?2@082`D01@L200@50P801@L200/02@`800/>2`0@4`l051PB01DJ4`0D6A403a<;00/>10082`40
1PP200D60P0200@50P0;00@60`041P@02@`700P<1@0830<020X200P;0`0=40L04A<:02@[6`0`>RP0
0P0V;al0300R:A`07b<G01dO5@0I6Q<05ADA01DF4P0F5Q4082<J02L[8@0_=BP0<cTZ03U1<080>T<a
00/0>D8_03Q1;@0i@2/0>T8/03a3;@0nARl0?TD_0419<P0nARl0?D<_0416<P020458=00;0459=013
BcH0@4Pc049:=013C3D0@DXe045:<`10Ac00@DH`04=8<@0o@c000P0oAC<02`0nA3@0?TDc03e5<@10
BC80@D/c041:<@0nB2`0?d//041;;00nB2`0?TL^0080@DPa00`0@TXf04=8>@17C3d0A4Tj04A;>@11
B3D0@TTh03]3<`0h@300>40^03Q0;@0l@bl203m7<P0:03m7<@0k@bl0=ch]03Ln;`0g?Rd0=Sh/038k
:@0b>bH0<3XS030h80<0<3LN00/0;C@K02hd700_=Ad0<3DP02ha7`0^<al0;C@O02lg900c?RP0<CdW
03<o:P0203E2:`0<03=0:@0c?bL0<S`T02hh8@0]=b40;SLQ034j8`0b>bD0<CTU038h9@0^<b40;c<Q
0P0a<b402`0`<R00<C@R030d8`0_<b<0<3DU02da900/<RD0:S8T02Xa8`0[<b40;C@Q0080;C<O00/0
:c8K02T_6@0[<1X0:BhI02P/700V:Q`09b`P02@Y7P0S:Ad08b/M02H/7`0202<X6`06024V600O9AL0
7bHG01lV5`0P9aT07R<H3oooool000gooooo[@3ooolJooooo`0601@I6`0?4aD030h?00P:200520@0
1@L20P031@402@082`@041@9014F2P0?50P04A@:014D2`0>4@P02`h600/>100200L90`801@H200/0
1PH300P91P0;2`D020X300@50P061P801`P300L8100:2`D02`l7018G300201<H3@0<01@H3`0G6Pl0
5a/>01XN4@0R9QT08bHJ01lS5`0O91X08bTO02X`9P0_=bX0=3d]0P0h@Bl02`0h@Rd0=d0[03Y3;@0i
@R`0>3l/03U0;P0mAS40?TXb03m;<`10BC80A4dd0080@DXb00/0@DTa049;=014C3D0Adhf04A<=@10
BC@0@DTd0419<@12BS80@dXb0415;`020416<00;03m6<P0oAc80@DTb045:<P12Bc<0@ddf045<<`10
Bc00@4``04==<`12C3@00P11Bc@03011BcD0@d/f04I;=P16BcH0AT/e04A:<`11AS@0@dTh03i4=00m
A380>T8^03Y0:`80?d@/00/0?T<[0415;P10AS40@TLe03e3<@0i?Rd0=C/[034i:@0e?R/0=CdX038j
8P02034h8@0;030g800b>B40<3LQ034e8`0`=2<0<3HS02db8@0_=RD0;SDT02hg900^>2D00P0_>RD0
300_>b@0<3/S03@o9P0c?B@0<c`T034i8`0_=b<0;SLT03<k9`0a=b@0;S<Q02/_7P80<3@R00/0;S8P
030b8P0_<B40;C0P02da8P0_<b<0;C8S02da9P0[;R<0;C8T02/b8P0202`b800;02/a7P0Z<1/0:BlK
02X`7@0Z;Qh09b/N02HZ7@0U:Ad092PM02<V6`0T:1`00P0S9aX01P0P91L07bHG01lU5`0N9AH07R@G
01/R50oooooo000=ooooojd0oooo6_ooool01P0G7B@05QdS01DK8@0A51/030lC00/?40802@/<00/0
3Q8>014E3`0>4@P02`h400d@1@0@50T04A@;010B2@0?40L030d500/:0`0200`;1P0;00X91@0:2@L0
2@P700H5100410800`8200@40`072@D030l800hA2@0<3`L00P0:3PP0300=40T03A0700X=0`0>4PL0
5ad@02@]6`0X<Qh0:cHR02`f900_>BT0<3//034l:`80<C/X0P0d?RX02@0c?2L0=CdW03Hn:P0g@B/0
>D<]03U6;P0iARd0?4T`041<<P02049;<`0;04A==015CCL0ATdi04M=>P15C3L0ADdg04E>=`16CcL0
ATlf04M>=@16CCH00P15C3L02`11BC@0?dPb03m8<@12CC80@Tdd04A@=P12CS@0?d/d03m<=00oBc80
@4/a0080@Thc00`0@4da045<;`11BS00A4Xb0497<015BS80A4Tb04A6<`14B3@0@dPc03m6;`0nAR`2
03m5:P0;03m3:00oA2P0ADT_04E:<P13B3<0@DDc03i4<P0j@Rl0>T4/03M09`0e?2D00P0d?2@02`0b
>B80<CHQ03<h900a=R40;cDP02he7`0]<b40;C8R02hc9P0`=bL0;SPU0080;cPU00`0<3XV02hj8P0b
?R<0=T4T03M08`0g@2D0=3`S034h8P0a=b@0<SPV034g9@0_=28202db800;02da7`0^<b00;S8Q02ha
800];Qh0;S4Q02hc8`0^<BD0;C0T030f9`0[<R<00P0X;b00100[<Ql0:RlM02/^7P0[;al202L[7005
02HZ6`0V:A`092LL020U6P0P91T00P0P9Q`01P0N9A/07R@J01hU6@0J81@072<E01/P4`oooooo000=
ooooojd0oooo6_ooool01P0T;3408bX_024W:`0N92T06b4U01DJ7P804A@G00/04aHG014C4P0;2`/0
2`d900hA2@0?50X041@9014C2P0>40L02`h500d=1@0200d<1P0;00d=200@3`d03`l@00X;30051@H0
10@400D71@0>4@h04QH@014D3@0>4P/00P0=4@T0300<3`P030l:00P;1P082`@02Pd500lD2@0J8A<0
;CHS03Do:P0kABh0>TD`03Lo;P80=Sh[00/0=CdZ03<k:P0c>RT0;cLV02lg:P0^=RP0<CXZ03<n:`0f
@Rd0>TH_03a8<@0203m9<@0904=<=P15C3T0A4`i04E=?017Cc`0B58l04MA>P18E3/0AU0g0080ADlg
0P16CcP02`13C3H0@dde045:<@12CC40@T`c04E?=P11C3D0?dXe041<<`0nBRh0?Td^0080?dd`00H0
@4h`041<;`10BRl0@T/a04=8<@15BS@204A7=@040497=@12Ac@0@4L`0457;`80@4L[00/0?D<V0497
:P13B2/0@TH]04=8<@13Ac<0@4@c04=7=@12BC<0?4D_03Y2:P0203Po9`0;03Hl9P0d>BH0<3HS02hc
8@0a=R<0<CDR02hb7P0_<b00;S<Q034h9P0`>2L00P0`>RH0300a?2T0;cXW030k9@0a?B<0=40T03M0
9@0e?B@0<CPT02hd8P0^=2<0<CLW02le9080;c@R00/0;SDP02dc7`0]<Ql0;S<R02`^800];b80;2hR
02ha9@0^<R80;C<Q02`b8P0202X_7`0;02/`7P0/<Qd0:blM02/^7@0Y;Ah09b`O02@W6P0R9AT08RLL
020V700Q:1h00P0O9A`01P0O9Q/072<G01/R5@0K8a@07B<C01/O40oooooo000=ooooojd0oooo6_oo
ool01P0S:2l09Rd`02@[:`0S:RT092XY02<Y9`8082HU00/082DU01DH6@0@4Q<03Q0@00lB3P0A5Ph0
4AH<014E2P0>4PH02`h400X<100300hA200:014C3@0?4@h03a4@00d?3P061`P01`P8010D400E6A@0
4QHA00`>2P8020X500`01`X400P:10092`@02@`400T;0`082P<03a@901XN400S9aL0:2`L034g9P0j
@C4203a4<`0;03Y3<P0h@C80=Cha030h;@0/<bX09blV02@[8P0S:al0;CLW03@o:`0iABh00P0nBC00
2`13CC@0ADdg04A<>013C3X0@d/i045:=`14CCP0AU0i04MA>@16D3T0BUDl0080BE@j00<0Ae0g04E=
=015CC@00P14Bc801P16D3H0A4df04E?>@15CcP0@Thd041=<080@dh`00`0A4l`04E?<@12BRl0ADXb
04=7<`14B3P0ADPi04=7>013B3L0@DPe0459<P13CS<204E?<P0;04A<;`15C2h0AD/]04I:;@10A2`0
?d<_03i3=011B3H0?TH`03e6;P0nAbd00P0mAR`02`0i?bP0=C/U02le800`=B<0;S8Q02hc800`<b00
<3<Q02lc8P0`=bL0<SXY0080;SLV00T0;cXX030k:@0`>bL0;STT02lj8`0e?bD0=SlU03Dm9@0c>BD0
0P0a=bH03P0a=bD0<cTW03<i9`0b>2H0<3HT02`a800Z;b40:RhS02P/8@0Z;b80;C8S02dc8`0/<b00
;30O0P0[<1d02`0/<a`0;3@K02dd6`0X:aP0:BXK02PY7P0T9Q/09BPL028V700O91/08bTN00808BLL
00H082HL01hU6@0O91@07R<B01hQ4@0K7`d?ooooo`003Ooooon]0?oooa[ooooo00H0:Blb02/`=@0W
;2h092X[02DZ:@0X;R/202L^;@0;02@Z;@0S:2X07R8U01PL7@0D6AL05QXC018G300=4PD0310200/?
0`0<40D00P0?50L02`0@5@P03a8900h@2`0=3P`03a0>00d>300@4@`05APB01HJ4@0B5Pd041@;0080
30l400`01PT100L:0@082P802@X400T<10092`D02P`9010D3`0D5a<06A`G01TK5`0_=RX203m9>00;
04=>>P12CCT0@4Xi03Dn<00]=BP092/P01`Q6@0G6QH06QlH02D]8@0^=RP00P0f@Bh02`0nBS<0A4hf
04=<=010BC@0@DTf0419=@12BSH0A4Xh04I=>`18D3d0B58m0080Ae8i00/0AU4g04A?=@16DCL0AU0d
04Q@<`16CS@0B50f04M?>015CCH0A4hg04A>=P0204=>=080@T`b00T0@d/d04M==@16C3L0AT/i04I:
>@17BcX0B4dm04Q>>`17CcX00`15CSL02`16CcH0ATlc04A=<015C340@DH]03i2;@0m@c00>d8a03e4
=00mA340?dPb0080?4@_00/0>T4]03a4;`0h@2`0=CXY030d900_=280<SPT034g8P0`=R<0<3HT03@k
:00202lh9P0<030j9`0b?BL0<ShW034m9@0^>240<3XR038l900e?2H0=S`X03Dk:@0_=B@0;S<S0P0^
=2<2038h9P0903<i9P0_=2<0;S@S02db8P0[<240;3<U02hd900^=B80;34O0080:RlM00/0;S@Q02`b
7P0[;a`0;2lL02d_7`0Z;1l09bXP02DX7`0S9Qd08BDK028W7@02024T6P06020T5`0N8aD082@E020T
500Q91<07R4A3oooool000gooooo[@3ooolJooooo`0602X^;00[;c00:R`_02P[:`0V:BP09R/X0P0W
;2/02`0X;S009b`a02H]<00U;2d08RTW01hT7`0E6Q803a<;00d@200A4`X03Pl900803Pd:00/040l=
010@30071@D01@H600H71`0720H03a4:01DH3@0I7a005ad>014G2P0200dA100<00X=0@0;3@<020X3
00d?1`0=40X030h900X;2@0:2P/03`h@018B4`0D51@06ATF0P0T:2002`0c>B`0?4@d04I??00d>bd0
:BlS024W6P0K7a@06A/C01LI4P0H7AD08bTO0080;CHX00/0=3l/03]6<00lB300?TT`045:<P10BC<0
@4Pd0459=`12B3L0@d/i04==>@02045==`09049?=`12D3H0A4le04A@<P14CRl0ATl`04M@<@16CS80
ADhd0080@DXc0P11Bc<03011C3<0@4/b049<=014CCL0AT`h04I;=`15BCL0Ad/k04I:>`18Bcd0AT`j
0459=080@d`e00<0@T`b04A><P12Bbl00P12BBd01P0n@R`0>cl[03Xn;P0i?S00>d8b03a3<P80>T8c
00/0>T8a03U1;`0h@B/0=clY03<i8`0b>B80=3XR02lf800^=B40;CDS02lh9P02030h9@03030k9P0`
?280;c/Q0080<3`P00L0;STO030j8@0a?280=3dT034g900a=bD0<3HS0080;cHQ00/0;cHO038i8`0f
?2H0<cXS034g900_=B80;38P02T`7P0X;Q`0:c4M02X`6`0202/a700;02X]7@0/;b40;BlQ02`_800[
;R40:BXP02HW7`0T9Qh08RDL024S6P0P8QL00P0O8QH01P0P8aH07B0C01lS500R9AH082<F01`Q50oo
oooo000=ooooojd0oooo6_ooool01P0T;2L0:S4Y02hb:`0_<R/0;c0/02`^:`80;c4_00/0;2h`02X[
<P0^<3L0;c8g030d=P0W;2/06AdL01LH5P0D4Q804a4A018?4P0200l<4P0;00d;4@0:2@l01PH;00D5
20061`L010D300X<100G7@d0728@01LL300A50P00P0=3`D0300:30<02`d600/=1`0?4P/04QD;00l@
2P0@3``03@`:00l=3@0G5A<06QPE01HE4`8061PE00/06a/G028S700[;R@0:2`S01lS6`0H71<03a09
01TM500O9AX08bXM02D]7`0202H_800;02Xd8@0]>B@0<ShX03I3:`0mB300@T`d04A>=`12BcP0@T`h
04A?>P14D3T00P14DCP00`16E3P0BEHi04QD>00204QC=P0604QC=016DC@0A4hc04=><@15D3H0A50g
0P14D3H01P12CSD0@Thd045;<`13CCD0ATli04M?>@80BDhj00@0BThl04a@?P1<DSh0BU0l0P16CSP0
2P17CcL0A4db04=<<@15CS<0ADhe0499<P12Ac<0@4@b03e3<P0oAS@30419=@0;03i7<P0lAS00>D@^
03e:;`0g@RP0>48W03Do900b>R00<SXR030h8`0_>2D00P0c>bL0300a>bH0<ShV038m8`0b?280<SdT
03<l900f?bH0=d0V03Q0:@0f?BT0=C/X030f9080<CLS00P0<CPQ03@j8P0i?RH0>3lV03Ln:00c>R@0
;SHP02/c7`80:c<N00h0;38N02hc7`0^<al0:c0N02``7`0/<B00;C8R02hc8`0X;Ah09BTK02P/7P0X
:b409BPM02@X708092TL00H08RLJ028W600R:1L082LG020V600Q9QP?ooooo`003Ooooon]0?oooa[o
oooo00H0620O01hU7@0T:Ql0:B/S02/]9P0];bT202lb;P0;02la<00`<S@0;c8g034h>`0g@3l0<3Pf
028W9`0O8R<07QhR01LE7@0A4AX00P0>3aT02`0=3QP01PHA00D43`0410X00P@500<50`0620804QL9
01XP4@0I7A005QH=00804A4:00`03@d700`=2@0?4Ph05ALD01PJ5@0F61D0418A00d=3P0@4Q<051<D
01PG5`0D4A<201<B4P805A@C00T06AXE01`O5`0F6A404QD<010@200=30D071lA02D[700U:al00P0M
8aX02`0K8aP06R4F01hV600U;Qd0;STT03I2:`0kB300?d/c045>=012CS<0A58d0080AEDf00@0AE8e
04UD>@18DSP0Ae0h0P19DcT00`18DcP0Ae8g04E@=P0204A?=P80Ae4h00`0A4hf04E?=P12Bc@0@T`f
04A==`16CCT0B4hi04U>>P1;CcX0Bdli04eA>`1DF482059F@P0;04eB?@1:D3X0BDli04M=>015C3P0
AD`g04E<=@15CCD0@dTb04=:<P13C3<00P12Bc<02`11BC<0?dPa03e7<00mBC80>dL_03U6;00g@bL0
=D4R038n8P0a>Ql0<SXQ0080<chU00`0=3hU03Lo9`0f?RT0=ClY03<m:00d>bH0=S`X03Dk9`0h?bX0
=clZ03M0:`0e?R/203@m9`0;03<l8P0^=Qd0<3DN03<i800c>R40=3`R034j800]=Qd0;3<K02Xb6P0X
;AT00P0Y;QX02`0Y;A`0:blO02hb8@0/<R80:RlQ02`a8@0X;1d08bPK02HZ7@0U:1/09BTL008092LL
00H08RTM024Y7@0R:a`092`M024X6P0S:1T?ooooo`003Ooooon]0?oooa[ooooo00H0620O01hU7@0T
:Ql0:B/S02/]9P0];bT202lb;P0;02la<00`<S@0;c8g034h>`0g@3l0<3Pf028W9`0O8R<07QhR01LE
7@0A4AX00P0>3aT02`0=3QP01PHA00D43`0410X00P@500<50`0620804QL901XP4@0I7A005QH=0080
4A4:00`03@d700`=2@0?4Ph05ALD01PJ5@0F61D0418A00d=3P0@4Q<051<D01PG5`0D4A<201<B4P80
5A@C00T06AXE01`O5`0F6A404QD<010@200=30D071lA02D[700U:al00P0M8aX02`0K8aP06R4F01hV
600U;Qd0;STT03I2:`0kB300?d/c045>=012CS<0A58d0080AEDf00@0AE8e04UD>@18DSP0Ae0h0P19
DcT00`18DcP0Ae8g04E@=P0204A?=P80Ae4h00`0A4hf04E?=P12Bc@0@T`f04A==`16CCT0B4hi04U>
>P1;CcX0Bdli04eA>`1DF482059F@P0;04eB?@1:D3X0BDli04M=>015C3P0AD`g04E<=@15CCD0@dTb
04=:<P13C3<00P12Bc<02`11BC<0?dPa03e7<00mBC80>dL_03U6;00g@bL0=D4R038n8P0a>Ql0<SXQ
0080<chU00`0=3hU03Lo9`0f?RT0=ClY03<m:00d>bH0=S`X03Dk9`0h?bX0=clZ03M0:`0e?R/203@m
9`0;03<l8P0^=Qd0<3DN03<i800c>R40=3`R034j800]=Qd0;3<K02Xb6P0X;AT00P0Y;QX02`0Y;A`0
:blO02hb8@0/<R80:RlQ02`a8@0X;1d08bPK02HZ7@0U:1/09BTL008092LL00H08RTM024Y7@0R:a`0
92`M024X6P0S:1T?ooooo`003Ooooon]0?oooa[ooooo00H06b0R01/P7@0H7AL06ahG01lR7@0V:282
02hb:`0;030c;`0b=c@0<CLf02he=`0_=cT0<CTi02hf=@0X;Rh09b`_028V;P0Q92h00P0P8Rh02`0K
7RT05ALQ00h?6@092Q<01PL=00D72@051PD04AH>01PM4@0G71005AH>00804a<=00`051<?01<C4@0E
51<06A/H01hR7P0P9R<07bDQ01PL6`0G6a`06AdL01@G6P0A4AD200l?4@0;00l@400>40h03a4<01@G
3`0A50/03a<800d@1@0;30<09B`I02lg8P0]=R<00P0K8QH02`0H7a@04aL>01<H3P0D6@h06AhB01hU
5P0V;Q`0;SLR03@o9P0kAR/0@Dh`0080A4lc00/0Ae<e04QB>019DST0BE@j04YE>P17DcD0AU@e04MD
>@18ECT0AU8h04IB>@0204E?=`0<04I@>017D3P0B4li04U@>019CcT0BDhk04U?>`17C3T0BDhk04]?
>`1=DCd0D5<m0P1AE3`02`1?DS/0C54l04aA?019CcX0ADhj04I@>@12C3@0@ddc0418;P11Ac00@dTa
0080@dPc00/0A4Tf04=9=P10B3@0?dPd03a5<@0h@Rd0=d8X03E08P0c?Al0<c`P034j8002038k8P0<
03A09@0h@bL0<chU03@o9`0b?2D0=ShY03Hl:P0h?B`0>3h^03Q0;P0e?2X0=clZ0P0g@2X02`0f?RL0
<CPS02de7P0/=A`0;CHL02de700a>Al0;SHL02/b6@0Z;aL0;34K0080;C<O00/0:RhN02/`8@0Z<280
:BlP02/`800Z<B00:C4P02H^700S:aT08BPF020W5P0202@Y6@0602@Z6P0P:1T07bDH028X700P9AT0
82DG3oooool000gooooo[@3ooolJooooo`06020T900L7b006AdK01LK5P0G71D07B0H0P0Q8aT02`0T
9al0:RdW02da;`0_=C<0<3Pg03Ho>`0^=c@0:c<a02`d<`0^=3H0<3Dg0080<3@i00/0<3<k02`^=`0U
:3807R4Z014C7@0;3QD020T>00d@3`0D5a405Q/B01@H4@0201@D3@0<01<C3P0D50h061TB01hQ6P0M
81`08RLT02<Z9`0U;2P092/W02L]:00J7Qd04aDG0P0>3a802`0>3Q003Pl?010A400B51404AD@00lB
3@0>4@/030l701TO4@0M9A@082PE00807RHE00D072<C01LL400D5P`051D=01DG3P0201@G3@0401TN
4@0R:AH0:c@M03I09@80@4X]00/0@dda04IA=017DCH0BE8f04UD=019ECP0B5@h04UE>P1;Ec`0BE@k
04UD?00204QD>`0<04IB>@15CSL0AThf04aB>P1;DS/0BU8m04U>>`19CSX0BDli04Y@>`1:CcX0Ce@l
0P1=DCT02`1>DSX0Ce@m04eE?01<Dc/0Ae4h04IA>014CcD0Ae8f04QC>015CcH0A4`d0080A4`e00P0
A4/g04A9=P11AcD0@DTe03a4<@0k@bh0?4D[03Q29P80=3dP00d0=ClQ03@m8P0d?B80=ChS03M0900f
?b@0=ChU03Hn9P0e?2L0=3/W03Ln:`0g?BX0=cl[0080=SdY0P0g?RT02`0e?2P0<S/V034l900_>R40
;STP02/f7P0]=Qh0<3PP02dc7`0[<Ad0:RhN0080;C8R00P0;34R02T`8@0Y<B40:S4Q02P_7`0Y<Ah0
:34L02</5`809BhH00T08b`G02@/600T;1P092`H020Y5`0P:1P092/J02<Y6P0O9AL03oooool000go
oooo[@3ooolJooooo`0601dS8@0O8R4071dN01PJ6@0I71L06a`F0P0K6aD02`0L7AP071`I01lO7@0S
9B809bdZ02lg<P0a>S<0<3Ta02lh<`0]=380;S<d0080<SDi00/0<SDl03@g@00b=d00;S@l02L]=@0M
8bX061dQ01@I6`0F6aL06AhG01HK4`0201@H400<01@H3`0G6A006QdD01LI4P0D5a8061/F01hS7P0X
;RL0;38Z02lf;@0/=2`0720M0P0H6QP02`0E4aD04@lA00l=4@0@41<04A8C01<F5@0@518041L@018I
3`0G7`l0620=00<061l<00@05Q/;01@H2@0D60T04aH90P0A5@P0100B5PT06Ah>01TK2P0S9a<203@k
8@0;03e5:@14CS00B58c04]D=P1:ECL0B5@i04QC>017DcT0BUHk04YF?01:ESh00P19ECh03018ECd0
AU4j04M@>P17D3/0BE<o04UD?P17DCX0Adlh04Q@>01:CcP0Be4i04a?>080CE4j00/0C54j04]A?@1;
DSh0BU<n04MA>`14CcL0A4lf04E?=P15CcL0A4lf04A>=P0204I@>00;04M@>015BcL0AD/g04A;=P0o
AS<0?D@a03]3;P0kA2/0=SlW03U39P0iA2@00P0h@R<0300g?b@0>44U03Y29`0j@RP0>D0Y03Ln:@0c
>RL0<cTV030f900c>BL0=SdY03Hm:080=CdX00/0<SXU03Dm9`0e?2D0=CdU03@m900e?B@0;cLO030f
7P0_=B40;cDS02hc8P0202hc900;02hc9P0]<bD0;38R02/a7`0W;1X09bdH02Xa6`0W;aT09S0J02H_
6P0U;AT00P0V;QX01P0S:aL08RXG024Y5@0O:1<08RTH024V60oooooo000=ooooojd0oooo6_ooool0
1P0C5QL0:2/W024P8`0M6al06ALL01PG6P8061LH00/06APH01HE5@0D51804aHC01LL5P0P9al09RhS
02/e9`0c?300<CP`034f<00202lb<@0;030c=P0b=3`0=3Q003@j@00b>Sh0;cLk02Pa=00R:b/082LT
01`S7P0F6QL00P0G6aL0300G6aD05a/D01TM5@0E61403a8<00lA3@0B5Q007b@K02L[800]<RH0<3DZ
030e:`80;30Z00/09RXW01hP8P0G6Al05AHM014D6@0A51L05a`J01/R6`0J8AP06R8D01PP3P0201XQ
3P0;01LN300D6PT04aT900lE1P0?5@D04A@5018F1P0D5`L05QT:018D1P0F5PP00P0M7P/02`0^;aT0
>3`V04=:<`18DST0BE@j04]G?@1;Ec/0BUPi04UH>@19EST0BE@k0080BUHl00`0BEDm04MA>`16D3d0
AU0m04UC?`1:E3h0BUDl04I@=@16D380Adlc04M==018CCD204U<=@0804M;=P19Cc`0B4ln04I??016
D3X0AU0g04E@=P14CSD204A==@0>04=<=013C3D0@d`e04M>=`14BC<0ADTf04M=>@14BcP0?TDf03a3
=@0i@S40=Sl]03I1;00f@RP203E0900<03I0900h@B@0>T<W03Hm8`0e?2@0=c`V03<i9P0c>BL0<3DW
02hd9P0a>2L0<SXV0P0b>BD02`0a>B@0<CXS034h8@0b>B40<CPP034h7`0^=A`0;S8L02hc7`0^<R40
;S8S0080;C0U00P0;S<U02dc8P0_=2<0;S<R02X^7P0V;1/0:2dL02H/6@809B`J00T0:2`K02P_700X
;a`0:2lN02@[700P9aL07RDD01hU4`0O8a@03oooool000gooooo00<0e]_H0?ooo`3oool0ZP3ooolJ
ooooo`06071hL@0i@CP0<3@_02X[:`0W:2X08b<V0P0N72002`0L6Qd06APH01LH500C5Q404aLA01<H
400E6Q008RLI02T]7P0_<bT0=CP`0080<cL`00/0<cHc03Dg>`0i?440>3a303Dl@`0b>Cl0<CXm02de
=`0V;Rl082HX01hS9@0201hP8P0<01hO7P0L7Q`05aTI01<E5@0?41403@d=01HI5P0O8a/07R8I01dO
5@0N8AL0:2`S0P0/<BX02`0^<bh0;C<a02T_;`0N8b@06AhO01LL7@0K8A`072<L01dU6`0K8AH06QlA
00806b4@00/06alA01DH2`0C5@/04A<9010B2P0@4PP04Q@901LH300G60h05AD;01HE2@0201LE1@0;
01dK2P0N7@d0=S/U03m7<017D3H0Be<h04iG>`1=F3T0BePj04]G>P1:ECX00`1:ES/02`1<F3h0BUDm
04MB?017DCT0BU<j04UC>@16CcD0Ae4e04I@=@16CcD0Adhf0080AT`d00/0Adde04U>>019D3P0AD`h
04E<=`15CSH0A4df04A<=@14CC@0AD`d04A;=00204I<=P0;04M>=P18CcH0Addf04I;>015BST0@TTj
03m6>P0l@cH0>T8c03Hn;P0b?BX00P0c?bP0300b?R@0=ClT03Do900e?RD0<c`W03Dl9`0c>BH0;cDS
02le900`=R@0;34Q02lf8P80<cTU00H0<c/V034i9@0b>RD0<CTT030h8P0_=b0202`d7P0302hd7`0/
<Al0:blO0080:blP00/0;S8S02`a8@0[<200;34P02/b8P0X;b009BdM02<[6@0R:AL09BXI02T^7002
02H/700602H]7@0U:a/08bTJ02<Z6P0Q:1H07b<@3oooool000gooooo00<0KX9i06QlL@2b_;P0ZP3o
oolJooooo`80oooo00@0XZNU04iJD`17Cd/0?dA20P0f>CT02`0]<2h092LQ01lR600M8AL0720G01hQ
600Q8aP07b0E020N5`0W9B@0;Bd/0080;Rh]00/0;bla03Hi>P0i?D00>Sm503]4B00h@DH0=3i202lh
>`0_>3T0:c4c02`d<P02030h=@0<02T/;00U9b`07ahV01DC7@0@3AL03P`E01LG700L824061/K018D
4P0>40d04aLB0P0H71P02`0R:2<0:2lZ02/c;00R:B<07RHO02@/8`0R:b407bPN01dU6P0H7Q@05ad@
0080724B00/06al@01TJ300D5@X05AD;01<C300@40T04A0:018B2`0C4``05aL?01PH3P02020Q4@0;
02<T4P0T9aD0:BlJ03Dk8P0oABT0AT`a04]B>01?ES/0CePo04iI@@1;ET400P1;Ed80301:ESh0BUDk
04YD>@1=EcX0CUDj04]A>01=DST0BDhg04U>>@19D3X0Adlh04UA>080B50e00T0BE4f04M=<`16Bc40
ADXb04M<<`18CcL0B4li04U?>P18CST00P17BcT204A;>@0;04=;=P15CcD0ADdc04M?=014BS@0ADTf
04=7=`0n@cD0?T@e03Tn;`0e?2`00P0b>bT0300c?bP0<SlT038n8`0a?B80<c`R03Ho900d>b80<STP
034h800e?BD0<cTS034f8@80<CHS00/0<SPT038h9@0c>BP0<CTX030j9`0^>2D0;SLT02hh8`0]=b80
;3HP02`b7P0202da800;02`^7`0^<B40;S4Q02hb9@0]<RH0;38V02L^8P0S:al092`N02@[700W;Ad0
0P0U;1h01P0R:Q`08BTL028Y6`0S:QX08RTF01lV4@oooooo000=ooooo`0607fAR@23UY00Q9R@082B
S02R[j/0_lS6Y`3ooolJooooo`@0oooo00l0g=oO0;:h^01`P7`0L81l05m^K014Cdl0@4Y804QAB`1<
EDX0BU5503Li=00];B`0;B``02d/<P0[:S000P0T8RL02`0S82@0:bX[02h`<P0e>C`0>3e103U1@P0f
?d40;cLk02`d>00^=cP0<SXi0080=Slm00`0=Shm03To@00d=c`0:BTd01lN;00K6RL07QlX01hQ9P0C
5AX0418C00l?3P0>3Pd2014B400501@E4P0G6QL07B8N01lW8P0X<BT00P0Y=2X0100V<BL082PM01`T
5P0K8Q8201/Q4P0;01dQ4P0J70h05aL;01LH3@0F5`d04a<:01<B2`0B4P/051@=00l?300B4Q000P0l
ASD02`14DSd0BEU004=B>011CC<0?dP/03i6:`13BBl0AT`d04YA>`1;Dcl0BeE10080BeM000`0BULn
04]E>`1:DST0CUDk051F?01BFSl0D5Hm051D?01<D3/0BU0l04aB>`1;DST204]B=P0;04YA=@17CS<0
Addc04Q==@1:CSD0Bdlg04Q=>@1<DCd0BU0n04I<>@14BSL00P14CST02`14CSL0A4he04===015CcD0
ADde04I==@16BcD0ATXg04E:=P11AS<0?40a0080>Cl_00@0=T0[03@n9`0d?R@0=ChS100f?RD0100f
?BD0=C`V03@j9P0e?2L2038h9@0402lf8P0_=R<0;SLT02dg9P80;cTV00D0;cTW02hh9P0_>RL0;SPV
02hf9P0202`a8`0;02/_8@0/<B<0;S8U02d`9@0[;bD0:RhU02P^9@0U;2809RdR02@[7P0V;Ah00P0T
:a`01P0S:1/08RLJ024X6@0Q:AP082LG01lV5Poooooo000=ooooo`0608>FS027V9<0RibJ08^KW@29
VId0QYJJ0P26UiP00`2V/k<0hNGV0?ooo`2R0?oooa[ooooo203oool02`3PiND0WZ^^07Z;S`1mT8h0
PIF?07nCR@1/NG<0GfYV06EbK@18Ce<09bLb00807ahW00/06QPN01PF6`0L71l09RLW02da;P0e>SL0
=chm03Ho@00a>Cd0>D=403a7A`0203i8B00<03e6B@0nADX0>d1703TnAP0c>T@0;cDo02`a>P0M8B`0
5ALQ018C6P0A41<04a<B0P0C4a402`0@3`h0410<010B3`0D5a<0:34X02Pa:@0]=b`0:34V02@/8`0P
:1h07RHK00807B<I00/0724G01TN5@0G6a805a/A01DH3@0F5``05AH;01TI4@0E50l061PB01dN6002
03@i;P0;059OB`1GIe00EfU?05EVB@1<Fcl0AE<i04A?=@13C3<0ADle04M@>01:Dc/00P1?Ecl0301<
ECd0CEHm051I?P1?F3h0CEHn04mH@01@Ecd0D5Pl04iF>P1>ECT0CU@j04iD>`80CE<k00/0Be8k04eC
?01;DC`0BTlj04U>=P19CSD0BDhf04Q>=`19CcT0B4hf04M==@0204Q@=`0504M?>016CcP0AE0g04MB
>017D3L00P16CCH01016C3D0AT/d0497<@11B3<203i5<00<03]2;P0j@B`0=C/W03@k9`0c>bL0=T0Z
03Ho:P0d?bX0<SdX03<n:00b>bP0<c`Z0P0b?BP02`0a?2P0<C/W030i9P0a>bH0<3XU02lh9@0_>2L0
=3d]03<l;`0`>Bh0<S/_0080;cDY00/0;C8V02`a9@0]<BD0:c0T02/a900Y<2<0:BhR02/`8`0Z;b<0
:2`R02P/800202DY6`06028U6@0R9QX08BHJ02DY6`0T:A/08B@J3oooool000gooooo00H0PYN?08ZL
U`2<WId0SIfP08jMX`2<W:@208ZIWP0508^KWP2;W9h0S9jN0<G@d03SjNP0X03ooolJooooo`/0oooo
00P0a<o?0:Ri]@2:XYP0Rj:D08ZNT@2<X980KWaf020O;0807ahW00/06aTO01LE6P0D4QD05A@F01lP
7`0T9b@0:Rl[03@m>00f?c/0@dm804EBB`02041;A`03041:BP0lA4P0?4A:0080>D5900L0>T=>03Q2
B`0f?TH09R/f01/N:@0F6B004a<I00804a8F00/03Pd@014?3`0B40l06A`F02Xb:00T;2@09B`T02P_
9@0X;b@08b/Q02<Y800201hS7@0;01hS7`0O91l07bHN01`Q6@0J7QD06QhD01TM4P0M7a@06QTA01dM
5P0Z:R000P0V91`02`19CSh0EF5;04eLAP19Ed<0CUi7055RAP1>Gd00AePh04ID<`17DS@0B54c0080
BU8h00T0Be8j04YA>@1<E3/0CEXn04YF?01=FSh0Ce`o04]G>`1=ES`00P1>EC/03P1>DS`0Ce<n04mC
?P1>Dd00CE5004U??`19D400B54n04QA>@18D3P0Adlg04Q@=`17Cc@0BDle0P18C3D02`18C3P0Ad`j
04A<>@16D3`0@d`j04A=>P13C3P0@TXc0499<@11BS40@TXa0080ADXa00`0@TLa03i5<00k@S00>3h_
03@j:P0c?2/0<CX/030j;00`?2X0;c`V034n9P0b?bH203A09P0;038m9@0b>bH0=3/V038i9@0b>BH0
<3HT030g9@0_=BD0;cLY034j;@0_>R/00P0^>2P02`0]=RD0:S8R02Ta8@0Y<B40:S<Q02`e8P0]<b40
:bhO02la8`0/;b<0:BdO00809RTK00H08RDH028U6P0Q8a`09BPO02<U7P0Q8ad?ooooo`003Oooool0
1P1oU8d0RIjJ08ZNW@2=X:40T::U08jPY@80SJ2P00L0SZ2N08fOW@2>XIl0SZ>O08fTW@2>YY/0b=C<
09h0oooo6_ooool>0?ooo`050<OBb`2AYiL0TZRF08VNS@1AG5P00P0P8BT02`0Q8RH071`M01HE5P0F
51D05A<C01LF500L7AT08RDQ02L/:00b>S<0>D8k0080?D<m00`0?TE103m5A`0nADT0?TE:03i7B`10
Adh0?dI<03i6CP0oB4l0>T98034h?@0S9BX201dM8P0;01XI7`0F51/04@hE028U9@0R9bD07B8O01/P
6`0R:Al09blR02D[7P0R9Q/00P0S:Al02`0R:20092/R028X7P0S:Ql082LM020W6`0P9AT06ahE01XJ
500F5Q<06a/G008071`G00/0GF]B05i_EP14DCl0;cP/034j;@0e@2d0Cf9204mR?`1AHSh0Celk04QE
=P0204MA=`0<04YB>P1:DSd0B58l04IA>P16E3/0BELm04iK@01;Ecd0CELo04aF?P1=E3`0C58m0P19
Cc/02`1:DCh0Be9004YB@@19DD00Ae0o04M@?P16D3`0Ae4j04YC>@18D3D0Adhd0080BDlf00/0B4dg
04M>=`17CcX0ATdl04E=>P16Cc/0A4`h049;=@12BS80@d/b04I><`0204E;<P0<04=8<@14B3<0@TTc
03i5<`0h?bh0<cd/02hh:00a>b/0<3XX034m9P0b?R<0<C/P0P0b>b402`0d>b@0<cXU03<j9@0`=b80
<STS038i900a>2D0;3@R02dg8`0a>BH0<3TV0080<3PY00/0<CPU02`b800]<b40:BhM02T_7P0X<1h0
:30M02Xa7@0]<B00;C4R02X^800202DY7P06024U6P0N8AL08bDJ02@X7P0Q91h082<N3oooool000go
oooo00@0QIbB08ZQV`2=Xil0SJ>Q0P2=XZ0208fRW`0508jRW@2<X9/0SJ6L08jRVP2?Y9/00P2@Yi/0
0`2DZid0[knc0<[Ec@2K0?oooa[ooooo403oool00`3Tj^D0b]K<07b?O`02045:A`0;02hb<00W:BP0
7A`O01XH6`0G5QH05QDD01LH5@0I6QD05aXD01dP6P0S9R000P0`=2`0300l@3T0@4E004=8A015CDX0
ADe=04M?D@14CU80@Ta@045=CP10BT/0@DQ903i3A080>C`o00/0=CLl02PW<@0Q7RX0:b`_024R9P0D
5AX04aDG01PK5`0H7AH0724I01lT6`02020U700;024X700O9aX082HI028Y6P0S:QX092XK028U6@0O
8AL071dH01XJ6@0O81l00P0K7Qd02`0f@3D0?4Li02L]9@0/<RP09BTP01dP5P0U;A`0?D/a05EXA`1I
KD`0EVQ;0080D5m500`0BUHo04UD?`16D3h0@4/j03m<>P12Cc`0Ae@o04YH@P1<F4<0C5M204]F@019
EC/204YE>`0;04eF>`1:ECT0BE8j04]C?018D3d0Adlo04UB?`19E3`0BE@k04I@=@17DCD00P17D3D0
1`18D3H0ATdf04M?=P19D3T0ATdh04I=>`15CCX00P15CSP04012BS@0@d`d04==<`13CC<0@d`a0458
;P12BS40@4Pa03e6<@0k@c00>D0`03@k;@0d>RX0<SXW034j9P0c?2D203<l9003038j900^=R40;3DR
0080;CLR00<0<CXU02hf8`0`>2D00P0^=B<03P0_=R@0;cHU02lf9@0b>2H0<STT030g8P0]=200:c8P
02P`7`0X<B80:S8R02/a8@0Z<R40:30O0P0U;1d01P0R:1`08RPK02@Z6P0S9aT08RHJ020T6`oooooo
000=ooooo`0308:GS`29XIP0RZ>J0080RZ6K00h0Rj:K08VOV029WiP0RYfE08fQV02AYI`0TZJM09>W
W`2CYid0TjJL09FWW@2DYY`0UjVN092RU`80aLk:00<0hNGR0?ooo`3oool0U@3ooolJoooooa<0oooo
0P2ka;l02`24Sh/0?dE602lb=P0V9B`08R0V020O800L6aT06a/F01TH500H61@061PE00805aDB00`0
:2PP02l_:@0i?3D0?dDo0499A@15CT`0AU9A041;C00nB4X0@Da;049:C@14BTd204I<CP0;04A8C@11
A4T0?3i703Lj@P0S92l05aHR014A6`0@4QL03Q0D00lA4`0B5A<00P0J7aT02`0M8aX07bDK01hS600P
9aT08bXJ02H/7@0T9a/09BLO02HX8P0W:BP09RPZ008082DW00/06A`O01TM7P0J7Ad08B<O01lP700L
7QX06A`H01TM600a>b`0@Dlk04mPB00205Q[C`0<05U/D01;F4<0=T0a02lh:`0^>2X0<S`^03I1<P11
CCX0A54l04YG@018ESh0BELo0P1;F3`02`1>G3/0BUHf04aF=P1;E3L0BE4i04UB?018D3X0AU4h04QD
>P17DSL0AU4f0080Ae4f00/0AU4d04MA=@17CcD0Addc04I:<`16Bc@0BDli04M>>018D3P0Ae0g04E=
=@0204E==00404A=<`0oB2l0@4Pa03m7<@80@TXd00H0?DD`03Y1;`0h?Bd0=3XY03<i:P0d>RX203Hm
:`0503Hn:P0d?RX0;CLV02Xc8P0]=2400P0^<b00100_=B40;S@P02hd800`>2<2038i8`0;034h8P0`
>280;cLQ02hg8`0]=2<0:S4Q02P_8P0V;b00:C<Q02H_7P0T;1`00P0W;ah01P0R:AX07B<F01lV5P0R
9QD08bLF024S5Poooooo000=ooooo`0608FKT`27WiP0Qj2I08JPVP27WiL0RZ6G0P2;X9L02`2=XIT0
SJ6J08nRW@2@Y9d0TZFM09BWWP2EYih0UZJO09VYX@2GZ9l0UZNN0080U:FK00@0U:JJ07J5O`2h_k`0
dM?DU03ooolJoooooaL0oooo00T0YJRY06U[KP0a<cH0;2h/02@U8@0N7a/071/I01XI5`0G5A<00`0G
4Q402`0H51808QlK03<b;00o@c`0?dI104==B@13CT/0A4i=045<C013CDh0ADe=0080A4Y<00/0A4U;
04U<D019Be<0ATQC03`nBP0a=4007b8]01<C800C4a`04A4G014B5@0201@E5P0;01XN6`0N8ah07b@O
020V700S:Ql09R/O02HY7`0U9al0=3L`03@g=@0a=3L00P0S92X01P0N7R@05aLM01LG700K7Ad0720L
01XM6@806b4K00<061lH01lW6P0T;Ad00P0a?BT0301DIdX0D69702/e9@0S:ah0728G01XQ5@0J81@0
;cTU03U3;@14CSH0BE@l04YF@080BUDo00/0C5Pn04]G>`1;EcX0BEDh04QC=`1;ECP0Be8g04Q?=P16
CSL0BE8i04E?=`0304A>=P0:04E@>014CC@0A4``0499;`15Bc80AT`c04I;<P18CCD0Adde04Q=>080
Ad`j00`0A4Th0458=P0oAS@0?DDb03i6<@0oB340?dP`03m7<00oAS00?48]03/n:`0h>B/203Hi:`0;
03@i;00b>B/0;SHW02de900]=280;3@N02dd7@0]=Ad0:S@K02Pa6@0/=1/00P0_=ah02`0]=Qh0<3LR
02hd8P0]=2H0;3<Y02D[8`0S:R808b/P02D]8@0V;R409blO00809BhM00H08b/I020X5P0R:AH08RHC
024T4P0P8a4?ooooo`003Oooool01P25Vi<0QinH08NPV@26X9X0QinG08ZQU`80Rj2G00/0SJ6I08fQ
VP2?XYd0T:BM09:UW@2DYih0UJNN09JVW`2IZJ40UjRO09JWWP0209BUV`0409BVVP1fQGl0^;nl0=7C
e9@0oooo6_oooolG0?ooo`090:FXZ@1YJfh0<C<f02`^;00T9B407QlK01`K6@0J6AL05aDC00<05a8A
00/061@B028O6`0c<R`0?d<l03m6@@13CDT0@di;04A>C@11C4`0@de>04E=C@0204A:C00;04A9B`19
C500BD]C04I8D`0l?TX0<CA001lR;@0C4b004a<L014A5`0A4QD00P0D5AH02`0J7Q/07R<N01lT7`0P
9Q`08bXO02H[7`0V:Al09BLO03@g<00d=cD0<C@g00808b@Z00H07QhT01LG7@0G5a`06adM01`P700J
7AT201/Q6`0301PO600O9aX092dM0080<CdY00`0E6M:051RA`0[=BD08b/N01`R5`0J8AD06R0D02li
9@0i@bd0A4hf04UD?01:ET0204YE?`0;04aH?P1;Ec/0BeLj04UE>018DcL0BeDh04]B=`18CcH0AThg
04UB>@15CcL00`14CSH02P15D3P0A4dd04A<<012BBl0AD/b04I<<`16Bc80B4de04M==@18CCP204M<
>P0<04A9>011B3H0?dHd03e5<P0nAS40?dPa03m8<00oAc00?dH`03a2;@0k?R/0>3T[0P0f>B/02`0d
>B`0<ST[02hf9`0]=B@0;C@R02`d7P0]=1d0;CDM02Xd6`0X<AT0;3@K0080;cLN00/0;CHN030g8P0^
=280;C@V02`c:@0U:b<08bXR02<[800U;B409RhQ02L_7`0202D^7@0602<[6@0P:1H08RTF028V4`0Q
918082<A3oooool000gooooo00H0PIB=08VNUP2;XY/0Rj:L08VOW026W9T208VNV`0;08bPWP2>XIl0
SZ6P092TX02@Xid0TZFN09JWW`2EY9h0VJVR09NVX02IZJ400P2GZ9h01P2EYih0Uj^P08jQU@1bPGL0
PhZ60:Z_ZY80oooo6_oooolI0?ooo`070<k?c`2OXYh0>T0g02L/900R9al06adI01TI5`0201PD4`0<
01XD4`0H4Q406Q@D01hI5`0U8b00;S0]03Hk>00mAD00@4U504A>BP17DDd0BE5=0P17Cd/02`17C4X0
AdU;04E6C@15AU00ADQB04E:E010ADh0<CLn01dO:@0K7BD05QTN00804A8I00/05APN01dR900P9RD0
8BPT02<Z9@0T:bD092TS028U800d=c00?dDm0498@`0203Hk>00;02/^;`0R8bH06aXO01`M800J7Al0
6QdL01XN6`0F6aL04aLC01PN4`0M91D00P0H7`l0100U;Qd0:S@R024Y6P0K8Q@201/Q500601LM4@0S
:Q/0:c8P03a6;`10BS80A4hg0P14CST02`1<Ech0C5Tm04eI?01<F3T0BE@g04iG>@1;DCD0BDlf04YA
>018CcP0ATli0080ADhi00/0ADlj04I@>`16D3/0ADde049:<@0mA2d0?T<[03m3:P12ARh0AD/c04E:
=@0204M<>00<04M=>P14BST0@4Li0416>00nAS@0?DD`03a4;`0mA300?D<^0455;`0m@2`0>cd^0P0l
?c002`0g>bl0<cP^034g;00b=b/0;SDT02`d8@0^=b80;cTQ02lh7P0/=Ah0;38M0080;C@O00/0:c8M
02le8@0]=2<0;CDW02df:P0Z<BL09BdS02H_900S:Ql092dN02H_7`0202H_7@0602@]600U;QL09bhF
02L]4`0R9Pl082@?3oooool000gooooo00H0PYB908^PV02<Y9d0R9jM08ROWP27WJ0208RMX00;08VO
X02=XJ00Sj:Q096SX`2CYZ@0U:NT09NXX`2GZJ40V:ZP09RXX02HZ:400P2K[:@02@2J[:<0V:bR09J[
X@2EZYh0S:6E07j@Q01ZNf`0N85j0::UXP2?0?oooa[ooooo703oool0103>d<h0UiZH02TZ:P0S8bH2
01lM800<01`I6@0M6QT07A/J01dK6P0O7Q/07adK024Q800V:2D0<3<`03m5?`17CdL0C5A=0P1=EE40
2`1<DU80BDaA04I9D@15B540@DIA04]FF`12C580B5=C03e6A@0j@D00<C@i00807b0[00/06Q/W02T]
=@0W;C<08BP[01lW9P0P:BD07bLR020V800P8Ah0;C0[03Pn>@0203e5?P0;03a3?@0i@C/0<CDb02H[
:`0P9BH071lQ01LK6P0B5A<03Q4?01LL500J81D00P0J7a<0300M8QH08bXL02H]800M91P06b8E01`S
5`0N9AT0:C<T03<n:P0hABh0?TTa049<<080@d``00H0BE8e04UA<`1:DcD0CEDi04eD>@1?Ec/204]C
>@0304YD>@19DcL0BUDi0080BE@j00P0BU<j04]D>`1=E3h0CU8m04Y?>P16BSP0@dPe0456<@<0@4L`
0P11Ac401P14C3@0@T/d0499=@12BCL0@4Lf03a4<`80?dLf00@0?4Db03i6<@0lA300>d8a0P0l@S80
2`0j@340>D0a03U1;`0j@Rh0=SlZ03@l9`0f?BT0=S`Y03<j9P0b>RL0<3PX0080;3DW00/0:S8U02Tb
900Z<b@0:S@T02/e9@0^>2P0:c@U02Tc8`0[=280:BlN02/`7`0202X`7P0602`b7@0[<AX0:c0H02P^
5P0X;1L09RTE3oooool000gooooo00H0Qi^A08jSW@2>YJ<0RjBT08ZRYP2;XJD208VOX@0;08RNX02;
X:00SJ:R09:VY02CYZ@0TjJS09BWX`2FZJ40UZZP09V[X@2K[:<00P2JZZH02`2I[ZL0VJfW09R/Y02H
[J@0VJjU09N]X`2EZYd0S:2@06=`J01LIf00^<2j0080cm7BR`3ooolJoooooal0oooo00l0Wj:Q069R
I`1RHVL0:R/a02d_<`0b=CL0:b`]02LX:00U9RD08R@Q02@V8P0V:2<0<3@]03@h<P11ASd00P19CDH0
2`1?DDl0Ce9C04iCF01:DEL0@d]B045<C`12CTh0AU9>04]GD`1:DU80BE1C0080A4Q?00/0>3a603Dl
A00Q9C406b0X01HM800D6a`05Q/H01LK5`0D51@05aDH024P8P0203@g<`0;03a2?010Acl0@DU003i8
@00^=S<09B`]01hS9P0G71`041@B010D4@0D5Q800P0E6A80300Q:1d09BdO02Xb8`0U;Ah092`L028Z
6P0N91H09RdO02/a8@0b>BD0=C`W03a3:@80?D@Y00/0A4X`04Q=<`18CC<0BDlc04aA=P1<DST0CE@j
04]C>P19DcT0BE@h04]F>@0204UC>00;04UA>01:D3/0C54o04iC@@1=DCl0BTlm04I;>P13BSH0@TXd
04===@0oBC<00P0oBS@01P0nB340?DH_03i8<00oAc40?THa03Y2<080?4Db00@0>D8_03M1;P0f@2d0
=d8_0P0f@2d02`0h@Bh0=D0]03U2;P0h@Bd0=d4[03Ho:`0h@2d0>44^03Po;@0f?2d0<S/^0080<3T^
00/0;cT]02/e:P0Z<bL0:34S02L`800X<R00:C<P02/d7`0/=R00:c<L02X_6@0202X_6P0602HZ6P0X
;1/09b`I02DZ5`0X:Q/09bTK3oooool000gooooo00H0R9jF08fTWP2>YJ@0SJBV08fSY`2<XZL208^P
YP0;08ZOX`2<XJ80SZ>S092UY02AYZ<0TjRR09FZXP2FZZ80U:NP09RZX`2K[:H00P2K[JX00`2J[Z/0
VJfZ09^_[00209V]ZP0609Z_ZP2J[jL0W;6V09R/W`27Uhh0N8N00P1MIFP00`1BEeh0`<K20>3Sh028
0?oooa[ooooo8`3oool02`2]/[40R8n=04mDE`1<E580A4]403Pm=P0d=bh0<C4Z030_:@0`;R`0=C<a
0080>3Hd00/0@d=004Q9B01=DU40CeMF04aHE@19EU00Ae9<04MBC@1>F5D0CUEG04iCF`0204eEGP0;
04aEG@17DeP0=3i702`e?@0J8bT072<T01LJ6`0C4aL04@hD01XE600J51@00P0l?3802`0k>S@0>CPe
03Li=P0j?S/0?dE103i7@`0iA3l09c0]018H5P0B5a<041@@00804QD?00`09RhP02H]7`0Y;al0:S0M
02T`7@0Y<Qh0:c4N02L/6P0S9QL08R<E01lP4P0V:AP202la7`0;03m3;017CS<0Ae0f04YC=`19DSD0
BE4g04Q>=`17CCH0Adhg04UA>P18DST00P17DCP01`17DST0BE<n04UC?`1=Ed80BE8n04I@>P15CcP0
0P14CSH02013CSD0@dlg045<=@11C3D0?d/c03e9<@0lBS00?DP^0P0mARl01P0kABh0>T<`03]4<@0i
@c00=d4^03U4<080>TDa00/0=d8^03A0:`0d@2/0=D0Z03Do:`0d?b/0>48]03Q1:`0i@B`0=cl]03Dk
;00203@l;@0;03<l;@0a>Rd0;cP[02`f9`0X<B40:C<Q02/e8@0/=R40;3@P02/c7P0[<A`00P0/<ah0
1P0Z;a/0:BlI02P^600V:aL0:2`K02P]70oooooo000=ooooo`0608BJT`2;XI/0Rj:N08bQX029WZ00
RYnS0P2<XJD02`2;X:<0S:6S08fSXP2?YZD0TJVW09:ZY@2E[:D0UZbS09FYY@2HZjT0UjZY0080V:^X
00/0VZb[09Z]Z`2J[Z/0Vjj/09b`[@2P/jh0X;B]09n`Y`2P/jH0O8^3069[JP0206I_KP05079kN@2I
Z9/0U:>G0;6m]03?f=40QP3ooolJooooobD0oooo00T0hnOT0<G=aP2;WH`0E5mI04]CC017CDH0A4A0
04=2?P0o?cX00P0f=C802`0d<c80=cHg0451@P1:CDd0BU9?04iHD01?FTh0DemB05=ME@1?EeH0Be9H
0080CE=M00/0D5QQ04mJH`1<F640BEEL03e8C@0f@4409BX^02<S9`0M5ad07QHJ02LR8@0204I5?@0;
02`W:00X9BL08alS02<P8`0_<S00=clj03a7?`0mC3l08bhU01DM5@0A5`d00P0=40L0300D60h05Q/?
01TM3@0Q9A<092TH02P_7P0W;A`092TK024U6@0X;B008BDJ01lQ60807QlF00P0?DDa05aZC01HIDP0
F6E705=L@`1>ECl0BE0m04M=>P80AD`h00h0@T/f049;=`12BcL0A4dh04E??017DSd0B58k04UE?018
DS/0ADlg04===@11C3@0@The04=A=P80@Dld00`0A50d041=<@0oBS00?TP^0418<@11B340?D@a03e3
=00k@c@0>D8b03Y3<P0kAc<203M2;P0;03M4;P0gA2`0=d<Z03M2:00h@BP0=ShW03Hm9`0f?2P0=chZ
03Hm:`0e?Bd00P0d?B/02P0c?2X0;SLW02hg:00]=RL0:S@T02Xd8P0Y<b40:c<P02`b7`0/<1h302/_
7@0602T^6P0U:QH08bLF02L[6P0V:QT09R`J3oooool000gooooo00H0QYRE08bOW`2>XZD0RinU08RM
XP28WJ4208^PXP0;08bQX@2<XJ00T:BT092TY`2@YJX0TjV/09:XZ@2CZJH0Uj^X09Z^[@2H[:d00P2I
[:`02`2K[J`0W:f[09b]ZP2P/Jl0X[:`0:6b[@2P/J/0XK6[0::e[029VI80IFe_0080IVe^00P0SifD
09^ZX02O[:<0Y;>W0:JeZ@2W]Z/0^<:l0<cAd8<0oooo6_oooolX0?ooo`060=kQh02l`l00LWYi07f8
OP26Tgl0ATQ20P15Ad002`11@C/0?CXh03hj>P0l>CX0?Sdo0494@P1;DDT0D5U>05=NDP1CGEH0CUME
0080CUAH00/0E5MM059GGP1=Deh0CUIP04eHG`1=Fed0B5AD041:BP0c=CH0:2@X03Tg=@0203lo>@0;
02DP8`0S82@06aLN01HB6@0F5AP06adM02<X8`0Y<BP09c4U01XS6@0G7A800P0G7Q40300B60`051T=
01@H3@0D5``061`@01XO4`0L81@05a`C01<F4@0Q:1h09B`P02P]8P80:2`Q00/0<CHW04eH@01OJe80
HW1F06=aF@1LJE<0D5Y804U??`12ASD0?D4a03Xo<00203]1<00;03i2<`11AcH0A4`h04MA>`18DCh0
ADln04A??@0oBcP0@Dhg041?=011D3800P11Cc803012CC00@Tdb049<<@14C380@DLb0498=@0nA3D0
?DDg03a6>@0h@cD0=d8`03U6<080=d@]00/0>4@/03M3:P0kAB`0>T8Z03Pn:P0g?R/0<STX030h9`0`
>BL0<S/X034l:@02034l:00;034l9`0`>bD0;cTS02hg8@0/=Al0:c@M02T`700[<1h0;C0O02`]7@0]
;ah00P0];al01P0[;1d0:2XK02LZ6`0X:ad0:2`N02DY7Poooooo000=ooooo`0608RIV@2=WjD0Sj6Z
08bNZ02;WZL0SJ2X0P2?XZL02`2?XJ<0T:>T096SYP2@XjP0TJFY096VZ@2AZ:T0TJNX09BXZ@2H[:h0
UZ^_0080Ujb]00L0Vjn]09j`[02N[J`0Wjj_0:6`/02S/k80XkBb0080YKF_00l0W:bX09FSX02?ViL0
Si^G09NVWP2S/ZL0YK:Z0:Ne[P2Z]Zl0Z[F`0:^e/02X/Zd0ZK>/0=CJe@3Zk^/0P03ooolJooooob/0
oooo00<0d=GA0;W4]`22Sgd00P1ePFd02`1CF4d0EUU>055BB@1;BdD0ADA10410>`0n?cT0@D<k04Q=
@`1=DdX0DUUC0080E5aH00/0F5eN05IKGP1BEed0D5MM04iFF`1;F5X0CUaL059OF`1BG5L0C51?04U:
B`0203/j?@0;028N:@0N7BP06QTT01@B700D51X04Q@G014E4`0C61<051/C01<L4`0D71400P0I8A80
300L8a<06QlB01PL3`0I6`l05QP>01TL4@0E5@`04A89010@2P0A4@d05QLB01TJ4P806a`E00/0:RhS
038f;018DD40DUi;05e]E`1RM5h0IWQP05QUD@0nA3D0;RlR02LV6`0202LU6P0;030^8@0e=BP0>CT[
0414<P14BSL0@ddk04=??@0oC3P0?ddd041@<011D2d00P11Cbd03013Cb`0@4XY0457:P12B2l0@dPc
03m5=@0oASL0>d8e03]4=`0h@cD0=T0`03E1;080=D8Y00/0=D4W03Y4:00i@2P0>d4Y03Pl:00j?R/0
>3`]03Hl;P0b>R`0<C/^02df:P0202/e:00;02`g900^>R<0;cXQ02lj7`0^>Ad0;3HL02df700]<a`0
;c<M02l`7`0a<R400P0_;al01P0^;B00;2`Q02/]900[;RD09BTP028U7Poooooo000=ooooo`0608BF
U`29Vj80SJ2Z08fOZ`2;WJT0S9bV0P2=WJH02`2>Wj@0TJ:W09:SZ02?XJH0TjJX09>XZ@2BYjP0TZNY
09BXZ@2J[Zl0W;2a0080VZj]00/0VZf^09Z^[@2L[Zd0WZj/0:2_[P2Q/Jl0X[>_0:6b[02U]Jh0YKF]
0:BcZP020:6_Y`0<0:>bZ@2V]J/0Z;B]0:Re/02/^;@0[KNc0:nj]P2^^;<0[KVb0:Zd[02/^J/0ZkVT
0P3Efm400`3Zk>L0oooo0?ooo`1j0?oooa[ooooo;P3oool20=3FbP0;0:^aY02AVXT0QHen07^2L`1V
KEh0CU=304I9>P10@SD0>SXa03dn=P0n@3/00P16BDH02`1>DU80E5]K05AMGP1BGE`0CUYI04aHE`1;
EeH0DUeK05QRG@1LHUl0FEeO0080EEYP00/0>3U702d`?`0R9C8061/W01DH8`0C5a`041HG00dC400;
40/04QT?01XR4`0201lX500<02</5`0S:aL08BHD01lS4`0N8Q<06Q`>01HH2@0A3`D04@h701@A3@0F
51006ALE0P0F4a<02`0D4aH061HJ02HX9P0a=S80@Da204mOC@1JK5<0D65805Y[B`11B380=cPX0080
;b/S00/0;RPV02LQ8P0[:2D0<c<Z03Tn<P0mACH0?dTd03a7<00lB2`0>dPX041;:P0203i8:P0<03e5
:@0l@RL0?48X03a3;@0k@Rl0>D0`03U1<`0g@3<0=3h`03Ho;`0h@2d0>44Z0P0g@BL02P0j@RL0?TDZ
03e4:`0m@b`0?D8]03Tm:`0g?2`0=Sh_03@l<00a>Rd302`e:00;02/d9P0[=B<0;3LS02hh8@0_>R80
;SXQ02`g7`0/=Al0;cHP02da7`0[;Qh00P0Z;Al01P0[;R40:RdS02P/8`0X;2<09BTO028V70oooooo
000=ooooo`06086HV@28WZ00Rj2U08bOZ02;WJP0RibT0P2<WJ<02`2<W:<0SYnU092RY`2@XjL0TZBU
09:UYP2CYZT0TZNZ09>WZ@2GZj/0V:b/0080W:n^00/0VZf^09f`/02J[Jh0W[2`0:2a/`2R/KD0X[:d
0:6a/@2T]K80Y[F`0:Jc[P020:Jd[P0<0:Fc[@2U/jh0Z;F^0:Zg/@2[^;<0[;Nd0:fj]P2]^kD0[[be
0:bj/02Z^Z`0[[j[0P2]_JX00`2]^JP0`/bo0=SOeP1j0?oooa[ooooo<@3oool02P3[k^X0e=WA0:Fa
XP2@Vh`0QY=n055FB@0m@CL0=SXb02la:`0/;BP202`[:@0603Hf<`1;CdT0CUE@05=LF@1FH5`0E5mL
0P1@Fe/00`1DGE`0FF5N05YQG@0205eSHP0;05aRH`1EG600?TA;03<j@00U:c<06AhT014F6P0<4Q80
2Q0;018J3P0K8a400P0U;aP0300]=b40;cXR02/d700Q:A@07B8?01TK2P0D5PH04a@5018A1`0F4`/0
6aP?01lL4P8081dH00/08AlL028N700N71/08b8R03<f<@10B3d0DEi902<X7P0W;b00:S<S04AA>@02
05UVB`0;05MNB01BETD0BD/l03m0=00k?S<0?D8e03m5=P0oAC@0?4<_03a4:`0l@bP00P0lABT0300i
@2P0>3lW03Po:@0g?BT0=C`X03Hm:@0h?bh0>3l`03Dl;P0d>R/0=3XY03Tn:`80>d4_00/0>D0]03Po
;00i@Bd0>Cl]03Q0;P0h@2/0=SdX03Hn:@0f?BX0<CTW02de9P0202dd9P80;3<U00T0:c<V02/d9`0[
=2L0:cDV02`f900/=B<0;3@Q02Ta7P0Z<1l00P0Z;ad01P0Z<1`09b`J02X_7@0[;al0:RhL02L/6`oo
oooo000=ooooo`06082FU`28Wj80S::X08bQZ@28WJH0RYfU0P2<WJD02`2>WjP0SYnY08jOZ02@XZT0
TjF[09:TZP2CYZd0U:N]09BW[02EYZ/0UZN/0080VJ^_00H0VZ^a09b]/P2M[K@0Wjne0::c^02R/KL2
0::`]@030::a]02V];H0Y[:c0080Z;Fe00/0Z[Nf0:Vf]02Y]K00Z[J`0:bi]@2_^kP0[[^h0:fk]P2]
^k@0[Kba0:fl[@030;6o[@060;6o[P2b_jl0/;f_0;:m/@32b/80emoHM`3ooolJoooooc@0oooo00L0
j^gZ0=3Hd01kQg`0Adi=03i4?`0g?3@0<3<Z0080;2dS00/0:RPP02`X8`0k>c@0@dE004Y?B`1@F5<0
E5iJ05QTG@1MJF40FF=L05INE`0205YQFP0;05QOFP1IHUh0Ef5O05=OG01:EeD0=d9201hT9`0D61P0
3a<?01LM4@0M9QH00P0R:aP0300X<Q/0;SPQ02/d7@0T:aD07B0?01HF2P0@40H03Ph7014B2P0C4`h0
:2/P024R60807A`B00/0D5Tm04M==00X9b00A4]003e2>@0f>c@0;c@]02HY8@0H6A<04a<=00l?2@02
03Y3<00;07nDL021U7<0OI1b05IOD@1AFTh0CEA:04U?@`17Bch0@TLh0457<P0mARd00P0nBB`0300m
Ab/0?4@Z03Y3:@0g?bD0=clV03Dl9`0f>bP0>Ch[03Ll;00b=bT0=3PY03Di:`80=3P/00/0=3X^03@k
;P0e?C00<c`^038l:`0c?BP0<clV038n900a?280;SPO02hf8@0202he8P0;02dc8@0]<b80:S8T02Ta
9P0X<BL0:S@X02Xe9@0Z=B@0:cHQ02/f7`0Y<ah00P0Y<Q`01P0Z<AP0:C0G02T^600X;AT0:B`I02P[
6@oooooo000=ooooo`0608>FV@29WZ<0SJ:Y08^OZ@29WZL0RYjV0P2;W:@02`2=X:H0Sj6Y08fNY`2C
Y:/0Tj>[09BV[@2CY:`0U:J]09BT[02EY:`0UJ>/0080UJB/00/0UZJ]09ZY/02KZK00WZbc0::a]`2S
/[P0Y;6f0:B`]@2V/[H0Y;6e0:Nc]0020:Rc/`030:Rd/`2Y]K80[KRd0080[;Rf00L0[[Vg0:nj^02]
^[L0[[fe0:jm/`2^_Jl0/Kn`0080/l2`00T0/[n^0;>o[P2c_Zh0]/2a0;Bo/02a_k00[K^]0=;Id@3U
j^D0M03ooolJooooocL0oooo00@0_<:m08ZBRP17CTL0>3dd0P0f>b`02`0a<bH0=CDZ038a:`0b<2l0
<S0`03@c<`13B480CeM>05MQE@1IHeL0FfEG0080F69E00/0E5eC05EOE@1HIET0EV=K059QF`1EIE`0
>TE001XO7`0J7aX061dE01PN500201XP4P0<01`R4P0N91<08BDF02@Y600N8Q<051D=01<A3P0A40l0
3`h>018@400S91l05A<C0P0_<bh02`2[b9h0Z<FP06YlJP17DTT0AU15024S800N7a/05QHC01PH4`0C
4Pl04Q0>0080518A00/0N8a]09F]RP2;X880Q9Qo06]jK01WMVP0I79Q069`G01LIeH0EF5=055NAP02
04eH@00<04MB>P15CcP0@d/f03m7<P0m@bl0>Sl[03Tl:`0i>b`0=cXZ03@g:`0c=RX0<SDY0P0c=bX0
2`0a=BP0;c@Y02lf:@0/=BL0:C<T02dg9P0[=B@0;3DT02dh900]>240;3LO0080:c@N00/0:c<O02Xb
800Z<R40:C4Q02Xd9@0[=2D0:cDT02Tb800[=200:S8L02Tb7@0202Tb6`0602/b6P0W;QP09b/G02H/
6P0V;1d092XK3oooool000gooooo00H0MXJ<08bOX@29WJ@0QIVT08BGX`26Vj@208RKX`0;08fOYP2>
X:P0Sj2Y08jOY`2AXZT0TZ>[09:TZ`2CYJ/0TjBZ09JV[@2IYjh00P2IZ:l209NW[P80VZR_00L0VjV_
09f/[`2Q[jh0Xjn^0:Nc/`2V/[D0Y[6d0080Y[:a00`0Yk>_0:Vc/02/]k@0[KRg0:Vd/`2Z][H0ZkRf
0:^i]02[^[80ZkV`0;2o/P2`_k020;2m[@0;0;2m[02c_jd0/l2]0;Fn[02d_j`0]L6_0;C0/02a_Zd0
[kfZ09NTT@2n`;X00P3LgMY`0?oooa[ooooo>P3oool03P2RXj40Q8Qo08B8O`1MHeL0Bdi60410?@0m
>cT0=S<a02h[:00Y9R<0;2XU0414=`19CT40FF1>0P1JHe402`1JIE<0C5I905IRD01>FDP0BUM804QG
B01=GD`0>4@g02D/8@0O9QP07B4D008061`>00H06A/>01TJ3@0M7A80824H01lP5`0H6A8201@C3@04
01@C400B40l05QDD01`L6`807AdO00/0Hg5P07^?N02adjX0JGeU03<i;00V:Qd07QlE01HE3@0B3P/0
510>01@@4002010>3P0;03Hm<`2E/Hh0R9n208JLP@1jSGD0E5mC05YVE@1PKE/0KG]X07f?N@20U7/0
0P1mSgH0301gQfd0J7AL061WD`1KH540EU]A04mDBP17CT<0?T@h03Y0=@0i?3@0=STa03Di<080=c/^
00/0<cP[038h:@0a>2P0;cLY02de:@0/<bP0;SDY02`c9`0Z<bD0;CHS02df7`0202Xa6P0;02hd7@0[
<A`0:S0N02T`7`0X<1l0:34R02H^7`0X<1l09R`K02P^6`0V:aT00P0W;1X01P0V:Q/092TI024W600T
;1h08b/P024Y7Poooooo000=ooooo`0607b>T023V9T0QibQ08NKY024Uj<0Q9NT0P24UZ<02`2;VjL0
SYj[08jO[02=WjT0S9nX08nSZ`2=XJP0T:BX096TZ02DYZX0UJR[00<0UZVZ00X0V:^[09RZ[02HZ:/0
W:Z^09f/[P2O/:`0Xk:^0:Ba[@2W];00ZKFa0P2Z][40302Y][40ZKF_0:Rd[`2Z]k<0Z;Bc0:Vf]P2Y
][D0Z[Nc0:bi]02_^kD0[[^a0;2n/@80/[na00/0/Kj_0;:n[P2c_j`0]L2/0;Bn[02f`:l0]Kn`0;G0
[`2f`:h0];f/0:^dX`020:N`WP030;g3]`3;c/P0oooo06d0oooo6_oooolm0?ooo`0;0>S[iP2l_kX0
IfUR05UJE00g<380=Bl^02hY:00X9280:RPR030`9`0i?2h00P17C3X02`16CCX0=CX^03Po<00b>RX0
;3DU030i:00kAS40@Tdd02/a800]<B4092PI00807b4E00L06AX@01PH3`0M7AD08R<L020R700F5Q<0
4aD@00804aH@00<051@@01hO6`0P8R400P0S9R<02`0R9R@0<CPc06MhI01UMV40?TLi01hO5`0U9AX0
4`h;014<2P0?20/03PH<00803`/A00/0Ae18086HP@28X8T0OiIo08JLP01iRg80JgMS05]RE@1MIUP0
RYb208JHOP0208ZLP00<09:SQ@25UGP0GVEE06AZGP1/M6T0KGM/06QcJ01RKEl0FfEH05=MDP19DTX0
ADa70P10Acl02`0nAS/0?D@h03]3=@0h@3@0<SXa02lc;00^<bX0;C8W02``8`0/<1h0;C8M0080;S0K
00/0<C8L034d7@0^<al09b`K01lW5P0J81<05ad@01TO4P0K8A@07R<E02@Y6@0202P/700602LZ7@0T
9a/09BPM028X7@0P9ah08BTO3oooool000gooooo00H0PIFA08VKVP2;WZ80R9^S08BFXP25Uj8208NJ
X`0;08ZKXP2<W:<0S9fU08fNYP2=WjH0SJ6X08jSZ02?XZD0T:BV09:UZ@2AYJL00P2@YJH02P2CYjL0
UJNW09NXZ@2JZ:/0WJ^/09fZZ`2O[:`0XZj_0:>_/02T[jl30:Nb[`0<0:Ve/@2Z][40Z[F`0:Vd/@2Z
^;@0Z;Fd0:Zh]02Y][00[;Vb0:nj/P2^^Jl0/;ba0`2c_k802P2c_k40]Kn`0;Bo[@2e_Zd0]l6_0;S3
/@2f`[00]l:^0;K0Z`2f_Z`20;Fm[0050;BnZP2c_JP0[;RR0;k7]`2TXJ<0J`3ooolJoooood00oooo
00P0fMWH09jJW00j=3@0>cLc03Ld;P0d<RX0=C@X03@e9P80<30Q00/0;RhN02/Y700U9AT0828E028V
5P0U:AP0<3DP03Ll9P0a=B<0;2lP02@V700201hO6@0<01/L600J71L07b0M02@U8P0N8Ad06ahI01LI
5@0H6a@061/B01@G400D5A408R@M0P0/<BH02`0d>Rd0=clb04=<?018DT00@d/j01dN5`0Q8a`06aTG
01LB500D3Q@04@/C00803`/C00/0>3Tj06ekKP1aQ7@0O99k08:GO029W7l0RYao082AN01lRg<0OHme
08:EN@0208FFN`0<08BDNP2CYHX0Q9=o05ELE`1HGeP0DEIA07B0KP25UGd0GVMM05URF`1JIEh0HFeT
0P1SL6H02`1TLFH0HFmQ05iYF@1IHU80CeI804E:?`0i>S80=3D/03@f:@0a=2<0;BlN0080<34N00/0
<S8O02l`7`0/;b008RDH01TL400?4`P02@`400H80P092`D02@`501LL3`0201dS5006028W600T9aT0
92HL02@W7@0P91/07R<I3oooool000gooooo00H0PIFA08VKVP2;WZ80R9^S08BFXP25Uj8208NJX`0;
08ZKXP2<W:<0S9fU08fNYP2=WjH0SJ6X08jSZ02?XZD0T:BV09:UZ@2AYJL00P2@YJH02P2CYjL0UJNW
09NXZ@2JZ:/0WJ^/09fZZ`2O[:`0XZj_0:>_/02T[jl30:Nb[`0<0:Ve/@2Z][40Z[F`0:Vd/@2Z^;@0
Z;Fd0:Zh]02Y][00[;Vb0:nj/P2^^Jl0/;ba0`2c_k802P2c_k40]Kn`0;Bo[@2e_Zd0]l6_0;S3/@2f
`[00]l:^0;K0Z`2f_Z`20;Fm[0050;BnZP2c_JP0[;RR0;k7]`2TXJ<0J`3ooolJoooood00oooo00P0
fMWH09jJW00j=3@0>cLc03Ld;P0d<RX0=C@X03@e9P80<30Q00/0;RhN02/Y700U9AT0828E028V5P0U
:AP0<3DP03Ll9P0a=B<0;2lP02@V700201hO6@0<01/L600J71L07b0M02@U8P0N8Ad06ahI01LI5@0H
6a@061/B01@G400D5A408R@M0P0/<BH02`0d>Rd0=clb04=<?018DT00@d/j01dN5`0Q8a`06aTG01LB
500D3Q@04@/C00803`/C00/0>3Tj06ekKP1aQ7@0O99k08:GO029W7l0RYao082AN01lRg<0OHme08:E
N@0208FFN`0<08BDNP2CYHX0Q9=o05ELE`1HGeP0DEIA07B0KP25UGd0GVMM05URF`1JIEh0HFeT0P1S
L6H02`1TLFH0HFmQ05iYF@1IHU80CeI804E:?`0i>S80=3D/03@f:@0a=2<0;BlN0080<34N00/0<S8O
02l`7`0/;b008RDH01TL400?4`P02@`400H80P092`D02@`501LL3`0201dS5006028W600T9aT092HL
02@W7@0P91/07R<I3oooool000gooooo00H0MXR608JKVP28WJ40QibS08NJY026VJH208RLZ00;08VM
YP2;WZH0S9nU08bOY@2;WZD0RYnV08fRYP2?XjD0TZFW096UZ02BZ:`00P2@YjP02`2DZZT0UJRV09VY
Z02KZjT0Wjj/0:6][P2R[Zh0Y[2b0:Ra/P2U[[00ZK>b0080ZK>`00`0ZkFb0:Zd/02[]K80ZkFb0:fh
]@2]^K@0ZkNa0:fj/P2^^K80[[Zb0:ni/02a_;820;:m/P060;>o/`2e_[<0];n`0;Jo[`2f_jd0^<:^
0P2g`Jh00`2f`:l0]L2^0;[4/@020;W2[P080;W2[@2j`jd0^/B/0;g:[@1mOg<0BD=30:RWX`3RiMiX
0?oooa[ooooo@`3oool01@2VYZ80S96104e@@019CC/0A4Le0080?cl_00/0<S0S02l]8P0Z:Ah0:2LK
02HX600W:QT0;c4P03/m;00i>bd0<C4X02PX8P02028S7P0<01dN6P0N81`09BLT02P[9`0U9b808RHP
01hQ700K7AX06ahG018D3P0A4@d051<>0P0I6a802`0W;Al0=3/Y04MB>P15CcL0=chZ02`b8P0U:1d0
824K01dM6@0L6a/06APH00806QXJ00/061TI02T]:@10B3d0C5E805eVE02J[Hd0TjB909>UR@2BY8L0
Sj2308fOPP0208bNP`0<08VIPP28VH@0RI^607V9N@1^NVd0IFiR06=]G`2P]YL0SZ>905]VG01KIed0
E5iF0P1CG5@02`1^OVd0N8Yf07b?N01mT7P0NH]c06ajIP1SKU`0GVMF05ELB`1=DT40B4dk0080A4Ld
00/0?Cl/03Dh:P0`=BX0:2`S01PK4P0=4@T02@`500D70@051`800`D100840@0200T;1@0600hA1P0F
6@/07R4C02<W5`0S:AT09BdM3oooool000gooooo00H0M8R6082EU`26VZ40R9fW08RKZ029W:X208RJ
Z@0;08VMZP2;WZX0RYjW08fQZ02@XZT0Sj6Y096SZ`2AY:X0TJBX09>WZP2FZJh00P2DYjd02`2EZJh0
VJb_09Z[[P2LZjh0WZ^^09j][`2Q[[00Y;6b0:Nb/P2U/;40YK6b0080Z;Jd00`0ZKFb0:^g]02/][L0
[;Nh0:fh^@2_^kP0/;^g0;6m]P2a_;L0/[^f0;6j]@2c_[L20;>o]`0;0;Bn]@2c_k<0]L6c0;K1/02h
`Jh0^L6]0;g5/@2k`[80^l:d0;_3]P2k`[D00P2m`kH02`2naK@0_LJa0;c6[@2nbZ`0]l>T07f1K`1N
FUD0/KbQ09RNS03DfLh0j>_U06D0oooo6_oooom60?ooo`0?0;o4^P2HWXl0FEa<05ULC013@c@0@T@b
03/n:`0l?bX0=cXS03Hi8P0e=bH0?3/]03hl<00h=bd0;BdU00809RHO0P0O7aT02P0S91h0:2TR02/^
:00^<BX0:blZ020S8`0K7A/04A8@00lB3P0>4@d2018E3`0;01HJ4`0U:Qd0:2lO02X`7`0]<R009RXI
024R5@0N7QP06aTI01lO800K6ah00P0k@cd02`0h?SX0?dQ004E?A@19DTH0@4<l069XG02JZi80R9N3
09:SR`29VH80T:690080SZ6900`0S9n908fQR`2<X8X0QY^508FHP020TgT0O8mf07Z=L`1oTgP0Nhig
07Z=M@1`PV`206emJP0;06alJ`1cQG80MhQf07Z<N01kSWP0O8eg07^=MP1nSgH0OHad07N3L@1aOFd0
0P1]NVX02@1ULV<0FfMK04]FB`0W;BT07R<M01LJ500;30L01`P300@50P0200830@<00@<100D010@1
01HH2@0Q9A8092TE02DZ6@0?ooooo`003Oooool01P1aQ8D0PYFK08FIX`26VZH0Q9NU08FIY@80QIRU
00/0QYZU08RMYP2;X:P0SJ6W08bOY`2<WZT0SZ:[08nUZ`2;X:H0SJ>V096VZ@0209FY[P0;09JZ/@2G
ZK<0UjVb09^[/P2LZk00VjZ_09j]/@2M[K00Wjfa0:2]/P2S/;<00P2V/k@0302V];@0Z;Fg0:Nc]`2X
/[H0ZkFh0:bf^P2/]KP0[[Rg0:be]02_][D0/;Re0;6l^@80/;bh00/0/knh0;:m]@2c_[D0]Kjb0;Jo
/`2g_k80^/2a0;[0]02l`[P0^/:i0;W1]`020;W2]00;0;W3]02ka;80^/B/0;S3Z@2h`ZX0]KjY0:nd
X`2d^ZL0][f[0;FoZP2b_JH00P34c;X00`2`/:h0oooo0?ooo`1P0?oooa[oooooB03oool20>7SgP0;
0:2OWP1OHEH0KgMQ071iH01KHD`0DEI304M;?015AcX0@d<g03Ld;00a;bL00P0[:R40300V9Ah0820I
020P6@0T9A`09bLP02/]9@0/;bP08bDR01hN7@0G5aL051@D018E4`804QHC00/05a`G01`R6P0S:al0
:2lP02Ta7`0Q9QH07R0D01`J5P0J61L061HI020P9@0203i4A00;06MgJ`1TMfT0IGQX06UjI@1MJEP0
ADM20<3I]01gQWH0MhQh05]WG@1OJUh00P1lSgT03025Uh00RIb408bQRP28WHL0S:>905ESE`1UMV80
PYEh07R;L01hRW@0O95k082FP080P9N000/0OiIm07N;M01gR7D0MHAe07J3MP1cPWH0M8Ae07F6L`1h
QW<0MhAc07R5LP0207N5L`0707N5M01gQW<0Nhig03Y1?@0C5AP03@h=00820P0400420@800@<100H0
0`H100/=0`0@4`D061`;02@Y5@0W:aP?ooooo`003Oooool01P1iRH`0PI>M082CX@20Tj80PIFR08FH
X`80QIVR00/0Q9RQ08NKY029WJD0Rj2X08ZOZ02;WjT0RinW08ZPZ02;X:P0S9nV092RZ@0209FW[P0;
09BU/02EY[80UjJb09RU[`2JZK40W:^b09bZ/@2LZ[80WJ^c0:2^]02S[[<00P2T[[<0302T[k@0ZkBh
0:Zc]`2Y/[L0Z[>i0:bc^`2/];T0[KNh0:ff]P2_][@0[kJc0;:j]P80/[^g00/0/kbf0;>m]P2d_k@0
/kjb0;:m/02d_[00]Kj`0;Jo/P2i`[H0^<:f0;O4]P020;G2]@0;0;G2/P2f`jl0]l>^0;W4[P2j`jd0
_<>^0;[1Z`2k`Jd0^L2/0;_3[@2ma:/00P2j`jT0102//Id0ZJfJ0<76]@3]knQO0?oooa[oooooC03o
ool02@3WjN@0`<Nc09jVS`2:TG`0MgaY05MGC01BD4D0AT8g03Tf;00203<c:@0<02X[8P0V9al0:2PN
02X/8@0Z;2<0:2XQ028S7P0N7a/06QTI01XI6P0D5AL05aXI0P0M8Q`02`0S:R009B`Q02/a9@0/<RH0
;SHX02/a800U:A/092DN020Q700N7A`06QTM0080DEiD00/0YlNR07J=L`1EIU<0EF=>0417>`16C480
R9^10763L01eRgD0H75P05]ZF00207:4K00<07nCNP23V7l0QY^408RLQP2=Y8X0@4M304aDC02T_IT0
?D0l05aWGP2H[iH0L89c0P1/P7402`1cRGL0NHaj07F5MP1bP7@0M85h079nN@1dPWX0M8=g07B4M01d
PW40M89_0080KgaX00/0Kg]W06ikI@1/NV@0<cHb00l<4@070`H01@<400<20P020P<00@4200420@02
00840@0600T;0`0J70l07R4B028W5`0S:QL092XG3oooool000gooooo00H0NhZ@086DWP24V:@0PiRS
08:FXP23UZ4208BGXP0708JIY026VJH0QiZV08^MZ`2:W:T0RijX08jQZ@0208bPZ00?08jQZ@2@XjX0
TjB/09>T[02DYjd0UJB^09JT/@2JZ;@0VZNe09bZ]P2OZk@0Wjbe0:2/]`2S/;T0Y:ng0080Y[:f00`0
Y[6d0:Rb/`2X/K<0Z;6d0:bf]`2^]kT0/;Vi0;2i^02`^KL0/;Rc0;6i/`2d_KD20;Bm]0040;Fm]@2d
_K<0];fb0;>m[`80];n_00D0];j^0;Fn/02f_k00];j`0;K1/P020;S4]00;0;S3/`2jaK<0^LBc0;[3
/P2i`jd0^/>/0;g6[02oaZd0_lJ/0;k5[02naJT00P2naZT01`2oajT0_<>X0;_2YP2k`jD0^/>S0=gS
dP3^l>L0G03ooolJooooodl0oooo00H0fn3?0<35[@2AUG/0Q8Qb05EDB016AcH203m2;`0<03Lm:`0`
=2H0<34T02l^8@0/;B00:2TN028R6`0O81X071hH01XK600I6aP07AlL0P0S9R402`0]<RL0;S<W030f
:@0`=2X0<3@X030e:00^<RH0;C4V02LY800K71D06AXC00805QPA00/0?TTf05EUBP0h?bl0>Cl_02hc
:00/<BL0:c0X02DZ8`1bRFX0I7ML06AeG00206ioI`0<07F6K`1gRW<0NHeh07b@O@20UX40Jg]/07:2
KP2EZh`0?40o04YAC`2P^Yl0Rj2:0P1XMfX02`24V880MhIf04A6AP1GGEX0NXAm075lN01/NG<0Kgic
0761L@1bP6l0MHE^0080Kh1X00/0KGaU06A`F`1>F4P0;c@]01<B4`0>30d02`P:00L41P071@D00`82
00<40P0200T;1`06010C3@0R9QT0:2hM02T`800Z<R40:S<Q3oooool000gooooo00H0MXN<082DVP23
Uih0Q9ZP08>GX026VJ@208FGX`0;08FGYP26VJH0RI^W08VHY@2<W:X0S9fZ08jOZ02?XZT0TJBZ08nQ
Z@2@XJX00P2@XJh02`2DY;00V:J`09NT/@2HYK<0VjNe09bZ]P2LZk@0W:Zc09j]]P2P[kL0X:fd0080
XJnb00`0Y;6b0:Na/@2Y/[40ZkBd0:bf]P2/];H0[KNg0:ff]P2^^KH0[[Vd0:nk/P2`_;420;:n/@0;
0;>m/`2b_;80/[fc0;>n/`2b_;40^<:d0;S2/`2h`K<0^L:c0;W3/02ia;400P2ja;802`2laK@0^l>d
0;c6]`2ka;H0_<Fd0;S2[P2j`jd0_LF/0;o7Z`2ob:X0`<NX0080`LRW00T0_/FV0;o7Z02oajH0`<RU
0;k8X`2kaZ40^/JN0;K1VP3Lhlh0FP3ooolJoooooe80oooo00<0eM_809BNN`1AD3X00P1GFD00301?
DC`0BD/j04I6=`10?c80>CL]030^9@0W9ah08bDL024S6P0N8AT07R0H028S6`80:2`Q00/0<CDX03Li
:`0i>bh0=SP/03Lh;@0c=2X0;c0V02`]900_<RT09bTQ01hP6@0201/M5`0;01LH500G6A<07AhG01`L
5P0K71L082<M028V7`0J7QT0>dHf05a/D01UMET00P26WGP0301[OF80EF9>04I@A@1FHe/0HgE[0767
M`1bQgD0N8ii06YmL01YO700NY5m09B^TP80RJ2500/0RIb406I_H`0X8bh0;Rdh096VTP1CG5`0@DE:
06=aI`1eRG@0Ef=F051IC002065_F@0;06MgH01TM5d0C5Y802L]9`0I71X04A0@00X82P081PP01`D5
00D40`030P800P0M8aL01P0Y<240:c8Q02`c8@0[<B<0:2`Q02L/80oooooo000=ooooo`060721R01n
TYP0PiJN08FGW`24UYh0QIRP0P26Uj402`27V:80QYRR08JGX028VJ80S9bU08bKY`2=W:X0Sin[08nO
Z02@XJX0U::/00<0UJ>^00X0UZ>^09^W/@2KYk<0VZJb09ZW/`2LZK<0W:Zb09^Y/P2LZK<0WZbc0P2R
[k@0302T/;<0Y[2a0:Rb/02[/k80[;Jf0:be^02/]KL0[;Fh0:ff]`2]^;D0/;^d0;2k/`80/;^b00/0
];fc0;Bm]02d_;D0][fe0;Ro]@2i_[@0^l6e0;_0]P2i_kD0^/:d0;S0[`020;[2[`0;0;g3/`2ma;D0
^/6d0;k5]P2na[<0_LJ`0;c6[P2nbJd0_/V[0;g7YP2ob:@00P31b:D02`2naJD0`LNX0;o6YP30aJD0
`LNU0;k8X`2laZ80^lJQ0;c7X02lb9l0`<N]0080d=;3EP3ooolJoooooe@0oooo00l0gn3I0;Zi[P2j
^Jh0T9=h09BLN`1oQ6P0GEa;04A0>00l>c80;RlU02X^8@0X;1l09bXO02PY7@0Y:1h00P0[;2@02`0e
=b`0?T4b0454=P0m@3D0=cXb030c:`0/;RP0:2XU02@V8P0V:R808RHM00807b<I00/06AdD01hP600J
6a@05QH@01/L500O8AP08RDM01lR7@0H71L092XQ02/c:00204=A?00<04AB>`14DC/0<3DX02dc9P0]
<RX0AeA605MXE01TMf00Df=A04YHC01aQg00LhUc0P1hSWL02`1lTG`0Lh9c02h]=P0d>Ch0MH]i07bC
OP12C4L0JWYX07:4KP0oASd05Q<F0080<C@^00/0KWmW04iJBP0e?SH0<3T`01`P700H71P03@l=00L9
1`072@D01@P200H80`0202Xe8@06041@=@0oC3@0<S`Y02`e900X;R009RTO3oooool000gooooo00H0
LhB<082BVP23Uj00QINQ08BFX024UZ<208>FXP0;08NKY027Vj80Qi^Q08bNY@2=WjL0SYjY08jLZ02@
Wjd0Tj>_09FR[P2FY:l00P2GY:l02`2FY:h0VJJ^09ZX[P2JZ;40W:Ze09^Y]@2MZK@0WJ^e0:2^]`2N
[K@0WJ^a0080XJna00`0X[:`0:Fc/02Z][80ZK>`0:fe/`2[/k@0[KJh0:jg^`2^^K/0[kZk0;2k^P2`
^kL20;:n^00;0;Bn]P2d_;<0];bc0;Jo^02j`k/0^[ng0;g3^@2j_kL0^[nd0;W0/`2j`k<00P2j`[40
2`2oa[@0_lFd0;k3]031akD0`LRb0;o7[P30b;00_lR_0;k8Z`2najP0`<ZW0080`L^W00/0_LNU0;o8
Z02najL0_/JW0<39Z@30bJH0_LNR0<7<Y@31bjD0_lVT0;k7XP020;g7XP030;W3X03>eK`0ko;Y05<0
oooo6_oooomH0?ooo`090>obj@38dKP0Vj:604Do>`1?CdD0@T@j03e0<`0j?bl0>d0_0080?3h`0P0i
>Rl02`0l@3<0BDln04eD@P0m@SP0>Shg03Ll=@0^<Rd0:Rd[02P[:00Z;RP0:BdU00809BTQ00/08RLM
02@W7P0O8AX061PB024T600T:1`09bXP028T700N8A/06QdH01PK5P02024W7@0<02L[800X:R009RTO
02@W700R9QX09BTM02T`8`1YOeh0C5Y203Dk;00Z;RH0D5]:0P1CGU402`1LJEl0MHMh07V?OP1IJF40
GW5R06UlJ@1]PFX0L89/06ioK@1AFU@0;2db0080CeI>00/0Ef1E05QSE`11BD406alO01`Q7@0E6Q<0
3Q4<00X<20072@D02@`700hB2P0201<I3@06041@=@19Fd00?4Pf03E0<`0[<bP08RTP3oooool000go
oooo00H0NXn>08JKW029WZ<0R9VT08FDX`26UZL208FFY`0;08JHY`27VjP0Qi^T08RKY02=WZP0SIj[
08jPZ`2=XJd0Sj:]092Q[@2CXjl00P2DY:d02`2CY:`0UjN^09VW[`2JYk00VjVc09n[]02NZ[80Wj^c
09n]/`2P[[@0XJna0080XK2a00/0Xk:d0:>c/P2U/k00Y[6_0:Zd/02^]k@0[kNf0:jg]`2_^;L0[kVg
0:jg]@030;2k]`0;0;2l]`2`^kH0/[^f0;Fm^02h`;/0][bh0;No^P2k`K/0^l:h0;W2]P2i`K@00P2j
`k<02`2ka;<0_/Fe0<37]`2la;80_LB`0<79/P30ak00_lN_0;_5Z`2kaJX0_lRZ0080_/VY00/0_<NX
0;g6Z02maJL0_/NX0<7:Z@31bjP0`L^V0<;<Z031bjH0`<ZV0;k7X`020<39Y@060;o8Y`2najL0_LJV
0;[5Y03Gg<`0i^SQD03ooolJoooooe/0oooo00P0cM3209VJS@2<Tg`0N7eX06U_FP1UJED0Gf9@05YM
C@80CU5400/0Addo04I8?014AcX0@4<h03`m=P0h>CH0=SPe03Dh=00f>3H0<C@b02hb;@0202lc;@0;
02db:`0[<2T08RDN01/K5`0L71P0828J02<V6`0P8Q/071hH01HH4`0Q8a`00P0`=BX0300^<RL0:BdS
020P6P0N7QL071hE01hT600L8AD0:2lN038k9`0e?BP0<3HS02P]7P808bDL00/08R@P030d;`1RLUl0
AU5803i8@@18DTP0GFaJ06IhIP1YO6d0JWa]06=aI@0206YhJP0;05ELEP16CDX0Cea?01/P7P0H7AX0
3Q8=00/>1`092`@02PX6018C3`0A4Pl00P0>3`l01P0D5aH061dI01lU7P0g@S@0<cda02P_9`oooooo
000=ooooo`0607f@TP24UYh0QiVS08NFY027TjL0RIJ/0P29VJh02`27VZ`0RIfY08RMY029W:<0RYjT
08ZNY`2<WjP0SJ6Y08jQZP2AXZ`0TJ:^0080TZ>]00/0TZB/09JX[`2GYZh0VZN_09ZW/@2IY[00WJZb
09j[/@2P[;80XJba09nZ[`020:6_/@0<0:Bb]02U/[@0Y;:d0:F`/P2X/[80ZkBe0:bd]P2]][H0[[Rf
0:bf]@2[]K@0[[Rf0P2a_;X02`2`^kT0/;^h0;6j]`2c_KX0/kbi0;Fm^@2f_[T0^/2i0;_2^@2j_kH0
^[jh0080^l2h00/0^l6h0;_2^02i`KL0^/:f0;_4/`2mak<0_LJa0;k8/@2nb:l0_/J]0;o7[P020;o6
[@0;0;o7[P2oajl0`LV`0<36[@2n`j/0`<JZ0<39ZP31c:P0`L^W0<39Z02nb:L00P2ob:T0202najX0
_lRZ0<38Z@2maJP0^lBW0;JoY02h`JH0g>7CCP3ooolJoooooeh0oooo00D0dMK90:J`TP28SWD0OH9Z
06EXE@0205QKC00;05=EA`1;Bd40B4Pm0492>010@3P0?C`e04eAA01=DdP0B4i40455?00g>S800P0b
=Rh02`0]<BT0;30Y02LZ9@0P8a`071dF024T6P0T:1`08bHK01hQ5`0J6a@09RPQ0080:bhV00`0:blU
02X/8`0W:2408B8L020R6P0K7QD06adC01@D2`0H60h071hB02<U5`0P8QD201TJ400;01HH4@0E5A40
>D4c05=QCP0P92809B`X02D[:`0_>C@0DV9D065cH01TMF800P1SLV<02`1OL680=3hj03U6>`0gA3D0
6R0I014E400B5Pl04Q<<018@300B40h04@h>00803@X<00H030T;00/92`0;2@`05aLG01dN700V:R@?
ooooo`003Oooool01P22TID0QYFP08VHZ027UjX0R9J/08JE[080Pi:Y00/0PiFY08NKZ@29WJP0RYjW
08bOZ@2=X:X0SZ6[08jR[02BXjd0TJ2[09BR[P0209BS/00;09JV/P2EYJh0VZR_09VW[@2KYjd0VJF^
09NT[@2LZK00WZ^a0:6//@2R[[<00P2Q[[40302S/K<0Xk2`0:B`/P2V[k80Yjnb0:Vb]02Z];@0Z[>c
0:jh]P2`^[/0[kRj0:jg^080[KNg00L0[[Vi0;6j^`2c_;`0]Kbl0;Fl_@2g_;d0^;fl0080^knm00/0
_<2l0;^o^P2l`K/0_<6k0;[0^P2la;`0_<Bj0;_4]`2i`k80^lFc0;c5/P020;g7/`080<38]P31b;D0
`<Jd0<36]02oa[@0_/Fb0<77/P33b;820<?7/0050<77[033bZd0`LNY0<;:[032bZh00P31bJl02`30
b:d0`<R/0;o6ZP31bJ`0`<N/0;g5ZP2k`ZP0^lBX0;S3YP38d;T0emg?04/0oooo6_oooomP0?ooo`03
0>[]i03>e<D0UJ230080LgMQ00/0Kg=M06=SEP1GEDh0CTe704Y:A012@S/0FVAA06QhG`1YNUh0I79F
03<e:00202`/8`0;02LV7`0R8Qd08b<Q02<S8@0R8b409RPS02HY8P0R9b807R8O020S8@0g?cH00P0h
?cD0300_<bX0;2hU02LY800X:1l0:RdS02DW7P0K71@05AD;014@1P0J6`d0820@01XI30804Q0800/0
3Pd800d<200J71D0EFA<02T`9`0X<2X07bDS01XP7P0G6aX0;3LZ03I1;P0202dc900;03Hn;P10C3X0
D61;04MD?`0=3PT05QPB01/N5`0H6aD06a`G01LF500A3Q400P0;1Pd01P0<1`h02`D;00d63@0=2140
3PXB01/L7@oooooo000=ooooo`0607j?U@24UJ40QYRW08BEZP23UJ`0Q9F[0P23UZX02`25V:T0QYbZ
08JLZ028VjP0RifZ08jO[02BXjl0TJ2]09:P[@2DXJd0UjBa0080VJBc00/0V:Fc09RV/`2HZ;00VZR_
09ZX[P2N[;40W:R`09^X[`2MZ[00X:fb0:2^/P0209n//P0<0:2]/`2S/;D0Y;2e0:Na]P2X/[D0Z[>g
0:^e]`2Z][D0[KRf0:fg]`2`^;X0/K^n0P2`^[`02`2_^[L0/Kbh0;Fl^`2g_K`0]k^k0;Zn_P2k_l40
_L730;c0``2l`<40_<300080_<2o00L0^[nl0;_2_@2j`[/0_LJj0;o8^@2naKH0_/Fe0080`<Jg00l0
_lFf0<36]`31b;P0`LRh0<79^@2ob;P0`<Rg0<78]P33b;@0aLVd0<?8/@35bZl0`/R]0<;9[`33bK40
0P33bk403033bk80`LR_0<79[@31bZd0`LV^0<79/030bJl0_/N/0;k9[@2laj/0^lNZ0;O3YP80a/ni
00<0k>oX0?ooo`3oool0A@3ooolJooooof<0oooo0P3Zk>D02`2e^jP0WjN>06a[H@1OGeP0F5Q@05=D
BP15ASd0AT/m059LAP15CSd0=3T]0080;S@X00H0:RhU02<T7`0Q8R008b<S02X]:P0[<2`202/`;@03
02<W9`0U:BX0BeM<0080@Ti400<0=T0g038j<00a=b`00P0_=2X01`0T9R006QXG014?3@0B4PT06AX>
01hO4@0M7a800P0F5`d02`0A40/030/900/:2@0G61<06A`H01PK600D61L04aPF01@J5`0L8a`072<G
00806R4B00/06Ah?01HJ3P0U:AX0:BdN01hP5P0T:1`08RHM024T6`0f?2d0:blT02HX8@02020O7@06
020L700L5aP0618E01<<4`0@2Q@04`lG3oooool000gooooo00H0NXfD08:EX@27VjT0QYRY08>DZ`22
TjX208BFZP0:08JHZ`26VJ`0R9^]08ZM[`2=WJl0SZ2`096R[`2BXJh0UJ6_09BO[`<0UZ:a00/0UZ>a
09VW/P2HYZl0VJN_09^X[`2N[;40W:Z`0:2]/P2NZ[40XZfd0:>_]P020:Ja]`0<0:>_]`2T[k/0YK2m
0:Fa^P2T[kL0Y[:h0:Nc^02Y][T0ZkRj0:bg^02_^KX0[KJj0P2`^Kh02`2`^K`0/K^l0;Bk_@2f^kh0
][Zm0;Nl_P2h_/40^ko20;g2`P2k`L00^l;00080^/6n00/0^/6l0;g3_02l`[T0_lJi0<;:^P2maKD0
_/Bc0;k5/`2ma;80_/Jd0;k4]P020<37^00;0<38^@31bKT0`LVf0;k6/`31ak<0aLRb0<G9[`34aj`0
a<R/0<G9/034b;400P35bK<03034bK80`lV`0<;9[P33bJd0a<V^0<?8[P33bJl0_/F^0;g4[@2oajh0
_/J/0;g6ZP80^lFZ00@0^/BX0;W3YP3KhM80k>oXA03ooolJooooofL0oooo00T0eM[>0::UVP1WIel0
IfUN059BBP1=CTH0B4To03m2>00h?C<00P0_<Rd02`0Y:bL09bTV028T8`0W:bP0;C8/034g;`0_=2`0
;S8Z02d^:P0];B`0=3Ld0080=3Te00`0<cTa038i<00a>Bh0<c``02lg;P0U:bD08R@R01`L6P0I6QH0
71lG01lT600K7a@201LL4@0;010C300A5@/03a4801<D3@0G6Q806AdH01DI5P0A5A404QH@01LM500G
71000P0E6Ph201HI3P0901<E300I6a<06AdE01`Q6@0I7AP06QdH02D[7`0d>bP0=3/U0080:B`I00H0
=3DQ03/j:@0_:b40;2TR02LU8P0N7A`?ooooo`003Oooool01P1jSI@0PYFQ08NKZ@26V:T0PiB[08:C
ZP80Q9JZ00X0QYR[08JI[028Vjd0RYf_08fM[`2>X;00TJ:_09:Q[P2EXJl0U9n_0`2FX[402`2FXk40
VJNb09RV[`2IYjl0VjR_09j//@2LZ[00X:fb09jZ/@2R[K@0Xjnf0080Y[6g00`0Xjng0:B_^`2U/;d0
YK6j0:B_]`2V/[P0Yk>h0:Vf^@2[^;X0[;Nh0:ni^P2]][X20;2i_P0;0;2i_02a^k`0];^m0;Jk_P2f
^[d0]kbn0;Rn`@2k_l80_L;20;_1`02k`/000P2j`Kh02`2j`K`0_L>l0;c2^@2oa[T0`/Zj0;g5]@2n
a;<0_/Fc0;g4/P2na[@0_/Bf0080`<Nh00/0`<Ri0<79^@31bKH0_/Jc0<77/`35b;80aLV_0<C7[034
b:`0aLV`0<C8/@020<G9/`0<0<C9/P33bK00`/V^0<?9[@34bJh0`lR^0<?9[`2naJh0_LB]0;o7[P2n
aZ`0_LJZ0P2kaJX0102ja:P0^L>V0=_QdP3/knQ40?oooa[oooooI`3oool02@3Ef/h0XZFJ06MWG`1W
JEh0DU9:04e>AP18BCl0?d8h03Pm<`0202lb;@0;02T[9`0W:BH08R@S02L[:00]<R`0<CL_02ld;00^
<RX0;BhZ02d];00d=c@00P0d>CD0300c>C40<ST`034i;P0c?300;cL^02D[9@0R928071`J01TJ5P0L
7aL07b@H01/O50805a`A00/041<<014E2`0?4@P04a@=01LJ4P0I7AP05ATF014E4@0B5Q005adD01LL
400201DJ3P805QT>00T04aD<01TK4`0I7AD0724I01TM600J7AP09B/O03@k:00d>bD00P0Y;1T01P0d
=B40>cXY02l[8@0/:B809bDR01hM70oooooo000=ooooo`0607f>T@21Ti/0QIRS08JGY`23U:H0R9RZ
0P28UjX02`29VJh0QIJ^08JG[P28VK00RYbb08bN[`2AXk00TZ>_09:P[P2DXK00U::b0080U:>a00/0
UJBb09NU/`2KZ;D0WJVf09f[]`2KZ;D0W:Zd0:2//P2Q[;80XZfc0:>^]0020:>^]P0<0:>]]`2R[;T0
Y:jm0:B__@2U/;`0Y[6l0:Re_@2W];`0ZKBm0:be_@2]]Kd0[[Jn0P2]]Kh02`2`^<40/KS00;>i_P2e
_;l0]Kc00;Ro`P2f_/80^<310;Bl_@2f`;l0^/?10080^L:o00/0^<2m0;g4_P2i_kT0^knh0;k4^02n
aKL0_lRh0<78]P2oaK@0`<Nf0;k4]P020;o6]`0;0<38^031b;X0`LRj0<;9]P34bK80a<V`0<G:[`35
bJd0a/^^0<?7[@35b;400P36b[D03035bKD0a/Vd0<G9/@34b:l0aLV_0<K9/@36b[<0`lRc0<;8]030
a[40`<R`0;o6[@80_/BY00H0_/NY0;k7Y`2jaZH0]/>V0:RbVP3GgM120?oooa[oooooJP3oool01P3<
dLD0PhYg06Y]H01QHeL0D55704U:@080>CTd00/0=3<`030^;P0Z:b/0:BTZ02X]:`0_<bl0<3@^02lc
;00a=2/0<S@[02/[9@0202TY900<02DX8P0W:R<0;C4W034h;00/<BP0:c0X02T^:00S9R809b`T02`d
:00S:b40728I0P0E6A802`0A50h03A0;00`?2P0D61805Q/D01XO6@0F6aD04QHA014F3`0F71805AT?
00804QH<00/041<;00hB2P0>4PX03A08010C2`0E5Q004a@?01`P600R9a/0:2hM02``6P0201dM2@06
03Hg7`0Q6a80=C8[02TU900_<b/0<SX_3oooool000gooooo00H0NXb?08:CV`23UJ40QIJV08FFY@27
UZH208VIY`0;08NGZ025UZX0QYV[08VL[P2:WJl0Rin]08bO[@2=X:d0Sj6^092P[P2AX;800P2AX;40
2`2AXK40V:Jd09ZW]@2IYKD0VZFf09ZU^02MZ[P0WZbf0:2/]@2Q[K@0X:ff0080X:jf00H0XZne0:>_
^02V/Kd0Y[2m0:Fa_P2U/Kl20:Jb_`040:Zc`02/]Kl0[kO00:ng`080/[W200/0/;O20;:j``2`^L00
/kg10;Fo`P2f_/80]Ko10;Jo`02h`Kl0][jl0;Bl^P020;Jn_00;0;Fn^`2h`Kd0^L6k0;_2^@2na;T0
_/>i0<36_@31a[h0_/>j0;o3^@2na;X00P2n`kT02`31ak/0`<Jj0<35^P33bKT0al^i0<C:/`32b;00
aLb_0<G:[036bZh0aLVa00<0aLRb00/0`/Jb0<K:]033ak80`lJb0<;6/@34ak40`lFb0<G9]P32a[<0
`/J`0<75[P020<36[0090;o6Z@30b:T0_LFY0;_4ZP2i`jT0]L2W0;>oZ035c[d0c=7803l0oooo6_oo
oom/0?ooo`040>[^i`2m_kT0OhIi06Y]I080BTM600/0BTQ503/g>00e<C80<bl_034];@0_:bd0<2h^
02d[:P0/:bL0;c0Z02`]9P0202LX8P0<02DV800R9Al08bHO028U7P0T9R0092XS02P_9P0U;2@09c0V
03Q5<@0U;Ql06b8G0P0C5a802`0A4Pl0418=010C3@0D5a006QhF01/O600J81H061hB01TP500M91H0
6AlB008061dA00/04AH>00lC3P0?5@l03A8;00P;100;3@H02``600d=1@0?3`L05AD;01dN4P0201XH
3`0604aC>`0A3@/0Ig5M05eZE@0@4Q007R@L3oooool000gooooo00H0N8ZB08>GX026VJL0Q9NW08FG
Z025UjH208JFYP0;08JHZ024UZX0QiZ/08RMZ`29WJ/0RIj/08ZN[02:W:X0RijZ08fN[02@X;400P2A
X;<02@2CX[H0UZ>f09RV]P2KZ;L0VJFe09^W]`2LZKL0W:^f09f[]P0209j]]`80X:jh00`0XZjh0:Jb
^P2W/[/0Y[6k0:F`^P2V/Kd0YK:m0:Nc_@2Y/kh0Z[:n0:ff`02^]kl20:jg_P090:jf_P2_^L00[[Rn
0:nh_`2`^L00/K[00;>k`02d^[h0]Kbo0080][jo0P2f_[h02`2f_Kd0^<2k0;W1^`2k`KX0^kni0;^o
^P2n`kd0_lBn0<36_P31b;h0`<Nn0080_/>m00/0_L>k0<36_02oaKT0_lFf0;g2/@30a[80`<Nb0<38
/033bJl0`lN_0<C7/@020<75/@0<0<?7/`31ak<0`/Vd0<?8/`31ak<0`/Jb0<C9]031a[<0a<Vf0<?6
]031a;40`/Fa0P30aK402`2naJd0_/F/0;g4ZP2najh0_<N]0;K1Z02e`:T0][nY0;FoZ02c_jH0_lNg
0080j^cW>`3ooolJooooofl0oooo00h0in[T09fPUP2MX9H0Nh5_05MHBP1BDT<0BdTk04@o=@0o>C<0
?cXc02hY:00^:RL0;BPU02/W90809R<P00`09RDQ02P/900U:b8082HL01lV700S:Ql08BTO028[7P0T
;Qd08blM02@^7@0N9AH201PO4P0;01LL400E6@h05AP>01TL4@0H71006alD01`Q5P0I7a@06b4H01dT
6@0M8aP00P0L8aP02`0B6a403A<=00lE3`0<4P`02Ph600T<10092PD020P400X81`091`D02PX50080
2@/300H03A0401HJ2`0K80l08bTE024W500I70h?ooooo`003Oooool0101oTiT0PiJP08JJYP25V:P2
08NJZ`80PiFX00/0QIV[08JJZP26VZT0QYVW08NKZ02:Wj`0S:2]08jR[`2?XZl0TJ>a096Q/P0209>Q
]@0;09FQ]`2EX[H0UZ>e09RU]@2LZ;X0VZNh09^Z]`2L[;H0WZff0::_]`2R[[H00P2S[kT0102T[kX0
YJnk0:Rc^`2Y];/20:Rd^`060:Rd_02W/[`0[;Fo0:bd_P2]][l0[;K30P2/]/802`2]]kl0[KNn0:ni
`02a^L80/[W00;6h_`2d^l00]K_00;Jl`@2f_/80];k10080];k000/0][g00;[2`P2j`<00^kno0;c1
_`2l`Kd0_L>m0;c3_02k`k`0^lBl0;W1_0020;k4`00;0;k4_P2m`kd0_<:l0;o4_02oaKP0_/Be0;g3
]@30a[H0`<Ja0<;:/`31b;400P30ak403032b;<0`lNc0<;7/`34bK@0a/Zf0<G9]P31a[@0`/Jd0<C8
]@34akH0`/Jd0<76]080_lFb00H0`LN`0;o6/02oaZl0_/J^0;k7[P2maZd30;_2Z`070;[2[02e_JT0
]KjZ0;FnZP2a_J@0e=W>0>KWh`0h0?oooa[oooooL`3oool02P34b;`0V9Z=06Y[G01GEDT0DTm204]8
?@14@SL0>cT_03<b:P0Z:2<202@R7P0<02<S7`0Q8b008RLQ024X7P0M91T06AlE01TO500Q:A/06R4B
01`R4@0O9a@07bDE0P0O91H02`0N8aL0728G01XP5`0I7QD05QTA01TL500K7aD07B<G01lV6@0N9QT0
72HH00806RDH00/0628E01DO400A6Pd03aD:00dC1`0<40D03A0700`=1@0;2PD020P400L9100200L:
0`0600L:0@0<3`804A@601PK2P0B4`D03@d33oooool000gooooo00H0NXbG08>FX@25VJP0QIR]08JH
[@26VZh208JJ[@0;08RM[025VZP0RIf[08VM[@29WJ/0Rj2/08jS[@2@Y;00Sj>_092S/@2CXk@00P2D
Y;L02`2DY;P0U:Bf09NW]P2GYkD0VZVh09b[^@2M[;L0Wjjh09n^]`2S/;P0Y[>j0080Y[2k00`0Y:jj
0:Na_02Y];d0ZKBk0:Zf_@2[]/00ZkO00:Zg_`2[^L00[;W00:fk`P2Z][l20:fia00;0:nja02^^/80
[kS00;:j``2c^L40];W00;Fk`P2f_<80^L350;Nma@2g_/D00P2i`/L02`2i`L@0_<C40;W2`02h`<00
^<2n0;[2_@2ka;d0^lBl0;_4^P2k`k`0_LBm0080_lO000/0`<G20<76`P31a/80`lS50;o4_`31akd0
`lZn0<;9_P31b;T0`lbj0<?;]P020<C<]@0<0<G=]P34c;D0`lZe0<;:]P32b;L0`lVj0<78^@32bKT0
`/Rh0<;9^@2oaKL0`LJg0P30a[H02033b;D0`lVe0<;8]@31b;H0`<Jc0<;8/P32b;40`LNa0P2oaZl0
202na:h0_LFa0;g5/@2k`k00]kn]0;BlZP2Z/il0dmW?=P3ooolJooooogH0oooo00L0_;jf06a]H01K
GDh0DEA404Y;?P0n?cL0=cLb0080=CD_00`0<S4/02`/:P0V:2L08bHU01lS8@0L8Ad06AhH01dS6P0J
81L06R0D020V6@0S:Qd2028X708082LM00T08RTO01lV6`0L8aL07bLG028[5`0S;1P09c0J024[5@0R
;1D00P0O:AD02`0O9aL072<D01`S4`0K8Q005Q`=01PL3@0D5P/04a<901@F300A4P`03@l9008030l8
00H0314700`@1P0<40L04QD:010A2@0<2PD?ooooo`003Oooool01P1hRYH0P9:R08BFZP24UZd0PiF^
08NJ/@80QIV/00/0QYRY08FHY`27VJP0S9j/08bNZ`2<WjX0SZ:[09:T/02AXk00Sin`08nO/P0208nP
/`05096S]02CY;<0UJJb09RX]02HYk800P2KZkH0102L[;D0Wjfe0:6_]`2R[kX20:J`^`0<0::/]`2U
/;T0Z;:k0:Vc^`2Z]K`0Z[Fm0:bf_`2/]/00ZkS10:bi_`2Z]k`0Z[Nm0P2]]kl02`2a^L40/[[30;Bk
a02e^/<0];[30;Fk``2g_<<0]k[20;Rka02f^/<0^;c400<0^/3300X0^l720;_0`02k`L00^l710;_2
`@2laL40_LG00;[2^P2oaK/0_L:i0P30aKd02`2oa;d0_l>m0;o3_`30aL40_lBo0<?7_P31a[`0`<Fj
0<78^P30akH0`LRe0080a<Vd00`0aLVf0<K;^@33b;P0`/Rh0<77^P31ak`0`LVm0<78_031b;X0`lZj
0<77^031akH20<?7/`080<C8/`35bKH0aLRg0<?7^033akL0a<Re0<;6/P31ak820<36/00;0;o4/@2n
a;<0_/Bc0;c2/@2k`K00^;j^0;Jl[P2e_Jd0Z;2P0;Rn/P36bL@0<`3ooolJooooogP0oooo00D0g]oL
0;Nj]01VIf<0Cdi<04Q9A@020494?00<03/l<`0b<B`0:bTY02DS9`0Q82<071dP01hQ8@0L8Ad05aXG
01<E4P0B5Q8051PC0P0F6aD02`0E6a<05a`D01TN5@0I7a@06b8F01PP400G7Pd06R4?01`T400K8`l0
6b8?00806Al=00/06B0>01TP3`0H7P`05ah;01XQ3P0J7`h06A/?01HF3@0E5Pd0418;00h@2`0200/>
300600`?300=4@`0310;00d?300>3P`02`X83oooool000gooooo00H0NH^F086BXP26UZP0QYJ]082A
ZP21TZX2082DYP0;08>FYP26VJD0RI^V08VIY`29VZP0RI^Y08ZMZ`2=WZ`0Sij]09>P/02?WK000P2@
Wk802`2@XK<0TjFd09FW/P2EYK00V:Nd09RW]`2GYkD0Vj^f09n]]`2P[KP0X:^g0080XJ^h00P0XJ^g
0:B_^02V/;T0Z;2j0:Va^P2X/K`0Yk6n0:Na_@80Z[Fo00l0ZkJo0:fh_`2^]kd0[[Nm0;6g_@2a^;`0
/kW10;Bj`P2c^L40];[20;Jk`P2g_L00^;g30;Jk`P2e^l000P2e^kh02`2g_Kl0^<2o0;S0_P2i`;l0
]kjm0;Nn_P2j`L40^[fn0;Zn_02k_k/0_<6k0080_L:k00/0_/>m0<35_`2o`kl0`L>n0<?5_`32aKd0
`L>k0<?6_@31a[/0`LNh0<;7]P020<;6/`0<0<?8]@33bKH0`<Nd0<78^02na;P0_/>j0;k3^@30b;T0
`LNi0;o5]`30akL0_lFe0P2oaK801@33b;80`lJ`0<;4/@32a[80`LJa0080`LF`00@0`<Fb0;c2/02m
`[40^Kj_0P2h_Jh02`2l`K40^/2a0;[0/P2i_[80^;f`0;Jj[02c^:X0/KNZ0:2VV@2d^jl0in[U0300
oooo6_oooomk0?ooo`0:0>3QgP2HW940LGUT075iI00n?3@0?3Tf038/<00W7bP08A/U01lK9080820U
00@07AhR01@E6@0?4AD03a4C0P0=3`h02`0;3@P041@<010E2`0=4`T03QD;00hD1`0B6PT051/801DN
2@0C6PD04QT200805ah500/06R0801HJ1`0C5PD041<3018E1`0C50T04Q@:014B3@0A51003@l=00X<
2`0200L81`0600/=2P0>4@d030h=00`?3@0>40`030/93oooool000gooooo00H0MHZB07jBW@22U:<0
Pi>W08:CZP1oT:T2082DZP0;07nDY`24UjH0Q9NW08NIZ`28VJ`0QiZ[08RLZ`2:VjX0S9bY08jN[@2?
WJh00P2AX;80102>W[40Sj2d09:S]@2BX;<209JT]@0509NU]02JZ;H0WJ^h09n[]`2PZ[P00P2QZ[T0
302RZkT0XZbg0::/]02V[KD0Z:nh0:Va^`2Y/kh0Z[C00:^d`@2/]<@0Z[;10:bd`P80[KC300<0/[S3
0;2g_`2c^L400P2c^L801P2d^/<0];W10;Fj`@2h_LD0^;c60;Jka080];S000/0];W10;Fk`@2f_<40
]Kc00;Fm`02f_;l0]k^n0;Zm`02l`<80^Kbm0;Zm_0020;bo_P0;0;k1_P2o`/40_ko10;no`02o_kl0
`/700<2o_`31`[l0`<:o0;k1_@30aKh00P33akd00`31ak`0`LJl0;k3^@020;k4^@070;k3^02o`kH0
`<Ff0<C6^033aKP0`LFf0;o3]0020;o5/`0;0;o5/P34ak<0`lBc0<73]031aKP0_/:e0;g3]@2k`K@0
^/2d0;k4]@2k`;800P2j_[402`2j_k40^knc0;_1]@2h_;80^;ba0;Jk[`2d^Zh0];^`0;6i/02^]Z/0
ZkBX0080Yk>R00<0d]O@0=OFf03oool0:`3ooolJooooogl0oooo00`0/;2^07=]M019@Th0;bLh02PP
<00R6bT081XT01`G800G51d05a@L01@E6P0@4aD200lC4@0;014E400A5Pl041D>00dC300:40T01`d6
014J3@0G8@d04ad801DM1P0D7@<00P0F7`D02`0H7`L051P501DG1P0B4`H04aD7010?1`0@40X04a<=
01<D3`0@4P`030l:00802`h800H02Ph8014E3`0<3Pd030h=00l@3`0?3``?ooooo`003Oooool01P1h
SY<0O9:K08:FX@22UJ@0P9:U082BZ080P9>Y00/0PiJ[08>FZP25UjX0R9V^08bM/P2;Vk40SIna08^K
[@2=Vjh0Sij`096N/00209:P/@0;09>Q]02EXkH0UJBg09NU]P2EXk@0UJBd09JS]02JYkP0WJZi09n/
^P2PZkX00P2PZ;/0302SZK/0Y:Zi0:F[^@2TZ[H0Z[2k0:bd_`2///40Zk;00:^c`P2]]L<0[KC20:fc
a@80/KK700/0[kG50;6fa02c^<<0];S30;Bga02d^<@0]KW30;Nj``2f^<40^Kg60;Jla@020;Fj``0;
0;Jla@2d^<80]k_30;RnaP2i`<P0][c40;Nm``2g_L40^[o20;c0``2k`<400P2l`;l02`2m_kd0_l2o
0<71`P30`<80`<330<;0`P32`L@0`L330<;1``31`L40_l300080`<?200`0`LC20<35`02m`[d0_/>m
0;k3^@31`kT0`<:g0<73]`33a;L0a<Jh0<?5]P32aKD20<?6]P060<;4]@33aKH0`lFe0<;3]`31`[X0
_L2k0P2m`[/00`2l`KP0^l6f0;_0/`020;c1]00;0;[0/P2j`;00^Kn_0;[0/P2i_[40^;fa0;Fj[`2d
^[00]KZa0;>i/02`]jd00P2^]j`0102^]jl0TYNG096IU@2LVJ8Z0?oooa[oooooPP3oool02@2CSY/0
=S4n03Ha=`0/92P08aXO01hG6`0M6AX06ALH01PI6P0201PI6@0;01HI5`0A51<051PF00h@400;3@d0
2`d<00dA300C6@d051/<01DN3@0A6`T00P0@6@H02`0C6PL05Qh:01DK2P0F70h061X?01HF2`0D50`0
4a<;01<C300D5@`03a8800803Q4800<03Q0700lB2`0A4`h00P0B4a400`0A4Pooooooooooo`0=oooo
o`003Oooool01P1eQi@0P9BP086EX`23UjL0Oi>S082BX`80P96U00/0PiFX08BDZP23U:/0QiJ^08VG
/029V:l0S9Z`08bL/@2<Vk00SYZ`092J/@0209:M/`0;09FQ]02GXkH0UZ6e09NS]P2GY;D0VJNe09ZV
]@2KYkL0VjNf09^U]P2MZ;T00P2MYKT0302RYk/0YJVm0:JY_02WZKh0ZJbo0:^^`02//<80[K730;2f
a02_]/<0[kG30;2faP80/[O700@0/;C40;6e``2a]L80/kO20P2d]l001@2e^<80];O00;Fi`02e^L40
][[10080];W100H0][_20;Vl``2g^L40^Kc30;Zna02j_L<20;Vk`P030;Vl_`2j_[l0_;nn0080_<6l
00/0_<6k0;k2^`2n`[X0_l2k0;jn^`2k^KL0`<2l0<70_P30_kd0_kjm0<30_P020<31`@0<0;o0_`2m
`;h0_L6l0;g1^P2n`kP0_<2d0<32]P32`[H0`L:f0<31]P30`kH0`<Be0P31`k<02`30`[40`<6`0;o0
[P2n_k00_l2c0;fo]@2j_[L0^/6h0;_2^02m`kL0^l6b0080^kna00/0^[n_0;Zo[@2j`:`0^l:^0;_0
[02k`:d0^Kj_0;Rl/02g^jl0]KZ/0;BhZ`020;:g[@070:ng[@2/]ZX0Z[BW096IS@1LG5P0QH=m09B>
T00W0?oooa[oooooQ03oool01`3?cLd0ViJF034W:00Z828091/N01hG6@0L5QP00P0L61P02`0K61P0
61@G01@@500E4QD04a0B00d:300B4a4061`G01TN5@0F71405QhA00805A`>00/05ah=01DL2`0E6`d0
5A/>01DJ3`0D6@d051H=018D3@0A4`h04aH>01@G300200lC1P0600/=0`0<30@03`l800h=200=3@P0
3Ph83oooool000gooooo00H0MHJB07^>WP1nT:<0OY2V07f?Y@1lSZ<207n@Y`0;082BZ022U:X0PiB]
08JG[`28Uk00R9Ja08fL]02<W;80SYfe08nM]@2AW[D00P2BW[H02`2BX;L0UJ:h09JR^02HXkX0UZ:i
09VT^@2JYkP0VZNg09RT]02KYkL0WJRi0080X:Vl00@0XJZn0:B[_`2VZ[l0Z:g20P2VZ/401P2X[<40
ZJk20:Z``P2Z/L80[;C40:jea080[kG500/0/;O70:nga02_]l80[kS20;6j``2b^/80/[W10;:h`@2b
^<00];_10;Bk`0020;>i`@0;0;Fla02g_<<0^;W30;Vj``2j^l@0^K[20;Zl``2h^/00^Kbo0;Zo`02j
`Kl00P2j`K/01@2j_kT0^l6j0;_1^@2m`kT0^l2j0080_L6l00@0_/>o0;c1_02m_k/0_L6m0P2n`/00
302m`l40_L?00;g3_P2j_kT0_<6j0;k4^P30a;X0`<:j0<71^`32a;d0_;ni0;k3^P80_L:g00/0`<Ff
0<74]@2o`[<0_/:d0;g0]P2n`[/0_/Bm0;[0^`2i`KP0^L:h0;Ro]P020;Vn]P0;0;Rk]02g^[40][Z`
0;Rm[`2h_Zl0]k^^0;Nl/@2g_K<0]K^a0;Bj[`2d^Jl00P2c^;402P2b^;40[kJ_0:bdZ`2]]jP0Z;:R
09:IR@0a9B/0>S4b09VEU@3;bLXT0?oooa[oooooQ`3oool0102GTY<0GeQH02DL700T7Ah2020K700;
01dH600J51D0618D01LD5`0F51@040l>00h?2`0C5Pd05a`@01XQ4`0L91@00P0L9A<00`0L8a405ah>
01HK3`0201DK3`0601@I3P0A5@d03Q4:010D3P0B5Q004AH;0P0@50T01P0?4`L0414600h@100>3P<0
4Q@8010D20oooooo000=ooooo`0607Z;V020TZ<0P9>Y082BZP1nSjT0O8fV0P21U:T02`21TjP0PYBX
08:CZP26UJd0QYB]08ZH[`2;V[00R9N]08bJ/@2?W;<0TIne00<0T9ne00P0T:2f09>R^02DXKT0U:6h
09BR^02FXKP0UjBg09RU]P80VjNh0P2JYKT0302LY[X0XJZm0::Z_02UZkd0YZc00:J/`P2W[<40YZ_0
0:R_`P2X/<80ZK720:^ca080[[G600/0[;?40:bda02/]<40[kW50;:kaP2b^l@0/KVo0;>j_`2d^/00
];_00;>j`0020;6j`00;0;:i_`2c^/<0];[30;Jka02g_<@0][_30;Rk``2i_L@0][c20;Bk_P2h`<00
0P2g_[`02`2f_K/0][fj0;Nn^`2g_k`0]kjl0;Vm_02j_kd0^[nn0;_1_P2k_kd0^l2m0080^l3000`0
_<;30;[1`P2j`kl0^<6l0;W0^`2j`;X0^l2k0;^n^`2o`;l0_Kk00;bo`P2k_l020;^o_@0;0;^o^P2j
_[P0^[jh0;^o^02k_k`0^l2l0;_2_P2k`[l0^l:n0;S1^P2h_[T00`2i_KP02P2i_[P0^;jg0;Nn]02g
_[@0]Kbb0;Bl/P2e_[H0];be0;:i/`2b^K820:je/@0<0:be/02[]:l0ZK>/0:RbZP2W/JP0ZKBW075b
K`1=BD/0>30c03D];P0a:2`0Ui>F0P39alTP0?oooa[oooooRP3oool03P2ETI<0FeEL05]EG00O6B80
8QdU02<O9P0K6B405ADJ010B4@0<3P`03Q4=018F3`0G7A@06R4F0P0N91L02`0L8AD05a`B01LL4`0E
6a@041D@00lB3@0@50h04AD?01@H4@0A5Pl03Q<:00803Q8900H03Q4900lB2P0?4`T04A@900h?1@08
2@8?ooooo`003Oooool01P1hR9T0OHjS07f>Z01oT:`0OXj[07b<Z`80OY2Y00/0PI>[082AZ@23TZT0
QiJ]08bJ/@2:V;00S9^a08bK/02=Vjl0SYba08nN]002092O]P0;09:Q]`2@X;D0Tj>g09FU^@2EXkT0
UJ:k09BP^P2EX;P0Uj:g09ZU^@2LZK/00P2IYKX0302HY;X0W:Nk09nY^`2QZKX0XjZn0:FZ`@2V[<@0
YZk60:B]a02V[/40YJk00:N_`0<0Z[;200X0ZkG30:^fa02]^<<0[;Bo0:ng`@2a^<00/kVo0;Fh_`2c
][l0/[No0P2a^L802`2`^L<0/[_50;6i`P2c^L<0/k[50;6ia@2b^<80];[20;Jka@2e_<@0][c30080
][k100/0][g00;Nn`@2j`L<0^L340;No`P2h_[l0^Kfn0;Vl_02j_k`0^knn0;Zn_@020;bm_0040;bn
_`2l`<40^Ko10;W1`080^<2m00H0^L2m0;Zn_P2j_Kl0^kjo0;c0`02j_Kh20;Zm_`0;0;Zm_@2k_kh0
^;bi0;^n^P2l_k`0^Kfl0;Rm_P2g_;d0^;fl0;Zn_02i_[P00P2h_;H02`2i_[D0][fc0;>l/@2d_[<0
]Knf0;:m]02b_;<0/Kbb0;6j/P2a^K@0];bg0080/KVc00`0[[N`0:bd[@2[/jl0Z[B_0:Vc[`2Y]:h0
Y:nX08fDS`1ACe80Ad=404A1@@0k=S/203<_=`0305aIHP2EUIT0oooo01d0oooo6_oooon=0?ooo`0;
0<K5b02OXZ80:2X`01lQ:@0J7B<051LI010B4@0>4Pl04AD@01DI4`0J7aX00P0O8ad02`0L7QP06ATC
01TJ4`0J7AP051LD01@G4`0D5a805AXA01DI4@0F6Q<04QD?00803a4<00H03a8=00lC3`0B5Q003Q4;
00P;1@061`8?ooooo`003Oooool01P1hR9T0OHjS07f>Z01oT:`0OXj[07b<Z`80OY2Y00/0PI>[082A
Z@23TZT0QiJ]08bJ/@2:V;00S9^a08bK/02=Vjl0SYba08nN]002092O]P0;09:Q]`2@X;D0Tj>g09FU
^@2EXkT0UJ:k09BP^P2EX;P0Uj:g09ZU^@2LZK/00P2IYKX0302HY;X0W:Nk09nY^`2QZKX0XjZn0:FZ
`@2V[<@0YZk60:B]a02V[/40YJk00:N_`0<0Z[;200X0ZkG30:^fa02]^<<0[;Bo0:ng`@2a^<00/kVo
0;Fh_`2c][l0/[No0P2a^L802`2`^L<0/[_50;6i`P2c^L<0/k[50;6ia@2b^<80];[20;Jka@2e_<@0
][c30080][k100/0][g00;Nn`@2j`L<0^L340;No`P2h_[l0^Kfn0;Vl_02j_k`0^knn0;Zn_@020;bm
_0040;bn_`2l`<40^Ko10;W1`080^<2m00H0^L2m0;Zn_P2j_Kl0^kjo0;c0`02j_Kh20;Zm_`0;0;Zm
_@2k_kh0^;bi0;^n^P2l_k`0^Kfl0;Rm_P2g_;d0^;fl0;Zn_02i_[P00P2h_;H02`2i_[D0][fc0;>l
/@2d_[<0]Knf0;:m]02b_;<0/Kbb0;6j/P2a^K@0];bg0080/KVc00`0[[N`0:bd[@2[/jl0Z[B_0:Vc
[`2Y]:h0Y:nX08fDS`1ACe80Ad=404A1@@0k=S/203<_=`0305aIHP2EUIT0oooo01d0oooo6_oooon=
0?ooo`0;0<K5b02OXZ80:2X`01lQ:@0J7B<051LI010B4@0>4Pl04AD@01DI4`0J7aX00P0O8ad02`0L
7QP06ATC01TJ4`0J7AP051LD01@G4`0D5a805AXA01DI4@0F6Q<04QD?00803a4<00H03a8=00lC3`0B
5Q003Q4;00P;1@061`8?ooooo`003Oooool0101dQ9/0NXVU07f>Z`1oSjh207n>[@80OXnY00/0OXjU
082AY@22TZD0QI>W08^I[P2:Ujh0QiJZ08^JZ`2@Wjl0TYj`08nK/@0208jL]@0;092N]`2@WkH0T9nd
09:P]02DX;H0UZ6i09FP^02GXKL0V::f09bV]`2IY;L00P2LY[X0302OZ;d0X:Zm09nX^P2SZK/0XZRk
0:F[_`2W[L<0Y:c30:B]`P2U[l<0Y:jo0:N``080Z;3000/0Z[?20:Zb`02[];l0[[K00:nf_`2b^<40
/KO00;:e_P2b/k`0];Fo0;Fh`@020;Bi`P0;0;:i``2c^L<0]K[40;Fha02e^LD0/kW50;6ia@2a]l00
/[S10;>i`P2d_<<00P2d^/802`2d^/00][g10;Fm`@2e_<00]KVm0;Nk^P2i_;T0^kbh0;bm^@2k_K`0
^kbk0080_;bk00`0^k^k0;Zm_P2k_l40^;bm0;Jl^@2g_[X0]kbk0;Vl_P2j_Kl0^l2o0;Zm_@2k_kl2
0;Rk^`0;0;Zk^`2k_[/0^Kfh0;Zn^02i_;L0^[bh0;Vj^@2i^kT0^Kbj0;Nj^02g^kH00P2f^[@02`2e
^[80/k^b0;6i/02b^[40/kbd0;>l/`2c_;40/kb`0;6j[P2a^Jh0/[R`0080/KV`00`0/;R`0:jf[P2[
/Z`0Z[6^0:Ra[@2X/J/0Yk:Y0:RcZP2HX9/0Ngb207b0P`1cN7X203Ph@`0502lb>00U:2d08bH[05QI
G@2?TI406`3ooolJoooooi00oooo00P0alS908n@TP0N8A`08RLL01/O5@0J6a805aP@01XK5@807A`H
00/07Q`H01dK600P81d07b0M01`N6`0K71P06A`G01<F4@0H71@05a/D01@H4`02010C4@0600`?3P0A
51<04QLD00hA3P082PL00P<23oooool000gooooo00H0M8BI07Z;Y01mSJP0Nh^Z07j=[01nSj`207f?
Z@0;07nAY`1nT:@0Oi6S08BEY026UJD0R9JY08RGZ028UZL0RYV/08^I[@29Uk000P2<V[<02`2>WK@0
Sinc096Q]02DXK@0U:2c09RQ]`2JXkX0VjFi09^U]P2JXkD0VZ:f0080VZ>i00`0WZVm09fX^`2NZK/0
X:Vk0:B[_02SZ[h0XZZo0:6Y`02RZ/80XJ[10:F]`@2U[/020:F_`00;0:Nb`@2W/;d0ZK>n0:be`02^
]l00/;S00;6g`02c]l00/kK00;Jh`@2d]/000`2c]l002P2c]l40]KS20;Nha02h^LD0];S40;>iaP2`
^<@0/K[40;6h`P2c_<<20;>k``0;0;Bl`P2d^kl0]Kg00;Jm`02g^[h0]kZl0;Rj_02j_Kh0^[bo0;Ri
_`2j^Kl00P2m_;l0302k^kd0^Kbm0;Rl_@2h_;`0]K^k0;Bj_02e_Kh0]K^n0;Jl`02g^l00^Kg00;Rm
_P80^Kbm00/0]k^l0;Jj^`2g^[T0^;bj0;Rk^02i^kP0^[Zi0;Vi^@2i^kT0][Ne0;Jh]@020;Fh]@04
0;Jk^02c^kH0/KRd0;:j]080/;Vb00D0/[^a0;2i[`2`^:d0/;J]0;6h/`020:ne]@0<0:jd/`2]];40
[;>`0:^c/02X/:h0Yk2_0:J_[02U[Z`0YJf]0:F]/02QZjh0W:ZY0P21TXl0200W:CT0:Blg02DY;`0P
92T07R<S020S6`2BTh`0b<W5603ooolJoooooi<0oooo00D0UiZA05UKD00Q8aD07b4E01`K5P0201`H
5P0;01hJ5`0P7Q/0820L020R7P0M81d07B0L01/O6`0H6aL06AhG01TO5`0E6A<00P0D61801P0@5100
30l=00`?300:30T01PL500830@oooooo000=ooooo`0607B6UP1jSJ<0O8fX07Z;Z@1mSZX0O8fX0P1m
SZP01`1mSJL0P96Z08:CZP24UZP0QINX08FFY`28UZT00P29Uj/03`28Uj/0RYR^08fJ/02=V[00Sifa
08jN/@2?W[00T9fa09BO]02GX[L0VZBh09VS]`2IX[P0W:Fj09fV_00209VS_00<09^V_02KY[/0VjNj
09nX^P2QZk/0XJZm0:2X_`2QZKl0Xj_20:J^``2U[<80Yjk30P2Z//H00`2[//D0[;?40:Za`P020:^b
`@060:je``2`]L80/KO10;6g`02`]l00[kNo0P2a^<002`2c]kl0/[Jn0;>i`@2e^L00];Ro0;:h`02b
]kl0/[Vo0:jf_@2^]kl0/;W00080/KVo00/0/[[00;>j_P2c^[`0]Kg00;Nn`@2g_<00][Zn0;Nk_`2f
^kl0];Ro0;Fg_P020;Ri_`0<0;Rk_P2g_;l0]Kbo0;Jl_P2e^kh0];Vm0;Jj_`2h^l00^Kbn0;Nk_@2h
^kh0][^m0P2d^[/02`2c^[/0/[Vi0;Bk^P2f_[`0^/2m0;Zm_02k_Kd0^[^j0;Rj^@2g^;L0];Jf0080
];Jg00/0];Rh0;>j^P2a^KP0/;^g0;2k]P2^^K@0[[Nc0:nh]02_][<0[kBa0;2g]P020:jc]@0<0:nf
]`2Z/[@0Z[:d0:Vb]02W/K<0Y[2b0:F_[P2U[Jd0XjZ/0:F^[P2P[:`0WZ^/0P2L[Z/02`1]N7h0D5MR
03PmB@0`=4009bXd02X^<@0d>SD0B55302PZ9@2EUIH0b<S901D0oooo6_oooonF0?ooo`0?09:CS`1I
F5L06aHJ01/F6P0M6A/0820M02<T7P0R9ah07bDN01hT7@0I7aT061dH01TN600J7aL06AlF00804aPB
00H03Q0<00P:20082PP01PH400D30P040`4?ooooo`003Oooool01P1fRYP0Ni2S07jAZ@1nSjT0O8fX
07f=Y`80P8nX00X0Pi6Z08BB[024Tjd0QIJ^08>EZP24UJP0QiFY08RF[@2:VJl0RYZ_0`29VZl02`2<
W;00SYjc08fL]02?W[D0T9nf09:O]@2EX[L0UjBi09JR^@2IY;`0V:Bl0080V:>l00`0VJFl09VU^P2K
YkX0WZVi0:2Z^P2QZ[/0X:Rj0:6Z_02SZl40YJc40:J/aP2U[<D20:J^a@0;0:R_a02Y/L@0ZK740:^c
a@2/]LD0Zk?30:fea02_]/<0[kK40:nga02^]kl00P2_]kd02`2a^;d0/KNl0;>i_`2b^<00/[No0;6g
_02_/k`0/KFn0;6g`02a^<40/;S10080/KW200/0/KS10;:i`@2c^l40/KVn0;:i_@2c^[h0/[Zo0;6h
_@2a^Kl0/[Zo0;Bj_`020;Jk`@0<0;Jk`P2f^l<0];[00;Bk`02e^[h0]k^o0;Ji_P2e^;`0]KVl0;Fk
_@2e^kh0][bo0P2c^KX02@2a^;L0/k^h0;Fk^P2g_;d0]k^l0;Rl_P2f_;l0];Zl0;Nl_0020;Fh^P80
];Rl00/0/KFj0;2g^P2a^;/0/;Ri0:jf]`2`^;P0/;Ri0;2f^02`][T0[kJg0:fe]0020:^c/P0<0:Zb
/@2Y/[80Yk2`0:N`/P2V/K80Yk>b0:Rc/P2T[jl0XJ^/0::^[02Q[J`0Wjf]0P2LZjX02`2JZ:L0V:JS
079jP01QIW80B4MM04Y:GP2CXid0Q92;055FF`1AFUL07AXS0080E4mG00<0SHZ?0?ooo`3oool0403o
oolJoooooiP0oooo0P35a<H02`2:R8`05A<G01DD4`0I6QD061`F01@G500E6AD05ALD01LI500E5a00
4aH<00803Q0800H020L400/:200>3@X02@L600P510081@<?ooooo`003Oooool01P1dQ9L0NhbS07j?
Z01mSjX0OHjZ07b;Z080PHjY00T0Phn[08B@[@23T:`0Pi6]086?ZP23T:T0QI>]08JC/@26UK800P28
VK@208VJ/P0;08fM/`2>W;D0S9Vf08nL^02?W;L0T9jf096O]P2DX;H0V:Bk09NS_P2HY;h00P2IYKh0
302KY[h0VZFk09^T^@2LYK`0WjRl0:6Y_02QZKl0XZVo0::/`P2QZL@0Xjc70:>/aP80Y:g400@0Xjc2
0:N`a02V[lD0Z[760P2W/<D01@2[/lL0[KC60:nfaP2_]l@0[[S10080[kVo00/0[KJk0:ng_`2^][l0
/;O00:nf_`2]]Kh0/;Fn0;6f`02b]l<0/[O10;6g`0020;>g_`0;0;:f_P2d]kl0];S00;:g_P2`^Kh0
/;Vm0;6i_`2a^;d0/KVm0;2i_02b^[h00P2f_L00302e^l00]K_20;Bi`02c^<00][W00;Bf_@2f]kh0
]KRm0;Jl_@2f^k`0]k^l0;Nj^`80]KVl00/0][bm0;Nm^`2f^kX0][Zl0;Jk_`2d^;d0]KZn0;Bi_02f
^[/0]KNk0;Fg_0020;Fh_@0;0;Bh_@2`];`0[[>k0:fd^P2^]kT0/;Vg0;:j]`2b^KL0/KNd0;2f]02/
];800P2W/:l0302Y/[40Z[>d0:Va]@2X/KD0ZK:e0:Zd]@2V/K<0Y:jb0::[[`2QZjh0XZfa0:6^/@80
Wjb_00/0WJR/09bW[02KY:/0V::X08jGWP2;U9X0SiVL09:NW02>ViP0Tj:F04a>D@0201H@7`0401/F
8`0H51d0D4eC08J5R0l0oooo6_oooonL0?ooo`090<?3a028QhP05A@C01TG5P0F5A<051@?01DF3@0F
5`d04a<;008030`700H02`X500`;1P0?3PP030X500T70`091`@?ooooo`003Oooool01P1/N940NhZU
07f<Z@1lS:X0O8^[07b<Z@80P8jZ00D0PHjY08:>ZP23SjX0PXjY08>?ZP0208FBZ`0408JC[@26U:h0
QiNb08NI/P80QYN_00/0R9Z`08bM/`2=WK<0Si^d092J/`2AVk@0TYbf09>M^@2EW[/0UYnn09NQ_P02
09VT_`0<09bV_`2KY[h0W:Fm09jX_02MY[T0XZVn0::X`02RZL40YJg50:>[a02RZ/@0Y:c50P2S[<@0
2`2U[/80YZk10:J]`@2Y[l@0Z:k30:V``P2[/l<0Zk?10:bd`02[/kh0[KFo0080[;Bm00/0[;Jn0:jg
_`2//kh0[;>n0:jd_`2`]Kl0/[O00;:g``2`]<<0/KO30;2g`P020;6f`00;0;:f_`2c]kh0][W00;2d
^`2a]Kd0];W00;Bh`02c^;h0/[Rm0;6f^`2c]kd00P2c^Kh00`2d^[h0/kRk0;>i_P020;6f_@070;>g
_@2c]Kd0]KJm0;Bf^P2e^;X0/kNi0;>g^`020;Bi_00;0;Bk_@2f_Kd0]Kfm0;Jk_@2f^K`0]KJl0;>e
_@2d][d0/kJl0;Fg_@2d][`00P2c][d02`2b]K/0/KFj0;:h^P2a^;T0[kNg0:jg/`2]][00[[J_0:je
[P2_];40[[Bb0080ZkBd00`0ZK:b0:Va/P2Z/[D0Z;2e0:R`]P2W[K@0Z:jd0:N^/`2U[K80XZZ`0::/
/`2OZ[4209fW[P0;09^U[02MYjh0WJF]09nW[P2KY:X0VJ>X09RQYP2GXJ@0UYnR08nKW027U8l00P1;
D5D01`0_;cL09BD[01dK8P0F4aX07QdP09ZJV@39b<T0303ooolJoooooil0oooo00H0U9FC05UHEP0N
7Q/05QH@01DD3P0E51<201<B4P0600h>3`0>3`h03a4=00lA2P081`<020H13oooool000gooooo00H0
L7jB07Z9X@1oSJT0Ohf/07b;Z`1kRZT207f=Y`06082@YP24TjL0PY2U08:AZ021SjP0PY6[0P24Tj`0
0`26UZh0QiN`08>C[P0208BE[`0;08JE[P26U:`0RYR^08bI[@2?VZh0SiV`092K/`2AW[L0TYff09FP
^02IX[`00P2HXK/0302IX[/0VZBh09ZT]@2LY[D0WJFg0:2W^P2PY[`0WZFm0:2X_`2RZKl0XJ[00:>/
`P80Xjg200/0Xjc00::Z_02W[[h0Yjbm0:Z`_`2X[[l0Z:nn0:Va_02Y/KT0[;>k0:Za^`020:^b_@0;
0:Za_02[/kh0[K6l0:fb_02_]Kh0[[Bn0;6f`@2`/l40[[;10:fa`02`]L400P2_]<001P2]/[h0[[Bm
0;2d_02c][d0/[Jn0;2c_@80/KFm00<0/KJm0;2d_@2c]kh00P2b]kd0302a]k`0/KJl0;2f^`2`]Kd0
[kBl0;:f_P2c]Kh0];Fm0;Bf^`2e]k`0/kJl0;>g^`80/[Nk00/0/[Rk0;6f^P2a]K/0/[Nm0;2d_02b
]K`0/[Fk0;6e^`2^];X0[K>h0:fb^0020:jd^P0;0:jb^P2]/kT0[KBg0:^c]02//k@0[[Nd0:be[`2]
]jh0Zk>_0:je/P2]];<00P2Z/k@0302W/K80Yk2a0:F^[`2W[k<0Z:bd0:JX]02WZK@0Yj^b0:JZ/P2W
ZkD0XjRd0:2X]080WZRc00/0WjR`09bU[@2LXj`0Vj>[09RQZ@2HX:T0Uj2X09ROZ02GWjP0Ti^S092M
W`0208^HUP0:08JDS01XLFh0=C<n03<a>P0Y9Rh0<c8e03Hg>00/;340TY:F0<S8bPT0oooo6_oooonR
0?ooo`0308j>SP1EEEH08B<S00806a/N00H05AHL00l@5P0;3@l02@/:00L910061P8?ooooo`003Ooo
ool01P1dPY00N8RL07b<Y@1mS:P0OXfY07Z:Y@80NhbS00/0P8jS082<X@1oS:80OH^Q07f=Y@1mSJH0
Oi2X086BZP23Tj`0QIJ_08FC[@0208JD[@0;08NF[@27U:/0R9F[08fH[P2?VK00SiVa08fG[`2=UZl0
T9Zb09BM]02GWkH00P2GW[D0302IXKL0UYjd09VR]02MYkH0W:Ff09ZS]`2KX[P0VjBi0:2X_02MY[X0
WjVl09nY_`80WjRn00T0Y:fo0:>/_@2UZkX0Yjnl0:N/_02V[;/0YJbi0:R^^P2Z/;T00P2//[X20:Za
^`0;0:R_^`2X[kd0ZJnl0:Z`_02[/K`0Zjnm0:Z^_@2[/Kl0ZZjk0:^^_@2]/Kh00P2]/[d00`2_/[l0
[k>o0:fb_0020:fb_0060:b`^P2]/[X0[k>j0:nb^02^/[T0[[>i0P2a][/0302`];`0/KBl0:na^P2]
/;T0/;Bj0:nd^P2`]K/0[k2h0:na^02`/KT0/[:j0;:c^@80[[>g00P0/;Jj0;2e^P2`];`0[K:k0:jc
_@2^];`0[K>i0:bc]`80Zk6f00h0Zk:g0:^b^02[/[P0[;2i0:jc^`2[/;L0[;>g0:fc]`2[/K@0Zk:c
0:bb/P2Z/K00ZJn^0:J][080Yjn_00`0Y[2_0:B^[P2SZjh0YJba0:FZ/@2VZK80YZRa0::T[@2SYZl0
XZJ_0:6V/02NY:l209jU[00309ZSZ02HX:P0V9nX0080UijW00H0UifV09JMY02DVj00T9RO08nGX02?
VIl208^FVP0;08^EV02;UIH0NhB707AoP01WL7@0GFIZ0413C@0c=4<0?T9=055JF`1ZKG000P29R8h6
0?oooa[oooooY03oool02@33`/D0RhZ>08^:SP0A41P020PA00@42`030`D00P<200@40`0?ooooo`00
3Oooool01P1[O8H0NH^J07b=X`1mSZH0NXZU07b=Y@80NX^R00/0NhbQ07b;X@20SZH0OhjW07f=Y`1l
S:L0OXnW082AZ022TZX0QI>]08FC[P0208JE[P0;08FE[028UZ`0RYN]08jJ/@2=Uk00SYVa08fG/@2>
VK<0SIRb08nK/`2DWkD00P2EWkH0302GWkL0Uj2f09BN]02DX;@0UJ6e09JP]P2HX[L0VZFj09^W^P2L
ZKX0W:Vk09nY_@80W:Jn00@0WZRo0::[`02SZkh0YJbm0P2W[Kh01@2UZk`0YZfl0:F/^P2V[;T0Yjjl
0080Z:no0P2W[kh0202W[[`0ZK2m0:R`_@2W[[`0YZfm0:V__`2Y/;l0Z[700`2[/[l01@2Y[Kh0Zjjm
0:Z]_02Z[kd0ZK2k0080Zjnj00@0[K6l0:jb_02^/k`0[;6j0P2]/kX00`2]/[/0[[>l0:fa^`020:jc
^P070:fb^@2^/kX0[K6l0:f`_02^/K/0/;:l0:fa^P020:^`^00;0:^a^@2]];`0/;Fo0:fc_@2]//00
[K>n0:V`^P2Y/KL0ZkBh0:bd^P2[/[/00P2Y/K/02`2Z/K/0Z[2i0:V_]P2Y[[D0ZZne0:ba^02[/KL0
ZJfc0:^`]02Y[[<0YJbb0080Y:bb00`0Yjnb0:J][`2T[:l0Y:Z`0::X/02SZK80XZRa0:2V/02QYk40
WjJa09^S[@2KXj`309^T[080V::Z00P0V:>Z09RSZ@2GWjL0UIfU09FOY@2CWJ80U9fP09:KWP80SiVL
00/0SiRL08bEV`2:U9X0Qi2F08B?U021SI80NHJ<07R4S01hQHh0NXR?06QeNP0202DX>P0303@m@P17
BE@0PhF:00<0oooo6_oooonX0?ooo`050<?3aP23Q8T01@L;00@51P030`<03oooool000gooooo00H0
K7b607B6U@1iS9d0O8jS07V:Y@1jRjL307^<Y`0:07^<YP1kS:D0O8bU07^<YP1lSJP0OHfW07nBZ020
TJP0Pi>Z08JE[080Q9F]00/0PiF/08FF[027UZ`0RIN^08ZE[P29UK00RIFa08ZG/`29U[@0S9Zd08jL
]@02092L]@0<096K^@2BWKT0Sibg092N^@2AWkL0T9jf09>P^02DX;X0UJ:m09JT_@2EY;/0VZNm0P2K
Y[h01@2KY[l0WJNn0:6[_`2QZKX0XjZm0080YJbo00@0Y:^n0:B[_@2U[;h0YZbo0P2TZkh02`2U[Kl0
YJjn0:B^_P2U[Kd0YZnn0:J^`02V[<40Z:k20:R_`P2X[l40Yjo10080Yjno00/0Z;2o0:Z`_`2/[kd0
ZZjj0:V_^@2Z[kX0[[:m0:fc_@2]/[h0[:no0:ba`P020:^b`P0<0:^b`@2[//00Z:nk0:R_^@2Z/K/0
ZK6j0:V`^@2Z/;`0ZJfm0:^a_`2///40Zk;00P2[/Kl02@2Y[k`0Yjjj0:Va^`2Y/;/0Z[6l0:bb_02Z
/K/0ZJnk0:V`^`020:Za_@80Z[6o00/0Yjjk0:R_^P2X[kP0YZfe0:R^]@2W[KH0ZJjg0:V`]`2Y/;P0
Yjfh0:FZ]@020:BZ]00<0:>Y/`2SZK80XjZa0:6W/P2SZKH0XjRg0:2X]P2PZKH0WjVe09^U/`2HX[00
VJB_0P2IXJd02`2GXJ`0UZ6/09BQZ@2CX:T0TifX09>LZP2BVjP0TYbV096MY@2@Vj80SYVN0080SYVL
00/0SiZN08fHW@2;UYX0QY:E08>@T`22T9<0PHnB07j;TP1mRY@0NhNB07Z9T@0206mmQ@0606j1P@0c
@4P04aXW00`B6@20PXD0`<316_oooon[0?ooo`030863Q011@DCooooo00kooooo000=ooooo`0606Yl
P`1hRYD0Nh^L07^;X01iRZD0N8RV0P1cPj@02`1cQJH0MHRW07V<Y`1iRj@0NhbU07^;Y`1mSJL0OXnV
07n@Y023Tj<0QIBT0080Q96U00/0Q9>[08:CZ`24U:`0QiJ]08RF[P29UK00RIFc08NC/`29UKD0RIJb
08ZH/P0208jJ]00<08nI]P2@VkT0SiZi092K^`2AWKX0T9fe096N]P2DX;T0Tj2j09:P^@2BXKT0UZBj
0P2KYkh02`2KY[d0WJNm0:2Y_@2RZ[d0XZVl0:>Y_02TZ[h0YJ[00:>X_`2TZL00YZ_10080XZRn00/0
YJW10:J/`@2U[<40Xjbo0:>]_02S[;h0Y:Zo0:BZ`02V[;l0YZbn0:J/_0020:N]_`0:0:J[_@2W[;`0
ZJfk0:R^^@2Y/;P0Z[6k0:R/^02Y[K`0ZZk10:b_a0<0Zjk300`0ZJc10:N[`02UZ[h0YZbk0:N^^`2Y
[k`0ZJfi0:R/^@2Z[KX0ZJ^k0:V/_P2Z[[d20:V]_00;0:N]^`2V[;T0Yjfj0:R_^`2W[[T0ZJnj0:R^
^`2TZkL0Yjji0:R^^P2W[[X00P2V[;T02`2UZkP0Yjjh0:J/]P2V[KH0Yjbe0:F[]@2SZKH0XZVf0::X
/`2UZkD0Y:Zf0080X:Jd00`0WjBc09nU[`2OYZh0WjJ^0:6V/`2QY[L0W:6e09fT]P2IXK80V:2_09bT
]02IX[8209NR/@0;09JR[`2DXJ/0Tj2X09>NY`2DW:T0TifY08nJY`2?Vj@0SibP08fJW02<VI/00P2>
V9h0102<Uj00RYJM08VEV`22SY<208>AU@0508B@U`22S9H0PXfE07n=T`1lRXh00P1jR8/01P1ePXD0
Nhb803M1A`0:31P020TA00H531[ooooo[@3oool?ooooo`003Oooool01P1[O8P0NHZH07b=W`1kRjD0
NXZZ07N8Z@80M8FV00/0M8NU07F8Y01fRJ<0NhbU07f<YP1lS:T0OXn[08:D[020TZH0PYBV08>CY@02
08>AY`0;08BE[@23U;00PiB`08FF[`25Tj`0R9F`08NB/`28U;H0QiJe08VH/P2=V[400P2BWKD0302>
U[40TIZg096K^@2AV[T0TYbh09:L]02CW[@0U9nd09>N/`2EX[D0UZ:f09NS]`80VjFi00/0W:Jk09^S
^@2NYk`0X:Zj0::Z^@2TZK/0XZNl0:>W_P2UZL40YJ[00:2W_@020:2X_@0;0::X_02UZ/00YJ[20:B[
`@2T[Kl0YZbn0:FZ_`2W[<00YZbm0:B[^`2W[[`00P2W[K`02`2W[;`0YZbj0:J[]`2V[KD0Yjjf0:J/
]`2W[KX0Z:fn0:R]`@2VZl00Yj_10080Z:c300P0YZ[10:J[`@2X[<00Yjbl0:V^_02Y[[X0Z:^i0:NY
^080ZJfi00D0ZZbl0:R[^P2X[;X0Z:bj0:R^^`020:J/^P80Yjfi00H0YZ^j0:R^^`2X[[X0Z:ji0:N]
]`2Y[[L20:R/^@0;0:R]^@2Y[KP0Z:fg0:V^]`2W[;D0YJ^f0::X]02RZ[@0X:Zd0:2X]02OYkD00`2O
Y[@02`2QYk@0WZBa09jS/02QY[<0WZ:e09nT^@2LXkL0VZ:c09ZQ/@2KXk80Vj>c0080Uin^00/0UJ2^
09BP[@2AW:X0Tij/09>NZ`2AWJ`0SI^Y08bKY@2;VZ40RYZO08ZHW@0208bHW`0;08RDWP27U9h0QiJM
08:@U@23Si<0QI2E08B>U`22RiL0PH^F07b9T01jQXX00P1kQhX01P1iPXH0NXB707N4Q00_<T@09BHh
020O;a[ooooo[@3oool?ooooo`003Oooool01P1ZNX/0NH^N07j?Y@1lRjH0NhZY07R7Z@80MhRX00/0
N8^W07Z?YP1mT:D0OHfV07j=Z01oSZT0P96[086BZP22TjP0PiFW08FEZP0208FBZ`0;08FC[P25U;40
PiBa08>E[`26UZh0R9J^08ZG/P29Uk80R9F`08^H/02?W;400P2@VZl0302AV:l0TYZc09:J]@2CVkL0
TIZd09JM]@2EWKD0UYje09FO]P2GXkL0Uj>c09^U/`80W:Ff00/0WZNk09jW_P2NYkd0WZNk0:6Y_02U
[L00Y:Rn0:BY`02UZKl0Y:Zo0:B/`0020:>/_`0;0:J]`02UZl40Y:W20:>Y`@2UZ/00YJZm0:BZ^`2W
[K`0Z:no0:J]_@2U[;`00P2W[;d02`2W[Kh0XjVk0:B[^P2TZkP0YZjh0:BZ]`2V[KT0Z:jn0:R_`@2V
Zl00YZ_10080YJW000`0Yjc10:R]a02W[<<0Z:g00:R]_@2Y[kh0Zjjo0:b^`02//<00Zjno0:Z]_@2[
[[/20:Z_^P0;0:V/^P2Y[K/0Yjbk0:N]^P2V[;X0Z:jn0:J/^`2V[KX0Yjfk0:^a_`2//;h00P2]/Kh0
2`2Z[[d0ZJjl0:V^^P2W[;H0YJ^e0:J]]`2T[KL0XZ^e0:6[]P2OZK@0W:Fb0080WJJc00`0WZRd09nX
]02OYk@0WZFb0:2X]@2LY;D0W:Bh09VQ]@2JXk@0VjFd09ZS/@2JX[8209RR]00;09BP/@2CX:l0Tin]
09:MZ`2CWj`0TYj]092L[02<W:P0RYZR08^KX02:VI/00P2=W9d02`2;VYh0RIZM08ZIVP26UID0QYBD
08NAU@26T9H0Qi:J08>>VP1nRiP0NhRE0080OHVC00H0OXR?07f5S01jPhX0M86706IcN`1QLG@Joooo
ojd0oooo3oooool000gooooo00H0J7N;07J9WP1kS:@0NHZT07b<Z01jRjP207N9YP0;07R;Y01fRJ<0
NX^U07f<YP1nSZH0OXjX07n?Z@20T:T0PHjV08FDZ026U:/00P25TZ`02`23Sj`0PY2/08>A[@26U[80
QiFc08NF/P29Uk<0R9Fb08bI/P2?W;<0SYZa0080SYVa00`0SiVc096J/`2AV[@0TYZe09BL]@2HWkL0
UYjg09BL]P2DW[D0UJ2d09JR/`2IYK@209^U]00;09bV^@2JY;/0VjJl09nX_@2MY[/0W:Bk09bT_02O
Ykh0X:Vo0:2Y`02PZ<000P2PZ<802`2PZ<@0XZ[50:6Ya@2RZ<<0XjW30:BZ`02TZkl0YZk00:B/_02U
Zk`0YZ^m0080YJ^o00/0YJc10::X`02QZKl0XZZn0:B/_02U[[`0Y:bi0:B]_02SZ[d0XjZo0:BZ_`02
0:F[_`0<0:J[_`2WZl80Z:c50:R/``2W[<00YJ_00:FZ`02XZl40ZJc20:R[`P2Y[<40Z:^m0P2WZ[`0
2`2UZ;d0YZZm0:FY_02W[;d0YJZl0:N]`02W[L40Yjg00:J/_P2VZkd0YZZo0080Yj^o00T0YJ^o0:F[
_P2SZKX0YJ^i0:F]^P2SZk/0Xjbk0:6Z^02PZKH00P2PZ;L209nX]P0<09nX]`2NYkD0W:Fc09bV/`2L
Y[@0VjFb09VT/@2GXk<0UJ6b09RR/`2GXK<0U9j`0`2GXk@02P2CX;80T9j^096M[@2?VjL0SIVV08jJ
Y`2=VZL0SIbV08^JXP2:VId208^KV`0;08VIW025UYX0QIFH08FDU`24TiH0Q92E08:>U@23SiP0PHjI
082>V@1nRiL00P1nRiD01P1oS9L0NhNB07R5S01fQ8X0LX:506YlNa[ooooo[@3oool?ooooo`003Ooo
ool01P1XMh/0MXVN07^<Y01iRZ@0O8bX07Z;Z080MhVV00/0N8^T07J9X`1jRjD0OHbV07j>YP1nSZP0
OhnY082@Z@21SZH0QIBX08JDZ`0208FB[00;08>?[022T:`0Pi6]08JF/P27UK<0QiJb08VG/`28UK80
S9Vb08nL/`2>V[400P2>VK40302?VK<0TIZc096J]02BV[D0U9be09RO]`2FW[L0U9bf09BN]@2EX;@0
UZ:c09VU]080VjFd00/0W:Ji09ZT^`2KY[`0WjRm09fV^`2LY;/0W:Bl09nW_P2PZKl0X:W00:2X`002
0:2X`P0;0:2Xa02RZ/D0XJW50::X``2SZL<0Y:[00:B[_`2V[/00Y:bl0:F[_02VZkd00P2UZkl02`2U
[<40XZS00:6Y_`2RZ[h0Y:bl0:F^_02T[;T0Y:fl0:>Z_@2SZ[l0Y:Zo0080YJ^o00`0YZ^o0:N[`P2X
[<D0Z:c30:N/`02UZl00YJ[00:R[`@2Y[<80Z:_20:V/`@2XZkd20:NZ_00;0:FX_@2VZ[d0YJVl0:N/
_@2UZ[`0Yjg00:N]`@2W[L00YZbn0:J[_@2VZ[l00P2WZkl02@2UZkl0YJ^n0:>Y^P2UZkT0YJfj0:>[
^`2S[;/0XJZh0:2Y]P020:2X]`80WjRf00`0WjRg09jW]@2LYK<0W:Jc09bV]02KYK80VJBa09NS/`2E
XK80V::c09NQ/`2DW[0309NS]00:09>P/P2@WZh0TIf]08nKY`2=VJH0SYZW08fJY`2=W:H0RiZR08ZI
W@80Ri^K00/0RIVL08FFVP25UIP0QIBG08BCUP24T9D0PXjE08>?V021SYT0P8jI07j;U`0207j;U@06
07n<U`1kQi80N8F<07J4RP1bPXD0JWak6_oooon]0?ooo`oooooo000=ooooo`06069aR@1eRJ40MX^V
07N:Y@1hRZL0NHZV0P1hRJH02`1gR:D0MHJU07R9YP1lRjP0Nh^V07b<YP20T:T0Q96Z08BAZ@26TjX0
RIJ]0080QI:Z00/0Q96Z08BBZP24TJX0Q96^08NC/`27U;<0R9Bd08RD/`29UK@0RiNe08ZE/P0208fG
/P0<08nH]02?U;80TIRe09:J]P2CW;P0Tibf09:L]P2AVkH0Tiff09>N]P2EX;H0UJ>e0P2DXk@02@2H
Y;T0Uj:j09RU_02JYKl0VjFl09bT^`2OYkl0WZO109fV`@0209jV`080XJW200/0WjO309jW``2NYl<0
X:O30:6Xa02OYl00Y:[10:F/`02TZkd0YJZl0:F[_@020::X_@0;0:BZ`P2TZL@0X:K309nW`P2RZ/00
Xj^o0::[_P2RZ[l0XZVn0:6X_P2RZ;l00P2VZl40302VZ/00Yj_10:FY``2UZ<<0YZ[40:BX``2TYl<0
YZW50:NZaP2UZ<H0YZ[60:BX``80YJS300/0YJW30:FZ``2RZ<40Xj[00:B/`02TZl00Y:_10:B]`P2U
[L80XZVn0:>Z_P020:BZ_@0;0:>Y_@2RZ;d0XZRm0:>[_@2SZ[`0XjVk0:>Z^`2RZK`0XJRi0:2U]`2Q
YkT00P2PYkT0302NY[P0WJFg09VR/`2JY;<0W:Fd09^T/`2HX[40Uj:a09RS/@2GX;40V:2c09NP/080
U9n^00/0U9j_096M[@2AWZh0TIn]08nLZP2<V:H0RiRU08bHY@2<V:<0RiNQ08^GX00208VEWP0;08ND
W@24TI`0Q9>M08BDV`23TYP0Pi2F086>UP21SiT0PHjI07f;UP1lRY@00P1kR9@01P1iQY80N8B>07F4
S01dPhT0LH2206j0OA[ooooo[@3oool?ooooo`003Oooool01P1XMh/0LXFO07F:Y`1hRZ`0MhZ/07N9
Z`80LhFW00/0M8FW07F7Y`1jS:P0NHZU07b<YP1nSZL0OHbV08:?Z024T:P0QI6Y08RC[P0208:=Z`0;
08B@Z`25TJ/0QI6[08BAZ`29U;00R9:a08ZA/P2:Tk<0R9>b08bF/`2>Uk<00P2AVK@0302BV;H0U9Vi
096F]`2BUkT0TYVi09:J]`2BVkH0TYbi09:L^02CWkP0TIfg09BQ]P80U:6e00/0U:2f09JQ^02GX[`0
V::n09JP^`2MY[l0WJBm09fT_P2LXl00WJG109^U`@0209fW`P0709jW`P2PYl40WjO009jV`02OYl40
WjJo0:6X_`030:>Y_P<0XZRm00/0XZRn0:>X_`2TZL80Y:S10:>X`02RZ<00XZRo0::X`02QY/40XZO3
0::W`@020:J[``070:BY`02SZ<00YJ[10:BX`02TZ<<0YZ[60:N[b0020:NZaP030:FZa@2UZL<0YJW3
0080Y:S300L0Yjc50:FY``2SYl<0XZW40:6Y``2SZl<0Xj[10080Y:_000l0XJRn0:>Z_@2TZk`0Y:^l
0:>Z_@2RZ;`0Y:Zo0:BZ_P2RZK`0XZJj0::W^`2RZ;/0XJJh09jT]P2OY[L00P2NXkD0302PY[L0W:Be
09^S]@2KXk@0VjBd09ZS]02HX[<0Uin`09RP[`2IXK40Uina09VR/`80Uj2`00/0UIj]09>L[02AW:d0
SiZ[096L[02BWJ/0Si^W08jKY`2;V:@0RiNT08bGY@0208^FX`0;08RBX026TZ40QY>P08FCW@26UI`0
QY6L08F@W@21S9h0OHRM07Z6VP1iQYL00P1hQiD01P1iR9<0N8RA07N8SP1dQXX0LhF406j1O1[ooooo
[@3oool?ooooo`003Oooool01P1UMHX0LXFM07>8Y01eRZP0M8JY0764Z080Kh:V00X0M8RZ07>7Z01e
R:P0MhZW07N9YP1hR:@0OHfW07f9Z021SJ/0PY2[0`24TJ`02`24TJ/0QY>[08NE[@27UJd0R9J/08RD
Z`29UJd0Qi:]08VE[`2:U:l0S9J_0080SYN`00`0SYNb096H]P2AVKP0T9Nh092I^@2?V;P0TIZf092J
]02AW;H0Tifi09:M^02CW[L209>N]00;09:M/`2DW[D0V:>j09RS_02GXKX0Uj2l09VR_P2HXKd0V::n
09ZU`P2KYl<00P2JY/802`2IY<00W:S009ZV_P2MYkl0W:Fm09nX_P2PZKd0X:Nk09jV^P2OY[`0XJRm
0080WjJl00/0XJNm0:2U_02QY[h0X:Bm0::X`02QZ;l0WjJm09nW_P2NY[l0WjK10:6Ya@020::Za@0<
0::Y`P2RZ/40XJW00:2X`02RZL00Xj[30:F[a@2SYl<0Y:W10::Y_`2RZL40XJK00P2PYKl02`2SYl00
XZO20:BY``2SZL<0XJW20:6Y`@2OZ<00XJRo0:6Z_P2QZKh0WjRk0080WjVk00/0WjJk0:2X_@2TZl00
Y:_10::Z_P2OY[/0WJFi09fV^02PYkP0WZFe09fV]@0209nX]`0<09fU^@2JXKL0VZ:f09ZR]@2IX[40
V:6`09JQ[`2FWjl0Uij_09RO/02EWK00UYn`0P2CVk002`2CWK40TYb_092K[02=V:P0S9RW08nJZP2=
V:L0SiVW08fHYP2:UZ@0RYBT0080Qi6Q00/0QHnO08FAW`24T9d0PY6J086@V@21SiP0PXjI08><W@22
SJ00O8ZM07R9V@0207N9UP0607J7T`1dQHd0M8J:07:5QP1_PX00KhAl6_oooon]0?ooo`oooooo000=
ooooo`0606UgS01_P9/0KhBQ0725X`1bQZH0M8NX0P1bQZL02`1aQZP0KX:U07:6Z01eRZT0MHNV07V;
Z01lS:P0O8^X082?Z@20SZP0PHjY0080OhbX0P1oSjP02@21TJX0PY:Z08:AZ@23TZT0QI>[08RD[@29
Tjl0RYBa08^F/@0208VC[P0908VC/02=U[<0T9Zf08nI^02=V;L0T9bh08nJ/`2AW;<0SYRb0080SYVg
00h0SIVd08nL]02?W;@0T9bd09>N]@2DWkH0UIng09NP^@2CW;P0U9bk09FL^P2EWkX0UZ2k09FP^`80
U:2l00P0Tj:m09FR_@2EX;X0U9nj09VS_`2GXKd0V:>j09bU^`80W:Bj00h0W:Fk09fV_@2MY[d0W:Bj
09bU^P2KXkT0WJBj09fU_02NYk`0W:Ji09fV^`2OYkl0WjK109jV`0<0WjS300/0XJW309jV`02PZ<00
WjNn09jU_`2OYKh0WZFl09jV_02MYK/0WjNn09jW_@0209bT^P0409jT_@2PYl00WZK009nW`080WJJo
00D0WJJm09bV^P2NYkT0X:Zj09jY^`0209fW^P0;09bS^02LYKP0WJFj09fU^@2NY[X0WZFj09bT]`2K
X[H0Vj>g09^S]P2KY;P00P2KYKP02`2IX[P0UZ2f09FN]02GWk@0UYna09JQ[`2DWjd0Tif]09BL[@2A
VZd0T9b]00<0SYVZ00/0SiZ/092L[`2>VZd0SYZ[08bGZ@2:U:H0RI6T08ZCY@29TZD0Qi:S08JAXP02
08FAXP0;086>W`20SIl0PI2P07n?WP1mSY/0OhnK082@W01nS9P0OH^H07V6U`1fQiH00P1hRYL01P1c
Q940LX>=0764R@1`Ph<0KX5o06UmMa[ooooo[@3oool?ooooo`003Oooool01P1VLi00JgfM06j4Y@1_
QJH0LHBV07J7Z@80M8FY00/0LhJ[07:7ZP1dRZX0MH^X07R<Z01hRjP0NXbX07^<Z01nSZT0Oi2Y082A
Z@0208:AZ@0;07j=Y`1oSZP0PI6Z086AZ`22Tj/0PI:Z08:AZ027U:d0R9Fa08ND/P28UK400`2<VK40
2`2<V;00SINc08jH^02<UkP0RiNh08fI^@2?V[L0T9bi08nL^`2=VkX0SIZg0080SYbe00/0Sife096M
]@2DW[L0U9fi09NO^`2FW[/0UIfj09FM^`2FW[/0Tibi09BQ_00209FR_@0309BQ_@2GX[h0VZG00080
V:6o00H0Uj2m09ZQ_@2IX;`0VZ:o09fU`@2NYl0209bV_P0;09ZU_02MYk`0WJNk09bT^@2MY[/0WZNn
09jX_02LY[T0WjNm09jV`P2OYl<00`2PZ<@02`2QZ<@0XJO40:6Xa02OZ<@0WjS30:2Y`P2PZL40WZVo
09bW_@2KYkl0WJW10080W:No00/0W:Fm09fT_@2MYL00VjC009jX`P2MZL40WZVo09jY_02OZk/0X:bi
0:6/^@020::[^@0:0:6[^P2QZ[`0X:Rm0:2X_P2QZKh0WjNl09fT^P2OYKX0WJBj09nX_P<0WZRl00`0
W:Fi09^U^P2JXkP0VZ>h09NQ]P2GX;H0UZ6f09FP]@2BW[80TIfb096N/@2AWjh209:N[`0;09:L[@2B
W;00T9Za08jI[P2=V:d0SYV^08bGZP2>VZ`0RiRY08RFYP27UZH00P26U:H02`23T:<0Q9:W08BAZ024
TjL0Oi2S07f=XP1lSZ40OHnN07f>W01iR9/0N8NL0080NX^M00H0MXNF07J9T`1dR8d0LXJ60766P@1`
QG/Jooooojd0oooo3oooool000gooooo00H0JWFD07F5Y`1fR:/0MHJZ07>3Y`1eQZT207N8[@0;07N7
[P1eQj/0LhNY07N:Z01kRjX0NXZY07f<ZP1nSjX0OhnY082@Y`22SjL00P24SjT00`26TJ`0QI6]08B?
[`0208B@/080QY>b00@0Qi>b08RB/P29TK00RYBa0P2:UK001P2<V;80T9^d08fG/`2?VKT0SiVl08fG
^P80S9Ff00@0T9Vk096K^`2?V[/0SIVh0P2@W;D02`2CW[D0U9bd09JM]P2HW[L0V9nf09NM]02HW[H0
Uibg09^P^@2GW;P0V9ni0080VZ>l00/0VZ:l09RN^`2JX;d0W:Bn09bS_02JXK/0W::k09bQ_@2LWkh0
WZ7009jS`@0209jS`00;09nU`P2NXl00X:Jn09fT^P2KXKL0WjJk0:6X_@2NY;X0X:Fk0::W_`2QYL80
0P2QY/@0302QYl@0XjS30:>X``2RZ<<0WjC209nV`P2OY/<0WJG109jV`02MY/00WJK209jX`P80W:Fo
00/0XJRm0:6W_02PYK`0WJ>m09fT_`2MXkh0WjNo0:2W_`2QYkh0WZJi09nW^0020:2U]`0:0:2V]`2P
YkT0X:Ri0:6X_02OY[`0X:Jk0:2U^P2MXKH0WJ6e09bQ]P<0WZ>h00`0W:6e09ZQ]@2IXK@0VJ2e09ZP
]@2IWkD0Uiff09FM]P2CW;D0Tifb09BN/@2DWJl209>K/00;096G[P2?UJ/0SiJ[08nG[02;TjT0S9>[
08^CY`2;UZL0RYFU08RDXP26TZ800P26TjD02`24Sj@0Q8nU08F@Z@20S:H0NhRQ07b;X@1kRil0NXZK
07R6V01hQ9L0NHJI0080MhFH00H0MH:C07N6T@1eQ8h0M8B80721P01ZO7LJooooojd0oooo3oooool0
00gooooo00D0IFf:071nW@1bPJD0L82T07B3Y`0307>1Z00;07J5Z@1gQZT0MhNY07N7Z01iQjT0NhZY
07b<Z@1lS:L0OXfV082=YP24TJX00P22SJP01026T:`0Q8j^08B?/@24TKD208:?]00508BA/`25Tk<0
QYBb08RD/@29Tk800P2;U;<0302<U;@0SIRf08bH]`2>V;T0T9Vj08bF]P2;U[L0SIRh096K^@2?VKH0
SIJc08nH]080SiVd00/0TYbe09>M]@2CW;@0U9fd09FM/`2FWK80VJ2d09NM]02IW[H0V9fe09RN]`02
09RN^00;09RN^@2JX;/0W:6n09^P_P2JX;X0Vj6k09fR_02NX[d0WZ6o09jR`02LXKl00P2KXKh00`2M
Xl00W:>n09bR^`0209jU^P0609jV^P2PYKP0XJJi0:6U^P2QXkX0WZ2i0P2OX[`0202PY;l0XZK00:2T
_P2QYL40XJC20:6T``2PXl80XJG30P2PY<003`2QY/00XJNn0::X_02RZ;`0XZRj09nS]`2NX[P0XJFl
0:2U_@2LX[`0WJFm0:2U_`2QY[h0WZ6i09nR^@020:2T^@0;09nQ]`2RY;T0XJBh09jR]`2MXkL0Vj6g
09fS^02MX[H0VIjb09^R]02KXKH00P2JX;H0302IX;D0VJ6f09RO]02HWk40VIn_09VL[`2JWk<0UIbc
09BK/@2CVk00T9N]09BK/080UI^a00/0TYJ]08jCZ@2@UZT0SYBW08jFZP2<TjP0R96T08VDX`27TYh0
QY6M08NCW`0208>=WP0;08F?X024SJ40Q8bT0869Y01mR:<0OXZQ086>X01lR9/0NhNJ07N3UP1ePI<0
0P1hQ9H01P1gPYD0MH6B07>0S`1aP8T0Kh6106UlMQ[ooooo[@3oool?ooooo`003Oooool01P1UKh/0
KgbK07>3Y01dQ:P0LX:V07B2YP80Lh:V00/0N8NZ07V9Z`1kRj`0NHZZ07V;Z01jRjH0O8fU07f=Y01o
SjH0P8fW08:>ZP0207n;Z@0;086=[@23SZl0Q8j`08:?/022T;80PI2`082A[P21TZd0Pi>]08JE[P27
U:h00P27U;00302:U;<0RIFc08VE/`2:UK80RiFa08nH]P2?V;L0SYVf096M^02@Vk<0T9Zc08jG/P80
T9Ze00/0T9Zd09:M]@2@W;<0TIbc08nI/P2DWK@0Uine09NM]P2FW;P0UYfi09NL^@0209VN^P0;09VM
^@2GW;T0VYnl09bR_P2LXkd0W:>k09bQ^@2KX;X0W:>n09^Q_@2JXK`00P2IX[X02`2KXkX0Vj>i09ZR
]P2KY[L0VZJf09ZT]02KX[80WjBe0:2U^@2PY;T0WZ>g0080XJJi00`0X:Bj0::V_P2RY[h0XJG00:6T
``2PY<80XZK40:2T`P2OXl40WZ>o09jV_@2LY;P209fT]P0809fT]`2MXkH0WJ>f09fT^P2MYKd0WJBm
09jU_02MXKP209nS^00809bO]P2OXKT0Wj6i09nR^@2OX[P0X:Bj09jT^@2LXkT209RN]@0409ZR]`2I
Wk@0VJ2c09VQ]@80VJ:g00`0UYjf09BL]02EW[<0Uj2c09NO/@2EWJl0UIf`09FL/`2BV[40T9V_08jE
ZP2@VJ`2092GZ`0;08nEZ@2=TjH0S9:W08R@Y028T:<0RI:S08N@XP27Tj@0QI>Q08BBWP23TI/00P20
SiX02`23TIl0P8fO08:=X021S:80Oh^Q07f9W`1mRId0NhNI07Z4U@1iPi<0MH2B0080MH6D00H0MX>G
0760T@1_Oh`0KX2706YmO`1WO7HJooooojd0oooo3oooool000gooooo00H0Hfn:06mmV`1dP:<0M86V
07>1YP1cP:@207J3Y00;07Z8Z01lRZ/0NXV[07V9ZP1hRZH0MXVU07V:Y@1kRj@0OhfU08:>Z@22SJd0
0P20S:d02`21SZd0P8bX08B@Z`25TZh0Pi6_086@[`21T:d0P96Z08:BZ@23TZP0Q96[0080QI2`00`0
R9>d08bH]P2=V;<0SYRa08jF/02@V;@0SiRg092K^P2>VKP0SYZf08fG/P2@V;42092G/00;09:H/P2@
V;40SIN`08nI/@2AVk<0TYVc09BL]`2FVkT0TiVh09FL^P2FWKX00P2HW[X02`2HW;/0Uibl09VN_02H
W[T0VJ2g09RO]@2KXKH0WJ>h09bQ^@2KXk/0VjBl0080Uing00/0V9ne09ZR]02KX[<0Vj>c09RR/P2I
Y;<0VZBc09ZS/`2MYKH0WjJi0:2W^`020:2V^00<09nU]@2OY;D0Wj:f0:6S^@2PY;`0X:Fm0:2V_P2M
X[/0W9nk09fR_@2LX[d0VJ2h0P2KXkL02`2LY;L0WJBh09jU^P2LXKX0VZ2k09bS^`2MYKT0Vj6f09jS
]@2OY;L0Wj>i0080W9nf00/0Vind09ZN/P2MX;@0WjBf09bR]02HW[<0Uife09NO]02HXK40Uij`09FL
/@0309JN]@80Tifc00T0Tiba09BL/@2AVJl0T9Va08fG[P2=UJT0S9JW08jHY`2>UZH00P2=UJH02`2>
UJD0S9:T08ZAX@2;U:<0R96Q08ZBX@2:TJ<0R92R08FAXP22T9d0P8nJ0080P8jI00/0PHnL086<W@22
Rj00P8VO07j8W`1lR:40OHVO07^6V@1iPY<0NX>E07N1UP0207AoUP0607>1V01^OY40L82<06YlPP1[
OWh0J7ag6_oooon]0?ooo`oooooo000=ooooo`06069]Q@1^NiP0LWjO07>0Y01aOJ<0Lh2T0P1fPj80
2`1ePZ<0N8FW07Z8ZP1iR:P0NHZW07R:Y`1iRjH0NHZU07^;Y@1mRjH0OhbX0080P8bZ00/0P8bY082<
Y@20SJ<0Q92V08B@Z025T:/0Pi:[08>BZP24TjT0QYBY08FDZ@0208JC[00<08JB[P28TZh0RiF^08ZC
Z`2=UZd0T9J`09:G]02@U[H0TINg092F]02?UK40TYRa0P2AV;402`2AUJh0TYR_09>I/P2BV[00SiJ/
09>H/02CV;40TiVd09BJ^P2BVK/0TiZi00<0U9^f00X0U9Zf09BI]`2FWKT0V:2h09RO]@2IWk<0VIjd
09VM]`2FV[P0Uijg0P2GWk@02`2HWk00VIn_09^O[`2JW[40VInb09VQ/P2GWZl0VJ6`09RO/02IX;D0
VJ2g0080V:2f00`0V:6b09^S/@2NY;40X:Fc09nS]@2OXkL0X:Fi09jS]`2LXKH0VZ2e09ZQ^02GW[@2
09JO]00:09NP]@2IW[D0WJ:i09jS^`2IWkL0VZ6i09ZP]`2HWk<0VZ2c09bQ/P<0WZ:f00/0W9nd09ZN
/P2IWK40W9nd09ZN/P2KWkD0V9nf09JM/`2FW:l0U9^]09FL[`0209>J/00<09BK/`2EW;80UIja09:K
[@2?UZX0T9R]092I[`2;UJ`0RY>V08bFY02?Uj<0T9JQ0P2>UJ402`2>UJ<0S9:R08bCX`2;TZ40R92N
08R?W@29Sih0RY:S08F>X@21S9h0OX^K0080OHZG00/0PHfJ0829VP22Rid0PhZN0827W`1lPih0Nh:N
07^3V`1jPIP0NGjG07QmV@0207InV00607=oUP1^OY00K7f706anP`1/P7h0JWeg6_oooon]0?ooo`oo
oooo000=ooooo`06069]R@1]NiT0LH2O07>0X@1bOZ<0Lh2T0P1ePjH01P1cP:@0MhBX07R6Z@1fPjL0
MhJX07Z:Z@80O8bZ00<0O8^Y07f<Z01oSjT00P20SZP02`1oS:H0PXjW08>=YP23SZL0PhjY08:=Z022
SZP0PHjX08:@ZP23TJT0QI>[0080QIB/00`0R9F^08RE[@2:UJ`0RiFZ08nG[@2?UZd0SiF/08jE[P2?
UZl0TIRa08nF/02>UK02092H/`0;092F/02AV[00TYZ_09:I/02CVK00TiVb09BI]02EV[H0U9Zj09BK
^`2EW;`00P2DVkX02`2BV[T0TiZi09:I]`2DW;H0Uijf09NM]02FVk<0VYjf09VM]P2EVkL0Uiji0080
V9ng00/0V9nd09ZO]@2LX;H0VYnc09ZQ/@2IXK00VJ2_09RN[P2FWZh0UYjb09FM]00209NQ]@0309JP
/`2KY;@0VZ6b0080WJ:e00L0WZ>h09jR^@2MX[P0WJBj09bS^@2KXKL0Vj6h0080Vj>h00/0VJ2g09RM
]@2HWKD0V9nf09RO]`2GWkL0VJ2h09NM]@2JX;H0Vj2e09^Q]P0209^Q]@0909^O]02LX;@0WIjd09bL
]@2KVkH0VYbf09VN]@2HW[00Uif^0080UIb/0P2EW:h209>J[P0:09:J[P2BVZl0TY^^08jGZ`2=UZX0
SINZ08^DY@2>UjD0SYBR08jCX080T9FS00/0RY2P08ZAW`2:U9l0S9FP08N?W026SIh0QX^O08R>X@26
SZ40Ph^P08>:X00208:9WP0;0828W020Qi`0PXJN0865WP1oQ9d0O8>M07b2WP1kPYd0N7jJ07QoV`1e
OYX00P1eOiT01P1cOi@0K7Z<06akRP1ZNh<0IgUm06IiN1[ooooo[@3oool?ooooo`003Oooool01P1U
KhP0KgfK0760W`1dPZ80M86Q07=oXP80M86T00/0M82U07J4Y`1fPjD0N8FW07f;Z`1kRZ/0OHb/07^:
ZP1lRj/0OHb[08:A[P02082=ZP0;082<Z`21SJX0Q8nZ08:>Z@21SZT0PHjZ08>?ZP23SjT0Pi2Y08FC
Z`24TJT00P26TZ/02027TZ`0R9>/08^E[@2=V:l0RiFZ08fHZ`2=UJT0S9B/0P2<Tjd03`2?Uk80SiFb
08nF/P2?U[80SIB^08jF[`2@UK00T9F_08nE[`2AUk<0TYRe092F]@2AUkH0TYRg09FK^`0309>K^`0:
09>J^P2DW;X0U9bh09NN]`2HWkH0Uijd09JM/P2FWK<0UIbd09FL]P80UIbg00H0V9ji09NM^02FVkD0
VIne09RO/`2GW[0209FL[@0309FO[`2DW;00V9nf0080VZ:h00`0VJ:h09VP]`2IWkD0W:6f09bP]@2K
WkL0W9nh09jR_@2NY;d0WZBl0:2U^P2MXK@209fQ/`0409^O/P2JWk@0VZ2f09VO]P80VJ2g00D0VZ2j
09VO^@2IW[L0W9nh09ZM]`0209ZM^00;09VK]P2JWK@0W9je09fM]@2KW;H0VYff09JK/02EW:d0UYf_
09FL[`2BVZ`00P2BVj`02@2BVZd0SiN[096I[@2=UJ/0SIJZ08jGZP2>V:/0SYN[08jFY`0208fCY00>
08bAXP2:T:80RY2R08bBY026Sil0R9:M08J?VP28T9h0QhjO08><WP23RYh0QXjQ08>;W`22RYl20868
WP0;07n6W`20QIl0P8BP0824X@1kPIl0NX6N07V1W@1fOi/0MGjH079lU@1cOIH00P1dOiH01P1bOY00
Kg^<06eiRP1ZN8L0J7R206AfNa[ooooo[@3oool?ooooo`003Oooool01@1SKHL0JgRF06imW@1`Oj40
Lh2T00<0LgnS00/0Lh2S07F2Y@1ePZ<0N8JU07b8Z@1mRjX0Nh^W07b;Y`1oSJT0OhbX08:?[002086?
[@0;07j=[P1oRj`0OXZY08B@[@23Sj`0QI6^08B@[P24T:`0QI2/08FB[P25Sj`00P26TJh03029UK40
Qi:^08RC[`27Tjd0R9J]08ZG[P2:U:d0S9F^08ZB[02;U:d0Ri>_08fE/@80S9>^00/0SiJ`092E/P2@
U[80T9Jb096G/P2CV;40U9Zb09FI]02CVK@0U9Ze09BI]`0209>H^00;09>H^@2DV[T0TiZg09FM^02H
WkP0UYbf09FK]@2CVK<0Uifd09JL]02GW[H00P2HW[P02`2HWKT0V9fe09^P]02JWK40V9bb09VM/`2G
W[80UYfa09NN/@2EW;40UYfc0080V9nf00`0VJ2i09ZP^@2IX;T0VYnh09^O]`2LWkL0Vinh09VM^02J
W[P0Vj2f09bO]02KWk8209bN/@0;09jQ]02MXKP0W9nh09bO^02IWKL0VYnh09bO^@2IW;H0VYjg09ZL
^@2JWKP00P2KW[L02`2IW;D0V9^c09VL/P2KWK<0UiZb09JJ/P2DVZl0UIb^09BJ/02DVk80TYV`0080
T9V`00`0T9V_09:J[@2AV:`0SiFZ08jD[02?UZh0S9:X08nEZP2@UJT0SI:X08Z?Y@2;TJH208V?Y00;
08N>X`26SZ<0QHjR08>;W`28SZ<0QXbQ08F;X@25RZ<0PhVR0867XP20Qj400P1nQIl02`1oPil0O82L
07f1WP1kOid0O8:N07UoVP1gOYL0MGbE07=kTP1`NHh0L7Z>0080LGV@00H0LW^@071iS`1]MX`0JWJ8
06MfPP1RLgXJooooojd0oooo3oooool000gooooo00D0Hff706]hUP1^OId0L7nQ07>0Y00307=oX`0;
07>0X`1ePZD0MH:S07R6Y@1lR:T0OH^Z07^;Y`1lRjL0OhfY07n<Z022Sj`00P21Sjd02`1nSJh0Oh^/
07j:Z@24T:d0Phn/08FA[P24T:h0Q92/08F@[025TZh0QHn/0080QY6^00`0RIFa08NB[P28Tjl0Qi>]
08RF[@2:Ujh0RYB]08bE[P2:TZ`0RiB]08^C[`2=UK4208bC[P0;08nF/02@UK80T9Jb092F/P2AUk80
TiRa09BJ/P2EVK@0TiVd09BJ]@2DVKL00P2CV;P02`2CV;T0U9Zi09>J]`2EWKP0V9nh09JL]P2EVkD0
TiVc09NM]02FW;@0Uijf0080V9jh00/0V9fi09RM]@2KX;@0VYfa09RL/P2IWK<0Uijb09JM/@2GW[40
UIba09JM/`0209RO]P0<09VP^@2JX;T0VJ2i09ZO^02KWkL0W9ng09^O^02IWKP0VYjh09^P]P2LWk@0
Vinb0P2LW[402`2NXK@0WJ6h09bO^02LWkP0VIfg09ZO^02LWkT0VIbf09ZN]`2JW;T0VYfh0080Vijg
00/0VIbe09RK/`2IW;80Vifc09NJ/P2FV[80U9Z_09FL[P2DV[00U9^b09:I/002092I/00<092I[`2B
VZd0TIR/08nEZP2>U:`0SiJ^08bBZ02?UJX0T9FY08fBZ02:SjD0Ri6V0P29Sj@02`27SZ<0QXjS08F>
XP23Ril0R8jS08J<X@25Rj40QHZS08>9XP21Qj80P8NQ0080OXFO00/0Oh>O07b0W01mPIh0NgnM07b2
WP1iOiX0MgjG07ElU@1cNi80L7V>071jSP02075iT006079kT01`NHl0KGJ<06YfR01WMX80HW=j6_oo
oon]0?ooo`oooooo000=ooooo`0606EbR`1]NYP0L7jO075nX`1cOjD0LWfT0P1bOJ<02`1cP:@0Mh>V
07R4Y01hQ:80NHFV07V7Z01jRJP0Nh^V07^<YP1oSjT0OhfX0080OXf/00L0Ohf_086?[`1oSZT0PY2X
08:>Y`23T:P0PhnZ0080Q8j/0100QI2^08F@Z`23SjT0PhnY08JA[@27TZh0QY2/08B?ZP27U:`0R9J]
08ZF[@2=UZl0SYN`08fF/02>VKD0RiB`0P2=Uk402`2<UZh0TIRa092D/@2BV;@0TIVb09BL/P2FW;40
UI^`09>G/02EVK@0TiRe0080TiVf00/0TYVf09>J]@2DW;D0U9Zc09JK]02EVk@0TYNc09>I]@2CV[@0
UI^e09JL]P0209FK]`0;09JK^02HW;D0VYje09RM/`2JW[@0Uibb09JM/`2DV[00Tib`09>M[`2FW[00
0P2FW[80302HWkD0Uije09NN]P2JWkH0Uibc09NL/P2JWKD0Vijg09VM]@2HWK<0Uib`09VN/@80VYnd
00/0WIne09^M]P2LWkP0VIbf09RM]@2KX;H0Vj2d09VL/@2IWK80VIbc09NJ/P0209RL/P0;09RM/P2G
W;40V9fc09RL/`2EVk<0U9Zc09:H/02CUZd0TiJ^09BH/@2?UK400P2<UJl0302<UJd0RiBX08jFZ@2>
U:P0T9F/08nD[P2=Tj`0Ri:Z08N?Y02<TjH0S92V08Z>YP80RhjX00/0Ri6Z08R=Z027SZL0Q8^S08>:
X@24Rj40Q8RR08F8Y023Qj@0PXRV07b4X@0207V1W00;07f4V`1mPYX0O86K07YoW01iP9/0Mh6K079l
U`1bOID0LgfE075kT`1`Ni000P1_N9001P1]MXh0JWB=06QdR`1WM8L0IGB1069aNA[ooooo[@3oool?
ooooo`003Oooool01P1SKhT0JgND075nW@1dP:D0M7fU07EnY@80M7bS00/0MWfS07V1Y01kPj@0NX:S
07b6Z01jQZH0NXRW07b;Z01mSJP0NhZV07j=Z00207f>Y`0;07j>Z020T:T0PHnW07n>X`1nSj80Q9>T
08F@Y029TZP0R96W08J?Z027Tj/00P25TJT01027TJP0RI:[08RAZ`27T:d208VB[`0608^D[`2?Uk80
SYJd08jG]@2<UK80S9Bb0P2=U[@02`2=U[<0S9J_08jF/@2>V;80SIR`096J/02CVk00TIR]09:I[@2C
V;00TiRb0080TiVd00/0TiZb09>H/02EV[80TiVb09BI/`2AU[00T9Ja092F]02@UK<0TIRd09>J]`02
09:J^00;09BJ]@2DV[<0UIbc09FL/P2FW;@0V9jf09FK]02DV[40UIj_09FO[P2FWjh00P2FW[40302F
W[@0U9bd09RO]P2GWKD0V9fc09NK[`2IW;<0Vijg09RL]02GWK<0UYfa09JL[P80V9fa00/0VIfb09RK
/P2IW;L0Ui^e09FJ/`2FW;00U9Z/09JL[@2GW:`0UY^^09BI/00209BI/@0;09>H/@2DV;40U9Zc09BH
]02CUk<0TIJa09:G/02CV;00TIF/096E[@2@UJd00P2>UJh0302;U:/0RiF[08bEZP2:TZH0Ri>Y08bB
ZP2;TJT0S9BZ08VAYP29TZ80RXnO08Z=X@80RXjU00/0R8bU08N<Y`23RjD0OhVN082;W@1oQiX0PHVM
0867W`1oQIl0OhRS07b5X00207V4W00;07V3V@1hP9H0NGnH07UnV@1gO9X0MGfL079kV@1`NIH0KWJB
06igT@1]M8l00P1ZLXl01P1ZLY00JG6=06=_R01ULXP0HW6105m_MA[ooooo[@3oool?ooooo`003Ooo
ool01P1VKhD0JG>B06mkV`1bOIl0MGnQ07MnXP80MWZS00/0MWZR07YoY@1hP:<0NX>T07f7Y01lR:<0
O8VS07j:X`1oS:@0OhfW082>Z002082>YP0;07n=Y021SZ@0OHVQ07n<XP1nS:80PY2T08:?X@26T:80
Q8fQ08N?Y`28Sj/00P29TJh0302:TZh0RY>]08VAZ`2:TJd0RXn^08jB]02;Sk80S96b08nE/`2<Tjd0
R92[08jD[`80SYFa00/0SIBb08VA[P28Tjh0QiB]08RE[02=VJ/0TIZ/08nFZ`2AUj`0TIN[096H[002
09:I[007096GZP2CVZ`0TiZ/09FH[@2BUZh0TYR_09BK/@0209>I[`0?09>I/02?UJl0T9Na092G/@2A
VK00TIN^096HZ`2BUjX0TYJY09>H[02CVJh0TiZ]09BK[02BVZP0U9bZ0080U9^/00`0UIZ_09BI/02E
V[40Ui^a09JI[`2GV[00UiV`09NJ/@2FV[00U9Z^09JL[02EVjP209FIZ00;09RK[`2HVk80V9Zc09NI
/02EV:d0UYZ]09FIZ`2FVZX0UIZZ09JIZP2DUJ/00P2DUZh00`2DUK00UYNc09FG/`0209>G/P0609BE
/02DUk00TYF^09:F[P2AUJd0SYBZ0P2=TjT0302>UJ`0SI>Z08V?Y@2;TJH0RHnU08ZAZ02:T:D0RY6S
08bCY02:TJ40RHnO08^=X080RhnR00/0R8^Q08J8Y026RZH0PXNQ0829W`1mQIX0OHBH07b3V01nQ9X0
OXBK07b2V@0207V0V@0;07MoV@1eO9H0MWbG07MnV01eNYP0LWVH071hU`1`N9H0KWFC06acTP1/M9@0
0P1XL8l01P1VKH/0IVn;06E`RP1SKHD0HFn005i]MQ[ooooo[@3oool?ooooo`003Oooool01P1YKH80
KgB@07AjV01eO9X0MgfM07MjW@80MgZQ00/0N7^T07]oYP1mPjD0OXRS07b7X@1kPj00OHJQ07b6X01l
Qj00OhbU082>YP0208:?Y00;08:>XP20S:<0PXbV08>=Y`1oRjH0Pi2X08JBYP28TJD0R92U08V>Z02<
T:h00P2=T[40302:T:h0RY:]08ZAZ`2:Sjd0SI:`092D]02>T[@0Rhn_08^A[`2;Tj`0SYB[08bAZP80
S96Y00/0RXn[08R=Z@24RjL0Q8fV08B<XP24RYl0R8bS08^=YP2<T:H0Ri6U08VAY00208bEY00608jF
Y02?UZ@0T9JV09:HZ02DVj`0T9NY0P2BVZ/209BKZ`0>09>I[@2DVk00U9^`092G[02AUjT0TiZZ09>G
Y`2DV:P0UIVZ09RM[@2EVJX0U9RX09JKZ@2FVjX209JJZ`0<09NJ[P2EUjd0UYZ`09BG[P2EVJl0UYR_
09RJ/02IVk80VYbb09JI[P2FVZ`0UYZY0P2FVJP02`2HVJX0UiN[09NH[P2FV:d0UiZ^09FHZ`2FVJX0
UYV[09JHZP2EV:/0TYBZ0080TiB/00<0U9J^09:C[02BU:h00P2EUk001P2BTjd0TiF^09:C[@2@TZT0
TIBY096CYP80T9>U00`0SI6U08bAY02;T:80S9:R08fCY027SZ40QhfR08V>X`29Sj<0R8fQ08N;W@28
S9d208^>W`0;08R8WP26Qj40Q8JS0825XP1nQ9l0OHFJ07f5U`1nQ9H0OX>G0825V@1mPIL00P1lOiT0
2`1kP9X0NGjI07QmUP1gNi@0M7RC07=hU@1aN9L0KGBG06YbU01/MI<0K7FA0080K7B?00H0J76:06Q`
RP1XKXP0IF^3061YO01OJgHJooooojd0oooo3oooool000gooooo00H0Jfj207IkT`1jPI/0NX2M07b0
WP1jOI`207YkWP0;07eoX`1mPJD0OH:T07n6X@21R9h0OhFL08:8X022RJ80P8VS07n;Y022Sj@00P22
T:802`24Sj40Q8jP08J>X`25S:H0PHRU086:Y024SZ<0Qi6R08V@XP2:SjD0SI2[0080Rhn^0P2;T:h0
2P2:Sj/0S96[08b@Z`2?TZh0SI6`08b@[@2;T:/0SYBY092FZ@2>TjH208fBY@0;08^?YP2:SZT0R8fY
08F<Y024RYh0Q8NK08J7W@25Pid0QH>O08:2W@1nPIT00P1oQYT02`1oQiD0PhVF08F:V028SY/0RY2N
08RAW`2<UJ80SiZV09:MZ02AVjL0U9^Y0080Ti^[00/0SiJY09:JZP2CVjL0Ti^U09FKYP2FVZT0Uib/
09JL[@2BUjP0UI^X09NLY`0209JJY`0<09JHZ@2GVJd0UYZ^09>I[@2AUj/0UIV]09NK[P2FV:/0UYJ]
09BE[02EV:/0UIVY0P2EV:T02`2HVZ/0V9RY09NGZ`2FUj/0UIR[09BFZ@2CUJL0UiZZ09NIZ`2GVZl0
TYF[0080TIBX00X0TYBW09:DZ02CUJP0UIFY09BDZP2BTZ/0UIJ]09>EZ02BUJD0TI>U0`2?TJ<0302<
T:40RY2P08bAX02<TYl0SY>P08jAX@2<SJ80RXbS08J9W`28SJ40Qh^O08R=W`80RXfM00/0RHZM08R8
W`26QZ40PXFQ07n4WP1kPiL0OHBE07f2U@1mPID0Oh:H07n1VP0207aoV@0;07YnUP1iOYD0NGbB07Yl
TP1iNi80MWRB07AgU01`M9@0Jg6B06YaS`1[M8/00P1YLhH01P1YKhD0JVj506IYP@1WJX<0IFUm05aR
L1[ooooo[@3oool?ooooo`003Oooool01P1[KX80MgbA07MmU@1hO9H0NG^F07]nV080NgfI00/0O7nL
07eoWP1oPil0P8FO0824VP21QY/0PHNN08B;XP22RZ40PXbQ08>?X@0208B?W@0;08F@W@24SId0R92R
08F=X@26SJ<0QXjR08Z@X@2;TZ80Ri2T08^@YP2<SjP00P2<SZP0302<T:T0RhnX08^@Z02:SjH0SI:W
08nCZ02=TJX0SI:/08jCZP2?UZT0SiFU096EY080Si6S00/0T9:V08nCZ02?TjP0SiBX08fAY@2>TJ@0
S8fQ08^;XP27Q9l0QXFM08:2V@020822U00607n1S`20PHh0P82?07ioT01lOY00N7f>0P1iOhl00`1i
P8l0PHRC08N=UP0208^BV`0;08fDW@2@VJ00TYZO09>KW`2BVZ40TiVU096GY@2CVjH0T9RS09>LYP2B
VZ800P2DVj40302FVj<0V9^V09BFY@2BUZD0U9RV09FJZ@2FV:T0V9VY09JGZ@2CU:L0TYFV09:FY@80
U9NU00/0U9NT09:DXP2FUJH0UYNX09>FY`2DUjP0UIVX09JJZ02DUZL0UYR[09BGZ`02096EY`08096D
YP2EV:L0TiFS09FEX`2BTZ80UIJU096BXP2AU9l2096DW@0?08jBW02<T9/0S92K08bAW@2:Sid0RY2K
08R>V02;TIL0SI6H08^>V@2:Rid0RHVP08N8W@29RYd0RhfM0080RHZI00/0RHRH08V8V`23PYT0PH6J
0864W01nPYP0Nh6D07b2TP1mPY80OX2D07n1U@0207anT`0;07QjSP1iO8l0N7Z>07MgR`1gMX/0MWJ=
079cS@1bM8h0KG6<06Q^Q`1XKh@00P1YL8<01P1ZKh40JVen06IWN`1UJ7X0I6Qg061WLA[ooooo[@3o
ool?ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`003Oooool01P0@4@T04148014A2P0A4@/0410>01<C4@805AHB00/05aPB01HG3`0F5`l0
61P@01LH400H6Q005a/@01@G3@0D5`h05AL>01HH3`0201PI3`0;01LI3P0E60h051P=01<F3@0A50d0
4aL?01<H400D61004aPA01DH4P0H6Q<00P0H6A<0300I6A<06AXB01TK4@0I6a806A`C01TM500I7A<0
6AhB01XO4`0I7Q806AdA01LJ4@805a/C00/06QhD01XN4`0H6a4061/@01TK4@0J71407AlC01`O4`0L
7AD071hG01/M5P0301`P6@0:01/O5`0J7QH06A`E01XN5@0H71@05a/C01PL4P0I714061/A01XL4P80
6QdC00/06ahE01/O600J7aP06alG01dP600K7QD06QdD01TL500H6Q@06ahG01`O5P0201`P500<01XN
4`0M81H06ahD01/O5@0L81H071lF01hP5P0M7a<071dC01dN5@0M7QH07AhE0P0M7QH00`0K7AH06QdE
01XM5P0201PK5@0601PK500I6a<06a`D01XK4`0I6a8061TA0P0H6Q402`0J71<05QLA01DF4@0E5Q00
5AH>01LG400G5a805ADA01@D3`0F5a805QHB00805A@@00`04A0;01<C2`0C50d04a@<01<E3@0E6@d0
4QL=010E300A50`03a8900hA200>40T200hA2@0;00h?1`0>3PL03a4;00hC400>4Q@03A0G00h>600?
31D03P`>00d>2`0:30T00P0<3P`0200<40h020/=00421@000080004100000@0000<00@050P0000H0
2@0000@0000300000`0000<0000200000@0200400`4100<0000Jooooo`0602lj6P0]>QX0:STL02Xh
8P0Z=bT0:SP/0P0[>2d02`0]>C40;3Pb02hg=P0`>CP0<3Ti034j>P0a>cP0<3/h034m>@0c?CT0<cdj
0080<S`i00/0<c`j03<m>`0c?CT0<S`j03<n?00d?Sd0=T4n03E0?@0e@Sh0=D4l03I4>`0203I3>P0<
03M4?00hASh0>DLo03]9@@0lBd80?D]203e;A00nCDH0?di7041?B010CTP0@4i90P11D4X02`11D4T0
@E18045@B@14DdX0A5=904ADBP14ED`0AUM=04AEB`14E4`0AUI>0080AeM>00/0AeQ>04UICP1:FTl0
Be]?04]LD01<GE40CEiA04aLCP1<GDl0CEe?04]MC`0404eND@0904]LC`1;G4h0BUY=04YJB`1;GDP0
@UDj01DP3P0@60L041H600802a0300@02@d200P<0P0830801`L00P071P0010030`000P<000420000
0P0200<400<00`<000X00`8000D20`050PH01P@600<21@020P@010@200H60@061@402@T30P0;2`D0
2`0>3PP03a49018C2`0D5@d05AH=01DG3@0D5Pd04a<=010@2P0>3@T02`/800<030`800/02@X600L8
0`0620<01PL100D70@031@000`<0008200010P000P<000<3000200D60@0;00L80P051`4010D000H6
0P0:2P@03a0800lA2@0?40X0414;00lA2`0?40/00P0=40X02`0?4`/02`h9004200010`000P<00043
00000P000@40004200000`0000<10080008500H0008900013@0101000P0<00D41`000@0?ooooo`00
3Oooool01P0i@3P0?DDm0419@@11Bd<0>D0m02<X:`806alP00/0724L01LK5@0F6a805a/?01TO400L
8A80720B01dQ4P0M81407B0B01`O4@0201dP4P0;01dQ4P0L8A80728C01XO4`0K81<0724D01XP4`0K
8QD0728G01hS600P8aX00P0O8aX0200P8aX082@H024U5`0P91L07B8E01dS5`0N9AP082PF0P0S:QT0
3`0S:1T08RDH028V6@0R9QT092PJ028W600Q9QL08RLH02@Z6@0U:QX09b`L02H[7@0V:R0092LO02@W
7P0202@Z800;02<Z7@0T;1`09BhL02H]6`0X;Q`09R`M02HZ7P0W:ad09R/L02D[6`0V;1/00P0W;1`0
2`0W;Ad09RdO02<[7@0S:QT09B`J02@[6P0V;1/09R/K02D[6P0Y;a`0:2hK0080:2dI00`0:2lK02T_
7@0U:QT09R/J02HZ6`0U:A/09b/L02X^7`0/<200:blP02`_8@0];b4202``8P0;02X_8P0W;1h09b`K
02L]6`0X;a`0:BlN02``7P0Z;ad0;30P02`^800Y:al00P0Z;B002`0Z;R809RTP02@V7@0S9QX08RDI
02<U6@0V9Q`09BHM028T700R91/08B<I00807R4F00`07b4E028U5P0Q91H08R@E028U5@0Q9AD07b8C
01dQ4P0M81407B4A01`P400L7a4201`P4`0;01/O4P0K7Q806alB01TO4@0I81407bTI00d@3@0<3P`0
30h;00/=2`0:30T00P0A5@h02@0C60l01`T500H70P0620<01@L300@60`061`@01PL500H81@0200D8
1@801@P400H01@L400D81@0520@01PT300H80`0820<Jooooo`06041=A@1EIeH0@U5703I0@@0b>480
=S]:0P0h?dX02`0k@Dd0>Ci=03a1D`0nA5D0?TIF0459F013C5X0AE1L04MBG@18DUd0B55L0080B59L
00H0BE9N04UCG`17DUl0Ae9O04IBG`18Df0204UDH00304]FHP1;EF00CUMO0080C5AM00`0CUMP04mI
HP1=F680CeYS055KH`1AFf@0DEYW059LJ@1DGF/0EEm/05EMJP1FGf`205QQKP0;05USKP1JI6`0FfE[
05aVK01MIfh0GVUa05iZLP1NJW00Gf]`05m[LP1PKG@00P1QKg@02`1SLGD0IgAg06QeN@1XMGP0IWEk
06IeO@1XN7d0J7Uj06UjN@1/NgX0K7]k0080K7]m00/0K7]n06elOP1^O7d0KWek071nN`1`OgP0L7mg
06ioLP1JJ5`0FFQJ05UWF@0205MSE`0<05EQE01EH5@0DEaA03Hj>00c=cD0<3@b02`a;00Y;RP0:BdX
02P/:@0X:bT09bTY0P0V9bL02`0U9bH092LU01<A5`0?31<03PdA00T:3@072@X01`T600P:100930D0
2Pd400802@`300L02Pd400T=1P0;3@H030h600`=1P0?4@T03a8:00803a<;01003a8<00hA3@0>4@`0
3Q4<00h@2P0<3PP02@`500T<0`0930402a0200dA100>4@H03Q8800hC2P0=4@X03A090P0>40T01@0>
3`P030h700T;100:2`D02`h500803Q4800@03A0700/>1P0930@020/40P0:3@D02`0930@01PP100H9
0P062@801PP300H8100930L020/600<50@011@400`D:00800`@D00H00P<F00@460081aL030P;00/8
0`061`4?ooooo`003Oooool01P2DZYH0VK6M09bfX02M^:00SjJ@0419B0804Q@J00/06AdL01<F500?
4Ph03Q89014E2P0E6P`05a`<01LL3@0H70`06Ah=01XO3P0201/O3@0:01/O3P0J7@l06QdA01/N4P0M
81D07R8G01dR5P0M8aP07B8H01dR6@<07B<I00`07R<I01lT600O9AH07bDF01dR5@0N91H07RDE01dU
4`0O9Q@08BHF028V5P0R9AD2024T5P0;028T5`0P8QD07R0C01lR5@0Q9AL082HH028W600T:A`09BTP
02<V7`0R9Qh00P0T:Al02`0S:A/09R/J02L]6@0W;1L0:2`H02/_7@0Y:ah0:2/M02X/7P0Y;Ad0:2`K
0080:2dK00/0:2`L02DZ6P0U:QX09R/K02P_700Z<A`09RhK02@[6P0U:QP09bdH02P]5`0202P^5`0<
02P]5`0W;1L092TE02@X5P0U:AT08bLH02DW6@0W:A`0:BXO02X]8@0/;R40;S4S0P0/<B802`0Z;b00
:2dM02T`7P0Y<Ad0;3<O02hd800^<b00;C4Q02hc8`0_=2D0;C4R0080;S4R00/0;S8T02h`900[;B80
:2XP02P/8@0Y;R40;2lR02`_900W:b009RTL02DX6`0202<U6@0<02DW6P0T:1T08bLG02@V5P0U9aL0
92LG02<W5P0T9QH08bDE02@W5`0S9QL082@F0P0Q9AL02`0O8aL07R8E020S5@0O8a<0724B01`Q4@0K
7a0061`>01DJ3`0E6A405APC00805AXC00/05Q/A01DI3@0D6@`051P=01<F300A50/051L>01LI400F
61404aHA018E4003018F4@0501<F4`0D6A805A/B01@I4@0C5a006_ooool01P0b>4X0=Ca>03@jC`0e
>E00=CUA03DiDP80=caB00/0>3eB03PmD`0i?UD0>3eF03U0E`0k@EP0>D1G03Y0E`0k@UP0?TEK03m6
G0020459G00;049:G012Bed0@DUM0418GP10BEh0@D]P04A<H013Bf00@TYO04E<G`16Bed00P16Beh0
3017CF80BTmU04Y?IP1:D6D0Be1T04aAIP1<DFP0CE9Z04aBJ@1=Df/0CE9[04iCJ@80CeAY00/0D5EZ
051FJ@1BFFT0DeYZ05AKK01EG6l0EUe`05IMK`1GGfl0F5m`05YRLP0305]UL`0:05mXMP1PJGP0H6Yh
05mZNP1NJG/0HFaj069^N@1TKgX0IFmj06I`N`<0IW5l00X0IW9l06QdO@1YM7d0JgIm06agN`1]NG/0
KWal071nOP1aP7l0LH1m0P1dPWd0301ePWh0Mh:007J2P01cOgl0Lh1o07:0O@1bPGX0Lh5h07B0M`1d
OgL0MH1i07AoNP80Lgij00/0L7af071oM00i?D006a/Q01/L7`0A51@03A4>00X=2@0:30@02@`300T<
0P0200P;0@0300H:00031P000`@0008010D000H010@000D60@051`4010D100H70`0720<300H50P0;
00L60`061`<01PP100H90@0?4`P05AX;01PM3P0J81007B<C01`R4`0J81800P0L7a802`0L7Q<061X@
01@E300A4@P03Pl700`=1P0;3@D02P/400L:0P062@001PP0008010H000<00`@00084000210000P03
1@001P051`802@`600X=1P082`800`D000<40P801@D400H01@H400d?1P0D5P/06AX=01HG2`0A4PX?
ooooo`003Oooool01P2G/9h0VkFT09njY@2M^:40VkFM069cI`806AdR00/05ATI01HJ5`0B5Q804aP@
01DJ3P0G7Ph06B0=01PO3P0H7Ph06R0?01`Q4@0201lR4@0:01hP400O8A<07alE01hP600N81T07b4J
01lR6P0N8a/06R0H01/Q60<072<I00`07RDH01dU5`0M9AD07B@C01lU500R9aH08RTF028Y5@0R:1D0
8bPG02@X5`0S9aH202<V5`0;02@W600S9aL08RDF028V5`0R9QP08RHI02<W6@0V:ah09RXP02<W7P0Q
9Q`00P0S:a`02`0U;AX0:2hG02X^5P0Y;1H0:bdI02l`7P0`;b00;2`O030`8P0^;b40;BlP0080;RlO
00/0:B`N02DW6`0U:1`09BTL02P_700Z=1h08b`H02@/600U;1L09bdG02L]5P0202L/5@0<02P]5`0Y
;QX09RXH02DX5`0U:1T09BLK02DV7@0W9al09bLP02PZ8P0[;R@0;C0T0P0[<B802`0Z<B009bhM02L_
6P0Z<AX0:c8K02dc700/<Q`0:S0M02/`7P0]<R40;C8R0080;C0R00/0;c4S030c900]<B80;30T02/_
900Z;b80:c0R02``8@0Z;Ql0:2dL02L[6`0202LY6P0602HY6@0U:QT09b`J02L[6P0W:QX09BLJ0P0T
9QP0100T9AT09BDK028S6P0Q8QT2028T6P0;01lT600N8aH07B8E01lU5P0N9AD07RDF01lU5`0M8QD0
61hB01LM4`0F6Q@00P0E6Q<02`0E6Q405AX?01PL3`0G6Pl05aL>01LH3`0I6A406AXC01PJ4`0F61D0
51LD00804aHC00H05QTE01DH500E6A<05a`D01HK4`0E610Jooooo`03038hB`0c>4l0<cQC0080<cUB
00h0=C]D03DkD`0e>e<0=SaD03HlD`0h?UD0>3mF03PnEP0k@eP0>3mD03U0E@0j@UD0?DEH03i6F`80
@4QK00/0@DYM049:G`12BUh0@dUN04=9G`13BUl0A4]P04A<H@15C680ATeR04M=HP0204Q<H`0<04Q=
I018CFD0BTmV04aAI`1>DFH0CE5U04mDI`1?E6P0CU=W04aDI`1>EFT0D5IZ0`1@EVT02P1BFVX0DEYY
05=JJ@1DFfX0EUe/05IMKP1GGVl0Eem_05UPL01JHW8205aUM@0;05eUM01OJ7D0GfQf065ZN01QJgT0
HVaj069/N@1TKWX0Ifmj06Q`N`1WL7/00P1VLG/02`1VL7T0JG=k06YdO@1YM7h0JWEn06]hOP1]NGd0
KG]l06ilO01_OGh0L7el0080LGml00H0LWmn079nOP1bOWh0LWmo07:0O`1dPWh207F2O00407F1N`1e
P7/0MH1k07N1OP80MGmn00/0M7mk07>2NP16CE00820Y020R9@0G6AX0418@00hA2P0<3PD020`200P<
0`0200T<0`0;00T=0P0520400`D000<400031@0010<000D400051@002@P000`;0`0;2P<00P081P80
3006104020L200L80P061`401@P100dA1P0D60X061`=01`P4@0N8a@07b<E01hR4`807R8A00/07B0@
01XL3P0F5`/04Q<:00d?200;30D02@/500T<1@0930@02@`200H:0@0200@7000600@500031@0010L0
00D80@041P4010H00P072P400`052@000P@00083000200<3000600@3000:2`004A4501@D2@0C4`T0
4A8;3oooool000gooooo00H0SjJD09^eX02P_JD0Wk^S09jkX024WHP203U5@00;01PL7@0I7QX04aTC
014E3P0C60l051X>01LM3`0J8A40728C01`P4`0O8aD00P0Q91L02`0R8aH08R<G024R6`0P8Q/07R0I
01dO600K7aL0728I01/Q600L91L072<F008072@E00`07BHE01hV500P9a@07bDC020W5@0S:AL08RHE
02<W5@0U:AP09BTI02DX6@0T9aP202@X6@0;02@Y6P0U:aX09BXH02DY6@0S9aP08RHH028W600S:1/0
8bPN020V7P0P9Qd00P0T;1d01P0W<1d0:S4J02/a6P0]<1/0;BlL02`]7@80;blQ00<0;S0Q02la900_
<2<00P0_<B802`0];b40:B/N02X/800X;1l09B/J02D^6@0U;AP092/F02H]5P0W;AL0:2hH0080:S0I
00`0:blK02T/700W:Q/09R/L02<Y6`0T9a`08bHL02PZ800X;240:BdR02/_8P0/<R8202X`800;02Ta
800Z<Ql0;3<N02le7P0`=Ql0;c@Q02`_800/<280:c0S02`b900^<RD00P0]<R@0200^=2@0;c<T02hc
8`0^<b<0;S<T02`b8P0]<b40;38O0P0]<Qh01P0]<B00:bhO02/^7`0Z;Al09b`M02L/7P80:2`O00D0
9BXN02HZ7@0W:Q`092LJ02<U6P02028T6@808bHI00/082DF01lV5P0P9QD08RPE024W4`0O91@07b<F
01dR5@0J81D061hE01HM4`0201HL4@0;01HM4@0H7Pl06Ah<01TL300I6Pd06AT?01/M4P0K7Q<06A`D
01XM5P0G6aD00P0F6QD01P0H7AH05a/D01HK4P0G7Q805Q/?01DH3A[ooooo00H0=CY<03DiD00d>E<0
=CYC03DkD@0f?58203PmD`0;03TnE@0i?UH0>T1F03U0E@0i?eH0>d9F03]1D`0j@E@0?DAE03m5E`0o
AUX00P10B5/01`10Aed0@TUN04=:GP14BUl0A4QP04=8H@13BF400P14Bf804016C6<0ADaT04M>I@17
CVD0AdeT04Q>H`19CV<0BdmT04e@I01>DVD0CeAV04iCIP1>E6H0CEAV04iFI`1?EFL2051EJ00;055F
JP1BF6/0DEUZ059JJP1CFfX0EEa[05MNK@1HGW00F5ia05UQLP1JHg800P1LI7<02`1MIG<0GfQd061Y
M01RJgH0HVag069/N01SKGT0IW1i06I_N@1WKgX0J71k0080Ig5k00/0IW1h06QaM`1ZM7P0JWAi06]f
N`1[Mgd0K7Qm06eiO01_Ng`0Lgin07AoP00207F0O`0<07>0O@1cP7`0Lh1n07>1O`1bPGh0M85m07F2
O@1dPW/0Mh=m07R3OP1hPgl0MH1n0P1eOgd02`1dOg`0Lh5j051HFP0P7b`07R0V01TK7@0C51@03Pl=
00`=2@092`H01`T400801`X300/020`200D900031P000P@00083000410001@D000@5000820002PT1
00X90`0200P7100<00D60P092PD02P/300X=0P0930402P`200h@1@0E5`T06Q`<01hP4@0O8Q<082@B
0P0O8Pl02`0N8Pl071l>01LH2`0B5@/03Q8:00/>1`092`D02@`500P;0`0930<02@`400802@d200/0
20X000H900062@001`T100H80@051`0020/000L:00031`000@<000<3000200@2000600@100071P00
3@d4014@1P0B4`P051D<3oooool000gooooo00H0GFUI07V;L`2=YHP0U:jB09ZgV02G]ID205mdGP0;
01XP700@51403a@>00`@2P0>4@/04AD=01DK3`0H7Q406AlC01XO500N8aL00P0P9AT00`0R9aX08RHH
024U6@03020S5`05020S5@0M8A@07R8D01lT5P0N8a@00P0N91<0300O9Q@08BLF02<X600T:AX082HH
028Y6P0R:AT08BLH02@Z6`0U:Q/09R/J02L/6`809b/J00/09BXI02DY600U:QP09BTI02<V5`0P9AH0
7bDG01lU6P0P9Qd082LO02<Z7`0202H/800;02H^7P0W;a/0:S4L02/a700]<Qh0;30O02da800/;ah0
;C4P02hc8`0_<b@00P0_<B402`0`<B00;RlN02d^7P0Z;1/0:BdK02L]6P0T:aL092/F02H/5`0X;QT0
:BlK0080:30K00`0:2lL02L]700W;Ah09R/M02D[6`0T:QT092PF02LZ6P0Z;1d0:R`N02/]7`0/;al2
02X_7`0;02/a8@0/<b40;C@R030g900a=bD0<3@V02lb:00_<bT0;34X02/`9P0[<B@00P0/<R<202`b
900902`c8P0]<b40;S<Q02/a7P0]<al0;cDN030d7`0`<R00;c4Q0080;C0R00`0:blS02T^8@0V:al0
9bdP02@[7@0S;1d092`J02D[600U:QT092LH02<U5`0R91H2028U5`0;024S5@0Q9A<08RHC024V4@0P
9100720A01hQ5P0K7aD06AdF01PO5P0G7Q800P0F71002`0D6Ph05A/<01@J2@0E6PT05AX:01DI2`0H
7A006AhB01TO4P0J81@06b4D00806AlD00H05ahC01LM400F70h05Q`<01LK3@0E60`Jooooo`0603@j
B`0d>4`0=CY@03HjD@0g>e00>Ce@0P0l?e<02`0l?eH0>cmG03TnEP0i?e@0>d1D03e2E00n@U@0?d=D
0496E`12AEX0@TIM0080A4YP1013BV001`13B680A4QQ04A:H@15Bf80A4]R04I<H`17CFD00P18CVH0
3015CFD0AdiT04Q=HP1:CV80C51T04iBIP1>DfH0CE=V04mEI@1?EFH0D5EW051EJ080DUMY00/0DeQZ
059HJP1BFFX0E5a/05AKK01EG6`0F5i_05QPLP1IH780FF5c05]SL`0205aTL`0;05eVM01NJ7@0GfUc
065[M01QK7@0HVef06A_N01TL7P0IG5i06IbN`1WLWX00`1XLgX02P1YLgP0JG=f06]dM`1/MWP0K7Mi
06ahN@1_NWP0L7]i079nO@1cOWd207B0OP80M85m00<0M8=m07:1O01bPW/00P1bPG/01@1dQ7`0MhAm
07R3OP1hPWh0MX1m0080MX5k00/0MH1i07B0N@1OJ6H09RHc01hP:00L828061/J014D4P0<3`d02P`9
00T<1@0200P;0@0500L:0005200010L000@700031@000P03100010041P0020T100T:0P0:30D200X<
1P0<00T<1P093@H02`d300dB0`0=4P802`d100X<0@0@50H05QX901/O3P0N8Pl07bDB0P0N8a40200M
8A0071l@01XM3`0F6a004QL<00lC2@0=3`L02`h50P0;3P@03@0:3P802a0200/@0P0<4@402@d100L;
0@082P801PP100@5000620001PT000<6000110000`010P001P010@000`@000T<100?4@H04A@7018E
2Poooooo000=ooooo`06028X700_=RP0@T`j05ASB@1[PEl0Pime0P1bRf@02`0T:Qh041<>018H3`0?
4Pd03A0<018F3`0E6a005Qd@01TO4P0K8Q@07B@F00807bDG00/08BHG024U5P0Q91L08B@G02<U6P0S
9a/092PK02<V600R91H08RDF020T5002024V500<028W5@0R9QL08RDH028U6P0Q9a`08BTK024X6P0R
:AX08bTK02@Z6P0U:a/09bdJ0P0Y;aX02`0X;AX09BTH02DX6@0U:1T092PJ02@Z6P0T:Q`08RTL02<[
7P0S:Qd08bXK008092`K00/09BdL02D_6P0V;QP0:C4I02X`6@0Z;aX0;30M02/a7P0/<Ql0;38Q02ld
9P02034d9P0;034b8P0a<R40;RhM02h_700[;a/0:BhK02D/600T;1P08b`H028Y600S:aX00P0T;1P0
300V;QX09bhL02L/700W;1`09b`K02H[6@0U:1L0:2XH02`^700[;A`0:b`M02`]7P80:RhO00/0:RlO
02/a800/<R00;S@Q030e8`0b=RL0<C@Y030e:P0^=2P0;C8U02/a8@0302`a8@0:02`b8`0^=R@0;cHS
02le8P0/<Ql0;C<P034e8@0b=1l0<S<P02l`7`80:bhM00`0:blN02P/6`0W;1/09bdK02D[6P0T:aX0
8b/H02<[5P0V;1H09b`I02DY600S9QL202<W5`0;02<V5P0R9QD08B@E01lS4P0M8A406b4A01dR500K
81D06AhD01LN4`0G71000P0G70l02`0C5`/05AT<01DI2`0C5`T04aH801DH2P0G70h061`?01LM3`0I
7a406R0C00806AlC00H05adA01HL3`0D6@/051L701@F200B50PJooooo`0603@kB@0f?D`0>3i?03Pm
D`0h?U<0>SmB0P0l?e402`0k?e@0>T1G03ToEP0k@ED0?49C03e4D`0oAE@0@DME04=:F@13BEh0@dIO
0080A4MR00/0ADUT04I<I@16Bf@0AD]S04I;H`17C6<0AdeT04Q?IP16CVD0AdiU04Q?IP0204Q@I`0<
04I?I`19DFL0BE5T04]AHP1>DV@0Ce9V04iCIP1?EFH0D5MW051FJ01AEVT0DeUZ0P1CFF/02`1DFF`0
DeY/05AJK01DFfd0EE]]05MNKP1HGfl0FF1`05QOL01IHG80G6=c00<0GFId00<0GVQe061[M01RK7@0
0P1QJg<01@1RKGD0I71h06A`N@1ULG/0IW9j0080JG=j00/0JgEl06aeN`1[MGP0JgIh06agN01]NGP0
K7Uf06ilMP1`OGT0LGim079oOP0207>0O@0<07:0O@1dPGd0MH=n07>2O@1ePgh0M8=n07B2OP1fQ7l0
Mh9n07R3OP1hPWd0MX5l0`1eP7/02P1gPW`0J79_02d^>P0T9Bl0828W01lP8@0I6aP04A8?00/=2007
208200D8000400L:00062P0010L000@70@800`D000D010H100D70@092P802P`400/?1@0200`@1@80
3A4800X0310700hC1P0>4`L0310600T<0`0=4@L04QL;01PN400K8A807RDC0P0O9AD02`0L8A<06alB
01/O4P0I7a405ad@01HL400C60`03a@800/@100;40D02Pl40080314400/03A8300/@0P0;3P<030d3
00P:00041@001@D000H700051`0010H00083000200020006000100000P001PP200`?1@0?4`P04QL;
3oooool000gooooo00H08RPL02lf:012C3X0E6=906^1G`23WgD207:;I00;02@Z7P0@4`h04QP?00lB
3@0=40`04QH?01DK400F7A006AlB01/R500M91H00P0O9AL02`0Q9QL08BDF024T5`0Q91L08bDJ02<W
6`0T:1/08bHH028T5P0R9AH082@D00808BHD00`08RLE028V5`0R9AP08RDJ024W700Q:A/08BPJ028Y
6P0S:A/092XJ02D[6`0W;AX202T_6P0;02P]6P0U:AP09BPI02DX6@0T:1X092XJ02@Z700R:A`08b/N
02<Z7@0S:Q/00P0T;1/02`0U;A`09BlJ02H^600Y<AT0:S0I02X_6P0/<1d0:c4N02`b7`0/<R40;c@V
0080<C@V00/0<C8R034b8@0^;Qd0;RlL02/_6`0Y;Q/09B`H02@/600S;1P08RTH02<[6P0202@/600<
02H^6P0W;Q`09b`L02L/700W;1/09R/I02DX5`0X:QP0;2hL02/]700[;1d0;2dN0P0Z;Ql02`0Z;al0
:c4P02`b800^=240<3DS038f9`0a=2T0<3DZ02hd:00]<RD0:c4Q00<0;34Q00X0;38S02hf900_=R<0
;cDR02`b7`0]<b00<CDQ038d7`0b<b00;c0O0P0[;Qd0300[;ah0:2`K02L/6`0W;A/09B/J02@[6P0S
:aP08b/F02H/5P0W;1T09BTH02<V5`808bLG00/08bHF028V5@0Q91D07b<B01dQ4@0K8A407B8D01/P
5@0I7Q@05ahC01LL400201LL3`0;01<G2`0E6@`05AT;01<G2@0C5PP05AP:01LL3P0H70l05ad?01TO
4@0J81<00P0I7a<01P0G7A405Q`?01@I2`0D5`L051H8018D21[ooooo00H0=3]903HmC00h?Tl0>3eC
03PnD`0j?e8203`oD@0;03/oE00j@5L0>CmF03]1E@0l@U<0?DAC03m5E011AeD0@dYI04=9GP13AUl0
0P14Af802`15BF@0ATaU04I;I015Bf<0AT]S04M<H`17CF@0B4mV04I>I@17CVD0B4mV0080B51W00`0
ATmW04UAI`19DF@0Be5R04iBI01?DVH0CU=V04mEIP1@EfL0D5IX055FJ@1CFFX205=IJ`0;05AIK01C
FV`0E5Y/05AKK@1EFfd0Eei^05QOK`1IH700F5m`05UQLP1LHg<00`1MIW@00`1NJ7D0H6]d069/M002
065[L`05069]M@1TL7P0I71i06EaN`1VLWX00P1YLgX02`1[MG`0K7Ek06]eN01[MWP0K7Mh06eiN01/
NGH0KWaf071mN@1aOWd0LWmn0080Lh1m00`0LX1m07B1O@1ePgh0Lh9m07F3OP1dPgh0M89n07J4O`1g
PWh0N8=n07R2O@1fPG`307F0N`0:07N2O01XLVl0;Bhj02@U;`0P8RL07b0Q01TK600A4Pl02`d800L8
0P801@P000@01`X000H:00041`0010L10P031@001@041P401@L100T:0P0:30@02`l5008031050P0=
4@P02P0<40L03Q<600hC1`0<40H02@`300dA1`0B5`/061h@01/Q4P0N9A<201lU5@0;01`Q4`0K7a80
6alB01TO4@0G7A005Q`@01<H300?50P02a0400/@1@0:3`@00P0<4@@02`0=4P<02a0200/>0`0<3@<0
20X000@500051@001PL000D700041P000P<00080008000H0004000020006208030l500lC200B5`/?
ooooo`003Oooool01P0D6@l06AhC01/P5@0K8AD0:2lN03a7;P80@Dld00/09R`L024V6@0L8AH05a`B
01<I3P0E6`l05Qd@01LN4@0I7a<072<E01hT5P02024V600;028V6@0R9aT08RDH028T6P0T9Q/09BLL
02DX6`0T:1X092HH02@U5P0P91800P0Q9A80300Q9A@08RDF02@W6@0S9a/092PO02@Z7`0R:1d08bXN
02D/800U;1l092XL02@[6P809bdJ00/0:BhJ02L[6@0W:QT0:BdM02T]800Y;200:BdO02P^7`0Y;Qh0
:2dK02L]600202H]5P0;02H^600U;AP09RdG02/a6P0/<A/0;2hK02h`7@0^<Ad0;C4N02dc8P0`=BD0
0P0`<b@02`0a<R@0;S0Q02d_7P0]<1h0:RhL02T^6P0X<1X09blL02H^6`0Q:AP07RHF00808BPH00<0
8bXJ02H[6`0W;1`00P0W:ad01`0V:Q/092LI02L[6@0Z;Q/0:blK02X^700[;ad00P0[;Qh02`0[<1d0
;34M02`a7P0/<Ql0;c@R038h9P0b=bP0<3HY030f:00]=2@0:c4O0080;38O00/0;S@Q02lg900^=R<0
;CDR02lf8`0_=B<0;S4R030b800b=240<S<Q030a7P0202l`700<02d_6P0Z;AT0:RhK02X_6`0Z;a`0
:BhL02P]700X;AX0:2hI02T^6`0Y;Qd0:BlM0P0T;1/02`0R:1P08bPG024U5@0O8A<07b8C01lS500N
8Q<07R4C01dP500J7a806Ql@008061h=00/061`;01PJ300H6@d05aP<01HG2`0F60X06A/=01XM3P0G
70h061d@01TO4P0201PM4P0601HJ400D5`h051H<018F2@0A4`L03Q046_ooool01P0d>dX0=C]=03Hl
C`0f?E00=SeA03ToDP80>T1B00/0>CmC03Y0E@0j@UP0?4AH03i5E`0oAeH0?dQF0418EP12BUT0A4]N
04=8GP0204A6H00704I8I@18C6T0B4aX04I;I@18C6@0B4eS04U?I`0204Q?J@0904Q@J019D6L0BU5X
04YAJ019DFP0BU5V04]AI01<DV@0Ce=U0080DEAX00D0DEEW055GJ01AEVP0DUUZ05=KK00205AKKP0;
05=IKP1CFVd0E5Y^05AKK`1EG6l0EUi`05MOKP1HGfh0FF1`05aRM01MHW@00P1NI7D02`1NIgH0GfUg
069[N@1RK7P0Hfeh06A`NP1SKWT0IG1k06EaN`1ULW`0Ig=m0080JGAn00/0KGIo06efO@1YM7/0JWIk
06aiNP1/NWT0KWai06imN@1_OW/0L7mm07:0OP0207N4P00407J2O`1gPh00NHB107N3P080NHB100H0
N8B007V4P01gPWl0NX>007Z3O`1hPGd207N1O00;07J2O01gQ7`0LG]e03/mA@0V9S0092DZ02@V9P0N
7ad05aPC014B300;3@H00P082`8200P<000900T=0`0;3PD020X400D70P041P<01@H300P:100:3@D0
2Pd40080314500`02`l500`?1P0=4PP03Q<:00lD2`0?4`X030l700/=1P0A5@/061hA01`R500O9AD2
020V5`0;01hT5P0M8QD07R8C01XP4`0F71004aT=010F2`0?5@T0314700/@1P0;4@L00P0=4PP02`0=
4@D02a0200/>0P0=3P802@/000H9000520001@L000@700041P000`@000800@8000H0004000410006
208030l500hB200@50X?ooooo`003Oooool01P0>4PX041@=018E3P0D5Pl05aXC01/Q5`807RDI00/0
7B<G01/P500J7a8061h?01LO3P0F70`05Qd=01PO4@0F710061lA01/R4`0201lU5@05028W5`0R9QL0
8BDG024U5`0T9aT00P0U:1X0100U:A/092LI02DY6@0V:aX202@Y600<028W5`0R9aP08bPJ02<X6`0T
:1h09RXO02HZ800V:al09b/O02DY7P0S:1`09R/L0P0X;A`02`0Z;ad0:BhL02P]700X:ah0:B`Q02T]
8@0X;200:BhO02X^7`0Z;Qh0:2dJ00809BXF00/09B/H02T^6`0Y;a/0;38L02hc7P0_<al0;c8O02h_
7P0^;al0<C<S038f9P02034d9@0;03<e9P0a<b@0;S4P02hb8@0]<b40;34O02/b7@0Z<Qd0:C4L02L_
6`0T;AX00P0U;AX0300W;A/09R/K02HZ6P0X;A`0:BhN02L/7P0T:Q/09BdK02P`6`0X;aX0:2lL02Xa
7`<0;34O00X0;30N02da7`0^<al0;S@O02hc800b=RD0<cPY038h:@0_=BD0;38Q0P0/<al01`0/=1h0
;3@P02lf8`0`>2H0<CLV030d900`<R800P0a<R40400_;b00;RlN038c7`0b<al0<30N02`_7@0[;Qh0
:RhM02``7P0Z;Q`0:BdL02X^7@0Y;Q/0:2dK02X_7P0Z;b0202H^7`0;02@[6`0R:AT08bPG028U5P0Q
91D08B<F024T5P0P8QD07R0D01dQ4`0M81<00P0M7a001`0M80l06ah=01PJ300H6@`061T=01PI300I
6`/00P0I70/02P0J7@l05aX>01DI3@0E6@d05QT>01LJ3`0D5``04AD800lB1@0?4@DJooooo`0603<k
C00e?500=SeA03DlD@0h?e80>3m@0P0h?e802`0i?e@0>T5G03]2FP0l@eX0?TEJ03i6F00mA5H0?dIG
0458F@11BE/0@TUN0080A4UR00/0AdYW04Q<J@18CFP0ATaW04M=IP18CVL0BE1W04Q?J@19D6T0BU1Y
04Y@I@0204aAI@0<04]AI01=DVD0C55U04eBI@1>DfH0CeAW055FJ01AEfL0D5MV055GI`1AF6T0DUQZ
0P1AF6/02`1CFV`0EE]/05EJK@1EFVh0EEa_05MOL01HH740FEm`05]QL@1MHW80GV9d0080GFAe00/0
GVMf061YN01RJgX0Hfej069/NP1SKW/0IG1k06IaO01UL7/0IG5k06McO00206]fO@0;06efOP1]MG`0
JW=l06]eO01/MW/0JgQj06ejN`1^Ng/0Kgak0760OP1bOgh00P1fPh001P1gQ840N8>107V3P@1iPh00
NH=o07Z4P080NX>000@0N8=o07Z3O`1jPgl0O8B00P1kQ7h02`1hPg`0MX9j07R4N@1<CTl0928/02HU
:@0S92<0828N01dN5`0E5A00414:008030l600/020/300T<0`0<3`L03Q4:00`>2@092`P01`P700H6
1P082@L02P`800X<1P0200X=1P0<00T<100:3@@03A4700hC2P0@5@`041<:00d>1P082P803A0601HL
3`0L8Q@082LG0P0P9aP02`0P9AP07R<G01dR500K8A<05ad@01<G300@5@X03Q<900`@1`0;3`H02Pl6
00802`l600/020`300X=0P0930002P/000L800051P0010H000D700041P000`@00083000300420005
000200031@002P`200d@1P0>4PT03oooool000gooooo00H02`l700hA2@0>40L04Q<:01DG3`0G71D2
01XO5P806AlE00D06b0E01XP4`0J8A<06R0B01PO400201HL3`0?01XQ3`0L8a007B<A01dS4@0O9A<0
7b@C024T500S9QH08R@F02<U5`0T9QL09BPJ02@X700U:ad092/N008092/M00P08b/L028Y700Q9a`0
8bTM02DY7P0V:Qd09b/N02DX6`809RXK00P09RTJ02X/700X;1d0:2`M02X_7`0Z;ad0:c4O02/`7`80
:RlO00<0:C0O02P_7P0X;Ah00P0Y;Qh202L^7@0:02P_7@0Z<1`0:BlM02X`7P0/<Al0;S8O02/^7@0[
;Qh0;S4Q030c90<0<SLW00/0<cLX034f:00`=BL0;c<U02dc8`0/<R40;3<N02Xd700[<a/0:C8J02Tb
6`0202/d7@0<02/b7@0[<1`0:BdL02X^700Z;Qd0:BhN02P_7@0X<Q`09c8I02H`5`0V<1P0:C8L0P0[
<Ql02`0]<b40;c<Q030e8P0_=240;C8O02db7P0`=200<SHS03Di9P0c>BH0<3HS0080;SDQ00/0;C@O
02lf7P0_=Qh0<CPR034g8`0`=R<0<3DR038f8`0`<R40;RhP02d]7`0302d^7P0;02`]7P0Z;Qh0:blO
02/_7`0[<200;34Q02/_8@0Y;Al0:RhP02/_8P0Y;R800P0X;b002P0X<1l08RTJ01lW5P0O9Q@07bDC
020U500R9aH08BDF024S5P0P8QD301dO4`0;01lQ4P0N8A407Ad>01dN400L7A806adB01TK3P0J70d0
6ad=01XL3P0H6`h00`0F6`h01@0G6`h04aL;010D2@0@50T04A@901[ooooo00<0=Ce>03HoD00f@500
0P0g?e003P0i@540>45C03Q1D`0i@5H0>d=J03]2F`0m@e/0?TEJ03m6F00oAeH0@DUI049:FP12BU`0
A4]N0P16C6802`18CFD0BDiU04M=I016CV@0AdmS04Q?H@19DF80BU9U04]CI`1=DfT0CE9X0080CU=W
00D0CU9V04mBIP1>DVH0CE=V04iEI`02051FJ005051FI`1AF6L0DEQW059IJ01BFV/00P1CFF/02`1E
Ff`0Eea]05QMKP1IGW40FEma05UQL`1KHg@0G6=d05iUM01OIW@0GVEe0080GFIe00/0GfMg065ZN01S
K7T0Hfah06=^N@1TL7T0IW5j06McN`1WLgX0Ig=k06UdO00206YfN`0;06YeN`1/MG/0KGIm06ifO@1]
Mgd0K7Qk06ekNP1aOWX0LX1k07F0OP1bOgl00P1cP7h02`1gPgl0N8>007Z5P@1jQ880Nh>107^3P01k
Ph40Nh>007^5P01jQ7l0NhEo00<0NXAn00/0NH=l07J1N@1hQ7/0E5YI02<O:00T8bL08B4R024R7`0P
8Q/06AXB018C300200lA2`0;00hA2`0<40T030l:00d@2`0=3`X030d800T:1P0820D02@P400X:1`0:
2`P00P0930L030082P@01`T200X>1P0?50X04QL=014E2`0>40H02`/100h@1@0F6`h06R4C01hU5@80
7bHG00/07R@F01dT5P0N91H0728E01PM4@0D60d041@:00dB200<40L02a0600X>1@0200P;0`0;00L9
0P0;3@@02@/000X<00082@001@H000@600051`001PT000@6000210000P020`001P010`00008000<4
00092P40310400`?1Poooooo000=ooooo`0600H90P072`802`h4014D2@0H6a4061`D0P0F6A<02`0F
6A806QhG01`O600K7a@0720D01/P4`0I7a8061h@01PO400I8@l072@A00807BDA00/07bPC01lW500O
9QD092TI02@X6@0U:1T09RPJ02L[700W:ah09b`P02@Z800202@[8@809RdR00X09B`Q02D/800U;1h0
9b`L02L/6`0U:AT09RTH02L[6P0W:QT0:R`K0P0[;Qd02`0[<1l0:blM02`a7P0^=200;C8P02X`7`0W
;Ql0:2lP02X_800Z<1l0:RlQ0080:BlP0P0Y<1h02@0W;ad0:C0N02X`7@0Y;ah0;34O02/`7`0[<200
;C8R030f9@02034g9P0;038h:00a>2P0<3HY034g:`0_=BL0:c8T02Xb800Y<Qh0:C8K02Tc6@0[=1T0
0P0]=A`0300^=Ah0;S@P02ld8@0]<1l0;2hO02/_7`0[<1h0:S4M02Ta6P0Y<aX0:34J02Xa7080;38O
00D0;c<R030e8`0a=R@0<CLT030f8@02030e7P0402ld7P0a=b40<3HP030e8@80<3DS00/0<3DQ030f
800^=1l0;cHO02hd800_=B80<CLS030f8P0`=280;S4Q02h_800302//7@0;02X/7@0Y;1d0:BdM02T]
7P0[;b00;34P02/_7P0Z;Ah0:B`P02T]8@0Z;b800P0Y;Ql0100X;Qd08BPH020Y5@0O:1<201hV4@05
024W500S:AL08bLF01lS500L81<00P0K81<02P0N8Q@07B0C01`N4P0L7Q<06ahD01XL4`0K7A807AlA
01`O3`0I6Pd301TK3@0601TK300I70`061/<01DI2`0C60/04AH;6_ooool01P0g@540=d1B03Q1E00h
@E<0>D5C03]4E@80?4AH00/0>dAJ03a3G00mA5d0?TMM03m7F`0oBEX0@DYJ0419F@12Be/0A4iM04I>
G`0204M=H00504Q>HP18CV40AdmQ04M@H@18DF400P19DV40101:DF<0CE9X04iBK01?Dfd204mDK00<
051DJP1@EFT0D5IY04mDJ01@EfT0DEQY051FIP1@EfD0DUUW059JJ01CFVX0EEe^0P1GGVl02`1HGVl0
Eee_05UPL01KHW80GF9c05aSM@1LIGH0GFEf05iVL`1OJG@0GVMe0080GfQe00H0H6Qh069[N01TKGT0
IG1j06EaN@1VLgP206MdN00306QeN01YMGX0JWEk0080JgEl00/0KGMn06egO@1^NGd0KgUn06mkO`1`
OGh0L7ij07:0N01cP7X0MH5m07B1OP0207J3O`0<07V5P01jQ800NhB107f7Q01nQhD0OHF307j5P`1m
QH80O8J107^5O`1kQWh0NXEm0P1kQWd02`1kQWh0NHAk07Z8OP1PJfD08b4[02<S:00S92H08B@R01lS
7@0K7QH05QP@00804a@>00/04A<=00lB300>40X03@l800h?200=3@D02@/400P800092P802PX400X:
1P0200T:1`0<00L91`0620D02@`800lD300B5`h04QH<00h@1P0:2@403`l501LI3@0K81807B@F0P0O
9QL02`0Q9aT082HI01lU6@0N9AP06R0E01DJ3`0@5@/03A4900/>1`0:3@D020/3008020X300D01`P2
00P:0P072@0020T000H7000200@6000400@7000520001PP000@600800`@000H00P<0000200051`00
30d200h@100<3PD?ooooo`003Oooool01P072P802@`300dA1@0B5`/061d@01TM4@805AL>00/04Q8<
01<F400A50h04QD=01@I3`0G7A406B0B01/R4P0K8Q006b<?01`T3`0201dV3`0;01dV4@0N9Q@07R@F
024V5`0T:AP092LH02DZ6P0Y;ad0:BlN02P^800V;2000P0T:b402P0U;2809RdS02L^8`0V;B409B`N
02H]7P0W;Ad0:2dL02T^6`0Y;QX202L[6@80:RlL00/0;34M02da7@0/<A`0;C8M02``7@0/;ah0:RhO
02T^800[<280:c0S02X^8P0202X_8P0;02/`8@0/<b80:c@Q02Xb8@0W<1d09RhL02Ta7@0Z<Ad0:c4M
02`c7P0_=R400P0a>2@02`0`>2H0;SLT034i9`0c>RT0<CTY02hh9P0/=b@0;3HR02`f7P0Z=1X0;3HJ
0080;3DK00`0;C@M02hd7P0^=1l0;S8P02d`800]<B40;C8R02`b8@0/<b00:c<N02Ta700Z<A`202dc
7P0;02ld800_=B80;cDR030f800a=ah0<3@K038e7@0a=Al0<CHP034g8@0a=R400P0a=b@02`0`=R80
;c<Q02hc800_=200;c@Q034f900b>2D0<CLT030f8`0^=280;30P0080:B`N00@0:B/O02X[800[;B00
:RhO0P0Z;al01P0[<1l0:RhO02X^7`0[;b40:2`O02L/7@809bhM00/09bdL02@/6P0T;AP08b`F01lX
4`0N9Q808RPE02@Y5`0S9aH08RLG024W5`0201dS500;01`R4`0K7a806AdA01PK400G6a405aXA01PK
4P0M8A@07AlD01TJ400G5``00P0J6P`01P0K70/06Q/:01TL2P0F6@X04aL8014D1a[ooooo00H0=ciB
03LoE@0h@5L0>D5G03U1E@0j@UH203Y2E`0;03a3FP0nA5d0?dEN0418G`10BF00@DYP04==H013CEl0
A4iN04M@H016Cf000P17CV002`18Cf40B59R04QAH@18DF40B59Q04]DI01<EFH0CEAW051EJP1?Df`0
CeA^0080CeA]00<0CeA/04mEJP1AEfX00P1@EVT01`1AF6X0DEY[05=KJ`1EGF/0E5a/05ELK@1GGfh0
0P1GGFh02`1HGFl0F5i`05UQLP1IHW80G6=d05eUMP1MIWL0GVMh05eVMP1MIW@0GVMe0080GfQe00/0
HVYg06A[NP1TK7X0I6ik06EaN`1VLGT0Ig=i06QeN01ZMWX0JWEk06]dN`0206efO00;06ifO@1_N7`0
KgUk079kO`1bOH00LGin07>0OP1ePGh0M89n07F1O`1gPX000P1hQ840301jQH40NXF007b6PP1mQh<0
OHJ407b5PP1mQH00OhN307n9P`1oR840OhV107n9P080OHQn00/0OHMm07R4N`1jQg`0K7Q_02h^=P0Y
:Rl0:Bh/028Y900J7aT05Q/D01<D3P02018C3@0;018B300A4@X040l900l>1P0?3`D02`/100P;0@06
2@0020/000P:0P0930D00P0:30H030092`L020X700/>2P0@5@`041@<00lC2@0?40H02PX100X90@0F
60T07B4B020V5`808BLH00/08RHI024V6P0O9AT07RDI01XP500C6@d03a<800`@1P0;3PD02Pd500X<
100200P:0`801`T300H010H000<500010`000P@0008500041P0200D7000900<500021@000PD00043
00020P001@D000/;0P0@4@H03a0700oooooo000=ooooo`0600H90`092`@02Pd400/?1@0=4PH04AD7
0P0D5`P02`0B5@T03A4900P;1@0930H03a@9018H300C60`05Q`>01XQ4@0L8a8072@B00807BDC00/0
7RHF01lV600P:1T08RPJ02<Y6P0R:AP09BdI02Pa6`0X<1/0:30L02P_7P0202@/7P0:02D]7`0U;B00
9R`P02P^8@0X;b40:C0Q02X`7`0[<Ql0:c4O02X_7@80:RlN0P0Z;ad02`0/<Ad0;C8M02ld7@0_=1d0
;S8L02la700/<1d0:2/L02P/7@0[;b00:c0Q00<0:c0T00X0:c4T02dc900/<b<0:S8P02P`7@0X<A`0
:C4K02/c6`0/=1`0;cHO0P0`=b802`0_=b80;CLR030i8`0b>b@0<C/V030k9P0`>RD0<C`V030j8P0^
>1l0<CXP0080<CTP00`0<CLP02le7P0`=Qh0<CDP034d8P0a=2@0<3<T02lc8`0_=B<0;SDP02`c7@0/
<a/202`b6`0;02da6`0`=Al0<3HP030f7@0a=A`0<CDJ03<f7@0e>B80<cPR030g8@0_=R400P0_=b40
2`0`=b40<3HQ02he800`=b40<CLR038h9@0a=b@0;cDR02lf8`0_=280;C8Q0080:RlQ00`0:B/Q02X/
8P0Z;280:RhR02/_8P0Z;b40:BhO02X_800[;b80:c0S02T^800V;1`202L^700;02D[600U:aD09B`E
02H]5`0U;1H08BHB024V500R9AD08BDF024V600P9aT00P0O9aT02`0O9QP07B<E01/P4`0J7A4071lB
01/O4P0L81<07b8F01hP5@0K7A406Q/?00806Q/=00H06Q`<01TJ2@0I6`X06A/:01LI2`0C5@PJoooo
o`0603LmE00h?eH0>d9I03Y2F@0j@UP0?4AF0P0j@ED02`0l@eP0@4EM0416G`10Af40@DUS04=<HP15
CV<0A4iR04E>H@16Cf40ATiQ0080B4mR00/0BU5T04UCI017D680B55R04UAHP19DF@0Be=V04iEJ01?
E6/0Ce=/04mCKP0204iDK@0<04mEKP1?EVd0D5IZ051GJ@1AEfT0DUU/05=KKP1DG6h0EUi_05IMKP1H
GG00FEib0P1HGG002`1IGG00FUib05YPM@1JHGD0G6Af05eUM`1MIWH0GfQf05mWMP1OIgD0GfUf0080
H6Uf00@0HVYh06A[O01TK7d0IVmn0P1WLGd01@1YLgd0JWEm06YfO@1ZMG`0K7Ek0080L7Mn00/0LGQo
071hO`1`NX00LGb2079mPP1cOH00M7n007N2P@1fPX40Mh:107V2PP0207Z4P`0307^5P`1jQ880O8J4
0080O8J400L0OHN407f6PP1nR8<0OhV3082:P`1oRX<0OhV10080OXQo00/0OXUn07^6O01hQ7/0MhAh
03Pj?P0W:2d0;34]024V800F6AD04A@@00hA300300h@2P0:00h@2@0=3`L02``300X<0P0:300020/0
00P<0P0;3P<02@`300X=10802P`400`020/300L90`0;30H03Q48010B1`0>40@030d200T800092040
5AP901`R4`0O9AP2020W6@07020V6@0O91P07R@G01hT5P0I7Q404QH;00dA1P0200/>100?00X=100:
30@01`X300L:0`062@801`T200<500010`000080000100010P000P<000<500041P000`@000800@<0
00H00@8000<300092@803@h5010A200@4PT?ooooo`003Oooool01P041@<01@L300@70@062@0020/1
00/@0P804QL600/04QP8010D1@0:3@802Pd400d@1P0<40H02`d500dA1`0C60`06AhA01`Q4`0201lV
5@0;024Y6@0Q:1X08RXK024Z6P0R:QT082PG028[5`0S;1L092dG02H_6@0W<A`00P0V;ad0300U;1`0
:2lO02X_800[<240;C8R02da8@0^<R40;S4Q02da800]<R00;S<R02hc8@80;34P00/0;3<P02he8@0_
=B40<3DQ02ld800^=200;C4P02`^7@0[;1d0:bhO02X]7`0202/_8@0;02da8P0]<R@0;C8U02dd900/
=B<0;3DR02/d8@0Z<al0:34K02Xc700Z=1h00P0/=Al02P0/=R00;cTR034k900`>b80<S/S03@l9@0e
?BD0<c/T03<j8`0b>B43038i8P0<038g8P0a=b80<STR034f8@0a=B00<cDQ038c8P0_<R80;S<R02le
8P0/<ah0:c4M0`0/<A/02P0`=Qd0;cHN030f7`0`=Qh0<SLN03@i800g?B@0=c/V038g900_=B0202he
7`0;02le7`0a=b40<CPQ030h8@0b>B80<3LQ02he7`0/<ad0:c8N02`b7`0^=B400P0]<b40300[;R00
:RdQ02`_8`0/;b<0;C0R02d`8@0Z;R00:RdP02/^800[<240:c0O02X_7P80:BlL00/09b`F02L/500U
:a<09b/F02P]6P0T9aL08BDG028V600Q9AL082HH01lV6002020X6@0;01lV600M8aD07B4C01lR5@0Q
91D07R0B01`P400O8a807R4B01`P4@0L81800P0J70l01P0H6Pd06Q`?01XL400J70l05aP>01<E2a[o
oooo00H0>D1B03Y1E@0k@UP0?D=J03i5F`0oAU`203m6F`0;03m6G011Aed0@DQP049:H`11BF<0@TYT
04A=I014CF80A4iQ04I?HP18DF800P19DV@02`1<DfD0Be9U04UAI@18DVD0BE9W04UCIP1<EFT0CeI]
051EK`1@E6l0D5E`0080DEMb00`0DUQc05=ILP1CFW00E5]]05=JK01CFf`0EEa^05MOL01HGfl0EUe_
05UOLP1KH7D205YPM00;05YQL`1LHG@0GF9f05eSM`1OIWP0GVIf05eVM@1OJGD0HF]f061ZMP1RK7P0
0P1SKGT02`1TK7X0Ifin06QaP@1XLX00Ig5n06QcOP1ZMGl0JgEn06afO`1^N7l0L7Z000<0LW^300X0
Lgj4079mQ01bOXD0LWf307IoPP1gP840N86207R2PP1iPX80NH>20P1kQH@02`1lQH@0O8F507b6Q@1n
R8L0OhZ707n:Q@1oRH@0OhZ4082:Q021Rh<0P8^200<0PXb300/0PH^107j8OP1lQgd0O8Um04E8B`0U
92/0:B`[02@W8P0I6aL04A8A00l?2`0200h>2@0;00l?2@0?40P03@h600X;10092`@020X200L90@09
2`<02`h500/>1P0;3PD00P092`@030072P802@/400/=1@0;3P@02`h200X=0@0:30402@X000`?0`0H
70d07B<D020W5`8082PI00/082LI01lT5`0P91H07bDF01/O4`0C5``03a8800/?1@0;3P@02P`300P:
0P0200H90`0300D70@0520000PD000<00P<00P010`000`0310001@H000@500020083000600410003
104030l5010D2P0B5``041@;3oooool000gooooo00H00`H600@71@041`4010L000<600072P0300/>
0@0:00`?0@0>4@804144010A1P0@4PP03Ph600`=1P0:30D03Q0801@I30806Ad<00/07R@A024W5@0R
:QL092`H02<[5`0Q:QL08BXH028[5`0U;QP09RlJ02H_700202L_700302L`700Y<A`0:c0L0080;C4O
00<0;C4P02ha8@0`<b<00`0a=B@03P0`=B<0;C<R02dc8P0/<b80;CDR02`e8@0]=B40;SDR030f8P0a
=B<0;c4O02`]6P0[;A/0;2dM0P0[;Ql02`0/<Al0;S<R02ld900^=RD0;3DT02Xd8P0[=240;3DR02/d
800Z=1l0;3HO00<0:cDN00X0;CHP02lh8@0a>R40<c/Q03Dm8`0e?2@0<cXR034h8@0c>B<0<SPR0P0d
>B@0300f>bL0=C/X03Dk9`0b=b@0<SHQ03<f8@0c=B80<C@Q02lc8P0^<b40:c4O02/a7@80:c<L00/0
:c8K02de7@0^=Qh0<CPP030g8@0b>B00<cXQ03<k8`0d>b@0=C`V038i8`0202hd7`0;02ld7`0a=b40
<cXT03<k900b>B80<3LQ02lg800^=Qd0;3<L02he7P0_=Ql00P0]<ad0300[<Ah0;C4Q02da8P0^<R@0
;S8R02la8P0/<280;2hS02d`8`0[<240:blO02T^70809b`H00/092/D02<[4P0S:A8092TD02P/6`0X
;1`09BTL02@X700S9QT082DI01dS600201hT600;01dS600L8QH06b4C01`R500M8a@0724B01XO3P0K
80h0720?01`Q400L81000P0J70l01P0F6@d061`@01LK4@0G6a805AP?014E31[ooooo00H0>d=B03a3
E@0nA5X0@4EL0455G`11AV020458G`0;0459GP11BUl0@d]O04=<HP13C6<0@daR049<G`13CEl0ADiO
04Q@H@1;Df@00P1<E6D02`1=E6H0C5=V04YCIP1;EFT0BUAZ04]EJ`1<EV`0CeQ_059IL01BFG80DUQ`
0080DUYa00`0DUUa05=JLP1EG780EEaa05ELL01FGVl0Eei`05UQLP1HH740Eei`05UQM01JHW<205UQ
L`0;05YSL`1MIG@0GVIe05mVMP1PIWL0GfQg05mYMP1PJWH0HVef069]M`1SKGL00P1TKg/02`1UKWd0
J71o06UaP`1YLX<0JWB306afPP1/Mh00KGMn06ihO`1`NH00L7^20080L7b300/0LWj407AnP`1dOX80
M7j307EnP`1hPH80NH:207Z3PP1jQ8<0NhB307b6Q00207f7Q@80OXR700X0OHR707n9R@1oRhP0P8^7
07n9Q@1oRXH0OhZ5082:Q@21Rh@0Phj60P24SXH02`23S8@0P8Z007f7O@20S7h0E5QG02LT;@0X:Rd0
9RTW01dO700E5A803`l;008030d700/03@h600h?1P0<30@02PT300X8100:2@@02@T200P:0P0:30@0
30h500/=1P0200X=1P0<00P;1@0:30H02P`600T:10072P<02@/300X=0`0:3@40418601TM400O8aL0
8BHH0P0S:1T02`0R9aT08BDH020S5P0O91D06b0B01DI3@0@50T03Q8700`@1P0;3@D02P`5008020X4
00<01@P200<5000110000P0210001P030`000080004300041P001@H000<500800`@000H00P<000<4
000>4@P051T=01DJ3P0B5Ph?ooooo`003Oooool01P0320D00`T300D90@052@000`L0008500800`H0
00/010H000H6000;2P404a8701PJ300G60`04Q8800d?1P0930<01`X200T=0`0200dB0`0;01@J1`0L
8Ph08BTD02D^6@0U;aX09S0M02L_800W<Al09c4N02H`7@0T;AP00P0S;AH0300V<1P0:34H02Xa6@0]
=1d0;S8N02ha800_<R<0<3<V030e:@0`=BP0<CLY030f:080;SDV00/0;CDT02hf8`0^>2<0<STU03<i
8`0b>2<0<CHS030c800^;ad0;c0M030a7`02034b8P0502lc8`0`=B@0<3DT030g9@0_=bD00P0/=R<0
100]=b<0;SPR02lh7`0`>Al202lg7P0602dd700]=1h0;S@O02he800a=b80<c/S0P0b>B800`0a>240
<cTQ038h800203@i8P0<03Ll9P0f>bL0=c`W03Dk9P0d>B80=STS03Dg900b=B80<CDS02hd8`0[<R00
:S4M0P0Z<A/02`0[<ad0:S@M02hi7`0`>Al0;cLN030h7P0a>1l0<3PP03@j8`0f?2H0<cXU0080<3HS
00@0;c@R02db800`=R@0=3`X0P0c>bL01@0c?2D0<CXS030h8@0a>Al0<STO0080;SDL00@0;C<M02hd
7`0_=240;c@T0P0_=2H01P0^<RD0;C4V02/_9@0[;R@0:RhQ02T^7@80:2lI00/09RhG02@[500U:Q@0
9R/G02T]6`0X;1`0:BdN02L[7@0U:A`092LL020S6P0301dP5`0301hR5P0N91H07R@F00807B@G00D0
7B<G01/Q4`0J81006b0A01dQ4P0201`P400601/O3`0I7@h05a`@01LK400E6@d041@96_ooool01P0k
@U<0?4=F03m6FP10Ae`0@DIM0457GP80@DUO00/0?dMO0458H013C640A4eR04A=H`16Cf80Ae5R04QA
G`1:DEl0CE=R04iDI@0204iDIP0904iEI`1=EVP0C5EW04aEJ01=EV/0CUM[04mHK01AFV`0Dea^0080
De]_0P1EG70205EKL00305EKK`1FFg00EEab0080EUeb00D0EUia05MOL@1IH780FF5b05YQL@0205YR
L@0;05]SLP1LIG@0GVEf061VMP1RIgP0HVQh06=[N@1RJgP0I6ih06E_NP1UKGX00P1VKWd02`1ZL7l0
Jg2106abQ01/LhH0KgJ706ieQ@1_N8<0KgV106iiOP1_NGl0LG^10080LWb200L0Lgj207IoP`1fOh80
MWn407IoQP1gPH@0N8640080NhF400X0OHN507n9Q`1oRHL0OhV707n:R@20RXT0OXV9082;S021SH/0
PXb90P23S8P01023SHT0PHb7086<QP21S8D208B?Q@0;08F>Q023S840OhQn086<O`1NHeh09b@^02PY
;P0T9bD06alJ01@G4@0@4`X00P0=40L01`0<3`H03A4700/>1@0;30@02@P300P70`082P<00P092`<0
0`0:30<02P`500X=1@0300X=1@0:00T<1P082`H01`X500P;0`0930<020X200`>1@0F6a007B8F024V
6@8092PI00/08bLI028U600P91H082DE01dR500I7Q005AT<00lD200<4@H02`h400/>1@0200X<1@0:
00L90`041P400`D000840003100010@000830003100010H000@700<00P@000H00P8000<30@0?4PT0
51P>01HJ4P0E6A<?ooooo`003Oooool01P042@@010T300H:0@072`401`X000D800800PD000/00`H0
00L800081P003`h201DD1P0E5PP04Q<600d>0P0;2`002`/100P9000200H7000;00`>0P0D5PT07B4C
02@X6`0Y;b40:S<W02Xd:@0[=RP0:3<S02Lc7`0U<1X00P0T;aH0300U<1@0:3<E02/d5`0/<QT0<3<M
034d8@0c=2D0<S@X030d;00^<b`0;SD/02de:`80;3DY00/0;SLW034j9P0a>RD0<SPS03Dj8@0d>200
=CPQ03Dg800e=R00=SPT03Dg9P0203@e:00;034c:00c=b/0<CHX030g9@0_>B@0;3HS02/d8@0/=B00
;cPQ03<k8@0b>Al00P0b>1l02`0d>B40=3PR03<f8P0b=R<0<CHT03<h9P0c>2@0=3/V03Dm9`0e?2D0
=CdS0080=3`R00`0=ChU03Ln9P0j@BP0>ClV03Lj900f>2@0=SLU03<e900a=2D0;S@U02Xc8`0Y<R03
02Tc7`0:02Td7@0/>1h0;c`M02lk6P0_>AT0<3PJ034i7@0d>b40=C`T03Dl9`80<STV00X0=3TZ038g
:P0_=2P0;cHX034h:@0d?2P0=3dW038m9P0a?2<0<3TP0`0`=ah0300`=al0<3HQ034e8P0`=2@0<3DW
02ld:@0`=BT0;S<Y02``9P0/<BH0:BhQ02P]7P80:30M00/0:30K02P`6@0Y;QP0:BhI02/_6`0/;Q/0
;2`K02/[700[;Ah0:B/N02@T6@02024Q5`0;01lP5P0O8QP07b<I01hT6P0O9A/08BLM024W7P0O9AX0
7BDG01dS5@0N8a<00P0L8@l01P0L8@h06b0>01XP3P0I7P`061/901<F1Q[ooooo00H0?4=C03e5EP0o
AeT0@DUL0458G013BUh20499G`0;0458H`12BF<0A4aS04I?H`15Cf<0Ae1S04YCH`1:Df80CE=R04mE
I@1?EVH00P1@EVP02`1?EfT0CeQY04iHJ@1?F6T0D5QZ055HJ`1BFF/0De]/05AKK@1DFfh0EEe_0080
EEa^00`0EUa^05MMK`1KGg40FUib05QNM01GGW@0EUib05ENL@1GGg00F61`05YRLP1LI7<205eUM00;
05iVM@1OIWL0HFMi069XM`1TJGT0I6Yj06I/N`1UK7/0IVik06I_N`1WKg`00P1YL7h02`1/LH00K7>3
06abP`1]MHD0LGR6071hQ01aNH@0LWV3079jP01bNh00M7b00080MGf200X0Mgj307QoQ01gOhD0N869
07R1RP1iPXT0Nh>907f6R01lQXD0OXN60`1oRHL03020RXP0PH^9082:RP23SHd0Q8j=08F>S024SHT0
Q8j808F>R@24SXT0Phf608>>Q080Q8n300/0Q8j308:<P@21RWl0PHan06Q`J00_;3@0;c0b02PZ:@0M
8Qh051TC014F2`0200lB2@0300`?1`0;3PL02Pd700<02`d800D02Pd500X=100:3@@02Pd400/>1@02
00/=1@0<00/>1P0;3`H02@d500P<1@072`<020`300T>0`0:3@<02`l5018F300J7Q407b@F0P0S9aP0
2`0T:1T08bLJ028V5`0R9aH08BHF01hR500H70l04aL:00hC1`0<40D02`h300802Pd300T02@`200T:
0@0620001@D000H500071P001@D000@300030`000P02100200420006000100041@804aL;01DK3P0G
71405AP@3oooool000gooooo00H01`/300P<100;3@@030l300`=0`0:2`4200P:000700T;00092P00
2@T000X;000:2P0030`100`<000200h=0@0?00`;0@0<2@802@D200T50P081@802PL501DE4P0Q8Qh0
9bXV02Ta:`0Y<b`0:CH[02Tg9`0X=b409c@L00809c@H00`0:CDF02Xe5@0]=AH0;C8H02la700b=B<0
<cHW03<e:@0`<bX0;c@]02de;P0]=bd202dg:P0;030j:@0b?2L0=C`V03Hl900g?2<0>3XQ03/l900j
>bH0>c/X03Xj:P0h>Bh00P0f=bh02`0d=Rl0<cP^03<j;@0b>bT0<C`W02lk900^>240<3TP03<l8@0g
?B80>3`R0080>chV00/0?3hY03Tj:@0h>BX0=cT/03Dh;00f>bd0=Sd/03Dm:@0g?bT0=d4X03Ho9@02
03@m8P0<03Dm8P0h?R<0>ChT03/o9`0j?BX0>C/[03Li:`0c=BT0<CDX02lf:00[=2D0:cDT0P0[=B<0
2`0Z=B00:C@L02Xe6@0/>1L0;SXG030j5@0b>aL0=SdO03Hl8P0f?2D0=clZ0080=cl]00/0=Sh^03@m
;P0b>bd0;cLX02df900_=b40<CXP03<m8@0c?1l0<CXN034h7P0203@i800<03Dh8`0d=b@0=3HV03<d
:00b=R/0<3D/02le;@0^=2/0:c4W02Xa9@0Y<B80:C4Q0P0Y<R002`0X<Ad0:C8L02/b6`0[;a/0;BhK
02h_7@0^;Ad0;bdP02h/8@0/:b40:2PO00809BHO00/08B@L01lR700O9Ad07bDL01lV700P:1d08BTN
01lW6P0N9QH07RDD01hV4P0201`T3P0601`T300M9@h07RD=01hT300M8@`06AX96_ooool01P0k@e<0
?DIF0419FP11B5/0@4MM0458GP80@TYQ00T0@TUS04=<I@15CVD0Ae1T04QBI019DVD0BU=U04aDIP1=
E6D00P1>EfL204mHJ@0;04mHJP1?FFX0CeYY055KJ@1CFfX0Dea[05AKK01EG6d0EUe^05IMK`1FGW00
0P1EFfl0301FG700Eee`05YOLP1JGg80FEic05UPMP1IHWD0FF=c05UQL01JHW00FfAb05eVM080GfMf
00/0HFYg065[N01QJWP0HV]h06=[N01UKGT0IVii06E^NP1VKg/0IW1l06MaO00206QaO00;06]cO`1^
M880K7B106egP@1`NH@0Lgb5079kP`1dNh80MGb107EnP01fOX000P1gOh402`1iPH@0NX6607V1R01h
PHT0NH6:07Z3RP1kQ8X0OHJ:07n8R021RXP0PH^90080PHb800`0PXb908>=RP23SH/0Phf;08F?S@26
Sh`0QXn;08NAR`27T8X0QXn908J>Q`25T8D208B?Q00;08>>PP25Sh<0Phf108:>P01bNg40=cHl03@f
>@0c=cH08R@S01PJ600C5Q400P0>4P/02`0<3`X02`d900P:200:30T02`h:00`?2@0:30D02@/200/=
0`0=3P<03@l300803@h400`02`d500X>1@093P@02Pl400/@100>50@03Q@5014G1`0@5@L041@701LJ
3@0M8Q@2024W600;028X600R9QP08BHF020U5@0Q:1P07bDG01/P4`0F6`l04A@:00dA1P0:3P800P08
30000`0930002`/100T90@0200L6000600P700061@0010<000<300020`000P800P010@001P000P00
0P@100dA1P0C6@/061d?01PL3@oooooo000=ooooo`0600X<1@0<3@D03a0600h@1P0:2`<01`P10P05
1`002`092P402``100X<0@092`001`P000P9000<30003Ph400d<100=2`<02`T300802@D300/02@@7
00P3200<2@h05ADH01dQ8@0T:bL09c8Z02Pd:00W=R@0:3LP02Le700202Te6P0<02/f6@0^>1P0;cHJ
02he7@0`=B00<SHT03<g:@0b=RX0<3H[038g;@0a>Rl0<3X]0P0_>RX00`0a?2L0<3/U03<l900203Y0
9`0603/n9P0l?BH0?CdZ03dm;@0h>Bd0>3X_0P0g>c002`0f>c80=S`a03@l;P0c?2/0=3dZ03@n:00c
?2D0=C`S03Lm8`0j?R@0?3dW0080?SdZ00/0?C`]03Xi;`0i>C40>3Xb03Dj<@0e>c00=Sh_03Do;00g
@RX0>D<X03Y29`0203Ln900<03Ll900h?2D0>S`W03/m:`0l?Rl0?3lb03Pm<@0c>Rh0<SX[034k:@0_
>BL0;SPT0P0/=R002`0/=Qd0:cDI02Tc5@0Z<Q<0:c<D02hg500a>QL0<cTL03<g7`0d>bD0=C`X0080
=3h[0P0c?Rd02@0b?R/0<C/V02li800^=aX0;SLG038k6@0a>AT0<cTL03Hi7`0203Li8`0<03Lg9@0e
=2L0<S4W02l`9`0]<BT0;SD]02Xb;00Z<RT0:C8V02Xc8`0Z<R40:S4P0P0]=B802`0]=240;38N02hb
7@0^;ad0<30O034`8@0a;b<0<BhU02dZ8`0[:R@0:2/V00809BTU00/08BLQ01dS7@0M91`072@J01lW
700O:1X082TJ020Y600O:1@07RLB01lX4@0201hW3P0601`S2P0M90T07R8:01lS300N8@d071`<6_oo
ool01P0lAE<0?TQF0419F@12BUh0@d]P04=<H080@daQ00/0A4eQ04A>HP16DF<0Ae9T04UDIP1:E6H0
BeIW04iGJ@1=EfT0CUQ[04iJJ`0204iJJP80CeYZ00T0D5Y[04mJJP1AFfX0DUaZ05=LJP1CGF/0EUi]
05MNKP1HGW000P1IGg4205UOLP0:05UPLP1IGg80F5ic05UPM`1JHWH0FV=d05YSL@1KHg00GFEa05iV
L`80H6Qf00<0HFYg069ZM`1RJgP00P1SJWT01P1UK7X0IVmk06I^O01WL7d0J75n06UcOP80JGAn00/0
KGEo06ieO`1/MGl0KGN1071jP`1cO8D0M7b507EmQ@1gOXD0N7n507R0Q00207Z2QP0;07^2Q`1lPhX0
Nh:;07Z2S01kPhd0O8B;07b5R@1oQhT0PHV908::R@23S8X00P23SHX03024Sh/0Q8j;08B>R`26T8d0
QXn=08J=R`26SX/0RI2=08V@S027Sh/0Qhn:08N@R@80QI6800/0QI2508JAQ024T8<0QI6107V5N00n
?d<0=STl03Dj>00O8R<06A/J018E4`0200hA3@0;00`>2`0;3@X02@X900X<2@0:3@T02`d600X<0`0:
3@803@h200h>0`0>3P800P0=3P401P0<30403@d200h@1@0A5@P04AL8010F1P8041D600@03a8400h?
0`0D5@X07b4D0P0S9aP02`0R9aP07bDF01hU500M91<082LE01lV5P0K8Q@06Ad@01@G2`0?4`P03103
00802`l100/02Ph000/=0@0:30402@X000T800092@001`P000D60003100010D000<4000200@30006
004200010`003@l601DH300H7Pl061/<3oooool000gooooo00H03Q8:00d@2P0<3`P02Pd500L91005
1`<200@60@0400L:0P0;3P<02Pd200P;008020X000D02P`100d>0`0=30<02PP200H40@0200@2000;
00P5100=2PX030X=00d<4@0C5AT06alQ028Y9`0U;bP09C8V02Hc8`0Y=B400P0[=b00300/=al0;cLM
02lf700_=Qh0;cDQ038e900g>B/0=CL]03<g;P0e>C00=3T`038j;@80<3/[00/0<3/W034m9@0c?RD0
=SlU03Lo9@0h?bD0>ChU03Pk9@0k?BT0>S`/03Xl;P0203Tl;P0;03Ll<00f?300=3X^03Dl;P0e?Bh0
=Ch]03Dn:P0e?2H0=C/S03Pk8`0j>bD00P0k>bL02`0k>BX0>cT]03Ti<00g>C<0<cLb03Dk<P0e?C40
=D0^03M3:`0i@bT0>T<W0080>40U00`0>3hV03Pm:00j?RX0?D0]03ho;`0n@340>d4b03Ln<@0e?Rl0
=3d/03<m:@0a>bD202dg800;02df700/<aT0:C0F02P_5P0Z<AH0:S0E02`c5@0]=1T0;cDM034g8@0b
>2D00P0b>BL02`0b>BT0=3`Z03<k9`0a>R@0;cPP02hg7P0`=a/0<3LJ030f6@0b>1`0=CTN0080=SPQ
00`0=SPT03Hg:00b<RL0;BlU02/`9P0X;RH0:2lW02T`9P0[<bH0;3@U02dd8P0/<Al202db800;02hc
8@0^<R00;S8N02l_700_;ah0;blO02l/7`0`;R80;RdT02`/9@0[;BL00P0W:bD02`0S:24082DM01lV
700M9AX07RDI01lW600N9QL07RHE01lW5P0P9QD082HC00807R@@00<06b0<01`R2`0N8Pd00P0N8@h0
0`0L7Pgoooooooooo`0Hooooo`0503i7D`10BEP0@D]J049;GP13Bel00`14CF002`14CV40AU1S04QB
I@18DfH0BUEX04aGJ@1=EfT0CEQY04iIK01?FV`0D5a/0080D5a[00/0D5YZ04mJJ`1AG6h0D5]^051K
K01BGFd0Dei]05APKP1FH6l0Ef1`05QOL00205QOL@0<05QOLP1JHW80FF5b05YQM01JH7D0Ff9g05]S
N01KHgL0G6Ae05eVM@1NIg@0H6Qe0P1PJWH02`1RJgL0HFYh06A]NP1UK7X0I6aj06=/NP1VKg/0Ig1l
06YbO@1[M7d0JgAl0080K7Ek00/0KWMl06igO@1^MWl0L7N2075iQ01cNhL0M7b607AnQ@1fOhL0MWj8
07MoR00207V1RP0507Z2R`1kPhd0Nh:=07^3S@1lQH`00P1mQh/01020RH`0PX^>08:<SP25SXl208B=
SP0<08B>S`26Shl0QY2@08NAT@26T900QY2A08J@S`28THl0R9:=08RCS@28Th`0R9>;0P27TX`02`26
ThT0QI6708>@Q@23TH@0O8em03/o@P0/;c<0:Rd[01`N700C5Q803Q4<008030l90P0:30L02@092`H0
20X500X=1@0:30<030h300h@0P0>3`803Ph200d<0P0200h>0@0600d=0P0?3P<04Q86014C2@0>4@L0
2`h30P092`40100;2`403Ph301LH300N81<2028U5P0;028U5`0P91H07b@F020T5@0R9QH082HG01/R
4`0I7a405Q`?014F2P0>4`H00P0<4@<02`0<3`8030l100X<0@0;3@402``000X<000:304020/100H9
000620001@L000800`@000H000800042000;30D04aD:01DH300E5`X?ooooo`003Oooool01P0=4Pd0
310<00X<2@082PH02P`800L:1`801@L300/01@P100L90@072@401PP100L90@082P402@/100P90008
20001`H000D4000200@2000;00P60`0E5@h061PE01XJ6`0M7B407b0V028V:P0T;2`09Rl]02Hb:`0W
<RT00P0Y<bD0300Z=280;3DP02de7`0]=1h0;cHP038g8`0e>2L0>3X[03Lh;@0e=bd0=3P^03<h;@80
=3/^00/0<C/[030k:00b?BP0=3lV03Ho9@0f?b@0=clT03Hm8`0i?RD0>ShX03Xn:`0203/o;P0;03Pn
;`0g?Bl0=cd`03Hl<@0e?C00=3ha03E0;`0c?RT0<c`T03Dl8P0g?2<00P0h>b802`0i>b@0>S/W03Xk
:P0i>bh0=cX_03Di;`0e>bh0=d0_03M2;P0iABd0?DP/0080?DLY00`0?4HY03a3:P0m@B/0?D4[03e0
;00n@2h0?T8`03]0<@0k@S80>44`03Do;P0c?2/202lg9@0;02`c7`0[<A`0:2hI02T_6P0Z<AX0:S0J
02/b6P0[<AX0;34L02hc7`0a=R400P0d>BD02`0e>BH0=CXW038h9@0a=b@0<CPT038j900b?B<0<S/P
030i700a>A`0<SPM0080=3TN00`0=CTP03Pj900f>2H0<c@U030c9`0]<2L0:bhU02/_9@0/<BD0;S@V
02le9@0/<b<202dc900;02`c8`0]<b40;C8O02da7P0^<Ad0<34N030^7P0^:ah0<2dP02h]8@0/:al0
0`0[;1l02P0W:Ql08bHL020T6`0O8aT07b@I01dT6@0L91P07bHI01lU600P9AL2020T5P0601hR4P0M
8Q407b<A01hR400M81006ad@6_ooool01P10AeD0@TYK04A=G`15CV00ADeQ04I>H@80ATmQ00/0AU1R
04QAI019E6D0BUEV04aFJ01>FFX0CeUZ055LK@1AG6h0DEa]055LJ`02051LJP0;055LJP1BG6X0Dei]
05=NL01CGg00EF5b05APL@1EH700Ef5a05QRLP1GGg<00P1IHGD00`1KI7@0FfAc05]TM00205]TM@06
05aUMP1MI7H0GFAg05aUM`1MIgP0H6Yh0`1RK7P02`1SK7T0Hfak06E^O@1VKW`0IFml06EaO@1WLW`0
JG=l06aeOP1]MGh0KWIn0080L7Mn00/0L7Uo079kPP1bNX@0LWZ307=jQ01cNhD0M7f707AnQP1fP8P0
N86907N0R@0207R2RP0507Z4R`1kQX/0NhJ;07^6R`1mR8`00P1nRX`01021S8h0Phj@08>=T026T982
08F?TP0<08J@T@28TI40R9:B08JATP26TY<0R9BC08NCT@27Thl0RIF>08ZFS029UHX0RYN;0P2:Uh`0
2`28UHX0QYB908BCR024U8H0P9620498B00S9BT082<S01DH5P0?4Pd03@l8008030h500/020X100P:
0P093@<02@/100X<0P0;3P803A0400hB1@0@4P@04Q86014B1P02014@1@0<00l?100?40H0410700l@
200<3PL02@/400L90P092`<030d4014B1`0G6@d07B4C0P0Q9QH02`0S9aP08RHG024U600Q9QL092TJ
02D[700P9aT07R@F01/R500H7a405A`>008051X<00/05AX;014E1`0>4`D03a8500hB100>4PH04AH9
00lD1`0>4`D03A8400T=0@0200D800060085000210002@/3018D1`0E60/05aP<3oooool000gooooo
00H03A8=00`@300:30T020X600X<20072PL200D70`0;00D80@072@401`T100H80@072@4020X100T;
0@082@0020P000L6000510000P040P002`081P<05AD>01PH5@0J6Q/07AdQ01lP9P0R9RX092`/02H_
;@0V<R/09c8Y0080:C<U00`0:S@R02`e800]=Al0;C@N02lf800b=b<0=CPW03Pj:`0g>2d0=CL]03@h
;P0c>2d203@k;P0;034k:`0`>bP0<SdX03@o9P0f?bD0=SlT03Lo900f?B<0>ChU03Xn:00j?R/00P0k
?bh02`0h?Rl0=cd_03Lm<00f?340=Cd`03@n<@0e@2l0<chY03<l900e?280=c`S0080>3/R00/0>C/T
03Xk9`0j>bX0>C/^03Lj;`0e>Bl0=C/^03M0;`0g@Rh0>DD]03e8;00203e7:@0<03a6:@0l@bX0?D4[
03e1:`0m@2`0?T0^03i2<00k@340>d8b03Q1<00e?bh0<c`[0P0_=bD02`0/<al0:c4L02P^6@0Y;aX0
:S4J02X`6P0[<QX0:c4J02`a700^<al0<CHQ0080=3TU00/0=CTV03Dj9`0b>2D0<CLT034h900b>R@0
<SdS038k800`>A`0<CTL038h7@0203@i7P0<03Di800h>R@0=SPV03<d9@0`<bL0;C0W02/^9@0[;bD0
;34U02hd9P0_=BD0;3<S0P0]<b@02`0/<b<0;C<Q02db7`0]<Ah0;S4M030a7P0`;Qh0;R/N030]800^
;B40;2/O00<0:b`O00X09bXO02<V700P91/07b<I01lT6@0M91T072@H01lV6@0O9AP082DG0P0P91H0
1P0N8Q807B8A01lS4@0N8Q007B0@01/M41[ooooo00H0@4ME049:F`14CEl0ADiP04E=H@16CV4204I?
H@0;04I@HP18DF@0BEAU04YEIP1<EVP0CUUZ04mIJP1AG6d0DEa^055LK@1AG6/00P1@G6X02`1AG6X0
DUaZ05=NK@1CGW00Dem`05EQLP1DH740EF1`05MQL@1HHW80Eemc0080FF5e00<0FfAd05]TL`1KI7@0
0P1KI7D01P1LIGH0GFAf05eTM`1LIGL0GFMh061ZN0<0HVah00/0Hfai06=/N`1UKWd0IVil06E_O01U
LGd0Ig9l06UcO01/MGh0KGEn06ifOP02071gOP0;071iO`1bNh80LWZ4079jP`1cNX@0Lg^507AmQ`1d
OXH0MX2807R1R@1gP8T00P1hPXX01@1jQ8/0NhJ;07^6R`1kQX/0OHR<0080OXZ<00@0PHb>08>>T023
SI00QY2B0P25Si803026T940R96A08RBTP26TI80QY:C08RDT`27Ti40Qi>?08VESP2:UX`0RIF:08ZG
R`80RYN<00/0R9F:08JDR@24ThP0Q9B6082APP12B4P08bDY020S8`0E61H03a8=00d?200200`>1@0;
00P:0@082P802@d300T;0@0:30802`h200d@100>4PD04184018B1P0A4PH00P0A40D0300?3`@03a06
010@1`0?40P030h700T;10072@802@/300`=100A4PL05aT=01dQ4`808BHF00/08bLH028V5`0Q9AP0
8BHG02@Y6P0U:a`082LI01hT5P0K8Q@061lA01DL3P0201@J300;01DJ2`0A5@L03Q<500lB1@0>4P@0
3Q86014F2@0?50L03Q<500dB10093@400P0520001P021@000P@000T;0`0B50L05AP;01LH30oooooo
000=ooooo`0600X>200:3@T020/700P:1@092`H01`T40P0520<02`072PD01`T400L80`092P@01`T2
00H900072@001@P000@600031@000`@000800P8000/00`<000P9100G6Q<0;S@Y03Dk<@0a=C40;30^
02X`;`0[<S40;cPc02`f<00202Pa:@0<02D^8`0U;Ql09BdL02H/6`0X;QX0:S0K02`b7@0_=240<CDW
03<f:P0e>2/0<cP/0P0e>bh02`0b>R/0<3TY030j9`0d?BL0<cXU03@l9@0d?2@0<c/R03@l8`0e?2D0
=SdX0080>3lY00/0=ShY03Dl:@0f?B/0=S`/03Lm;P0g?c00=Sl`03Dn;@0f?R/0=ShX03Hn9`0203@k
8`0;03Dk8P0f>b80=c`S03Pm9P0i?BP0>CdY03Hl:@0e?BT0>48/03]5:`0lABX00P0j@bX0300k@b/0
>T8/03U0:`0g?BT0>3hY03Xo:P0k@2/0>d4]03]2<00j@Bl0>T8`03Hn:`80<3LT00/0;3<P02/a7P0Y
<1h0:BlL02Xa7@0Z<1/0:c4L02T_6`0W;AT0:RlJ02`a700202ha7P0;02lc7P0^=1l0<3HP03<i8P0d
>bD0=3`V03Ho:00f@2P0<chS038l8@0`=ad00P0^=1`01P0`=Q`0=CXP03Hj8P0e=b80<cDT030c9@80
;BlS00@0:blR02/`900]<RD0:c8T0P0Y<B@02`0X<2<0:C4P02Xa7`0[<1h0;C8M02lb7@0_;Q/0;B/K
02/Y6P0/:QX0;RdJ0080:bPF00/0:bTG02TY6P0V:1/092HL028T700Q8a`082@M01hR700N8a`07B<K
01dS600201/Q5P0601`Q5P0M8QD07R<E020S5@0O8AD06adC6_ooool01P13BUT0A4aO04I>H`18D6H0
B4mU04UAI@80Ae5T00/0BE=V04]FI`1<F6H0CEUW051KJP1CG6`0Dee]05ANK`1CGFl0Dei^05=NK`02
05=NKP0905AOK`1EGVh0EEi^05IOL@1FHG<0EV1e05IPL`1HH7<0FF9c0080FV9d0P1LHgH0301MIGL0
FfAd05]TL`1MIW<0G6Ec05aUM01NIWH0GfIg05iVN@1NIg/0H6Yj069[N080Hfai00/0Hf]i06E[O@1W
KH00J6n106M`P@1XLH40JG:106adP01^MH00LGR1075gP@02075hP`0;07=jQ01dOHD0M7b507AkQ01f
O8D0MWb607InR@1fOXP0NH::07V4RP1hPhT00P1iQ8X02`1kQX/0OXV<07f:R`1mRX`0P8b?086<SP20
S8`0PXj>08B?S`25T8l0R9BA0080Qi:@00`0R9:@08VBT@28TY00Qi:B08RETP28UI40RYFA08ZET02;
UY00RYJ>08ZFS02;V8d208VGR`80RIJ900T0QiF908JFR026V8H0CeUC02HY:P0M81h051LD00lB300<
3PP00P0:30@010092`802`d400/>100<3`@200d>100500`?1@0>4@H041@8014B200B4`P00P0A4`P2
00hA1`0:00d?1P0;3@D02`h600X=1P0:3@D02`d400d@100@50L051P;01/P4P808BLF00/08bPG028X
5`0Q9QL08bPH02<Z6@0T;1X08bXI020W5`0M91H07B@E01dU500201hU500;01hT4`0H7@h051P9018F
200B5`X041H;01@I3P0E6`h05a`?01TN3`0A5@P00P0;30<01P061`0010@000L70@0A4`P05aP=01PJ
3Poooooo000=ooooo`0600H:0@072P8020/300X;1009208020P20P0;3@D0200>4@X0418;00l?2P0?
4@X03A0700/>0`092`401PT00P041P003P031@000P<00083000210000@<000L:1P0W<240<S`[03<j
;@0g?c<0=3/a034g;P0e?C40=Clc0P0T:R@0300M8a`06R0F01XO4`0K8A007R<A024V4P0R9Q<09BTD
02/`7@0^=2<0<SPX03Dk:P<0>D4]00X0=ClZ03Ho:00h@2P0=clW03To:00i?RT0>ClY03Pn:@0h?RX0
=chY0P0h?bT02`0h@2X0>3lZ03Po:P0g?bT0>3lZ03Y0;@0i?bl0>3h_03To<00j@2h0>T4/0080=S`V
00/0=S`T03Hm8`0h@B@0>44S03Q0900h?bD0>40W03Lo9`0h@BH0>D8V03]2:00203]2:`0403e3;P0l
@S40>T0`03Ll;080=S`Z00H0=clZ03U1:`0i?bX0>T4[03]3;@0h?bX203@j9P09030g8@0/<Ql0:S0O
02X`7@0[<Qd0;38N02`b7@0Z<1`0:2dK0080:RlL0P0[<1`02`0[<A`0:c8L02he7@0c>R00=3/R03Dk
900f?RL0=chY03Ho:@0e?bP0<c/T00<0<3LO00/0<CTP030g7`0_=B00<SPR034f8`0^<b40;S8Q02`a
7`0Z;ad0:blN02`b8@0202he9@0;02dc9@0/<R@0;C8T02/_8@0/<R00;S@P02hb7`0/;ad0:b/K02TY
6@0Z;1T00P0X:AD02`0V9a<092HD02DW5`0T9QP08R@I024S6P0Q91d08BDN028W7P0O9A`07B<J0080
6b4H00H07B8I01/Q5`0L8AL07R4H01lQ6@0M7QLJooooo`0604E<G@16CV40B59U04UCJ019DVP0BeEY
0P18DVD02`18DfH0C5QY04eJJP1?FfX0DUe]05ANK`1EGfl0EV1a05APLP1DHG40EF9a0080EF9b00/0
EF1b05IPM01GH7@0F65d05MQM01EH7D0Ef1e05YSMP1KI7H0G6Ae05eTM@0205iVMP0<05iWMP1LI7<0
G6Eb05]UL01MIW40GfQd05mXN01OIg/0GfQm061[OP1PK7`0HVek0P1SKWX02`1UKg`0IVio06Q`PP1Y
LH@0JG6206UbP@1[M880K7B206ieP`1`N8D0LGV50080LWV700<0LWV807EmR01eOHP00P1fOHP01P1i
Oh/0NGn>07N0SP1hPXd0NHF>07V6S080NHF<00/0NXN>07f:T@1mRi00OXfA082<T022SI40PXnA08:A
T`24TY<0QY:B08VFU00208ZET`0<08VET`2:UY<0RiNE08^FUP2;UYD0RYFE08bFU@2?VID0SiVC08jI
TP2=VY80S9Z@0P2=VXh208fJS00908^HRP28UhP0RY^8061[H@0/;S007b4R01LJ6@0A51803A4<0080
2`h700D02Pd400lA200?4P/041<<014C2P02010A2004010B200>4@L03Q47010B1`804A<800`03a88
00hA200>4@P030l600/>1P0;3PD02`h400dB100@50D04AH701PM3P0M8Q<2028W5P0;02<X5`0T:AL0
8bPH02@X5`0S:1H08bTG028Y5P0R:1H082HD01hV500O9aD00P0O:1D02`0O9aD07B<D01`Q4P0J7a40
61hA01LM3`0I7`l06b4A01hR4`0S9aL06Q/?00804Q8900H03@d500X80`071`<03@l801<F300F6Pl?
ooooo`003Oooool01P052P801PX100P;0@0:2`802PX100T:0P803A0800/04AD<01DI400E61005ATA
01HJ400C60/0310600P;0`0520401@L000D70@0200@5000;008400031@400`H100/@1P0D6@`07b@E
03]5;`0g?b/0<3HU03Lo;@0g@C000P0M8aX0300G71D041@?00hB2P0?4`P051L901TL2`0L7@h0824A
02T]6`0_=B80=3XX03Lo;080>D8]00/0>44/03Q1:P0j@bX0>d@Y03a4:00oA2X0@DD/0415;@0n@bd0
>d4[03Y0;00203]1;00;03a2;@0n@bl0?T@_03]3;00i@B/0>D4]03]1;`0m@Rl0?44`03e2;`0l@R`0
0P0k@2T02`0i?bP0>T4W03a5:@0lABT0>T@X03U2:00j@bT0>d<X03]4:00kABP0?dL[0080@DP^00/0
@TPb0457=00oAC@0?4<b03Xo;`0f?2X0=chZ03Po:P0g?bL0>T4Y03U1:`0303Y1;P0603Hm:P0_=bD0
;S@S02`c8P0[<al0;3<N0P0`=R000`0]<al0;34N02`a700202`b6`0;02`b700[<A/0:c8L02`c7P0]
=1h0;cLP034i8`0b>RD0=3dW03E0:00g@2P00P0c?2@0300b>R80<CPS034g8`0`=b<0<3PS034h8`0a
>B@0;SHS02de8@0^=B00;C<N02dc7`80;cHU00/0<CPV02dd8`0/<R40:S0Q02`a8@0/<R00;34N02`c
7P0]<al0:blN02X_700202P]600;02L/5`0W:aL09b/I02H[6`0U:AX08bLJ028W7@0S:1d08RTM01lV
6P0N9AT00P0N9AL201dT5P0401lV600P9AT082@I01hP5a[ooooo00H0ATeQ04QAI@19E6T0BEEY04UC
J019EFP204UFJ00;04YFJ@1;EfT0CU][055MKP1BGFl0E5ma05IQL@1FHW80EF9b05ESL@1FHg800P1E
Hg000`1EHW80EV9e05ERM@0205IRM00605EQL`1GHW@0F6Ad05YTL`1KIG<0G6Id0P1LIW<0301LIg40
FVE_05aXL01LIg00GfUc061ZMP1OJGP0GVQi05mZO01QK7l0I6mo06E_OP80IG1o00/0IG1n06E^O`1W
LH80J7>506UbQ01[M8@0K7F606ifQ`1_MhP0KgR906mjR@02071kR@0;071kR01bOHP0LWf907EnRP1g
P8/0Mgn<07N0S`1hPY40Mh>A07V5TP1iQY000P1jR9002`1jQi00O8RA07j;TP1oSI80P8bB086>T`22
T9@0PI6E08>BU@25Ti@0QiBD0080R9FF00@0RIJF08^HUP2:UiH0RYJF0P2<V9L01P2<UiD0SIRD08fI
TP2>VY80SIZB08fLT@80S9Z>00/0S9Z<08bKS@2<VX/0RYR808^JR01^Nfh0<C@g02HX:P0L82405QPI
018C4`0200lA300;00d?1`0F6@l06A`D01HI500B5A0041<;00lB2@0>4@P03A0700d@1P0@4`H00P0A
4`H0300@4`L03Q8700hB200=4PH02`l400/@0`0<4@<04AL601@J2@0D6@T05QX;01XN3`807R8B00/0
82DE024W5`0Q:1L08BPF028X5P0T:AL08RTH024X5@0P9Q@082HE01lV5@0201hV4`0;01lW4`0N9Q@0
8RXG028Y5P0N9A@07RHB01hU4@0N8a0082DD02P]700R9AL00P0K71801P0C50`03Pd800T;200;3@T0
3Q<:010E2Poooooo000=ooooo`0400D81@072PH020`400L90P801PP10P072@@02`0:3@P03a<<018G
3`0E6Q<05adD01DK4@0?50X02Ph400H90004204010H100800`D100@00@D100440@042@8020d30P0:
3P801@0F6``07R8C020T5@0c>RL0?DPc0080;3HW00`08BPM01DH4`0A4`l040l;010@2P0B4``05AH>
01hP5@0W:a`0<3HS03@j:00h?b`203Y3;`0;03U2;@0h@2/0>D4[03Y2:`0lA2X0?dD/0457;`0oAS00
?48/03a1;@0l@Rl00P0m@c002`0oAC40@4Lb03i5<00nAS40?DDa03a5<P0mAS40?dD`03m3;`10A300
?D4^0080?44^00P0>d4^03a3;`0kA2d0?4L^03e7;`0mARh0?DH[03a6:@80?TLZ00l0?dP]0458<011
B300@TLd0498=P12BCL0@TTh03m5=00l@bl0>T0]03Ln:P0e?BT0=clZ03U0:`0k@bl00P0nAS802`0k
@c40=Sd]034i:P0_=bX0;cLW030i9@0_>2D0<3PR02hg7`0^=Ad0;C<K0080;SDK00@0;38J02/a6@0/
<A/0;34L0P0[<1d01@0/=200;cPS034l9P0a?RL0<clX0080<chX00`0<cdV03<n9@0a>bD0;cPR02hf
800_=b40<CTR034i8`0_=R80;SDR02dc800/<B0202hc8@0;02le8P0/<b40;34Q02hc900/<B80:blO
02X_7P0Y<1h0:c4O02/c7P0[<Q`00P0Z;aT02`0Y;QP0:2dG02L/5`0V:aP09RXK02@X700S:1d08RPM
024Y7@0P:A/082PJ00807bHG00H07RHE01hU5P0O9QL082LG024X600P91LJooooo`0304A=HP16D6H0
Ae9X0080BEEX00h0BUIX04YFJ@1:EVT0BUMY04YHJ@1=FF/0DEe^05=OK`1DH740EF5`05IRL@1EHG00
EF9a05MTLP80EfEa00<0F6Ec05MTM@1GI7H00P1FHgD01P1GHg@0F6=c05USM01JIGD0FVEf05YUM@80
FFEd00`0FFIb05QWK`1JJ700GFQb05mYM@1OJ7H0GVQh05iZN`1NJW`0H6]m069]O01SKW`206I^P00;
06I_P01VKX00J76306YbQ@1ZLH@0JW>406afQP1]MXH0KWN706miRP1_NX/00P1`NhX02`1`NhL0LGj7
079nR01dOXX0MX2<07J0S@1gP8l0N86A07R4T`1iQY@0NHJC0080NhNB00/0OHVB07j9T01nRI00P8^B
08:=T`21Si@0PY:E08>CU@24U9@0QYBC08NDT`0208REU00;08^GUP2<V9P0RYJG08bHUP2;V9D0S9ZF
08bJU@2<VI<0S9ZB08bJT02=VXl00`2<VXh02`2>W900Sif>08nKS02<VHT0SI^:07V6NP0m@DD0<3<g
02<W:@0M82806A/L008051HD00/05QPB04MB?P0U:b804A@B014E4P0>4P`030l800/=1P0<3@H03@h5
00lA1P0200h@1P0<00hA1`0=4@L0310700/?10093P802Q0100lF1P0D6`X05ad<01LL300C5PT051H:
0P0J70l02`0N8a@07bHG01lV5`0O9QH082HG028X6@0S:AT08BPF020W5@0P9Q@08BLF008082HG00/0
82LD01lW4`0S:aH092`H028Z5`0P:1H07bLC01hV4@0N91809RdK02H[6`02020U5`0601/N4P0D5P`0
3Q4:00hB2P0<4PP02@d43oooool000gooooo00H02`h>00T<2`0:3@T01`X400@60@0310020084000;
00H80`0:30L03A4;010D3P0B5`l04aL@00hC2P0:3P@01`/000@700041@400P0310402`0210400`D3
00L91@082`@01PT100D70@061`4020/300/>1@0E6Pl08b`L00808BXK00`07RDH01dQ500M81@06Q`B
01LI4P0G61<05QL@01/M5@0R9ad0:c0U030f:@0e?Bd203U1<00703Q0;P0g?b/0=clZ03U0:`0i@B/0
>T4]03a4;P0203i7<00503e4;P0nAC00@4Pc0418<`0oAc400P10BC<02011BC<0@T/d0418<`0oB380
?TH_03m5;P11Ac00?T<_0P0m@c002`0nA380?4<b03e4<00nAc00@4Xb03m9<@0mB2d0?TT/03i::`0n
B2`0?DH^0080?dL_00`0@DTd0458=P15BCT0A4Th04A:=`11B3@0@4Pf03e5=@0h@300=ch]03Lo;00i
@2`203a3;P0;03i5;`0k@Rd0>Cl]03Po;P0g?Rd0=Sd[038j:00`>2D0<3XT02lh8@0_=ah00P0_=Qd0
2`0]<a`0;C@L02hd7@0_<ah0;S8O02`a7P0/<Qd0;3@P02li900_>bD0;c/V0080<SlX00`0<ChX034m
9@0b>b@0;STR02hg800/=Al0;SHQ02hh8`0`>2@0<3LT02dc800/<1h202hb7`0;02la7`0_<B00;c8Q
02d`800^<R<0;C4S02/`8P0Z<2@0:C0R02Ta8@0/<R000P0/<Qh02`0[<A`0:BlI02T_600X;AL09b`K
02DY6`0U:Qd092TL028W6`0R:1/08bTM00808bLJ00H082DG01hT5P0M91D07B@D01hU5P0M8aHJoooo
o`0604A=H@17D6H0B5=Y04UDJ@1;EVX0C5IY0P1;EVP02P1<EfP0CEQX04mIJ@1CGF`0EF1_05EQL@1D
HG00EVAb05MULP1FHg4305ISLP0;05MTM@1GHgH0Ef=f05MRMP1FHWH0F6Af05UTMP1HHgH0FVAi05]T
NP1JI7X00P1JIGX0301IIGT0FFIg05UVM01KIWL0GFMg05eWN01NJ7X0H6Yl05mZO01OJg`0H6el06=_
OP80IFj100/0Ig6306Q`P`1YLH<0JG:106UbP01ZM880JgF406efQ@1_N8L0L7V;071jS@02071kS00;
079mR`1cPHT0MH>;07J2S01eP8h0MX6?07J2T@1hQ9<0N8FD07Z7U01kR9@00P1kQi802`1oRi40P8^?
07n;S`21SI40Q8nC08BAT`25Ti<0QiBE08NDT`29UID0RIFF0080RIJF00`0S9RH08jIV`2=VIX0SYZH
08fIU`2=ViL0SYbG08jLU02?W9<0T9fC096MT@2@W942092MTP0;09:OTP2AWHl0TIf@08jLS`2<Vh`0
PY2304]?DP0h>d00;2lc02L[;00U:2L00P0L7ah02`0I71T0BUQ3028Z8@0A5A404aLC010D3`0=4@X0
30h900`=1P0<3P@03A0500<03A4600/0310500d@1`0;3PH02Pd500X>0`0B60X05ad?01TN400E6`d0
3a@8014D2P0201LK400801`Q5@0O9AP082DI028W6@0Q9QP08RLI02<X6@0R:1L2024X5P0>028X5P0P
9QL082HG020V5P0O9AD08bXI02D]700R:Q/07bLH01hV5P0O:1@07RHA028Y500R:AL201lW5P0601hV
5@0I81404aL<010C2@0=4@L02@d43oooool000gooooo00H04aLL00lD600<4A<020/<00H81`041`@2
00<50P0;00H80`0>4PP041@800dB1P0=4@D03a8900d@200;3PH02Ph400P;0P072@800P061`802`05
1@401PH400P91@0720800`@000<300051@801PL200P:10092`@03A4800803a@;00`041@;018E2`0B
5PX051P;01dR500S:1X08RPI024W6P0S:Qh09blT02`d:00`>RX203@m;00;03Dn:`0e?bX0=d0Z03Ho
:@0f?BX0=cl[03Y3;P0lARl0?4P`03e8<010BS800P11BS802`10BC00@DXb04=;=015C3D0A4`e0458
<`10B3<0@DTa045:<P12BS80@DL`0080@4H`00P0?TDa03e5<@0nAS00?dTa041:<@12CC@0@D`c03i9
<080?d/a00l0@DXb045:<`11BS<0?dXc045;<`12BC<0A4Xd04=9<P13B340@DLb0456=00oA3<0?D<a
03Y2;@0i@2X00`0m@RT02P0n@bX0?d@^0497<P0oA340>cl_03Hl;00b>RT0=3dY03@m9`0c>R<2030h
800;02lf7`0`=al0<3HO030e800^<b00;S@P02`b7`0]<b80;3<S02`e8`0]=R<00P0/=b<0300]>2<0
;STQ034l8`0c?R<0<c`S038j8P0`>280;cLR030h900b>2D0;c@R02/`7P<0;C4O00X0;S4P02d`800[
;Qh0:bdO02d`800/<240;34T02/^8`0/<2@0:S4R0P0X;ah02P0Y<1d0:2hK02P]6P0Y;Q`0:BhM02L[
700U:A/092LK02<V6`0Q9AX3024U6@0601hS5`0M8QH07R@F01`S5@0L8QD06R4D6_ooool01P19Ceh0
Be9T04aEJP1<EV`0BeE[04]EJP80C5IY00/0C5MW04eHI@1AFfP0EEi/05QRL01FHW40EF9a05ITL`1H
IWD0EfIc05ISLP0205ISL`0;05QTM@1IIGD0F6Ee05MSMP1GHWL0Ef=i05QTNP1HIGX0FVAj05]TN`1K
I7`00P1KI7d0301LIGd0G6Ml05eXNP1NJG`0GVUk05iYNP1NJW/0H6Ym05mYO@1RK7l0HVj106=_PP80
I72300/0IW6406MbQ01XLh<0J7>006]fP01]Mh80KWR506miQP1_NXP0LGb<075mSP0207=nSP0;07=o
S@1dPH/0MX><07N3S@1hPi40N8:C07N1U01hQYD0NHND07V7TP1kRI800P1lRY802`1nS940P8jA082=
T@21SY80Q8nC08B@T`24TI<0QY:D08VEU@2:UYL0RiNI0080S9VK00`0SIVL08jIV`2<VIX0SYZJ08nL
VP2@WIX0T9jI092NUP2AWY<0TYjA09:NT02AWY0309>OTP0:09:NTP2AWi80T9f@08nLSP2:UhP0F5eM
03Xj@@0f=S`0;Blb02``<0809RXY00/06QhL020U7`0P9Qd072<I01HJ4P0A5@`03Q<;00dA2`0<3`L0
2Pd300/?0`0200`@100<00`A1@0;40@03A4600`@1P0:30D02@/400dA1`0D60`061`@01PL4@0C5Pd0
41<<0P0F6Q402`0K8AD07bDG024V6@0Q:1T082LH01lV5`0P9aL08BPG020W5P0S:AP09BXH00808bTH
00/08BHG01hT5`0R:A/09RhN02</6`0O:1P07bLG020W5`0P9aH092/G028Y5`02020W5`06024W600K
8A<04AH;00lC1P0=40<02Pd23oooool000gooooo0P0I82H0100H7BD051PP010C6@0<41<200T<3P0;
00`?3P0@51003@l900X<100<3`D03Q4700lB200@4PT03Pl600`=100;2P<00P0:2@<02`0:2@D02PP6
00X92@051@D00`<200810@020P401`P500/>200>4@T030l700802@`500`02Pd600/?1P082`<02@d4
00lD2@0J8A808b`J02Xd800^=b@0<3/X038m;00a>b/2030i9`0;034j9`0b?2P0<CXV038i9@0c>bL0
=3dY03I0:`0g@R/0=d@[03U6;@0mBC000P0oB3002`12Bc<0A4df04A<=`15C3T0A4/g04E<=`14CSL0
ADhf04E?=P16CCD0A4`e0080A4/f00/0@DTd03m8<P0mAc00@4/`045;<@12CC@0@D`d03e:<P0mBc80
?DX`03i9;`0203m;<00<03i<;`0nBRd0?dT]0458<010ARh0@dP`04=8<P13AS80@THb0497<`0oARl0
?TH]0P0nABT02`0k@2@0?D8V0456:`13B2l0@dLa0414<@0nA340?48`03]2;P0h@2T0=CdU0080=3/T
00/0<cTS030e8@0a=R80;c<P02ld800^=1l0;38N02/`800/<R80;cDU02hf900202dg900<02hh9@0^
>B<0;c/Q038n8P0e?b80=ShS03@k8P0`=b40;S@Q02le900`=RD0;S<Q0P0/<Al202`a7@0902`a7P0]
<Al0;2dN02`^7`0]<240;BlS02`_8`0]<b<0:c8R0080:2lP00/0:C0N02X_700Y;A`0:RdM02P[700V
:A`092PJ02@W6@0S9a`07b@J01hT6@0201hT6P0401hT6`0L8QT072<H01TO4`806R0C6_ooool01P1:
DU/0CEAP04mGJ01=EV/0C5I]04]FK080BUEY00/0BeMX04aHI`1@FfT0DEe[05AOK@1EHG00E61a05IR
M@1GIGT0EfEj05ITN@0205MUN080F6Eg00T0F6Eh05QTM`1IIGP0FF=i05USNP1II7P0FfEf05aVMP1L
IWT00P1LIG/0101MIWd0GFIl05mWO01OJ7/2061YNP06065ZN`1QJGd0HV]o06=]P@1RKH80Hfn30P1T
Kh<02`1UL8<0Ig:206UcP`1ZM840K7J006iiPP1_NX80L7^4075lQ`1bO8/0Lgf=0080M7j>00/0M7f>
07F0S@1fP8h0Mh6?07Z3T`1kQ9H0NHBF07V6UP1kR9D0NhRD07b9U00207n<U@0;08:>UP23SiD0PhjE
08:>U025T9H0QI6E08BAU027TiH0R9FG08ZGV02;V9T00P2=VIX0302<V9/0S9VI08bHV02>VYT0SibJ
096NVP2BWiX0TIjI096MU@2BW980TYjB09>OTP80U:2C0P2CX9@02@2AWi40Sif?08nMSP2?W8`0HfMS
03Xf?`0i=cl0<30e02d_<P0202`_;@0:020T8`0L7ad071lK01dR6P0I7A@05AP@010C2`0@4PT03Q06
00/?0`<0310300`02a0300X>0`0<40H02`l600T<100:3@@03a8801@I300H6`l06QdA01LJ400A4`d2
01DH400;01hR5P0S:1X08bPI02<Y6@0Q:1P07bLE01lX5P0P:AH08BPE028Y600Q:1P00P0P9aL02`0O
9QL07bDG028Y6`0U;1`08BXI01lW5P0O9A@07bDF01lT5@0O8QD07R8D00807R<D00H082DF01XQ4P0@
5@X03a@600dA0`082P4?ooooo`003Oooool01P0S:Rl08bX^024X:`0O9BP07B<V01PN80805ATK00/0
51PH014C4`0;30`02PX900`?2@0>4`T03a<900lB2@0=3`H02@`400X<100200/;100;00`=1P0?3P/0
3`h?00`=3@0720T010@500<4100;3P/041@@010D3P0<40X00P0;3PL0300930H02`h700L:10062@80
20/300X=100C60`08RTH02hf8P0d?BL0>D8]03Q0;P80=Sh]00/0=Cd[03<k:P0c>RX0;cHW02dd9`0[
<RL0:cDW02hi:00a?BX0=T8/03Y6;`0203e7<00;045:<`13BSH0@dXh04=;>P14C3X0ADlj04E@>016
DCP0AE0g04E>=P14CSH00P15CcL02`14CCD0@d/c0459<@10BS00@DX`04=<=012BcD0@4Xe045;<`0n
BRl0?D/]0080?dd^0P10CBl02P0oBRh0@DX`0457<013Ac<0@dLd0454<`10AC<0@4Hc03i5;`10B2h2
03m8;00;03i5:011ART0@TLZ0496:`11ABd0@DD`03m3<P11AC<0@DLb03e5;@0j@RX00P0h@2L02`0g
?BH0=3TT02le8@0/<Al0;C8P02ld800]<Ad0;34N02`a7`0^=B<0;cLU0080;SLV0P0^>BL02P0^>B@0
;SXR034l8P0d?R<0=CdS038i8`0_=B80;C<Q02le900_=2<202hd8P0902hd8@0]<b00;34O02/`7`0Z
;B00:R`O02X]800/;R80;34Q0080:c4P0P0Y;Qd02P0Y;a`0:c4K02/`6`0Y;1X09bXK02HZ7@0S9QX0
8B@H020U6P0O9AX301lV700601hU6P0L8aL06b8D01XQ4P0K81406Qh>6_ooool01P15CUP0BU9N04iG
I`1>EVX0C5IZ04aGJ`80BeMZ00/0CEYZ04iIJP1?FF/0D5Y/05=NK`1DHG40E61a05EQM`1FHWX0EfAm
05MUO00205QUN`0;05MSNP1FHgT0EfAj05QUN01IIGP0FVEh05]TN@1KHgP0G6Ee05]VM@1LIWL00P1L
IWT0201LIgX0GVMk05iWN`1PJG`0HV]k069[O01RJWh0HFYo0P1TKH803`1SKX<0I72406MbQ@1WLXD0
J7:506UcP`1[MH<0JgF206agP@1]N840K7N106mjQ@1bO8X0M7b=07AmT00207EnTP0;07J0TP1hPI<0
N82C07V2U@1lQ9L0O8BH07^4U`1lQiL0O8NF07f8UP1nR9H00P20RYL02`22S9H0PXfE08>?UP24T9L0
QY6G08NCUP27U9L0RIFH08VFV02:UiP0S9RI0080SY^K00`0SIZJ08fIV@2>VY/0SYbK08jLV@2?W9T0
T9fI09:MV@2CWYP0UInG09BOU`2DXIH209>PU@0;09:PUP2BWi@0TIjB092OT02@WXd0T9n;075jKP13
@dD0?cm3034`=P0/;S400P0[;R/02`0R9B807QlL020R7P0S:2007bDK01TO500D5P`04A8800l@1P0<
3P@030l30080310300`02a0300`@100<40P0310800d@200?4PT04AD;01@H3@0F6@h05QT=01@G300A
4`X201HG3@0;028V600U:A/092TJ02<X6@0Q:1P082PG020X5P0Q:QL08BTF028Z5`0P:1L00P0N9QH0
2P0N9QL07bHH020X6P0Q:A/07bLH01dS4`0J8A006Al?01PM3`0G6`l301DH3@805AX>00@04QH<00hB
200;3`@01`/13oooool000gooooo00H08bT^02H/<00T:b`08RTX02<Y9`0T:RL2024W9P0;020V9P0I
7Al04aHH00lA4P0>4@l041@>014F2`0@50P03A4500X>0P0930<00P0<3PD02`0>4@H03Q4900h@300=
3`d03@l>00T92@072@L03Q8=01@G4P0A5Pl0310;008020/400`01@L100H80@072@801`T200L:0P06
20402`l601<G300L7a<08B@G02LZ7P0d>b/203a4<`0;03e7=00kA3<0=d0a038k;P0[<bT09B`S024X
7P0M8a/08b/O02di9`0d?b/00P0jABh02`10BS80@dde04=<=P11BCH0@DXg0419=P11BSH0@d`g04E?
>015CcT0Ae8l0080B5<j00/0AU0f04A<<`14C3<0A4`b04=:<015CC@0A4de04A==`14CSL0@T`e045<
<P02045<<00<049<;`12CBl0@DT_04=8<013Ac<0@dLf04A8>013AcP0@dPh0498=P11BC@0@T`b0P13
CC802`13C300A4`^04A;;015BBd0@DD/03e2;@0m@S80?D@d03e5<@0lABh0?4D]0080?4@[00/0>40X
03Hm9P0b>2<0<3DS02hb8@0]<B00;S8P02lc8@0_<b80;cDT034i9`0202hh9P0<02`g9@0_>RL0;cXW
02li900]>280<3/R03@m900c>b@0<cPT03<h9P0_=BD0;S@T0P0`=RD01@0a=bH0<3HT02dc8@0[<200
:RlR0080:2dQ00@0:S0S02`b8P0/<R00:c0O0P0Y;Q`02`0Z<A/0:c<K02/b6P0Y;AP0:BXJ02LY7@0T
9Q/092HL02<V700O8aX082HL00808BHL00H07RDI01dT5`0N8a@07B8A01dQ400K7PdJooooo`0604I?
F@19Df00CEQW051KJ`1@FV`0CUU/0P1;Ef/02`1>FFd0Ce]^059ML01BGW00Df1`059PL01CHG40E69c
05ERM01FI7L0EfEh0080EVEh00/0EfEh05QUM`1HIWP0FFIi05QUN01JIGX0GFIl05iVO@1MIGX0GFIi
05eVN00205mXN00<05mYN@1PJg/0H6Uk061YO@1RJWh0Hfao06=/P01PJX40Hff406E_Q@1ULHL0Ig:7
0P1YLhH02`1ZLhD0JW>406egQ@1]MhD0KGR606miR01_NHX0L7Z<07=lSP1dOI40MGjD0080MWnD00P0
MGnD07IoT`1hPI<0NX:D07^3UP1lQID0OHFG07n8V080P8VJ00h0PHZH086<V021S9P0PhfH08F>V025
T9T0QY2I08JAV@28U9T0RIJK08ZFV02:UiT0RiRI08fJV`80SifM0P2>WId02P2>W9d0SYfM092NW02@
WYX0TInJ09>OW02DWi/0UJ2J09FPV02DXIP209:PV00;09:PU`2@X9D0T9nC092PT@2AX8d0Tj>=07V5
MP19C4/0ATU7034b=00[;Rh00P0[<2X02`0U:b@08BDM02HZ800W;B8082HK01LK4@0B5@X04187010A
1P0?4@L03A4600803Q<500`03A8400dB1@0>4`P03A4:00lC2`0B5P`04QH;01<G2`0B5P/04QL:014F
2P0@50T2018E2@0;01hQ4@0R9aL09BTI02@Z6@0U:QT092XI028Z6@0T:aX08RTH02@Z5P0T:AL00P0Q
9aL02`0O9AP07RDH01`T5`0K8QD06R4C01LM400D6P`04QP:014E2@0?4`T03Q4800803A0800H03A88
00lD2@0A50/04A<:00d@1`082`<?ooooo`003Oooool01P0X;C00:Bhb02H[;P0T:BT08bPW02H[:@80
9R/Z0P0T:R`02@0P9RP0724R01LL6`0F6aD04QL=00dA1P0;3P802`l300/>100200`@1@0;00lB1`0?
4@P030d800T;1`0:2`X02``:00d?2P0A50d051P?018G300@50X00P0;40@030072P001PT000L90@08
2@<020/400P;1@082@H02`d:010C400D5Q<05APE024U7P80=3d_00/0?4Hd041;=`11C3T0>48a02`d
9P0V;B007R@J01LK5@0E6A<07B<J02H]8@02030j:P0;03Q4;`0oBS<0@4/c03m8<P0oB3<0?dLc0418
<`11B3D0@dXh04E<>P15CSX00P14CcP01014CcH0@Thd04=>=013CS8204A=<00504I><`16CC@0A4`d
045:=011Bc@00P12C3<02011Bc40@4Xa045;<P14Bc@0AD/f04A9=`14B3H0ADTh0P16BcX03015C3P0
@d/f049;=@12BcD0@d`d04A><P13C2l0@TT^0455;00l@BX0>cl/03To;P80>T4`00h0?4@a03]3;`0k
@bl0>40]03U1;P0h@2`0=C/Y034f900^<b40;cDQ02lf800_=B40;S@R030g9080;cLU00/0;SPT030k
9@0_?2<0<3`S02dh7`0]=al0;cTQ038k8`0c>RD0<SPU030e900302dc8@0;02lf8P0a=b@0<CLT030e
8`0]=240;C8Q02X`800Z<240:c4Q02`c800Z;a`00P0Y;Q/02`0Z<1d0:c4N02X^700Z;A`0:bhN02T/
7`0V:1h092LN024T6`0P8aX082@I00807b8H00H07b8G01`Q4`0N8Q@07b<C01lR4`0M814Jooooo`06
04MBGP19EF80C5QX04iIJP1?Ff`0CUY]0P1=F6h02`1=FFl0CUY`055MLP1@G780D5a`055NL01BHG80
DF1`05ARL@1EHg80EVAc0080F6Ie00L0FFMd05YWM01JIW@0FfMg05YVM`1JIWT0FfIk0080GFIl0100
GFMl05aWO01LIg`0G6Ml05iZO01OJg`0HF]m065ZO@1QJWh0IFj106A]P`1SK8D0I6f506E_QP1VLXL0
J7:70P1XLXD01P1[M8D0KGN706mhR01_MhP0KgR9075iR`80LGZ=00<0LW^?07AmT@1fOi800P1fP9<0
2`1eOY80Mh2A07R2T01jQ940OHFC07j6U@1nQYH0PHVH086:V@22RYX0PhZI0080Q8bI00/0Q8jI08N@
VP28SiX0RI6L08RBW028Tid0RIBL08^EVP2;UiX0S9VK08jMW`0208jNW`0<08jNWP2=WYd0SIfM08jN
WP2BX9l0Tj6N09>PW@2BWi`0TinL09BPW@2DX9/0Tj2H0P2AWiL02`2CXIT0TZ:G092QTP2AXY40T:6?
09:RT01oSGh0DEEC04eBCP0b<cD0:R`/0080:B`Z00/09b/V02<W800Q9Qh092TP028V7`0M7aP061T@
01@G300B4`T04Q<8010B1P0200`A100<00/@0`0<4@@03A4600d@200>4@T03a8:00lB2@0?4`T04QH<
01@I3@0B5`/041@90P0B5@T02`0K7Pl08RHF02@X600U:QP09R`G02@[5P0T:aL09bdI02@[600R:1H0
8RLE008082@E00/07B0C01TM4P0F71005A/?01DJ3P0C60/041@9010D2P0?4PX03A4900/?2@0200/?
200600/>1`0<3`L03A4800hA200=40L02@`43oooool000gooooo00H09b`Z02X^;00Z;Bd0:B/[02PZ
:00W:RL202P/:@0;02P/;P0V:S009b/a02L/;`0V:b/08BLS01PL5`0@50h03Q0:00l@2P0?3`/00P0=
30X200h=300900L61`030`@010D500@5100930H04QL<01PM3`0G7@h04AH:0080310300`02@`100T<
0P082P802P`500d?200;3@P02P/700T9200<2`/04A0A01@C4P0F5Q<201`M600;02LZ8@0c>2/0?D@d
03Hm;`0W;B4082HI01HI3`0G6Q405aXC01PN5@0O9A/00P0W<2<02`0^>BH0=D4[03Q5;00jARd0?TP_
03m9<P10BC<0@4Pe0417=P11BCL0@D/g0080@4df00/0@Dlf04=@=P14CcD0A4la04A@<014Cbl0ADl`
04A=<@14CC80@DXb041:<P0203m:<P0<03m;<P0oBc40@4Xb049;=014C3H0AD/f04E:=`15BST0ATXj
04M;>`17C3/0@TTe0P12BS@02`12Bc80@T``045;;P11BBd0@TT^03m4;@0l@2`0>Cd]03Pm;`0j@340
>d8a0080>T8b00/0>D8`03U1;P0g@2/0=d4Y03@l9@0b>B40<cXQ02lf7`0]=1l0;C@Q02df900202lg
900302hh900_>b<0;SXO0080;c/O00L0;STO02lj800a>b40<c`T034h8`0a=b@0;S@R0080;SDQ00/0
;SDO034g8@0e>R@0=C/T038h900_=B40:c4O02P_7@0X;Q`0:BlL02X`6P0202X_6`0;02T^700Y;1h0
:bhO02X]7`0Z;R009bXO02DW7@0S9A`08RDL024S6P0P8QL00P0O8QH01P0O8QD07R4C01dQ4P0O8a<0
7b<E01`Q51[ooooo00H0B5=P04]GI01=FVX0CUY/04iJK@1>Ffh204iLL00;04iJL01?Fg00D5aa051L
L@1AG700D5a_059PL@1BGg00E69a05MTLP1HIG<00P1JIgD01@1IIW@0FFIc05aWM01MJ7H0G6Mg0080
FVIi00@0FVIj05]VN`1NJ7`0GVQm0P1NJ7`0301NJW`0GV]l05m[O01RJg`0Hfam06E_P@1TKX80I6n4
06A^Q@1TL8H0I76706EbQ`80J7>600/0JW>606afR01_MhT0L7N9071iRP1aNHX0L7V:075kS01cOHh0
MGn@07J1T@0207N1T@0;07J0T@1gP940N8:A07b4T`1mQI<0OXJD07n8U@20RYH0P8VE08:;U`24S9T0
0P23RiT02`25SIT0QXnI08J?V029TY/0RI>L08RCV`29U9X0RiJK08fHW@2>VIh0SY^O0080SI^N00`0
SYbN08jMW@2AWih0TYnN09>PWP2EX9l0U:2M09>OV`2CWi`0U:2N09BQWP2BWiX2096OV00;09:QV@2A
XIP0TJ6F096QU02@Wi80TJ6A082=P@1@E580E5eD038f=00V:BP00P0U9bD02@0T9bD08bHT02@X9@0X
;bP0:c0X02<V7P0I6a@051D?010@200200l@1@803@h400`02`h200`A0`0=4@@03Q8700`?2P0:30T0
2`d900d@2`0A5@l04aP@018G3`0>4`/200hC2@0;01LK3P0O91D08bPH02DZ600U;1H08b/D02@[5@0S
;1L08BTG01hV5P0O9QH00P0O8aD02`0J71005AP=01<G300C60/04AH900hB1P0=40H03Q89010D3@0<
3``02Pd900802Pd700H02P`500X=1@0930@02@`300X>10082`<?ooooo`003Oooool01P0P9b<09B`T
02X_9P0]<2P0;RlY02`]:@80;Bl/00/0;2h^02X[<00/;SD0;c8h034f>@0[<C00724P01PJ6@0E51D0
4a0C014?4`0200d;4@0;00/940071Ph01@@;00<31`041@D00`D300D70@0B60P06R0?01LL300B5@P0
0P0<3`D030092`802P`400X=1`0?4@/04Q@<010A300>3`/030`:00d<300C4A405aDD01HD4`8051<B
00/061PD01/K5`0R91d092LO01dR6@0F6A80414:018D300K7a@08BPK02@[7P0202<[7@0702@]7@0V
<Ah0:SHQ030k9P0g@b/0?DP`041<=002045;=P07049==`12CSH0@e4f04=A=P13DSD0Ae@g04MB=`02
04IA=@0504IA<`16D3@0A4hc049=<@13CC<00`13CcD03012CS@0@Ddd045;<`11Bc<0@ddf04A==`17
CCP0B4hh04U>>@1:CSX0BU0k04]B?080BDlj00X0Adhg04A<<`13C380@d/c04A<=012BS<0@TPb0456
<`0oA340?TDb0`0oBC<02`0mAS40?4D`03U4;@0iAbd0>4D[03M29`0f@2@0<S`P030i800`>B40;cLR
0080<CXU00`0<S/V038l9P0b?2<0<C`S034l900a>R<0=3`U03Dn9P0f?RP0=C`W03Dl:00a>2D2030f
8`0;030g800`=al0=CXR03Hl8`0e?2@0<c/S02lg800/=1h0:S8L02Tb700Z<A`00P0[<Ad02`0Z;a`0
:BhL02`a7`0[<200;38Q02T^7`0U:A/09BTL02HZ7`0U:1d092PL00808bLL00H08BHJ024V6@0P9aP0
82LG01lV5`0P9ALJooooo`0604MCG@1:EV40C5UX04iJK01>FVd0CEY^0P1=Ffl02`1>Fg00CeYa051L
L@1BGG40DUe_05=OK`1CHG00Df1_05ESK`1HIW80F6Id0080FFIe00/0F6Ef05YUM`1LIWT0G6Ii05]V
N@1JIg/0FfMl05UVN`1JIWX0GFQk05mXO@02061YOP0<069/P01SKX80I6n206A^P01UKX40I6n206=_
PP1RL880Hg2406AaQ01TL8@0IW:40P1XLh@02`1ZM8@0KWJ606mgR01bNX/0LW^;071jR`1`NX`0LWf=
07=mSP1gOi00NH6@0080NH6?00/0N86@07Z3TP1kQ9<0OHJD07j7U@1oR9D0P8VE086:UP21RYD0PH^E
08>=V00208B>V@0;08J@V`26T9X0QY2I08NAV@28TYX0R9BK08ZFV`2;Ui`0S9NM08jIW`2>VIh00P2>
VYl0302@W9l0T9fO09>PX02DXJ00U:2N09FPW@2FXYd0UZ>N09JRWP2FXYl0UJ:O09:OW080Tj2J00/0
U::J09FSV@2FXiP0U:>F09:RU02CXY80RIV604a@B`1>ET`0>Chi02PZ:P0202DW9P0;02/^:`0W:RT0
9b/Z02/b;00[<BP08bLO01/M600E5a40414:00d?1`0>40L00P0<3`@0300;3`@0310400`@100<40H0
2`h800X=2@0:3@P03Q@;01@J3`0D6a404QT?00hD2P803A<900/05A/?01`S5@0Q:AT08b/I02<[5P0T
:aD09B`F02@/5`0S:aP08BTH020X5`0201`R4`0;01LL400D6@d041D;010E2P0?50P03A4800`?1P0=
4@L03Q<900`?2@0:3@H00P0830@01P072P4020/100H:00052P001``000L;00oooooo000=ooooo`06
01LN7P0J8A`07R@K028U700V:240:B/U0P0]<B/02`0^<Bh0;S4a02hb=00^=3L0<SXk034i>00W;Bd0
82DU01lQ900I6B4051@N00804A4L00/03a0K00X:5@061A000`<;00421@010`<00`D100dA1P0F70h0
61d?01HG3@02014B2P0<00h>200=3@T03Pl<01<D4P0G6AD05aXG018F500>41003Q0A018C4`0E5AH0
4a4C0P0A3a402`0B4Q404A4?01<D400G6A805AT?014C2P0?40L02`/201HI300U:aX09R`N00807B<I
00/06AlF01HL4`0H7Q<072@F02@]700/=R80=40Z03U4;@0lB2l0?TX_045?<@0204=B<`0;04A@<`16
DCH0Ae4h04I?=`18DSP0Ae8g04EA=@15DCH0A50e049>=013CSD00P14CSH03013CCD0@ddd04=<=012
BcD0@T/f04A;=`16C3P0Ad/h04Q<>@19CCP0Bdhi051D?`80DEE000@0CE4l04Y?>P18CST0AT`h0P14
BcL01@13Bc@0@d/c0458<010B300@DTa0080@DTb00T0@DLb0417<@0mARl0?4L`03]6;`0hA2/0=T8W
03A08P0a?B000P0`>Al2030j8@0<038l8`0d?bD0=3dV03<l9P0a?2H0<S/U03@k9`0e>RH0=SdY03Lo
:P0f?RX0=3hZ0P0c?BL02`0c?2<0;SDN02`b700`=Qd0<3LN030h7`0`>1h0;CDL02/b6@0Y<1P0:2dG
00809b`I00/0:2`K02T]7@0[<1l0:RlP02T_800Z;b009bdM02<Z6P0T:A/08bPJ024V6002028V6@06
024V6P0P:1/07bPJ024Y6`0P9aT082DG6_ooool01P17De`0BEIP04aII@1=FVX0CUY/04iJKP80CEY^
00/0CUYa04iJL`1?Fg@0DEac055LL@1CH740EF9b05=OK`1DH6l0EV=a05QUL`0205QUM00;05MTM@1H
I7L0FVEj05aUN`1KIWX0FVEk05]VO01JIW/0FVEj05eVN`1NIgd00P1QJWl00`1SJh00IFf206E]P@02
06A]P00706E_PP1UKh<0Hfn306=_PP1TLX80I76106McP@0206UdPP0;06]fPP1`NXD0LWZ707=jR@1b
Nh/0L7Z<075lS`1bOI00Lgj@07EoT01gP8l00P1hPHh02`1jQ900OHJB07j5TP1lQ980OXNE0829UP21
RiL0PH^F086<UP22S9L0PhbI0080Q8jJ00/0Q8nK08F?V`26TI`0Qi6L08NBV`29U9/0RiNM08fHW@2?
VYd0TIbO096KWP0209>MX00909>MXP2BWJ80TYjS09>OY02EWj40UZ2Q09BOX02EXJ00UJ:P0080Uj>P
00h0U:6M09FQW02EXI`0UZ6K09JRV@2GXiH0UZ>D09BRTP2CXI00TZ>=05MLEP0g>CX0?44n030c<P80
:2X[00/0:bh[02T/:P0T9bL092TV020U8@0I7QX05APD01@H500?4`l03Q4;00hA2@0200dA1`0<00d@
1P0<40D03A4700`@1P0<40L0310800/@200=4`P04AP;01<K3@0B6@/03a@80P0<40L02`0H7Q407bLG
028Z6@0T;1X09B`J02H/6@0W;AT092/G02@/600R:aL07RLC00806R8@00/05Qd?01@J3@0?50T03108
00/@1`0<40P0310700`@1P0=4@H02`h500X=100200P;0P0600D800062@0010L0008700021P000@@0
3oooool000gooooo00H05ahN01XQ700N91/08RDL02HX8@0Y:bD202da:`0;02ha;P0^<C40;S8d02hd
=`0b>S/0<CTh02L];@0P9BD07b4T01TI8@0D51h00P0A4A`02`0?41/02PXE00H540030`/00@850043
0`031@403A4601HL3P0H7@l05QL=00804A8:00`03Ph800d=2@0>3``04a@B01LI5@0G6QL04QHD00h@
400>41404Q<C01DE5P0C4A<2014?4@0;018B4@0A4@l04a@@01LI4P0E6@l04A<:00l@1`0;2`805QT<
02D[6P0V;1h00P0M8aT02`0I7aH05Q`C01PN4`0L91H092dL02`f8P0d@2X0>D@]03a8;`0nBRl0@Dla
0080@e8c00/0A50c04IA=P17DCP0ATlg04QB>017DSL0AE4e04EA=P14D3D0@Thd04=>=@0204A>=P0<
04===@13CC@0@d`d049;=@12BcH0A4/g04I<>017BcP0B4`i04U=>01;CST0D5@o0P1AED00101=DC`0
BTlj04Q>>@16C3P204A;=`0504=;=013Bc<0@DP`0418<011BC400P11BC802@11Ac80@4La03e6;`0l
Ac00>dH_03Q4:`0f@RL0=40R034m8002030i7`80<3XQ00`0<S`S03@o9@0d?BH0<c`V034l9P0b>bD0
=3/W03Dj9P0f?BT0=clZ03Hn:P0d?RX203<m9`0;03<l8`0^=Ah0;38L030f7@0`=ah0<3PO030h7P0]
=A`0:c8I02T`600X;AL00P0W;1T02`0X;1/0:BdM02/`7`0Z;b00:BlP02X_800W;Ad08bXJ02@Y6`0S
:1X08BHH00808RHI00H08BHJ020X6`0O:1X08BTK020W6@0P9ALJooooo`0604MCG019EV00C5UU04eJ
JP1>FV`0CUY^0P1=FVh02`1>FW40CUYc04mKM01AG7<0DEaa05=PL@1EHW80Dem_05APK`1FHg40F6Ec
0080F6Ed00/0EfAe05QTM`1JIGX0G6Ek05]VNP1JIG/0FfIl05YVN`1JIGX0GFIk05iWO@02065ZO`03
06=[P01UKH80IFf10080I6f000L0IFn206E_P`1SKh<0Hfn206AbPP1TLH40Ig>10080JGB200/0JgJ2
071jQ@1bNXL0LgZ9079kR`1`NX`0LGb?079mT01cOY00MGn@07N0S`0207R1SP0;07Z4T01mQY80OXFB
07b4TP1nQiD0P8VF086;U`21RiH0PHbF08:<U`23S9T00P24SYX02`24Si/0QHnK08JAW027TI`0Qi:K
08VDV`2;Uid0SIRM08nJW@2AW9l0TI^N0080TifP00T0TifR09:MXP2BWZ<0TinT09FOX@2FX:40U9nP
09FQX02EXZ000P2GXj003P2DXId0UJ6L09FQW02FXI/0UZ:I09NSUP2FXi@0U::B09>QT02BXhd0EeaF
03Li>P0l@Ch0<3<b0P0X:R/02`0[;R/0:B`Z02@W9`0T:BH082DQ01TN6P0E61@051PD00lC3`0>4@/0
3Q4900803A4700`03A0600`@1@0=4@L0310600`@1`0<40P02a0800dC200A60/04a/=018I2`0?50P2
00`@1`0;01PN4@0O9aL08RXI02@/6P0U;1X09R`I02L]6@0T:aL092`H028[5`0N9a<00P0J8Q002`0F
7@l051X=00lD2@0<40P02a0700`@200<40L0310600dA1P0;3PD02Pd4008020/200H01@P000H90004
1`000PL000860001100?ooooo`003Oooool01P0K82806QhN01LL600G6a@06QdG020R7080:2/S00/0
;2lX02lc;P0`=S<0;SDd02dd=P0`>3P0;SLe02P_;P0W;Bh09BX_02@Y;`0202@V<@0;028T;`0L7RP0
51DP00h>60082A4010H;00<51P0;3`X051P>01HJ400B5@d00P0B4``0200B4@d04Q4>01@C4@0J6aL0
7B4L020U8P0O9B<0728O0P0J7ah03`0E61X03a4D00d=4@0=3A403@d>00`>300=3`/041<=010D300>
4@P030l500X<0P0J8100:C8N02Tc7`0201lW6@0;01TO500D60l04QH<018F300E6@l061d@01hT5@0T
;1X0;3HP03A09@0lB2/00P11CC002`15D3<0AU4e04M@=`17DSP0B5<f04MB=@15Dc@0AU@g04ME>@16
DSP0AE4h0080ADlh00D0A4hg04E>=`16CCH0B4lg04Y@>00204Q>>P0504I<>017C3T0B4dj04Y?>`1>
DS`00P1>DSX02`1>DCX0C54j04]A>`1:CcT0ADhh04E?>013CC@0@ddc045;<010Ac00@DL`0080@DLb
00/0@TPd0498=@0oAS@0?THd03]4<@0h@B`0=d8Y03Do8`0a?1d0<CXM034j7`02034k800<038m8`0f
@2D0=3hT038l900a?2@0<S/U03@k9`0e>RT0=C/[03Hn;00d>bT0=C`X0P0e?RP02`0e?BL0<CTT02de
7`0[=1`0:cDL02Xc6`0/=A`0;CHL02/b6P0Y;aP0:RhI0080:c4N00/0:RhN02T^7`0Y;b009bdO02T_
7`0Y<1l09blN02D]6P0S:aP082TE01lW5002024X5P0602<Y600O9aL07B@F01lU6@0O9AP07R@E6_oo
ool01P16DE`0BEEP04aIIP1<FFX0CUY]04iJKP80CEY^00/0CU]`04mKL@1AGG<0DUec055LL@1BGW40
E5ma05AOL01DH6h0EV=_05ISL00205MTLP0705QULP1HI7@0FVEi05aVN`1LIG/0G6Aj05aUN00205eV
N00705iWN@1QJG`0HFYm065ZO@1QJG`0HVam06=]O@0206=/O00706A]O@1TKWh0IFn106E`P`1ULH<0
IG:006QeP00206UeP@0806agPP1_NX<0LWj707AmR@1cO8/0LGb;079mS@1dP8l207F0T00807N1T01g
PHh0Mh6>07Z3S`1mQI40OhJD0826U@21QiH308:;V080PXbG00X0PhfI08B>V@24SYT0QHnI08J@VP27
TI/0R9:M08RCW02;UI`0SINK0P2AVYd01@2AVYl0TifQ09>OX`2CWj<0U9nT00<0U9jT00L0UIjS09NP
X`2FWj80UYnR09NRXP2GXZ00UZ:N00<0Uj>L00/0Uj>K09JRV02GXiD0UJ:C09BRTP2CXI00UJFA06M`
J@0a<3H0?44o03Dg=P0202`];00;02/^:`0Z;B/0:B/[02P[:P0N8B8061`M01@F500C5A004A@<00hC
2@0>4`L00P0=4P@02`0=4080310200`?0P0<3`<0310500dB1`0<4@P02a0700`B1`0>4`P03Q8700<0
310500/06B0B024Y6@0R:aX09BhL02H]700V;1/092TI028Y600R:QH082TD01`T4@0201TP400;01HM
400E70h041H<00`A200:3`H0314800/@1`0;3`@02`l300X=0`072P800P0620401P041`001@P000@7
00031`000@D0000300oooooo000=ooooo`0601lR8P0M820061`K01HJ5`0F6Q@06AdE0P0L7QD02`0O
8AT08bDP02PZ9`0[;b`0;3@b034j>00a>SH0:c@`02/b<00/<c<0;S<d0080<3<g00/0<3<i02ha>@0[
;SL08bL`01PL9@0@4a/02`dB00/>400@51005AXA01DI4@0201<E3P07018C3@0C4`d05QL@01XK5@0J
71P07B4N020W900202D/9`0302L^:00P9R805ATH0080414C00/03`h@00d<3P0>3@h0414@00lC400?
4Pl03A0<00`@2@0A5`/061l?01XR400201/R4@0;01TP3`0F6`h04aH:018E2P0C5@/04Q@:018E2`0C
5``06b8A028Y500/<a/00P0i@RL02`0oB2`0@dda04I@<`18DC@0B58c04MC=P17DSL0Ae<h04UE>P19
E3X0B5@k0080Ae<k00L0AU8i04E?=`14CCD0B50h04UA>P18D3/0Adhk0080Addh00<0B4hi04U?>@1<
DSX00P1<D3P01P1;D3P0C58k04aC?01;DS/0AU0h04A?=P80@dhd00<0AU4f04A?=P13C3@00P13Bc@0
2`13BcD0@dTd0457=@10B3@0?4@a03]2;P0kA2`0>48W03Do8P0d?B00=ChP0080=3hQ00`0=3dQ03Dm
8P0f?R<0=ShT03Dn9P0d>bH0<SPU03Dl:00d>RL0=3/X03@l:00e?2P203Dl9`0;03@k9P0b>bD0<C/T
02lj8P0^>R00;CPO02`e7P0^=Qh0;C<O02`b7`0Y;Qd00P0[<2002`0[<280:BlQ02P_800X;ah09bdM
02H]6`0W;aX08b`G02</5P0S;AH08b`F00808b/F00H08RXF020X5@0O9aD08BTG02<Z600O9AHJoooo
o`0604IAG019Df80C5MX04]GK01=FG00CeYa0P1>FW002`1?G780D5ec059NLP1BGG40Deia05EOL`1G
Hg@0EV5b05EOL01GHW40F6=b0080Ef=b0P1HIG<02@1KIWH0FfIi05aVN@1MIWX0GVMh05mXM`1PJGP0
GfQi065ZO002069ZO@0<065ZO@1SK7h0I6in06A_O@1TKWd0IVmn06M`O`1XLH00Ig6306QbQ01YLh80
JWF10P1/Mh<0101^N8@0L7Z607=mR01dOXP207EnR@0507J0SP1fOi00N86@07R1S`1hPY000P1hPi40
1`1jQI80O8FD07f6UP1oR9P0PHRI08>9VP23RYT00P24S9T03`25SIT0QXjK08N?W027Si`0R96M08NB
W@28TY`0RIBM08VDW02;UiX0SYVJ096LW02AVid0TIZO09:MXP02096MX`0<09>OY02EX:D0UJ2T09JO
X`2FX:<0V:6R09NQX@2GXIl0Uj:O09NSWP2HY9d0V:BL0`2GY9/02P2FY9T0UZ>H09JSU`2FXiH0U:>D
09FVU@1]N6l0<C<h03a2@00h?3X2030b<@0;034d<P0_<S00;c@`02ld<00L7b006adM01HH5@0A4@`0
414800d@1@0<4@<00P0;4040300<3`403A0300`?100<3`H030l800dB2`0>4P`03A8:00`A1`0<40L0
3A4600dB1@804AH800/07B@B02<[600U;A`09BdM02D]7P0T;1h08RXL02<[6`0R:QP07RHC01XR3`02
01HM3P0;01@K3P0C6Ph04QT>00lF3@0=4PT03A<900`A1`0;3P@02Pd400/=10082P800P051P001P03
1@001PL000@700031P000PD0004300oooooo000=ooooo`0601PM700N8B0071`N01LH6P0G61H061XF
0P0H6A@02`0I6QD06ATF01TH5`0K71X082DQ02P`:P0]=Rl0;SL^02lh<@0]=C40;C<a0080;c<d00/0
<3<h034c?00a=Cl0;cDn02/b>@0S:S007B8W01LM7`0G7AT061hG01DJ500201<G400<018F3P0E60l0
5a/B01HI400A50h04QD@01LL5`0Q9Ql0:BlU02hd:P0^=B/092XT0P0L7a`02`0H6AT04a4D00h>4P0@
3a<03a4C010C4`0A51<04ALB018I400F7@l05al<00<05ah;00X05AX901<G200A5@H04AD6010D1@0?
50D041@601DI2P0E60P06Qd:0P0Y;QL02`0g?280@4P[04I@<P19DSD0BE<f04MC>017DcL0AU<h04QE
>P19ECX0BEDl00<0Ae<l00/0AE4i04A>>015CSX0Ae4m04UC?@17DSX0ADhf04I>=@17CSD0B4hf04Q=
=P0204Y>=`0604U>=`1:Cc/0B4ll04QA?@16D3X0A4hf0P13CSD00`13CCD0@ddd04===00204A>=P0;
04I>>013BSD0@dPe04A:=P10Ac<0>d<`03Y2;P0i@R`0=ClX03E09P0g@R@00P0f@280300f?b<0=clS
03U19@0h@2@0=chV03Hl9P0c>BD0<CPU02le8`0`=RD0<c/X03@k9`80<cXV00/0<3PT034i8`0b>R<0
<c/S038j8P0c>b40;cHN02dd6`0^<ah0;S<R02db8@0202`a8P0;02`a900/<R@0;38R02/a7`0W;1/0
9B/H02L^6@0U;AP09BhI02@]6@0T;1P00P0U;1T01P0S:aP08BTF020X5@0N9Q807RHD01lT5A[ooooo
00H0BE=O04]FIP1<EfX0C5Q]04iJL01@G742051KLP80DEad00T0DEed059MM01DGG@0EEif05MPMP1F
HGD0F65e05URM@1HHW<00P1JHgD02`1JI7D0FVEf05YVM`1JIWL0G6Mh05iXN@1OJ7P0H6Yi065[NP1P
JW/0HFYn0080HF]n00`0HFao06E_P@1TKWl0IVmo06M`P@1YLX80JG6006QbP`1YLX@0JG>406YdQ01]
MXL206miR@0;075jR01aNXL0Lgf:07EoRP1eOhP0Mh6;07R0S`1iOi40NX6B07^2T@1kPi400P1kQ940
2`1lQI<0OXJE07n8V@20RIT0PhZJ08B:W024Ri`0Q8bL08B<V`25S9/0R8nN0080RI2O00/0RY6P08ZC
X02<U:00RiFM08bGW@2=UiX0SYVJ09:LV`2CWIh0UIjP09BNXP0209:MX@0<09BPXP2FXJ<0Uj:S09VS
XP2HXZ80V::Q09RRX02GXYh0V:>N09VTWP2IY:00VZBP0P2IY9d02`2IY9h0VJBL09NSVP2GXYT0Uj>G
09NUU02HZ9D0MX9g03Tk@@11B4H0?44n0080=SXg00/0>Clh03Dj<`0^<R/0<cP`01hO7@0L7AT05aPC
014C300?4PT03Q4600`@0`0200`@0P0<00dA100=4@H03A4800hB300>4Pd03A4<00hB300?50/03Q88
00dA1`0>4`H03Q<50P0B5`L02`0L91408b/G02P`7@0X<1l09bhP02D/800U;B008R/M024Y6P0N9AH0
6R4B00805A`>00/04QT<018H300C6Ph04AP=00hD2P0<4@P0310700X=100930@02P`400P90P0200H7
0@0600H5000610000`@00085000110000@<03oooool000gooooo00H06b0O02T]:00U9RD07adP01XI
7@0I61`201PF6@0;01LF600E4a@04a8A014C4@0C5a8061hG01hU6`0W;b40;SHX030g;00a=Rh00P0_
<bl02`0_<S80<C<h03@f?P0d>Cl0<SPo02lg?00[=3H09Bl_020X9`0K8R005Q/J00805QXH00`05aXF
01HJ5@0F6Q@051PB00hA300=3`/041<>01/O5`0R9Q`09RXN02/^8P0]<RP202da:P0;02T^:@0T9bH0
7AlS01LI7`0B5AX04A@H01DI600J81X06R4H01XQ5@0G7`l00P0H7`d02`0G7@`04aT8018G200?50H0
3Q<500hA0`0@5@D04aL701DG2@0B4`L04Q8500806AP700/08R4>02`]6@0k@B/0A4dd04MA=`19EC/0
BUHj04UF>019EcL0Ae@f04MC>00204QC>@0<04UE>`17DCX0AU0k04E>?017DC`0Ae8l04QC>P15D3@0
A4ha04E><P16CC<0AT`c0P17Bc<02`16Bc@0Ad`h04M>>`14C3X0A4dh04A>=P14CcD0@ddc045:<P12
Bc<0@T/b0080@TTc00/0A4/d04A:<`14BC@0AD/g04=:=`0oAcL0?4<e03U1<P0f@2h0=3l[03A0:@02
03<n9@0<03<n8P0f?b80=d0T03Dn8`0d>b<0=C/U03<h9@0a=bD0;S@U02db900]<b@0;SHS0P0`>2@0
2`0a>2<0<3PR02lh8@0`=b00<3LO02lf7P0]=1`0;38J02da7@0/<1l0:blP0080:blR00/0;30S02`a
8@0/<B00;34P02T_7`0V:a/09B/J02@[600R:QL08bXG02H[6P0202H]6`0602H^700T:aX08BLG01hU
5@0N91<07B8A6_ooool01P19EUl0C5UT04eIJ@1?FVh0CUU_04mJL080D5Y`00/0DEab059LLP1DGW<0
EF1e05ANM@1DGGH0EUig05MNM`1IHGL0FF=f05MRM00205QRM00;05QRM@1HHgD0FFEg05UUN01LIgT0
GFMi05mYN01PJWT0GfUj061ZN`1PJWd00P1QK7h01P1RK7l0IFj206I_P@1WL840J72306UaQ080JG:4
00@0J7:206YdP`1/MX@0KgV70P1`NXL02@1aNhT0LWb9079mR`1bOH/0Lgj:07F0S01gOhd0NX2@07b2
T00207f4T@80OXJB00P0OHJA0829U@20RIP0PHZH0869V@22RIX0PHZL08>=WP80PhbN00`0QXjN08V@
W@29T9d0RY:M08^CW02<UId0SIFL08jGW02?VI`0T9VL09>LWP2DWIl209FNW`80U9fN00`0UYnP09JP
X02GXZ80Uj:R09NRX@2HXZ00V:>P09VTX@2IY:00VJBN09ZTW`2JY9h209VSW00;09ZTV`2LYi`0VZBI
09RRU`2HXiH0V:FB09NWT@23TH40?d=604A:B00j?cd00P0c=c802`0d>S80=3X`02d`:00^<RT07AhI
01/L5P0F5a404A<:00hA1`0>4@D031040080310300`02a0400/>1@0<3`P03A0<00h@300<3@X03@l:
00hA2@0>4`T03A4500/@0P0;3P4200`@0`0;01hV4@0S:aH09blJ02L_700U;Qh092dO02H^800S:ad0
8BTL01hW6@0I81<00P0D71001`0B6@d03aD;00lE300=4`/03A<:00/?1P082`<00P082P400`072@40
1@H000H7000200H7000500H6000310000@@0004300000P003oooool000gooooo00H0Df=G04UEB`0e
?3H0<CHb02`^;P0X:B/2028Q900;01hL7`0K6QX061TD01@G400B5Pl04aP@01DI400L7a<08R@G02X[
8P0`<b`00P0a=2h02`0`<c40<cHh03Lj?P0g>d40=ce403<k@@0a>Sh0;SLi02Ta<P0S:R/08BLX0080
8BDW00`07b4R01`O7P0H6A/04a@G00h>4P0;2`h0418B01`P6`0L81X061/C01PJ4P0O8QX202DZ8P0;
02T^:@0[<Rh0:S4^024W9P0I7ah061hL01/Q700K8QX072@J01XP5P0G71000`0I7Pl02P0F60/04Q@9
010B200@4@T03Pl8010A200C50X05AD<01DF300D50T201LE1P0;01/I200L6`X0:B`I03To:011B300
B50d04aD>01=EST0BeLj04]G>`19EC/00P19E3/03018E3X0BEDk04UD>P17DSX0B54h04Q@>018D3L0
AThd04E==016CcD0ADhe04I>=@80AD`c0P16C3@02@17CCD0A4Xd04=9=014C3@0@d/e04A;=@14C3D0
A4/d04A:<`0204A:=@0;04A;=@16CS@0AD`d04E;=@14BCH0@TPg03m5>00l@SD0>D4b03Hn;P0b>bX0
0P0`>bH02P0a?B@0<ShS03<m8`0b?2<0<CXT03<k9@0c>B@0;SDQ02hd800_=R8202dc8080;cDR00/0
<CPT034h8`0`>2@0<3PT02lg8`0]=B00:c<N02/d7P0/=1h0:c8N02X_7@0202/^7P0;02`^800/;b00
:RlN02X_7`0Z<200:2lP02D/7@0R:QX08BTH028Y5`0U:aX00P0T:Q/01P0R:Q/08bXK028X6P0R:1T0
8BPG01hS41[ooooo00H0BUQL04iKH`1@G6/0D5]^051JL01@FW82055LL`0;05=MLP1CGW00EUm`05IO
L@1FGg80EF1d05EPM@1FGgL0F69i05MSN@1FHWP00P1EHGD02`1GHWL0Ef=g05QUN@1HI7X0FfMl05eY
O01MJGP0GV]i05i[N`1MJW/0GV]l0080HVin00H0HVeo06A]P01WL880J76306M`P`1XLH<206UbQ@04
06YdQ@1[MH<0KGN206miPP80KgZ400/0LG^7075lQ`1aOHT0LGf:079nRP1cOX`0MX2?07V1T@1kPi40
O8BB07b4T@0207f6S`0;07b7SP1nRI40P8VF082:V@20Ri`0PH^M082:W@22Rih0Q8fO08F>W`26T9d0
0P28TYX02`2;UIX0S9FI08^FV@2;UIP0SYRL08nJW02>V9X0T9^M096MWP2BWYh0TijM0080U9jM00`0
UYnO09FPW`2FXJ80UZ:R09JRX@2GXZ00V:>P09^VX@2KYj40VjJP09ZUW`2JYId209VUV`0;09RSV02I
Y9P0VJBG09RTUP2GXiH0V:BD09NVTP2;VXP0B4]<0415A00h?C/00P0]<2d02`0Z;BH0:blV02T[8`0/
;bD07b4J01XL500E60l04A<:00lB1`0?4@@03Q440080310500`02`h500X=1P0;3PT03@l<00h@3@0>
40/03a0<00hB2`0@5@/041D700hD1@0>4P@200`?0`0601`S3`0S:QH09R/H02L^6P0V;Qd09RhO0P0U
;Ql00`0R;1d07RHH01PO500201<J400:014H300@5P`03A8900`@1`0<40H02@h400P<0P082`002@`0
00P:00@01PP000D01PP100@6000310000@<00041000?ooooo`003Oooool01P1aQWd0LXIl06EgK`1N
KFD0Ef9M04aDDP80ADa:00/0>T4o02P/:@0S:2008RLM028V7@0T:1h092HL028R6@0O7QP08b0P02/Z
:`0202XZ:`0;02XZ;00a<S<0=CTj03Lk@@0i@4@0>45503@m@P0_>3/0;3Dh02/b=00/=3<00P0_>3@0
300]<c80:Rh`02@U;00J6B<04a0K010=5`0E4a/06adP01HJ700A4a<03@h<00hA3P804aHC00/06QhJ
024W8`0U;2L08bXT01lW800S;2<092hT020Z800N9Q/06B0D01LM400201TN400;01XN400I6P`051D9
01<C2P0D50/0410800l?200@3`T04A4:01<C300D50d00P0Q8aD02`0X;1X0:BlK02`d7P0d?2<0>T4U
0457:P16C340Be8h04eD>`1=ESl0BeE10080BEE000`0BEHn04QD>`19DcP0BeDh04eE>@1<DcT0CE8i
04Y>>019CCP0B4hi04I>>018D3L204Q?=@0;04Q?=016CS80A4/`04A:<@15BS80B4he04M==`18CSX0
Addj04I;>015BSP00P13BSP02`11BCH0@T`c04=<<P14C380A4Xb04=8<`12AcD0@4De03m4=00l@C40
=c`]0080<SXZ00`0<SdX034m900a?280<C`Q038k8@0d?B80=3/R038i800a>200<cXR03<i8`0b=b82
030f8P0;030e8P0`=R<0<3LU02lh9`0^>2H0;SPT02dg900]=b<0;3LR02/e8@0Z<Qh00P0/<Al02`0[
;Ad0;2lP02da8@0/<2<0;30T02/`900X;b<08b/P02<[7P0S:Q/092/K00809B`M00H08RPK01lW6@0Q
9aX08BPH020X5P0N9Q8Jooooo`0604YHG@1=FV<0Ce]Z051KK`1@FW80D5]d0P1AFg@02`1BGG80E5m`
05EPK`1FHFl0EF1_05APL@1EHG80EV9f05EPM`1EHWT0EF9g0080EF9e00P0EVAf05UVN@1JIW/0FfMm
05]XO@1MJW/0G6Yg05i/N080GVYi00L0Gf]j069`O01RL7`0HW5m06AaO@1XLh00J7>20080J7:400H0
J76506UdQP1YMHD0JGB306ehP`1`NH@2071iQP0;071kQ`1bOXT0LWj807=oR@1ePH`0MWn=07V1TP1k
PY@0OHBC07f6U01mQI<00P1mQY8207f7T@0907n9U@1oRIL0Oh^J086<W021S9d0PhbM08B=W@27Sil0
RI:O0080RI>O00/0RiBM08^EW02<UY/0RiJL08bHW@2=VIh0SIVM08jKW@2AWil0TInP09>QX00209BQ
W`0<09FRX02EXJ80Tj2R09FRX`2FY:80V:FR09VVXP2JYZ80VjNQ09^UX@2LYj<0W:RQ0P2KYYh02`2J
YI`0VZJJ09ZVV@2JYiP0Uj>F09RSU@2HY9@0UJBA05=GEP0i>Sh0>Cdm0080:bd]00/09BTT02HZ8P0S
9R008bHO020S700L7aL061/B01DH3`0F5`d05AL;01<E2@0200hB1`0<00`@1`0<40P030l:00hA3@0?
4`d041<=014C3@0B5Pl04QL?014F2`0@5@T04AD80P0A50D02`0D5`L07B0@020U4`0T:QL09blK02L_
7@0W;ah09BlN02@^7@0Q:a/072@F008061lB00/051X?010F2`0=40L030l600`@1P0=4@H02`l400/>
0`0;3`<02Pd200L90@0200D70@0600D60@072P<01`X200D7000310000P803oooool000gooooo00H0
OY:908>FSP25V980PiF@086BS`1jRHP207N7Q00;0720OP1IIfP0DEeM05EQG@1JIeh0FVIJ04Q?B00d
=cH0=SPk03<d>`0/;3<00P0R8BL02`0N72408R0S02PX:P0`<S@0=3Pi03Hm?@0f?d00<CTl02/c>00]
=CP0<CXk0080=Chn00`0=Slo03Q0@@0g>Sl0;c4j02DV<`0P82d0824[01hP9`0D5A`0418E00h>3`0=
3@`200l?3P0;014A3`0C51405a/G01XO6`0T;2D0:38Y02Td:@0V<BL08BXO01`S5`0J8A<00P0J8180
2`0J7a806A`?01HF300F5P`05AL<01<C2@0B4PT04Q8;01<C300@3`/040l>0080<3HZ00/0BUQ304eN
AP1;G480AU@j045<<@0nAb`0?dL]04=:<@16CCH0Ae0j04YC?P0204YE?P0<04YF?@1:E3/0BU<i04]C
>@1=E3X0D5Ln04mF?@1>Dc/0C50j04Y@>@1;DCX0BU4i0P19D3H02`19D3@0B4hd04M==017C3@0B4`c
04U==@18CCL0B4di04U>>`16C3P0A4Xe0080A4`f00/0A4df04===013CC<0A4hd04A==015C3@0AT`d
04E:=@15BC@0@DDb03e2<00203Y0;`0603Ho:`0d?RP0<c`T03<l8`0d?2<0=3`T0P0e?BD0100c?2@0
<c/U03<i9@0c>RH2034i9@0;02hf8`0]=B80;3DS02`f8`0]>2@0;SLT02dg9@0]>2H0;SPW02dg9`0]
=RL00P0[<R@02`0Z;R40:RlR02``8`0/;b<0:RhS02P^8`0V;2<09B/R02D[8@0T:Qh092/M008092XL
00H08RLJ024U6@0P9QP08BPH020W5`0O91DJooooo`0604]IH@1=Ff@0D5aZ055LKP1BG780DUed0P1A
Fg<02`1BGG<0DUeb05APL@1EHg40EF9a05ESLP1EI780EfEe05MSMP1HIGP0EVAe0080EVAb00/0EfEc
05UVM01KJ7L0G6Uk05iYO@1PJgh0H6al061]NP1PK7P0HVaj06A_O00206EbOP0<06McOP1WM7l0Ig>1
06McP`1XLh<0J7>406QbQ01ZM8@0JWB506]dQ@1^N8L0LW^90P1cNhT02`1dOHT0M7n;07=nR`1eP8/0
N8:<07R1S@1jPHl0O8>B07b4TP1mQI<0O8FC0080OHJE00/0OHNE07b7U01oR9H0OhVF082;V023SI`0
Q8jL08>=VP26T9`0R92N08^CXP0208bDY00;08bEX`2<UZ40S9NO08fHX@2<V9l0SYZO08nKWP2@W9h0
TYnO09>QX02EXZ400P2EXZ00302EXj40UZ>S09NRX`2GY:@0V:FS09RUX@2JYj40VZJP09^WX02KYZ00
W:NP09bXX080W:RN00D0WJRM09fXV`2LYiX0VjNI09VUUP0209VTUP0409NTT`1HFUX0?Ce203Tl?@80
;C0a00/0:2/Z02HZ:00T:2@07b<N01lT6`0O9QX07B<G01/P5@0M81<06Qd>01DH2`02010D2@0<00hB
200=4@P02`l700`@2P0?4Pd04AD@01<G4@0C5`l04AH<00lD2P0>4PL031430P0<40802`0<3@40720@
028W5P0U:QP09blI02P`6P0W<1X09S0K02H_7@0U;Qd082PH00806b4C00L05adB014F300>4PT03A47
00dB1`0>4`P03Q8700803Q4700X02`h500L90P0620401PP100D60@0620801`X300D70@0210000@80
3oooool000gooooo00H0PYJ<08JHT@2:ViP0RYZL08ZJWP28Uid208JGVP0;08JGV024UIP0Oi2D07nB
TP22Ui<0PYN>07V;PP1/Ng@0Kgig05aWI@0/;SP00P0K6B@02P0J6Al05A<I01HD6@0M7Ah09RPV02lc
<00d>CP0=Chl038k?00i@d8303m:B@0<03a6B00kA4P0>T5703PoAP0e?4D0<SU302he?`0T:C@06A`W
01<D7P0@41H04A4C0P0A4A402`0?3Pd03Pd<00l?300A50l08bXR02H^9P0Y<BL0:C8W02@/8`0Q:B00
7RHK0080728I00/06b0H01XO5`0H71@05a/B01DH3`0D5``05AH<01PI3`0G5Q005QH@01lP600202X[
8`0;04I>?P1AGdX0DfE<05=TBP1@HDD0BEPn04EC=`13CS<0@dhb04A?=017D3L00P1<E3/0301;Dc`0
Be<k04eF>`1=Ec`0BeDl04aG?P1>Ecd0CEHk04eF>@1=E3P0CE<h04aB>P80C54j00D0Be0k04]@?01:
D3`0B4hj04M=>00204M==@0304I<=@17CCL0Adde00<0Addd00/0ADdf04A==`13CCH0ADlg04E>=`14
BcH0@d/e04=:<`13BC40@DPa03m7<@0203m6<00<03a3;@0j@B`0=CdX03<j9`0b>RH0<c`Y03@m:P0b
?2X0<C`Y030k9`0`>bH0<C/W0P0a?2L02`0`?2H0;cXU02li9@0_>2@0;cTT02hf8`0]=RD0<SXZ034j
;00`>2h0<3T]0080;CDX00@0;38U02X`8`0Z<2<0:S0R0P0Y<2801@0X;R00:BhQ02X^8@0Y;2409RXN
008092TJ00H08B@G020T600P91T08bHJ02@W6`0P8aTJooooo`0604YFI01=FFP0D5a]055LKP1AFg40
Deed0P1CGGD0101EH7P0E5mg05=NM@1DHG<205ESLP0505IUL`1IIgH0FFIg05QUM`1HIGD00P1IIWD0
2`1JIgD0FVQf05]YM`1LJGX0GVYn061ZO`1PK7h0HFem069^N`1TKgd0IW5o0080IW5n00`0IW9o06Mb
P@1VLH80IW6206QcPP1YMH80JWF306]gQ01/MXH0KGJ706igR@1aNX/207=kR`0;07ElR`1dOH`0M7j=
07F1S@1gPX/0N8:;07V2S01jPhh0NhF@07^4T@1lQI<00P1mR9D00`1nR9D0OhNF0869V@0208:;VP06
08B=W024SY`0QHnK08NAW028TId0RY:N0P2;U:002`2;UJ40S9JQ08bHX@2=VJ40SIRQ08nJXP2@W:40
TIfO09>OW`2EXJ40UZ6R0080Uj:S00`0Uj>T09RTY02IYJ@0VZNU09ZWY02IYZ80VZNO09^XWP2KZIl0
W:RP09jYW`2NZYd209jZV`0409bYV@2KYiT0VZRI09VWV080VZNG00D0VZJF09ZWU@1QHf00>cTo03Tg
>P0202`[;@0;02HV9`0S92H09BXY01dQ7`0T:R409bdQ020V6P0M8QH071lC01PJ3@0E5`/00P0B50T0
300A4`T03Q0700`>1P0<3`P03A4:010D3P0A5Pl04AH=00hB200;3`H020`200L:0@801`T000/02PX1
01hR400T:AH09bdH02L^600X<1P0:34I02H`6@0W<A/09c0L02<[6@0201lU5@0;01XO4@0B5``041@:
00lD2@0>4`P03A8600dA1P0<40H03A0600/=10092`<00P072@801P051`0010H100@600031@000P<0
004300oooooo000=ooooo`06082DSP26VY@0RY^J08^LWP2<WJ40S9bS0P2:VYl02`2:VY`0RY^L08^M
W@2:Wih0Rj6M08ZRV@2;XiH0RZ6B08bQTP1nT8@0?T=800806QTT00/071/Q01LE6P0D4AD04a4C01LF
5P0M7ad08RDR02`c;P0b>cH0>dDo041<A00203m:A00<03i7AP0mADL0>d=803Q0B00h@4L0>T=<03Y3
B`0g@4P0<3I002<W<@0M82P05ALM0P0B4QL02`0@3a<03`d@00l>3P0D5Q@09B/T028Y8P0P9b009B/R
02L^8P0T:b008RPN00807bDM00/07R@N01lT7`0O9Ah07B<K01/P5`0J7aD06AhC01XM4`0I6A4061PB
02<S6`0202<S6P0;03m3=01FHT`0D5m903i;>P13DSh0BEY104eO@@1:G3/0AeLe04MD<`15D3400P17
D3@204U@>00:04QA>019ECX0B5Hj04YG>`1=FSd0BeLk04YE>P1<ECX0C5@j04aB>`80Be0k00/0Be0n
04]A?`1:D3h0B4lo04M??P16CcX0ATlg04I>=P17CcH0ATld04M=<P0204M<=00;04I;=@16BcP0A4/h
04A<>P13BcT0@d`j049;=`11BC<0@TP`0459<012Bc000P13BC003012Ac00?dD`03a3<00i?bl0=3/[
034j:P0_>BX0;STZ02lj:@0_>bH0<3`T030l8`80<SdS00/0<S`T038k9@0b>B@0<CLT030g8`0`=R<0
;cHT02dc8P0/=2D0<3PZ02hh:@0202hg:00;02df900[<R40:2lN02L^7P0Y<Al0:C8O02/b7`0Z;ad0
;BlO02`_8@0X;Al00P0U:A`01P0Q91L0828G020R6P0S9Qd08RDM020Q71[ooooo00H0BUEW04eHJ`1A
G700DUeb059LM01BGG@205AOM@0;05EPM`1DH7H0EF1g05IRMP1GI7@0EVEe05MUMP1HIWH0FFIg05UW
M`1KJ7P00P1KJGP02`1KJ7P0G6Uj05eZO01MJW`0Gf]m069]OP1SKWl0Hff006I_P@1WLH00JG>10080
J7>100`0J7:206QbP`1YLh@0JgF506]eQP1ZMHD0JgN506iiQP1]MhL0KWV906mjR`1`NXd2079kS00;
07EnS@1dOhh0MX6@07J2T@1fPY00N8BA07R5T@1iQI00NXFA07Z7TP1lRI800P1mRi802`1oS9D0PXfG
08:<V@24SIX0PhbJ08B=V`24SI`0QHnM08RAW`2:U:40RiBP0080RYBN00/0RiJP08jGXP2>V:40SIVP
08nJX@2AVj<0TYfS09>OXP2FXJ80V:>S09ZTY@0209RRY@0<09VSY@2JYJH0W:RU09^XY02MZZD0W:VT
09^XX@2JYj00W:RR09nYX`2NZ:00WZVO0P2NZid00`2MZYX0WJ^J09^YV@0209VWV00609ZXV02IYYH0
W:ZH07N1MP0j>3`0=c@g0P0/:R`02`0V92H08b<U02lc<@0U:2P09BLT02DX8`0N7a/08RDN02<V7@0N
8AH06A/?008051D:00@04Q<900lA200=3`L030l70`0=4PP01@0>4`T03a8900dA200930<01PP10080
1PL000P02``301dR400U:aL0:BlL02/a7@0[<Q`0:c<M02Pa70809RlJ00h092`I020V5`0P9QL0728D
01TN4P0D6@h04AH;010E2P0@5@T04AD900hB1`0=40H030l500`=10802`h400@020X300L:0P062040
10H00P03100?ooooo`003Oooool01P1oUHd0QifF08ZOW02;Wil0SJ2R08fOXP80S9nO00/0SJ2M08bN
V`2<Wi`0SJ6L08bRV`2<Y9X0SJFH092WV02AZ9D0SjFB06alL@0202hb=@0;028T9P0P820061LH01DC
500D4Q8051<A01PH5@0L7QX07R<N02P_:00`>3000P0g?CH0300k@C`0?D=203i5A`0nATT0?dM:0417
C00oAT`0?TI=03m8CP0lADX0=cm202``=08092DZ00/07alU01XH800D4QX07QhQ02<W9P0J7Qh05a/H
01/Q6P0R:Ad08RPL020U6@0201lU6`0;024W7P0Q:1h082LL024X6`0P:1/082PJ01lU5`0L7a@06ATB
01HE4`0H61D00P0I6AH02`15D3h0GVmE04AA?`0]=BX0;3@X02/d9@0nBc80C5lm051R?P1AHSl0C5/k
0080Ae<h00`0Ae0h04QA>`17DCd0ADlj04=@>P14DSX0BULm04]G?P1:ESh0BeDo04]C>`1:DCX204M?
>@0;04Q@>`19DSd0BE4m04QA?P17Cch0ADhm04I@?016D3X0Ae4h04I?=@16CS@00P17CcD204I==@09
04I==`15CCT0A4/i04E=>P13BcT0@DTe045:<`11BC40@d/a0080@dXa00`0@TP_0457<011B380?TDa
03U0;P0d?B/0<3TY030i:P0_>2L0<3XU030k8P0`>R02030i7`0;034h8@0`>280;cHR02lg8P0^=R40
<3PS02lg8`0]=B80:cDQ02hf8`0^=R@00P0_=bH02`0_=bD0;C<P02db800Z<1d09bhL02D^700U;Qd0
:2hM02X_7P0[<1l0:BhO00809BXM00H082DI01hS5`0P91L08RHK020T6`0O8Q`Jooooo`0604]HJP1?
Ffh0DUid05=OM01CGWD0DEec0P1AGG402`1CH780E61b05IRM01HIGD0EfAf05MUN01FHgH0EfEf05QW
M`1HIgP0FfQj0080FFMh00/0FVQh05aYNP1LJG`0GV]m061]O@1QKG`0I6mn06E`P01VL840IW6006Ia
O`0206QbP@0506UcQ01YLX@0JG>506YdQP1ZMHH00P1[MHL01@1/MXT0KWV:06miRP1`NHd0LW^?0080
Lgb>00/0MGj>07AoS`1cOhl0MH2A07J2T`1hQ9<0N8FC07R5TP1jQY80O8VC07b9TP0207b:TP80P8fD
00P0P8^F08>=V@23SIX0PhfM08J@W`27T9h0R9:P08VDX0<0RYFO00@0S9NQ08fHX@2?V:00T9VP0P2B
W:801@2CW:80UIjT09JPX`2GXJ80V::S0080V:>S0P2JYJ@02P2MZ:H0W:RT09bXY02MZJH0W:RU09^W
Y@2MZJH0WZVU09jZX`2NZZ4209n[X00309jZWP2NZi`0W:VJ00<0VjRJ00D0VJVG09VYV025U8@0?Cm0
038b=@0202d^;P0;02PW9`0R8b80:R`Z02X];00T92H08B<T01lP8@11BSd0<3H[01lQ600L7a<00P0F
60`0300C50P04A<800lB200<40D03A4500dB1`0=40P03A4900lC2P0<40P020/300H80@801@L000D0
2`h501dT4P0S:QH09blI02Tb700202Xd700402Pa6`0T;AL08RXE01lV5080728C00/07B8C01`Q500K
7a8061dA01@H3@0B5P/04aD:014D200@50P03a8800d@1@0200X>0P0600X>0`0;3PD02`l500P:0P06
1P401@D13oooool000gooooo00@0Q9^A08VPV02:XY`0Rj:N0P2;X9h208^PW00;08ZOVP2;WiT0SJ2J
08fQV@2?XiX0T:FK092VV`2BZ9/0TZNI09BYV@28W8`00P1MJf<02`0h?cd0<3@b020Q8`0L6ah06ALI
01HE5@0G5Q@061TC01HG4P0I6QD07AlI00809BLQ00`0=3H_03/n>00oA3l0@TQ404=:B@15CTh0A4i@
045;CP0oBT`0?dY:0417B@10ATL203e1A00;03Tl@00a<CT0:2La02TZ<00T9BX051@K010A5`0B5AD0
51PD01DI5@0I7QL00P0L8AT02`0N91X07RDI01dT5`0P9QL08BTH02<Z6@0R9QP07b8G01hN600L71X0
7R0O00807B4P00/092XV02hg;@0U;2@09RXR02<W7`0L7aL06b0E02`f9016ES/0DfM905MZC00205AU
BP0<04iL@`19ECl0@Tdk03a6=P0jASH0?DTh049>>`16Dcl0B5E104YG@P19ED00B5Dl0P19ECX02`1<
ESX0BU@g04UB=`1:DSP0B4lk04I>?017D3d0Ae4j04MC>P15CcD0A4lc0080ATld00/0AThc04E>=015
C3@0Adde04I<=P15BcL0AD`h04A<=`14CCH0@T/d045:<`02045;<P0<049:<010B2h0@4P_03m7<00n
AS40?DDa03Y1;`0e?2d0<cTZ038i9`0`=bH0<CTV0P0c>bD0200b>R@0<3PT02/d8@0[=240:c<P02hf
8@0]=B40;SDR0P0]=2403P0^=B80;cDS02le8`0_=R<0<3LR02lf8@0]=1l0:c8O02T`7`0W;b00:30P
02T`800Y<B009RhM0P0U;1`01P0Q:1X07bDH024W5`0Q9QH08BDG01lS61[ooooo00H0C5UW04mKK@1B
Gg<0DUic059OM@1BGW82059NL@0;055NK`1BGfl0E65`05ERL@1EI7<0EFAf05ITMP1FIWL0EFEi05QW
NP1HIGX00P1IIWX02`1KJGT0G6Uj05aYO01OJgh0Gf]k069^O01TL7d0IG5n06A_OP1VLGl0J7:10080
J7>000`0JWF106]eP`1ZM8<0JWB506UdQ01ZMHD0JgJ606agR01^N8X0KWR906igR@1`NH`2079lS@05
079mS`1cOhl0M82@07J2T@1gPi800P1gPi<00`1iQY<0NhND07j9U00307j9U00;086;UP20RiH0Oh^H
086;VP22Ri/0Q8fM08N?W`29T9h0R92M08RAW`29TYl00P2<UJ802`2<UZ40SINR08jGX@2@Uj80TIVR
09>KX@2CVj00U9bR09NNY@2FWj@0V:6S00<0Uj:R00/0VJBT09bVYP2MYjL0WJRV09fXY`2NZJP0W:RW
09bWYP2NZJD0WZVT09nYX`020:2[XP0;09nZX02NZYh0WJVL09bWV`2LZ9`0VjVL09NVU`2GZ9L0RYV8
03m1@@0_<3400P0^;bl02`0Z:bX09RPU02LY9@0Z;BT08R@S01dQ800b>C80>T@g02/b9@0M81D06QdA
008051H:00`04Q<7018D200@5@P03A8500`A1P0<40L02a0800`@200<40L02Pd500H90@082@4200H8
000;00X>100L8a407bLD02@^6@0W<A`0:38K02Tb6P0Y<AX09RhG024W400N8`l00P0K7`l02`0M8180
82<E01hQ500M81<071lC01XL400F5``04a<9018C2@0F6@`05AX:00804AH600H04aP801@J2`0B5`T0
3A8600X<10051P4?ooooo`003Oooool01P21V8l0QinE08RPV028X9T0QijH08VPV080R9jG00/0R9bD
08ZOUP2>XYT0T:>K096UW@2BYYd0TZFK09>TV`2EYI`0UZNM09>UV`0208VKT@0907V:P01GHUl0>3a0
02h`=@0T92X08R4S01dL6P0K6QH061PE00805QDB0P0E4a40300M6QD09B<M02l`:P0i?CH0@4I0049;
A`15Cd`0@4];03e8B@0nBDX0@4U;04=9C080A4U<00/0@dQ<04=6B`11@d/0?3m802`^>@0N7RX051HP
00l@600>3QD03PlC010B4P0201DI5@0;01XO6@0N8Q/07B<I01hT600Q:1T092XK02@X6`0T9Qd09RPR
02PY:@0X:R`00P0Q9BL02`0I72005aTL01LI700M7ad07R0K01/L6@0H6aL05a/G024X7P0b?Bd0?T`g
0080CEi400`0EfU=059RBP0f@C40:S<V02H_8`0X<B@0;3DX03M3<@0nBcD0AE8k04MD?@18E3d204UE
>`0;04]I>P1:ESL0BE@e04UC=@17D3L0B54i04Q@>@15CcH0AU0h04I@=`16D3D00P15Cc@02`14CS<0
ADld04E><`16C340A4P`04A:<P17C3H0AT`f04M>=@16CSD0ADde0080A4/d00`0@d/c03m8<00nARl0
?DD_03m7<@10B380?TH`03Y2;P0i@2h0=S`Z03@i:@0c>2P203@j:@0;03<j:@0b>bT0;CLV02Xc8`0[
<R00:c8N02`b7@0]<ah0;3<N02/c7P0]=1l00P0`>2402`0`=b00;cLP02he800]=B80:c@S02P_8P0U
;2008b`O02L`800V;ah08b/J008092`K00H08b/J01dT5@0M91D082DD024U500P8a@Jooooo`0604eH
IP1?FVd0DUmd05=PMP1DHGH0EF9e0P1DHG8205=QK`0905ASK`1EHg40EF=d05ETMP1FIGP0EfIi05MV
N01IIgP0FVMh0080FVQi00/0G6Yi05eZN@1NJg`0H6am065]N`1RKW`0HVmk06=_O01SKgd0IG5o06Ma
PP0206UdP`0<06]fPP1ZMX<0JWB306]eQ01ZMH@0IgB306YgQP1[N8P0KGV906mjRP1`NX/0KgV;0P1a
O8l02`1cOY40LgnA07F1T@1ePY40Mh>B07R5T`1hQ9<0NHBC07b6U01nQiD0OhVF0080PHZH00/0PHZI
082:V@1oRYX0P8VK086:W024S9`0QhjM08R?W@29TId0Ri:N08^CWP0208fEW`0;08jFX02?Uj40T9RR
09:JXP2AVJ40U9bP09BNX02FWj80Uj2S09NQX`2HXJ@00P2HXj<0302HY:D0W:NX09bVY`2LYZL0WJNW
09jYZ02NZJL0WJRU09fXYP2NZJ<0WjRS09nWXP80XJVQ00/0XJZP0:2ZX@2OZ9h0WZRL09fYW02LZi/0
UjRG09NZU`2>Wh`0ADY603Lk=`0203Lk=@0;030c;`0Z;2L09bXT02da:@0R91l07AhJ03Y2<`0lAC<0
=3`X028V5@0K70d00P0E50T02`0A4@L04A@900hB1`0=4@D0314500/A1`0;3`H02`h600X>1@082P<0
1`L100<020P000/01`P101TM300R:AH09RhL02Pa7P0X<A`0:c@L02/c6`0W;QT092TD028V4P0201hQ
400;01lR4`0S9QL09BPJ02@Y6@0U:aX08bHG01lP500I6@l05QL=020T5@0U:AP00P0Q9AD01P0Q9Q80
7RDA01dS400G7@`03a<600H90@oooooo000=ooooo`0608>HT026WID0QijG08JOV@26WIL0QifE0P29
WYH02`2:WYL0S:2I08fQW02=XI`0Sj>K096TW02CYI`0U:BM09NWW`2FYYl0UJFM0080U:FK00/0TjFJ
08JHSP1_OGL0D5UH03Di?00a=380:B/U024R7@0L7AT06AXF01LE500201HB4@0<01HA3`0G4A006aLD
02PT800e=S00>3hi03i6@P11C4L0@Te:045<B`12CD`0A4a<0P14BdX02`14BDT0ADU;04M8C`15AU40
@D=>03PkA`0[;cT061XV01@D7`0A4AT03a0E00804A8E00/05QTI01/O7@0M8Qh07R@M024W7P0S:Al0
92PN02@U7P0_<R/0=SXe03Hj>P0202T/<00;01lO9@0H61l05ADJ01LH6`0J71/06AdI01TO6@0J81X0
5Q`F01TP5P0N9aP00P0T;a`0300nCC@0B5Tn02hi9P0R:Q/072<F01PO4`0F70l092`L038k9`0nAc00
AE0h04QB?080B58m00/0BEDl04YF>`1:EST0BE@h04MC=P19DcH0BU4f04M>=016CCD0Adlg04E>=`02
04=<=P0;049<=P13CCL0@d`e049;<@10B2h0@DP^0498;`13B2h0ADXa04I;<`16BcD00P16BSP01P14
BCP0@DLf03i5=00lA3<0?4@`03a5;P<0?DD^00<0?D8/03/n:`0h>RX00P0f>2X02@0d>2`0<SP[02de
9`0/=2@0:c8Q02Xb7P0Z<a`0;3DM02Xd6P0202Pa60<0:c@K00X0;CDO02dd8@0/<b@0:c<X02H]9@0R
:B408RTP02<Z800S:b0092dN0P0T;A`01P0S:aP082PE024Y500S:18082@@01hQ3Q[ooooo00H0CEQW
04mJKP1CGW@0E61g05ARM`1EHWD205=PLP0;05=QK`1CHFh0E6=_05ETLP1DHW<0EVAe05UWN01JJ7X0
FFMh05UWMP1KJGH00P1LJGD02`1MJWL0GVYg05eZN01NJWT0H6ai065^N@1QKWX0Hfmk06EaO01WLWh0
J7>10080J7:300H0JGB506YeQP1YMHH0JWF606UfQ`1XMXP206YhR@0406ejRP1^NXT0KgZ:071jR`80
L7^>00/0LWf?07=oT01dP8l0MX:A07R3U01iQI@0NHNE07V4U01lQiH0OXZG07n:U`02082:V@0;086<
V`20Ri`0Oh^L082;W021Ri`0Q8bM08N>W`27Sil0R92N08V@W@2<Til00P2=UIh02`2?Uil0T9RQ096I
XP2BVZ80TIVQ09BLY02EWZD0U9nU09FPY@2FXZ@0VJBV0080V:>V00`0VJBW09ZVY`2LYjH0WJRW09jW
Z02OZJT0WZZX09fXY@2NZJD0WjVT0:2ZY02OZJ<20:2YX`0;0:6[XP2QZZ<0WjRQ09nYX02NZId0W:ZK
09VZVP2GZ9L0U:JA059HDP0e=cL00P0g>SH02`0^;b`092DR01hO700a=B/0:RhS020R6@0R9AX0@ddd
04MC=@0N80l07Ah?008061L<00<051@;01<D2P0A4`T00P0>4PD01@0<4@H02`d500X=1@0:30@020T2
008020H00P081`402`061P0061`?02<Y5`0X;a`0:C8N02Tc7@0Z<QX0:C8I02D^5P0R:QD08BTD0080
7R<C00/08BDE02DZ6@0X;Ad0:S0O02/b7`0/<Ql0:BdM02DY6P0Q9AT0:30P030h900202hd8@0602T`
6`0X;AP09R/F024W500F6P`01`P13oooool000gooooo00H0PiR@08JMU@27WYL0QYnI08JMU`27WID2
08VNUP0;08ZNU`2<X9T0SJ6L08fQW02?Xi/0TJBL09>UW02DY9d0UjNO09JVW`2EYId00P2DYI/02`2C
YIX0QYR>06mmM`1@FEP0=CTl034d<P0Y:bD08B8M01`M6@0I6QH05aDD00805Q8A00`05Q4?01LA400K
5a@0:2@P03Df<00h?ST0?TI2045<A`12CDX0@Da;049=C014C4`204A;BP0;04A9B@15BD/0AdQ?04E6
D@11@dh0>3]702/_>@0H6RH051@O014A6@0?41D00P0A4QD02`0F6AT06alM01dR7P0N91d08BLN02<Y
7`0T:1h092DN02lb:`0f>SD0=SXj0080:B``00/07alU01PH7`0E5AX05aPK01XL6`0I7AT06AlI01XP
6P0F71H06B0F01hW600202@_700<03i==018FCh0;STV028Z6`0L8aH061lC01HL3`0T;1`0<S/W03i7
<015D3P0B58l0P18DSd02`19EC`0BUHk04YF>@19E3P0Ae<f04UC=P1:DCH0Adhd04I==@17CcL0ADhg
0080@d`f00/0@T`f04===`13C3D0@T/a0418;P11B2h0@TP_04=8;P15BS40AT/c04I;=@0204I:>006
04A9>011AcH0?TDd03a4<`0lA300?4D^0`0mABh00`0m@R`0>ch[03Pj:P0203Hh:P0903@h;00b>2/0
;CDW02`d900[<R40:S8N02Xc700/=Ad0:S@J0080:34H0`0[=1/02P0]=Al0;C@Q02`c900[<bP09RdU
028Y8@0R:B008bXP02<[800T;Ah202@]700602<[600P:1D08BTD02<X4P0P91007R4>6_ooool01P1=
F6L0CeY^05=NM01DH7L0E69g05ERM@80Df1b00/0Df5_05=QKP1DHfl0EFAb05ARL`1FI7D0FFMh05YX
NP1IIgP0FFMf05]YMP0205aYM@0;05eZM`1NJWL0GFYh05iZN@1PK7T0HFii065^NP1SKg/0IG5l06Mb
OP1XLh400P1XLX<01P1YM8D0JWF606UeQP1ZMHH0JGJ706QfR080JWR900@0KGZ:06ijR@1_NXX0L7Z;
0P1`Nhh02`1bOHl0Lgn@07B0S`1fPY40N8>D07V5U01iQiD0NHBD07b7UP1nRYL0OhZG0080P8ZI00/0
PHbK082;W01oRi`0P8^L086;W024S9d0QhjO08N?W`28T9h0RI2M08bCW`0208fEWP0;08nGW`2@V:40
TIVR09:JXP2AVJ40U9bT09FNY@2DWjD0UJ2U09JRY02IY:H00P2HXjH0302IY:L0VZJW09bWYP2MZ:L0
WZNX09nYZ@2NZZP0WJRU09jYY@2OZJ@0X:ZT09nYX`80X:VS00/0XJ^R0:6ZX`2OZ:40WjVP09jYW@2L
ZY/0VJZJ09NXU`2DYY40DUQB03Dg=`0203Lj=P0;02h_;00T9B807QlL034e:`0Z;R<0828I028U6P13
CC@0Ae<e01hP3`0M7Pl00P0H5``00`0D50/04a@:014C2@0200hB1@0500`A1P0;3@D02Pd500X<1008
2@800P081P0200P70@0;00H6000H70l08bTG02P_700Y<Qh0:C<M02Xb6P0Y<QT09BhF028Z5@0Q:A@0
0P0N8a<02`0Q9AD09BXI02P]7@0Z<1l0:c8O02`b7`0Y;Ad09BTJ024U6@0X<200<3PT0080;S@Q00H0
:C0K02P]600V:aH08BLD01HJ3007204?ooooo`003Oooool01P21Th/0QibC08ZPV@29X9/0R9jK08JK
VP80QYbJ00T0RIjM08bPWP2>X9l0Sj:P08nRWP2AXih0U:FO09FTWP2FYIh00P2FYYl209NXWP0;09FW
WP2FZYl0TZJK08:CR01XMVh0F6=J04YDB00/<R/09R`U01dP700I6AP00P0G5AD0300H4a<05a8A01PB
4P0J5A@081dJ02HV8`0/;bd0=3Xf03Y1?@10BD@0Ae1;04QAC080B51;00/0ATa:04I9BP14AD`0A4E=
04=6C`14BU@0@TQA03Y0AP0X;3@08RD[01/N900201<D6`0;018D700K7b@082HX020W9P0R:BH08RXT
024X8`0Q9B00:B`V03Pm=P0nA3h00P0k@Cd02`0`=3<0:Rd]01lP8`0L7B006ahP01TL700G6aT05APF
010E400D6A406R4D008061l?00`07B@E02H_7@0S:a/06B0C01PN4@0I81<06AlC01dT5`0Y<B00=ClX
03a7;P10BS82049<=@0804QB>@1:ESX0BeHi04]F>@19DcL0C5Dg04]C=P19CcD204Q?=P0>04I>=`15
CcP0ADlh04E?>@16D3T0ATli04M>=`14C3@0?TD_03a2:`0m@RX0?T<[0456;`12Ac4204A8=00<04E;
=`14BSL0@4Lg03m6=`0mACD0>d<`03]3;`0k@S00>d8_03i5;`0l@B`0>Sh/0P0j?Rh02`0h>bh0<cT]
038h;00c>B/0<3LV02de8P0^=B40;cPR02lg7`0]=Ql0:c<N0080:c8O00/0:S4N02Xa7`0[<R40:c@T
02/d9P0Y<RH09blT02D]8P0T;2008b/M02H^7@0202D^700602D^6@0T;AL09bhE02H/4`0S:1008BD?
6_ooool01P1;F6D0CUY[059NLP1CH7@0E61e05AQM080Dema00/0DUm_059RK`1BHW40EVAd05IUM`1G
IGT0FFMk05YXNP1JIgX0FfQi05]WMP0205aXM@0;05iXM`1PJWT0Gfak05i/N`1OKG/0HFmk065`N`1S
L7`0Ig9o06UcP@1XLh400P1WLX@01P1XLXD0J7>606QcQ`1YMHP0JGJ:06YgS080KGV=00@0KWZ>071l
S@1`O8`0L7b<0P1aOHd02P1aOXh0Lgn?07B0S`1fPI00NH:A07Z3TP1jQY<0NXFD07b6UP1nR9L307n;
V00;082:V`21Ri`0PHbK08:=V`24SI`0QHjN08B>W`25Sj00Qi6Q08VBX@2<UJ800P2>UZ402`2?UZ40
TIRS09:JX`2CVj80Ti^S09BMY@2EWJH0U9jV09FPZ02GXjP0UjBX0080UjBY00/0Uj>Z09VUZ02KYZP0
WJRX09nZZ@2QZj/0X:ZY0:2ZZ02QZJD0X:VT0:2ZYP030:2ZY`0;0:6[Y@2QZj@0WjZR09nZX@2NZih0
WZ^K09^ZV@2IZIL0VJ^G061YHP0e=cX00P0c=SP02`0X:2T0824N01PF5@0Y;B<0<CHX02db8`0R91P0
>D0[059P@00P8QD07AhB00806AP@00`051D=01@D300B4`X04187010C1P0>4PL03Q4700d?1@0:2`<0
2PX300`:0`0=30<200`;100;00P90P0G6`d08bPE02T_6P0[<A`0:S4K02L_600U;aH08BXA01`U400I
8@h00P0J8A002`0P9aH09B`K02X_7`0/<b40;SHR034i900^=R40;3@O02he8@0a>RH0>40/0080=SdX
00H0;SDO02X_6P0X;1P09b/H01dQ4@0@4@H?ooooo`003Oooool01P23UH/0RinF08bSW@28Wi`0QIfM
08JMW`80QYbN00/0QifO08ZOW`2<X:00Sj:Q096TX`2BYJ<0U:JR09FXX02EZ9l0UZNN09RXX@0209RY
XP0;09RZX`2GZj80UJZP09FZW`2AYYX0RIf@07Z=OP1OKf80BE9:03@g=@0/;Bh00P0U9BL0300N6ad0
7AXK01lN7P0O7Qd07ahL01dM6P0N7Q`08B8P02PZ9`0f?3H0@4Lo04M>AP80C5==00/0CE=A04Y>D@17
BU40A4QB0416D015CUD0A4iC04E@D@13CD/0?dM503To@@0202`_=`0;020Q;@0W:cD09R`d01hU:P0L
8b@06b@Q01`S7`0L8Q`06adJ024S800^<Bh00P0g?CP203]3?00903Hm=`0^=34092XY01dQ8P0G71`0
4QDE00hA3`0A5A005Q/C00805adB00D06QlD024X6`0U;1h08BPK01`T5P0201`S5`0502D]7`0a>bT0
=d8/03]6;P0nB2d00P10BB`02`15CC40B4lb04Q?<P1:DC@0C58g04aC>@1;DSP0BE4h04QB>018DSL0
BE@g0080B5<g00/0Ae0g04YA>P1;DC`0C50l04Y>>`16BcT0@dPg0457<`0oAS00@4L`03i7;`0203e6
;`0<03m8<00oB340?dLa03m7<`0oAS<0>d8a03a4<`0nASD0>D8`03Y3;`0i@Rl0=d0^0P0i@Bl02`0i
@300=cl^03M0;P0i@Bd0=clZ03@l9`0f?BT0=C`Y03<i9P0b>BL0<3PX0080;CDX00/0:C8U02Pa900X
<B@0:34R02Pb8P0Z=2<0:C<S02Tb8@0Z<b00:C0N02T^700202T_700602P^6`0X;AT0:2dG02L/5P0V
:QH09BPF6_ooool01P1=FVD0D5eZ059PKP1DHG40EF1d05IQM@80EF5c00/0E65a05ITLP1GIW@0F6Eg
05QVN@1HIWX0FVMi05YXNP1LJGX0FfQi05]WN00205eXN00;05mXN`1QJW`0HF]m065[O@1QKGl0Hfmo
069`OP1ULH00Ig6106QcPP1WLh800P1WM8@0301WLhD0J7:706UbR@1YM8X0JGB;06afS@1^Mhh0KWR>
071jS`1`NXd0L7^<075lS080LWj>00H0M7n?07F1T01fPY00Mh>@07V2S`1kQHl207j7T@0307j7T`1n
QiD0PHZG0080PXZI00D0Ph^K08B<VP26Si/0QXjL08J?W@0308J@W`0308RBXP29Tj@0S9FV0080SYJV
00/0SiJU092HX`2AVJ80TYZQ09>LXP2DWJ<0UIfT09FNY@2FWjL0Uj:Y09RUZ00209RTY`0609ZVZ@2M
ZJX0WJRW09jZY`2OZjP0X:^X0P2PZZD0102QZZ<0XJ^S0:2ZX`2PZZD20:6[YP0;0::/Y@2PZj<0WZZQ
09jZW`2NZih0WZbL09b[VP2JZYP0VZ^H06UcK00g>3h00P0`<SD02`0R92@07R0M01LH4`0O8QL09bXM
02hd8`0U:A/0Ae0i08fVN@0d>bX04Q8<008061TB00`04a<<014@2@0@40L04Q88014C1`0A50L051H9
01@F200A4`P04A8801HH2`0I7@h201HI2`03018D1P0O8a409b`G0080:S0I00H09R/E028X4`0O:140
6b8=01PO300G7@/201hT4P0602L^6`0Y<200:c8Q02dd8P0`=b@0<CTT0P0_=R400`0b>B<0=3TU03Hm
:00203@k9`0602le800Z<1`09b/I02T]6@0W:aP071l?3oooool000gooooo00H0QibB08fSV`2<Y:00
S:>S08ZRYP2:XJD208VOXP0;08NMW`29WYl0Rj6Q08nSXP2AY:80TZFR09:VX@2DYj00U:NN09NYW`2I
ZZ800P2JZZD02`2I[:L0V:bV09N[Y@2G[:@0UjfU09N]Y02F[:00TjRI07Z:P01/NG00IgA[0080AD]=
00`0<S@l03Lk?`0m@D<0<C<f02`^;`0Y:bX09bTU02HX8P0W:B<0:bhW030b;@0h>S@20453?@0;04Y<
B01=Cdl0CU9E04]CEP15CU80@Ta>045<C013CT/0BEA@04YCDP1:DE@00P17CU@02`0nA4`0>T5902L]
>00L8R`051/Q01<J700D6QP04aLE014@4P0C4A@06QLI0080;B`Y00/0>cli03a2>`0nACd0?4Dm03Hn
>@0]=3@09B`]01/Q8@0A5A@03a<@010C4002018F400<01hU6P0U;1l0:C0Q02L^7`0S;1/08b/K020W
5`0R:1T09BTJ02X_7@0]<Ql0=3TS0P0h?RD0200nA2X0ADX_04M<<P17CC80BDhc04Y@=P1:DCP0BE4h
0P17D3L03P18DcL0B58g04QB=`17D3H0B4li04Y@?@1<DT00Be4n04Q>?014BcP0@TTe045:<`11Bc<0
?dXc0P0mB3<01@0mB340?4H_03a6;P0mARl0?DD_0080>D8^00D0>d<`03Q1;`0f@2d0=3h/03Do;@02
03I0;@0;03Do;00c?R/0=Cl/03Ho:`0e?bX0=3dZ03Dn:`0g@2d0=cl/03Hl;00c>bd00P0`>B`02`0_
>B`0;CHZ02Xc9`0X<B<09BhO02H_7P0X<Ah0:S@O02Xd7P0Y<Q`0:C0I0080:BhI0P0V:aT0100V:aP0
92PF02HX600V:AXJooooo`0604YHHP1>G6L0DUm^05APL`1FHGL0EV5h0P1EH7H02`1DH7@0EV9c05QU
M01IIGD0FFIf05YWNP1KJ7`0FfUl05aZN`1NJWP0GFUh0080GFQj00/0GfUn061YOP1RJh00HFZ0069]
P`1SKX<0I6n306A`PP1ULH40Ig>106IdP`0206IdQ00606MdQP1WLhL0JGB906]eR`1[MH`0K7F<0P1^
Mh`0101_N8d0KgZ=071kS01aNh/2075lS00;07AnSP1eP940MH:A07F0T01gPY00NHBA07Z4T@1lQY80
OHNE07n9U`20RYP00P22RiX01@23RiX0Q8fK08F>V`24SI/0Q8jL0080Q92P00@0Q92O08NCX@2:U:<0
SIJV0P2=UJH02`2?UjH0TIVV096JY@2?VZ<0TIfT09:NY02DWj@0U9nU09FNYP2EX:H0UZ:V0080V:BV
00@0VZJX09^WZ@2LZ:P0WZZW0P2N[:L01P2N[:H0WjbT0:6]Y02P[:<0WjbR0:2[X`80XjbU00/0Y:fU
0:6/Y02O[:<0Wj^Q09n/X02O[9l0WZ^N09bZW02M[9/0MX5g03Ph?@0203<f=@0;02L[:00P91h07AlG
01`L4P0M7a<0=clZ03m9<P1<FCh0UK6104AA>P0@4@X00P0K7Q80300E5@X04A84018B100C4`D04Q<6
01@F2@0E5`X06A/<01TK3P0H6@h08RPF02@/60808BTE00/082HB02L]6@0Z<A`0:2lJ02@Z500N90h0
6b4=01dT3`0N9A407bD@028W4`0202L/6@0;02/_7@0/<B00;38R02lf9@0b>2H0<CTU030g8`0`=R<0
<SPT03@i9P0h?RT00P0f?BT01P0a=bD0;C<R02T_7P0W;a`0:2hK02@X5`oooooo000=ooooo`0608NN
UP2<Xi`0Rj:O08bSXP2;XJ@0RZ2T0P29WZ@02`29WZ<0RYnQ08bQXP2=Xj80SjBR092VX@2BZ:00U:VP
09:VW`2EZ:80V:ZT0080VJZV0P2H[:T02@2I[JX0V:bZ09R/Z@2J[ZX0VZnY09Z_Y@2J[Z80RY^A07F2
O00206E_KP0<05UPI01bO7L0N8Al06I^K01PJVH0Ef9I0458@00f>S80=3D^034`:`0`;B`0=34_0P0e
<c402`0j>CP0?clo04M:BP1<De80C5MD04YFD019EDd0BEA=04aFDP1=EEH0C59H0080C55K00/0C5AM
04UDF`0oBU80=D1802@^=@0P:2/05a/N01@D600B3aD05a4E01XD5@0203Dc:`0;03Xi<P0c<Rl0<C0`
038d<P0i?SX0?DE003]6@00b?SP0624M014G4`0?4`l00P0>40/0300L8aL08BLI02<Y6@0W;AT0:2lK
02P`7@0Z<1`09bdJ028V5P0Q8aD07AlA01hP4P809BLH00/0=S/W04UB=`19DSL0BU@i04YC=`19DCH0
ATde04I<=@16CCH0ATdg04I@>00204A>=`0;04E@=`17DC/0Ae4m04QC?@18DS`0AU0i04A>=`13CCD0
@T`d045<=012CSD00P10C3@0300oBc80?DX`03a8;`0kARd0?DH]03e5;P0k@bd0>T<_03Y2<00h@C00
=d0^03Q2;`80>4<_00/0=T8]03A0:P0c?bT0=3lY03@n:00c?BT0=ClZ03Ho:@0g?bX0=Sd[03Dk:`02
03<j:`06038k;00_>2X0;CHY02`e9P0X<R80:34P0P0Z=2000`0Y<Qh0:S4M02X`700202/a700602T^
6P0V;1L092/E02DZ5P0U:QL09R/J6_ooool01P1<F6D0Cea[059OL@1DGgH0E5mg05EOM`80E5if00/0
EEmf05MRMP1HI7L0F6Ag05UUN01JIWX0G6Ul05eYO@1MJW`0GV]k05aYN@0205aXNP0;05iYOP1OJGh0
H6Yo069/P@1SKX80Hfj306=_Q01SKh<0Hg6206AaP@1ULh800P1WMHD0301WMHP0IW>606MdQ`1YMHT0
KGN:06ihRP1]Mh/0KWN=06mhSP1`NXd0LGb=079mS080LWj;00/0M82=07J1T01fPY80MH6A07J2S`1h
Q900NHFC07Z5U@1lQiP0OHRH07n:V@0207n:VP0;086;V`23SY`0PhfL08>>W022SYd0PXnN08>@W`24
TJ40QY>S08VEY02;UJD00P2=UZD02`2?V:D0SiVT08nIX`2=VJ<0T9bT096NY02CWj@0U:2U09BPYP2E
XJL0UZ6X0080Uj>Z00`0VjJ]09bV[@2LZ:T0WJRX09j[Z@2N[:T0WJ^W09j[Y`2Q[:D0XJbS0:6/XP2R
[J<20:B^Y00;0:B^X`2S[J@0XJbV0:2[Y@2OZj<0WjZR0:2ZX02NZIh0WZbN07f7OP0m?4800P0h>CX0
2`0X:BP08R@O01hP600L7A407b0C04]G?01CH4<0DUm308FOLP16DSP05aT<00807Qh@00`06AP801DE
100G5`H0824@02LY6P0K71806adC02<W6@0S:QX082LF02H^6P0Y<A/202Pa6P0;02Xb7@0[=1d0:S<N
02P`6`0R:A@072<>01hV400S;1D09RlG02Xb6P0/<a`00P0]<b002`0]<R00;C8Q02le9P0b>2X0<cTY
03Dl:@0c>BL0<3HT038g9@0h?R/0?TD`0080>T8/00H0=C`Y02le9P0Z<2809bdN02H/6`0U:AX?oooo
o`003Oooool01P24VY<0RJ2I08^QW@29WYh0QibO08NMX0<0RInR00X0RInP08^QX02=Y:@0SjJV096Y
YP2BZZD0U:^S09FYY02GZZP0UZVX0P2FZZP02`2HZZT0VJ^Y09V/Z@2J[J/0W:n/09j`Z`2O/JX0W[2W
09nbYP29VY00HVaZ0080HVYZ00`0Lgei09:PU@2FYIT0V:RL09ZZW@2EYiL0Lh1g05QQG01CFeD0CE9<
059FC@15A3h203Tg=00;03Dd<P0f=3@0?3Xk0493A015BTT0B51;04eGC01AG4l0DUeC051HE@1<DeH0
0P1:D5P02`1?EEh0D5QQ04aFH01:EEh0A51E03e8B`0b>S`0:B``028P900N61`09B0P0080@D0i00/0
;bXZ02DQ900Q72407ATN02<S900]<Bl0=3hg03Q4>@0[>2`05QlG01<I3`0200dB200<010E2`0C60`0
51P;01PM3@0N91@08BPH02<Y6@0O9QL0724F02H[7`0U:Qh08BDK0P0O8AP02`0_=2H0EF=605]XB`1K
J4/0Ef=9055JA019DCh0AT`j04=:=`13BSH0@4Le0080?dLd00/0@4Tf049;>015Cc/0AU4k04QB>`16
D3/0A4hh049<=@10C3@0?d`c045?=002041?<`0<045=<@10C340?dX`03m9;P0oAbl0@4La03e3<00l
@S<0>T8d03Q1<P0h@S00>D@a0P0f@Rd02`0f@B`0=T8[03I2:@0g@BL0=clW03Dm9`0d>bH0<STU03@k
9`0d>bP0<c/Y0080<S`Y00/0<S`X02lh9P0]=RD0;3DU02Tc8P0Y<R009c0N02P`7P0Z<1h0:RdM02X]
6`0202X^700602P/6`0U:QL08RHF02DY6@0U:QT09BXJ6_ooool01P1>FFT0D5a]05=PL`1CGgD0E5me
059MM080E5ie00/0EF1f05IRM`1HIGP0EfAh05UUN@1KIW/0G6Ql05aYO@1NJWl0GV]n05aYO00205]W
O00805eXO@1NJGh0H6]o065/P01SKh40I6n106=`PP1TLX@206EcP`0<06EbPP1VLh<0IW>306QdQ@1W
MHD0IgB406QcQP1/MhT0KgZ;06miS01_NHh0L7Z=0P1aNhd3079nS@0;07B0S`1fPY00N8BB07R3TP1h
Phl0NHFA07Z7U@1lQiH0OXRI07j9V`20RY/00`21Ri/02P22SI/0PXfL08>>W`23T9l0Pi2N08FAW`27
Tj<0R9BU08ZDY@2<UZH2092HZ00;092IYP2AVZH0TIZV09:MYP2AWZ<0TZ2Q09>PX`2DX:<0UJ6T09NS
Y`2HXjT00P2IXjX0302KYJd0WZN_09jX[02OZZX0X:^Z0:2[Z@2OZZP0X:^X0:6/Y@2QZj<0XZbS0:>/
X`80XZbS00/0XZbR0:>]XP2R[:@0XZbV0:6ZY02QZZ80XJ^Q09nZW`2P[J00PXV1040nAP0203Ph?00;
02d];@0Q8R407QlK01XJ4`0Z;Al0FFM805=P@P1;ES/0HgA@04mI>P12Ab/00P0b<Q`0300X9Q808Ah=
03Hh901DG4<0CeQ201lP600P8QT0:c0S02/b8P0Z<R00:S4N02`c7P80;3@O00/0;CHP02/e7P0Z<Qd0
;CHO02de7@0Y<1T0:C4J02Xc700[<a`0;SHN02he800202hd8P0;02db8@0^=280<3HU03<i:00d>bT0
=chZ03Hl:00f>bL0=C/V03i7<010BS800P0h@R/01P0c?BP0;3DS02H]7P0T:Q`092PK028U60oooooo
000=ooooo`0608FGU02:WYd0SJ2S08^NY029W:<0RIfR0P2:Wj402`2;X:00S:2O08jQX@2?XZH0Sj>X
096VZP2AZ:T0TJNV09BXY`2H[:/0Uj^/0080Uj^[00/0VJ^[09b]Z`2L[:X0WZj]0:2`[`2P/Jh0X;2/
0:2aZ`2Q/j`0UJFO07AoO`0206igM`0<08>?RP2M[:40WZbR0:>`Y`2V]:X0YkFZ0:6]YP2DWiX0Qi2=
08:<QP2=VhX0I6aO0P1;D4H02`15B400@40k03ll>P0m>SX0?3Xl03hn?@13Ad40BU1704mHC@1@FU40
CeQC0080CUEF00/0DeML05=GG@1>DU/0CE=M04aFG@1<F5`0BeQH04IBD00m@d80<C4d03@b<`020410
>`0;02LS9P0P7B806aPO01DB6@0C4QH05AHH01XN700P9Ql08RXP01TS6@0E71400P0F7@l0300D6Pd0
4aP<01<H300D5`/05AP=01LK400H71405AT?010C3@0F6a@07R<J028W70808bLL00/0:c4S03i6=01E
GdP0G6Q@069`F01PL5P0F6EA04eEA011ASH0=SX/03<f:00203Dh:@0;03Pk;00l@300?dDc04=;=`16
CSX0A4hl049>?@0oBcP0?ddf03m><`0oCS000P10CRl03011CBh0@4`^0459;P12BRl0@DLa0415<`0m
A3@0?4<e03]4=`0g@S@0=D0_03E3;@80=D8[00/0=D8Z03I2:00h@bT0>D8Y03Ln:00g?2X0=3TY030g
9`0_=bH0<3PW02hi:00202dh9P0;02hj9@0_>R<0;SPQ02hg7`0[=1d0:c<L02Xa6`0Z<1`0:blM02//
700];Qd00P0];Ad01P0[:ah0:2TK02LY6`0W:Qd09R/M02@X7A[ooooo00H0CUQZ051LL01BGg@0DUic
05=NM01CGGD205ANM`0;05IQN@1EHGL0Ef=h05QTN@1HIGT0FFEj05]WO01LJ7/0FVMj05aYN`1MJg`0
0P1MJW`02P1MJWd0GVYn05iZO`1MJWh0HFj006=_P01TL800I7:106EbP@1VLh<306MdP`0<06QcP`1W
MH@0JGF606]fR01]MhT0KWR906mhRP1`NH/0L7Z:071kR`1aO8d0LWf>0P1cOY002`1cOY40MX6D07N2
T`1iQI80N8B@07Z6T@1kQiD0OHNE07n8U`20RYX0PHZL00<0Ph^N00L0PX^M08>=WP23SIl0Q92Q08BA
X026Tj40RIFS0080RiFV00h0SYNX092GZ02@UjP0TYVX09:JY`2BVZD0TibT09BOX`2DXJ40UJ:Q09NS
XP2IY:D0V::U09VSZ080VjFZ00D0W:J[09fV[@2NZ:d0Wj^[0:6[Z@020::[Z@050::[Z02Q[:L0X:^U
0:2[Y@2QZj@00P2S[:H02`2R[:D0XjbT0::/Y02S[:@0XJZQ09nZX02OZZ40WJZO09fZV`2=V8/0AdQ<
0080>3Tm00/0;S0a02<U900L7A/05QHC03Hm;01FIDP0E69604eJ?`13CCD0BeDj06=`C00205eTA00<
05EH?00m>BX0PXi^08RIN@1;DT<0;BlV02LX7`0^<RD0;c@U02le900/<b<0:c<S0P0/=B@02`0_>BD0
;cXU02hh8`0`>R40<3TP02dd7@0/<Q/0;C@M02dd700/<a`0;C@N0080;C<P0P0]<R402@0^=2<0<CPV
03<i:00d>bP0=SdY03Hm:00f?2L0@DTb03i7<00203Dn:006038l9P0Z<b0092`K02@Y6`0U:1d08R@K
3oooool000gooooo00H0QYNH08^LX02<WZL0RifX08ZLY`2;WJH208bNYP0;08jPY02>XJ<0Sj6T092R
YP2@XjL0SjBW092VY`2?YZL0TZJW09JZ[02EZjh00P2FZZ`02`2H[:/0Vjj[09^]ZP2M[:/0Wjj^0:2`
[`2R/[00X[>]0:Bd[@2Q/J/0VZVT0080UJ:M00`0UjFM0:6aYP2S/JT0YkB]0:Re[`2Y]:l0ZkF`0:Vb
[P2Y/jd0Yk6Y0:FcY@2EY94208JBO@0;06Q_H@1QIUT0GV1F05AEC@1<CDL0@T8l03i0=`0n?cL0@TDl
04M<@`1<DD/00P1?EE802`1CFET0EEYL059IG01@Ee/0C5EH04YFE`1;FET0CeaI05=NF@1AEe@0CE1A
0080ADM900/09B8^020O;00J6RH05A<N018A6P0@4QL03a<C00lE400?5Pl04AT@018J400201LP400<
01`T4P0K8Q406Ad?01PK3P0G6Ph061/?01DE2`0A4@P03Pd700l>2P0C4`l05QH@0P0F5a802`0M7aT0
:B`U03Lm<P18DT@0DV1?05UZEP1PLe/0GFiE04]F@@0g>RX0:2LK00809R<I00/0:BDL02d[8@0b<2H0
>3X/03m5<`11BSL0@D`i03e:=@0lBS40?D`]041>:`02041=:`0<041;:P0nB2L0?TDW03m5:`10AC00
?D<b03]3<`0i@3<0=d0c03I0<P0e@300=40[0P0d@BP02`0d@2D0>48V03U19`0i@2P0>CdX03Pj:00g
>b`0=3X]038i;00_>2`0;3HZ0080:C<V00/0:SDT02`g8P0/>200;STN02`h700/=a`0;3HK02/c6`0]
<Q`0;C0N02h_7`0202d^7P0602d/800Z:R00:B/R02P[8`0T:2008B@M6_ooool01P1<EfP0D5a^05=N
L`1BGG@0E5if05IMM`80EUih00/0Ef1i05QRN01HI7L0F6Eg05UUMP1IIWL0G6Uj05eZN@1LJWP0GF]i
05aZN@0205aYNP0;05i[O@1NJgh0GV]o05m/P@1PK840HFj2069^P@1TL880IW6306MaP`1WLXD00P1X
M8H0301WLhD0J7F706UfRP1[MhX0KGR:06egRP1^N8X0L7Z:071jR`1`NXd0LWb@079mT@80MH2C00/0
MWnB07R1T`1iPi80NHF@07V4SP1jQI00NhFD07j7U`1nR9T0PH^M086:W00208:;W@0;08>=WP24SIh0
PhfN08F>W`25Sj00QI6Q08JDX`27U:<0RIFS08^GYP2?V:L00P2@VJH02`2BVZL0U9^W09BMYP2EWjH0
U9nU09BPX@2EXZ40Uj:R09VTY@2IXjH0VZBX0080W:JZ00@0WJN/09fW[@2PZ:h0X:V/0P2QZj`01P2Q
ZjX0XJbZ0:6/ZP2O[:P0Wj^V0:6]Y`80XZbX00/0XZ^X0:>[Z@2R[:L0XJbU0:2/X`2O[:40WZZP09fZ
WP2N[9/0Tj6?04i?D00203Xj?@0;02h`<@0O82405aTH014B4@0c>bd0Df1705=QB01>GD@0AU<l05MU
BP1ZNe/00P1`OUd0302<Vg<0G5m:0;C:WP28V7/0@TLl03a1=00g>R`0=cTZ03Hj:@0e?2X0=3`Z030i
9`80;CLV00/0;STW02dh9P0^>2@0<C/U030j8`0^=R00;38K02dd700[<Q/0:RlK02dc7`0302hc8@0:
02db8P0^=BD0<3LW03<l:P0e?R/0=Sh[03Ho:P0f?RP0?TL^03a5;@80=CdW00H0<CXU02Tc7`0T;1/0
8bTI02@X6`0T9Q`?ooooo`003Oooool01P23UiL0QYZN08ZNY@2<WZT0RibX08ZKY@80Ri^S00/0S9fS
08jOY02@XJH0SZ2U08nSY@2AY:H0TJFW092UY`2AYJH0Uj^[09V][P0209Z][@0;09V/[@2I[Jd0VZb[
09b][02N[Zd0Wjn^0:6a[`2P/Jd0X[>/0:Bd[02S/ZX00P2R/:P0302P[jL0Xk:Y0:FbZ`2W]:h0ZKF`
0:bf/P2^^KD0[KNc0:fh/P2[]Zh0ZKJZ0:^iY`80Z;JQ00/0WjZG09ZUT`2CWH`0RI:307MoK`1NI5@0
BTln03m2=00i>c00=cP`03Lh<P0203/m>P0;04I9B01>E5<0DUYJ059LF`1@FeX0C5QG04YFE@1=F5P0
E5iK05UPG@1JGeh00P1HG6002`18C5@0?45<02T]>P0N8Rd061/V01<G7P0@5AP02a8@00T>2P0>50/0
620A00807RLC00`08bdG02D^600S:QD082DC01dQ4@0J7Pd05QP8018A1@0A3PD04Pl901HC3@0I5Q42
01LD4`0;01DB5@0F4aL071XK02HY9`0e?CH0AeA505EVCP16ESl0AUDk04EA=`0k@2d00P0m@3002`0g
=Bd0;b/Y02hZ9P0a<2P0=SX^03To<P0lAC<0>dD`03]6;00jA2P0?4LW0080?4HX00`0>T8W03Y09P0j
@2L0>ClY03Po:`0g?Rd0=cl`03Ho<@0d?C00<c`]03Dm:`0g?RT203Q0:00;03Q19`0j@RP0>d8Z03Y1
:P0j@2/0>Ch[03Hk:P0e>b/0=3`/030h;00/=2L00P0[=2H02`0Z<RD0:S<S02/d8`0[=R80;3LQ02dh
8@0[=Al0:S@O02`d7`0[<Ah0:BdL0080:BdM00H0:2`N02L[7`0W:b00:2`Q02H[7`0S9a/Jooooo`06
04aII`1@G6d0Deme05=PM`1EHGP0EV1h0P1FH7H02`1GH7D0FFAe05YWMP1HIWD0FFMf05]XM`1LJgP0
GFaj05a/NP1LK7T0FfYh0080G6Yi00/0Gfen061/O`1OJh00H6b1061/PP1QKHD0HFf406A`Q01ULH@0
IW6406IbQP0206IcQ`80J7F600X0JGF706agR`1^N8d0KWR=06iiS01`NX`0LG^>075kT01cO9<0M7jD
0P1fPI@02`1gPI<0N8>B07Z5T`1jQI40NhJA07^5TP1nQiL0OXNJ07f8V`1nRY`0PH^K0080PX^L00/0
PhbN08F>X026Sj40QhnQ08J?XP25Sj<0QI6S08JCY028UJ@0RIJT08jIY`02096JYP0;09:KY02CW:D0
U9nX09FPZ@2EX:P0U:6V09BQY02EXJ@0V:>V09^UZ@2LYZ`00P2MYjd0302OZZh0X:Z^0::Y[P2QZJ`0
XZZ/0::[Z`2Q[:/0XJfZ0:6]Z@2R[ZP0XJfX0:6^Z080XJfX00/0XJbX0::[Y`2S[JH0XZfT0:>^X`2R
[J00XJbO09n]W`2O[Yd0V:NC055DD`0203De>00;02l_<00U9RD07b4P01PG600_<b/0CUU6059NBP1@
FdL0@d`k05=OB@1YN5`00P1YMU/0302Q^900QYEj0;gH[@1bOfL0BE0n0498=@0g>RT0=3DU03<e9@0e
>BL0=3`X02lg9080;3HT00H0;CLV02dg9@0_>2@0<C/V038l9`0_>2<202dc800302T_700W;A/0:S0O
0080;C@Q00/0;cHS02he900a>2P0<cXY03Do:P0f@2/0=3lZ03I0:P0e@2T0?TT]03M09@02038k8@06
02df7P0Y<Q`09bhJ02L]6@0V:aT09bXL3oooool000gooooo00H0OYFG08BKW@29Wj<0RYjV08RLY@29
Vj<208^KX@0;08^LX`2<WJ<0SInU08jPYP2@XZD0TJ>U096TY`2BYZX0TJJX09FXZ@2FZJX00P2I[:`0
2`2I[:h0VZb_09V/[P2L[Zl0WZnb0:2`]02O[k<0X:na0:6a/02T/k00Y;:_0080YK>^0P2U/jl02P2V
/jh0YkF^0:Vg/@2Z][<0[;Rd0:bi]02/^K<0ZkV`0:ZiZ`2/_:X20:flZP0;0:fkZ@2]^ZT0[[ZY0:Zf
Y`2KYYT0TZ2=06M`H@10A3`0=CPb02lc;00[;BL00P0Z:RD02`0];2P0?3dh04I:A01>EE00DUYG05=M
FP1AG5X0D5]J05ANG01GHE`0F5mJ0080FV1M00/0Ff5P05QPH01:DE@0?TI:034i?P0O9B/05A/O00hD
500:3`/03Q@;01TQ4@0201lY500<02Td7@0^>B40:cDL028Z500M8@h061X9014C100?4@<04105018A
200J6@l07QdB0P0N71<02`0V91/0:2HM028O6`0V9B@0<C<^03Tn=P16Ccl0<3HY01`Q5`0R:A/0:c@S
0080BULm00@0H6a@05iWD01FG4T0Ad/m0P0o@cL01@10ACL0?dDe03a2<@0l@R`0>d<X0080>d@X00`0
>D4W03Ln9P0g?bH0=C`V03@k9@0d>bH0=C`Y03Hl;00e>bd0<SPY03<i:00f>RT203Pl;00;03Lm;@0f
?B`0=cl/03Hn;@0f?R`0=ShZ03Dn9`0d?BL0=3`V030h900]=2<00P0/<b<02`0[<B80:c8S02Xa900Y
<BD0:C4V02Tc9P0Z=2@0:c@R02Xc800Y<Ah0:BlM0080:2lL00H0:2hI02H/600W;1T0:BhL02P/6@0W
:aPJooooo`0604aHI`1@GFd0Df5d05=PM`1EHGT0E61g0P1EH7D02`1FHGL0F6Ei05UWNP1HIgT0FVQj
05YXM`1KJGL0Ff]g05]ZNP1KJgX0FfYj0080FfUi00X0GFYk05m/O@1OK7l0Gf]o05iYP01QK8@0HFb5
06=`Q`1TLHH0IW>60`1ULhD0301WM8<0IgF206UeP`1[MXL0KWN906ehR@1^Nh`0Kgb=071lSP1bO8l0
LgfA07EoU080MX6B00/0MX:A07R4TP1iQI40NHJA07^8T@1kR9<0OHRG07n9VP1oRI/0P8ZM08:;W@02
08>;WP0;08>;X026SZ80QXnR08J?XP26TJ<0QI2R08FBXP26UJ<0R9NS08VHXP2<VJ<00P2@VjD02`2A
W:<0TifT09BNY`2EWjT0UZ6Y09JRY`2EXZH0UJ:W09JSZ02IYZ/0VjN]0080W:R^00@0WJZ^09nZ[@2N
Z:X0WZVY0P2QZZX01P2R[:X0Y:j[0:B_Z`2T[Z/0Xjj[0::]Z@80XJfY00/0XZjX0:>]YP2U[ZD0Y:nS
0:>]XP2S[Ih0XjjO0:6/W`2O[Ih0VjZK05UMGP0202l/=`0;034_=00X9b/08B4S01`K7@0^;b/0Dea<
05QQD@17C480<34[03`o<`1WLeT00P1NJ5<0302M/Hd0[<:M0:[2V`1II4h0>3h/03@h9@0U9AL09BDH
02X/7`0^<R<0;C8S02X_8080:2hP00/0:S8R02`e8P0`>B<0<S`T038k9@0_=b<0;CDR02/c800X<1h0
9blN02Pa7`0202/d800;02df8P0^=R<0<CPU03Dl:@0f?BX0=Sd[03Dm:P0d?2P0<cdX03]5;@0d?bL0
0P0`>R801P0/=A`0:38J02H^600U;1H09BXF02HZ6@oooooo000=ooooo`06082FU`25W9l0RZ2U08ZO
Z028WJH0QibS0P2:Vj<02`2<W:H0SIjW08bMYP2?X:P0TJ>Z096SZ@2AXj/0TjF[09:UZP2CY:X0U:B[
0080UJJ/00/0UjR^09ZZ/02KZk80WZfd0:2`]P2R/KL0XJne0:6^]02R[k@0Xk6d0:Jb/`020:Nd/`80
Z;Bc00X0Z;Ba0:Vd/02Z][80[KRf0:fj]`2]^KH0[;Vd0:bk/@2/^jd0[kf/0P2`_Zd02`2`_Jd0/;f^
0;2m[P2b_K00[k^_0:^j[02BX9@0HVaV04M?BP0j@3P0<CH]0080;BlT00/0:RXO02/Y8@0a;bX0>c/g
03m1?`17C4T0D5UC05EPF@1JIUh0FVEL05IOEP0205INEP0;05EME`1FGUT0EV5L05EPG@1>FeT0@e1=
02`d=00C5aP04ADB01<H3`0J8A<00P0N9QD0300S;1L09c0K02Pa6`0U:aH07R8@01HG2P0@3`L03Pd8
00h?200@40/08bHL01lP608071`E00/0EV5606elFP0d>2d0?D@k0458?P0b>340:RhY028S7P0H6A<0
4Q4=00h>2002020S6@0;06j0H@2;XGd0Q9Qh06ekI`1EH5@0EEmD051HC01<DdD0Adho04=:=`0oB300
0P0nB2d0300nB2`0?4DZ03]4:P0h@2H0=ShV03Dk9P0e>RH0=c/Y03Hk:P0b=bP0<CHW038f:080<cHZ
00/0<CLZ034h:`0b>Rd0<3T[02hg:00_>BH0;c/T02lj8P0_>B40;CLN02`e7`0202`d800;02`c800Z
<B00:C4Q02P`8`0W<2D0:38V02Td900Y<b40:C@P02Td7P0X<ad00P0X<QX01P0Y<AP0:2lF02L]5P0W
;1P09R/H02L[6A[ooooo00H0CU]W055NK01DHG40E61d05EPMP1EGgL205=NM@0;05IQN@1HIG/0FFIl
05YWO01JJ7X0FFMf05]XMP1LJWP0FfUj05aYO01NJgd00P1MJG`02P1LJG`0GFYn05m/P01NJgl0GV^0
05m[PP1PK880HVn306A`Q@1WLhD306McQ00<06MdP`1YMH@0JGB206]eP`1]MhL0KGR806ijS01_OHh0
LGf?075mS@1aOHl0M7nB0P1fPY802`1gPi40N8F@07R5S`1iQhl0NhRA07j8U01nR9D0OhRF07n9V@20
RI`0PHVM0080PX^O00/0PhbP08J?XP27T:80QY2R08JBXP25TJ40QI>O08NFX028Uj40RYRR08^IX`02
08jJY@0308nJY@2BVjH0U9fX0080U9nX00D0UJ6Y09JRZ`2FXj`0V:F/09VV[00309^X[@0709bY[02M
ZZd0WJRZ09jZZ@2PZjP0XJ^W0:B]Z@020:F^ZP030:F^[02T[Z`0Xjj[0080Xjn/00/0XJjX0:6]Y02S
[Z<0XjnS0:B^X`2R[J40XjfQ0:6]W`2O[Yd0WJfL05eRH@02030]>00;02d/<`0S8BP081dQ020O800e
>380GfYG0761J013Acl0<2l]030`;@1NJE<00P1JHdl0301gQFL0SZ9l086EL@1>FT80=Sd[02X_7P0O
8QD07AlE02<U6`0V:Ah0:2`O02L[7@809BTM00/09b`N02Xa7`0]=B00;cLO02`b7@0Y;ah0:c8P02Xc
800W<1h09blN02H`7@0202Pb7P0;02/f800]>240<3PP038i8P0c>BD0=3/W03Dl9`0a>2@0<3LT03Y2
:`0d?BP00P0]=R801P0Z<Qh0:30K02H]6@0S:QL092TG02H[6Poooooo000=ooooo`0607jAU@27W9l0
RinU08VLYP26VjD0QibT0P29Vj802P2<WZ@0SInW08fNYP2?X:L0TJ6Y09>SZ`2BXj/0TZB[09:SZP2C
Xj/309FSZ`0;09BT[02FYJd0VJN^09^Y/02N[;<0X:nd0:6_/`2S[[80Xk2c0:B_/`2T/;<00P2U/K40
302V/K00Yk>`0:Zf/P2/]kH0ZkJd0:Zf]02/^;H0ZkNd0:bj/`2[^k40[Kb_0:jm[P80/;f^00/0/;f/
0;:n[02b_J`0/kf]0;>n[P2b_Zl0[kf^0:2^W`2:V8P0HVaQ0455?P0203]0=00:03Pk;P0h>Bd0=3@]
03<a;`0a;Rh0;bh^03Df<`11ACh0CUI:05END@<0FF=E00/0EV1C059LD@1GHeH0EV=G055OEP1AHEL0
AeI<02D]:@0M91d06AhG01PM4`0201LL400<01TN3`0J7`l07B0B020T5P0O8aD05QL>01<B3@0A40d0
3`h=00l=3@0I6AL05aHD0P0N7ah02`1oTgL0Y/:N09B_T01OL5l0?DDk02/_9`0K71L05QHB01DD3`0C
4@l04A0>00803P`<00/0Ae5109B]R029Wh00R9b10721K`1RLF<0HG1O06=aG@1RKed0GV]I05e[E@02
05QVCP0<051MA@1<ET00B54l04A;>011ASD0?D8a03Xn;P0h?2d0=cX[03<e:P0b=BX0<C@X0P0b=RT0
2`0`=BP0;S<W02hd9`0/=2H0:C8T02Xd900Z=2<0:S<S02/e8`0/=b40;3HO00<0:C8L00@0:C4M02T`
7P0W<1l0:34Q0P0X<R80100X<Al0:34M02P`6P0W;aX202L^6@0602P^6@0V;1P092TF02@Z6@0T:Q`0
8RTK6_ooool01P1>FfP0DEi]05APL@1DGg80E5md05IQM`80EEmh00/0Ef9l05UUO`1IIWd0FFIk05YX
NP1LJGT0G6Yh05e[N@1LJGX0G6Um05eZOP0205eYO@0;05aYO01MJWd0GVao05eZOP1MJgh0GV]o065^
P@1SKh80IW2506M`QP1YLXH00P1ZMHH0201[MHL0K7J806afQ`1/MXH0KGN806mjR`1_NXd0L7^>0`1b
OXl03P1dPI00MH:A07F2T@1fPi40MhBA07R4T01jQi00NhR@07f9T@1mR980OhRD07n8U@20RIP0OhZJ
0P21Ri`02`24SId0Q8jO08F?X026T:00Qi6Q08NBX@26U:00QiFP08ZGX`2>VjH0Si^X0080T9^[00/0
T9^Z09>N[02DWZ/0U9nY09BPZ02FXZX0UZB[09JSZ`2HYJ/0VJNZ09VWZ`0209bZ[00<09bZZ`2NZZ/0
Wj^[09j[Z@2O[:L0XJfU0:B^Z02U[ZP0Y:jW0:F_Z@2U[ZT0Y:j[0P2T[Z`02`2S[Z/0XjjW0:>^Y02T
[j@0XZnR0:6^XP2Q[Z40X:jP09j^W@2M[Y/0Ifm[0080?T5600/0<34g02@T:@0R828071XK03Lk<`1F
HTl0HG1J05EPC`10AC/0=cXc05IQCP0205aXDP0<05AOB@1HID/0EfI:04mL@@0g?bd0:C0Q024V6P0M
8AD08B@G02@X6P0W;1`09BXK0P0Q91H02`0R9AL092XJ02L]700U;1/082@H02H]800X<240:C4P02Pb
7`0X<A`0:34K0080:C8K00D0;3HN02hg7@0_=a`0;cHL02lf7P02038j8`0402dc800a>2@0>D4Z03@l
9P80<3LS00H0;3<P02/b7P0Z<1h09bdL02D[6P0W;Qh?ooooo`003Oooool01P1fR8d0Q9RJ08NKXP25
V:80PYFR08BGXP80Q9RQ00X0RIbT08fNY`2>WjP0SIjW08jOY`2@XJT0Sj6Y096SZ@2AXjP0TjFZ0`2G
Yj`02`2EYZd0UJN/09RX[@2HYjd0VZR]09^Z[@2N[J`0XJn/0:Ba[`2V/[80Y[6c0080Y[:a00`0Y[>^
0:Rc[P2Y/jl0ZkJd0:Rd/P2W/k<0ZKJe0:Vg/`2Y^;80Z[R`0:fk/02^_Jl20:nm[P0;0:nkZ`2`_:/0
/[j[0;:mZ`2c_J/0];n]0;>o[`2b_Zh0/Kj/0:FaW`22RG`00P1bN6`02`1aMf/0H6EK04M9A012@Sh0
=S<b030[:P0Z9R<09R@O034b:@0o@cH0C5920080E5]900/0Ef5>04YBA01<ETH0B5=2049??P10CSh0
AUE3049??@0Z=2D082HI01lT5@0201XM3`0<01LI300G60`06QX@01hO5P0N7aP061PB018B300A4P/0
4Q4=018@3P0F5A<06aXJ0P0K6a`02`0k@C/0GFeM09:^SP1mUGP0>T@e02P/7`0N7Q@05aD=010=200?
2`T040/<00803P/=00/09BTU07bDN02>YhX0PiYo082EN`1SLEl0F6AC05UTD`1SKUh0OHih08>GO@02
08>FO00<086BMP1ePfP0I6eG065WEP1NI5T0FF1F051HCP16Cd<0@4Lk03a2>00i?CD0=c/c0P0e>S00
2`0d>Bd0<SPZ038i:@0_>2T0;SHY02Xa9`0/<RP0:c8V02T`8`0Z<R00;3<M0080:S4J00P0;38J02`b
6`0[<Ad0:2lM02D]6`0T;1d08b/L02<[6`8092XI00T09BXI02H[6P0V:aX09RTJ02<W6@0Q9QP08BTK
024X7@0P:1d06_ooool0101=FfL0DUi^05=OM01CGWH205AOM`80EF1j00/0Ef9m05YUP01JIH00FVIl
05aYO01MJW/0G6Uk05eZN`1LJGT0GFYm05aXOP0205e[OP0;05e/OP1LK7`0GFek05i^NP1OKgd0HG21
06=bPP1SLH<0I76406IaQ@1WLHD00P1YLhH0301[MXL0JgF706egR@1/MhP0KWR:06mjR`1_NXd0L7^>
079mSP1cOhl0Lh2>07B2S@80MX>@00/0MX>A07N4TP1hQ980NXRC07^9T`1mRi80OHVD07n9U@21RiD0
PXbH08:=V@0208:<V`0;08>=V`25SY/0QI2L08JAW028Til0R9>N08RDWP2:UZ40S9RT08jIY`2?VJP0
0P2AVZ/02`2AVj/0TIf[09>NZ`2BWZP0U:2Y09BQZ02EXjP0UZBX09RUZ@2KZ:X0W:V/0080WJV/00/0
WZV]0:2Z[@2QZZl0XJ^]0:6[ZP2T[ZT0YJnY0:F^Z@2U[ZL0YJjV0:F_Z0040:J`ZP0:0:F_Y`2T[j<0
Y;2S0:B`X@2R[il0XJfN0:2^W`2M[9l0WJjM07V5O080ADY=00/0=SXm02`^;P0W:2D08R4M034b:P17
C3l0BU95051LB`14CSl0>D4c05MVC@02061_E00<04eI@@1;Ecl0B5<k04E>=`0e>bX0;C8T02DX7@0O
8QP08RDI02@Y700R:1X07bDF0P0M8A<02`0P9AH08bTI02DZ700U:ad06A`D02@X700W;Ah09blN02Tb
7P0[=1h0;3@M0080;CDM00/0;SDN02lf7`0`=b00;SDO030g7`0`=R40;S@P02/`7P0`=R40>40X03<j
8@0202lg7`0602/c7`0Z<Al0:30N02T^7@0W;Ah0:c4S3oooool000gooooo00H0O8n?08:EU@26VYd0
QiZR08BFXP23UJ8208>EX@0;08RIX`2;VjH0S9fX08bMY`2;WJH0S:2X08bPY`2=XJH0Sj:U096SY`2B
YJP00P2CYZP02`2DYjL0UJNW09JXZ@2FYjX0VZV/09^ZZ`2M[:/0X:n/0::_[02T/:d0Y[:^0080Yk>_
00`0Z;B_0:Rd[P2W/Zh0Z;B`0:Nd/P2V/[80Yk>c0:Nd/@2Y][40[KVc0:fi/@2^^k020;6n/00;0;2m
/02a_Jh0/[j/0;>mZP2c_J/0/kf]0;Bo[`2d_jh0];n]0;BnZ`2`^JL00P2[/j802`2Y/Z00W:FE07b0
MP1cN6`0?3Dg03H`;`0`:RX0:RHT02PU800];B@0<c@W0080>ch^00/0?T@a038e9`0_=2H0:c4R02L_
7`0Y<1l0<S/W03]5;@0`=R<0:RhN02DX6@0201hP5@0301TJ4@0F5`l06Q/D0080824K00L061TE01<E
4@0C5Pl04aH?018C3P0H6QH07R0M00809BTS00/09BTT02/a:`1=FT/0FFQF04YFA@0R9Ad07AdE01TF
4@0A3@`03PT<00d52`0200`73P0;03Dh=P1cQW<0PiZ507fEO`23VGl0PIAi07B2J`1WLV00HFYJ07^;
M023UGX00P26Ug`0302<WH00S9j006ehI01KHEL0HVQO06A]I01YLfP0JGEU065[G@1IHeP0DEYB04eF
D080BU=;00/0Ae1604A<@@11BC`0?D@h03Po=@0b=bl0;c8Z02``9P0[;b<0:blN02X_6`0202`_6`0;
02h`6P0^<A/0;C0L02DZ6@0N91@05Q`?018G2`0A5P/051T=01HJ3`0N8Q@00`0U:AX01@0T9aX092HK
028V700O91`07RDK01[ooooo00@0C5YY055ML01CGgL0EEmk101EH7/02`1GH7`0FV=n05YUO@1MJ7d0
G6Uk05iZO01NJg`0GVYm05eZO@1NJgh0GVYo00<0GVb000X0GFao05e^OP1MKW`0GVmm061`O`1SLH40
HFn0069`PP1TLH<0IW:50P1XLXH0301ZMHL0K7N806]gR@1/MhT0KgV:06mjR`1`Nhd0LWf>07=nSP1d
P8h0MH6=07J3S`80Mh>B00/0Mh>C07N2T`1hQ9@0NXNE07b8U@1oRiL0P8^G0829UP20RYD0PH^G08:=
VP0208:=W00;08>>W024SY/0Q8jK08JBW@28Til0R9:O08VDX02<UZ<0SiVW08nIZ02@VJT00P2AVJX0
2`2AVZX0TIbZ09:NZ@2BWjL0U::Y09FRZ@2FXjX0UjFY09VVY`2MZ:X0WZV/0080X:Z_00X0X:V`0::Z
/@2S[;80Y:fb0:>[[P2T[J`0YJfY0:J]Z02X[jH0YjnV0P2V/:L20:J`YP0;0:NaY@2U/J80YK6Q0:B`
W`2V/Il0YK2N0:B^WP2Q[Yh0WjfN09f]W@22T8<00P18C4d02`0i>c`0;c4`02X[:00X9b80:BPR03Ph
;`19CSl0B59003m8>00g?bh0E6=70080I7IE00`0Cea004YF>`19DcP0@dTa03Hi9`0_<B80:2XN024S
6@0Q9AX092/O028Z7P0O9aX201lV600;028Z6P0T:aX08RXI028X6@0F6Pl06QdA020R500R9aH09bhK
02Xb7@0/=1d00P0^=Qh02`0_=b00<CPS03<i9@0_=R<0<3HS02hd8P0]<R00:RlN034g900lA2`0<cXR
0080;cLN00H0:c<M02Tb7P0X;ah0:BhN02X_800]<b<?ooooo`003Oooool01P1mTH`0QIRE08VLWP27
VZ40Q9NQ08BFX@80QIRR00/0QiVQ08ZKXP2;W:<0RibT08^NY02;X:H0S:6V08fQY02>XZ@0T:>V08nT
Y`0208nTY@0;096UY@2BYJD0UZRW09VXZ@2KZJX0WJZZ09jZZ`2PZjh0XZf_0:>][P2U/:h00P2V/Jh0
302X/jl0Z;B`0:Vd[`2Y/jl0ZKJb0:Ve/`2X]K40ZKF_0:^g/02]^;00[KN^0:jj[`80/;b_00/0/Kf`
0;>n/02c_Jl0];j^0;Bn[@2e_jd0]/6^0;G1[P2e`Jd0]KnZ0;FoZ`020;BmZP0;0;>mZP2d_jT0/KbV
0:VeWP1SHU`0>c@f040l>00m?3<0>ST^03Lg:P0g>2P00P0b<b<02`0/;1d0:RPL02DT6@0P8AD082<D
02<U5@0[;a`0=CTU03Dh9P0/;b809RPN00807b0J00`06a`H01XK5`0N81`08R@Q020R7P0K7QX05aXF
01LI500H6a<051H>014C3@0I6QD202DY7P0;02dc9P0f?Rl0A4dk04QC?P12C3P09RXO020R6P0M7AT0
61DE01DA500C3A<00P0A3A<02`0Q7b<0CUI?05i]H01`Pfh0NHac08VLOP2;WH00QiQn08:CN@20TGL0
PYEi0080QIMk00`0Q9Ak08ZKPP2;VhD0IW1V05aUG@1DFU@0HV]N08^MP`1fPg40EEiG05EOF@1KIUl2
05eZH@0;06AbIP1YN6L0IgES06AaGP1LIUD0D5M904E8?P0l?S@0>3/_03Dh:00a<b800P0a<R002`0b
<Qh0<34O02`^800U:A`06A`@00lB20082`<010L000H80P05208030l600805AT=00H06b0B020S5@0Q
91L08RDJ024U6P0O91PJooooo`0604eJJ`1AGW80Deif05AONP1DH7`0EF5m0P1EHG/00`1FHWX0FF=j
05YTN`0205eXO@0605eYO01MJGX0GFUk05eZO@1NJWl0G6Un0P1MJX002`1OK880GF^005e[P01MJgl0
GFam05m^O@1RLGl0HG1n06=bO`1ULh00IW>20080JGF600`0JWF806]hR@1[N8T0K7Z:06ijS01`Nhd0
LGb?079nSP1bOhd0Lgn;07>0R`1cPHd207F3TP0;07N3T`1gPi@0N8BE07^7UP1mR9H0P8ZF0829UP20
R9D0PHRF0829V@23S9`00`22SI`02P24SYl0QHnP08JAX026TZ00Qi:P08ZDX`2=V:L0SiZY08nIZ@2@
VZP2092JYP0;092JY@2BWJH0TYjV09>PYP2EXjH0UJ>W09NSZP2IYJ/0VZFZ09bWZ`2OZJd00P2QZZl0
302QZK00X:V`0::Z/02SZk00Xj^_0:>/[02U[:T0YZjY0:R^Y`2W[ZH0Yk2W0:N_Z@80YZjW00/0Yk6V
0:JbY02V/J80Y;2P0:FaX@2V/J80YJnQ0:>^X02P[9d0WZfL08^GRP0204Q:CP0;03Lf>`0b<C80;Rd/
02`/:P0/;2L0<S@[04eF@`1:E400?4Dc03<j:`18Dch00P1YNU/0301AGD<0BE<j04UA>015Bc80>ShW
030d7`0Y:QX08b@G024S5`0R9QX08bPK02@Y7@8092TL00/08bXK02H/6`0R9aL0720B01HH3@0B50X0
5AH<01TL3P0X;AX0;34O02hd8002030g8`0;038i9@0b>BL0=3/W03Dl:00b>2@0;c@R02hc8@0Z;ah0
<CLT03]3;@0c>bD00P0_>2401P0[=1d0:c<O02/b800Y;al09bhM02Xa7`oooooo000=ooooo`0607fA
S025V9D0RIbN08NJX@24Uj40Q9JQ0P25V:802`27VJ40RY^R08^LX`2;W:@0RijT08^PYP2<XJH0SJ6T
08jRY02@XjH0SjBW0080SjBU00/0TJFU09:UY@2FZ:L0VJRY09^YZP2MZZX0WZZ[0:2[[P2R[Jl0Xjf^
0:F`[P020:Ja[P0<0:Rc[`2X];00ZKB_0:Vc[`2Y][80ZKFc0:Re/@2Y]Jl0ZkN`0:fh/02]]jh0[[Z_
0P2`_:l02`2a_K00/kj`0;>m[`2d_Zh0];j]0;Fo[@2f`Jh0]L6^0;G1[@2e_jX0]Kn[0080];fZ00/0
/kfZ0;BoZ@2a_:H0ZKFN06=RG00k=3H0@3`h03dl<`0j>Bh0=cLZ03Lh:002038c8`0;02`/7@0Z:1`0
9B@I020Q5@0P8a@08bDE02/_700e>BD0=CPV02`_8P0V:1h00P0O81X0300K71P06Q/G01hP700R9240
828N01/N6P0G6QH05aTD01PK4`0D5Ph04A<=01TJ5@809BTN00/0;C<V03Hn;`14CC/0B5<n049<>00V
:Ql0828J01dM6@0H5AD05A4D01<=4`02014=4`0;024O8`1>ETl0GVeP0723KP1iS7<0RIan08^MP027
V7h0PY=i082AM`22UGT00P25Ug/03024U7/0RY^208^KQ@1VL6H0G6EM05AJE01RJeh0Rif307J3L@1E
GUL0EEmI05]VG`80GFYQ00/0I79V06UhI`1WMF<0I75N05aVE@1@EdT0ADPn03`n=00h>bl0=CPX034c
8P02034b800;038b7P0`<Al0;2hP02DY700I71003a8800P;0`041`001PP200D80P0<3`H00P0E6@d0
1P0K818082<E024T5`0R9AX08BDJ01lT61[ooooo00H0CEY[055NLP1CGWH0E5mj05APO01EHGd205EQ
N`0305IRNP1IHgX0FVAk0080GFQm00H0GFUl05eYNP1MJG/0GFYm05iZO`1LJGh205eZP00;05m/PP1M
Jh00GF^005e[O`1MK7d0Gfim069aO`1QL7h0Hg9o06EcP01VLh800P1YMHH0301ZMHP0JgR906]hR@1/
NXX0KWZ<071kS@1aO8l0LWj>079oS@1cOh/0Lh2;07>1S@80MH>B00/0Mh>C07N3U01hQ9D0NhNF07f8
UP20RYH0P8VF0828U@21R9H0P8VI08><W00308:=W00:08B>W`25Sj00QY6P08JBX027TZ00RYBS08fH
Y`2?VZT0SiVY092JZ080T9ZV00/0T9ZU09:MYP2BWZH0Tj2V09FSYP2EXjL0Uj>Z09VUZ`2JYJX0W:N[
09nY[@020:6Z[`0<0:6Y/02PZK00XZZ`0:>[/02SZjl0Xjb/0:F/Z@2V[ZT0Z:jW0:N^YP2W/:L0YjnY
0P2V[ZL02`2W/JH0Y[:T0:JaXP2T/:00YK6Q0:JaXP2U[j40XjjP0:2/W@2N[I`0RiN:0080B4Y>00/0
=cHk038a<P0^;B`0;2`Z02`/9`0b=2/0CEI304YD@00lAC<0<cX[04QC?P0206UjF`0<055M@`19DcX0
BE4h04E;<P0j?RL0<3@O02TZ6P0S91L08B<G028V6P0S:1/092TM0P0T:A`02`0S:Q/09R`K028W5`0L
81805QP=018D2P0E5P`06A`>02P]6P0/<Al0;S@P0080<3LS00/0<STU038i9`0d>bL0=C`X038h900_
=280;S<Q02X_7P0a=b@0>d<]03<k9@0202lh8@0602/d7@0[<al0:c8P02T_7`0W;Qd0:S4O3oooool0
00gooooo00H0MHR607nDT`25VYh0QY^R08JIY026VJH208NJY`0;08NKYP29W:H0RijU08ZMY02;WZD0
RYjU08^OYP2=XJD0T:>U096UZ02AYZX00P2@YJP02`2BZ:T0U:NW09JWYP2IZJP0W:^Z09n/[02Q[Jh0
Y:n`0:J_/02U[Zl0YJn`0080Yk:`0P2Y/k002P2Z/k40Z[Bc0:^g]02/^;@0ZkNb0:fj/P2]^K80[KVa
0:jh/02`^k420;:m/`0;0;:m/P2c_[40/kj`0;Bn[P2d_Z/0][n[0;S1[@2g`:d0]/2^0;G0[`2h`[40
0P2i`[002`2i`Jh0^L:/0;W3Z`2lbJ`0WZN@05]HDP1:Ad80NH5[06]aG@1DFDP0DUM40080@dDe00/0
=cHX034a8`0];Al0:R/M02PY6@0X:QP0;2hM03Pi:@0j>Rd0<S<Y02XZ8`0202<T7P0301dN6@0L7AP0
8R@P00809RTT00L09BPR024U800L7a`06QdH018D3`0?40`0414<00805AL?00/0720E02/a8@0j@Rd0
>d@^03Hn:@0[<B0092LJ01lP600L71P06aXJ01XJ6P0201dO7@0;01dP7P0U:BD0=Sdd04=;?`18CT80
OXac09NYS02?XHL0TZB8092QQ@2>X8@00P2=WhD0302:Vh@0R9V408RKQP21Th00MHAc06ijJ@1YMF@0
R9Z008nUR@1[NVX0HFmQ05]XF`80EEmE00/0HVmR07F7M01iS7H0O8mg07^>MP1cPfd0K7]V06UeH@1T
KEX0F61>05=JB@0204iD@P0;04I<>@0l@C80=S``02P^9@0L8QP04AD=00X=1P06204010H000430000
0@000P031@401P072P<03@l501PJ3@0Q91@08RLF02<Z6A[ooooo00H0CUU^059MM01CGgP0E5ii05IQ
O@1EGgd205AON`0;05IRN`1HIG`0FVIm05YVO01KIgd0FfQl05YWO01LJ7`0G6Um05iYP01MJ8000`1M
JX402P1LJX00GV^105m/P@1PKH00H6io069`OP1SLWd0IGAn06EdO@1VLgl206UdP`0:06]fQ`1/MXT0
JgJ906ahRP1^NXd0LGZ@079lT@1dOI00MGn@07B0SP80MH6=0P1ePHl02`1gPi<0N8BG07R3UP1lQYP0
OXNI07n8V020R9T0P8VH0869V021RYX0Ph^K0080PhbK00/0Q8jL08B>W`26T:40QY6Q08NBX@27Tj00
RIBS08bGYP2=V:T0SYRZ08nJZ003092KYP0:09:MY`2BWJD0TinV09>QYP2EXZL0UZ:W09VSY`2JY:T0
WJJ/09nV[@80X:N^00P0WjN`09nX/02PZK00XZZ`0:>[/02SZjl0Y:b]0:B/Z`80YZf[00l0Yjj[0:N]
Z`2V[JT0YZfY0:B^YP2T[Z@0Y:nS0:>^X@2U[j80YJnS0:B^X`2S[J80XZfO0:2]WP2<V8`00P19BU00
2`0l?D40>S/k03Ph=00b<Bd0;R`X038c;01BFdP0DUe804=<>@0d>b/0@T`g0080JG]J00`0Dem404YC
>`17CcH0AD/c0497;`0g>RL0;blO02XZ700X9a`0:2XN02HW7@0T9Qh202<U7@0;020S6@0O8QL07B4D
01PK3P0C5PX03a<700d?1P0?4PL09blJ02`c7P0`=R800P0b>2D02`0c>BH0<SPW038i9`0b>BH0<3HS
02hd8@0]<R00:c0N02dd8P0a?2H0;CLQ0080:cDN00H0:38L02Pa700Z<Ah0:BlO02H[7@0Z<R0?oooo
o`003Oooool01P1cQhD0OI:C08BHW`26VZ@0QYVV08JIY`80QYRW00/0QYVW08RLZ029WJL0RYnV08fP
Y`2=WjP0Sj:Z092TZP2>XZL0T:FX09BWZ`0209BW[@0409>W[02FZJl0UjZ^09ZZ[P80VjZ]00<0WZf_
0:2_/02R[k400P2S[k420:Jc/`0<0:Ne/P2X]K80ZKBe0:Zd]P2[][P0[;Ng0:ji]`2_^[D0[[Ve0;2i
]@2`^;@0/;^f0P2a_KH02`2b_KD0/Kfb0;:n/P2e`;00]/2_0;No[P2j`Jl0^l6a0;[0/`2j`[H0^L6e
0080^l6d00/0_<Bd0;_4/02ja:`0_<N[0;W6Z02LY8d0MGAZ09nVTP2Y/I`0WJNB09FPR@0207MnJP0;
04U9?@14ASH0@dLd04=7<@0o@b/0?40X03Pk:00k>bd0?C``03Th;@0];BD00P0W9al0300Q8AX07QhG
020P6P0T91d0:2XS02`_9`0/<2T08bDT01dN7@0B4a803a0>00d@3@803a8=00/04aLA01dS6@0T:ad0
9bdM02T`7@0U:QP0828D01`L5P0I61L06aXK01/J7@02030e=00;04A=A`13CTH0CUa@051KCP1<DdL0
CE1909>SRP2:VH@0Q9>0082@N`20SgX00P29W8@02@29W8D0RYf708^OR@27W8D0QIV107f@M`1gRW80
NH]b07b@M@0207^?MP0707N:L`1cQW00LhI`07>5L01cQG40M8Ic07N8MP0207R9MP0507R9M@1jRg@0
O8]c07V6L`1dP7000P1aOVh02P1^O6`0IgAV05aZG00f?cP0720M01LK5P092PH010D1008300010P03
0001000600020002100030h301XM300R9a<09BXG6_ooool01P1>FFd0DEYb05=NN01DGW/0EUml05IQ
O@80Ef9m00<0F6=m05UUO@1KJ7d00P1KJ7d01P1KIgd0FVMm05aXOP1MJWl0GVV005aVP080G6Mo00/0
FfQn05aZO`1NJgl0Gff105m/P@1OK7l0HFio069`O@1SLG`0Hg5m06IbP@0206QbQ@0<06YcQ`1ZLhP0
K7F:06igR`1`NHd0LGZ@07AlT@1dOI00MGj@07J0T@1ePI00MX:@0P1ePY402`1gPi@0N8>H07V3V01j
Q9P0NhFI07j7VP21RYd0P8ZM082:W022S9`0PXbM0080PhbM00H0PhfN08B>X025Sj00QY2Q08N@XP27
TJ@208VDY@0308ZEYP2<UjP0S9JY0080SIRY00/0Si^X08nKYP2@WJH0Tj2W09BPZ02FXJT0Uj6Y09ZS
Z@2LY:/0WZF/09nW[`0209nX[`070:2W[`2QZ;40XZV`0::Y/02RZk40Xj^`0:>/[P020:B/[P030:F]
[P2U[:d0YJb[0080YJfZ00/0Y:fX0:B/Y`2T[ZD0Y:jT0:F_X`2V/:@0XjfS0::/XP2QZj00X:bO096N
TP0204e>E00;0494B013Ad<0?3lh030`:P0];2D0<30Y04eCA01<Dd80?TDf02ld:00lA3400P1^PUd0
301FIDL0Ae4h04QB>@16CSD0AD/d04=7<P0l?B`0=cP[038c:P0`<2X0:RXT02@T8080824L00/07R4I
01hQ5`0M8AD061/?01<G2`0@50L03Q4600X<100Q:1P0;cPS02lh8P02034i9080<3TU00T0<3TT02hf
8`0^=R40;SHO02dc7`0Z;ah0;3@R02lj9@0[=Al00P0Y<a`01P0Z<a`0:c4L02/a7P0[;ah0:2/L02T^
7Poooooo000=ooooo`0607:4Q@1mT9D0PYFP08>FY022UZ<0PiJS0P24Uj<02`24Uj80QIZS08RNY@2:
WjD0RYjU08VMYP2:WjP0S::X08ZOYP2:WjD0SZ>W0080TZF[00H0U:N_09BW/@2FYk40UjR`09VX[P2J
ZJl209^Z[`0309bZ/02N[;40X:ba0080Xjna00`0Y;:c0:Nc]@2W/[D0Y[6d0:Rb]P2Y/[P0ZkBh0:bf
]P2[];@0[;>c0:je/`2_^KD20:ni]`0;0;6l]P2a_;D0/[fd0;>m/P2c_K00];f`0;Jn/02h_[80^/2f
0;W2^02h`KL00P2g`;@02`2f`K<0]l>`0;O2[02g`JT0]/6Y0;K0ZP2c^:H0/[RV0;JmZ`2f_Z/0]L2Y
0080[[VQ00/0N7Y`06e_I01lPfl0PHYa079iH`1KHDl0DUM704Q;?@14A3T0?CXa038`9`0202d/8`0<
02LV7P0Q81X0820H02<T6`0V9Ql0:2XR02T[900R92007AdL01PG600D4aD04A@C0P0B5a<02`0G7AL0
6b4J024Y7@0W;R00:C4P02D[6P0O8Q@06a`E01/I5`0H5AL071XO0080=cdn00/0MHQg06f2L01QM6@0
I7IR05YWE01:CdH0V:^@08jRR`1aPg<0I7=U055KDP020761K@0<08:EO@24V800RIj608RMQ`2:XHP0
GfmP04QCB@25VW`0LX=Z06mnJ`1kSGT0OI5l0P1jT7/02`1jT7X0Mh]e07J9M@1eQ7@0M89e07:0M@1b
PGD0Lh=c07B3L@1dPW40MH9`0080M85^00L0M85_07B2K`1hRW<0Ce]@018B5`0;2``00@4100<00000
0`000@001P0210002@/2018D1P0G6PX07b@A02<X51[ooooo00H0CEUZ051JL01EGgL0EV1j05EONP1G
Hgd205QSOP0905UTO`1IIGl0FVEn05]WO01MJ7d0FfQl05eXOP1MJ7l0GFR00080GVV10P1MJ8000`1M
JGl0GVZ005i[P002061]P006065]P@1RKh40I76106IcPP1VLH<0Ig:50P1YLhT0301ZMHX0JWB906ef
S01_N8h0L7V@079kT@1dO980Lgb@07AmT@1eOi<0MH6C07J1T`80Mh:D00/0N8>F07V4V01jQIT0NXJI
07Z5V01lQiX0P8ZM086:W@20RIh0PHZN08>;W`0208><W`0;08B=X025SZ00QHjO08NAX@28TJ80R9:T
08ZDYP2:UJD0RiNW08bHZ02<UjX00P2=V:X02`2?VZX0T9fY09:NZ02DWZL0UZ6Z09VRZ`2IXZX0VjF[
09bTZ`2NYZ`0X:R_0080X:V`00L0X:Vb0:2Z]02QZ[<0X:Va0:2[/@2QZk00XZ^_0080YJf_00<0YJf^
0:J][@2V[J`00P2U[Z/02`2U[ZT0YJjX0:B^YP2U/:L0YJnU0:F_Y02T[J@0XjfS0::/X`2PZj40UZ:H
0080DU=H00/0?3a30452@@0m?CP0<S4Z02l^9@0b<2L0BU1004U>?P0o@cD0<cH[03Xo<@020721G`0<
05UWC015CSX0BU@n04QA>`16CSP0Bdlj04M8=`15ACL0?She03Th<P0c<bh0:RTW0P0U9R802`0P8aX0
7B0D01XK400F5Pd04aD;014D2@0?4PP02@`401dU5P0_>BD0;cPU0080<3TV00/0;SLU02dh900]>2<0
;CPS02`f8@0]=b00:c<O02Xa7`0Z<b00;3HR02Xd7`0202Td7P0602/d7`0[<ah0:c4L02T^700[;Qd0
;C8P3oooool000gooooo00H0NHV>07jAV@20Tj00Oi>P082DX@21U:0308>GX00508BHX@26VZ<0RIfV
08RMY`29WJH00`2:WZH03`2;WZH0SJ2V096SZ`2AXj/0TZB]09>T[`2EXk00UZB_09RW/02JZK40VjVa
09bY/@2LZK80WZbc0::]/`020:>^/P0<0:>]/P2W/;D0ZK6e0:R`]@2Y/[H0ZkBi0:bd^02/]KL0[KFe
0:fe/`2^]K80/;Rd0P2a^[D02`2b^[D0/[^d0;:l/P2b_;00/Kb^0;:l[P2c_Jh0/kb_0;Fn/P2e_k<0
]<6c0080]<6b00/0/l2a0;G2[`2f`Zh0^<:^0;S2[02i`J/0^l6[0;_2Z`2i`:X0^/6Z0;c3Z@020;_3
Z00;0;BkXP2^/id0[K>L0;2iW`2[]9T0W:>:08fCN`1YJUX0G5Y>04]8?@0m>bl00P0e=BT0300]<2@0
9RXP02LW7P0Y:Ql0:R/Q02DX7@0P8Q/07AdI01XJ5`0H5aL05ADF01HH5`806alK00/092TP02L]8@0Y
<2<0:c4U02`b9P0[<B809R/M02DX7P0R8ad07A`I01PH6002030f<@0;07^BMP28Y800DV9=04eJAP0o
B3T0>Chd06AaGP1OKEd0JWmY06UmI`1JJUH00P1ZNf@0301jSG@0OY9j08:FO`24V880RIn6065_H@10
AD40V[6?055ICP12B4H0SjB=07nDP080IWQ[00/0LHEd07Z>N`1]Nfd0K7Q]075lM01bOGP0LH1i07:1
MP1bPW<0Lh5a07B2K`02071nJ@0;06ijI@1ZMf40HFeJ03m5?@0D4QD02@D800D310030@800P420040
0@000@000P010`001P051`805QP=020S500R9aL08bXI02@/61[ooooo00H0CEQY051KL01DGgD0EV1g
05MQN@1II7`205YSOP0;05YTP01KIH40FVB005]WO`1LJ7d0FfQk05aYO01MJGl0GFR0061ZPP1PJX<0
0`1OJ8802P1PJH<0H6Z2061[P01QKH40HVf1065^P@1SL8<0IW:606QcQP1YLhL206YdRP0<06afR`1/
MH/0K7F<06igT01_NI80LG^C07=mT`1dOY<0MH2C07B0TP1eP980Mh>C0P1hPi<02`1iPY<0NX>D07^4
U`1nQYP0OXRH07n8V@21RY/0PHZM0869WP21RYl0PX^O0080PhbO00/0Q8fO08F?X028T:40RI6Q08VA
XP2:TjD0RY>T08^DYP2<UjP0SINZ08jHZ`0208jIZ`0;08nIZP2BWJ`0U9j[09BNZ@2FWjX0V:6Z09VQ
ZP2IXj/0VZBZ09bVZ`2OZ:h00P2OZ:l0302NZK40WZRb09jZ/P2OZ[40WjZ_0:6/[`2R[:h0Y:f/0:B]
Z`2U[Z/0Yjf[0:R^ZP80YjnY00<0YZnW0:N`Y@2V[j<00P2U[j@20:J_Y@040:B^Y02R[:80X:ZQ09^X
W080HFEU00/0?Se30411@P0n?SX0=SD`03<a:`0c<BX0B4/l04]A@011ACL0<C<Y03Hj:`0206emF`0<
06IeEP15BcX0BU4o04Q@?P15C3X0DEI105eSB`1EFDD0C4dn0492=`12AC/0:BPV0P0V9b802`0Q8a`0
71hD01TI3@0F5PT04a@9018D2P0@4PP03Q0601LJ300X;a`0:C0K0080:C0N00/09RdM02D]7@0X<B00
;3LS02Xe8P0X<Ah0:34M02Tb700Y<ad0;CPN02dh7@0202/d700602/c7@0[<Qd0:S0M02T_7P0[;al0
;S<Q3oooool000gooooo00H0NXV?07nBVP21UJ00PYNQ086EX@22UZ4208>GXP0;08BGX`24Uj@0QYRU
08VJY`29VjP0RYbX08bNZ02=X:P0S9nW08fPY`2>XJP00P2@XJ/02`2CYJd0U:B]09BR[`2GYK40VJJc
09ZX]02LZK<0WJZc09j[]@2P[KH0XJff0080XZnd00`0Y;2b0:J`/@2W/;40Yk2c0:Zc]@2[];H0[KJg
0:jg]`2^]kD0[[Nc0:jh/@2a^[820;:l/@050;:k/`2b^k80/[bb0;:l[`2a_:h00P2c_Zh0102d_Jl0
]Kn_0;Bo[P2e`:l20;O2/P0;0;S3/`2h`[40^L>c0;W2/P2h`Zh0^<:/0;[2Z`2la:/0_LF[0;k6ZP2m
a:P00P2ma:H02`2naZH0_<BV0;_3YP2ka:@0^/>R0;[5X@2d_YX0XZV:09>IOP1aM5l0BDPg0080A4Lb
00`0?48_03Dj:P0c=2L0<C4T02l^8P0Z:Ql092@K01lP6@0L7QL06Q`F01TK5P0L7QT2024T7P0;02da
9`0_<bL0<3DX034d:@0`<bP0<3@X02ha9@0/<2D0:bhT01hO5`0I6Q800P0F61002`0T:Ad0>TDb034h
:@0^<RD0:2`R02L[8P0W;2@082DN04iMB@1[Of40HW=H0080LhIZ00`0LH=Z0721J`1]OV/0LHEd07N<
N`1cQgD0KX1]08RNP`1NJUl0@TU:08ZPR`2BZi8207V<NP0;07b?N`1oTGd0?Cm004=5B01ePGP0KgUe
05mXIP1XMVh0KWe^06imK01]OFP00P1/O6D02`1[Nf@0IgIO055LBP0f?S<06A/I00d<3@0;20X020D7
00H410030P800P41008020X600H051L@01lS600W;1`0:BlP02P_800Y<20Jooooo`0604eFJ@1@FFl0
Deed05IOMP1HH7L0FV=j0P1JHg`01`1JHgl0FVB005YUP@1KIX00FfMn05YWN`1LJG`00P1MJ7h01P1O
JH00H6V105iVO`1NIWl0GfN0069ZP@80HFZ000L0HFf206=^P@1TL880I72306IaQ@1XLXD0JG:60080
JW>800L0K7>906edR@1]M8X0KWN=06miS`1bO980MGjD0080MGjE00<0MGnE07EoU01fP9@00P1gPY<0
2`1hPi@0NH>C07Z4T`1lQI@0OHJE0828UP20R9T0OhRJ0829W@1oRih0OhZM0080OhZK00/0PHfL08B>
W@26Sih0R92N08RAW`28TJ00RI>Q08^EY02<UJL0S9JW08jHZ00208nJZ@0;092KZ@2BW:X0TifZ09FN
Z@2FWZT0Uj2Y09RRZ@2IXjX0VjF[09bVZ`2NYj`00P2NZ:d0302NZ:l0W:R`09bY/02MZjl0Wj^/0:2[
ZP2Q[:X0Y:fZ0:F^ZP2U[JT0Z:jZ0:V`Z@80Z:nW00/0YZjU0:J_X`2V[Yl0YZjP0:N_X`2W[j@0Yk2T
0:F_X`2S[J80XJbQ0:2^X00206Q]K00;03Tg@010@480>SXh03ho>P12A3`0Ad/o04]@@@1:Cd00@DLh
03<g;00b=bX00P1VMeL0301`PF00A4Xi04M>?P16CCh0@DHh05AKAP29VWH0JW9J06=ZEP1PJ5H0CE=8
02/[:@809bTU00H0824K01PI4@0C4`X04A06010?1@0@40H2018C2@0301@F2@0S:1@08bPB00808BDB
00/07B4@01hS4`0V;1/0:S8O02D]700O9AH08RTH02H_700Y<Q`0;CPN02dg7@0202hf700602dd700]
<a`0:S0K02X_7@0/<B40;C<R3oooool000gooooo00H0M8J:07fAU@21UI/0PiNN08:FWP23UZ0208BF
X@0;08>EX`25UZ<0QYNS08NGXP2:VJH0Ri^W08bLY`2=WjP0SZ6W08jPY`2?WjP00P2@X:/02`2AXJd0
UJ>]09JT[`2GYK40VJFb09ZW/`2KZK80VZRa09bZ/`2MZk@0WJ^c0080Wjb`00H0XZna0:B_/02W/:h0
ZK:a0:^c]02Z/kD20:^e]@040:bf]02/]k<0[[Va0:nj/080[k^_00/0/Kba0;6k/@2a^k80/K^a0;:l
/@2e_K80^<2b0;S0/`2h`;80^<6`0;S2[`020;W2[`0;0;[3/@2j`[<0^L:c0;[3]02k`k<0^L>_0;S1
Z`2ka:/0_LJZ0;k6Z02naZH00P2oajD02`2ma:@0_LBU0;g4Y@2naZ@0_/FR0;_6X@2jaIh0]l:K0;G1
VP2X]8d0Kg5G0080GV1800`0Fee605MJA@1BE440ATDg03hl<@0c<BP0:BTP02@V700R91X07b4I01hO
5`0P8QT202@W7@0;02lb9P0e=bX0>3X]03Pj;@0f=b`0<S<Y02d^9@0Y:R80:R`S02P[8P0P8Q/00P0L
7QL02`0E5a805AHA01XK500I6A<061TD01/N600P8a`071lJ02@Y8017E3h0D5i60080LhQV00`0JGaN
05QWC`0lACP0@de404iKE01UN6X0Jh1^06n4K`1ZOVd0HWEX07:8MP24WH<208NOQ00;08FJP@1`OFd0
;R/c02/Y=01^OW<0LX9f03a1A@1EH5X0M8Mb05YWF@0j@3T00P1<ETH02`1UMEd0HG1J04YFA@0`>Bl0
720M018C4P092@X01PD600D410040`400P8000805a`B00H0:c@R02`e8`0]=B<0:c4Q02L/800U:AhJ
ooooo`06051IJ@1DG6h0Eemf05MPMP1IHWT0FFAj0P1IIGX02@1JIWd0FfMn05]XOP1MJ7l0GFQn05]W
O01LIg`0G6Mm05eXO@0205eYOP80GVUo00/0HF^0065[O`1SKH00HVj106=`PP1SKh40Ig>306QbP`1X
LH@0J7:606UbQP0206YdQ`0<06]eR01_MXP0L7N8079jRP1bNhd0M7b@07MmU01gOIH0MGfG07AnUP1e
OiD0Mh2E0P1hPYH02`1hPiH0N8BD07R4T`1iQ9@0O8JE07n9UP21RIX0P8VK082:W01oRY`0OhZM0080
P8^L00/0PHbK08>>W024SY/0Qi2L08VBW@29TYh0RiFP08fFXP2>UZ<0SiNU096JZ00209:LZ00;09>M
Z02DWZP0UIjX09FMY`2EWZH0Uj2V09ZSY`2IXjL0WJJZ09fWZ`2NZJ`00P2OZJ`0302NZJd0WZV^09fZ
[P2NZZ`0Wj^Z0:2[Z02S[JT0YJf[0:N^[02X[Z/0Z:jY0:R_Y`80YjnU0P2U[Z<02@2V[j80YZnQ0:J_
XP2Y/:@0Z:nS0:F^XP2T[Z<0XJbR0:6_X`0206]`LP0;03Dc?P0o?cl0=cHc055EAP1CF4H0GVA?05YP
B`1?E4<0CEA303a2=@0i@3<00P1PL5H0301[O5l0BU=104UB@011AcT0=SX^04iFA02G[8P0Rian08NE
NP26U7X0F5mB02TX:0809RPS00/07R0H01XL4P0E5P/04A8600l>100@3`D051<901HG300H6Pd07B8@
01hT3P0201/R3@0;01TO3@0I7@d09R/I02he8P0O8aL051H>020V600U;A`0:S<O02lg8@0_=Qh00P0`
=R001P0a=b40;cDP02`b7P0/<Ql0;C<S030g9Poooooo000=ooooo`0606n0R01iS9<0P9BL08>FWP23
UIh0Q9FO0P24UJ002`25Uj40QIRP08BGW`27VJ00RYZS08^JYP2<VZL0SYfZ08jNZ@2@WZT0Tj6[00<0
UJ:]00X0UZ>]09RT[P2HY[00V:Fa09VW/P2JZ;80VZNa09^Y/P2KZK40VjZa0P2O[[40302R[k80Y:n`
0:Ja[`2X/[00Z[>c0:^c]@2[];H0ZkBh0:bf]`2/][H0[[Ve0:nj]080[kZa00/0/K^a0;>k/P2c^k80
]Kbd0;Nn]@2h_[@0^Knd0;Zo]@2h_K<0^;nc0;S0[`020;S0[P0;0;_1/@2l`[<0^l6c0;c2]02naK80
_LJ_0;_4[@2laj`0_<RZ0;_6YP2maZ<00P30b:@02`2naJ<0_/JV0;k5YP2na:D0_lJT0;g6XP2kaJ00
_<NQ0;_6X02laj00[kRD0080WZ>500`0Vj630::ZR@2GX800M7MQ04E1>P0o?CD0<c<Z02`_8`0Y;R00
:BdP02X[7`0[:b0202//8`0;038c:P0o@S<0@dLh03i3=`0g>S80<CH]02`_:@0X:RH092HR02@X8@0S
9ah00P0P8aX02`0K7aD071lF01`M5P0F5A006Q/B020R5`0S9Q`08B<M01/M6@0J7aP08bPO0080<CX[
00`0=d4_03Q1;`0`=RP0:RlR02L[8@0d?C00AE91069fG@1EIE00@Ti105=SD`1[OVT207:7L@0;07B9
MP1fQgP0DEYG03m8B@1MKV<0O9=l05IUE`1SLf40LH=]04mIC@0L6Qd00P0Y:RP02`1OK5T0E61@03U2
>@0Z<R`07b@P01PK5`0?4Pl020X800D8100520801PT2008061lA00H0?dlc04AD>@0hA2l0;CHV02P_
8P0T:1hJooooo`0604iHJ@1CGVl0FF9h05YSN`1IHg/0F6Ak0P1GHgX01`1IIG/0FfIk05]VO01NJ7h0
GfUo05eXO@1KIg`00P1LIg`03P1MJ7`0GfYn05eXOP1MJ7h0GVUo05mZO`1PJWl0HFf0065^P01RKX00
IG6206QbP`1XLX@0JG:70`1ZM8H0201ZM8D0KGN806mhR@1aNXX0LW^=07AlS`1eO980MWjE0P1eOYL0
3`1fOiH0NH6G07V1V01iPIP0NX6G07V1UP1kQ9D0OXNI07n9V@1oR9T0PHVL0828W@1oQid0P8RM086:
W`0208><X00;08:;WP22S9l0PhfN08J?W@28TIh0RY:O08^DW`2=UZ00SYNQ092HXP2BVJ@00P2CVjH0
2`2DVjP0U9fW09BLZ02DVjP0UIfX09NPZ@2IXjP0VZ>W09fVZ@2NYZX0WZRY0080WjZ[00`0WjV[09jY
Z`2MZZX0WJZX09nZZP2QZj/0XZ^[0:>[ZP2U[:/0YZf[0:R]Z@2Y/:L20:R`YP<0YZnT00P0YZnS0:Na
X`2X/:80YjnS0:F]X`2S[J<0X:^S0:2^Y080LgYj00/0?Si703i0@@0f>3H0DEU904mE@`1RJU40HFUA
055GA@1BFdT0@DXk03]3=@0205YXC`0<06UjG01?FD<0C5E00415=00c=2T0D5I4096TP`2=Wh40TJ:4
09V[S01/Mf<08QhO0P0T8b002`0P8QT06Q/A01DE2`0B4PL04@l6014@1P0H6`/071l>01hQ4@0N9180
7B@B00806R4A00X05ad?01HI3`0b>BT0?DDb01DG4P092PP07R@H02df8`0`=b80<STR0`0`=Ql01P0b
=R80;c@R02db8P0]<b80;S@S02lf9@oooooo000=ooooo`0607F7S01oTYP0PiNO08BGX023U:00PYBQ
0P22U:802`24Uj<0QIZS08FIX028Vj80RifU08fMZ02>W:P0SYj[08nP[@2BXJh0U::^0080UJ:]00/0
U:>/09JT[02HYJd0VJN_09ZX/`2KZ;@0VjRc09bY/`2N[;D0WZfd09b[/00209j][`0<0:6`/02S/Zl0
Y[B`0:Na[P2Z/jl0Zk>b0:bd]@2]]KP0[KNh0:ji^02^^;P0[kVf0P2_^kD02`2a_;D0/KZc0;:j/`2d
_;H0]kni0;Rm]`2i_kL0^[nh0;Zo]@2i`;<0^<2b0080^L6`00/0_LBb0;g4/`2m`k<0_/>b0;o5/02n
ajh0_lJ^0;k7[P2laZX0^lJX0;k7YP020;o:YP0;0;c6Y@2laZH0_LFV0;g5Y@2ob:L0_lRV0;g7XP2o
bJ@0`<ZT0;o9X`2nb:800P2naj80302kaJ40_<FT0;[5X`2Z]9@0LG9R059@AP1CEDT0Bdm104E:>@14
BCL0@dHf04=5=P80?d8e00/0?D4e04A9>P19Ccl0@DLj03Pl=00g>cD0<3@`02`_;00Y;2/0:RhY02T]
9P0202L[8`0;02@X800T:1h08R@L01TI4`0K71D08B<J02@W7@0Q91`07AlJ01PK5P0G6AD00P0Q9Qd0
300W:b409RTO02<U7@0P8QT07b8G024V6@0S:1`0B5Hn051OA00h@Bh0;c@W03Ln<@80@4Pl00/0Ae58
05aZG`1cQgH0GViS05ATF@1OLF00IgUT06anJ@1]OF`0GfaQ0457A@0204U?B`0;05eVF`1=Ddd0HFmN
01/O7`0K81d04AH@00`@2P072PD01@P400T;1P0=40X00P0?4`/01P0X<b80>dXd03Q5<`0f@C<0;cP]
02@/8Q[ooooo00@0C5Q[055ML@1EHGH0EF1i0P1GHW`205QRNP0;05USNP1JI7X0FfAk05]TO01KIg`0
FVMk05aYN`1MJG/0G6Qj05aYNP1MJG`00P1MIgd02`1PJWl0HF]o05mZO`1PKH40HFf1069^P@1TKh<0
IG6406MbQ01XLXH0JGB60080JWB600`0JWB706efR`1_Mh`0L7R=075kS`1bO940LgfC07AoU@1eOiL0
MgjH07QnV01jP9T207Z0V00;07V0UP1iP9@0O8:F07n4U`20QIT0P8JJ0828V`20Qi/0OhJK0827W020
RIh00P21Rj402`21S:40PhbQ08B=X@25SIh0R92N08RBX02:Tj00S9BP08^EX@2<UJ40SiJS0080TIVU
00/0TYZV09>KZ02AVJP0TYZY09BMZ@2FWZT0UinY09NOZ02HXJP0VJ>W09^UZ00209bWZ00<09fXZ@2N
Z:X0WJRY09fXY`2NZJT0XJV[0:6ZZ`2RZj`0Xj^/0:B/Z`2V[JX0Z:jY0P2V[jD02`2V/:D0YJnT0:B^
X`2U/:@0Y:nS0:F^X@2U[Z<0YZjS0:B]X`2Q[:40X:jR0080OhR200/0AdQ=0495A@0j?SX0@4Dl04M>
?`1HH4/0J7AJ04mFA@1CFTP0ADdm03U0<@02055NAP0<06YmFP1EHdL0CUU004YB>`0j?Rl0C59108jQ
P02:Vgh0S9b109JVR@21SgD0;RdY0P0U8Ql02`0R8Q`071`F01LF3P0C4PT04A47018B1P0H6`/06b4>
01`Q400O9A<07R@D00807B<D00/06A`?01<D300Z;R@0?TLh01XM6P0;3@`061hD030j9@0^=b40<cXS
034g7`02030f8006034g8`0^=2<0;C8S02hc9@0a=bD0<SPU3oooool000gooooo00H0NXj>08>GV@26
VIl0QYRR08BCXP25U:H208FEZ00;08FGZ025VJL0QYZT08FIXP29Vj@0RibW08^MZ02<WjX0SJ2[08jO
ZP2@XJd00P2BXZ`01`2@XZT0TjF[09JV[@2IYZh0VJN`09^X/P2MZK400P2MZ[40102O[;80Wjb`09n^
[`2O[Zl20::`/P0:0:>b/@2T/:l0Yk:_0:Zd/P2]]K@0[KFf0:fg]P2/]k@0[;Jd0:fg]080[kVf00/0
[kZf0:ji]02_^KD0/[^f0;Fm^02d^kL0]Kfh0;Vo^@2j`KL0^;ne0;Ro]0020;W0/`0;0;W1/P2k`k@0
_L>e0;_2/`2k`k00_LJ`0;k6/02maZh0_<F/0;_4Z@2laZT00P2majT02`2laZT0_<BY0;c5Z02maJL0
_/JX0;o8Y`2obJH0`L^V0;o:Y@2nb:@0_LNS0080_LNT00`0_LJU0;g6YP2maJD0^lJU0;2kV`2EVX80
Uin608fEO01gOFL0KgAN06IYEP1PHU02055DAP0;04Y>@@15B3`0@dDh03m1=@0k?3@0>CTe03Pi=@0g
>SD0>3Xg03@g=00_<Rh00P0_<bd02`0]<R/0:c0Y02DY8P0K7AP06AXE01dP600Q91X08B<J01`N5P0G
6A807AlH0080:blV00`0;C8W02T]8P0Q8Q`07QlH01/L5@0I7Q@06alD01`P4`0X;Qd0;38O02`b800V
:Q/2020R600;01dO6@0Q9200AE1304aHB`0d?3P0=Shh04MCA`1GIeP0HWET06MjJP1UMFL00P1XMfT0
2`1RKV@0<SHh04QDBP0T:bD07bDO00dA3@0<40T02P`500X:100?3`/03a0=00803@d<00H03Pl?014D
4P0D61D0:30V034i;P0W;RHJooooo`0604]GJP1?Fg40E61g05AOM`1GHWX0F6=l0P1HHgT02`1II7P0
FVIi05aWN`1LIg`0FfIj05YWN@1LJ7/0GVYk05eYN@1NJW/0GVYl0080GFQn00/0GfUm061[O`1OJWl0
HFf1061]P@1QKX40I6n306I`Q01WL8@0Ig:506UcQ`0206YdR00906YcR@1/M8/0LGN>07=jS`1dO940
M7jB07F0T`1fP9D0MWnG0080MgnH00X0N82H07R1U`1hPIL0NH6F07^3U@1mPiD0Oh>E07f1U01nQ9P0
OhJJ0P1oQi/03`1oRId0OhZN07j:W`1nRYl0Oh^N086=X023SJ00QHfP08J?X028TJ40R9:R08^DY02;
UJD0RYFU08bFY@0208jGYP07096JZ02BVjT0TIZX09:KY`2BWJL0U9fY09NPZ`0209RQ[00@09NPZP2J
Xj/0VjF[09^UZ`2LYZ`0WJR]09fY[02MZ:X0WZV/0:6Z[P2RZjh0XZZ_0:B//02U[K40Y:b_0:F/Z`80
YJjX00D0YZnV0:J`Y@2T[j<0YK6T0:>^X`030:B^X`030:B]X`2Q[:80XJnT0080RiJ>00/0AdQ=03m0
@@0i>cP0?d8k04]AA@1=DdH0JgUR04]BA@1?EdT0Ae1103Hl<@0204]GA00<06f1G`1HIdX0CEU004]G
?P14CST0B50n08^MN`2<WGl0RYYm08jMPP2?WH80CE160P0X9B@02`0U92807ahL01TI500E50l051@=
01DF300J7Pl0724C01dR4`0P9AD08BHF00807b8D00/06QX>01HE300N7aL0;C4X03i7>@0?4A403a<?
02Tb8@0]=B80<3HS02le8P0202he8@0602lf8`0_=240;S8P034d8`0d>2L0=CXX3oooool000gooooo
00H0OY2C08BFW026Uj80QYJU08JCYP26TjT208JEZ`0;08FFZP26VZP0QibT08RLXP29WJ<0RYfU08ZN
YP2<X:P0SZ6Z08jOZP2@X:d00P2AXZd02`2AXj/0TjF/09JV[@2HYJd0V:F^09RT[P2HYJh0W:V`09jZ
/02OZk00WjZ_0080Wj^_00`0XZnb0:>`/P2S/;<0Xjja0:F_/02X/K80Z[:d0:Zc/`2/][@0[;Je0:^e
]@2[]K@20:jh]P80[[Vg00T0[kVg0;6j^02b^kT0/kZh0;Bl^02h_KP0^/2i0;Vn]`2i_KL00P2i_[L2
0;W0]`090;S0]P2h`K@0^L:a0;[4/02ka;00_<N`0;_6[P2laZh0_/J^00<0_/B^00X0_lJ_0<37[`31
aZh0_/>/0;o4Z`2oaZT0`<VX0;o9YP2ob:L0_/NX0P2najT0302laJP0_/JX0;o7Z@2naZP0_<FX0;S0
Y02g`:@0]KjR0:ffVP2JXXH0R8me07IkI080Fee=00/0F5Y:051AA@1;Bd40ADDl0451>@0n?3H0C513
05QQD01AFT/0C5A603Tm<P02030b:P0;02/]9P0X:R@09bTT024S7P0L7AP07b4I02<V6`0Q9Q/07R0H
01XK5P0T9Ql00P0Z;RH0300/;bH0:R`R02DW7`0R8a`0828J01hQ600K7A<051@;01<C2@0H6@d07b0B
01hN4P805aL>00/04a@=014A300S9Qd0EVI?02lg;P0T:RD08BLW02<[:@0f@CX0DV9A05e^F@0205MT
E00;05MUEP13D4D0?Ta003m=?00N91`03A4<014E3`0B4``04Q8=01<A3`0@3@d00P0<20/01P0:1`X0
2@H900X62P0>3A005ADF020S81[ooooo00H0CUU/051KLP1BGWL0DEef05=NM`1DH7H205EQM@0605MS
M01HIG@0FfMh05eYO01KIW/0FVMk0`1KJ7`01@1MJGd0GVYn05eZOP1MJWh0GV]o0080Gf^000P0H6b1
065]PP1PKH80Hfn206E`P`1VKh@0IW2406QaQ`<0JW>700/0KGN:06miRP1`NHX0LW^<07=mS@1dOXh0
MGjA07J0U01eP9H0MGnF07F0U`0207N2V@0:07V2V01gPIH0NX:E07b3UP1kPID0Nh:F07f4V01mQIP0
OXRJ07n9W@<0P8^Q00/0OhbP082=X021SJ00PhfO08J@X@27TJ80Qi2R08RBY@29U:L0R9BV08ZEYP02
08^GYP0;08fHYP2?VZD0Si^S092KY02AWJH0TYjX09FPZP2FX:/0Uj6/09RQ[02IXZd00P2IY:h0302J
YZl0W:N`09bX/02MZ:l0WJR^09jY[@2QZZd0XZ^^0:B[/02SZk00Y:b_0:>/Z`80Y:bX00/0Y:fW0:>_
Y`2R[jD0XZnS0::]XP2S[J<0Y:jT0:>]XP2R[J80X:^R0:2]X`0208nLT`0;04Y:D@0n?T@0>CXm04M=
A`1JHeD0D5I<06QeHP19DDP0C5I;04E?A00e?3D00P15D480301YOF00FFU?04aH@P1<Ed80Ae4o04M@
@01oT780RYan08RGO@29V7l0RIN106UcI080?T4l00/09RLW024R900N7al06AXI01PH500J71<07B0E
024S600R91P092LI02DW6@02020R5@0;01/I3`0J6100DEa403m7>01IIE004A8A018D4@0U:al0:S4Q
02`b8@0]<R000P0^<b40100]<b40;c@Q02ld7`0c=b<203Hi9`oooooo000=ooooo`06082@U025U9d0
QIFT08FFZ025UJX0Q9B[0P21TZT01P22U:P0Q9RW08NLY`27VjD0RIfW08^NZ@80SJ2[00<0T:6[096P
Z`2CXJd00P2DXZl02`2DY;40UJB_09NV[P2HYZ`0VJF/09VV[@2GY:`0VZN^09bY[`2NZ[00X:ba0080
Wjba00`0X:fa0:6^/02R[k40Y:nb0:F^/@2W/;<0Z;:c0:Vc/`2/][@0[KNf0:jh^P2^]kT20:fg^00:
0:fg]`2_^KP0/[^k0;>j^P2d^[/0][^l0;Nl_02i_Kd0^kjn0;Zn_0<0^[nk00X0^Kni0;[1^`2j`kX0
^/>g0;[3]02ja;<0^lBc0;g5/`2ma[<0_/Jd0`2oa[D0102naK@0_LFb0;o5/P30ak420<;6/0050<35
[@32b:d0`<JY0<78Z`31bJd00P31bJh03030b:h0_lN/0;k6ZP2oajX0_/J[0;k5Z`2la:T0^lBX0;W4
Y`2e`J<0[[ZM0:B`T`80RI1g00/0OH=[071bH01OGE<0DTm:04i=A`17B3l0Bdm205aYD`1VMe/0Hg=F
03Xo;P0202d_900;02PX800R8Qd0824N028R800S8b809RPT02HY900S:B@07R<Q01dQ800g@3L00P0m
Ac`0300a=bl0;34W02T[8P0X:R00:RdS02HY800L7AH04a<<010@1P0F5`X07Ad>01/K30804Q4900/0
3@`700X91@0?3`/0=d0a02/c:@0Q9b806b4O01LN700D6AP07RHN02Tc8`0202D/700;02L^7P0`>BP0
?dXh04MD?@0L7aH05AL@024U6`0I6aD07b4J01dM6@0D4Q<00P0?2a001P0=20l03@H=00d6300<1@h0
30H@01@B5a[ooooo00H0CUY/051MLP1CGgL0Demg05=PM`1EHWH205ARL`0;05ISL`1GI7@0FFIf05UV
N01IIWT0FVIj05]XO01JIg/0FVQi05YWM`1LJGT00P1LJG`02`1NJGh0GfYo05m[O`1OJh00Gf^105i[
P01QKX40HVn206=`PP1ULHD0IW6600<0JG>700/0K7N906mjR`1`NX/0LWf=075lS@1bOHh0Lgn?07F0
TP1ePI<0MH6D07F0T`0207N0U@0;07N0UP1iPIH0NX:G07V2U`1jPYL0NX>G07Z4UP1lQYP0OXNJ07n9
W@21RYh00P21RZ002`20Rj40P8bR086=X`22SJ80Q92R08F@XP26TJ80Qi:T08RBY028TjD0RYBV0080
RiJU00/0S9NT08nIY02AVj<0TYfS09>NY02BWJH0U9jX09JPZ@2FXJT0V::[09RR[00209VS[@0<09^W
/02LYk40W:N`09fX[P2MYj`0WZR[0:2ZZ`2QZjX0Y:^/0:B[[@2T[:d0Y:b[0P2S[:T01@2S[:L0XZbW
0:6]YP2P[J@0XJfS0080XjjT00@0XZfR0:6]XP2NZZ40W:VN0P2>Vi002`1=D5@0@dE:0414A@1=E4d0
HfeN059HCP1KIEP0C5A;04]DB014CD40=C/c0080Ae5100`0HG5F05a[D@1?FdD0CEM404UA@P19D4<0
P8md08VJOP28UWh0RIN008BAO@25Tgd2079mJP0;020N8@0O72406aTM01HD5`0E4a<06AXE01dP5P0P
8QL08R@H02LZ6`0Z;1h00P0R8QH02`0L6A406AHA06=`E`1WMeh0Ae54010@4`0E61P0;cP]02lh;00_
>2P0;3@R0080;C@Q00H0;3@Q02dc8@0]=240<3HR03<i9@0f>RL?ooooo`003Oooool0101lSY@0PiFN
08FGY@23UJP208:CZP80PiFY00/0PiJX08BIZ026VZP0Qi^Y08VKZ@2<WJ`0Sj2]08nN[02AWj`0TZ2/
09FQ[`0209JR/@0;09FR/@2FY;40UZF_09NV[@2IYjd0VjZ_09^X[P2LZ:l0VjR_09j[/@2O[;400`2O
[;802`2P[K@0XZnf0:B_]@2T[k@0Z;6e0:Rc]P2X];@0Z[Je0:bf]P2^]kP0[kRk0080[[Rj00/0[kVh
0:nj]`2b^[T0]K^j0;Jk^P2g^k/0^Kbn0;^o`@2l`<80^l300;^o_`020;Zo_P080;Vn^`2j`;/0^L2j
0;_3^02ob;P0_<Bd0;c3/P2m`k<20;g4]00>0;g4]@30a[L0`<Jg0;o7]`2nb;L0_/Nf0;k6]030a[<0
`lRc0<;6/033ajh0`LN[0<78[@32b:l20<;9/00<0<;9/@30ajh0_lN/0<38Z`30b:`0`<N^0;o6[@2m
aJ/0_LJ/0;c6Z`2jaJT0^LFW0P2d_j<02`2]]Y/0YZnE08^@O@1/KF<0F5MA05EEC@19BT80@TDk04U>
?`15C3`0=CX^0080;S@Y00/0:2`S02@V800O8Ah0828P02LZ9`0[;bX0:c0[02X_:`0V:BP092LX03]4
?@0204=>A00<03Dn=P0c>c80<3L]02le:`0^=2X09BPR01`M6P0B4A00410:01DF3@0K7A0071h@0P0G
6@h02`0@40X03@`700`;1`0A40`05QTC01HJ5P0D61H04ADC014F4P0G7QH06B0E00805ah@00/05ad>
01HJ3@0J71408RDH01`O5@0M8QL08BHL01/N5P0^=2L0<CHX02/_8`0202DW7P0602HT7`0V8ah07aTI
01TC5P0D3aD04@dE6_ooool01P1:F6X0CE]`051NM01AGgH0DUmg05ARM`80EF=e00H0EVAe05MUM01H
IGD0FFIf05YWM`1KJ7P205]XN@0305aZN@1JIgL0FfMh0080GFUm00/0H6V0065[Q01PJh80HFb3065]
P@1OK7l0HFio069`P@1TLH<0IG:506QcR00206afR`0306efR`1^N8d0LWb@0080LgfA00L0LGbA079m
TP1dOi80MX6C07J2TP1fPY<0N8:F00<0Mh6E00X0N8:H07Z3V`1jPi/0NhBK07^7V`1lQYX0OhVL0828
V`20RYh0P8ZM0P20Rj002`20Rj40PHbS08:=YP22SjH0Pi2U08>?X`23Sj40QY6R08RCY02;UZP0SINW
0080SIJU00/0SYRV092HY@2BVZH0Ti^T09>MY02DWZD0UYnU09NPY`2GXJL0V::W09RRZ00209ZTZ`0<
09^V[P2KYZl0VjJ_09bV[P2MYjh0WZR^09jX[@2OZJd0XZ^]0:B/[@2S[:`0XZb[0P2S[JX02`2R[JT0
XZfX0::]Z@2Q[JT0XjnZ0:6]YP2Q[JD0Wj^T09fYX02KZ9h0VJNK0080SI^@00/0EeaN04E8CP1:DE80
HFaP05aUE`1AEdX0DUU;04aDA`18DD@0?dHj03<h;P0203i6=P0<06AdE`1QLEH0DUi804aF@`18Cd00
ADTn07Z8L02=Wh80RIR008^JP`26Tgl0S9^30P25U7d02`0T8R<06aHK01dJ700G51H0510A01@B400I
6A<08B<H034d900g>RT0<cHW008092HJ00/071dC01LD3`1DG4P0OY1_05EPC`0L7Ah051DI038l=00c
?C80;CLY02Tc8P0202Xc8@0602Xb800Z<b00:C4O02/c8@0_>2@0<cXW3oooool000gooooo00H0NXfC
086EW@23UZ@0QIRX08>DZ022TjP208BEZ@0;08FGZP24UZ/0QIR/08RJ[P2:Vjl0S9f_08nP[P2AXJh0
TYn]09>O[P2DX:l00P2EXK402`2EX[00UZB`09NU/02HYJl0VJN_09^Y/02KZJl0WZ^`09jZ/02PZk80
XJfc0080Xjnf00`0XZff0::]^@2S[[/0Xjjj0:>^]`2T/KP0YK:h0:Jd^02X][P0Z[Fh0:be^@2/]KX2
0:fe^`0;0:ng_@2_]k/0/KVl0;Bj_@2e^K`0]KZm0;Jl`02h_/00^Kjo0;Vo_`2i`;l00P2h`;d02`2h
_k/0_<:k0;_0^02l`[L0_lJg0;g5]@2ma;@0_/Fb0;c4/@2maK80_L>d0080_/Be00/0_lNg0;o7^02o
akL0_/Jc0<36/@33ak00`lN]0<?6Z`33aj/0`lN]0<;7[`020<C8/P0<0<?8/P33b;40`/R^0<76Z`33
b:`0`lR]0<;7[P2oaJl0_LB]0;g5[@2maJ/0_<FZ0P2j`jT02`2j`jP0^L>V0;G0X`2T[YD0Oh=e07Ei
JP1QHeL0DU=;04i?A@14AS`0>che0080<cH_00/0:bdY02TY9`0S9B@09BLV02/_:`0^=2d0;cD/02db
:P0^<2T0;RhZ02l`;@0202lb;`0<02hc;@0^<b/0;cD[034i;@0^=R`0:2hW02<V8`0N7ad06adH01hQ
6P0O91X06b4E0P0F6a402`0@4`d03Q4900d@200A4P/05APA01PL5P0E6AD03a<@00lC3P0C61005AX@
00804aP<00/04aH;018D2`0@4PT04Q@<01@H400H71D05a/E01PK5P0N8aT0;3<R030g800202P]5P06
02//5`0b<1l0<2dQ02XV7`0/;2H0:2XT6_ooool01P18EVP0BeU/04mNL@1@GG@0DEed05=OMP80EF=f
00/0EfEg05QUM@1IIWD0FVIg05aXN01JIWT0FfMj05]WN`1KJ7`0FFIj05UVN`0205aXOP0;05mYP@1O
JX80H6^3065]P`1QKX00HFin069_OP1SLGl0IG:306QcQP1ZMXT00P1/Mhd01P1_N8l0L7V@075jT01c
O940LWfA07=nTP80M82D00@0M82C07F0T`1fPID0N8>G0P1gPIH02`1gPYT0N8>J07V3V`1iPi/0NXFK
07^6W01lQi/0OXRL07n7W020RIh0OhZO0080OhZQ00@0Oh^R086<X`21SJD0PHjU0P24T:H01@23SjD0
QY6T08RBY@2:UJL0S9JW0080SINW00/0T9RX092HZ@2AVZT0TY^W09:LY@2DWZH0UZ2V09JPY`2FX:H0
VJ>X09VSZ@0209ZT[00409^T[@2KYJl0VjF^09bW[P80WJN_00H0WZR_09nY[`2RZk00XZ^]0:>/Z`2T
[Z/20:>]ZP0;0::/ZP2R[JX0XJbY0::]ZP2T/:`0XZj[0::^ZP2PZZL0WjZT09fYX@2LZZ000P2FY9X0
2`1VK6`0ADM<04a?C@28Ugd0FEm@05AIBP1JHU80C5A803m6?P0d>3@0:RdZ0080=CXa00X0Hg=H06Ad
E`1FHTX0D5U404]B@@13B3/0Lh1W09:UQ02;W800SIj30P29V7l208^KP00;034a;P0K5aX08b4N01/I
5`0@3@d03@T:010=300d>2X0FfM<061/D`1:DT400P0X:b@02`0T9Ql08R8O05YTDP1jRg00KWeV038g
<@0D4aH0?4Lk038j<00Y<BH09RhP00809RhO00H09blN02Tb7P0X<ah0:S<O02hf8@0b>2@?ooooo`00
3Oooool01P1jSI<0PIFM08>FY025V:P0PiBX08:CZ080Q9FY00/0QINZ08BFZ`25V:`0R9Z^08ZK[`2<
WJl0Sj2^096Q[P2BWjd0Tin^09BP[`0209FQ/@0;09FR/02FY;00UjF`09RU[`2IYjl0VjV`09^Y[`2N
Zk00WZZ`0:2[/P2Q[K<00P2S[kH0302R[KH0XZfi0:>^^`2S[[X0Xjjg0:Ba^02U/[P0Y[Bh0:Rf^02Z
]KP0[;Fi0:be^P80[KFk00/0[kNm0:ng^`2a^K`0];Zm0;Fi_02e^[d0][c00;Rn`02i_[l0^Kno0;W0
_`020;S0_@0;0;Ro^`2l`[/0^l2h0;c2]`2oa[L0_LFe0;g4]02naK80_<Ba0;g5/P2m`k@00P2na;D0
2`2oakL0_lNh0;o7]`2na[<0`<Ja0<?7/033ajd0`lJ[0<?7Z`33ajd0`/N_0080a<Rb00`0`lRb0<?8
/@32b:h0`LJ[0<?8[033b:d0`/N^0;o5[`2ma:d0_LF]0;g5Z`2laJX20;[3Z@0;0;[3Z02i`jH0]L2S
0:B^U@1oPgD0MGUZ065SE`1BDd/0CTm504A6?00k?SD00P0c=Rl02`0[;BT0:BTW02<U900U9bH0:bl[
02hd;@0_=B`0;C8Z02h`:@0^;RX0;c0]0080;c8_00`0;S<]02hc:`0_=B/0<CT]02hf;00X;RL08bHS
01hO7@0K7AP07R4J01lT6P0K8AD201HK4@0;010C3@0>4@T03A08014B2`0E614061`F01DI5@0?4a00
3a<>01<H400E6Q000P0C60`02`0C5P/04Q@;010B2@0B50`051P@01PL5@0G6aD061/F01hS6@0/<b80
<3LP0080:2dF00H0:b`G038`7`0`;B40:RHO02`/9P0X:R@Jooooo`0604QFJ01;FF`0Ceia051MM01A
GG@0Demf0P1EHgH02`1GIGL0F6Ee05UVM@1JIWL0G6Qh05YVN@1KIgX0FfMk05]XO01IIWX0FFIk0080
G6Qn00/0GfV105mZPP1PJh<0HFf3065^P01QKWh0HVmn06=aO`1ULX<0J7>606YfR@0206agS@0606mh
S`1`NI00LGZ@07=lT@1bOI40LgjB0P1dP9@0101dP9<0MH2C07J1U@1hPiL207N1UP0;07N2V@1hPiX0
NH>K07V3V`1jQI/0NhJL07b7V`1nR9`0OhNL0829WP1oRYl00P1oRZ40101oRj80PHbS086=Y@21SZD2
08B@YP0508>?Y@26TJ@0R9:U08ZEY`2<UZL00P2=UjL02`2@V:P0T9RY096JZ@2BVjL0TYbU09BNYP2F
X:H0UZ2W09JPYP2IXjP0VJ>Y0080VZB/00@0VjB]09^U[`2KYJh0W:N^0P2MYjl01P2NZ:l0WjV_0::[
/02RZjd0Xjb[0:B^Z`80XjfZ00/0XZbZ0::]ZP2Q[:T0XZfZ0:B`[02R[Z/0XZjZ0:2ZY`2OZZ@0WJVQ
09bZX00209JTVP0;06I/K015Ad`0C4m=08RGO@1IGe00E5U:05YRDP1<E4P0?dHn03@h=00Z;BX00P0e
>S402P1SLeP0I7AG05IRBP1@FD@0Be9104=8>`1cP6L0TZF408^LP02=WX<208VHO`80Ri^000/0<C4^
01/G6P0S8Ah06aTG010=3@0=2@X040d<03@h:P1KId`0H6aC04YB@@0202P[900;02@V7`0R8Ql0FVAB
07Z;L01^OFH0<SLa01@C5P0lAc/0<SX`02Ta9P0V;R000P0V;Ql01P0W;ah0:C8N02Pc7P0Z<al0;SHQ
038h90oooooo000=ooooo`0607b>T021TiP0PYFO08BEY022Tj@0QIFV0P27UZP02`27UjX0QIF[08BE
[025Ujd0R9V_08VL[P2=X:d0Sj6]08nO[@2@Wjd0TJ2`0080TZ2`00/0TZ2_09FS/P2IYK<0VZJe09bW
]P2JYkH0VZRd09fZ/P2OZk40XJ^b0:6//`020:6]]00<0::/]@2QZkH0XZbj0:>/^`2S[[/0Y;2l0:Fa
_02U/K/0Yk:l0:Zd_@2[];`0[;Bm0P2^]Kh02`2^]Kl0[kNo0;6h_`2c^kl0];bn0;Fm`02f_L40][jo
0;Fm_@2d_K`0]/2m0080][nm00/0][jl0;W1_@2h_kT0^Kjg0;c2]P2l`kH0_LFg0;o5]`2m`k@0_/Be
0;c2]@020;c3]@0;0;o6^030a[T0`<Ji0<77]`33bK<0`lR`0<?8[`34bJd0a<R/0<?7Z`33ajh00P34
b;401@34b;80`lJb0<C7/032aZh0`lN_0080`lN`00D0`/Ja0<;6/P30aK40_lJ_0;o5[0020;k3Z@0;
0;g5Z02maZH0^/FV0;O2Y@2`^j00Z[BK09ZSS@20QWD0L7AU05MID01AE4X00P0n?ST02`0g=S<0<S0a
02`[;00Y:2T0:BXZ02`^;00]<2d0;C0[02h`:@0a<bX0:b`T00809bPQ0P0T9Ql02P0W:b80:c0V02T^
9@0X;BD09b`U02DY8`0T:B80;SLY02H_8`0L91T201DI4P0;010B3P0<3`X02`h9010C3P0E6A<061dG
01LL5@0C61404QL?01HL4@0E6a000P0C5``02`0?4`X03Q4:00dB2P0<3`L02`l7010B2`0?40/05QTA
01/N500P9AH09b/H00807Qh=00H0@4@Z024L4`0h=Bh0A4Ln02<T8@0Z<BPJooooo`0604UEJ01;F6/0
Ce]a051MM01@G7D0DUig0P1DH7H02`1EHgH0EV=e05QUN01KIG/0G6Ek05UTO01JIGh0FfIn05aXO`1K
J7d0FfMm0080G6Qo00/0GFR005iZP01NJWl0GV^005m]P01QKWl0HVmm069`O`1TLX<0J7F706]jR`02
06ahR`0<06eiS01_NXd0L7^?071kS`1bOI00Lgn@07B0TP1cOY<0LgjD07AoU01eOiD0MX2F0P1fP9L0
1@1fPIP0MH2H07N1V@1hPiP0N8BH0080NXFJ00@0NhJJ07^5V@1mQih0OHVQ0P1mRJ80101lRJ40OX^Q
07n<XP21SZ@208B@YP0508>>YP24SjH0QY2V08NAY@2:UJL00P2=UjT02`2=UjP0SYRY092JZP2@VZT0
T9^X096LZ02CWZT0TijZ09>NZ@2EX:/0V::/0080VJ>^00`0V::^09ZT/02HXjl0VZFa09^V[`2MYjl0
WjV`0:2Y[`2RZJl0XZ^]0:>]Z`2T[ZX20:>]ZP0;0:>/ZP2R[:X0XZbZ0:6/ZP2Q[J/0XZj]0:>^Z`2Q
ZjP0XJ^V0:2[Y@2NZZD00P2KZZ@02`1[LWD0BD]A04E7AP1IH540CeA704]@A01OJEP0DU]?04A;A00j
@3d0;C4`0080<3Ha00`0EfMA05m^D`1FHTX0De]704eC@`11ASX0J7EO096UQ029VWd0SIb208bIP@2;
V80208nNQ00;0410>@0M5aP09B8O01/H5@0=2PP02@L500/92@15CSh0Q9Yh07jBM01fQfd00P0j?c/0
2`13BTD0CUI?06AbH@1cQ6d0Kh1Y04UBA@0K7A/0BEE3038g;@0[<RH09bdP00809B`N00H092dN02D_
7@0V<A`0:S<N02he800`=B4?ooooo`003Oooool00`1hRhl0P9:I08:CX00208>EY00>08BEY026UZD0
QYJU08JGY`24UJL0Q9NZ08NJZ`29W:`0R9b/08VNZ`2:WJX0S9j[08fN[02?X:l208nO/00;092P/@2D
X[<0UjFc09VU]@2HXk@0V:>e09ZW]P2LZ[D0WJZc09j[/`2NZkD00P2N[;D01P2P[KD0XZjf0:B_^P2U
/;/0Y:nk0:B`_@80YK6m00@0Yk:m0:Vb_@2/];h0[KFn0P2_]kl01@2_][l0/;S10:jg_`2_^Kl0/[_0
0080/kc000@0];bn0;Fm_P2d_K`0];bj0P2e_K/02`2d_K/0][nk0;O0^@2h`;P0^l:g0;g2^02n`k/0
`<Fm0;o4_02m`[T0_/Bj0080_L:i00/0_/>i0;o4^@2n`kP0_lFf0<;7]@32b;<0`<N_0<;9[P33bJ`0
`lR/0<C7[`020<;6/00<0<?7/@31aK40`lRb0<;6/P31a[80`<Fa0<;5/032a[40`lJd0<;5/`31a;00
`<B^0P2oaJ`02`2ma:X0_/JY0;c4Y`2k`jT0^L>Y0;G0Y`2c_jL0/KbU0:2ZUP2>UXD0OXAf0080Gf1H
00D0DU1;04=1?P0k>3D0>3@`03D`;P02034];00402dZ:@0Y9b@0:bXU02/[9@809bLQ00<092@O02<U
7`0R9ah00P0P8a`01`0S:2009BdT02<[8@0S;240;c/Y02Td8`0K8aL00P0D6Q401@0A5@h0418=010B
2`0B5Ph05a/B00806AhD00@061dB01LN4P0K8QD06AlC0P0H7Q802`0B5`l03A8<00dB3@0<40/01`/4
00P;10092P@02PT400/9100>3@H051D;008051<:00H0;C4P01XI400f>Rh0G6YA01LJ4`0J7aHJoooo
o`0404IBI`19EV`0CEYb04mJM080DEeg0P1CGgL0201DH7P0EV9h05MRN@1II7X0FV=k05URO@1II7h0
FFEm0P1IIG`03P1KIgd0FfMo05]WO`1LIh40GVV205aYP01MJWl0GV]n05i[O@1PKGd0HFmn06EcPP1X
MXD0JWR70P1ZNHT0201/NHX0KgZ;071kSP1`O900LGbA079mS`1bOXl0LWf@0P1bO9800`1dOY80MGnD
07EoU@0207EoU@0:07F0U`1fP9P0Mh6H07R2V@1iQ9T0NHFI07V5V01jQIP0NhJJ07b7W080OHNM00D0
OHVM07j;W`1nRih0Oh^P08:>X`02086>Y00408:?X`25TJ@0Qi>T08ZDY`80RiFY00X0RYFX08bHZ@2>
VZX0SiZZ08jIZ@2?VZT0TIfZ096MZ@2AWJX0TYn[0`2DX:d0302DXJd0Uj>^09RT[`2JYK00VZF_09bV
[P2NZK00WjN^09nW[02QZJd0XJZ[0::/Z@80XjfZ00/0XZ^Y0:6ZZP2QZZX0XJ^Z09n[Z@2OZZX0XJ^Z
0::[Z@2PZZL0WjVV09fXY@0209f[Y00;06eeM`14Adh0@dM703i3?P12Acl0@DLo06ajI`1CGU@0BE5<
04=;AP0b=cD00P0a>3<03017DT80Dem:051JA`1?EDH0BDm403m2>`1XMV<0T:B708RHP02<Vh@0S9V4
08^HPP80Sij500/0@44k01dH700U8R4071/H01<C3`0>3`/03Pl<02T_9@1XNE`0Nhe]08>DM00205mX
F00;06]fIP1aOVh0LH1^075oK@1aPFd0HFiL03m6?@1@FdX0=3``02/b9P0W;Al00P0S:Q`01P0S:a`0
9RlM02H_700X<Ad0;CDP034h90oooooo000=ooooo`0607V<T`21UIh0Q9NT08>FY@24UjP0Q9JV0P23
UJD02`24UJL0PiJX08FHZ@26VJP0QibY08RLZP29WJ/0RIbZ08ZLZP2<WZ`0SYn_0080T9ja00@0TZ2d
09>P]02FXk@0UjFd0P2HYKD01@2JYkD0VjVd09^Z]02MZkD0WZ^e0080WZ^f00`0XJfh0:>`^@2T/;T0
YK2i0:B_^02T/;X0Xjnj0:F`^P2X/[`0Z;6l0:^c_@2]]/020:be_P070:be_02/][d0[;Jl0:jg_P2_
]kh0[kRm0;6i_P020;>i_@80];bn0P2e_Kd02`2d^k`0][jl0;Ro^`2i_kX0^[jj0;Zn^@2k`;/0_<:k
0;g3_02naKd0_LFl0080_<:l00T0_L:k0;c2^P2m`kT0_L>f0;_1/@2m`k00_LBa0;k5/@30aZh00P31
aZh20<34[`0<0<35/@2oaK80`<Ja0<76/@31ak80`LFa0<76/P30aK80`/Jd0<?6/`30`jl0_l:`0P2o
`k401`2m`jd0_<>[0;_3Z@2la:`0^lJ/0;O2Z02e_jP00P2f_jP03`2e`:L0[;NP09fUTP2MYI80SYN2
06mcH@1IFd/0De9204M3>012?CD0@3/d03Lc;@0`;BL0;BXV02TU8P0202@Q7P0<028Q7@0T9b408bPQ
020V700N91T07BDI01hU6P0Q:Q`08BXJ01lY5`0Q:QP07B@D0P0I7a402`0G7A005AX>01@I3P0G6Q00
5aX?01TL4P0J7Q@061hD01TO5@0L8aP072<G00806R8G00/051hC00hF3@0=50`0318;00X?1P082`@0
20T400P80`071`<01`D300H70P0200H80@0600L9000>4PD05QX:01hT400N8`l061/;6_ooool01017
EfT0BU]^04iNL`1AGG@2055MM@80Demf00/0E5mh05APNP1EHG/0EV5i05MRN@1HHgT0FFEj05QUN`1K
Igd0G6Mo05aXO`0205]WO`0;05aXP@1NJH<0GFZ105i[O`1PKH00H6b0065]P01RL840IG>106UhQ01/
NhH00P1]NhP02P1]NXX0KgZ;075kSP1aOI00LWb@075lT@1bOI40LWjA079lTP1cOY<407EoU00;07N1
UP1iPiP0N8:I07N1V01gPYT0N8FK07Z6VP1iQYP0NXJG07b8V@1lR9X00P1mRI/02`1nRid0OX^N07n<
WP1oS9l0PHfP082=X@21SZ80PhnS08BAXP27Tj@0RIBU0080RYFV00/0RiJW08bHZ@2<VJP0SIZW08fI
YP2=VZL0SYZW092LY`2AWZP0TZ2X09BQZP0209BPZ`0<09FQ[02FXJ`0V::^09VS[P2JY:h0W:J^09fW
[P2NZ:l0X:V^0:2Z[02QZZ/0XZ^Z0P2SZjX0102SZj/0Xjb^0::[[P2QZjd20:2/Z`050:6[Z`2PZZT0
WjZW09jZY@2LZ:000P2N[:402`1fOgh0@D9;03a0@`0h?C/0?dHo04UAA`21U7T0GVYJ04M@AP15CD@0
<SHb0080<cP`00`0A4`n04]CA01?EdL0D5M804aAA@0l?ST0I6iO09BWRP2:VX00SIf308^KP`2:VH42
096RQP0504Q;@`0H4QD081hL01XJ600F5Q@00P0B50l0100F5a409RXN059LA022UG42075oIP0;07J3
K@1hQg40MhIa07F3K`1eQ700KgiZ06=`H01SLUh0>D0e02H[8@0V;Qh00P0S:aX01P0T;1T0:34L02Tb
7@0/=R00<3PT03<i9Poooooo000=ooooo`0607fAV022UYl0Q9RT08BGY`25UjX0QIRZ0P23UZP02`24
UjT0Q9VX08JJZ026VJL0QYZW08RMZP2:Wj`0S:6]08fP[@2?XZl0T:2`0080TZ2c00/0Tj6f09>Q]@2D
X[@0UJ>c09VW]`2JYkP0VZRf09b[]P2M[;D0X:jf0::_]P020::]]`060::]^02S[KT0Y[6j0:Rc^P2W
/kX0Z;>l0P2W/[/0102Y];d0Z[Bm0:^f_P2Z];l20:Ze`@0:0:^f`02/][h0[KNo0;2h`02a^<00/KNo
0;:i_`2d^L00]K_10;Fl`@<0/kg000/0];bo0;S0`@2h_kl0^;fn0;Vo_@2i_k`0^/6k0;_2^`2j`[X0
^L:j0;W1^P020;_1_@0;0;k4_P2m`kd0_<:m0;k3_@2n`kT0_L>f0;g3]@2oaKL0_lJd0<38/`30b;40
0P2oak001P31b;80`LNb0<76/@32ak<0`lRd0<C8]@80`<Fd00@0`/Jd0<;7]@30a;<0`<Fd0P2oa;<0
1P30aK00_lF`0;o7/02naZl0_LJ^0;c4[080^l:[00<0^l6Z0;[2ZP2g_jX00P2g_j`02`2c_ZP0Yk6K
096HQ@20QG<0IVII05MEB@1?C400AdHi03hm<P0g=Rd0;B/U0080:2HQ00`09BDQ028S800Q920082HO
01`S6P0I7aD05adC01/S5`0J8A<061h?01hT4`0O9AH201lT5`0;01hS5`0L8aP06b8H01TO5P0F6a80
5a/A01XP500L8aD07bHG01hV5P0M9aH00P0K9AD02`0I8Q@05QlA01<M3P0A60/03aD700`A1@0=3`H0
30d400/;100:2PD01`T400801PT200H01PT100P<000<40804QH6014C1@0;2P4Jooooo`0604UGJP1;
Ffh0CUib04mMLP1@G740DEeb0P1DH7H02P1EHGP0EV9j05EQN@1FHWP0EF5f05QTM`1HIWX0FFEk05YU
O01MIgh305iXP00;05iXPP1PJX<0H6b405m[PP1OJgl0H6b1069^PP1TLH<0J7F406aiQ01^O8D00P1_
O8P00`1_Nh/0L7^<075lSP02075lS`07075lT@1bOI<0L7fD079mU@1cOI@0LgjC07AoU00207F1UP0;
07J0U@1gPYH0N8>H07V3V@1hPYT0NHBK07R4V`1kR9/0NXJI07Z6VP1lR9/00P1mRY`02`1nRid0Oh^M
082=WP21SIh0PXjN08:>X022SJ40PhnS08>@XP24TJ80QiBT0080RYNT00/0S9RU08ZGY02;V:@0S9ZS
08fKY02?VjH0Si^W092LZ02AWJP0TZ2W09BRZ@0209FRZ`0309JQ[02GXJ`0VJ:]0080VJ>_00L0WJJ`
09fV[P2OYjh0X:V/0:2Z[02PZj/0XJ^/0080XZ^]00D0XZf/0:B/[@2RZjh0Xjb_0::/[@020::/[004
09n[Z@2OZjP0WjZV09fXX`80WZbQ00/0PHf504A7C00k@480=CLg03Xm>01@F4/0OHab06QdH018D4D0
ATi3034e<00202h_:P0<04E:?01=E4<0DEU7059JB@1?EDL0@48j05iVE`2EZ8T0RYZ008fMQ@2;Vh@0
RYV20P2CYXT01@1HHE405Q4A01hL5`0H5Q<05ADC00804a@A00@051@A01XJ500e>b`0KWiO0P1GHD`0
2`1/NF00LX1W07>0J@1dPF/0N8I`07J6L@1^Of/0KWmZ03Y1>00Y;R@0:c8S00809bhL00H09bhJ02Tb
7@0[<al0;cHR03@i9@0c>BH?ooooo`003Oooool01P1iRiD0Oi:N08>FY@24Uj/0PiF/08FI[P80QIV/
00/0QIZZ08BHY`26VZT0RIb[08RLZP2:WZ/0S:2Z08nS[P2?XZh0SZ2_092P/P02096R]00:09:S]@2C
Xk@0U:Fd09JV]02HYk@0VZVf09^Z]P2M[;H0WZfe0:2^]P<0Y;2i00`0Xjfi0:B_^P2W/[/0Z;>j0:Rd
^`2Y]Kd0Z[Fn0:^f_`2Z][l0ZkRo0:^i_`2Y][d20:Zf`00;0:ji``2^^L80[[O00;2h`@2b^L40/kRo
0;>i`02e^/40]kg30;Jla02e^l@00P2h_lD02`2h`L@0^/;20;W1_`2h_kl0^;nn0;S0_@2j`kd0^lBm
0;W2^P2j`kX0_<:k0080_/Fn00/0_/Bo0;o4`02oa<00`LG30;o4`02oaK`0`/Rm0<77_030akT0`<Rh
0<7:]P020<?:]00<0<C;]@34bkH0`/Ve0<78]@31akH0`LNh0<37^030akT0`<Nh0<78^02oaKH0_lFe
0P30a[D02`31a[<0`lRe0<;7]@30a[D0`LJe0<76/P31a[00`LJa0;o5[`2naJd0_LB^0080_LB`00/0
^l:_0;W0[@2e_:X0[kRV0:6YU`25RWX0JFeN05aPD01@DTH0@d@m03Xj=@0203Lh<P0<03@d;P0_;b/0
:2TW02@U9@0P8b806b0N01TM6@0K81T06AlH01LM500J81D07RDI0P0P9QX02`0M91X07B<J01hU6`0N
9QX072@G01dU5P0O9aD08BXE02</5`0Q:QD082TC00807RHB00L07BDD01`S500K8Q806R4>01PN3@0H
70d05AT<00804a@:00<04A8:00d?2@0;3`P00P0;3`P01@0<40P02`l700hB200?40T030/501[ooooo
00H0BEAV04aIJP1=Ffh0C5U]051LL01CGW<205AOMP0;05APN01FHGT0EV9i05IRN01FHGL0F6Ai05UU
N`1JIW`0FfIl05eWO`1MIh000P1MIWl02`1MIX00GVR2061ZP`1NJH40GVZ0061]P@1RKh80IW>106ei
P`1_NX<0L7Z30080L7Z600`0LG^;079lS`1aO940LWfB07=nT`1bOI<0LgnE079nU@1cOYL0LWbE079m
U@1eOYL207J0U`0307EoU@1eOi<0MX2C0080Mh6E00H0NH>H07V4W01kQI`0NhJK07Z5V`1mQYh207f8
W@0;07j:W01oRid0P8bL08:=W023Si`0PXfK08>=W024Sih0Pi2P08BAXP27U:@00P2:UZ@02`2:UZ<0
RiRR08bHX`2<VJ<0SIZS08jJY02@W:D0T9bV092LY`2@WJH0TInW0080U:6Y00X0UZ2Y09NQZP2IXJ/0
VJ:/09^S[@2MYJl0WZJ_09fV[P2MYjd0WjV/102NZZT00`2OZjP0WjZW0:6[Y`020::[Z0060:>/Z02S
[:L0XZfV0:2/Y@2NZZ@0WJRR0P2N[J802`26Th/0AdY?0455A@0f=cL0>3Tf059HC01XM5l0HF]I05EN
C`11Acl0;c8_0080;2dY00`0@4<f04eC@@1BFDD0DeY704iDA016BS`0FV5?09JWQ`2<Vh40SI^508^K
QP2:VX@208jQQ`0;05]TE@0I5AH08B0K01hK600L6QP05A@B018A3P0B4Ph05QD?03Hl:P1<Ech00P0e
>2X02`0k?S40JgMO06ikI@1aOfP0N8Q`07V;L01cQV`0L85W03Dk<00/<BH0;34T00809bdO00H09R`L
02T`7P0Z<Ah0;38P030f900c>2L?ooooo`003Oooool01P1gRID0OY2N08:DY`23U:`0PI:/08BE[@80
PYJY00/0PiJW08>GY@26V:H0RIZX08ZLZ@29VjP0RifX08nQ[@2@XJh0SYj^08fM/00208jN/@0;08nQ
/P2AXk40TZB`09FU/@2FYK00V:Rc09RY]02IZ[@0W:^d09n]]@2P[;L00P2R[KP00`2Q[;H0Xjfg0:J`
^@020:Ra^P070:Vc^`2X/[`0ZK>m0:Ve_`2Z][d0ZKJk0:Ve^P020:bf_00;0:jg_P2`^;l0/[W10;>i
`@2b^L40/kS00;Fj`@2f^L00]k[10;Fh`@2f^L400P2g_L400`2h_/00^Ko00;Vo_P020;Vo_P060;W0
_P2j`[l0^/6m0;[0^P2k`KT0_<6h0P2m`[T01P2m`[/0_L6k0;g1_02o`[h0_l>m0<74_080`<Bj00<0
`<Ji0;o5]P2oa[<00P31ak803033a[@0`lRf0<;7]P30a[L0_lFh0;k4^P2oaK/0_lNj0;o6^02oa[L0
`<Jg0;o5]@80_lFb00/0`LJa0<?7/P33a[@0`LBd0<75]031a[80`LF`0<35/02na:l0_/>^0;c1[P02
0;_1/00;0;[1/02i_jl0^;j^0;Jm[P2f_Jd0[kFW0:>ZW02@UX/0NWef069TG`1DEDl00P19BT40300n
?cD0=3<^02`Z:@0U8BD081dR01/J7`0M7b407B4O01PL6P0A51803a8@00lC40804AD@00/041D>018F
3`0D6A004aT>01DK4@0D6`d04aX:01@K2@0F7P/05ah:01HM2P0201HL200;01HL2@0F70/051X801<H
1`0F7@X05a`<01HI300D5@/04a@<00l@2P0<3PX00P0930T00`0930X02`l;00/>2P0200/=2`0300X:
1ooooooooooo01Sooooo00H0Ae5W04UEJ@1<FF`0Ce]^055KL@1DGWH305=NNP0:05=ONP1DHGT0EF9h
05ISN@1GI7X0F6Ek05UVO01JIgd0GFR005aWO`80G6Eo00/0FfEo05eVP01OJ840GVR105aXP@1PK840
Hg2206QePP1_NhD0L7^6071jQ`02075kR@0<075kR`1cOHl0LWbA07=nTP1dOi<0LWjB07=nT`1bOI<0
LWbD07=lU@1cOIH0M7jF0P1dOiD02`1dOY@0MWnD07F0TP1gPY@0Mh:C07N2U01hQ9P0N8>I07Z3U`1m
QIX0OHFL0080OHJL00H0OHRL07j9V`1oRYX0PHfK08>>V`25SY`208F?WP0308J@W`25Sj40R9:R0080
RYFR00<0RYJQ08^GX@2<Uj800P2=V:801P2=VJ<0SibS092LX`2BWZ@0TIjU096OY@80TZ2V00`0UJ6W
09NPYP2HX:L0V:6W09ZSZP2LY:/0W:F/09^T[02LYZ`0WJR/09jYZ@2NZZT209jZZP0;09nZZP2PZjP0
X:^W0:6[Y02PZZ80XJ^S0::[X`2Q[:80X:^Q09fYW`2KZ9h00P2N[J402`29UHd0B4Y@0494A`0f=CL0
>3Xi05QRE@1IHU@0FVAC05ANC`1=ETT0>Cdi0080<3<_00`0?T@g04]D@P1AFDH0DEQ504]@?P16BS/0
DUU808nRP@2=WH00S9b408fMQP2<WXH208nRR00;05aUE`0I5AP08AlM01dK6@0J6QL051@A010B3@0A
4P`04Q8;03@k:@1=FCd00P0_<B402`0L61<0J7=L07B3J`1_Of/0MXQa07V<LP1fRVd0LhMX03Hm<00Y
;BD0:BdS00809bXQ00H09RXN02P]7P0Z<1d0;34M02ld800a=R@?ooooo`003Oooool01P1fRI@0OY2M
08:CX`24U:T0PI:Z07j?Z080Oi:W00/0P9BU08>FY025V:D0QiVV08NHY`26V:P0QiZX08ZLZ@2<W:X0
T9j]08jL[@0208jM/00;08fN/@2@XK80TjBb09>S/02EY;40UZFe09FU]02HZ;@0WJ^f09j[]P2NZKL0
0P2OZ;L0302PZKH0XJ^f0::]]@2U[KL0Yjjg0:N`^P2W/K`0Y[2l0:Rb_@2Y/kh0ZKBn0:^e_P80[;Bm
00/0[kJm0;6g_02a]kh0/[W00;:h`02c^L40];W10;Bi_P2g_<40][[20;Bi`0020;>i_P0;0;Bj_P2f
_;l0][fm0;Jm_P2f_Kd0]Kbl0;Nl_P2h_;h0^Kfl0;Zm^P2i_[T00P2k`;/02`2l`K`0_/:m0;k1_P2o
`;d0`<6m0<32_@2o`K/0`<>l0;o3^P2n`kP0`LJg00<0`LFd00@0`LJe0;o5]02naKD0_/Bf0P2l`[P0
1@2naKL0`LJh0;o4]P2oa;H0_/Bd0080_L>a00/0_lF`0<75[`30`Zl0_l:`0<35/P2o`k40_l>`0;k2
/@2k`K00^l2`0;Zo[`020;Rm[@0;0;Vm[P2i_Zl0^Kjb0;Rl/@2f^jh0]KV/0;>gZP2a]jX0Z:nS09nW
V@2CVh/00P25SW/0301HFTh0?CTh03Lb=@0[8bd08a/X01dH900N6b@07Q`T01/L800E5Q/0418G00hA
4`8030l>00/02Pd900hB2P0@50/0318900`C2@0;4PL03QH801<L2@0C70L04a/4014H0@0201@L0`0;
01PO1P0E6PH04aD400lA0P0@4P@04A86010A200@40/03a4=00h@3@0:30X00P072@H01P082PL03A0<
00/>300:30/030h<00`<2A[ooooo00H0BUAV04eGJP1?FVh0CeYa051KL`1AG7D2059MN00405AON`1D
HG/0Demi05EQNP80EV=k00D0EfAk05QUN`1IIG`0FfMn05]VOP0205]VP00;05]UPP1MIh<0GVR305eX
P`1MJH80HFf406EaQ@1YMHD0KWV7079mRP1aO8X00P1aNh/01@1`Nh`0LGf>075mS`1cOY80LWfC00<0
LGfB00@0LGfC07=nU@1cOYH0MH2F0P1ePIH02`1ePID0MH6C07J1TP1gPi<0N8BD07R3U@1iPiT0NH>K
07^3V`1nQY/0OHFJ0080OXJK00/0OhNK07n9W020S9`0PHjK086>VP23Si`0Q8nN08J?X027T:80Qi2Q
08RBX@0208ZCW`0;08ZFX02;Uj00RiNO08^GW`2<VJ00SI^Q08fLX02>W:40T9jS096OY@2BX:P00P2A
WjL0302EXZP0Uj:W09RRY`2IXZP0VJ>Z09ZTZ`2KYJ`0W:N]09bXZ`2LZJX0WJZ[09jZZP80WZVX00/0
X:^Y0::[Z02RZjD0XJbT0:2/Y02P[J@0WZ^T09j[X`2O[:80WJZP09f[WP0209f]W`0;08fKT01:CE80
@4A703Lh>P0g=cP0D5I<04iDB@1EGU00C5I804aGB@15CT<00P0e>c@03010AcX0BE=104eG@`1?F4@0
Be500454>011A3T0Rien08bNP@2:Vh40Rib408JIPP80RYj400/0HFaL01dJ7P0R82007AdL01XJ5`0G
5a<05QHA01@E3P0D5Ph09b/N05e[B`0203i2;P0;02@R701VLed0M8E^06inKP1dQG@0NHae07Z=L`1h
Rfl0?dHl02T]9`0`<RP00P0];R@01P0Z;240:RhN02/`7@0]<ah0<3HQ03<g8`oooooo000=ooooo`06
07B:T@1jSiP0Oi:O086BY020TJL0OXnX0P1nTJT0101nTJH0PIFU08>FYP25UjX208NI[00508NJZ`29
VZX0RYZY08bLZ`2=W:d00P2?WZl0102>Wk40SYnc096Q]@2AXK<209BQ/`0509FS]02HYKD0VjVg09jZ
]`2NZKH00P2OZ;L0302PZKP0X:Vf0:6Z]02SZk<0YZjf0:R`^P2X/K`0Z;6m0:Zb`02Z/l80ZK710:Zb
`@80[;;200<0[kG20:ne`02a]kl00P2b^<401P2c^<80/[S10;>h`02f^/80]k_40;Bj``80/kS000/0
/[S00;:g_`2d^Kl0];[00;Fl`@2d^kl0]KZn0;Jk_`2i_/40^;fn0;Rl_0020;Vl_0050;bn_02m_kh0
_ko00;jm`02o_[l00P30_l001030`<00`<6o0;k0_@2n`Kd20<33_@080<35_@2oaK`0_L:j0;g2^P2l
`[L0_/>g0;g0]@2n`[D20<;5]`0:0<33]@2o`[@0_/>c0;k3/`2n`k80`/Fc0<;4]030`kD0_l>f0;g1
]P80^l6e00<0^[nd0;[0]02j`;800P2i_[402`2h_K00^Kfa0;Zo/`2g_K80]kba0;Jk/02c^:h0/[V_
0;:i/02_]jd0[KFZ0080Z;>U00`0VZ:G06QVK01CCeX0>31202PP<P0V7b`08A/U01dG7`0G4aX05a<I
01@D600A51H2010C4P0;014D4@0?50l03a<>00dB3@093PT01P`600XA200C70`04Q`8018L1P0B6`<0
0P0B70<00`0D70D051X5018F1@02018D1`06014A1P0?3`P04A4:018B300@4P/030h80P0:3@H01P0:
30H03A4;00d@300<3P`03Pl>00l?3A[ooooo00H0B55S04aEJ01@FVl0D5]b055KM@1AG7L2059LN00;
05ANNP1DGgX0EF5l05IRN`1FHg/0EVAk05QTN`1IIG`0FFIl05]WOP1KIgd00P1JIGl02`1KIX80GFN3
05mXQ01OJH@0H6Z406=^QP1WLXH0JWB706mjRP1cOX`0Lgn<0080Lgj<00X0LWf=075mS@1`OHl0LGfA
07=nTP1bOY80L7f@06mlT01aOi80LWjC0P1dOiD207=oT`0:07F2T`1ePI80MH6B07J2TP1gPiD0NH>I
07Z3W01jPih0OH>N07n6W@<0P8NL00P0P8VL082:W020RY`0P8bK082>V`22Si`0Q8nK08B>V`80Qi2N
00h0R9:N08ZEX02:UJ00RiJQ08bHXP2;V:00RYNM08bIW@2=W:00SY^Q08nKX`2?W:D0TIjW09:OZ@80
TInX00@0Tj6Y09BRZ@2HY:X0VJB[0P2HXj/01P2IY:`0VjJ]09bXZ`2LZ:T0WZZZ09jYZ080WZVW00/0
X:^V0:6[X`2R[:<0XZbS0::]X`2Q[J@0WjbS09j[XP2MZj40WZ^P09f[W@0209f/W00;09:QU01<CU80
?T5603Hh?@0a<C<0CeE:04Y?A@19CTD0ATi204]FB017DT<00P0d>c00300j@cD0B5<n04YE?P1;ESd0
Adhi03/m<00c=2/0P95d08fPPP2:Vh40RYb508FHP`80R9b500/0JgYY01lO8`0T8b<08B0N01hN600K
6a@06QXC01LI4@0I6Q<082@J02le9`0202lb:00;0418>P1aPfP0MHM^0762KP1dQG40NHae07b>MP1m
SgD0B51502/]:00d=bd00P0_<BH01P0[;B80:B`N02P]7@0/<B00;c@S034g9@oooooo000=ooooo`06
07J<T`1lTYX0OiBO086DXP1oTJ<0Oi6T0P1nT:D02`21TjP0PiFY08:DZ025UJ/0RIV_08ZI/02;Vk00
RYZ]08ZH[02<VZh0Sib_0080T9f_00/0TYnb09>Q]02EX[D0UJ>e09BR/`2DX[80UJ>c09NT]02JYkH0
W:Vg09fX^00209jW^@0<0:2V^P2RZ;T0Y:Vi0:>X]`2W[;T0Zk2n0:^a`02Z/L00Zk;00:fd`@2//l40
[K?40P2_]LH0102_]<@0[[?20;6e`@2c]l820;>f`@050;>g`@2d^<40]KO00;Jj`P2e^/800P2c^L40
2`2d^/80]KW20;Fi`@2f^l<0^;k50;Nla02f^/80][[00;Rm`02j_/00^kno0080^kjm00/0^knk0;bn
_02o`;h0_kjn0;jn_`2n_;h0`;o00<2n`@30_/00`;no0;jo_`020;o0_`090;o1`02o`[l0_<6l0;c1
^`2l`KT0_L2f0;o0]P30`KH0`L:e0080`L>e00d0`LBe0<74/`31a;<0`<>b0<;3/`30`[40_l2b0;o0
]P2m_kP0^[jg0;_1^@2k`;L0^[ne00<0^[na00/0^Kj`0;Rn[P2h_Z`0^Kj^0;Rn[`2h_Jh0][Z^0;>h
[@2d^K00/[R^0:nfZ`020:jeZ`0<0:ff[@2RZZ@0V:6J065RJ00c;S/0>cHk034Y:`0W7R808QTM01hH
6P0I5AP061LH0P0H61T02`0G61L04Q<C018D500@4Q8030`=00/;2`0=40d04QL?01@J3P0D6`d04Q/;
00803aP700/041P601@L200C6PT05AX<01DI3@0E5``04Q<:018B2P0A4@X04Q<;010B2@0200d@1P06
00`?1@0=3`L03a0;010@3@0?40h03a0=6_ooool01P19DF@0Be=W04iHK01?FG00D5Yc055KMP80DE]g
00/0Deej05IQO01FHWd0EV9m05ERN`1FHW`0F6Al05UVO01JIWd0FVEl05]XO@0205aXOP0;05iYP01P
JH40H6R006=[Q01TK8D0I6j506MbQP1XLhL0KGR:079nS@1fPXl00P1hQ900301fPHl0M82@07AoTP1c
Oi40LgnB07=mTP1`Ni40LWbB07=oT`1bOi80LWjB07B0U080LgnB00/0MH2B07B0T@1eP980Mh>D07J2
U01gPYL0N8:I07Z3V`1lQ9d0OXJN07n8WP0207n8W@0807n9W@21Ril0PHbO086=W`20SIl0PHjM08B@
W@25T9d208NAW`0>08RBX029U:80RIBR08ZFX`2;Uj@0RiRS08bHXP2<VJ00SY^R08nKX`2@VjD0TIbX
09:NZP2CWj/209>PZ`0<09FP[02EXJ/0Uj>/09RT[02JY:`0VZF[09VTZP2JYJ/0W:R[09fYZ@2OZZT0
X:^X0P2R[:L02`2RZjH0XZ^S0:2[X@2R[:00XjjQ0:6]X@2Q[J80XZfR0:2[X@2PZj80X:bP0080Wj^L
00/0VZRH05EGF@11@TH0>ci0038b=019CT@0CU=604U>@`18CT<0CeY;04=<?`02034f;00<03Dk;P1A
GTD0CUY104eF?P18CST0?T4c030_:P1hQVh0Sj6508ZKP`2=WXP0RIZ50P2;WHL02`1oSg`0:BT]028P
8P0Q7ad08B0H01hM4`0I6@h051D<01HG3P0P91P08B@J00807b0J00/08B<N06amHP1fRFd0LH5Z07R8
L01mSG@0OY1f08BEN01FGTh0;c0Y03Pj<@02038f;P0602da:@0Z;B@09b`O02`a8@0_=BD0<SLX3ooo
ool000gooooo00H0M8NC07fAW@1nTJ00P9BU07jAY01mSj4207j@X`0;082BYP21TjP0PY>Y08BD[027
UZl0QiF_08ZH[`2;V[40Ri^`08fJ/02?V[400P2AW;802`2BW[<0UJ6e09JQ]@2EXKD0UJ:d09RU]P2H
Y;@0VZJe09VU]02IY;@0VjJg0080WJJi00`0WjJj0::W^`2UZ;`0YZVm0:NZ_P2XZkh0ZJg00:^_`P2/
/L80[KC10:fd`P2^]<<20:nda00;0:jda02_]L<0[[C10;2e`@2a][l0/[Jo0;>g_`2b]Kl0/[Jn0;Bh
`02d^L000P2b^<00102d^L40][[10;Ni`@2g^L420;Rk`@050;Nj`02g^L00]kZn0;Rl_P2j_[d00P2j
_[X02`2j_kT0_<2j0;c0^@2m_kT0_;ji0;Vi]P2n_[X0_[nk0;jn^`2m_K/0_[nm0080_/2n00`0_Knn
0;bo_@2l`;/0^kni0;_0]`2l`;@0_/6e0;o0]030`;H0`<6g0;k1]P2m`[@20;o2/`070;o2/@2o`Jl0
_Kn]0;bn[P2m_[40_;je0;Zo]`020;W0]`0?0;[1]@2j`;<0^Kja0;Vn/@2h_:l0]kb]0;Rm[02h_j`0
^Kn[0;VnZ`2g_Jd0]kb_0;Jj[P2d^Z`0/kNZ0080/[N/00`0[kF/0:feZ`2[]:P0X:ZM07b0MP1/KF80
<bT[034W:00/8B<09AdN01lG6@0L5QL201/G5`0;01/G5P0H51@05A0B01@@4P0C3a403@/<00h>3@0D
5Q405adC01LM4@0G7Q400P0F7@h02`0G7Pd05Qd<01<I2`0D6Pd051T>01<H300B5@`03a8;00lA300A
50d04QD;00803a<700H02`h300/;0P0<30@03@d500`=1P0>40PJooooo`0604MAI@19DfP0C5Q[04iI
K@1?FW00D5Yc0P1AFgH02P1BG7P0Deei05EPN`1FHG`0EF5k05IRN`1HI7/0F6Ek05UUNP1IIWX305YW
NP0;05]WO01MJ7d0GVUm069/PP1SKH<0I72306IcQ@1VLh@0JGF6071nS01fQI000P1hQi<0301gQ980
MH>B07B0TP1cOi<0LWjD07=mU@1aOI@0LGbC075oU01`OY<0L7jB079nTP80LWjA0`1eP940201gPi40
N8FB07R4U01hPiH0NXFI07f6V`1jQ9/0NhJN0P1jQ9d02`1kQYd0OXVP082:W`20RZ00PHZP08><X@24
SZ00Q8nP08J?X025T9h0QI6O0080QY:P00/0Qi>Q08RDX@2:UZ<0S9RU08fJY02=VjD0SibV092MYP2A
WJP0TYfZ09:NZ`0209>OZ`0<09FP[@2FX:`0UJ2/09RS[P2JY:h0VZF^09ZU[02JYZ`0W:R[09fYZ@2P
ZZP0XJ^X0P2RZZP02`2RZjP0XZ^U0:6[X`2QZj<0X:bR09n/X`2Q[:@0XZfU0:2/Y02OZj@0Wj^S0080
W:ZN00/0W:bL05iRH@14ADT0ADI603He=`0o@C`0Ad]004aBA01=ETL0DUe=04]FB00203Hn=00<03Lo
<@1JJDd0EfE:051KA01=E400ATXl03Hg<`1`O6X0U:N>08ZIQ02<VhL0RIR60P2<VhP02`25Th00;2Xa
024N8`0S8Ql0820G01dN4P0K6`h04a@:01<E2`0O8QL08BHL00808bTN00/05ADA05i/E01fR6/0KGiV
07R8K`1nSg@0PI9g086CMP1CFT/0=3D_03Xm=00203Hk<006030e:@0[<2<0:RhP02hb8@0c=bH0<cHV
3oooool000gooooo00H0MHJC07Z<W01mSj80OHnU07b=Y01kS:8207f?Y@0;07nAY`20TZP0PI:Z08BD
[026UJd0QiF_08ZI/@29V:l0RiZb08jL]02?WK@00`2@WK@02P2BWkH0U:6g09FQ^@2DX;L0UZ6g09NS
]P2HY;H0Uj>c09VU]@2JYkL209fX^P0<09jW_02QZKd0XjRm0:F[_`2UZKl0YJW00:FZ`02VZl00Z:g0
0:V_`@2Z//80Zk;20P2/]<@02`2]]<@0[[G30:be`@2^]l40/;W30;2i`@2`^<00/KS00;6g_`2b^Kh0
/[Vm0080/[Vo00/0/kW10;Bj`P2e^<40][W20;Rj``2g^L80^;[10;Rj`02g^[l0]kbn0;Ro_P020;S0
^`0;0;Nn^02h_[T0^;jh0;Vo]`2i_kP0^[jj0;^o^`2j`;`0^l2m0;^n^P2k_kX00P2k`Kh0302l`L40
^l6o0;[1_02i_kT0^Knh0;_1^@2l`[T0_L2i0;o0^P2o`;`0_;jj0;^o^P80^l2h00/0_L:f0;k1]02m
`;@0_<6d0;^o]@2l`;T0_<:k0;W0^`2h`;T0]l2g0;Jn]P020;Nl]@0;0;Nk]02f^K80][Za0;Jj[`2g
_:l0][^^0;Fi[`2d^k40];Za0;:i[`2b]jh00P2a]Zl0302_]K00[KB^0:^bZ`2Z]:P0ZK>T0:2YV@1C
CDd0>2la03<[;00^9BH09ahO02DM7P808QXM00/07QLJ01XE5`0I4aH05a@I01HC5@0@3`l030d;00lB
2`0C60d05adA01XQ4`0201`S4`0;01/Q4@0G7@d051X=01@J3`0B60h04AH<010D300=4@X03a@<014E
3`0?50X00P0?4`P01P0>4@H03Q0500h@1@0>3`@03Q0400lA1A[ooooo00H0ATmU04UCJP1<F6h0CEU_
04iIL@1@FW<2055LM@0;05=MM`1CGWL0EF1i05MTN`1FHWX0EfAk05UUN`1HIGX0F6Ai05UVNP1JIgX0
0P1KIgX02`1JIg/0G6Ql05iYOP1PJX40I6n606EbQP1VM8<0IWB106MeP`1/NhL0LH:=0080M8FA00`0
M8BA07>1T01bOhl0LGf@075lT`1bOYD0LWjF071mU@1bOiH0LWnE079nU@1cOi@207=oT`0;07F1TP1f
PY40MhBA07N4T@1iQY40N8B@07R3T@1jQID0O8JH07^6VP1kR9d00P1kQYh0101lR:40OXVR07j9X@1o
RZ4208><Y00508B=Y026Sj@0QXnS08JAX@26TZ000P27Tj402P28UJ<0RYJS08^GY02;V:@0S9VV08ZH
YP2:VJD0SI^U08nMY`2AWJT3096NZ`0<09:NZ`2CWj/0UJ6]09JR[P2HY;00VZF`09ZV/02LYk00W:J]
09bWZ`2OZJ/0WZRZ0P2OZJT02`2PZZT0XZ^X0:>/Z@2RZjX0XJbY0:2/Z@2Q[:T0X:bX09n[Z02PZjT0
WZZV0080VZRQ00/0Vj^O06E/JP11@TL0@TE303@d=00n@C`0AD]204eFBP1AG4h0Dem@04iKC00203e:
?00<03Y6=@1JK500FFQ<05=PAP1<ET00@TLj03Xk=`1ePfl0UJR=08^KQP2;VXP0R9J50P2;VXH02`24
Th00;R/b020K8`0S8B407QhG01XJ400H6@d051H;01TK400W;240;cL/0080;SDZ00/0:BhU05aZE01c
QF`0KWmX07B5K@1kS7<0Oi1g082CN01?F4`0=CTb03Y1=@0203Dk;@06030f9P0]<R80:c0O02ld8P0c
=RD0<cLU3oooool000gooooo00<0N8VF07b>WP1nTJH00P1mSjP03P1kS:L0OY2W07j@Y`20TZL0P9:V
082AY`24U:/0QYB/08NE[02:VJl0R9N]08VH[@2<V[00SYfc0P2?W[@02`2>W[@0Sijd096P]P2BX;L0
TYng09>P^02CWkL0U:2f09FR]@2IYKH0VZJg0080V:>h00H0Uj>g09bV^P2PZK/0XJVk0:>Z_@2TZKl2
0:BZ`0040:F/`02V[L00YZo00:R``P80Zk?300/0Z[;30:^b`P2Z/l40[;G10:jg``2`^<80[kRn0;6h
_@2b^;h0/[Vo0;6h_@030;2h_P80/KW100P0/[W20;Bj``2c^L<0];W10;Jj`P2e^/80/kVo0;Fl_`80
]Kfm00<0]Kbk0;Fk^P2f_K`00P2f_[d01P2f_;/0]kfk0;Rm_02i_kd0^Kjl0;Zn_@80^Kjm00X0^[o0
0;Zo`@2h_kh0^<2l0;No^P2h_kX0^;fi0;Vm^P2l_Kd0^kbn0P2j_Kl20;Vm_@040;Vm^P2i_KP0^;bg
0;Vl]`80^Kfj00D0^;nl0;Vo_P2j`;d0^;nj0;Jm^0020;Nk]P0;0;Rl]P2g_;D0][ff0;Fl/`2e_K<0
];bb0;>k/P2c_;<0/[^c0;6i/`2a^;800P2^]K00302[/jl0Z[:^0:Ra[02X/Z/0Y[2Y0:NbZ02?UHh0
IFAU03`e>`0j<S<0=Bh_02lX;0809b0X00/081/T02DR:@0X9R/06QTR01DF7@0?4A<02`d=00/=2`0>
4P`051PA01PN5P0201/Q5`0;01/P5P0G6a405QXA01HJ500@5A003Q8=00lC3@0@50d04AH?018F3`0?
4`/00P0=4@P200d@2@0400hB2@0>4PP030h400L80A[ooooo00H0Ae5V04UDJP1;EVd0CEM`04mJL`1A
G7H2059LM`0705=MN01DGWT0EEmi05IPN01FHGT0EV5j05MRO00205QTOP0?05QUO@1IIW`0FVMl05YW
O01JIG`0G6Mo05iYP@1OJh<0I6n706EbR01VM8L0IWB606MeQP1XMXL0JgZ90080KWj<00`0L7n?079o
T01bOi40LWjB079lT`1aO9@0LWfD075lU@1cOYH0M7fG079lUP1cOYH207=oU@0;07B0U@1ePI<0N8FC
07V5T`1hQ9<0MhBB07N3TP1hQ9@0NHFF07^7V@1kR9`00P1lR9d0101lR9h0NhNO07b6X01nRJ42086;
X`0508><Y026SjD0QXnS08N@X028Tj000P29Tj402P29U:40R9BQ08VEX`29UJ80RYJQ08ZFXP2;Uj@0
SYVU092JYP2BWJP309>MZ@0<09:MZ@2CWjT0UZ6Z09JPZ`2GX:h0V::_09VS/@2KYK80WJJ`09jX/02O
ZJl0WZR]0P2NZJ/02`2PZZX0XZ^[0::/[02R[:/0X:bZ0:2/Z02OZZL0WZVV09jZY`2NZjL0W:VT0080
VJNO00/0W:fO075kL`0l?T00?D4m02la;`13BD00BeA904aFB`1EHe@0Cee?03m:?P0203E0=00<038k
;`1IJe00FV]>059PAP1;Ed00=cd`03<e;`1fQVd0UJ^<08ZJQ@2;VHP0RYN70P2;VXP02`23TH00<c8f
01/F7@0O71l06aXH01/I500J6A<05aP@01`N500]<bH0A4lm0080=Slb00/0BUM7061`G01^P6T0LH=[
07>5K`1fR7@0NXaf07^>M`1BGU40=cde03U0<`0203@l;P06030f9P0^=280;38R02dc8P0b>2H0<CLU
3oooool000gooooo00H0MXJI07Z;X01lSJL0OHjZ07f=Z`1kRZX207b=Z00;07j?Z01nSjL0PI2W08BB
Z@2:Ujh0RYN_08VG[P2;VZl0SI^_08jL[`2>Vk000P2>W;<02P2@WkH0Sine08nP]02BXKH0U::h09BQ
^@2CWkP0Tijg09FP]@2HXkL309ZU^@0<09RT^@2KY[/0WJNj0:2W^@2QZ;/0XZNn0:J[`P2T[<@0Xj_2
0:>/`02S[;h0YJjn0P2W[kl02`2X/<00ZK;00:Vd`@2[]/40[;Bn0:fd_P2`][h0/[No0;:f_02b]Kd0
/[Jn0080/KO000/0/;O20;2h``2`^L80/KO20;:h``2`]l<0/;K10;6h`02d^L80/k[30;Bj`P020;Bk
`00;0;Bl_`2e_<00][k10;Jn`P2e_<00][bm0;Nl^`2h^kT0^Kbi0;Vm^`2i_;/00P2j_;X0302k_;`0
^[jn0;Vn`02g_[l0][jl0;Jn^P2g_K/0^Kfl0;Vl_@2i_Kh0^[fm0;Vm_@80^;^m00/0^;^k0;Zm_02h
^kT0^;bg0;Zm^@2i_;X0]k^j0;Jj^`2g^k/0^;bj0;Nk]`020;Nk]0060;Nk/`2d^k40/[^`0;:k/@2c
_;<0/[bd0P2a^k400`2`^:l0/;Ra0;6i/`020;6i/@0<0:jg[`2]]:`0Z[6/0:Vb[@2X/Zd0Yk6/0:J`
Z@2KYId0Kg9a051=D@1=Bdd0B4E90P0e<CX02`0X9Bl0:R/a02/]<P0N82L06ahT01PK700C5Q@041@@
014D3`0D5a405a/E00807AlI00/071dI01TI500I6A<06QdH01HI5P0E61<051LB01@H3`0D6A005ATA
018E400200hA300600`?2`0?4Pl04AD@00dA30082`H010D16_ooool01P19DfL0BUI[04aHKP1>Efl0
CeUb059MMP80E5ih00X0Deai05EMN`1FGgX0F61i05MQN@1HH7T0Ef1j05URO@1HHWd0F6An0`1IIGl0
2`1KIX40GFN305iXQ@1OJXH0HVj906AaRP1XMH`0J7J<06UfS@1YMX/0JgR;0080KW^=00P0L7b?075n
TP1`OI80LGfA075lT01aNi80LWbC07=lUP<0M7fI00h0LgfI07AmU`1dOIL0MWnG07J0UP1eP9@0Mh:E
07J1U@1gPiH0N8BF07V4U`1iQIL0NXJI07^8V`80O8RM0P1nRYl02@1nRJ00OhZR07n:X@20Rj40PXfQ
08>?X025Sj00Qi6N08RAWP0208VDX00;08VDX@28Tj00RIBQ08ZFXP2;UZ40S9JR08jHXP2?VZ<0TI^T
09BMY@2DW:H00P2EWJL0302EWZX0U9j[09BPZP2EX:/0V::]09VQ[P2JY;00VjBb09^T/02NZ;40WjV`
09jZ[P80WZZ/00/0WjV[0:6[Z`2PZZX0X:ZX0:2[Z@2R[ZT0X:fV09n/Y@2OZj@0Wj^S09fZX@0209^Z
W@0;09b]W01cOW<0>cdn03e2?P0`<C00@dPn04iHBP1AG4d0Df1@0459?`0c>S400P0X;bP0300W;RH0
FFYA05]_D`19FD<0BEI0034f:P0];bP0L7eW09FYR`2:VH<0SI^808fIR080S9^900/0Q9B303Hg>P0H
4aX081dN01hL600O7AL071/F01HF4P0H6140;c@W05m]E00205UUD@0;04YDA`1HIEL0LHE_0763KP1b
Q6l0LH9_06j0K01bQfh0Df1>03Dj<00h?S000P0e>bh01P0a=bT0;cDU02hd900^=B@0<STV034h90oo
oooo000=ooooo`0607J6V@1jRj00O8fW07f>ZP1mSJ/0NhZZ0P1lSJP02`1nSjP0OXnW086@Y`24TZT0
RYN^08ZG[`29Ujh0RiZ_08fK[`2>W:l0SY^`0080SYbc00X0T9nf08nO]@2?X;@0TZ6f09BR^02DXKT0
Tinh09>N]`2EX;D0V:>g0`2JYKT0302HY;T0VjJk09fW^P2PYkT0XJRk0::W_P2VZl80Y:c40:>[`P2S
[<00Xjbn0:F^_P80Yjno00/0Z;300:Vb`02Y]<40ZkK10:bd_P2]];h0/;Jn0;:g_`2b][`0/[Fm0;:f
_P020;6g`00;0;2g`P2`^<<0/;W20;6g`P2b^<<0/;O30;2f`@2a^<00];W20;>j``2d^/800P2d^l00
2`2d_;l0]Kc00;Jn`@2f_/80]Kc00;Jl_@2g_;/0^;^i0;Vl^@2i_K/0^Kbk0080^[bj00`0^kbl0;Zn
_P2i_/00]kjo0;Jn_02f_[X0]kfk0;Vm_02i_;d0^Kfn0;Zm_@2i_Kd20;Rk_@0;0;Rk^`2j_K`0^;^i
0;Rl]`2j_KT0^Kbj0;Nk^P2f^[/0]k^k0;Rl^P2g^kL00P2g^k@01P2g^k<0];^a0;:k/02b^k40/kbc
0;:l]080/K^a00<0/;R_0;2h/@2a^K<00P2a^K40302^]jl0[KB/0:Za[02Y/Zd0Z;:]0:Na[02V/:T0
VjFM06mbL@1@CE40CD]=04Q5B@80=C4j00/0:2D_02X[<@0[;C807R0W01/N900H6a`04aHD010D400A
50l051LA01LK5@0201dO6@0;01`M6@0I6A@06ATC01XM600F6AH05APC01@G4P0D60l051T@01DI4@0B
5A000P0>4@`01P0<3`/03a8?014E400=4@`020/600@50A[ooooo00H0BE=W04YFJ`1<F6h0CUM_04mI
LP1BGGH205ANN00:05=LN@1EGG/0EUmj05QPN@1GHGT0F61i05MPNP1IHWd0F69m05QTOP<0FFEo00/0
FfJ105eWP`1NJ8D0GfZ6069^R@1TLHX0J7F<06QfS01YMXd0JGJ;06]hR`0206ikS@08071lS`1aOY80
L7fB075mT@1aO900LG^B079lT`1cO9H307AmV@0>07=mV@1dOIL0M7fG07IoU`1fP9H0MH2D07N2U@1f
PID0Mh>F07R4UP1iQ9L0NHFG07Z6V@1kR9/207b8W@80OXZO00T0OXVP07n:XP1oRZ40P8^Q08:=X@23
Sj00QHnP08NAWP28TIh00P29U:002`29U:40R9>P08VDX@2:UZ80RiJQ08bFXP2>V:80SiZS096KY02D
WJD0U9bV0080UIfW00`0UIjZ09BNZ`2DX:X0UJ2[09RR[@2IXJh0VZB`09^T/P2KY;00WZRa09nY/02N
ZZh209jZ[00;09nYZ`2QZj/0X:ZZ0:2ZZ02PZjT0XZjY0:2]YP2O[:D0Wj^T09n[X`2MZZ400P2KZYd0
2`2L[I`0Lgic03/m?P0m@Sh0<34`04=8?P1>F4X0DEa=05=PD011BCl0<cXa0080:2lX00`09bhV05UZ
D@1KKe<0BEU304UF@00a=RX0;BlX071mI`2EZH/0RYV308fKR02=VHP208bKR@0;08BDP`0f=cX061<J
020M7P0N71P07adG01`K5P0F5Q8061PA02ld9`1OKE@00P1IIE402`1:E4L0F6EG0765K`1aPfh0LXA_
0762K`1^P6`0LXM^05=PCP0e>S00>3h`0080=C/^00H0<CLY02le9@0^=2@0;SDT038i9P0a>2@?oooo
o`003Oooool01P1bPYT0MhNQ07b<Z01lS:/0OHb[07f=Z`80OHjX00/0O8fT07f>X`20T:80Pi6S08NE
Z@29UZ`0QYBX08NFY`2;Vj/0SY^]08bI[`0208bI/P0;08fL]@2>WK@0Sijb096N/`2CWk@0UJ2f09FO
]`2EWkH0Uj6e09VS]02HXKD00P2IXkL0202MYk`0WZRl09fW^@2PZ;X0XJNi0::X^`2TZ[l0Xj_10P2R
Zl403`2R[;h0YJjn0:J__`2V[kl0Z;700:R`_P2Y/[d0[;Bn0:fe_P2_][l0/;Jo0;6d_P2a/k`0/[>m
0;Be_`020;:f`00;0;6g`02b]l40/kW20;Bh``2e]l@0/kO40;2ha@2_]/40/;O00;6g`02b^l<00P2b
^L402@2b^L00/k_00;Bk_`2d^kl0];Rl0;Fh^P2g^[P0^KZh0;Zk^@020;Zj^`80^k^k00`0^[Zj0;Vj
_02i_;l0][Zl0;Bi^02d^kP0][bk0;Jk_02g^kh0^;fo0;Rl_@2i_Kd20;Rj^`0;0;Ni^@2h^kT0^;Zg
0;Rk]`2h^kH0^;Zf0;Ri]`2h^KP0^;Zi0;Jh]P2f^KD00P2e^;<0102d^K<0/[Vb0;2h/02a^;020;6i
/@050;6j[`2a^Jh0/;R]0:ng[02`]Zd00P2`][00302^]K00[KF]0:Za[02Y/:d0Yk2/0:J_ZP2V/:X0
Yk6Z0:2YY02<T9@0RHjB08>;S080EeeR00/0<3<k02DZ;P0R9RX07b4V01dO8P0M81`092PL01dP500J
6a405aP?01PH4P0201XH500;01`J5P0M6QL07A`I01hO700K7AX06Q`H01TK5`0E61<05APA01LL500C
5a400P0A51001P0=3`h03A4@00lC4@0=40d01`T600420A[ooooo00H0Ae5X04QEK@1<FW40CEY_04iJ
L01?FW42051KL`0;05=MM`1DGWP0Deef05EOMP1FHGL0Ef9h05MQN01IHg/0FFAl05UUO@1JIX400P1I
IH002`1KIH40G6N405iXQP1PJhP0Hfj:06AaR`1WM8d0JGJ?06UfSP1YMXd0JgN<0080KGZ=00`0Kg^>
06mmT@1_O980L7bA071lS`1bOY80LWfC079mU@1cOIT0LWbH07=mV01dOiP207=mU`0;07EnUP1gP9D0
M7jD07EoU01eP9@0Mh:E07R6V01hQIP0NhJK07b7W@1mR9h00P1kR9h00`1nRYl0OhbO07j;WP0207n;
X006082<W`20SYl0PHjO08B?W`26T9h0R96O0P28TZ0208VEX00908VEXP2;V:@0S9ZU08bIY02=VZ<0
SibS092LX`2BWJ<0TijU0080U9nX00`0U9j[09>O[02DXJd0UJ6^09NR[`2HXjl0VJF_09ZS/02JY;00
WJR`09fX[P2MZZd209jZ[P0;0:6[[`2QZZh0XJZ/0:2ZZP2OZjT0X:bY0:2]Z02O[JH0X:bU09n/X`2N
Zj400P2KZid02`2K[9X0M81d03m4@`12Ad<0=STg0417?P1?FT`0D5a>05=OD@10BCl0>40e0080<CT^
00`0;C@Y04eKA@1FId`0AU8n04QE@00c>B`0;c4Z06eiI@2BXhP0RIR108fMQ`2?WXX208jMR@0;08FF
PP0g>C/06QLM028P8@0L6aT06aXF01TI5@0E5Q806QhG02Ta901`QFD00P1[OV802`1WN6<0ADi707^A
N@1bR7<0HWAR03m;@P11CT<0Jh5U05MVCP0a=bX0>3h^0080=S/[00H0<cPX034g9@0a=b@0<cTV03@l
9`0b>bH?ooooo`003Oooool01P1cQ9L0N8VP07Z;YP1jRZP0Nh^Z07b=ZP80O8fX00/0O8jV07j>Y@1n
Sj<0PI:S08BEY025UJH0QYFW08FDYP28UZT0RIR/08RF[P0208ZH/@0;08bJ/@2=WK40SYja096O/P2C
W[80UInd09RQ]`2JY;P0VJ>f09ZR]@2JX[L00P2IXKP0202JYK/0VjNj09^V^@2NY[X0XJVj0::Y_02Q
Z;h0X:Ro0P2QZL003`2SZl00Y:bo0:F^`02U[/00Yk300:J`_@2W/Kd0Z[:n0:bd_P2]]Kl0[kFn0;6f
_`2a]Kh0/[Jo0;6e_P020;6f_`0:0;:e_`2b][l0/[K00;Fg`P2f^<80/kO20;:h``2_]l40[kO00:nf
`0<0/;W000L0/[[00;:j_P2c^[d0];bn0;Fk_`2f^Kd0][Vk0080^;Zm0100][Rm0;Ng_@2i^Kd0^KVm
0;Vi_02h^[/0][^l0;Jk^`2d^KX0/kVk0;>j_02d^kd0]KZm0;Fj_P2g^kh0]k^m0P2f^k/02`2e^K/0
/kRj0;Bh^02e^[P0]k^i0;Rk^02h^[P0^;Rg0;Ri^02e][D0]KJd0080];Fd00/0];Rf0;:j]P2`]k@0
/;Rb0:ni/P2^^;40[kRa0:jg[`2_]Zh0[[B]0:nf/@020:jd]00<0:fc]02[/k80Z[:`0:Va/02W/:l0
YJj^0:F^[02T[:/0Xj^[0:B/[P2QZjh0WJZ[0P2AXj002`1<E5d09RXg02T^=P0S:2h07b<V01hS7P0S
9a/09BPK02@W6@0P8QH071dG00806aLF00/071PF01lN6P0O81`07b4L01dQ7@0M8A/06QhJ01LL600G
71H06AhG01HK500201<H4@0600lB3P0:3@/02Pd900P:1`041@<00@816_ooool01P15DfP0AUE[04QH
KP19FFl0BeY^04eJL080Ceab00/0DEed055NM@1BGW@0Df1d05APM01EHGD0EV9h05MSNP1GI7`0F6En
05YWP@0205QVP@0705YVP@1JIh40G6R205iYQ01RKhT0I7::06EcR`0206MeS00@06IcRP1ZMh/0K7V;
06aiR`1^O8d0KG^>071mT@1aOI<0KgfC07:0U@1bOY@0L7fD071mUP1`O9H0L7fE075mU080LWjD00/0
LgfD07F0U01ePID0LgnC07=oT01ePi<0MXFG07N5V01hQYX0NXNM07b9W`0207^7W`0;07Z7WP1nRYl0
OX^M07j;W@1nRih0OX^O07n=W`20SIh0PhjO08J@X025T:000P25TZ002`26U:40QYFQ08NFX`29V:@0
RIVT08^JY@2<VZD0SI^S092KY02@W:@0TIjV0080TInX00`0TZ2/09:P[@2CXJh0U::`09BQ[`2FXjh0
V:F^09VU[P2KYjh0VjR^09ZX[@2JZ:`209bXZ`0609jZ[@2OZZh0X:^]09n[Z`2OZjX0WZ^Y0P2NZjP0
0`2MZjL0W:^T09b[X@0209RXW`0;09Z/WP1kRH00A4Y<03m4A@0i?3h0>d4o04I?A`1;F4d0EF=D04]G
B@0lAc/00P0g?cD0300d>2h0>3l`045;=`0j@S00?dPf03Pn<@0_<2/0H6UI09:TR028UX80S9b908jO
SP80SIn<00/0QiV703Tm?`0D41T07A`N01LE5P0E51805AHA018D400U:R80;cL[05i`EP0206n5I`0;
06=dG`15CTL0NXii07J<MP1IJE/05QXM01XN7@0lASH0BE@o03@i:`0g?2h00P0f>b/01P0d>RP0<SLU
03@j9@0f>bL0=SdX03@k:0oooooo000=ooooo`0607B7UP1hS9l0NhbV07Z;Y`1kS:P0NhbW0P1lSJH0
2`1mSJL0OhjX086BZ@22U:P0PiFW08BEYP25U:L0QiFY08RFZ`27UZT0R9J[0080RYR]00/0S9Z_08fL
/02=W:l0SYb`096M/P2CWkD0Uj:g09NQ]P2GXKL0V::h09^T^P0209NQ^P0<09RS^P2IY;X0VZFi09bW
^02NZ;T0X:Vk09jV^`2PZ;`0XJVo0:B[`@2UZl80Y:_10P2W[/<02`2Y/<@0ZK330:Va`P2Y/L40Z[70
0:bc`P2]]<40[kC00;2e_`2_][l0[[Fm0080[[Jm00/0/;Jm0;6e_@2a][h0/kNo0;:f_P2a][`0/;Fl
0;2f_02^]K`0[KJn0:jg_`030:nh_`060;2g_@2b^[`0/[^m0;Bk_P2e^kl0];Vm0P2d^Kh0402b]kh0
/kJm0;Fg_P2e]kh0][Vn0;Jj_P2d^[h0];^m0;Bj_@2d^Kh0];Rl0;Fi_@2g^[d0][Vl0;Fi_@2e^K`2
0;:h^P0;0;6h^02a^;L0/[Vi0;Fk^P2g_K/0^;fl0;Rk_02g^[X0]kVi0;Fg]`2c]KD00P2b]KH02`2b
][L0/;Ni0;2h^02_^;H0[kVf0:jh]02^][<0[[Fc0:ne]02^];80[[Fb0080[;>c00`0[;>d0:Va/P2W
[k40Y[2a0:F_/P2T[k40Y:j^0:>/[02QZZ/0Xjb/0:2/ZP2MZZX209^ZZ@0;08NFU`1YLgT0BU1J03Tm
B@0];cd0:bhh04Q?C@1II5P0=CTf02`^;@0Q8B<00P0J5Q/02`0H4aP071/J01hO6P0O8Q/0728J01XP
6@0H7QP05Q/G01LK5P0G71@05Q/B00804QH?00H02`h:00P91`0820H01PD400@20@040@0Jooooo`06
04QFIP19EfX0BeU`04YHL@1<FG80C5Yc0P1>Fg800`1@G7@0D5if059NM@02059NL`0605=NL`1EHGH0
EV9i05MTO01GI7d0FFEo0P1IIH002`1HIGl0FFIn05UWO@1LJGl0H6j406=aQP1SLXL0IGB906MeR`1X
MX/0JWN;0080JgN<0P1]Nhh02P1`OI40LGjC071nU01_OI<0L7jB06imT01^O940KgfB075nT`1aOY82
0760TP0;07:0T`1dPI@0Lh2E07:0U01bP980M8BD07J5U@1gQYT0MhJK07R5W01hQY/00P1kQid01@1j
Qid0O8RN07f9W`1lRIh0OH^N0080OHZM00@0OhbM086>W@23Sil0PhnP0P24TJ4208BCX@0908FEXP27
Uj<0RIRT08ZJY`2=VZP0SY^V092KYP2?VjL0TIfZ0080T9j[00X0TIj]092P[P2@X:h0TZ6^09>R[@2C
Xjd0Tj>/09JT[02HYjd0VJR]0P2JZJd209b[[@0;09bY[02NZJd0WjZ]09jZZ`2NZZP0WZ^X09jZY`2M
ZjL0VjZW09ZZY@2JZZ@00P2HZ:402`2JZj40NXJ204]?E00l@4H0ADa:04I=A`10Ad40D5a@05ERD`18
DT@0=S`c0080<cL_00`0;c<Y02/`900[<240:c0O034f9@0h?Bd0<C<Z069/F@2@XXD0QiF108ZIQ`2:
W8X208VLR`0;08:DQ@0a=3T05Q<L01XI7@0E51@0518?01DC3@0C4Ph09b/R030c:@1OK5D00P1gRVh0
2`1XMf<0Hg1S0720L@1gRgT0DV1D00h@5@0F5aX04Q4A02DX800_=2H0<SHY0080<cTY00H0<STW038h
9P0d>RH0=S`Y03Ll;00e>B/?ooooo`003Oooool01P1eRIL0NXnP07b?YP1mSjT0O8bW07^;YP80OXfV
00/0PXnY08>@Z`22T:/0PY>/086AZ@22TZL0Q9:X08JD[027UZh0R9R`08RI/00208NH[`0;08ZJ/02<
W;80S9Zb08fK]02>WKD0Sifd09:O]@2DXKH0UJ:h09JR^P2GXk/00P2FX[/0302HY;/0V:Bi09RT^02K
YkP0WZRi09nY^P2OZ;T0WjRj0:6Z_P2QZ/80Xj[40:B[a@80Y:_300P0YJg20:N_``2W[/80ZK330:Va
a02Y/L<0Z[?30:bc``80[[G300`0[KJo0:ff_02]][`0[[Jk0:nf^`2_][d0/KNn0;2f_P2_][/0[[>k
0:nc_02`]Kh20:nf_`<0/;K000X0/;Jo0;6h_`2`^;h0[kNk0;2h_02_]k`0[kJl0:ng_02_^;d0/KVn
0P2d^[l0302d^L00]K[20;>i`02b^Kl0];Vn0;Fh_@2d]k`0];Nk0;Bh^P2d^[/0];Vl0;Fj_080/[Rj
00/0/KNh0;:h]`2d^[P0];Zj0;Fi_02f^[`0];Vl0;>i^`2e^KX0]KRj0;>g^@020;>g^`0;0;6e^P2_
];T0[kBi0:je^02/]KL0[[Jg0:nh^02_]KL0[kFf0:je]@2[/k<00P2Y/K402@2X/Jl0Yk2`0:N`/@2U
[k00Y[2b0:Nb/P2V/K40Y:n_0:2[[0020:2[Z`0>09n][@2LZj/0W:^[09^XZ02IYZD0Qi:E07InQP1N
HG40EeU[08B?T@2:Ui<0JgAe06QcKP0f=cX201D>6P0;01PC7@0D4QP04Q0C01@C4P0E5Q8051DB01<F
4`0C510051D@01@F3P0B5@X00P0>3`L01P071`<02@L500`;1`0:20H01`D300L40a[ooooo00H0Ae5S
04UDJ@1;EW00C5Mc04aFL`1;EW4204eIL`0;04mKM@1@G7D0DUef05=OMP1CGWD0DUid05=OMP1DGgL0
E65j05ESO01HI7h00P1II8002`1HI7l0FFIo05UWOP1KJgl0Gff2065`PP1TLhD0I7>606MeR01XMXX0
JGN;0080JWN;00`0KW^>075oT@1cP9<0Lh2E071nU01^OI<0KWfA06elS`1^O8l0L7b@075lT01aOI42
07>0T`0;07:1T`1aP980LX2D07>0U@1dPID0MX>E07N5UP1hQIT0NHFL07R3V`1hQ9T00P1jQiX02`1l
R9`0OHVM07j:WP1nRIh0OHVN07n;WP20SIh0P8fM086?W`22T:00PY2Q0080Pi6R00/0PY6Q08>CX@25
U:80QIBR08NEX`2:V:H0SI^V08jLYP2?VjH0T9bX08nLZP0208nM[00<08nN[P2>W[00Sin`092O[P2D
Xjh0UJB/09JS[02EXj`0V:J]09VX[@2LZJh0WJV]0P2NZZd209fY[00909fX[02NZJ`0WZVY09jZY`2M
ZZL0WJZX09bZY`2JZJD0VJVS0080UjRP00/0VZ^R07^6P`19C5<0@4A80416A00m@c`0<SH_04QB@`1J
Ie<0Dei<03Y0=`02038g<00<02lc:`0^<bH0:S0P02H[6P0Z;A/0=cTW03@d:P1PJEL0UZV;08ZJPP2<
WHL0Rib70P28VHD02`23UH80=3Pi01DC6P0K6Q`061LG01LG500G5Q805A@@020Q6@0X:Al0HFeC0080
MXMZ00/0KgiV07>2K01bPVh0NXeh05QTF@0A4AT04@hD00l:3@0P7QP0;c8U034d9002038f900603@j
9P0d>BH0=3XV03Dl9`0f?B/0=S`^3oooool000gooooo00H0LH2E07V:X@1kS:H0O8fX07^<Z01jRZL2
07j<Z00;082=Z@21SJ/0PXjZ08:?Z`21SZT0PHjX08>@ZP24TZh0Q9>`08FF/P26Uk<00P27V;002`2:
V[00S9bc08^I/`2=V[H0SYZe08nK]@2@W;D0TYfe09FP^@2FXK`0UZ6m0080V:>m00`0VJBm09VT^`2I
XkT0VZBj09fV^P2OYk/0X:Rm0:6X_`2RZ/40WjS20:2Xa02QZl@20:6[``0;0::[`@2U[L80YJk30:N_
a02W[/@0YZk30:Vaa02[//@0[KC40:bd`@2]]/000P2]][h0202/]K/0[[Jm0:bd_@2]]Kh0[;Bm0:fc
_@2_];d0/;Fo0P2`]L003P2`]Kl0/KJn0;6f_P2a]Kd0/[Fm0;>g_P2a]Kd0[kJl0:ng_02`^;h0/;Nm
0;2g^`2_^;/0/KRk0P2c^[d0302c^Kd0];Vo0;>h_`2b]kl0/kNo0;>e_02c];`0/kFk0;>g^P2d^KX0
]KVj0;Fh^P80];Nj00/0];Vl0;Fl^P2e^[P0]KZj0;Fi_02c]k/0/kNl0;>g^`2d]kX0/kJj0;>d^P02
0;Bf_00;0;6e^P2`];/0[kBk0:fd^@2/]KL0[[Je0;2h]02`]k<0/;Ja0:jd/@2//k400`2X/Jl00`2X
/K40Z;6d0:N_/`020:R`]0060:F_/P2T[K40XZZ_0:2Y[@2PZjl0Wj^_0P2NZZh209^VZ`0909ZTZ`2J
Y:X0U9bS08nHWP2AVYh0TYfM096MV`2BX9T0L7Ud0080924]00/07ATV01PD7`0E4aX03``B01<A4`0M
71X06ALF01HF4@0D5@`05AD<018B2`0200h=2@0600X91P0:2PH03@d800`<1P071@4020D16_ooool0
1016Cf@0BE9Y04]EK`1<EG8404eFL`0;051JMP1?FgH0DEef05=NMP1CGgH0Deif059MM`1CGgT0E65k
05=QN`1HI7l00P1HIGl02`1IIWl0FFJ005UVP01KJ800GV^0061]O`1RL880IG>506IdQ@1WMHD0J7J7
0080L7n>00T0NhZH07j=W@1lRY`0MX>I071mUP1`OID0KWfC06elTP1_O9400P1aO940101cOI80LgnC
07=oT`1cOi8207>0T@0807B0U01ePI@0Mh6E07N2U@1gPiD0N8BG07V4V01iQIT207Z6VP0;07^7W01l
R9d0O8RO07f8W`1oRYh0Oh^N082<W020SId0PXjP08>>X@24Sj400P25TJ8308FBXP0808JDX`28UZ<0
RiNS08fIX`2=Vj@0SY^U08nLY`2AWJX2092M[00<08nM[P2?WK40T9na09:P[`2EXZh0UJ>_09JT[`2G
YJh0V:F^09ZW[@2LZ:d0WZR/0P2OZJ/01P2NZJT0WZZX09jYZ@2NZ:/0WZRZ09fYZ@80WZZY00<0WJZY
09bZYP2JZZ@00P2HZ:002`2IZYl0QI>:04E8C@10ADH0=3Ph02hb<00T9B<0>d8g05m]E`1IIE00BeI6
0080?dHj00T0>3db03<h;00^=2H0;C8S04mH?`11A3@0=cPa05=ICP2DYh`00P2:W8D03P2;W8H0R9R2
08RHPP27UX40ADQ501HB6P0P7b007AhK01`N6@0J6aL05aLC01HF400T9aX0Ef980P1kSV/02`1`PFD0
M8A[07J5K@1gQg40MHAa03Hi>@0L6Qd07a`L028P6P0`<B<0<C<R0080<cLT00H0<cPU03@j9P0e>bL0
=C`X03Pn;00g?2d?ooooo`003Oooool01P1]NY40NHRP07^:Y`1kRZT0NhZZ07Z:Z080O8^W00/0OhbW
082=Y`22SZP0PHfW086=Z022SjT0Q92Z08BAZ`25TZ`0QYF`08BF[`0208>E[00;08FG[@28VJl0RiZ`
08bI/02>V;00SiVb092J]02@VkH0TYfh09>N^P2FX;`00P2GXKd0202IXkd0VZFl09VS^P2LYKT0W:Bg
09nW^`2PY[d0WjFm0P2RZ/403`2QZL80XZ_30::/``2R[<<0Xjc10::[_P2TZkh0YZg00:R^`@2X[/00
ZK300:Vb_`2Z/[d0Z[:k0:^c_0030:Zc_00:0:bd_@2[/[d0Zk6l0:bc_@2^/kh0[kFo0;2e`@2_/l80
[k?10:ne`@80[kBo00D0[kBm0;2d_@2b][h0/[Bk0;2c^`020;6f_P040;:f_@2`][`0[kBj0;:f_080
/KJl00`0/[Rl0;6g^P2a][/0[kFk0:nd^`2`];/0/[Bl0;>e_02d]KX0];Jj0;6e^02b]kT20;:g^P0;
0;:i^`2c^K/0/kZk0;Bi_02c][/0/kFk0;:d^`2b]K`0/;Bj0;6e^`2a];/00P2a]K`02`2_/kX0[kBi
0:ne^02^]KH0[KFe0:be/`2/]Jl0[;B]0:^c[02]]:l0[K>a0080Z[:b00`0Yk2a0:J_/02W[k40Yjnb
0:J]/`2UZk<0YZ^b0:N//P2UZk40XZV`0:6Y/@2OZ;4209jX[`0;09ZT[02LYJ`0W:>[09fT[02JXjX0
V::X09NPYP2GX:D0UYjT096KWP2<V9H00P1YLg<02`1?E5H0=3Hj028P9`0J5al06ADK02`/:`0X9RH0
8R8P01LH500E51005A@B008051@D00H0410B00d?400<3Pd030l:00P910061@0Jooooo`0604Q@H`1:
DfT0BeE_04aEL@1=EWD0CeQg0P1?F7D02`1?FgH0DEag055LMP1CGGH0Deig05=NN01CH7X0EF5m05IQ
OP1GHWl0F6F00080EfB000/0F6Io05UVO`1GI7h0FVN105aXP01PK840H6f106=`Q01ULXH0IWB606aj
S@0207V:V`0;08:DX`26UjL0P8jS07R4W@1aOYP0L7bD06mlT@1]Ni00KW^@06ikS`1_O9000`1cOY80
2`1cOi40M82C07B0T`1eP9@0M82D07J1U@1fPYD0Mh>E07V5U`1iQIP0NhRK0080NhNL00/0NhRL07b8
W01lR9l0OHRQ07f:XP1nRj40OX^N082=W`21SJ00Q8nQ08B?X`0208F?X`0;08JAXP28Tj80R9>Q08VD
X02:UZ40S9ZS08fIXP2<VJ<0SI^T08nLYP2AWJT00P2@W:/0302?Vj`0TIf_09:O/02DXJl0UJ6]09JS
[@2GY:d0V:F]09VV[@2JYjd0W:RZ09bXZ@80WZVZ00/0WjZW09jZY@2NZZL0WjZZ09nZ[02NZZ`0WZ^/
09f[ZP2MZjP0W:^U09b[Y00209Z[XP0;09Z[W`2?X980Ad]?03/o@00_<C80:Rd]02@U9P0d>C@0GVaI
05QUDP1GI5800P1>FTT0300mACL0=C/^02hc9`0/<2H0K7]N04=8>P0j?3H0C51808jOQP2>WhP0S9f7
08jPR@80RY^300/0RIZ0055FCP0K5A`08b4S01dL700L6aX061TG01LG5@0G61<08RDK051LA@0207nD
L@0;07:3J01dQF`0MXI_07F6L01eR740KGeX05EQD@1IIU40BEA103@h:P0k?R/00P0h>bT01P0a=BD0
<SLV03<j:@0d?2X0=cl]03Ln;Poooooo000=ooooo`060760T@1hQid0O8^U07j<Z@1lRZX0NHRW0P1k
RjH02`1nSZ@0PI2T086>X`1oSJ<0OXfU07j=Y`20T:T0PI6Z08>CZ`25U:d0Pi>]0080Pi:/00/0Q9B/
08BBZP27UJ/0RiN/08bGZ`2>V:h0SYR`08jJ/`2@Vk<0TYfe09JO^00209NO^00<09NP^02GXKH0V::d
09^U]02KY;D0WJFg09fT^@2MY;/0WZJl09nV_@2NY[d0XJVo0P2QZ[l02`2RZ[h0XJVk0:BZ^P2V[;X0
Yjfl0:N]_@2U[;/0Yjjj0:R_^02Z/KT0Z[2i0080ZK2k00/0Z:nj0:R__02Z/;/0ZZnj0:bb_02]/kd0
[K:n0:fa_P2/[kh0Zjnn0:f`_P020:fa_P030:fb_@2^/[`0[K:k0080[k>k0P2^/[/0102_/kX0/;Bj
0:jb^P2_/k/20;2e_0080;2f^`2_];X0[[>j0:jc^`2^/kX0[k>j0;6d^`2a/[T20;:c^@80/KBi0P2`
];P02`2`]KT0[kFi0:nc^P2_/kX0[[>k0:nc^P2_];T0[k>i0:^a]`2//[L0Zk2f0080Zk6g00/0Zk2g
0:ba^@2Z/KH0ZK6d0:Za/`2[/k80Zk>_0:^d[@2Z/Zd0Z[6^0:Za[`020:Ra/@070:J`/02T[[00Y:b^
0:F//02VZk80YZRc0:FW/P020:BW[`030:BX/@2RYk80WjFb0080WJF`00/0W:F]09ZSZ`2JXJX0VJ2X
09NOY`2FWZL0UYfV09FMY@2DW:@0TIZR08nIW`0208^GV@0;08RETP1jQH40E5ML0412BP0j>d80=cLm
03/m?`0Y:C409BH]02@U:P0T9bP00P0H61`01P0D51X030hD00P93P0720P010H300@50A[ooooo00H0
A4iM04M@I01:DV/0BU=_04aEM01>EWH204iHMP0;04iIM`1@FgP0D5]h051LN01AGGP0D5ai055LN@1D
H7/0E5ml05MRO`1II8000`1HIGl02P1HIWl0F6In05]XP@1MJH<0GVZ305m/Q01SL8L0I72806I`R@1_
OI<207b<X080P96T00X0O8^P07N3VP1dP9P0LWfD075lT01_Nhh0KWZ>06ajSP1/NXl0Kgb@0P1aOI00
2`1bOI40LWjB07=oU@1eP9L0MX6H07F1U`1gPiL0MX:G07J1U`1fPYP0N8BI0080NHFL00@0NHJM07^8
WP1lR9h0O8VO0P1mRJ401@1oRil0OhfP082=X022SYl0PhfP0080QI2S0P27T:D02@27TJ<0R9>Q08RC
X029UZ80RYNR08^GX@2<V:80SY^T08nKYP0208jJY`0:08nKZP2?Vj/0TIf]09>O[@2CWjX0TYnY09>Q
Z@2DXjX0V:J[09VWZP80VJNY0P2KZJT02`2MZJL0WJVV09bYYP2NZjP0Wj^Z09fYZ@2KZZT0Vj^X09ZZ
YP2JZZ80VZZQ0080VJVN00/0VJ^L092ST`1>EeH0?D91034d<P0/;B`0:b/[03@g<P1KJ5H0F6ED05IR
DP02059NC00<04E??`0h@340;cHX02``900d>2X0<c@Y03Dd;P19Bd@0T::8096RR`2>WhT0T::;0P2;
WHH02`2;W8<0G6AG01XD6P0T8B807Q/L01XI600G5QD05aLD01XI5P0Q81/0ATdm0080Q9Uf00/0M8I/
07B6L01dQG<0M8Ab07>5K`1eRFl0MHU^07J9K01ULe/0>Cd`03m3<@0203Pk:`0602lc9@0^<bD0<CLX
03<k:00f?bX0=3/X3oooool000gooooo00H0L82=07N7V01iRZ00Nh^U07^;YP1jRZ@207V:X@0907b;
X01mRj00OX^Q07f:X@1kRj<0Nh^T07f>YP1oT:P0P96Y0080Pi:/0P25TZ`02`26U:`0QI>Z08NDZ`2;
Ujd0SIN^08fG[`2;UJh0S9F^08fG[`2@V[80U9fd0080UYfd00`0Uije09NO]02FW[80V::c09RS]02H
XKD0V:6f09ZS^@2LYKX0WJJi09bW^@2NZ;`209fW_00;0:2X_@2RZ[d0XjZk0:F/^`2V[;`0YJ^j0:>Z
^02V[;T0Yjfg0:R_^02Y[kP00P2X[[T02`2W[[X0YZfk0:N]^`2X[[X0ZJnk0:R^^P2X[K/0ZJjm0:V]
^`2Y[[`0Zk2m0080[;2l00/0[:nl0:b`_@2[/;/0Zk2k0:^`^P2Z[[P0ZZnh0:fa^@2]/;P0[K6g0:ba
]`020:jc^0040:nc^P2^/[X0[[6j0:b`^080[[6i00H0[k>j0:f`^02][[L0[[2h0;2a^P2`/KP20:fa
]P090:fc]`2^];T0[kBk0:fa^`2[/;/0[K:l0:Za^02Z/KH0ZK2d0080Z[6f0P2Y/;L02`2Y[kP0Zk2h
0:Z_]P2Z[kD0Zk6e0:Z`]02Y/;<0ZZna0:V^/02W[Zh0YJb/0080Y:b]00`0YZn_0:B][@2RZjd0XjZ_
0::X[`2SZ:l0Y:N_0:6T[@2QYJd0X:F^09jT[P2LXZ`209bSZ`0;09^SZ@2FX:L0UinX09JNYP2GWZH0
UYbU09FLX`2CVj00T9RN08nHWP2?V9d00P2;UIX02`2;U9P0RiFG08B>T01jQ8P0Lgj106M`MP1KI6X0
@49A04aBGP1JIFT0BU9D00805QDR00H05aLP00X;50041@d00P<600420@020P4Jooooo`0504A?G@17
DF<0BUEZ04]EL01=EgD00`1<EgD02`1;EgD0C5Ug04iKN@1>FgP0Ceeh04iLM`1AGGP0DUii05AONP1E
HG/0EfAm0080EVAk00/0EF=l05IUOP1GIGl0F6N205YXP`1KJ8<0GVZ4069^Q`1SKhP0IG2:06]fT@02
07F1VP0907R6WP1hQid0M8>H07:0U@1aOI@0L7^B06mkT@1_Ni80KGZA0080KGZ@00<0KWZ@071lT@1`
O9400P1bOI<02@1cOi@0M7nF07AoV01eP9P0MH2G07B0V01ePIT0MhBK07R4V`0207R5V`0;07R7WP1j
RJ00NhVP07Z9X@1kRJ00O8ZO07j<W@1oSId0P8fN08:?W`24Sj000P26T:@02`27T:H0QI2W08F@YP26
TjH0Qi>T08NDY028UjD0RINU08VHY02;VjD0S9ZW0080S9ZX00`0S9ZY08jJZP2@Vj/0TYj/09:OZ`2B
X:X0T:6Y096RZP2CXjT0UJJX09NVZ@2IYjX209^YZP0;09bYZ02KZ:H0W:RW09jZY`2N[:T0W:^Y09ZZ
Y`2KZjL0Vj^U09VYXP2IZIl00P2GZI`02`2GZIT0TjNF05MQG`15C4`0=CTj030b<@0f>CD0?44j05MS
D`1GIE@0EV=A0080DEa;00`0B5A303U3=P0/=2T0;34V02/^900Y:B40:2DQ03ln>@2HZHh0VZbC08nO
R`2>X8/208bORP0;08fNRP1[MVP07AXO028S8P0L71/071`H01TJ4`0I6Q405aD?01lN5`12B3P00P29
WW`02`1dQVh0LhAb07:2MP1cQ7L0LXEb07:9K`1bRF`0MH]/05e[E@10ASX0?dHi0080>3ha00H0<cT/
030e:P0a=bX0=C`/03Lo:`0e?2X?ooooo`003Oooool01P1[O8H0M8JC07V:WP1kS:<0NHZT07Z:Y080
NHZS00/0NHZQ07Z:X@1lS:<0OHbU07b<YP1kRjH0O8bU07j@YP1oT:P0PY6Y08>B[00208>C[00;08>D
Z`25U:/0QYBZ08ZF[@2;UZh0S9N_08ZE/02;U[40RiNa08bH/P2@W;@00P2BW;@0102CW;D0UIfe096K
]02AWK@209:N]00609BO]@2FXKP0Uj>i09VV^P2JYkX0VjNj0P2KYK`02`2KYKd0WJNn0:2Y_@2QZK/0
Y:Zl0:J[_@2TZ[`0Y:Zk0:B[^P2TZ[T0YJ^k0080YJfm00T0YJfn0:F]_@2T[;`0YJfk0:J^_02U[K`0
YJ^l0:N]_P2W[[h00P2X[kl20:R`_@070:R^_@2X[K`0Z:bj0:R]^`2X[[T0ZJfh0:Z^^@020:b`^`0@
0:ba^`2[/;X0Zk6k0:^a^`2//K`0[;:k0:^_^@2[/;P0Z[6h0:Z`]`2[/KL0Zk2j0:Z^^`2[[k/0[;2k
0:b_^P80ZJjh00/0Z:jh0:V`^P2//[`0[;6l0:^`_02//[d0Z:ni0:N_]`2Y/KL0Z[:i0:Zb^`020:V`
^`0;0:R_^P2X[[P0Yjjf0:N]]02X[K@0ZJje0:Z`]`2X[[@0ZJjc0:N]]02UZk<00P2RZK40302TZk40
Y:^_0:>Z[`2RZ:l0XJN_0:6W/@2PYk40WjJ`09nW/02MY;00VJ6]09RQZP80V:2Z00/0V::Y09JQZ@2F
XJT0UJ2Y09FPZ02EWJL0Ti^T09>LY02AVj80TI^O092JW@0208jHV`0;08jGVP2<UIX0RI>I08J@U@23
SY80PHfA07b9S`1iQH`0NHJ?07Z7T01bP8L00P13BUT01P0oBU006b4/00L;5`062Q000`D700820a[o
oooo00D0@diP04MAIP19E6`0BeA`04]FM00304UFL`0;04aIM01<FGD0CEUf04aIMP1=FgH0Ceaf051L
M`1BG7T0Deij05AQNP1DHW/00P1EHW/02`1DH7X0EF=l05ETO`1GIX40FFN205]WPP1MJH<0GV^4061]
QP1RKXP0IG2:0080JGJ=00`0KW^B06mmT`1^OI<0KG^C06ejT@1^Ni<0K7VB06]hT`1ZMY80JgN@06ei
T@1^NY4206eiT@0606ijTP1`Ni<0LGfD075nU@1bOYL0LgjH0P1dOiT00`1ePIT0MX:J07N4VP0207N4
V@0307R6V`1jRIl0NXVQ0080NHVO00H0NXZM07b:W01lRi/0O8ZL082<WP23Sj0208B?XP80Q96U00D0
Pi6T08FCY@26U:D0QiBT08NEY@0208VGYP0@08^IY`2<VJL0RiVX08^IZ02=VJT0SiZ[092KZ`2CWJd0
UIn]09FQ[@2DXZ/0Tj:[09:QZ@2EY:/0UjJ/09VV[@80VZN/0P2LZ:/02@2NZ:X0WjVX09fZYP2LZZH0
VZZU09ZYYP2IZ:<0VZVS09ZZX@0209RXW@0;09JWV@2DYiH0FVEQ04I=C00`<SH0;c8b03]1?010B440
FFEF05UVEP1GI5@00P1AG4d0301?Fd/0ADm302da;00`<bh0;2dX02LT8@0S71h0>3@c09f]T@2R]9T0
TZ6<092PS080Sij:00/0SYn:06ahJ@0M72008b<S01dN6P0M7QL06AXA01LG3`0F50l08b8J04aB@@02
08nUP00;07>7KP1`QG40Kh=h06YoM`1gTX40FG1O05mfH@1[PFT0F6EF03m8@00nAC/00P0g?S<01P0b
>Bd0<3L/030e:`0d>Rd0=cd]03<k:@oooooo000=ooooo`0606]kP`1bPi00MhVJ07Z;W`1iRZ<0N8VT
0P1hRJH02`1gR:D0N8VV07V:Y@1jRj@0NXZT07Z;YP1kRjD0OHnV07j?YP21TJH0Q9>X0080Q9>Y00/0
PY>Z08:DZP24UJ/0QiF/08VE[@27Tjh0QY>`08ND/@28UK<0RIJb08^I/P0208fI/`0<08jI]P2?V[L0
SIZf08jK]`2?WKP0SYbe092M]P2BW[P0Tj2j09>Q^`2BXKT0UZBj0P2IYK`02`2JY[d0VZFm09nY_@2O
Z;X0X:Nk0:>X_02TZ[d0XjRm0:>Y_@2SZ[d0YJ^n0080XjZm00/0XjVn0:B/_P2S[;h0Xj^m0:B/_02S
[;d0XjZn0:BZ_`2W[L40YZbo0:F/_P020:F]_P0;0:F/_@2W[[d0ZZjl0:V]^@2X[KP0Z:ji0:Z^^P2[
/;/0Zk2m0:^^_`2[[l000P2Z/<40302Z/<00Z:no0:N]^`2V[KT0Yjji0:R_^@2W[[L0Z:jj0:R]_02X
[Kd0ZJjo0:Z`_`80ZJnm00/0Yjjk0:J]^@2V[KT0Yjji0:N^^P2Y[kX0Z:jj0:N]^@2W[[X0Yjnk0:R^
^`020:N^^`070:J/^P2W[[T0YZbf0:F/]@2V[;@0YJ^d0:F[]@020:J/]@0@0:F[]@2TZ[D0XZRc0::X
/`2QYk80XJN`0:6W[`2PY[00X:Jc0:6W]P2NYKD0WZJe09fV]02JY;80V:6`09RR[`80Uj6^00D0UYn/
09BPZP2CX:P0TYjW09:LYP02096JY`04092JY@2?Vj<0SYZP08fIW@80S9NK00/0S9NL08^FV`29UIX0
QY6D08>?T`21Si80P8jB07j;T@1mRI<0NhRB07Z8T00207B2R@060720P`1FIfP092hg00T>60031`d0
0@866_ooool01P12CV<0AE1W04IBK01:E700BUAc04QBL`80Ae9c00D0B5=c04QDL`1;EW@0CEUd04iJ
M@0204mJM@0404mJM`1AG7T0Demk05=PN`80E61j00/0Demi05EQN`1FHWh0EfF005UVP01KIh40FfJ0
05aXP@1NJX<0H6b4069_Q@0206AbQ`0<06MeR@1YMh/0JWV>06]jT@1[NI80K7RE06YeU01YMI@0JgJE
06]fTP1[MY00K7N?0P1]N900201_NI80LGZC075kT`1cOID0LgnD079nUP1bP9P0Lh2G0P1ePIL03P1f
PIP0MX6I07J1V@1fPYX0N8BL07R5V`1iQYX0NXNK07^7V`1lR9/0OHZK07f:W01nRil0PHfQ0P21SZ40
2`22Sj<0Pi2S08>@X`23T:40Q9:R08FCX`26Tj<0RIJV08ZGY`2:UZP0RYNX0080RiRY00/0S9VY08fI
Z@2?VZX0Tif[09FNZP2DX:T0TinX09BQZ`2EXJh0Uj>_09NT[P0309VU[P0;09ZU[02KYZ`0WJN[09fW
Z02LYjD0VjRT09^XY@2JYZ@0VjNS09^YX@2JZ9h00P2HYi`02`2FYYT0TZBD05AMF`0j?T40;S0d02d`
<00i?cP0?THl05aZF01JIUH0F69C0080DU]?00`0CeM<04mGB`0o@c`0=SLd02/X:00V82808aXO03Lb
<`2P/9@0Y;FJ09>SS@2@X8d208jNR@0;08fOQ`1WLfD061LL020Q8@0L7Q/06A/E01PI400G60l05QH?
01hP5`14CSd00P1nUG802`1ZP6@0JX1W0767LP1HJ600LHQh06UnK00oBd@0JgiZ05=PE00mA3h0?4<j
0080=Cdb00H0<ST_03<j;P0c>Bd0=CX]03Hl;@0d>RP?ooooo`003Oooool01P1YNh80MHNA07V:VP1i
RYh0NHVT07J6Y@80Lh:S00/0LH>S07:5Y01eR:@0MhZS07V:X`1iRJD0NhbW07f?Y`1nSj@0P96R08:B
XP0208>AY00;086@Y`21TZ/0PI:[08BCZ`26U:`0QiB^08NC/@25T[80QY>d08NE/@29U[000P2<V;<0
1`2=Uk<0SiVg08nI^02?V[T0T9^i092K]02@W;<00P2BW[H2096O]`0>09>Q^02HY;X0V:Bj09ZU^`2J
Y;X0WJJk0:2Y_02QZ;X0XJNi0::X^`2SZ;d0XjRo0::W_P2SZ;h20:6W_@040:6W_P2TZL00Xj[00::Z
_`80XZ^l00D0XjVn0:BY_`2TZ[d0XjZl0:J[^`020:J/_00;0:BZ^`2UZ[/0YZ^i0:N]]`2W[KH0Z:jh
0:N[^02WZkX0Yjbo0:V]`@2YZl400P2YZl80202WZ/00YJVo0:BY_@2UZ[/0YJ^j0:N]^P2WZkP0YZVg
0P2WZ[P0202WZ[/0Z:^k0:N[^`2WZk/0YJ^j0:BZ^@2UZkP0YZfh0P2V[;P01@2W[;T0YJZg0:F[]`2V
ZkL0YZbg0080YJ^g00/0Y:Zf0:F[]P2VZkD0YJ^e0:JZ]02TZK@0XJNd0:6X]02OYk80XZRb0::X]002
09jU/P0<09jT/@2NY;00WJ>]09fS[@2OYK00X:Bd09bQ]02JXK@0V9nb09NN[`2IXK00V:2a0P2FWjl0
2`2EXJh0Tin[096NZ02BWJL0TY^X096KZ02>VJH0S9RS08fJW`2;V9/0RYRJ0080RiJL00/0RYFM08RC
W028UI/0PXjD086=TP21Si<0PXjE082;U@20RY@0OHZA07^9S@0207V6R@0607J1Q@1hQXD0FVMX01HI
9`0<3AL02@LB6_ooool01P10C6D0@TmX04EAK@18Dg00BU=c04YCM080BE=d00/0B5Ac04QDL@1:E6l0
BeI^04eIL01?Fg00CUU`051KM01@FgL0DEai059NNP0205=ONP0;05AONP1FHW`0Ef=m05QTO`1IIH00
FVB105]VP`1MJ8<0GVV3065]Q@1RKX@00P1RKhD0301TLXP0IWB906IdR`1WMXh0J7B@06QdT@1YMI80
JWFC06afU01]Mi<0JgJB06]gT@80KWRA00/0KWR@071jT@1aNi80LWfD079mT`1bOY@0LWjE07=oU@1f
PYL0Mh>G07V2U`0207^4V`0407V3W@1gPY/0Mh:J07Z5VP80O8NJ00D0O8JJ07n9W01oRYd0OhZN086;
X002082;X080PXjQ00T0Pi2Q08B@X024TZ00Q9:P08FBX@28U:<0RYJU08VFY`29UZP00P2;V:X01@2;
VJX0S9ZZ092KZ`2AW:/0TibZ0080TifY00D0UZ2[09NQ[@2HXZd0VJ>]09ZT[@0209bU[@0;09^T[02K
YZX0VjJY09ZVY`2JZ:D0VjRT09ZWY02IYJ80VZNQ09ZVW`2IYI`00P2HYY/02`2FYYT0TJ6C059HF00`
<ST0=3Li02lb<@0a=2d0@DPj05i[E01IHdl0DUU:0080BTe400`0BTa405AHCP19BT@0?chm03Hc=@0d
;S40<2T]04<o?`2FY8d0WjjF09FUT02@X8h208bMRP0;08ZNR01WMFL06QXP024S900I6QX06AXD01PG
3`0H5`h05aP>02<W6P0`>B/00P16Dd002`1LKUH0IWaP05U/E01HJU<0HgIN096[R01FI5D0Df1D051O
DP0/<Rh0=S/c0080=S``00H0=CX_03Dk<00g?C00>3d_03Ll;`0c>B/?ooooo`003Oooool01P1/OHX0
MHNF07^<WP1kRZ<0NHVX07N7Z080LhFV00/0M8NU07B8X`1gRZ80N8ZS07^;Y@1lS:L0O8fY082BZP20
TZL0P9:T086BY@0208:@YP0;08>BZ`23Tjh0PI:^08:C[@23TZ/0QYB]08JC/@26Tk<0QYBb08NF/02;
VK000P2@V[40302?Uk00T9Rc08nI]@2?VKH0T9Ze096K/`2CW;80Tifb09>M/`2DX;@0U:6d09FQ]080
V:>f00/0VjBi09ZS^@2KY;X0WJNi09nX^02RZK/0XZNk0:6V_@2TYkl0XjRn0:6X_@020:2X_00;0:6X
^`2SZKh0Y:S00:>Z`02SZ[h0Y:^n0:>X_02UZ[d0YZbm0:>[^P2U[;/00`2UZkX02P2TZKP0XjVf0:BZ
]02T[;@0Y:^e0:F[]`2VZk/0YZ^n0:FZ_`2UZKl20:JZ`@0<0:FZ`02TZL00YJ[00:JZ_@2VZk/0Z:fj
0:R[^@2WZKT0Z:^j0:V/^@2Y[;X0Z:Zi0P2X[;T01@2W[;T0YZ^h0:FZ^02UZkL0YZbh0080YJ^i00@0
YZbh0:N]^02W[KL0Z:fg0P2X[KP20:R/^0080:R[]P2W[;D0YZ^d0:BZ]02RZ;@0X:Vc09nY]02NYk<3
09fU/P0909fV/`2NY[<0WJB`09fR/02OYK40WJ>d09bR]P2KX[H0VJ6c0080VJ6`00h0VJ6a09NP[`2G
X:l0U9n]09:O[02@VjX0T9bZ096MZ`2@W:/0SIZZ08ZJY@29VJ00RIVO08RGW080RYRM00/0RIFM08ND
W026UI/0PY6E08:?TP24Si<0Q8jE08:;UP21RiH0OHRB07V6S@0207Z6RP0607V3R01iPXH0N8B605AL
IP0g>d/0;c926_ooool01P11Bf@0@deX04QBK@1:E700BUAc04YCL`80BUAb00/0BeIb04]EL01;EFl0
BeI_04aHKP1?FVl0CeY`055LM01@G7D0D5]f04mKM`02051KMP0;059MM`1CGWT0EV5j05MRO@1IHh40
FV>305aVQ@1NJ8D0GVZ4061/Q@1RKXH00P1RKXL0301SL8T0Hg6:06AaS01ULhh0IW:?06MeT@1XMI40
JGFB06YfTP1/Mi<0JgNC06ajT`80JgRA00/0JWN@06eiT@1^NI80L7bC06mkT`1`OID0LWjG075nU@1d
OiL0MX2H07R2V00207^3VP0;07^3W01hPYd0N8>K07V5V@1kQIT0O8JI07f6VP1oR9`0OhZN082;WP22
Ril00P22S9l02`24SZ80PhnS08FAX`24TJ00Q9>N08FDX024Til0QI>N08NEX@27UJ@0RINW0080RYNX
00`0RYNZ08bHZ`2?VZd0TI^]09:L[@2BWJ`0Tin]09BO[@2GX:d0Uj6[09VRZ`2KY:`209^TZP0;09bU
Z@2JYJL0VZFW09ZVY`2KZ:H0VZRV09^XYP2JYjD0VZJS09ZWXP2IYj000P2GYYd02`2EYIX0UZNI05aR
HP0a<CH0=SXg038d<00a<BT0@4@f05eVCP1FGTX0ADPn0080>CPg00`0B4Q705eQF`1QIUh0C4e<04M8
B015A480AD=004e=BP28U800V:J@09JUT@2@X8h208RJR00;08RKR01/O6h06a/P020Q8@0M7AT071dE
01PF3@0G5@/05A@:02<W600^=BD00P0d?Bd02`0oC3T0Cem702Xd9`0_?2`09S0U08BPN`1bRFX09B/T
04EB@P0I6aT0:2/S0080;C4W00H0<3@Z03@h;P0g?2l0>3h^03Lo;P0b>BT?ooooo`003Oooool01P1Y
NH/0M8FH07^<XP1jRj@0NXVW07V7Z080MXJV00/0MXVU07R<Y01kSJ@0NhbU07f<YP1mSJL0OXjY07n?
Z@20T:L0PI:U08BDZ00208>@Z@0608>AZ`23TZd0PY:^08>D[`24U:h0QYF^0P28UK000`28U:l0RYN_
08fI[`0208jH[P0<08jG[`2@V;40TIRc096I]@2AVK<0U9^c09FL]02DW;@0U9fd09FP]@2EXK80V:>b
0P2KY;D02`2LY;P0W:Fl09bU_02MYKX0WZNk0:6Y_@2QYk`0XJNm0::X_P2RZKh0XJVn0080XJZn00X0
XZZo0:>Z`@2SZ<40XZO00:>X_`2SZKd0XjRj0:F[^`2U[;`0Y:^k0`2TZ[/0102UZkd0XZVk0:6X^@2S
Z[P30:B[]`040:F/^`2U[;h0Y:^o0:BZ`080Y:Ro00`0YJZo0:FZ`@2VZl<0YZ_00:J[_@2W[;d0Z:bn
0:V/_`2Z[L00ZZfo0:V/_@2Y[;X20:V/^@070:R[^@2WZkX0YJZi0:FZ^@2UZkT0YJbm0:J[_0020:F[
^P0?0:N]_02Z[[h0ZZfm0:Z]_@2X[;d0Yjbl0:J[^@2UZ[H0Y:Ze0:BZ]P2SZkL0XJZe09nY]02NYk<0
WJFc0080W:Fb00`0WJNc09jW/`2MY[<0W:Bb09fV/`2KY;<0VZ>d09RP]02GXK80VJ>b09VR/@2GX;02
09NP/P0;09FQ/P2BWjl0T9f]092LZP2AW:T0T9bY08nJZP2<VjP0RYZT08VIW`28V9/00P2;VY/02`2:
VY`0R9VK08NHV@25UID0QI>D08FAU024SY@0Q8nG08:=V01oRiP0NhVE0080O8RC00H0OHVA07b5S@1i
PhX0MX:806aiP01TM7PJooooo`06045:H@13CFL0ATm/04QAKP18DG00B59`0P19DW002`19DVh0B59_
04YDL@1<EG80BeEa04aGL01=F700CeYc04mJM@1@FgP0CeYh0080D5]h00/0DEah059MM`1DH7T0EV5k
05QSOP1IHh40FVB405]VQ@1MJ8<0GVV2061/Q002061/Q@0<065^Q`1SL8X0Hfn>06AbT01TLI40IG:B
06IbT@1VLY80IgBC06UdU01ZMI@0JgND0P1[Mi<02`1[MY80K7RC06eiU01^NYH0KGZF06ikU`1_OIP0
LWnH07AoV01dOYP0M7nI0080Mh:J00X0Mh2I07IoV@1fPIT0Mh>H07V4V01jQYP0NhJJ07f6V`1nR9`0
OhZM0`22Rid01022S9h0PhfP08>>X@22T9l208>BW@0508BCW@24Til0Q9>R08FDX`27UZH00P28UZL0
302:UjT0S9N[08jI[02>VJd0SiZ]096L[@2BWZd0Tin^09BP[@2EX:/0Uj:Z09VTZP80VZFY00/0VjFX
09ZTYP2KYZL0VZJV09ZVY@2JZ:H0VJRW09RVYP2HYJD0UjBS09JTXP0209JUW`0;09FTVP2HZ9T0IVmZ
03@c>@0m@3d0>C/f03De;`0m?cH0Eem<05MNCP1<DDH00P0k?ST0301HHEH0HFaR08:CP@1PJF00FEmH
04A5A01;BdP0BdY907j7N@2AWh`0TJ2?092PS`80R9N700/0QYN40760L00N7b@08B8R01dL6@0L71D0
61P?01@C2`0C4P/07b8F02de9@0203Q3<@0;034l;00P9a`06b8H01XQ5P0?50`0H7IE06EkF00E6Q80
;SLZ01@F4P0O8AT00P0W:R401P0]<BL0=3L/03Pl;P0e>b`0=3X[02lf9`oooooo000=ooooo`0606Ed
R@1aPiT0MhVR07N9X`1hRJD0NHZU0P1fR:D02`1fR:@0M8NR07N8X`1kRZD0Nh^T07b<YP1mSZL0OhnX
082=YP23TJL0QY>Z0080Q96Z00X0PXjZ086>Z@21SjX0Q9:^08FC/@26U;40QiFb08ND/P29U[40S9Ra
0`2<Uk00302<U[40SiNa08nH/P2AVK@0TYVd09BL]02DWKH0TY^e09:K/`2CW[<0U:2b09FQ/P80Uj:b
00/0VZBf09RS^@2IY;X0VjFk09^U^P2JY;T0Vj>k09fV_P2NYkh0WJJn09jU_`0209nV`00;09jV`P2P
Yl<0WjS30:2V`P2OY/40XJNo0:>Z_P2T[;l0Xj^k0:BZ^P2TZ[/00P2SZ[d02`2TZ/00XZS109nV_`2O
Ykh0X:Vl0::[^`2RZkT0XZ^k0::Y_02QZ;d0XJNm0080XjRm00`0YJVn0:FY_`2VZ/<0YJW20:FZ`02T
ZL00XjS00:FY`02VZ/40YJS10:JY`@2VZKh20:FX_@0;0:BW_@2TZ;d0XjRl0:>Y_02TZK/0Y:Zn0:F[
_`2TZkl0Y:bn0:>Y_@2TZKd00P2UZKh02`2SZK`0XjVm0::X^P2SZKT0Y:^j0:>Z^P2QZKT0X:Vh09nW
]@2OY[D0X:Ng0080WZJf00`0WZNf09bU]@2JX[80VZBa09ZT/P2IXk40Uj>`09FQ/02EXK40UZ2a09JO
/@2DWJl209BN/00609JQ/P2BWjl0T9f]092MZ`2?VZP0S9NT0P2;Uj@00`2;V:@0RIRQ08RGW@0208VG
V`0:08NFVP24TiT0PY:G08:BUP22TID0PXnD086=T`21SIH0P8fG07j;U@<0O8ZD00H0O8VD07Z6T@1f
Ph`0MH>90761Q@1/OWdJooooo`06045:G`13C6D0ADiZ04M@K@18DVl0B55`0P19Dg802`19DW00B55^
04]DLP1<E7<0C5Ec04]EM01<EW<0CUQe04iIM@1@FGL0CeUg0080D5Yh00/0DE]i059LN@1BGGL0E5ii
05IQN`1GHWd0FF>305YTQ@1JI8<0G6N205iYP`02061[Q@0<065]QP1RKXP0Hfn;06=_S@1SKi00Hfj@
06=^T@1TL9<0IG:E06IbU@1XLiD0Ig>D0P1YM9D02`1[MYD0K7VD06aiU@1]NID0KWZC06mkU@1`O9L0
LWfG07AnUP1dOYP0MGjJ0080MGnJ00@0Mh:K07J1V`1ePIT0Mh>K0P1gPiT01@1hQ9/0NhJL07b7WP1m
RIl0OhVO0080PHZM00/0PhfO086<WP21SIl0PY2P08:@WP21T9d0PY6L08>BX024TZ80QYFV08JDZ002
08REZ@0<08VDZP2;UZ/0RYJZ08^G[02=VJd0Si^/096LZ`2BWZ`0TYj[09>OZP2DXJP0UZ>X0P2GXjH0
2`2HXZD0VZBW09VTYP2JYJH0VJFV09ZXZ02IYjT0UjFW09FSY@2EXj<0U:>Q0080UJBP00/0U:BK09RY
VP1[M6l0=cLn0412@@0j?3T0<S@a04E:@01BFD`0EEe?04mIC0020417?`0<05=ND@1SKf40Q9J0086@
O01lQGD0?S/n04Q5A`0m>400Mgmf09:OS`2;V8T0U:>A0P2=W8X02`29V8D0NHMg020O9P0N7B4071/J
01PH4`0E5@h051D=01HG3`0U:Q`09R`N008092/N00/08RPL01TO5P0F71@05Q`A018G300[=R<0>4D_
018H400L8QX051PC01<F400202D[7`0602lf9`0c>bX0=ch/03Hn:`0c>RT0;S<T3oooool000gooooo
00H0IGB90763V@1gRJ80MhVS07R9Y@1iRZD207J8Y@0;07J8Y01dQj80MhRS07^:Y@1kRj@0O8bV07f>
Y`1oSjP0P8fV08>AY`26TjX00P24TJX02P22SZX0PHjY086?ZP24TZh0QI>a08JD/@27UK80QiBb08VF
/@2<V;4308bG/00<08bF/@2?Uk40SiRb096I]02BVK@0U9bd09BM]P2BVkD0TY^c09>N/`2DX;80UJ6b
0P2GX[802`2JY;H0V:>i09VT^P2KYK/0VjFj09ZT^@2KXk/0WJJn09jW_P2MY[h0WZFo0080WjK000/0
WZK20:2W``2OZ<<0X:K209nV`@2QYkl0XjZn0:B/_`2SZk/0Y:Zj0:BZ^`020:>Z_@0;0:BZ`02RZ<40
WjJo09nW_P2PZK`0XZ^k0::[^@2RZk/0XZVl0:6X_@2QYkd00P2SZ;d0302UZKh0YJVo0:JZ``2UZL80
YJ[00:BY`02SZ<00YJW00:JZ`@2UZ<40YZW10:JY_P80YJRm00/0Y:Nm0:BX_@2SZ;`0XjVl0:BY^`2T
Z[h0YJ^o0:B[_`2T[;h0XjVm0:BY_@020:FY_P0;0:>Y_02SZKd0XZRj0:>Y^@2TZkX0XjZj0:6Y^@2P
ZKP0WjNe09nV]@2PYkL00P2NY[H0302NYkH0W:Fe09ZR/P2JY;40VZBb09VS/@2GXk00UJ6`09FQ/@2F
X;40UYna09BM[`80U9j`00H0UZ6b09:O[`2@WJd0T9f[08nJZ02<Uj@208^GY00308^HY029V:40R9NM
0080RINK00X0QiJJ08BCV@22TYL0PY:F08:AU@22Si@0PHfC086=UP20SIL0OX^E0`1lRY@01P1lRI@0
NXJA07J3S01ePhT0LH6506anOA[ooooo00H0@DYO04=<I@15CVX0Ae1]04QBK`18DG0204UCLP0;04UB
L018DFh0BeAb04aDL`1<EG<0BeEd04aFL`1>F7D0CUUe051IM`1?FGL00P1@FWP02`1AFgT0DUai059M
M`1DGWT0EV5k05MRO@1IHh<0FVB505YTP`1LIh80GVV30080H6^500`0HFf6069^R01SKh/0Hfn=06=_
T01SKY00HfjA06A`T`1ULYD0IW:E06QcU@1WLi@206UdU@0;06]fU@1/NI@0K7VE06eiU@1^NY<0Kg^E
071lU`1bOIL0M7jF07AnV01eOYX00P1eOiX0101gPY/0MX6K07F1V@1gPi/207N3V@0507R4V`1kQY`0
O8NN07f9W`1oRIl00P21RYd02`23SIl0PHbN086=W`22T:00PY2N086@W@22TI`0Pi:P08BBXP26UJH0
QYBX0080R9FY00`0RIBZ08^FZ`2:UZX0RiN/08fI[@2?Vj`0TIb[09:N[02BWZ/0TinZ09BQZ02FXjP2
09NSYP0;09RRY@2JY:L0VJBV09ZUYP2IYJH0VZRX09VWZ@2GYJL0UJ>U09FSX`2DXj400P2EY:002`2D
Y9/0V:VJ06]dK`0g=ch0@49103Xl>@0b=340ADY0059IC01EGDl0CeU<0080@4Lo00`0DeiA06=_H@24
UX00PI1l07b5M@0n>ch0B4E703dh@01gOgH0TYn?08^HR@2DXi4208fLRP0;08VHQ@1iQgL081lV01hM
8@0L6aX061PC01DE3P0D5@d05QL?02DZ700V;1h00P0T:ah02`0R:1`06AlF01HL500F71404QL<02/f
8`0hABl04QP@01`R6P0D61<04aH@00809B/O00H0;cHW03<k:P0g?R`0=Sh[03<j:@0^<b@?ooooo`00
3Oooool01P1SLXT0Kh:J07B9X`1fRZL0MXVW07N9YP80MXNU00/0MHFT07B5Y01fQjD0NHVU07Z9Y@1k
RjD0OHfV08:@Z023T:L0Q96W08NDZ`0208FAZP80Pi2Y00T0PY2X08:?Z`25TK00QY6b08NB/`27TK80
Qi:a08ZE]02:U;800P2<U[40302>U[<0T9Fd092F]02AUkD0TYVg09:J]@2AV[D0T9Ze096K]@2BWKD0
TYfd09>Q]080Tj6c00/0UZ>f09FQ^02FX[/0Uj>m09RR^`2JY;/0W:Bl09fT_P2LY<00VjBn09bT_P02
09fV_`0909jV`@2MY/40WJG109jV`P2OY/80WjK00:6W_P2SZKh0XZZm0080XjRk0P2QYk`02`2RZ;h0
XjS20:6V`P2PY/40XJRo0:6Y_`2QZKh0XJRm0:6W_P2PYkh0X:Jn0080Y:W000`0Y:Vo0:FY_`2TZ<40
Y:O10:>W`P2TZ<<0XjK20:BW``2VZLD0Y:O40:BXa02TYl<20:>W`P050:BY``2TZL80XZO10:2W`02Q
ZL000P2RZ/00102RZl40Xj_00:6X_@2QZK`20::X_0050:6X^`2QY[`0XJNk0::X^`2RZK/00P2RYkX0
102RZ;/0X:Jh09nT]`2OYKL209nT]`0<09jU]`2LYKH0VJ:c09VR/P2KXk<0VZ:b09RQ/@2FX:l0UZ6_
09JO/02FWk40UYn`0P2EWZh01P2CWJd0TIb/08nL[02?W:/0SYbZ08fHY`80RiNT00<0RYJR08ZEX@2:
UJ000P29U9l02`27TYd0QI6M08>BW@24Ti`0Pi:I08:@U`21SYH0OhbH07j<V@1lRIH0NXND0080NXNC
00H0N8FB07N4S`1dPh`0Lh:90762Q01]OgdJooooo`06045:G@14CF80ATmY04UBKP18DVl0B51`0P1:
Dg<01P1;E7@0BE5a04YCLP1;Dg<0Be9b04]DM0<0CEIe00l0CUQf04iHM`1?FGL0CeUg051KM`1BGWT0
DEeh05=NNP1EHGd0EV6005QSP`1HI8D0FVB405aVP`1OJH@00P1PJH@0301PJX@0HFb7069^R@1RKH/0
HVf=069_S`1SKi00HVn@06=aT@1ULi80IW>B06IbTP80JGBD00/0JgJD06YeU01[MY@0KGVC06ijT@1`
NY80LG^D079kT`1cOI<0M7jE07InU`0207MoV00407N1V@1fPIX0M82J07N2V`80N8>J00D0N8:I07V3
VP1lQY`0OhNN0868W`0208>:W`0;08F=W`22S9l0PHbO08>>X024TJ40QI>R08FBX@25TJ80Qi:S08RD
Y@29UZH00P29UZL03029UZP0RiNZ08^FZP2;Uj/0SYV]08nK[@2@Vj/0TIf/09:N[02BWZX0Tj6Y09FQ
Z@80Uj:V00T0Uj6U09RRY`2HXjL0VJBW09RTYP2IYZH0VJNX09NTYP2FY:<00P2FY:8209JUX@0;09JU
W@2HZ9`0Lgef03`m@P11AD@0>Shm03<g=@0i?ST0ATi205=NC015CD800P0b=S@0301@F540HfeS08JE
P@2=WHL0VZZA04]:BP0m>3h0=C0j06edK`2@X900QiB708nOSP80T:6=00/0RYb707V9M`0O7b@06APK
01LF5P0C4Pl04A0:014A200D5@X082DG024W600201lS5`0;01hQ5P0I7Q<05a`C01@J4@0B5`h04QH?
014E400C61805ATC018F4@0@50h00P0P9aX01P0]=R@0<CXW03@n:P0c?BP0<c`V02lg8`oooooo000=
ooooo`0606MgR`1`PYX0LXJR07F8Z01eR:X0LhJY0`1aPjH02P1dQZL0MhVX07R:Y@1iRZD0Nh^T07b<
Y@1nRjD0PHjW08>@Z@25TJ/208:>ZP0;086>Z@23SjT0Q96Z08BAZP27U:d0Qi:]08R@[`28T;00Qi6`
08VC/02<UK400P2>Uk40302@Uk<0TINf092F]P2@UKH0TINh092H]P2?V;D0T9Vf096K]P2AWKL0T9bg
09:N]@80TYjc00/0TYfc09:N]@2FXKT0UZ:l09FO^P2IX[`0Vj>l09^R_02IX;h0VjC009ZT`00209ZU
`@0709bV`02MY[l0WJJn09fV_P2MYKh0WZJn09nV_@020:6W_00?0:6V_02QYk`0XJNl0:6W_02PY[`0
XJJm0::W_`2QY[l0XZJo0:6V_`2OYKh0WjJn09nT_P2OYL00WjG10080XZW200`0XZS00::W_`2RZ;l0
XZNo0::W`02SZ<<0YJW60:FXa@2TZ<@0XjS20:>W`@2SZ<820:>W`@0;0:>W`P2TZ<80XZO10:6W`P2O
Yl80XJW20:6Y`02RZ[l0XZVn0:6X_@2QZ;/00P2RZK/02P2QZ;/0XJNl0:>Y_@2SZ[h0XZRl0:2U^@2O
YKT0WjJi09nU]`2NXk@309fT]@0<09fS]@2JX[@0VJ6d09ZQ/`2JX[80V:6a09JP/@2EWZl0UYf]09NN
[P2FWZl0UYna0P2FW[002`2DWJd0TY^/092KZ`2>V:X0SYVY08nKZP2>VJL0SIVV08bHY@29UJ80RYFS
0080RIBR00/0Qi6O08F@W`24TIh0Pi6K08BBVP23T9T0PhjJ086;W01nRYh0NXJK07N5UP0207N6U@06
07N7T`1fQY00MHJ=07>5R@1aPh<0Kh9m6_ooool01P10BE/0@deR04I@J@18DFh0Ae5^04QAK`80BE9b
00/0BeAd04YCLP19DW80BeAc04YBLP1;Dg80C5Ed04eFM@1=EgH0C5Mf04aHM`0204iIM`0;051MN@1C
GWX0DUej05=NO01EH7l0F6:305QRQ@1HHh<0FF>105YUPP1NJ8<00P1PJHD02@1QJHH0H6^806=]RP1R
KH/0H6b;061]R`1QKX`0Hg6?06AbT@0206MdTP0>06McTP1ZMI<0JWFC06]eTP1]Mi@0KGNC06miT@1_
NY40L7Z@075kT01bO940M7nC07AoU01fOiH307N1V@0607N2V`1fPIX0MX6H07N3U`1iPiL0NhBH0P1l
Q9P02`1nQYX0PHVL08B;WP24Rih0QHbP08><W`23S:00PXbQ08:<X024Sj40QY6S0080Qi:T0100Qi:S
08RDX`28UJ<0R9FS08NEX`29UjL0RYVX08bIZ`2>VJd0SiZ^08nK[02@WJ`0TYjZ09>NZ@2EWjX0Uj6[
0P2FXJP02`2GXZT0Uj6X09NSY`2HY:P0V:FX09VVY`2GYJD0UZBT09RUY02HXj<0Uj>R0080V:BQ00/0
UjBM09RWW01kQWl0>CQ10453A@0m@3l0=cTj03<f=`0m@Sd0DUe>04]DB00203Pk>00<051FC`1TJf80
Q920092PS@2T^9l0HfYS03Tg?@0j>Cl0I6eU096SS`26UH@0Rib90P2<X8/02P28WHL0Nhil028U:P0C
51T061TI01HF4`0D4`h04a8;018C2P0G6@h301XO4P0;01/P4`0I7A405aXA01@H4@0B61804QHC00lB
4`0B5AD051PF01<G500B5Pl00P0O9QP01P0Z<al0;cLU038l:@0a?BT0<SdW030j8`oooooo000=oooo
o`0606EeR@1_PIP0L8BO07:7Y01bQZH0LH>V0P1^PJ@02`1`Q:L0LHBU07:5Y@1cQZD0MHNU07J7Y01k
RZH0NhRV07j;Z020SZT0PXnZ0080PXjY0P22T:T02@23TJX0Q9:[08FCZP25TZP0QY:Z08JA[027Tjd0
R9:^08ZD[P0208ZD[@0<08^D[`2=UK80SiNe08jG]P2>UkL0SYRf08jH/`2?VK80SYRb08nJ]P2@VkL0
T9^d0P2@W;<02`2@Vk80TYbd09BO]`2EX;P0UYnh09FM^02FW[/0UYnk09FO^`2GXKh0VJC00080Uj>o
00/0UJ:n09NS_@2GX[/0Uj>k09VT_02KYKd0W:Fk09bT^@2LXkP0W:>i09jU^P0209fT^P80WZBj00T0
WZBk09jR^`2NY;d0WjJm09fU^P2MYK/0WZJm09jU_`2OYl800P2OZ<<0302PZ<40WjS009jW_P2NYkh0
WjNo0:2W`02QYl40X:G00:2V_P2PYkd0X:No09nU_`80WZ>l00/0X:Fn0:6V`02PY/40XJS009nW_`2O
Z;l0WJJm09fV_02OZ;`0X:Rl09fV^P0209bV^@0;09fU^P2MYKT0WjNl0:2X_@2OYk/0WZFj09bS^02K
XkH0WJFf09bS]02KXk<00P2LYKH0302KXkL0V:2f09NO]02GX;<0Uj2`09JP[@2DWZ`0UIj]09BL[@2E
W:h0Ti^]096J[080TIZ]00@0SiV^092K[@2>VZ/0S9RX0P2;UZH01@2:UJD0RiFU08ZEY@28Tj<0Qi:R
0080QY2Q00/0PXfN08:=W@22SY`0P8jJ07j>U`1oSIL0P8fG082;V@1oRi`0NhNJ07N7U`0207J8U@06
07B5T@1bPhd0LH>90723Q01]PGl0K81j6_ooool01P0nB5h0@4aR04=?J015CfX0Ae1/04M@K`80B55`
0P18DW402@19Dg80BUAc04]DM01:Dg<0C5Ee04]DM@1<EGH0C5If04aHM`0204iJN00;04iKN@1@FgT0
DEaj059MO01DGgh0Ef:105QSPP1HI880F6>105UTP@1LIh<00P1OJH@0301OJHH0H6^905mZR@1PK8T0
H6b8061]R`1QKh`0Hg6>06=`T01VLi80J7BA06IcTP80IW:A00H0JGFA06YfT@1[Mhl0KGR?06mhS`1`
NY82075kT`03079mU01cOYH0LgfF0080MGnJ00/0MH6L07F0V`1fPIT0Mh>H07N3UP1gPYD0NXBE07^5
UP1kQIL0O8JJ07n9W002082:W@0;08>;W`22RYl0PhfQ08>>X@22SIl0Q8fO08F?X@25T:80Qi6T08NC
Y029U:<00P29UJ<03027U:80R9JT08ZIY`2;VJX0S9R/08jJ[P2>VZ/0Si^[09:MZP2EWZX0UYn[09NP
Z`80UJ2Y00/0UZ>Z09JSZ02GY:H0UZ>V09NUYP2HYjH0UZFT09JTX`2IYJ<0V:>Q09JQW`0209NRW@0;
09JQVP2IYYX0N81k03Pc?`10?T@0@D9404=6A@0n@3l0>cll05AODP1BG4l00P19CdL0301=DTX0HV]O
08>BP02;VhT0V:^E07b8NP10@DD0?3e306=]I`2J[iT0QiZ808VMR`80R9f;00/0RYj;086DP`0X;3<0
51DM01TL7P0I6QT05QLB01<C3@0A4@/051H>01PL4P0201PM4P0;01/O4`0N8QD07AlF01`M5`0K7AX0
6QdN01XK8@0I6B4061XO01DG600@50h00P0P:1T01P0[=200<CTU03<l:@0c?BX0<S`Z038j9`oooooo
000=ooooo`0606MeS01ZNiH0KH6O06f4XP1_Q:@0LhJW0P1bQJL02`1aQJL0KX>U0724YP1cR:P0M8RV
07J9YP1iRjL0NXZV07f<YP1nSJL0OhfW0080OXbV0P1nSJH02@1oSjP0P92Y082@Z021TJP0PI6W08JC
ZP27TZd0R9>_08RD/00308RD[P0;08^E/02=Uk<0SIRf08^E]@2=V;H0SIZe08jJ/`2=VK80S9Rf08bG
]P2;UkD00P2<VK802`2=Vk80T9bc09>M]02CWKH0UIjh09>L^02AV[T0Ti^i09>L^02CWKP0Tijj0080
Tj2k00/0TJ2k09>Q_02EXK/0U9jj09FP_02EWk`0UZ2j09VR^P2KXkX0Vj>k09^T^`0209ZT^`80VZ>i
00P0VZ>h09ZR^02KXkX0W:Fk09bV^@2LYKT0W:Jl09fU_`<0WJG000`0WZO209jV`P2NY/40WZK009fU
_P2MYKl0WJBn09fU_02LYK`0W:Fj09bV_02LY[d209^T^`0;09^S^`2MY;d0WJBn09fU_`2LYKl0W:Fn
09ZU_02KYKX0W:Nh09nY^@2NZKT00P2MZ;T02`2LYKP0W:Bg09bT^@2MYKT0WJJi09fU^@2KXkL0VZ6e
09VQ]P2KXkL0VZBh0080VZFh00`0VJ>h09NP]@2EW[@0UYjd09FO/P2EWk00Tij^09:M[@2BW:`0T9Z/
08nJ[02=VJT208jJZP0;08jIZP2@VZd0SYV]08fHZ`2;UjT0RiFW08RBY029TZD0RI>U08JBX`25TJ80
0P24TJ801020SIh0P8fO082>X@20Sj0207b=W00507f=W01mS9X0O8^H07V6UP1fQIH00P1gR9L01P1d
QI<0LH:>0723R@1_Ph<0KX:006]oNA[ooooo00H0?TQO041<I@12CVP0A4mX04A>J@15Cf`204I?KP0;
04IAK`17DG00BE5a04QAL019DW80BU=c04YBL`1;Dg@0CEMg04eHM`1=FGL00P1>FWP0201=FGP0CUUi
051JN@1BG7d0Def005IOP@1HHX80Ef>20P1GHh403`1JIX<0G6N405aWQ01MJHD0Gf^905mZR`1OJXX0
GVZ9061]RP1QKXX0HFj;069]S01SKhh0IG6>06EaT00206A`T00906UdTP1YMI40JWJ?06afSP1^Mhl0
KgZB06mjU@1^NIH0KWZE0080LWjH0P1dOi/02@1eP9d0MH6K07F0V@1fPIL0Mh>G07R2U`1iPiP0NX>H
07^5V`0207b8WP80OHVO0P1oRj002@21SJ00PHbN082<WP21S9h0PhbN08F?X025Sj40QY6S08NBX`02
08FBXP0<08FCX`26UJD0R9JU08VHYP2;VJT0SiZ[096K[02AVZ/0Tib/09FM[@2GWjd0UinZ0P2EX:P0
2P2EXZP0U::V09>RX`2CXj80U:BR09JTX`2EY:<0UJBR09NUX`2GY:8309JRX00;09FQW02IYi`0KG=`
03D^>P0m>400@D1504Y>C@11AT@0>Cdj055LC`1@FTh00P1AFDh0301;CdP0G6=J08BBP02:VHD0Ri^4
08VHPP15ADL0<2dh06A^J`2J/9d0QYV:08^MS080QYN700/0RY^8082AO`0T92`06QTP01dN7P0I6AL0
5ADB018B3P0C4Pd061XB01`N500201`M5@0;02/a8P0X;Al082<G02LW800W9BD0@TE4038d>@0W9bd0
9RPY01PI6@0C50l00P0T:QX01P0Z<Qh0;SHS038j9@0c>bL0<cdX030i90oooooo000=ooooo`0606Md
T01/O9`0KX:T06n5YP1`PjD0LXBW0P1dQZX0101cQJX0LHJZ07:7Z@1dRJH207N:Y`0507V:Y`1kS:P0
O8fX07j?Z01oSjL00P21SjL02`1oSJL0OXbW07n>Z@21Sj/0PI6[086BZ`21T:T0QI:/08JB[`26TK00
Qi:_00<0RIJ_00/0RiJ_08^F/@2=U[D0S9Jh08ZE]`2:U[L0S9Rf08jI^02>VkX0S9Vi08^H]P0208^I
/`0;08jL]02@Vk<0Tibe09>L]P2FW[P0UIbh09BL^02EVkT0UIbi09>K]`2DW[X00P2EXK/02`2DX;/0
U9nk09RR_P2IX[h0V:2m09NP^`2IX;/0V9nk09VO_02LX/00WJC00080W:Bn00/0VjBm09bU_02LY[/0
Vj>i09^S^02LYK/0WJNl09^T^02LYKX0WZFo09jU`P0209jV`P0:09nW``2PYl<0X:K209nU`P2NYL80
WZK209jW`@2NYl00WJNn09^V_@80VZJo0P2KY[l02`2KYK`0WJBl09bS_@2JX[h0VjFo09^V_`2LY[d0
WJNl09jX^`2MZ;P0WjZg0080X:Zg00/0WjRg09nX^02NYkX0WjNk09nW_02NY[/0WJFi09fS^02LX[P0
W:Bj09fU^P0209bV^@0<09^S]`2HXKH0VJ6f09RQ]P2GWkD0UIjd09BM]@2CW[D0TYbc092L/@2@WK00
T9f]0P2AW:h02`2AVZd0T9V]08jH[P2=Uj`0RiFZ08^FZ`2;UZX0S9NY08^GZ027UJD0QYBT0080QI>U
00/0Pi2S08:?Y022T:L0PY2V07j>XP1kRj40Nh^O07^<W01jRiT0N8NH07N5VP0207R7V`0607F5UP1e
QY80M8J=07:5Q`1`Q840KH9j6_ooool01P10BF40@D]U049=J@13CV`0@diZ04A>J`80A4e[00D0A4e/
04M@KP17D6l0ATm^04M?KP0204UAL@0404YCLP1;Dg80C5Ed04aFM@80CEMe00/0CUQg04mHN01@FGP0
DEYk055JO@1DGH00Ef2105IRP@1HHgl0Ef=n05UUP00205YUP00;05]VPP1LIXH0GVR805mZR@1OJHT0
Gf^9065/R@1RKXX0Hfn;06A_S01TL8h00`1TKhh02`1WLHl0J7:>06YdS`1/MHl0KGJ?06miT@1^NY<0
Kg^D06mlU@1aOID0LWbF0080M7jI00/0M7jK07AnW01dOi/0M7nH07N1U`1iPYT0NX>I07V3V@1jPi/0
NhJN07b7W`0207b9X@0;07j:XP1oRj80OhbP07n;WP1oSIh0P8bN08:<WP24SYl0QHnQ08J@XP26TJ80
0P25TZ403026Tj<0QiFU08NEY@28UZH0RYJV08fHZP2@VJ`0TIZZ09:KZP2DW:/0UIf[09JNZ080UIjW
00<0UJ2X09>QY@2CXJ<00P2DXj<01P2EXj80U:>R09>RX@2EXZ80UJ:Q09NRXP80UZ:Q00/0U:2M09RV
W@1bNGH0;BHd04A1A`14@dT0A4M;03Xn@P0g?3`0C5M=04eIC@02051JD00<04=7A01[MFP0T:6;07R4
M@27UX40Pi9m0451@`0Y9380HVUW09R/VP2:Vh/0SIj<0P29UhD01P2<VhL0SIj602TW:`0N6a`071/G
01LF4@8051@>00<05AD>01/M4`0O8QP00P0I6A@02`10BCL0>T8d02hb:P1HHE80?3lm05URF`0n@TD0
:BX_02T[:P0D51@06A`D0080:2dM00H0:BlL02/b7`0_=R@0<STV03<l9`0^>BD?ooooo`003Oooool0
101XLi40Lh6Q07B4Y`1cQ:L207:2YP80MHBZ00/0M8>Z07B5ZP1cQZP0MHNV07R8Z01iR:P0NXVX07b<
Z01nSJL0OhfV086>YP0208:=Y`0;08B?ZP24SZ`0Phj^08>?/022S[00Pi2a08FA/@25T[40QI6a08R@
/029T[000P29Tk00302;UK00SYRc08fG/`2<UkH0SYNj08bF^02:U;D0RY>d08fF]`2?VKT0SYVi08fI
]`80SYVd00/0TIbc09:L/`2CVk<0UIbd09JM]02FW;80UYfc09NM]@2IW[H0UYbf09JL]`0209RP^@0;
09VP^P2GW[X0VIjk09ZP_02IX;X0VJ2i09ZO^@2LX;/0Vijm09bO_@2MX;h00`2LXKl02P2LX[l0WZBm
09fS^@2KXKL0WJBh09nV^`2NY;T0Wj>i0:2T^`2PXkh209nS`00:09nU`@2QY/40XJG00:6U`02OXl00
WjC109jT`@2MXl00WJBn09bS_P80WJG00P2MY[h02`2OY[/0X:Bi09jS^@2MX[/0W::l09^Q_02LY;`0
WjJn09nU_@2NYKX0WZBg0080WZ>f00/0Wj>f0:2U]`2NYKL0WjFi09jT^P2MXkT0WJ>h09bQ]@2LX;<0
Vinc09^P]@0209fR]P0409^P]02IX;<0Uijb09NN/P80V9jb00H0Uibc09FL]02CVk<0TY^`09:J[`2C
Vjh209>J[`0;092F[02?UJ/0SYBY08jEZ@2<U:T0Ri>Y08V@Y@29Tj@0R9:Q08JAW`25TJ000P24T:40
2`23SZ80PhfR08>=YP20RjD0NhRQ07^9X01kRYh0NHNJ07R6V01fPiH0MX:F0080MX>F00H0MH6C07F2
T01dPXd0LX:906n0P@1ZO7PJooooo`060458G`10B680@T]X049;J`12C6/0@D][0P12C6/204A=K080
ADi^00L0Adm^04I?KP18D6h0BE9]04UBK`1:Dg40C5Ac0080C5Ab00/0CEEd04iFM`1@F7L0CeYg051K
N01CGG/0E5mm05EQO@1EHG/0Ef9j05QSO00205UTO@0<05UTP01KIX<0GVV5061YQ@1QJHL0H6Z7069/
R01RK8T0HVf9065]R`1SKhh0I72>0P1ULXl02`1WLXl0J7>?06YdS`1ZM8h0JgF>06egSP1^N8l0KWV@
071jTP1`O9@0L7bF0080LGbG00/0LWfH079lV01cOIX0M82I07IoV@1hPIP0NH:G07R2U`1iPYP0NH>I
07^6V`0207f9WP0;07j:W`1nRZ00OX^N07f:W@1oS9d0P8fN086=W`22SZ40PhjP08F@X026TZ000P27
TZ80302:UJ@0RYFU08VCY02:U:D0RiFV08jGZP2?UZX0T9VY09>LZ@2CW:P0U9fX09JOZ080UZ2W00@0
UZ6W09FRY@2FXjD0UZ>T0P2FXZ<01@2EXZ<0UJ6S09FQX`2EXJ<0UZ6R0080UJ6O00/0UJ6K09JTW01o
R8@0:bPe06M_J@1<CU40BTe>03i2A@0`<cP0CeQB04mHD@0204mGDP0<03e1@P1VLVH0W[JI079oL@25
UH40MX=d03/k@@0a;c/0Ff5R086AQP26UXP0SYj;0P29Uh802`27UWl0SIj302l^;00O71X07adF01/K
400H6@h05aP=01LI3P0K7A406alD00805ATB00/08RLO04eHA`1JIUH0KWeZ06A]H`1^NFd0G6EM04Q>
B00f?3L06a`L024S7@0202HZ7`0602T_800]<R<0;c@U03<i9`0e?BT0<3TV3oooool000gooooo00H0
I6f:06YgUP1`Oj40KgnS07:1Y@1bPJH207:0Y@0;07F4Z01fQJP0MXNX07J6Z01hQjP0NXVW07^:YP1k
RjD0OHfU07j;Y@21SZL00P20S:L01022SJT0Q8f]08:=[`21S[42086>/P05086?/022TK00Pi:`08FB
[`27T[000P29T[401P2:Tk80RYBc08ZD]02;U[H0SIJg08fF]P80RiJf00@0SYVg08nJ]@2=U[80S9Ja
0P2>Uk802`2@V[<0TI^d096K/`2BW;80TIZa09>K/@2FW[80UYbc09JK]02FVkD0UYbf00<0Uifg00X0
Uijh09ZP^`2JXKd0VZ2j09ZQ^P2KX;T0W:2k09bP_P2LXKh0VZ2m0P2JXK`0102JXKd0Vj:m09ZP^@2K
X[P209bT^00509fS]P2OY;L0WjBh09nR^02MX;P00P2LX;P01P2NX[/0X:Fm0:2T_@2PY;l0Wj;009nR
`@80Wj?100@0Wj>o09jS_@2OY;h0WZFl0P2OYKP01@2PY[P0WZ>f09bQ]P2NX[T0WZFl0080Vj:k00@0
WJ>k09nS^`2NX[T0WInf0P2NXKP01@2NX;L0Wj6g09nR]`2NX[L0Vj:f0080VJ2f00@0Vj6f09RN/P2I
X;80VInd0P2HWkD0302GWk@0UYjd09JN/`2GWk40Uij^09NL[@2GW;00UI^a09:J/02AVJl0SiJ/092G
[080TYV^00/0T9FZ08fCZ02=U:P0Ri6V08^BYP2:TJH0QhnS08NAXP26TYl0QI2K08FAW@0208:=W00;
08:=W@22SIl0PX^P0828XP1mR:80O8NO07f:W@1kR9X0NXFH07N2U@1dP9400P1ePI<01P1fPY@0M82A
071nS@1^OXT0KGj106QkMa[ooooo00H0@DQN049;H`13C6L0@T]Y049:J`12BV`204A=K`0604A=KP14
C6d0ADi^04I?K017Cf`0B55]0P17D6/00`19DVd0BE9_04aEL`0204eFM@0;04eFMP1>EWP0D5Qk04mI
N@1@G7T0DUej05EPO@1EGg/0EEmj05QRN`1HHg/00P1IHgd0101KI800FfF105eUPP1OIh<2065XQ@06
069ZQ01QJX@0HF^5069/Q`1TKXX0I6n<0P1ULHd02`1ULXd0IW><06QdS01YMH`0JGF906afR`1^N8d0
KgV@071iTP1aNi@0LG^F00<0L7bG00X0LGbH079lV@1dOiX0MH2I07J1V01eP9H0NH:G07^2V01kPiT0
O8FJ0P1mR9`207n:W@0907j:W01nRYd0Oh^N086<WP22SJ00PhnR08B?X025T:00Qi:R0080RI>S00`0
RIBR08RCX@29U:80RIBR08bFYP2>UZT0SYJZ092JZP2BW:P0TYbV09BMYP2FX:L209JQYP0409FQY@2F
XJH0UZ:U09JRY@80V:>V00D0Uj>V09NRY@2GXZ<0UZ:R09JRX@0209FQW@0;09BPV@2FY9T0QY6902l/
>01@E5@0CE5@04mED@0n@d80;Bld051ID`1>EU800P1>EU003015BdP0D5UC09B/T@24V880RIj607R8
N01FGE`0@45;05mVJ`1VKW40QIB:08nPSP80RY^400/0QYAk07j>LP0Z:RD06aPE01hL5@0I6@l061T>
01PJ3P0H6`d06Qd?01`O4P0201`O5@0;018B3@1:DT40NhYa06mjJ@1cOg00MX=e071oK`1XMfH0@4Lo
02@V900Z;BH00P0[;b<01P0[<B80;C<S02ld900`=RH0=3XX034g9`oooooo000=ooooo`0606=^RP1/
NIH0LH2P07>2Y@1cPJD0LH2T0P1bPJ@02`1eQ:L0N8NY07V9Z`1hRJX0MXRW07N9Y01iRZ<0NX^R07f=
Y01oS:H0P8bY0080OhZY00/0OhZ[086;[022SJd0PHf^086?/020SZl0Ohj/07n@Z`20TJ/0Pi:[08BA
Z`0208FA[P0;08NB/@28U;80RIFb08ZE/@2:Tjh0S9Fb08fG]@2>VKH0SIVf08jJ/`2=VK400`2=Uk40
202?V;80SiVb08jI/@2>V[40SYRa096J/P2DW;@0UIbf0P2DVkL03P2EVkL0Uibi09NL^@2GW;T0UYZh
09NL^P2IWk/0VJ2j09VQ^@2JX;L0VYng09ZP^P2JXK`0VJ6k0P2GWkP02`2GX;L0VZ:g09RQ]02IXk@0
V:>c09RS/P2HX;00Vj:b09fS]P2NY;L0WZ>g0080WZ>f00`0WjBg09nS^@2PY;/0X:>l0:2S_`2NXkl0
WjC009jR`02MXKh0WJ:n09fS_02JX[L209^R]00;09^S]@2LX[D0W::f09^Q]P2KX[/0Vj>k09bS^P2K
X;L0W:6e09fQ]P2LWkH00P2LW[H02`2MX;H0W9ne09fQ]P2MXkL0Vj:g09RN]02FW;<0UYjd09NO/P2G
Wk40Uijc0080UYne00`0UIfe09>K/`2CW;80U9fb09BM/02CVjh0Ti^_096I/02?Ujh0SYN/08bEZ@2=
UZT208nFZ@0;08fDY`2<TZ@0RY2T08R@X`26Sj40Qi2R08J?X@25Sj40Q96Q08>AW@20SiX00P1oSYT0
2`20SY/0P8fM082;WP20RZ00OHRO07b8WP1lR9d0NXJH07V3U01hPY<0MH2A0080LgnB00H0Lh6E071o
T@1^OX`0K7f506YlO`1WNWLJooooo`0604=9HP14BVH0@dYY049:JP12BFX0@dU[0P13BFd01@14Bf`0
A4Y[04A;JP15CVX0AdmZ0080ATeY00@0B51Z04UBK01:Dfh0C5=`0P1=E7@02`1<E7@0BeAe04mGN@1@
FG/0D5]m055KO01CGGd0E5im05ANO01FHGd0F69l0080FV=l00`0G6=n05eTP01NI840GVB1061XPP1Q
JX@0HFZ3061ZP@1RJh80I6f506I^Q`1VL8T206A`R`0;06EbS01ULXX0IW>:06MeR01XM8H0JWF706]e
R@1]MX`0KgR>06mjT01`NY400P1aNi802`1`O9@0LWbE07=lU`1dOYP0MGnG07AoU@1dOi@0Mh6D07Z2
UP1lPiP0O8BI0080OHFI00/0OHJI07j8V`1oRY`0OXNL082:W`22RZ00PX^P08B<X024SYl0QhnO08N@
W`0208NBX00<08RBX028TZ40R9>S08ZDY@2;UJH0S9FW08jFZ02?VJT0TIVX09>KY@2FWZ@0UIjR0P2E
Wj40202EWZ40U9jR09FQY@2EXJD0Uj>V09RRY@2GXZD0UJ6T0P2FXj803P2EXZ00Tj2M09>PW@2CX9X0
TZ6G08bKSP0j>D00@TA605]SG019DD`0>Sll02HY:P1=Edd0CEE=0P1>ETh0301<DTT0GfUK096VR`1f
QWH0Oi1o08:CP`1kRG`0G61Q04a;E@1_M7D0O8B008fKS@80RYZ600/0QYEn07f>M00X:BH071/I01`L
5`0G6A005aT>01LK3`0E6P`061/<02HZ5`0202X/7P0;01LD400o@CL0Ohme06egJ@1bOW00M8=d0721
L01YNVH0?4Dl01`O700[<2L00P0/<RL01P0/<bD0;3@T02de9@0^=bL0<3PY02lg:@oooooo000=oooo
o`06065]R01ZMi@0LGfN079nX`1aOZ<0LGnS0P1dPJ802`1gQJ@0N8NW07V6Z@1hQjT0MhVV07F8Y01g
RJD0N8RS07^;X`1oS:H0Oh^Y0080Oh^[00/0OX^Z07n:Y`21SZL0Pi2Z08>@Z`21Sj`0P8n/07n@Z@20
T:P0PY2V08>@Z00208B@[00<08F@/027Tk80RiJa08^E[P2=UJh0SiJa08nG]@2?V;P0SYNg08jH]P2<
U[40SYN`0P2>UJh02`2?UZl0T9N`08nG[`2>V:l0SYN_096H/02BVK<0TiVe09>H]`2BVKT0TiZi0080
UIbh00/0UIZg09BI^02FVkT0UYbh09JN]`2FW[@0V:2d09ZP]@2JWkH0VJ2i09VQ^P0209NO]P0609JN
/`2HX;40VJ2`09ZP/@2HX;40V:6b0P2HXK400`2IXK80Vj>f09fT^@0209bS]P0<09bS/`2LX[80WJ:c
09nR]@2OXkP0WZ>i09jT^P2MX[X0Vini09ZO^@2JX;X0Uijg0P2HX;H02`2JXKH0VZ:f09bR^02LXKT0
VIni09ZQ^@2JX[P0VZ6d09ZP/`2MXK@0WJ6f0080W9ne00/0VYfc09RM/@2IWK40WJ6c09^P/P2HWK80
UI^c09JM/`2EWZl0UIb]09FK[`0209>J/@0<09BL/`2CW;80TYba09:K[`2AVJh0T9R^08nG[`2<UZh0
RY>X08ZDY@2;UJ<0SIJT0`2<U:<02P2;TZ80RI2Q08VAX027T9l0R92O08V@X027Sj40Q8nQ082=W@1o
SIT207f;U`0;07n=V@1oRiX0P8ZM0828WP1nQih0O8JP07Z5WP1iQ9T0N8:D07R0U01gOiH00P1dOIH0
1P1bOYH0KWfA06anR`1[O8<0JGam06QlMa[ooooo00H0@dIO04E8I@15BFT0A4UZ04E:K015BF`204A8
J`0;04A9J`14BVT0A4YX04E<J015C6T0ATeZ04E=J`16CVd0BE9^04]DK`1<Dfh00P1<Dfl02`1<EG00
BeAa04aCL`1?EWL0D5Yk055KO01CG7d0E5in05IPO@1FHG`0Ef9k0080FF9j00`0Ff9k05eSO@1OI7l0
GF>005iUP@1RJX@0HV^4065[P`1SK8@0I6f606E^R01WKhT206M`RP0;06Q`R`1XLX`0J7>;06YdR@1Z
MHL0JgF706]dR@1/MH/0KgR<06miS@1^Mh`00P1_N8h02`1`NY00LG^A079kTP1eOYD0MWjF07MoUP1g
OiD0N86D07^3U@1lQ9@0Nh>E00<0OHFG00P0OXJI07n7V`20R9h0PHVQ0828X@21RZ80PX^P08>=WP80
QXnN0P28T9l03029TJ00RY:S08^CY@2=UJP0SYFY08fDZP2>UZT0T9RY096IY`2DVjH0UYfT09JNXP80
UYnR00X0UInQ09BNX@2DWj<0UZ6U09FPY`2EWjD0UJ2U09BPYP2EXZH0UJ:T0`2DXJ402`2AWid0SifG
096QU@16B4/0@4A507>1LP1;DTd0?44n02LY:`1;ED/0C5I<0080CEM<00`0Ade4051EBP1nSGH0MhEb
07^8MP27UX<0Pi6007V1M@0n>D40I6IV07ImN02;UhX208RFQP0;08FEP@1kSGL0<3@_01TI600N7aX0
5aTC01@F3`0E6@l04aL=014E2P0g@bT00P1=FCd02`0F5100CUA707Z8L`1/N6/0LGia07>2M01aPg<0
JG]X049=@@0]=Bd0<C/_0080;SH[00H0;3<W02`e9P0/=RD0;STW02hi:00]=bL?ooooo`003Oooool0
1P1PJhD0JGJB06mlW01bOZ40L7bR075nX`80M86R00/0Lh6R07F3Y@1hQZP0MhFV07N7YP1hRJH0N8ZV
07V9Y@1jRZD0NhZS07f:Y@0207j;Y`0;07j;Z01nRj@0Oh^R086=Y022SJH0PhfX08:?Z@21SjP0P8nW
08>BZ024TZP00P24TZX02`25TZ`0QY6/08VC[029TjX0RiBZ08fD[02?UK00SYBb08nE/`2>UK80SI>_
00<0SiJ_00T0SiF^092F[@2AV:l0TYV_092G[@2AUZh0TYN_09:G/P2CV;L00P2AV;T209>I]`0;09:J
]@2BVKH0TYRe09BJ]P2FWKH0UYfd09JL/P2HW;<0V9be09FI]P2EVkH00P2FWK@02`2GW[40Uif^09VM
[`2IWJl0V9j`09NN[`2FWZh0Uij^09JN[P2GW[80UYfd0080UYje00`0UZ2b09RR/02KX[00WJ:a09jR
]02MX[D0WZ:g09bQ]P2KX;D0VInd09RO]@2FW;@209FM/`0;09JN]02GWK@0VIfe09ZO]`2HW[D0V9jg
09RO]P2FW[<0Uijb09VO/@2JWk<00P2LXK@02`2JW[<0VIfb09VL/02JWK80VIba09VM/`2GWKD0UYfb
09FK[P2BVJ/0U9Z]0080TiV]00`0TYV`09>J/02BVjl0TIZ]08nFZP2>UZX0SYJ/08^DZ`29TZD0RYBS
08fDXP2>U:0208nDX00;08bBX@2;TZ00Ri:Q08ZAW`28T9d0QHfJ08J=W029Sj00QHfP082:W@1oRY/0
0P1mRIP02`1oRYP0OhRI0828VP21R9`0OhFM07b2W@1iP9`0NH6K07QoV01gOIH0MWbG0080MGbG00H0
LWfE06ilT01ZNhP0JWb306UlOP1XNgPJooooo`0604=6H014B6D0ADUW04E9I`16BFP0ATQY0P17BVT0
2`16BVT0ADYX04E:J@15BfX0AD][04A<J`15CF`0ATe^04U@L@19DG00BU9_0080BU=^00/0BeE^04aF
KP1=EW00CUMd051IN01AFWX0De]m05EOO`1EH7d0E5mk05IPN`0205UQN`0605QON@1JHGX0GF=l05iR
O`1OI840H6F30P1PIhD0101QJH@0I6b606A[Q`1UK8L206I^R00406M^R`1XKh/0J72906UbR@80JG:8
00D0JW>906]dRP1/MXT0KWV<06iiR`0206egRP0;06miR`1aNhd0LW^>07AlS`1fOI40MgnB07MnTP1i
PI<0NX:B07^5T`1jQ9800P1kQ9D02`1kQ9L0OHFI07n7W020Qj00PHRR0868X`21RJ40PHZP086:W@23
S9d0QXnM0080R92M00`0Qi2O08RAX@29TJ80S9BT08jGY`2?UjT0SiJX092FY`2AV:H0TYVV09BKY02E
WJ@209FNY@0;09BNX`2CWJ40TifQ09FPY02EWjH0U9nU09BPY`2DXJP0Tj2X09:PYP2BWj800P2BWil0
2`2?WI/0SY^G09:RV@1PIfL0;2Tf06MaJ01CFe@0@4I102d_;`1>F4`0CEM;0080BE5700`0?3lj0454
?@1KHe@0MH9[08BDN@2:Vh80QYEo08>?O@0j=ch0FeeN07R0NP25THH208BAQ00;08BEQ01gR7H0<CDd
01/K700O81d06Q/G01DG4P0B5@d04A@<00h@2`0e@2`00P1;F3l02`0B40/0ADXl07F2K01]N6/0Kga`
07:1M01bPg<0L89_04IAA`0^=Bh0<SX/0080;CDU00<0;38S02hd900]=2<00`0^=b@?ooooo`003Ooo
ool01P1SKXT0JgRE071oW@1aP:00LWnQ075nXP80Lh2T00/0LGjR07B1Y@1fQJL0MH>V07J5Y`1hR:P0
NXZY07^:Z@1jRJT0Nh^W07n?Z00207n=Y`0;07n;YP20S:H0PHbU086<Y@21S:L0P8bW086=Y`20SJL0
PHnX08:@Z023TJT00P24TZX01@26Tj`0Qi>/08VDZ`29TjT0S9F[0080SIFZ00D0S9>[08fD[@2=UJh0
SYJ`08fD[`0208jE/@0308fE[`2>Ujh0SiR^0080T9J^00H0TIN`096G/`2AUk@0TYNg09:I^@2CV[X2
09>J^@0709:J^@2AV;P0TIRf096J]@2EWKD0UYfd09JL/P0209NL/`0?09BJ]02EVkL0UIbf09FL]P2F
W[D0Uife09RM]@2IWK<0VIna09RO[`2GWjh0UIb/09BL[02DWJl0U9bb0080UYnd00`0UInc09RQ/`2I
X;80VZ2c09bO/`2LX;H0WJ2g09bP^02LXkX0Vj:i09^Q]`2KX;H209^Q]@0;09VP]@2GWK<0Uibc09NM
]02GW[D0Uijf09RO]`2FWKH0Uije09ZO]@2HWK@00P2JWkD02`2IWK@0VYfc09bM/`2KVk@0Vi^e09VK
]P2GW;@0UYb^09FL[@2CVZ/0Ti^[0080Ti^/00`0TYV/092G[02@V:`0SiN/08nH[02=UjT0S9JY08^F
Z@2;U:D0S9>S08fCXP2<TIl208fBX@0;08ZAX@27Sih0Qi:M08RAW027Si/0QHbL08B;W@25S9l0QXfP
08::W`22RYh00P20R9d02`1oQi`0OhFK0824W@20Pid0OH:M07^1W01jP9d0NH2L07MnV@1eOIT0M7fI
0080M7jH00H0LWfC06aiR`1ZN8P0JGZ506IhO`1TMgTJooooo`060455G`12AV80A4MT04I8IP16B6P0
ATQZ0P16BFX204E9J@0404A:J@13BfT0@d]X04=;J@80A4aZ00<0ATi/04UAK`1:DW400P1:DW402`1:
E700C5I`04aFL01=EW40CeMd051GM@1AFGT0Deam05AMO@1DGW/0EEmk0080FF5l00`0FF1j05YRN@1L
HWX0GF5l05mSO`1OI840GfF2061WP`1SJh80Hf^106EZP`1WJhH206Q[Q`0306M/RP1WKHT0Ifj80080
Ig2900H0JG::06YcRP1YLX/0J76:06YdR`1YM8P206YdQP0;06egQ`1]MhH0KWR7079kR`1eOHd0MWn?
07R0T@1iPI40NH:@07V4TP1hPi800P1iPi<02`1kQID0OXJG07n7VP1oQYd0OhJN07n7W`21Rj40PH^O
08:;WP24SIh0QHjM00<0Qi2M00/0R96O08RAX02:Tj40SIFS08nGY02@UZ@0TYNV09:IYP2BVJD0TYZS
09BMY00209>OX`07096NX@2AWZ00TIjO09>OX@2EX:80UInR09JQY@0209>PX`0?09>OX`2CWj40TYjN
09:NWP2AWI`0TIjI09>RVP1_MgH0:BDc04E9B012B4<0=c/g03Pk=P1=EDT0C5A70080CEI900`0@TPo
03Pl=P0o@c/0IG1L08RHOP2BXh/0RIJ308F@PP10?4H0KGA`07V3O026TXP208FBQ@0;08FDQ@1iQgL0
;2d_01`L7P0O7ah06AXF01@F400A50/0418900l>2@0nAC@00P1FHd/02`0A3`l0<38^07:1K@1[NFX0
KG]^0721LP1aPg80L89_05MVE@0b>2h0:BdQ0080:c0O00H0;38O02dc800^=240;CDR02`e8`0/=28?
ooooo`003Oooool01P1SKHP0JGND06elV`1`Oil0LWnO079oX@80LWnR00X0LGjR07>0Y01dPJ<0MX>T
07^9Z01kRJT0NhZY07Z9Z01jRJT0O8ZY0`1oSJ/01@1nRZX0Oh^Z086<Z@22SJX0P8bY0080PHjZ00@0
PXjY08>?Z@23T:X0PhnY0P25TJ/03026TZ/0QY6[08RC[02:UJd0RIBZ08ZEZ@2:U:T0RY>Z08ZBZ`2:
TJ`0Ri>^08fD/080S9B_00/0S9>]08fD[P2=Tjl0SY>^08fD[P2?UK00TINc092F]02@UK<0TIJe09:H
]`0209:I^@0;096H^@2AVKT0TYVh09:J]`2DW;H0UYfd09FL/`2CV[00UI^a09BK/P2DW;@00P2EW;H0
2`2FW;P0UY^f09JK]02GW;<0Uifa09JL/02DVjd0U9^/09BM[P2BVjl0U9bb0080V:2f00`0V:2g09NO
]`2GW[D0VIne09ZO]@2IW[D0VYjg09^O^@2KX;/0Vj6i09fR^02MXK@309^O/@0309ZN/`2IW[D0VIje
0080Uife00@0V9jh09RM^02HWKH0VIfg0`2IW;L02`2HV[D0V9Zc09RJ/P2JW;80VIZc09NJ]02EVK00
TiZ[09BK[@2CVjl0TIV]00<0T9V/0P2?Uj/02@2=UJX0Ri>X08fEZP2=UZX0SIFY08fEY`2=TZ@0Ri6S
08Z?XP0208V>X@0;08R?X@25SYl0QHnL08B>VP25SY`0QHfM08>;W@22RYd0PhZO0869WP20R9h00P20
Qih02`1nQ9d0OH>M07f2WP1mPYh0Nh2N07UoW01gOY/0MGfI07=lU@1`NY40L7^B0080LWbB00H0LG^?
071jS01/MhT0JWJ706IfPP1SMG/Jooooo`0603i5G010AUh0ADUR04M8IP17B6P0ATMX0P14AVP02`14
AfP0A4QX0498I@12BV@0@T]U04=<I@14CVH0A4eV04=<IP16CfT0Adm/0080B51_00T0B51^04]CL01<
E700C5Ia04iGL`1?F7D0D5Yh059LN`1DG7`00P1DGW`205MPO@0<05URO01JHW/0G6=k05eTO01MI7d0
GVEo061WP@1QIh40HV^1065YOP1RJGl0Ifb20P1XJh<02`1XJhD0J6f806I]R01VKXT0IVn:06E`R@1W
LXX0Ig6:06I^Q`1WKhD0IVj30080I6b100/0IFf106M_PP1UKX40Ig6206]dQ01]MHH0KgR8075kR01a
O8L0M82:07N3SP0207V5T@0907^7U01mR9H0OhVI07n8V@1oRIX0OhZJ086<VP22SIT0PhfJ0080QHjM
0P25Si`03027TId0RY:P08^BX@2<Tj<0S9>U08jDYP2@UZD0T9NT09:IY@2CVZD0Ti^T09:LX@80T9fO
00/0T9jP096NW`2@WYl0Tj2O09FQW`2EX:00UJ6R09BPXP2DX:<0TinQ09>OW`02096NW@0;08nMVP2>
W9L0TJ6H06efM00/:3H0=C@g02d];P0S8R@0C5A5055KB@1?EdH00P1>ET@0300oACH0>Chb03Dg<01G
GU40XkVJ09:RSP2;VHP0R9B404M4B@23S800QHn408ZER080R9B600/0Q9:007j<M`0a<Rl05aHG01hO
6`0J6QD05QL>01@D2P0B4PT03P`5049:=P0205UUCP0;01HB4`0f>SL0IgIY06AcJ01WN6`0JWe^06b0
KP1XO6L0EFEA02he:@0Q9QT00P0Y;ah202`a7`0402/c800]=R80;3DS02Xc8Poooooo000=ooooo`06
06=^Q`1XMI80K7^J06mmX01aOj<0LWjS0P1`OJ402`1aOZ80M86T07B1XP1fPj80NHJV07Z8Z01iRJH0
NHVT07^:Y@1nS:L0OhbY0080OXf[00X0OH^]07j<[01mRZP0P8bY086=ZP23Sj/0Phj[08:>Z`23SZ/0
Pi2/0`24Sj/02026TJh0QY:^08JA[@25T:/0QY>[08RF[028U:`0RiB]0P2:Tj`03`2;U:l0Ri>`08^C
[@2;Tjd0S9B^08nE/02?U;40T9Fb08nE/@2AUjl0TYR`09>H/@2CUk40TiRc09:H]@0209:G]P0;096F
]P2BV;H0TiZf09BK]@2FWKH0UIbe09>I]02BV;80U9Zb09BK/P2EVk@00P2EVkD02`2EVkL0UY^d09VM
/P2IW;40V9^`09NK/02FW;40U9^_09FL/02CVjl0U9^`0080UYfc00@0Uije09NN]P2HW[L0VIjf0P2I
WKD01P2IWKH0VI^f09RL]@2HWK<0V9fa09VM/080VIf_00L0W9nc09bO]P2KW[L0VYff09RL]P2IWKH0
VYjg0080V9bd00l0V9^e09RJ]P2IW;@0VIbd09RL/`2GVk80Ui^a09RK/@2FV[40U9R`09:I[P2BV:`0
TiR^09>H/02AUk000P2>UZh02P2>Ujd0SYN[08jFZP2?UJT0SI>Z08jD[@2<TZX0S96X08bBYP2<TJH2
08V>Y080R8jT00/0R8fT08J=X`25S:80PXZP08>:X024RZ40Q8RP08>7X@22R:80P8JR07j4X00207b3
W@0;07f2W@1lP9/0NgnK07YmV`1iOi/0N7nI07ElUP1dNi@0LW^B071iSP1_NHd00P1`N8h01P1_Mhh0
KWN=06YeR`1YM8L0IWB1065bNQ[ooooo00H0?DAM03m6H013B6D0ADQW04E7J015AVP304=6I`040498
IP12BFD0@TUT04=:I080A4eU00@0A4eV04E=I`16CfT0BE5]0P1:DFl02@1;D700C59b04iEM01=EG@0
CEEe04iHN01@FGX0D5Uk059JO00205AMO080EEel00`0F61n05UQO@1JHW`0FV=k05aVO01MIGd0GfIo
061WP@1QIh40HFR006=ZPP1UKH<206E/Q00;06I/Q01WKXL0Iff:06M^S01UKhd0IG2<06MaR`1XLXT0
IW2706M`QP1VKX@00P1UKH402`1VK840IVb3069ZPP1RJh40I6b106=]O`1SJgh0IFio06IaO`1XM800
K7R30080Kg^800/0Lh2=07F2T@1iQY<0NXRD07b9U@1mRYD0OhbE07n=T`20SI@0PhnI08B>VP0208B>
V00<08NAW@29TZ00RY6P08Z@X02;TJ@0SI:V08fBY02?U:@0TYNT09BJY02CVZD0TY^R0P2AW9l02`2A
W9h0TIfN09:NW`2DXJ00UJ6P09BOX02DWj80TijS09:NY@2AWZ80T9fN0080T9jN00/0SijL08ZJUP2>
X9H0LWmh02l]=P0d<S<0;B/[01lL701GGdd0FVE@051IA@0204aD@@0<034c:@0b=2X0>Sdb0495>`2J
[Xh0UjZB092OS`2<VXX0DE9A08bGQP2CWY00SIR<0P2:V8P02`24UH40PYEj03m6>@0E51807b0I01dM
5@0M71<06AT?01LF3@0A3PP0?D8b0080HFeF00/081dO04aCC@1VM6/0HG1[05maJP1OLFH0HGAS065d
G`0d?S@0:S8X02L_8P0202P_7`0602Xa800/<R40;C@Q02`d8P0[<b80:C8R3oooool000gooooo00H0
Hfj706QeTP1/NiX0KgfP075oX`1bOZ<2071mX@0;075nXP1dPJ@0M86R07J3XP1iQZH0NXRX07V9YP1i
RJ@0NhZU07j<Y`1oS:T00P1nSJ/02P1mRjd0OXb/07f:Z020S:T0PHfZ08>?Z`23SZ/0PXj[08>>Z`23
T:`308B?Z`0808JA[P26TZh0QY6]08F@Z`26Tj/0R9J/08RD[02;U:d208ZC[00?08^D[`2;Tk00Ri>]
08^C[@2<U:h0SiF`08nD/@2@UK80SiFa096G[`2BV;00TiRa09>G/@2CV;<0TYRe0080TYNf00/0TIJf
09:H]P2CV[H0U9^e09JM]P2EW;D0TiVd09:H/P2DV[80U9^b09FK]00209FK]@0;09FK]`2FVk@0VIfb
09VL/@2HVk00Ui^`09JL/@2DVjl0UIb`09>K[`2DVk000P2FWK<0102GW[D0Uijf09RN]`2IW[H209VM
]@0609VM]P2IVkH0V9be09RM/`2HWK40VIf`0P2IWJl01`2LWk<0W9nf09^N]`2JWKH0V9bf09VM]P2J
W[L00P2HW;@03`2HVkD0V9Zf09VL]02IW;@0V9bc09NK/P2GVk40V9^a09JJ/@2DV;00TYV^09:H[02C
V:h0TiR`096G/00208jF[P0:08jG[@2>Uj/0SYJZ08nEZ@2=TjX0SYB]08bBZP2<TJP0S9:V08bAYP80
RHjT0P28SZ@02`28SJ@0QXfS08F<XP22RZ00PhZP08B:X@24R:00PhNQ08:8XP20QZ80OXBP0080O8>M
00/0OH:M07b0V`1kOi/0NWfK07UoV`1hOiT0MGbF07AkU01bNi80L7V>06miS@02071hSP0606mgSP1^
Mhd0JWF;06UdQ`1VM840HG9j6_ooool01P0mA5d0?dIP04=8I@15B6L0ADMX04E6J0<0@dIW00@0@TQV
0499I@12BF@0@dYT0P14CFD01014CFH0ADeW04I?J@19DFd204YAK`0904]@L01<DW80CUEd04eEM01=
EGD0CUQh051INP1@FG/0DUYl0080E5el0P1EGG`0301HH7h0FF5m05YRO01JHg/0G6Il05eUO@1OIWl0
H6N1065WP@1QJ800HfZ206E]P`80IFb400/0IVb406M^Q`1WKHX0Ifj<06E_S@1UL8`0Ig6;06QbR@1V
L8L0Ig2606I^Q00206E]P@0;06I/P@1VK8<0HVZ2069[P@1TK840Hfeo06=[OP1UKWl0IW5o06QdP01/
N8<00P1_NhP02`1cP8d0MH:A07V6T`1jR9@0O8VE07f:U@1oS9D0OhfC082=U023SiT0Q8jJ0080Q8jH
00`0Qi6M08VBX02:TJ00RY2P08^AY02=TZH0SI:T08nDY02BUj@0U9ZT09>JY@2BVj82096LW`0;096L
WP2AWIh0TYjO09BQX02EXJ00U9nP09BOXP2CWZ<0TYjU096NXP2@WIh00P2@WYh02`2?WY`0RYZF08jP
UP1bOgP0;bdf03@b<`0]:b/07a`L05MOC@1JIE00D5U50080C5A100`0<C<Y038d:P0j?C80@TDk09Z^
SP2GZY80T9n?08bJRP1ADU40S9N609>NT02=V8`208ZHR00;08BEP@22UGX0?dHi01DD4P0O81T07AdE
01dL4`0I6@l05aH=014>200m@S800P1QKEH02`0P7Al0C5==06IdJ`1QL6/0Gg5Z05maIP1QM6<0HGAO
03@n=00Z<RP09blR0080:2lO00H0:S4P02`b8@0]=240;3@R02/c8P0Y<R8?ooooo`003Oooool01P1S
KhT0JGFB06ekV`1_O:00LGfS079mY080LG^R00/0LGfR07F0X`1gPZ<0Mh6Q07V5Y01hQJH0N8NV07Z9
Y@1jRZD0O8bV07f<Y`0207f<Z@0807f<Z`1nSJ`0OhfY07n>YP20SZ@0PY2U08:?Y`23SZX208B>Z`0?
08B@ZP23SZP0PhjX08B?Z@26T:`0QHnZ08>>Z024TJX0QY>[08VE[02<UJh0S9F_08^D[`2<U[80RY>`
0080RiB`00/0RiF^08fE[P2>U:l0SiJa08nG/@2BV[00Ti^_09>J[P2BUjd0TiR`096G/P0209:H]00;
096H]02AUk80TYVb09:I/P2CVK40TiVb096F/P2AU[<0T9Jc096H/`2DV[D00P2CV[H02`2DV[L0UIZd
09NL/`2FVk80V9bc09NL/`2DV[80TiZ`09:K[P2BW:d0U9f^0080U9b_00`0UIfc09FL]02EW;@0Uife
09JK/`2EV[00UiZa09VK]02HVk@0Uibb09JK[`2GW:l209RM/P0;09ZM/`2IW;@0VYbf09RK]@2FVk<0
Uibb09RM/P2HW:l0Uib_09NK/@2EVK400P2EVK002`2EV[00UY^`09FJ/@2FV[80U9Vb09:G/@2AUk00
TIJ]092DZ`2AUJd0SiF_0080S9B^00`0RiB[08ZCZ@2;U:P0Ri>V08fCZ02=Tj`0S96[08^BZP26SjD0
R92S08Z?X`28SJ<208V<Y@0;08R=Y`27S:L0QHbV08::X@20RIl0PXVM08:9W`22Qj40PHJQ07n6X`1l
Q:400P1gP9/02`1iPIT0NX6G07YoV@1iOYT0MgfI07IoVP1bO9L0L7ZD071jT`1_NI80KgV?0080KGJ>
00H0JgB>06UbS01ULHX0IG:706AcP@1PLGPJooooo`0603i3G@10AV80@TUV04=9I`14B6P0A4MX0P13
AVL02P13AfL0@TMV04=7IP14B6H0A4UV04A;I`14C6L0ADeX04I=J`16CVd304Q@KP0:04Y@K`1:DG40
C5=c04eCL`1>DgD0DEMi059HN@1CFWX0E5]k05IMN`<0Eeil00`0F5mn05MOO@1GH7`0FF9k05]TN`1L
I7`0GVEn05mVO`1PIX40H6J2069XP`1TJh@206A/Q@0706A/QP1VKHL0J6j:06M]S01VKHd0Ifn=06U`
S@0306YbS00>06abR`1/LXT0K7:906abR@1/LHX0JW2:06M`R@1VKHL0I6b506=ZP@1TK840IFf2069[
P01SJh0206=/P00;06I_P@1XLH80K7F406mhQ@1aNhH0M7n907F2R`1hQXd0NhR>07n<T@21SI<00P24
SY@03027TIT0RI6M08ZBWP2:TId0Ri:O08bDX`2=U:80SYBQ096GXP2AV:40TYVP09>KW`80TIZK00/0
TI^L09:KW02BW9d0U9fO09JMX@2EW:40U9fR09BNXP2BWZ40TInQ092OW`02092NW@0;08nMVP2<ViH0
SInE07f<PP0o@T@0=cLd02l]:00U8Ah0G69?05]SD01?EDD00P1:DT40300h?S40=C/]03e4=@0g>C40
NhUb09^^T`2@X900S9^>06UaKP20S880OXV4086>R080S9j@00/0Q9N5086DO00m@cL05Q@A020O6@0M
71L07Q`G01/J500H5Q005Q<?0496>00206ajHP0;04E;A01PJeh0I75U06=aI`13C4/0<cTk04YHC01W
Nf40<CX_02L_900Z<bD00P0Y<2401P0Y<1h0:S8P02/c8`0/<b80;3<Q02T`7`oooooo000=ooooo`06
06=^QP1WLhl0KG^J075nX@1cOZ<0M7fS0P1dNj80201cNZ40MgjR07R0XP1hP:80NhFV07V6Y@1iQZ@0
NhVU0`1lRjH207b<Y@0;07f=Y@1oSZL0OhbU07j<XP1lS:00PI2Q08:?X@25Sj<0QXjT08F=Y@25T:P0
0P25T:T03026SjT0Qi2Y08J?Z@26SjX0R92]08VA[`28T:h0S9>_08fD/P2<UK80RY>`08^C/@80S9Ba
00/0S9Fb08^D[`2;UJl0RiF_08^F[@2>V:d0T9V]092G[02@UZ/0TIN]096G[`0209:G/00;096H[`2A
Ujd0TiV_09:G/02AUZl0T9F_092E/02@UK40SiBa08nE/@2@Uk<00P2@Uk@02`2AV;<0TYRa09:I/02C
VJl0TiR_09FJ/@2DV[40TYR_09>J[@2CW:`0U9f/0080U9b^00`0U9ba09>J/P2DVk<0UY^c09FJ/@2F
VJh0UYV_09VL]02GV[80U9Z`09FK[`2DVZ/209FJ[00;09NK[`2GV[00UiZd09FH/`2CV;00U9Z_09BI
Z`2DVZX0UI^Z09BIZ`2CUjd00P2BUZh02`2BUZl0TiJ`09>G/@2BUk80TIJb092D/@2AUJl0TIF^096E
[@2@U:`0SYB[0080S9>[00`0Ri>Z08ZCZ@2:TZP0RI2U08R?YP2:TJP0RI2W08ZAY`28TJ@0R92Q08V?
WP28S9h208V=X@0;08N;X`25RJ@0PXVT07n8WP1mR9`0OHJJ07j5VP1nQI/0OH>L07f5W`1kPih00P1h
PY/02`1gPIP0MGjE07IlUP1gO9P0MG^H07=jV@1`NIP0KWRE06eeTP1[Lhl0K7>?0080JG2>00H0Ifn=
06I^S01SKhT0HVn7065`PP1NKWHJooooo`0603]1FP0nAEl0@4MQ03m5H@11AF<0@dIU0P11AF@02`11
AfD0@TIU04A7IP15AfL0ATQX04E9J015BfT0A4YY04A:J`15C6h0ATe]0080ADe[00/0ATi[04M>K@19
Cfh0C51`04iBL`1?Dg@0D5Ae059GN01CFGT0E5Yi05EKN@0205IMN@0<05MNN@1IGgX0FF1k05YQN`1K
HWX0G6=k05iTO@1NHgh0H6B106=VQ01SIX<0HfF30P1TIh@02`1TJ8D0IVZ706Q/R@1ZKH/0JFb;06Q^
S01XL8`0JG2<06YaR`1ZL8X0KG:;0080KgF=00/0L7J=075fS@1`Mhh0KgJ>06ifS`1]MXh0K7F;06]c
R@1[LhP0JW2706]aQP0206U_PP0;06M^O`1WKWd0J6em06Y_O`1ZKh00Jg2106Y`P@1ZLX00K7J006ii
P@1eOXH00P1iPXT0301oQhd0PhZB08F<U027SiD0R92I08bCW@2=U9d0SIBL08nGWP2@V9h0TIVN096J
V`80TIZH00/0TY^K09:KW02CVih0UIbN09NMX02FWJ40U9bP09>MWP2BWYd0Tj2N09:OW@0209:NW@0;
092LV@2>W9D0TInD07j9O`17AdX0>CLh02`U9@15@ST0OhQ^05MJCP1AET/00P1>EDP03014Bcd0?dLg
0415>011A3/0LWaX09JUS02BXHl0RYN;08>>Q`22ShP0GVI[06ilM`80SJ:?00/0Oi9o082CN`0m@ST0
6aLF024P700L6QP06APE01PF4`0E4a0061HD04M=?`0206UhHP0;061]G01VMF<0IWAS06UiI`0g>c`0
6QXU02P^<@1EIeD0<Sda02L_9@0Z<bL00P0Z<B@01P0Y<B80:C8R02/d900[<b40:S8O02Xa7@oooooo
000=ooooo`0606I^Q01XLHd0K7JF071iV`1cO9d0MGbO0P1eNJ402`1eN:40N7bS07MnXP1hPZ40NXFR
07Z5X@1jQJ00NhNP07b8X@1mRZ@0OXbV0080P8fU00/0OXbR07j;XP1mRJ40OXZR07f;XP20SZ<0PXnR
08B?X024SJ40QHfU08N>Z@0208V@[@0<08VA[P29TZ`0R96Z08R?Z`29SZd0SI6b08b@/P2:S[00S96`
08^B[028T:T0Ri6[0P2<TZd02`2;TJl0Qhj/08F>ZP24T:T0QY:Y08RBYP2=UJP0SYBY08nEZP2>UJP0
SYJY0080SiNZ0P2@UjT02@2AUjT0TYJZ09:G[02@UZ`0TIN]09:I[@2AV:`0TYR]092E[@0208nF[`0;
08nF[P2?UZ/0T9JZ092EZ02@U:L0TYJY09>HZ`2CVJ`0TiVZ09:IY`2CVjP00P2CVZX0302DVJ`0TiN]
09BG[P2EVJl0U9N^09FG[P2FV:h0UYV`09JH[`2DV:d0U9ZZ09>IYP80TiNV00/0UYV/09NI[`2EV:l0
UIV_09FH[@2DV:/0U9NY09BHZ@2DVJT0U9NX09:DZ002096CZ`0;09:D[`2DUK00TiF`09:E/02CU[00
TI>^09:D[P2ATjd0TI>/092CZ`2=TZP00P2<TZH0102<TjT0Ri:X08R>Y029Sj<308R>X`0508R?X@2:
TJ80RHnP08N=WP28S9d00P29SIl02`28RYl0QHRR08>6X`21QZ80OXFN07b3V@1jPYH0O8>F07f2U`1l
PiP0O86G0080NGnG00/0MgjH07ElU@1eNiD0MWbF07=iU@1aMiD0KgJE06ifU@1/M980K7>B06]cTP02
06UaT00606E]RP1UKHT0IFj8069/Q01OJgl0GFag6_ooool01@0l@EX0?D=M0416H010AEl0@DIP00<0
@TMQ00/0@4IR0416H`11AfD0A4MX04E8J@13AVT0@dQ[04A;K015CFh0ATi_04A<KP0204A<K00;04E=
J`16CF/0BU1^04aAL01=DW40CE9b04eBL`1?E7H0DEIf059HM`1DFWP00P1GGGP0101GGWL0F5ig05UN
N01JH7X205aSO00605eROP1MHH00H6>3065TQ@1SIXD0I6N50P1TJ8<00`1SIh<0IVV606MZQP0206U/
QP0606U]Q`1YKhP0J72906M`R@1XL8T0JW6:0P1[LX/02`1]M8`0L7N<075hS01bN8l0LGR@06mhS`1`
NHl0LW^?07AmS`1eOHh0Mgj?0080Mgj>00/0M7b:079jQP1aN8@0LWN6075dQ`1^LHL0JVj406Q]PP1W
KX00IVim06Y`O`0206ecP@0;06meP`1bMhD0MWZ807UnS01lPhl0P8RB08>;T`26SY<0RI>G08^FV02>
VIX00`2@Vi/02`2CW9d0TIZK09>KW02EWI`0UYjK09JNW02CWI`0TYfK09:LV`2AWI/0TYbK0080TibK
00/0TY^K096KU`2AWI<0QY660490AP0g=3T0;BP]06AZF`2T]Y80C4e204]?A00204]@A@0<04E<?`11
B3T0?T4d0451=P1ZL5h0TIf509FRS`2=V8/0RYF;07b5PP1GFV80IW5`0P29W8`02`1mSgl0OI1n03m6
@`0E4aP07alP01XJ6P0G5aH05aHD01HD4`0F4a@0BE120080KWiW00/0I75P06QgI@1[NFL0L7i/0498
A@0H5b<0>D9202`d<`0X<B/0:34W02Pa9P0202Ta9P0602Pa9@0Y<b@0;CDS02`e8@0Z<Al0:BlM3ooo
ool000gooooo00H0JFf106ebS01cNID0MGbJ07MmW01gNY/207IiWP0;07MjX@1jOJ@0Nh2T07b4X@1l
QYl0Nh>M07b4W`1lQZ00O8JO07b9XP1oS:D00P21SZ@02`20SJ00P8^P08:<Y022RjD0P8ZU082<YP23
SjD0QY2S08N?XP27SJD0RXjZ0080Rhn^00`0RHn^08V@[029SjX0RHjZ08^?[@2>T[00SI6a08Z>[P29
Sj`0RY6[08bBZ@2;TJL208^@Y`0;08V>Y`28SJP0QH^V08>:Y022Rj00PXRL08>7W@27RJ80R8ZR08N;
X@25Rj000P26SZ002`28TIl0RI6N08bCX@2>UJ@0TINX08jEYP2?UjL0TIZY09:JZ@2CVjX0TiZ[0080
TiV^00/0T9J[08nFZ02AV:P0TYNU09>GY@2DV:L0UY^[09BIZP2CUZL0U9RV09FIY`0209BHZ00<09JH
[02DUj`0U9R^09>G[@2BUZ`0U9N]09JH[P2GVJl0V9V_09FG[@2DUjX0UIVY0P2DUjL01`2FV:P0UYNY
09FFZP2EUj`0UIR/09BGZP2DUZP00P2EUjT03`2DUjX0TI>Y092BZ@2@TZT0TYBZ096BZP2@TZX0TiF]
09BE[P2ATZ`0TYB]09:CZ`2@TZP0Si>V08nBY00208nAY00608b?X`2:Sj80RHnQ08^@X02<TJ40RHjQ
0`27S:400`26Rj00QHZN08J:W00208V<W@0;08R9W026QYl0QHFQ0865XP1nPil0Nh>H07b4UP1mPiD0
O86D07j2U`1lP9L00P1kOYL02`1iOIL0N7fG07QlU@1gNY80MGVB07=gT`1aMYD0KG>E06U`TP1ZLY40
JgB>0080JW>;00H0Ig2806M^Q`1WK8H0IFZ3065XO@1MIgDJooooo`0603e1FP10@eh0@TIQ0496H@11
AV00@TMO0P12Af002P12Af40@dMR04=6I@13AVH0A4IW04=7J012AfT0@dMZ04A;K016CVd304E<J`0;
04I<K@17CFh0BU1`04YAL@1<DW80CU9b051DM01AEWD0DUMe05=GM01EFWD00P1FG7L0301EFgL0EE]e
05MMMP1JH7T0Ff5i05eSN`1MHW`0GV5o061RP`1PHX80HVB306EXQ@80IFR200/0IFQo06QZP@1XJX<0
JVb406]]Q@1[KhP0JVj706U^QP1XKXL0JG2706Y`Q`0206aaR@0;06idS01_MH`0L7F;079gS@1cNHl0
LgR>07AjT01eNi40MW^B07QoTP1iP9800P1hOi002`1gOXl0NH2?07^3S`1mPXl0O7n?07]nT@1hO8l0
MGZ>07=gRP1aMXP0L7B70080KW:700`0KW>706eaQP1^LHH0L7>607=fQ`1fNXX0MWb907UoR@1lPhX0
OhN<08><T028T9<208ZBU00;08ZCT`2=UYD0T9RG09>KV@2EW9X0UYjK09BLV@2DWYT0U9fI09>MVP2B
W9X00P2AVYT02`2AVY/0TY^I09:NU026THD0A456038^=00b;c40Mh=[08>AL`1@E4D0B4e10080BTm4
00`0@dPm03Lj;`0e=RX0=C8W05UIB02GXXL0SIB608jES@2<U8d0O85o079gM01TJFX208VIR`0;07j?
P@1lSgl0?dI401HD6`0O7b406a/K01XJ6@0I6AH05A<A01@B4@1@FTL00P1_OV802`1MIe@0FF9C05aV
EP1/N6D0CEE;01TH7@19DdT07R4R024V8`0V;RD09c0U0080:30S00H0:30Q02P`7`0/=200;C@P02`a
7`0Z;Qd?ooooo`003Oooool01P1YK800LgJ=07MmU`1hOYX0NGfJ07UlVP80NG^K00/0NgbN07aoX@1l
P:80OXBP07n5W01oQ9X0OhFL08:8X@20R:40OhVR07n=X@02086>X00;08:>W`23SIh0Q8fQ08B<X`21
R:<0P8VR08><X@26Sj40R8nQ08V>X`2:SZP00P2;SZ/0302:SZ/0RHj[08V>Z@29SZP0RXnX08fAZ`2=
TJd0S92]08Z@ZP2<TjP0SYBV08jCY@80SI6S00/0RhnT08Z>Y`29SJL0QXbT08F;X024RI`0QHJK08F4
W023PId0PH6L07eoV00207f1UP0;07j3T`1oQ980PHFD08>7UP24RIP0PXZH08B=V`27TIh0RIBP08fF
X@2?UZ800P2@V:D02`2@UjH0T9RV096IY02BVZ<0TYVS09>HYP2EV:P0U9^Z09:HY`2BVJH0U9ZU0080
U9RT00H0UINU09FHZ02DUj/0TYR[096FZ@2BUjX209FHZ`0409FFZP2CU:X0TYBY09:EY`80TiJW00/0
UINX09FFYP2DU:H0UYJZ09>EZ02BUJL0TYFV09BGZ02EUjP0UYN[09>FZ`02092BY`0;092CY@2AU:L0
TYBV09>DYP2CTZH0TY:X09>CZ@2ATjH0TI>R092CX@2>T:000P2<SYh0302<Sil0RHjN08V?WP2:Si`0
S96L08b@W02;SIh0RX^P08J8W`26RIl0QXZM08N;W@80R8^K00/0QhRJ08N7W024Pi`0P86N07j2W@1k
PIL0NX6C07^1T`1kP980OH2E07j0V00207anU`0;07QkT`1hO980Mg^@07QiSP1gNHl0MGJ?07=dT01`
LY00Jg2@06Q^S01XLHP00P1XLHD01P1XKX<0JFf206EXO`1TIgl0I6Ql05eRLA[ooooo00H0?d9G0413
F@11A5d0@TAP0495H014Ael304=6GP0:04=7H012AF80@TAS0456H`11Af80@TQS04=9I@14BFH0AD]X
04M;J080Ade[00/0BDi^04Y>L01:Cg40BTmb04a@LP1=DG40Ce=`051EK`1BEW00DeM`05AJL@0205IL
LP0<05EKL`1FFg<0EUad05QNMP1JH7L0G61i05eQNP1NHW`0Gf9n065RO`1RHX40IFJ30P1UJ8802`1W
JWl0JFf006M[O`1XK840JFb306]]Q01ZKH@0Jfj506]_QP1[KXD0K6n50080KW6700/0Kg>:06mdRP1_
M8X0LGJ;075gS01cMh`0MWZ>07MjT01gNi40N7f@07Z0T00207Z0SP0;07UoSP1jP8h0Nh:>07f3S@1m
PXl0OX>A07j4T`1oQYD0OhBD07n3U@1oQIH00P1nPiD0301kPI@0N7jA07MlS`1gNX/0N7^:07IjR@1f
NXP0MGV507MkQ@1hO8<0O7j507j1Q`80OX>800L0P8J908B;S@26SHl0R8n@08jEU@2@UiD0TYVF0080
U9bG00l0U9fI09:LV`2AVYX0TIZJ092HU`2AVIH0TYbC08ZCQP12?T<0;bP^04mAB01YLEh0DE=704i>
AP19BT<00P1;CdD03018CD40>cha03Pj:`0n?Bd0DU5009RQP`2@UXH0VZ6F09>ITP25RH<0MGMd06a^
JP80Sif;00/0PI1o07b=NP0g?3X05aHH020P7@0L71T06Q/G01TK5@0C51005QLC05ERBP0205eZD00;
03Lk;P0c=Rd0CE=306E`F@1?ETD081lL03@h;P0M7Q/08BLP02<Z8@0V;R800P0W;b800`0W;b40:2lO
02/a800202dc8@0302/`7_oooooooooo00gooooo000=ooooo`0606Y]P01cN8`0MWbC07MkU@1hNY@0
NG^F0P1jO9P02`1kOIX0NgjL07f1W@1oQ9h0Oh>J07n4V@20QI`0PXVP0869X021RZ00P8bO0080PXfM
00<0Q8jL08:<W025SIh00P24S:401P24Rj40QhjP08V@X029Sj80RHnT08Z=YP80RhfW0P2:SZP02P29
SZL0R8fV08Z?YP2>TZL0S92W08bAZ`2<TJT0SIBX08jDY02?U:<208jAXP0;08f@X`2>TJH0SI:V08jB
YP2<TJ@0S8nR08^<X029RJ00QX>N08B2W@21PIT00P1nOi<02`1mOhl0OX2=07ioS@1lOHh0Ngf?07Ql
S@1gOHh0N7n?07MoSP1nQY40QH^E0080RHnI00/0SI>M08jGWP2AVYh0TIZM092HWP2AV:<0T9JT09:I
Y@2@V:<0T9VS09:IXP0209>IX00<09BHX02FVJ@0U9FU096DY02BUZD0TiNW09BGZ02FV:P0U9FW09>C
Y`2ATjD0T9BS0P2BUJ@02`2BUZ<0TI>Q09:CX`2EUJL0TYBV09:FYP2CUjH0U9RV09>EYP2DUJT0U9N[
0080T9>V00/0Si>U09>FY@2CUJ<0Ti>R09:AX@2CTj<0TI:R092BW`2@Ti`0Si:K08fAV`0208^>VP0<
08^@W028SY`0RHnK08N>U`29SiH0Ri2G08Z>U`29RY/0QhRM08J6W@26Qi/0RH^L0P27RIP02`27R9L0
R8NI08>2U`1oOiP0Oh:J07f1U`1jP9<0NX2A07b0T@1lOi80OX2D0080O7jB00/0MgV=07MjSP1gNHd0
MWJ;07EdRP1eMH`0LW:;071aS01]LH`0J6b706I^Q00206M_PP0606Q^P01YK7d0I6Ik06AVNP1SIgL0
GfEa6_ooool01@0o@5@0?d5F0413FP12AEd0A4IN00<0@dEL00L0@dIL0455G@12AEl0@TEQ0458HP0o
AV00@TQQ0080A4YR00D0AD]T04I:I@16BVL0ATYW04Q=J`0204Y?KP0804Y>KP1;Cfl0C55`04eBK@1>
E6h0D5E_055GK`1CFVh205ELK@0<05ELK`1FG740Eeac05MLM01HGWH0F5ig05aPN@1MH7P0Gf9k065S
OP1SHgl0IFF10P1TIX002`1UIgh0If]n06I[O01VJgd0I6Um06IZOP1YJh40JVf306Y^Q01YK8<0K6n3
0080KW2600/0Kg68071dRP1_LhP0KgB:075eRP1cNHX0M7R;07IiSP1gNhl0N7b>07Z0S`0207^1S`0;
07YoS@1kP8d0O82=07b1SP1mPY00OXBB07f4T`1mQI<0OhJE0827UP23RiX00P24S9X03024RiX0Ph^I
08B;V023QiH0PHFC07j3T01kP8`0NGf807UmQP1iO8@0Ngf307]mPP80O7j300/0OH6607n4R020QHP0
PHN908F;S028SH`0Ri2?08jDT`2@V9H0TiZH09>MVP0209:LV@0;08nHU02>V980SiV>08bGQP11?T40
:1dT06]`GP1eOVP0FeiA04Y8A01:BTD00P1=DTP0301:DD@0A4Tk0414=012AC80C4dk08jHN@2CW8H0
[;ZU09fWV@2:THD0Oh=i06]]I@80RYN100/0Pi5k07V9L`0h?CP0518D01hN6@0J6QD05aXD01DI4`0B
5Q005a`C03M2;P02049==`0;02ld9@0Z;240BU4n06MfF@1AG4D071dH02<V7@0R9ah08bTP02DZ800V
;B000P0W;R401P0W;B80:C0R02`b8`0^=280;38P02X_7@oooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {299, 0}} -> {-0.0508884, -0.0375078, \
0.00526762, 0.00526762}, {{9.625, 190.438}, {291.875, 156.25}} -> {-12.9439, \
-9.62807, 0.929149, 0.929149}, {{208.5, 389.312}, {291.875, 156.25}} -> \
{-197.728, -9.62807, 0.929149, 0.929149}, {{9.625, 190.438}, {142.688, \
7.0625}} -> {-12.9439, -148.245, 0.929149, 0.929149}, {{208.5, 389.312}, \
{142.688, 7.0625}} -> {-197.728, -148.245, 0.929149, 0.929149}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize two-channel color distributios of training image", \
"Subsection"],

Cell[CellGroupData[{

Cell["RG plane", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[\({#[\([1]\)], #[\([2]\)]} &\)\  /@ \ d1\  // N, pr, 
          style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[\({#[\([1]\)], #[\([2]\)]} &\)\  /@ \ d2\  // N, pr, 
          style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(distRG\  = \ 
        Show[gd1, gd2, FrameTicks \[Rule] None, \ yS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 0 r
.02 w
.06278 .06278 Mdot
.06278 .05886 Mdot
.06278 .05886 Mdot
.0667 .06278 Mdot
.0667 .06278 Mdot
.07062 .0667 Mdot
.07062 .0667 Mdot
.08239 .07454 Mdot
.07846 .07454 Mdot
.08239 .07846 Mdot
.08631 .07454 Mdot
.07454 .07062 Mdot
.07846 .07454 Mdot
.07454 .07846 Mdot
.0667 .07062 Mdot
.0667 .07062 Mdot
.0667 .07454 Mdot
.07454 .07846 Mdot
.07846 .08239 Mdot
.0667 .07062 Mdot
.0667 .07062 Mdot
.06278 .07062 Mdot
.05494 .06278 Mdot
.05494 .06278 Mdot
.06278 .07454 Mdot
.06278 .07846 Mdot
.0667 .07454 Mdot
.06278 .07062 Mdot
.07062 .07846 Mdot
.07454 .07846 Mdot
.08239 .07846 Mdot
.07846 .07846 Mdot
.07846 .07846 Mdot
.07454 .07454 Mdot
.08239 .08631 Mdot
.08631 .09023 Mdot
.08631 .09023 Mdot
.07846 .08631 Mdot
.07846 .08631 Mdot
.08239 .09415 Mdot
.07846 .08631 Mdot
.07846 .08239 Mdot
.07062 .07846 Mdot
.07454 .08631 Mdot
.07846 .09023 Mdot
.07454 .08631 Mdot
.07454 .08239 Mdot
.07454 .07846 Mdot
.07846 .08239 Mdot
.08239 .08239 Mdot
.09023 .09023 Mdot
.09023 .09023 Mdot
.09023 .08631 Mdot
.09415 .09415 Mdot
.08631 .09023 Mdot
.09023 .09807 Mdot
.09023 .09807 Mdot
.08631 .09023 Mdot
.07846 .08239 Mdot
.07846 .08631 Mdot
.07846 .08631 Mdot
.07062 .07846 Mdot
.0667 .07846 Mdot
.07062 .08239 Mdot
.07062 .08239 Mdot
.07062 .07454 Mdot
.07846 .08239 Mdot
.07846 .08631 Mdot
.08239 .09023 Mdot
.08239 .09023 Mdot
.08239 .09023 Mdot
.09023 .09807 Mdot
.09023 .09807 Mdot
.07846 .08239 Mdot
.07846 .08239 Mdot
.07454 .07454 Mdot
.07846 .07846 Mdot
.08631 .09023 Mdot
.09023 .09807 Mdot
.09023 .09807 Mdot
.08239 .09023 Mdot
.08631 .09415 Mdot
.08239 .09415 Mdot
.08239 .09415 Mdot
.08239 .09415 Mdot
.08239 .09415 Mdot
.09023 .09807 Mdot
.08631 .08239 Mdot
.08631 .08631 Mdot
.08631 .08631 Mdot
.08631 .08239 Mdot
.09023 .08631 Mdot
.08631 .08631 Mdot
.08631 .08631 Mdot
.08239 .08631 Mdot
.08631 .09023 Mdot
.07846 .08239 Mdot
.07846 .08239 Mdot
.07454 .07846 Mdot
.07454 .07062 Mdot
.08631 .08239 Mdot
.07846 .07846 Mdot
.07454 .07454 Mdot
.07454 .07454 Mdot
.07062 .07062 Mdot
.07454 .07454 Mdot
.06278 .0667 Mdot
.0667 .07062 Mdot
.07062 .07454 Mdot
.0667 .07062 Mdot
.07846 .07454 Mdot
.07454 .07454 Mdot
.07062 .07062 Mdot
.0667 .0667 Mdot
.07062 .07062 Mdot
.0667 .0667 Mdot
.0667 .05886 Mdot
.05494 .04709 Mdot
.05886 .05494 Mdot
.05494 .05494 Mdot
.05494 .05886 Mdot
.05886 .0667 Mdot
.06278 .07454 Mdot
.05494 .07062 Mdot
.05102 .06278 Mdot
.04709 .05886 Mdot
.04317 .05102 Mdot
.03925 .05102 Mdot
.04709 .05494 Mdot
.04317 .05102 Mdot
.04317 .04317 Mdot
.04317 .03925 Mdot
.05494 .05886 Mdot
.04709 .05494 Mdot
.04317 .05494 Mdot
.04317 .04709 Mdot
.05102 .04317 Mdot
.04709 .03533 Mdot
.04709 .03925 Mdot
.04317 .05102 Mdot
.03533 .03925 Mdot
.03533 .04317 Mdot
.03533 .04709 Mdot
.04709 .05886 Mdot
.00396 .00788 Mdot
.00396 .00788 Mdot
.00788 .00788 Mdot
.00396 .00788 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.0118 .00788 Mdot
.0118 .00788 Mdot
.0118 .00788 Mdot
.00788 .00396 Mdot
.00396 .00396 Mdot
.00788 .00396 Mdot
.01572 .00788 Mdot
.01572 .00788 Mdot
.01965 .00788 Mdot
.08631 .09807 Mdot
.10591 .1216 Mdot
.11768 .12944 Mdot
.11768 .12944 Mdot
.11376 .1216 Mdot
.11768 .13336 Mdot
.1216 .1412 Mdot
.11768 .13728 Mdot
.10591 .12552 Mdot
.10199 .1216 Mdot
.10983 .12944 Mdot
.11768 .1412 Mdot
.12552 .14513 Mdot
.1216 .1412 Mdot
.1216 .13728 Mdot
.11768 .12944 Mdot
.1216 .13336 Mdot
.11768 .12552 Mdot
.11768 .13336 Mdot
.1216 .1412 Mdot
.1216 .1412 Mdot
.11768 .1412 Mdot
.10199 .1216 Mdot
.10983 .12944 Mdot
.10591 .12944 Mdot
.10199 .12944 Mdot
.10591 .12944 Mdot
.11376 .13728 Mdot
.12552 .1412 Mdot
.12944 .1412 Mdot
.12552 .13728 Mdot
.12944 .14513 Mdot
.13336 .14905 Mdot
.13336 .15297 Mdot
.12944 .14905 Mdot
.11768 .1412 Mdot
.12552 .14905 Mdot
.13336 .16473 Mdot
.13728 .17257 Mdot
.14513 .1765 Mdot
.13728 .16865 Mdot
.14513 .16473 Mdot
.13728 .14905 Mdot
.13728 .15297 Mdot
.14905 .16473 Mdot
.1412 .16473 Mdot
.13728 .15689 Mdot
.1412 .16865 Mdot
.14905 .17257 Mdot
.15297 .1765 Mdot
.16473 .18434 Mdot
.15689 .17257 Mdot
.15689 .16865 Mdot
.1412 .15297 Mdot
.14513 .16081 Mdot
.14905 .17257 Mdot
.13728 .16865 Mdot
.14905 .18434 Mdot
.14905 .18042 Mdot
.15297 .1765 Mdot
.15689 .18434 Mdot
.14905 .16865 Mdot
.15689 .17257 Mdot
.15297 .16865 Mdot
.14905 .16865 Mdot
.14513 .16865 Mdot
.14905 .1765 Mdot
.14905 .17257 Mdot
.15297 .1765 Mdot
.14905 .18042 Mdot
.13336 .16473 Mdot
.1412 .16865 Mdot
.14905 .1765 Mdot
.14513 .17257 Mdot
.15297 .18434 Mdot
.14905 .17257 Mdot
.14513 .16865 Mdot
.16865 .1961 Mdot
.14905 .17257 Mdot
.14905 .1765 Mdot
.15689 .18434 Mdot
.17257 .19218 Mdot
.1412 .16081 Mdot
.16081 .18042 Mdot
.14905 .16473 Mdot
.15689 .17257 Mdot
.16081 .18042 Mdot
.1765 .19218 Mdot
.1765 .19218 Mdot
.17257 .18434 Mdot
.17257 .18434 Mdot
.17257 .18434 Mdot
.1765 .19218 Mdot
.16081 .1765 Mdot
.15297 .16865 Mdot
.14513 .16473 Mdot
.14905 .17257 Mdot
.14513 .17257 Mdot
.15689 .1765 Mdot
.16473 .18434 Mdot
.16473 .18434 Mdot
.16473 .18042 Mdot
.16473 .16865 Mdot
.15689 .16473 Mdot
.16081 .1765 Mdot
.16473 .1765 Mdot
.13728 .14513 Mdot
.13336 .1412 Mdot
.12944 .13728 Mdot
.1216 .12944 Mdot
.12944 .13336 Mdot
.13336 .1412 Mdot
.12552 .12944 Mdot
.12552 .13336 Mdot
.13336 .13728 Mdot
.12552 .13728 Mdot
.1216 .12552 Mdot
.10591 .11376 Mdot
.1412 .15297 Mdot
.12944 .13728 Mdot
.13336 .1412 Mdot
.13336 .14513 Mdot
.12944 .1412 Mdot
.10983 .12552 Mdot
.10591 .12552 Mdot
.11376 .12552 Mdot
.11376 .12552 Mdot
.10591 .11768 Mdot
.10199 .11376 Mdot
.10591 .11768 Mdot
.09807 .10983 Mdot
.10591 .11768 Mdot
.09807 .1216 Mdot
.09023 .11768 Mdot
.09023 .1216 Mdot
.11768 .15297 Mdot
.04709 .05494 Mdot
.05102 .04709 Mdot
.05102 .05102 Mdot
.03533 .04317 Mdot
.03533 .04317 Mdot
.07846 .10199 Mdot
.05102 .0667 Mdot
.00396 .00788 Mdot
.00788 .00788 Mdot
.00788 .01572 Mdot
.00396 .00788 Mdot
.00396 .00788 Mdot
.00788 .00788 Mdot
.00788 .00788 Mdot
.00396 .00788 Mdot
.00396 .01572 Mdot
.00396 .01572 Mdot
.00396 .0118 Mdot
.00396 .0118 Mdot
.00396 .0118 Mdot
.00396 .01572 Mdot
.00788 .01572 Mdot
.01572 .0118 Mdot
.01965 .0118 Mdot
.59215 .68234 Mdot
.61176 .70587 Mdot
.62352 .72547 Mdot
.62352 .72939 Mdot
.4902 .56862 Mdot
.12552 .1412 Mdot
.09807 .10591 Mdot
.09807 .11376 Mdot
.0667 .07846 Mdot
.05886 .07062 Mdot
.05886 .07062 Mdot
.07454 .09415 Mdot
.09415 .10983 Mdot
.09807 .11376 Mdot
.10199 .11768 Mdot
.10591 .11376 Mdot
.10983 .1216 Mdot
.10591 .1216 Mdot
.10983 .12552 Mdot
.11376 .12552 Mdot
.10199 .11376 Mdot
.10983 .12552 Mdot
.10983 .12552 Mdot
.1216 .13336 Mdot
.11768 .13728 Mdot
.11376 .13728 Mdot
.1216 .14513 Mdot
.11768 .13728 Mdot
.11768 .13728 Mdot
.1216 .1412 Mdot
.12552 .1412 Mdot
.12944 .14513 Mdot
.12944 .14513 Mdot
.12944 .15297 Mdot
.12552 .14513 Mdot
.11768 .13336 Mdot
.1216 .14513 Mdot
.10983 .1412 Mdot
.11768 .14905 Mdot
.13336 .15297 Mdot
.13728 .15297 Mdot
.1412 .15297 Mdot
.13336 .1412 Mdot
.13728 .14905 Mdot
.1412 .14905 Mdot
.1216 .12944 Mdot
.12552 .13336 Mdot
.12944 .1412 Mdot
.13336 .15689 Mdot
.13336 .15297 Mdot
.14513 .16473 Mdot
.14905 .16473 Mdot
.14905 .16081 Mdot
.1412 .14905 Mdot
.14905 .16081 Mdot
.1412 .16473 Mdot
.14513 .16865 Mdot
.15297 .1765 Mdot
.15689 .18042 Mdot
.16081 .18042 Mdot
.16081 .1765 Mdot
.16473 .18042 Mdot
.16081 .16473 Mdot
.16081 .17257 Mdot
.16081 .1765 Mdot
.16081 .18042 Mdot
.15297 .17257 Mdot
.16473 .18826 Mdot
.16081 .18434 Mdot
.15297 .1765 Mdot
.15297 .1765 Mdot
.16081 .18042 Mdot
.16473 .18434 Mdot
.16081 .18434 Mdot
.16081 .18826 Mdot
.14513 .16865 Mdot
.15689 .1765 Mdot
.16081 .18042 Mdot
.16865 .18826 Mdot
.16473 .18434 Mdot
.16081 .18042 Mdot
.15297 .17257 Mdot
.14513 .16473 Mdot
.14905 .16865 Mdot
.14905 .16865 Mdot
.14513 .15689 Mdot
.15297 .16081 Mdot
.15689 .16473 Mdot
.16865 .18042 Mdot
.17257 .18434 Mdot
.18042 .19218 Mdot
.18434 .1961 Mdot
.1765 .19218 Mdot
.16473 .18434 Mdot
.16865 .18826 Mdot
.17257 .1961 Mdot
.16473 .1961 Mdot
.18434 .21179 Mdot
.18826 .21179 Mdot
.18826 .20787 Mdot
.18042 .1961 Mdot
.19218 .21179 Mdot
.19218 .20787 Mdot
.18042 .1961 Mdot
.18434 .20394 Mdot
.18434 .1961 Mdot
.1765 .18434 Mdot
.16865 .18042 Mdot
.15689 .16865 Mdot
.16473 .18434 Mdot
.16865 .18042 Mdot
.18042 .18826 Mdot
.1765 .18434 Mdot
.15297 .16865 Mdot
.15297 .16473 Mdot
.14905 .15689 Mdot
.1412 .14905 Mdot
.14905 .16081 Mdot
.14513 .16081 Mdot
.1412 .15297 Mdot
.14513 .15297 Mdot
.15297 .16081 Mdot
.14513 .15689 Mdot
.14513 .16473 Mdot
.14513 .15689 Mdot
.13728 .14905 Mdot
.14513 .16081 Mdot
.1412 .15689 Mdot
.13336 .14905 Mdot
.13728 .15689 Mdot
.1216 .13728 Mdot
.12552 .1412 Mdot
.12552 .1412 Mdot
.12944 .1412 Mdot
.10591 .1216 Mdot
.10983 .13336 Mdot
.10591 .12552 Mdot
.09023 .10591 Mdot
.09023 .10983 Mdot
.09023 .10591 Mdot
.08239 .09807 Mdot
.09415 .11768 Mdot
.10199 .1216 Mdot
.08631 .10591 Mdot
.08239 .09807 Mdot
.08239 .09807 Mdot
.07454 .08631 Mdot
.07062 .08239 Mdot
.09023 .10199 Mdot
.09415 .10591 Mdot
.09023 .10591 Mdot
.07846 .09023 Mdot
.07846 .09807 Mdot
.07454 .09023 Mdot
.07846 .09415 Mdot
.07846 .09415 Mdot
.08239 .10199 Mdot
.08631 .10983 Mdot
.08239 .10199 Mdot
.08631 .10199 Mdot
.59215 .68234 Mdot
.61568 .71763 Mdot
.63136 .73332 Mdot
.62352 .72547 Mdot
.59999 .69802 Mdot
.25492 .29413 Mdot
.07062 .07846 Mdot
.09807 .11768 Mdot
.08631 .10199 Mdot
.07454 .09023 Mdot
.08239 .10199 Mdot
.08631 .10983 Mdot
.10199 .12552 Mdot
.10199 .12944 Mdot
.09415 .1216 Mdot
.09807 .11768 Mdot
.10591 .12944 Mdot
.11768 .1412 Mdot
.1216 .13728 Mdot
.1216 .13336 Mdot
.1216 .12944 Mdot
.1216 .1216 Mdot
.1216 .12944 Mdot
.12552 .13336 Mdot
.12944 .13728 Mdot
.12944 .1412 Mdot
.12552 .1412 Mdot
.10591 .12552 Mdot
.11376 .1412 Mdot
.11768 .14513 Mdot
.1216 .14905 Mdot
.1216 .15297 Mdot
.1216 .14905 Mdot
.1216 .15297 Mdot
.1216 .14513 Mdot
.12944 .14905 Mdot
.1412 .16473 Mdot
.1412 .16865 Mdot
.12944 .16081 Mdot
.13336 .16081 Mdot
.14513 .16473 Mdot
.14513 .16473 Mdot
.14513 .16081 Mdot
.1412 .14905 Mdot
.14513 .15297 Mdot
.1412 .14905 Mdot
.13336 .1412 Mdot
.1412 .15297 Mdot
.13728 .14905 Mdot
.13336 .15689 Mdot
.1412 .16473 Mdot
.15689 .1765 Mdot
.14905 .16865 Mdot
.1412 .15689 Mdot
.13728 .15689 Mdot
.14905 .17257 Mdot
.15297 .18042 Mdot
.16081 .18042 Mdot
.16865 .18826 Mdot
.16473 .1765 Mdot
.17257 .18826 Mdot
.1961 .20394 Mdot
.18826 .18826 Mdot
.1765 .18042 Mdot
.1961 .1961 Mdot
.18434 .19218 Mdot
.18042 .18826 Mdot
.18042 .18826 Mdot
.15689 .16473 Mdot
.14513 .15297 Mdot
.14513 .16081 Mdot
.14905 .16865 Mdot
.18826 .22355 Mdot
.16473 .20002 Mdot
.14513 .18434 Mdot
.14905 .1765 Mdot
.15297 .18042 Mdot
.16081 .18434 Mdot
.15297 .1765 Mdot
.15297 .1765 Mdot
.15689 .1765 Mdot
.16081 .18042 Mdot
.14905 .16865 Mdot
.14513 .15689 Mdot
.14905 .16081 Mdot
.14905 .16081 Mdot
.15297 .15689 Mdot
.16081 .16081 Mdot
.16081 .16081 Mdot
.16865 .18042 Mdot
.1765 .18826 Mdot
.18042 .1961 Mdot
.17257 .1961 Mdot
.17257 .1961 Mdot
.15297 .18042 Mdot
.15689 .19218 Mdot
.16865 .20002 Mdot
.1765 .20002 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.16865 .19218 Mdot
.18042 .20394 Mdot
.18434 .20394 Mdot
.18042 .1961 Mdot
.18042 .1961 Mdot
.20002 .20787 Mdot
.19218 .20394 Mdot
.17257 .18826 Mdot
.17257 .18434 Mdot
.16865 .18434 Mdot
.16865 .18434 Mdot
.18042 .19218 Mdot
.1765 .19218 Mdot
.16473 .18042 Mdot
.15689 .17257 Mdot
.15297 .16865 Mdot
.15297 .16081 Mdot
.14905 .16081 Mdot
.15297 .16865 Mdot
.15297 .17257 Mdot
.15689 .16865 Mdot
.15297 .16473 Mdot
.15297 .16081 Mdot
.14513 .14905 Mdot
.14513 .15297 Mdot
.15297 .16081 Mdot
.14905 .15297 Mdot
.13728 .1412 Mdot
.13336 .1412 Mdot
.13336 .14513 Mdot
.12552 .1412 Mdot
.1216 .1412 Mdot
.12552 .1412 Mdot
.12552 .14905 Mdot
.1216 .14905 Mdot
.1216 .14513 Mdot
.12944 .14905 Mdot
.11376 .13336 Mdot
.09415 .11376 Mdot
.09415 .1216 Mdot
.09023 .10983 Mdot
.08631 .10591 Mdot
.08239 .09807 Mdot
.09023 .10591 Mdot
.09415 .10983 Mdot
.09807 .10591 Mdot
.09023 .09415 Mdot
.09415 .10199 Mdot
.10199 .10199 Mdot
.09807 .10199 Mdot
.09807 .09807 Mdot
.08239 .09023 Mdot
.08239 .09023 Mdot
.08239 .09415 Mdot
.09023 .10199 Mdot
.08631 .09807 Mdot
.09023 .10591 Mdot
.09415 .11376 Mdot
.09023 .10983 Mdot
.08239 .09807 Mdot
.58039 .67842 Mdot
.62352 .73332 Mdot
.63528 .75292 Mdot
.62352 .72939 Mdot
.61568 .72547 Mdot
.42746 .50588 Mdot
.1216 .1412 Mdot
.10983 .12944 Mdot
.09023 .10591 Mdot
.07454 .09415 Mdot
.07846 .09807 Mdot
.08239 .10591 Mdot
.09023 .11376 Mdot
.10199 .12944 Mdot
.11376 .1412 Mdot
.11768 .1412 Mdot
.11768 .12944 Mdot
.12944 .1412 Mdot
.13336 .14513 Mdot
.13728 .13728 Mdot
.13728 .13728 Mdot
.13336 .13728 Mdot
.12944 .13336 Mdot
.1216 .12552 Mdot
.11768 .12552 Mdot
.10983 .12552 Mdot
.1216 .14513 Mdot
.10983 .13728 Mdot
.11376 .14513 Mdot
.11376 .14513 Mdot
.11768 .14905 Mdot
.1216 .15689 Mdot
.1216 .15297 Mdot
.1216 .15297 Mdot
.1216 .14905 Mdot
.13336 .16081 Mdot
.14513 .16473 Mdot
.13728 .15297 Mdot
.1412 .16081 Mdot
.14905 .16865 Mdot
.14905 .16081 Mdot
.14513 .15689 Mdot
.1412 .15689 Mdot
.14905 .16473 Mdot
.15297 .17257 Mdot
.14905 .17257 Mdot
.14905 .16473 Mdot
.14905 .16473 Mdot
.1412 .16081 Mdot
.14513 .16081 Mdot
.14513 .16081 Mdot
.15297 .16865 Mdot
.14513 .16473 Mdot
.13336 .15689 Mdot
.12944 .15297 Mdot
.14905 .18042 Mdot
.16081 .20002 Mdot
.1765 .20394 Mdot
.17257 .19218 Mdot
.18042 .18826 Mdot
.18042 .18434 Mdot
.18042 .18042 Mdot
.1961 .19218 Mdot
.18434 .18434 Mdot
.18826 .19218 Mdot
.18826 .19218 Mdot
.18826 .19218 Mdot
.19218 .20002 Mdot
.17257 .18434 Mdot
.16081 .17257 Mdot
.16473 .1765 Mdot
.15689 .17257 Mdot
.14905 .17257 Mdot
.14905 .18434 Mdot
.14905 .18434 Mdot
.1412 .17257 Mdot
.15297 .18826 Mdot
.15689 .18042 Mdot
.16473 .18434 Mdot
.16865 .19218 Mdot
.16865 .18434 Mdot
.16865 .18042 Mdot
.16081 .16865 Mdot
.15689 .17257 Mdot
.14513 .16081 Mdot
.14905 .15689 Mdot
.14905 .15297 Mdot
.16473 .1765 Mdot
.15689 .16865 Mdot
.16473 .1765 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.16865 .19218 Mdot
.16473 .1961 Mdot
.16865 .20002 Mdot
.1765 .20394 Mdot
.18042 .20787 Mdot
.19218 .21571 Mdot
.18434 .20394 Mdot
.16865 .18434 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.18434 .20002 Mdot
.18434 .20394 Mdot
.18434 .20002 Mdot
.18434 .20002 Mdot
.19218 .20787 Mdot
.19218 .20787 Mdot
.18826 .20394 Mdot
.18434 .20787 Mdot
.18042 .20394 Mdot
.18042 .20002 Mdot
.1765 .1961 Mdot
.18042 .20394 Mdot
.18042 .20002 Mdot
.1765 .19218 Mdot
.16865 .18042 Mdot
.16081 .17257 Mdot
.16081 .18042 Mdot
.16473 .18434 Mdot
.16473 .18042 Mdot
.15689 .17257 Mdot
.14905 .16081 Mdot
.15689 .16865 Mdot
.14905 .16081 Mdot
.14513 .15297 Mdot
.14513 .14905 Mdot
.13728 .1412 Mdot
.13728 .14513 Mdot
.1412 .15297 Mdot
.12552 .15297 Mdot
.12552 .15297 Mdot
.12552 .15297 Mdot
.1412 .16473 Mdot
.13336 .15689 Mdot
.13336 .15689 Mdot
.12552 .14513 Mdot
.11768 .13728 Mdot
.10591 .13336 Mdot
.09807 .1216 Mdot
.09023 .11376 Mdot
.09023 .11376 Mdot
.09415 .1216 Mdot
.09807 .12552 Mdot
.10591 .1216 Mdot
.10591 .11376 Mdot
.10591 .10199 Mdot
.10591 .10591 Mdot
.11376 .1216 Mdot
.10983 .11768 Mdot
.10983 .11376 Mdot
.10199 .11376 Mdot
.09023 .10591 Mdot
.09415 .10591 Mdot
.09807 .11376 Mdot
.09023 .10591 Mdot
.09415 .11376 Mdot
.10199 .12552 Mdot
.09023 .10591 Mdot
.09415 .10199 Mdot
.45491 .5098 Mdot
.59215 .68234 Mdot
.60391 .70979 Mdot
.6196 .73332 Mdot
.6196 .73724 Mdot
.5647 .6745 Mdot
.26276 .31766 Mdot
.0667 .08631 Mdot
.09807 .11768 Mdot
.06278 .07846 Mdot
.05886 .07454 Mdot
.07062 .08631 Mdot
.08239 .09807 Mdot
.09415 .11768 Mdot
.10199 .12944 Mdot
.10983 .13336 Mdot
.11768 .13336 Mdot
.12944 .14513 Mdot
.13336 .14905 Mdot
.14513 .16473 Mdot
.13728 .15297 Mdot
.13728 .14513 Mdot
.12944 .1412 Mdot
.12944 .1412 Mdot
.12944 .1412 Mdot
.1216 .13728 Mdot
.11376 .13336 Mdot
.11768 .13728 Mdot
.1216 .14513 Mdot
.11376 .13728 Mdot
.1216 .14905 Mdot
.1216 .15297 Mdot
.13728 .16081 Mdot
.14905 .16865 Mdot
.14513 .16473 Mdot
.12552 .15297 Mdot
.14513 .17257 Mdot
.14513 .16473 Mdot
.1412 .16473 Mdot
.15689 .1765 Mdot
.15689 .17257 Mdot
.15689 .17257 Mdot
.15689 .17257 Mdot
.15689 .17257 Mdot
.14513 .16081 Mdot
.15689 .17257 Mdot
.15689 .17257 Mdot
.15297 .16473 Mdot
.13728 .14905 Mdot
.13336 .14905 Mdot
.1216 .14513 Mdot
.12552 .14905 Mdot
.12944 .15297 Mdot
.12944 .16081 Mdot
.14513 .16865 Mdot
.16081 .18434 Mdot
.15297 .18434 Mdot
.16081 .18826 Mdot
.1765 .20002 Mdot
.18042 .20394 Mdot
.18042 .20002 Mdot
.18042 .18826 Mdot
.18826 .20002 Mdot
.1765 .18826 Mdot
.18434 .20394 Mdot
.18434 .20394 Mdot
.18434 .20002 Mdot
.19218 .20002 Mdot
.18826 .19218 Mdot
.18434 .18826 Mdot
.18434 .18826 Mdot
.16081 .17257 Mdot
.15689 .18042 Mdot
.15689 .18434 Mdot
.14905 .1765 Mdot
.14905 .17257 Mdot
.15689 .1765 Mdot
.16865 .18826 Mdot
.16865 .19218 Mdot
.17257 .20002 Mdot
.16081 .18826 Mdot
.16081 .18042 Mdot
.15689 .1765 Mdot
.15297 .1765 Mdot
.14513 .16865 Mdot
.14513 .16865 Mdot
.14513 .16081 Mdot
.16081 .1765 Mdot
.16865 .18434 Mdot
.17257 .18042 Mdot
.17257 .18826 Mdot
.17257 .18826 Mdot
.16865 .18826 Mdot
.18042 .20787 Mdot
.1765 .20394 Mdot
.18826 .21571 Mdot
.20002 .22747 Mdot
.1961 .21571 Mdot
.19218 .20787 Mdot
.18434 .1961 Mdot
.18826 .20394 Mdot
.1765 .19218 Mdot
.1765 .20002 Mdot
.1765 .20002 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.1765 .20394 Mdot
.18042 .20394 Mdot
.18042 .20394 Mdot
.18042 .20394 Mdot
.1765 .20002 Mdot
.18434 .21179 Mdot
.18826 .21179 Mdot
.19218 .20787 Mdot
.1961 .20002 Mdot
.19218 .1961 Mdot
.18826 .1961 Mdot
.1765 .18826 Mdot
.16473 .18042 Mdot
.15297 .1765 Mdot
.16473 .18826 Mdot
.14905 .1765 Mdot
.14905 .18042 Mdot
.15297 .18042 Mdot
.15689 .1765 Mdot
.15297 .16865 Mdot
.1412 .15297 Mdot
.1412 .14905 Mdot
.13728 .14905 Mdot
.13728 .14905 Mdot
.13336 .14513 Mdot
.13728 .15689 Mdot
.13728 .15689 Mdot
.13728 .15689 Mdot
.12944 .14513 Mdot
.11768 .12944 Mdot
.1216 .13336 Mdot
.11376 .12552 Mdot
.10199 .1216 Mdot
.10199 .12552 Mdot
.09807 .1216 Mdot
.09023 .11376 Mdot
.09023 .11376 Mdot
.09415 .11768 Mdot
.09023 .11376 Mdot
.09415 .11376 Mdot
.09415 .10983 Mdot
.09415 .10983 Mdot
.10591 .12552 Mdot
.10983 .12552 Mdot
.09807 .1216 Mdot
.10591 .12944 Mdot
.10591 .12944 Mdot
.10199 .12552 Mdot
.09807 .1216 Mdot
.09415 .11768 Mdot
.09023 .11768 Mdot
.09415 .11768 Mdot
.09415 .11376 Mdot
.08239 .09415 Mdot
.15689 .1765 Mdot
.25884 .29806 Mdot
.34119 .39217 Mdot
.47451 .55686 Mdot
.52157 .62352 Mdot
.58431 .70587 Mdot
.38824 .47451 Mdot
.05886 .07062 Mdot
.07062 .08631 Mdot
.05886 .07846 Mdot
.05102 .06278 Mdot
.05494 .06278 Mdot
.07454 .09023 Mdot
.08631 .10983 Mdot
.09415 .11768 Mdot
.10199 .12944 Mdot
.10983 .13336 Mdot
.12552 .14905 Mdot
.12552 .15297 Mdot
.13728 .15297 Mdot
.13336 .14905 Mdot
.12944 .14513 Mdot
.13728 .14513 Mdot
.14513 .16081 Mdot
.1412 .15689 Mdot
.14513 .16081 Mdot
.13336 .14513 Mdot
.13728 .14905 Mdot
.1412 .15689 Mdot
.13728 .15297 Mdot
.13728 .15689 Mdot
.13336 .15689 Mdot
.14513 .16081 Mdot
.13728 .14905 Mdot
.13336 .15297 Mdot
.13336 .16081 Mdot
.13336 .16081 Mdot
.13336 .16081 Mdot
.1412 .16865 Mdot
.13728 .16473 Mdot
.14513 .16473 Mdot
.14905 .17257 Mdot
.16473 .18434 Mdot
.16865 .18826 Mdot
.15689 .1765 Mdot
.14513 .16081 Mdot
.15297 .16473 Mdot
.14905 .16081 Mdot
.1412 .15689 Mdot
.13728 .16081 Mdot
.13728 .16081 Mdot
.13336 .16081 Mdot
.14905 .18042 Mdot
.13728 .16473 Mdot
.1412 .17257 Mdot
.14513 .17257 Mdot
.15689 .18826 Mdot
.15689 .1961 Mdot
.15297 .18826 Mdot
.17257 .20002 Mdot
.1765 .20002 Mdot
.17257 .19218 Mdot
.1765 .20002 Mdot
.1765 .1961 Mdot
.18042 .20787 Mdot
.18042 .20002 Mdot
.1961 .21571 Mdot
.20002 .21179 Mdot
.20002 .20394 Mdot
.20002 .20002 Mdot
.18042 .18042 Mdot
.18826 .1961 Mdot
.17257 .19218 Mdot
.16081 .18434 Mdot
.14905 .17257 Mdot
.1412 .1765 Mdot
.14905 .18042 Mdot
.1412 .17257 Mdot
.14905 .18434 Mdot
.14513 .18042 Mdot
.15689 .19218 Mdot
.15297 .18042 Mdot
.15689 .18042 Mdot
.15689 .1765 Mdot
.15689 .18042 Mdot
.15297 .17257 Mdot
.14905 .15689 Mdot
.16865 .17257 Mdot
.18042 .18434 Mdot
.17257 .1765 Mdot
.1765 .18042 Mdot
.18042 .18826 Mdot
.16865 .18434 Mdot
.17257 .1961 Mdot
.17257 .20002 Mdot
.18042 .20394 Mdot
.19218 .21571 Mdot
.19218 .21179 Mdot
.20394 .21571 Mdot
.1961 .20787 Mdot
.19218 .21179 Mdot
.18434 .20394 Mdot
.1765 .19218 Mdot
.17257 .19218 Mdot
.18042 .20002 Mdot
.17257 .1961 Mdot
.1765 .20002 Mdot
.19218 .21963 Mdot
.19218 .21571 Mdot
.18434 .20787 Mdot
.17257 .19218 Mdot
.18826 .21179 Mdot
.1961 .21179 Mdot
.20394 .20787 Mdot
.20002 .20394 Mdot
.18826 .19218 Mdot
.16473 .18042 Mdot
.1765 .1961 Mdot
.15297 .17257 Mdot
.15689 .1765 Mdot
.15689 .18042 Mdot
.14513 .17257 Mdot
.14513 .1765 Mdot
.13728 .16865 Mdot
.14513 .16865 Mdot
.15689 .1765 Mdot
.15297 .16865 Mdot
.14513 .15297 Mdot
.1412 .14905 Mdot
.14513 .15689 Mdot
.13728 .14905 Mdot
.1412 .15689 Mdot
.13336 .14905 Mdot
.12944 .14513 Mdot
.10983 .13336 Mdot
.11376 .13728 Mdot
.11768 .13728 Mdot
.10591 .12552 Mdot
.10199 .12552 Mdot
.09807 .12552 Mdot
.09415 .11376 Mdot
.09415 .10983 Mdot
.07454 .09023 Mdot
.09023 .11376 Mdot
.07846 .09807 Mdot
.07454 .09415 Mdot
.07454 .08631 Mdot
.09023 .10591 Mdot
.09415 .11376 Mdot
.09807 .11768 Mdot
.09807 .1216 Mdot
.11376 .1412 Mdot
.10591 .13336 Mdot
.10199 .12944 Mdot
.09807 .1216 Mdot
.09807 .11768 Mdot
.08631 .10591 Mdot
.08631 .09807 Mdot
.09023 .09807 Mdot
.07846 .08631 Mdot
.09807 .1216 Mdot
.12552 .14905 Mdot
.1216 .1412 Mdot
.13336 .16081 Mdot
.21963 .26276 Mdot
.32943 .39609 Mdot
.30198 .36472 Mdot
.13336 .14905 Mdot
.13728 .15689 Mdot
.11376 .13336 Mdot
.09023 .10983 Mdot
.07846 .09415 Mdot
.09415 .11768 Mdot
.09415 .11768 Mdot
.09415 .1216 Mdot
.10983 .13728 Mdot
.1216 .15297 Mdot
.12552 .14905 Mdot
.13728 .15689 Mdot
.13728 .15689 Mdot
.13728 .15689 Mdot
.13728 .14905 Mdot
.1412 .14513 Mdot
.15297 .15297 Mdot
.15297 .16081 Mdot
.15297 .16473 Mdot
.14513 .16081 Mdot
.14513 .14905 Mdot
.1412 .14513 Mdot
.12552 .1412 Mdot
.13728 .15297 Mdot
.13728 .14905 Mdot
.13728 .14905 Mdot
.1412 .16081 Mdot
.1412 .15689 Mdot
.14905 .16473 Mdot
.14513 .16865 Mdot
.13728 .16081 Mdot
.14513 .17257 Mdot
.15297 .18042 Mdot
.15689 .18042 Mdot
.15297 .18042 Mdot
.14905 .18042 Mdot
.16081 .18826 Mdot
.16473 .18434 Mdot
.15297 .16865 Mdot
.15689 .16865 Mdot
.16865 .18434 Mdot
.16081 .1765 Mdot
.16865 .18042 Mdot
.16473 .18434 Mdot
.16473 .18826 Mdot
.15689 .18042 Mdot
.15689 .18042 Mdot
.16081 .18434 Mdot
.14905 .18434 Mdot
.15297 .18826 Mdot
.1412 .17257 Mdot
.16081 .18826 Mdot
.17257 .1961 Mdot
.17257 .18826 Mdot
.18042 .18826 Mdot
.18434 .1961 Mdot
.18434 .20002 Mdot
.1765 .1961 Mdot
.18042 .20394 Mdot
.19218 .21179 Mdot
.19218 .1961 Mdot
.1961 .20002 Mdot
.18826 .19218 Mdot
.18434 .19218 Mdot
.18042 .19218 Mdot
.16473 .18042 Mdot
.16473 .18826 Mdot
.16081 .19218 Mdot
.15297 .18434 Mdot
.14513 .1765 Mdot
.12552 .15689 Mdot
.12552 .15689 Mdot
.1412 .17257 Mdot
.14513 .17257 Mdot
.16081 .18434 Mdot
.16081 .1765 Mdot
.16081 .1765 Mdot
.15689 .17257 Mdot
.15297 .16865 Mdot
.14905 .16473 Mdot
.16865 .18042 Mdot
.1765 .19218 Mdot
.17257 .18826 Mdot
.16865 .18042 Mdot
.1765 .18826 Mdot
.17257 .18826 Mdot
.1765 .1961 Mdot
.1765 .20002 Mdot
.18042 .20002 Mdot
.18042 .20002 Mdot
.1961 .21571 Mdot
.20394 .22747 Mdot
.1961 .21179 Mdot
.19218 .21179 Mdot
.19218 .21571 Mdot
.18434 .21179 Mdot
.1765 .20394 Mdot
.1765 .20394 Mdot
.18434 .21179 Mdot
.19218 .22355 Mdot
.18434 .21963 Mdot
.18434 .21571 Mdot
.19218 .22355 Mdot
.18434 .20787 Mdot
.18434 .20002 Mdot
.20002 .21179 Mdot
.20787 .21571 Mdot
.20002 .20394 Mdot
.19218 .1961 Mdot
.18042 .18826 Mdot
.1765 .18826 Mdot
.16865 .18434 Mdot
.17257 .19218 Mdot
.17257 .19218 Mdot
.16081 .18042 Mdot
.16473 .18434 Mdot
.16473 .18434 Mdot
.15689 .1765 Mdot
.16081 .18042 Mdot
.17257 .19218 Mdot
.16081 .18042 Mdot
.16081 .18434 Mdot
.1412 .16473 Mdot
.1412 .15689 Mdot
.1412 .16081 Mdot
.12944 .14513 Mdot
.1216 .12944 Mdot
.12944 .1412 Mdot
.12552 .14513 Mdot
.11768 .13336 Mdot
.11768 .13336 Mdot
.10983 .12944 Mdot
.10199 .12552 Mdot
.09807 .1216 Mdot
.09807 .1216 Mdot
.09807 .10591 Mdot
.09807 .10591 Mdot
.10199 .10591 Mdot
.09415 .10199 Mdot
.09023 .09807 Mdot
.09807 .10591 Mdot
.10983 .1216 Mdot
.10591 .1216 Mdot
.08631 .10591 Mdot
.10199 .1216 Mdot
.10591 .12552 Mdot
.10199 .1216 Mdot
.09415 .10591 Mdot
.08239 .09807 Mdot
.08239 .09807 Mdot
.07846 .09415 Mdot
.07454 .08239 Mdot
.05886 .06278 Mdot
.05886 .07454 Mdot
.07454 .09415 Mdot
.08239 .09807 Mdot
.08631 .09807 Mdot
.11376 .12944 Mdot
.12944 .15297 Mdot
.12944 .16081 Mdot
.11768 .13728 Mdot
.11376 .13728 Mdot
.10591 .12944 Mdot
.09807 .12552 Mdot
.09023 .11768 Mdot
.08631 .11376 Mdot
.09415 .1216 Mdot
.10199 .12552 Mdot
.09023 .11376 Mdot
.10591 .13336 Mdot
.11768 .14513 Mdot
.13728 .15297 Mdot
.14513 .16473 Mdot
.1412 .16081 Mdot
.13336 .14905 Mdot
.13728 .14905 Mdot
.14905 .16473 Mdot
.15297 .16865 Mdot
.15297 .16473 Mdot
.14905 .16473 Mdot
.14905 .15689 Mdot
.15297 .16865 Mdot
.14905 .16865 Mdot
.13728 .15689 Mdot
.13728 .14905 Mdot
.1412 .15689 Mdot
.14905 .16865 Mdot
.1412 .15689 Mdot
.14905 .16473 Mdot
.15297 .17257 Mdot
.15297 .17257 Mdot
.15297 .1765 Mdot
.15689 .17257 Mdot
.14513 .16473 Mdot
.13728 .15689 Mdot
.15689 .1765 Mdot
.16473 .18434 Mdot
.16865 .19218 Mdot
.16081 .18042 Mdot
.16473 .18042 Mdot
.16473 .17257 Mdot
.17257 .18434 Mdot
.16473 .1765 Mdot
.16473 .1765 Mdot
.16865 .18826 Mdot
.17257 .18826 Mdot
.16865 .18826 Mdot
.16081 .18042 Mdot
.14905 .16865 Mdot
.15297 .18042 Mdot
.16473 .18826 Mdot
.16473 .19218 Mdot
.18434 .20787 Mdot
.18434 .20394 Mdot
.18826 .20394 Mdot
.1961 .20002 Mdot
.18434 .18826 Mdot
.18826 .19218 Mdot
.1961 .20787 Mdot
.20394 .21571 Mdot
.1961 .20394 Mdot
.20787 .21571 Mdot
.18434 .19218 Mdot
.1765 .18434 Mdot
.18434 .20002 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.16865 .1961 Mdot
.16473 .1961 Mdot
.16081 .1961 Mdot
.14905 .18042 Mdot
.13728 .17257 Mdot
.1412 .17257 Mdot
.15297 .18042 Mdot
.14905 .16865 Mdot
.15297 .17257 Mdot
.16081 .18042 Mdot
.16473 .18434 Mdot
.14905 .17257 Mdot
.13728 .16081 Mdot
.14905 .1765 Mdot
.16473 .1961 Mdot
.16473 .18434 Mdot
.17257 .19218 Mdot
.1765 .1961 Mdot
.18042 .1961 Mdot
.1765 .20002 Mdot
.1765 .19218 Mdot
.18042 .20002 Mdot
.18434 .20394 Mdot
.18826 .21571 Mdot
.1961 .21571 Mdot
.20394 .21963 Mdot
.20787 .22747 Mdot
.1961 .22355 Mdot
.18042 .20394 Mdot
.17257 .1961 Mdot
.1765 .20394 Mdot
.18434 .21179 Mdot
.18434 .21179 Mdot
.18826 .21571 Mdot
.19218 .21963 Mdot
.19218 .21571 Mdot
.1961 .20787 Mdot
.19218 .1961 Mdot
.1961 .1961 Mdot
.1961 .20394 Mdot
.19218 .1961 Mdot
.1961 .20002 Mdot
.20394 .20787 Mdot
.18042 .18826 Mdot
.17257 .18434 Mdot
.17257 .18826 Mdot
.16865 .18826 Mdot
.17257 .18826 Mdot
.16473 .18042 Mdot
.15689 .1765 Mdot
.1765 .19218 Mdot
.16473 .18826 Mdot
.16473 .18434 Mdot
.16865 .18826 Mdot
.16865 .1961 Mdot
.15297 .18042 Mdot
.13728 .16865 Mdot
.1412 .15689 Mdot
.14513 .16081 Mdot
.13336 .14513 Mdot
.13336 .1412 Mdot
.12944 .13728 Mdot
.13336 .1412 Mdot
.12944 .13728 Mdot
.12552 .13728 Mdot
.11768 .12944 Mdot
.11768 .12944 Mdot
.11376 .12552 Mdot
.11376 .13336 Mdot
.10199 .10983 Mdot
.09415 .10199 Mdot
.09807 .10199 Mdot
.09415 .09807 Mdot
.09415 .10199 Mdot
.10591 .11376 Mdot
.10591 .11376 Mdot
.10199 .10983 Mdot
.10983 .1216 Mdot
.09807 .10983 Mdot
.09415 .10591 Mdot
.09415 .10199 Mdot
.09415 .10199 Mdot
.08239 .09415 Mdot
.07062 .08631 Mdot
.06278 .0667 Mdot
.0667 .07454 Mdot
.05494 .07062 Mdot
.0667 .07846 Mdot
.0667 .07062 Mdot
.08631 .09415 Mdot
.09023 .09807 Mdot
.10591 .12552 Mdot
.10983 .13336 Mdot
.10591 .13336 Mdot
.10199 .12944 Mdot
.10591 .12944 Mdot
.10591 .13336 Mdot
.10199 .12944 Mdot
.10199 .12552 Mdot
.10199 .12944 Mdot
.09807 .1216 Mdot
.09023 .11768 Mdot
.10983 .13728 Mdot
.11768 .1412 Mdot
.1216 .14513 Mdot
.13336 .14905 Mdot
.12552 .1412 Mdot
.13728 .14905 Mdot
.13728 .14905 Mdot
.13728 .14905 Mdot
.14513 .15297 Mdot
.14513 .15689 Mdot
.14905 .16473 Mdot
.14513 .16081 Mdot
.15297 .1765 Mdot
.14905 .17257 Mdot
.14513 .17257 Mdot
.14513 .16865 Mdot
.13728 .16081 Mdot
.13336 .15689 Mdot
.14905 .16865 Mdot
.14905 .16081 Mdot
.15689 .1765 Mdot
.15297 .16865 Mdot
.14905 .16473 Mdot
.15689 .1765 Mdot
.15297 .17257 Mdot
.15297 .16473 Mdot
.16865 .18042 Mdot
.16473 .18042 Mdot
.17257 .19218 Mdot
.16865 .18826 Mdot
.17257 .19218 Mdot
.16473 .18434 Mdot
.16473 .18434 Mdot
.16865 .18826 Mdot
.17257 .1961 Mdot
.16081 .18042 Mdot
.16081 .18042 Mdot
.16865 .18826 Mdot
.16081 .18042 Mdot
.15297 .18042 Mdot
.16865 .18826 Mdot
.17257 .1961 Mdot
.17257 .19218 Mdot
.1765 .20002 Mdot
.18434 .20002 Mdot
.19218 .20787 Mdot
.1765 .18434 Mdot
.18434 .19218 Mdot
.19218 .20002 Mdot
.20002 .21571 Mdot
.20002 .21571 Mdot
.20002 .21571 Mdot
.20787 .22355 Mdot
.20394 .22355 Mdot
.19218 .21179 Mdot
.18434 .20787 Mdot
.18434 .20787 Mdot
.18042 .20394 Mdot
.18042 .21179 Mdot
.17257 .20787 Mdot
.1765 .20394 Mdot
.16473 .1961 Mdot
.16865 .20394 Mdot
.18042 .20787 Mdot
.17257 .1961 Mdot
.16473 .18434 Mdot
.15689 .1765 Mdot
.16865 .18826 Mdot
.16865 .18826 Mdot
.16473 .18826 Mdot
.16473 .19218 Mdot
.16081 .20002 Mdot
.16081 .20394 Mdot
.15297 .18826 Mdot
.15689 .19218 Mdot
.16865 .20394 Mdot
.18042 .20394 Mdot
.18042 .20394 Mdot
.18434 .20002 Mdot
.18826 .20787 Mdot
.18434 .20394 Mdot
.18042 .20394 Mdot
.18042 .19218 Mdot
.20394 .21179 Mdot
.20787 .21963 Mdot
.21179 .23139 Mdot
.20394 .22747 Mdot
.1961 .22355 Mdot
.18826 .21571 Mdot
.18434 .21179 Mdot
.18826 .21571 Mdot
.19218 .21963 Mdot
.20394 .23139 Mdot
.20394 .22747 Mdot
.19218 .21571 Mdot
.1961 .21179 Mdot
.20787 .21571 Mdot
.19218 .1961 Mdot
.18434 .18434 Mdot
.18042 .18042 Mdot
.18826 .1961 Mdot
.18826 .19218 Mdot
.18434 .18826 Mdot
.1765 .19218 Mdot
.1765 .19218 Mdot
.18042 .20002 Mdot
.1765 .20002 Mdot
.1765 .20002 Mdot
.17257 .18826 Mdot
.16473 .18434 Mdot
.17257 .19218 Mdot
.1765 .19218 Mdot
.16473 .18434 Mdot
.16473 .1961 Mdot
.15689 .18826 Mdot
.13728 .16473 Mdot
.13336 .16473 Mdot
.12944 .15297 Mdot
.13336 .15297 Mdot
.1412 .15297 Mdot
.14513 .16081 Mdot
.13336 .1412 Mdot
.13336 .14513 Mdot
.12944 .13728 Mdot
.1216 .12944 Mdot
.12552 .13336 Mdot
.12944 .1412 Mdot
.11768 .12944 Mdot
.11768 .11376 Mdot
.11768 .11768 Mdot
.10983 .11768 Mdot
.10983 .11768 Mdot
.10199 .10983 Mdot
.10591 .11376 Mdot
.10983 .1216 Mdot
.10591 .11768 Mdot
.09023 .10983 Mdot
.09023 .10591 Mdot
.09023 .10591 Mdot
.09807 .11768 Mdot
.0667 .08239 Mdot
.0667 .08239 Mdot
.06278 .07846 Mdot
.07062 .08631 Mdot
.03141 .03925 Mdot
.04317 .05494 Mdot
.04709 .05886 Mdot
.07846 .08239 Mdot
.09415 .10199 Mdot
.09415 .10983 Mdot
.09415 .11376 Mdot
.09415 .11376 Mdot
.10983 .12944 Mdot
.1216 .13728 Mdot
.10983 .12944 Mdot
.1216 .13728 Mdot
.11376 .12944 Mdot
.09807 .1216 Mdot
.09415 .11376 Mdot
.10199 .12552 Mdot
.10983 .13728 Mdot
.11768 .14905 Mdot
.11768 .15297 Mdot
.12944 .16081 Mdot
.12944 .15297 Mdot
.13336 .15689 Mdot
.14905 .16473 Mdot
.14513 .15689 Mdot
.15297 .16473 Mdot
.15297 .16081 Mdot
.15689 .17257 Mdot
.15689 .1765 Mdot
.15297 .1765 Mdot
.14513 .17257 Mdot
.14905 .1765 Mdot
.14905 .18434 Mdot
.14905 .18042 Mdot
.14513 .16865 Mdot
.14905 .1765 Mdot
.14905 .1765 Mdot
.16473 .18434 Mdot
.15689 .17257 Mdot
.14905 .16081 Mdot
.15689 .16865 Mdot
.15297 .16865 Mdot
.15689 .16473 Mdot
.1765 .18042 Mdot
.17257 .18042 Mdot
.16865 .18826 Mdot
.17257 .18826 Mdot
.18042 .20394 Mdot
.18826 .21179 Mdot
.18434 .20787 Mdot
.16865 .18826 Mdot
.15689 .18826 Mdot
.16081 .18826 Mdot
.16865 .18826 Mdot
.16865 .19218 Mdot
.17257 .1961 Mdot
.16473 .1961 Mdot
.16473 .19218 Mdot
.16473 .19218 Mdot
.15689 .18434 Mdot
.17257 .1961 Mdot
.17257 .19218 Mdot
.17257 .19218 Mdot
.1765 .1961 Mdot
.17257 .18826 Mdot
.1765 .19218 Mdot
.18826 .20787 Mdot
.1961 .22355 Mdot
.20002 .22355 Mdot
.20002 .22355 Mdot
.1961 .21963 Mdot
.18826 .21179 Mdot
.1961 .21963 Mdot
.1765 .20002 Mdot
.17257 .1961 Mdot
.16473 .1961 Mdot
.16865 .20394 Mdot
.16865 .20394 Mdot
.16865 .20394 Mdot
.16865 .20394 Mdot
.18434 .21963 Mdot
.18434 .21179 Mdot
.19218 .21179 Mdot
.18434 .20002 Mdot
.18042 .18434 Mdot
.17257 .18434 Mdot
.17257 .18826 Mdot
.16865 .19218 Mdot
.16473 .1961 Mdot
.16081 .20002 Mdot
.16081 .20002 Mdot
.16081 .20002 Mdot
.17257 .20394 Mdot
.18042 .20002 Mdot
.18826 .20787 Mdot
.19218 .21179 Mdot
.20002 .22355 Mdot
.20002 .21963 Mdot
.19218 .21179 Mdot
.19218 .21179 Mdot
.18826 .20787 Mdot
.19218 .20787 Mdot
.20394 .22355 Mdot
.18826 .21179 Mdot
.18826 .20394 Mdot
.1961 .21571 Mdot
.19218 .21179 Mdot
.19218 .21963 Mdot
.18434 .21179 Mdot
.19218 .21963 Mdot
.18434 .21179 Mdot
.18826 .21179 Mdot
.19218 .21571 Mdot
.1961 .21571 Mdot
.1961 .20787 Mdot
.18826 .19218 Mdot
.18434 .18434 Mdot
.1765 .1765 Mdot
.1765 .18042 Mdot
.16473 .17257 Mdot
.16473 .18042 Mdot
.16473 .18434 Mdot
.16081 .18042 Mdot
.17257 .19218 Mdot
.1765 .1961 Mdot
.17257 .18434 Mdot
.16865 .18042 Mdot
.16081 .17257 Mdot
.17257 .18826 Mdot
.17257 .18826 Mdot
.16081 .18042 Mdot
.16081 .18826 Mdot
.1216 .14905 Mdot
.12552 .15689 Mdot
.1216 .15297 Mdot
.11768 .14905 Mdot
.12552 .15297 Mdot
.13728 .15689 Mdot
.14513 .16473 Mdot
.13336 .15297 Mdot
.11768 .13336 Mdot
.10591 .1216 Mdot
.10983 .12552 Mdot
.12944 .1412 Mdot
.11768 .12552 Mdot
.11376 .1216 Mdot
.11768 .12944 Mdot
.11376 .1216 Mdot
.11376 .1216 Mdot
.11376 .12552 Mdot
.11768 .12552 Mdot
.10983 .1216 Mdot
.10591 .11376 Mdot
.10983 .1216 Mdot
.10199 .10983 Mdot
.10199 .11376 Mdot
.10199 .11768 Mdot
.09807 .10983 Mdot
.07846 .10199 Mdot
.07846 .09807 Mdot
.07454 .09023 Mdot
.02749 .03925 Mdot
.03925 .05102 Mdot
.0667 .08631 Mdot
.09023 .10983 Mdot
.11376 .13728 Mdot
.10591 .1216 Mdot
.08239 .08631 Mdot
.08239 .08239 Mdot
.09807 .10591 Mdot
.08631 .09415 Mdot
.09023 .10199 Mdot
.09415 .11768 Mdot
.10199 .12552 Mdot
.10983 .13728 Mdot
.10983 .13728 Mdot
.10983 .1412 Mdot
.10591 .13728 Mdot
.11768 .15297 Mdot
.11768 .15689 Mdot
.1216 .15689 Mdot
.1216 .15297 Mdot
.12552 .15297 Mdot
.14513 .16473 Mdot
.14905 .16473 Mdot
.14513 .16081 Mdot
.15297 .17257 Mdot
.16865 .18434 Mdot
.16473 .18042 Mdot
.16081 .18434 Mdot
.14905 .17257 Mdot
.14905 .18042 Mdot
.15297 .18434 Mdot
.15689 .18826 Mdot
.16081 .18826 Mdot
.15689 .18434 Mdot
.14513 .17257 Mdot
.15689 .18434 Mdot
.15689 .1765 Mdot
.15689 .1765 Mdot
.16473 .18434 Mdot
.16473 .18434 Mdot
.15689 .17257 Mdot
.16473 .18042 Mdot
.1765 .19218 Mdot
.18434 .20394 Mdot
.18042 .1961 Mdot
.17257 .19218 Mdot
.18042 .20002 Mdot
.1765 .19218 Mdot
.1765 .19218 Mdot
.16865 .18826 Mdot
.17257 .19218 Mdot
.1765 .1961 Mdot
.17257 .19218 Mdot
.16473 .18434 Mdot
.16865 .19218 Mdot
.17257 .20002 Mdot
.1765 .21179 Mdot
.16865 .20394 Mdot
.16473 .20002 Mdot
.15689 .18826 Mdot
.16473 .1961 Mdot
.1765 .20394 Mdot
.17257 .20002 Mdot
.1765 .20002 Mdot
.18042 .20394 Mdot
.19218 .21963 Mdot
.19218 .21963 Mdot
.1961 .22747 Mdot
.18826 .22355 Mdot
.20394 .23139 Mdot
.20394 .22747 Mdot
.1961 .22747 Mdot
.18042 .21963 Mdot
.1765 .21571 Mdot
.1765 .21179 Mdot
.17257 .20787 Mdot
.16865 .20787 Mdot
.18042 .21571 Mdot
.1765 .21179 Mdot
.18434 .20787 Mdot
.18434 .21179 Mdot
.18434 .20787 Mdot
.18434 .20002 Mdot
.1765 .19218 Mdot
.18042 .1961 Mdot
.18434 .20394 Mdot
.1765 .20002 Mdot
.1765 .20394 Mdot
.17257 .20394 Mdot
.16473 .1961 Mdot
.17257 .1961 Mdot
.18826 .21179 Mdot
.18826 .21179 Mdot
.19218 .21571 Mdot
.18826 .21179 Mdot
.1961 .21963 Mdot
.1961 .21571 Mdot
.1961 .21179 Mdot
.20394 .21963 Mdot
.1961 .21179 Mdot
.20002 .21963 Mdot
.20394 .22355 Mdot
.20002 .21963 Mdot
.20002 .22355 Mdot
.1961 .21571 Mdot
.19218 .20787 Mdot
.18826 .20787 Mdot
.19218 .21571 Mdot
.19218 .21179 Mdot
.1961 .21963 Mdot
.20002 .22355 Mdot
.1961 .22355 Mdot
.18826 .21179 Mdot
.18434 .20394 Mdot
.17257 .18826 Mdot
.16473 .17257 Mdot
.16865 .1765 Mdot
.17257 .1765 Mdot
.1765 .18434 Mdot
.16473 .18042 Mdot
.17257 .18826 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.16865 .18434 Mdot
.1765 .18826 Mdot
.17257 .18826 Mdot
.16081 .1765 Mdot
.16473 .18826 Mdot
.16081 .18826 Mdot
.16081 .18434 Mdot
.14513 .1765 Mdot
.14905 .18434 Mdot
.13336 .16865 Mdot
.12944 .16081 Mdot
.12552 .15297 Mdot
.14513 .16473 Mdot
.14513 .16473 Mdot
.1412 .15689 Mdot
.1412 .15689 Mdot
.12944 .14905 Mdot
.11768 .1412 Mdot
.11768 .1412 Mdot
.10983 .12552 Mdot
.10591 .1216 Mdot
.10199 .11376 Mdot
.09807 .10983 Mdot
.09415 .10199 Mdot
.10199 .11376 Mdot
.12552 .1412 Mdot
.11376 .1216 Mdot
.09807 .10199 Mdot
.09807 .09807 Mdot
.10983 .10983 Mdot
.10983 .10983 Mdot
.10591 .10983 Mdot
.10591 .11768 Mdot
.08631 .09807 Mdot
.08239 .09807 Mdot
.0667 .08631 Mdot
.03533 .04317 Mdot
.05102 .06278 Mdot
.05494 .0667 Mdot
.05494 .07062 Mdot
.07062 .09023 Mdot
.08239 .09807 Mdot
.08631 .09415 Mdot
.0667 .07846 Mdot
.05494 .0667 Mdot
.03533 .04317 Mdot
.05102 .0667 Mdot
.07454 .09023 Mdot
.09023 .11768 Mdot
.09415 .11376 Mdot
.09807 .12552 Mdot
.11376 .1412 Mdot
.11376 .14513 Mdot
.11376 .14513 Mdot
.1216 .15297 Mdot
.11768 .14905 Mdot
.12552 .15689 Mdot
.12944 .15689 Mdot
.1412 .16473 Mdot
.14513 .16865 Mdot
.1412 .16473 Mdot
.16081 .18826 Mdot
.16865 .20002 Mdot
.16865 .1961 Mdot
.16865 .19218 Mdot
.16081 .18826 Mdot
.14513 .17257 Mdot
.15297 .18434 Mdot
.15297 .18042 Mdot
.14905 .1765 Mdot
.15689 .18826 Mdot
.15689 .18826 Mdot
.16081 .1961 Mdot
.16473 .19218 Mdot
.1765 .20394 Mdot
.17257 .18826 Mdot
.16865 .18434 Mdot
.16081 .18042 Mdot
.16473 .18042 Mdot
.16865 .18826 Mdot
.18042 .20002 Mdot
.18042 .1961 Mdot
.18826 .20787 Mdot
.18826 .20394 Mdot
.18826 .1961 Mdot
.18826 .20002 Mdot
.17257 .18434 Mdot
.16081 .17257 Mdot
.16865 .18434 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.16865 .18826 Mdot
.1765 .20002 Mdot
.18042 .20787 Mdot
.1765 .20394 Mdot
.16081 .19218 Mdot
.15297 .18434 Mdot
.16081 .19218 Mdot
.16865 .20002 Mdot
.18042 .21571 Mdot
.18434 .21179 Mdot
.1961 .22355 Mdot
.20002 .22747 Mdot
.19218 .22747 Mdot
.18042 .21963 Mdot
.20002 .23139 Mdot
.20002 .23531 Mdot
.19218 .23531 Mdot
.18826 .23139 Mdot
.19218 .23531 Mdot
.1961 .23924 Mdot
.18434 .22355 Mdot
.18434 .22747 Mdot
.19218 .23531 Mdot
.19218 .22355 Mdot
.20002 .22747 Mdot
.18826 .21179 Mdot
.19218 .21571 Mdot
.19218 .20787 Mdot
.20002 .20787 Mdot
.1961 .20787 Mdot
.18826 .20394 Mdot
.18434 .20394 Mdot
.19218 .21571 Mdot
.18042 .20787 Mdot
.1765 .20394 Mdot
.1765 .20787 Mdot
.18042 .20002 Mdot
.18434 .20002 Mdot
.1961 .21571 Mdot
.1961 .22355 Mdot
.19218 .21571 Mdot
.20002 .21963 Mdot
.1961 .20394 Mdot
.20787 .21963 Mdot
.20394 .22355 Mdot
.1961 .21963 Mdot
.19218 .21963 Mdot
.18826 .21571 Mdot
.1961 .22355 Mdot
.1961 .21963 Mdot
.18826 .21571 Mdot
.18042 .20394 Mdot
.1961 .21963 Mdot
.20002 .21963 Mdot
.20394 .22355 Mdot
.20002 .22355 Mdot
.1961 .22355 Mdot
.19218 .21571 Mdot
.18826 .21179 Mdot
.18042 .20002 Mdot
.16473 .18042 Mdot
.16081 .1765 Mdot
.16473 .16865 Mdot
.16865 .18042 Mdot
.17257 .18826 Mdot
.17257 .18826 Mdot
.17257 .18826 Mdot
.16473 .18434 Mdot
.17257 .19218 Mdot
.17257 .19218 Mdot
.17257 .1961 Mdot
.16473 .18434 Mdot
.14905 .1765 Mdot
.15297 .18434 Mdot
.14905 .1765 Mdot
.14905 .18042 Mdot
.14513 .18042 Mdot
.14905 .18042 Mdot
.1412 .16865 Mdot
.12944 .15297 Mdot
.13728 .15689 Mdot
.1412 .15689 Mdot
.13728 .15297 Mdot
.13728 .16081 Mdot
.13336 .16473 Mdot
.12552 .15689 Mdot
.12552 .14905 Mdot
.11376 .13336 Mdot
.10591 .12552 Mdot
.09807 .11376 Mdot
.10591 .1216 Mdot
.10199 .11768 Mdot
.11768 .12944 Mdot
.12552 .13336 Mdot
.11768 .12552 Mdot
.10591 .10983 Mdot
.10591 .10591 Mdot
.10591 .10983 Mdot
.10983 .11376 Mdot
.10199 .10983 Mdot
.10199 .10983 Mdot
.09807 .10591 Mdot
.08631 .09807 Mdot
.07454 .08239 Mdot
.02357 .03141 Mdot
.02749 .03533 Mdot
.02357 .03533 Mdot
.03533 .05102 Mdot
.04317 .05886 Mdot
.05886 .07454 Mdot
.08239 .10591 Mdot
.07454 .09415 Mdot
.06278 .07454 Mdot
.03925 .04709 Mdot
.04709 .05886 Mdot
.05886 .07846 Mdot
.05102 .06278 Mdot
.04709 .06278 Mdot
.07062 .09415 Mdot
.09807 .1216 Mdot
.11376 .1412 Mdot
.11768 .1412 Mdot
.13336 .16473 Mdot
.12944 .16081 Mdot
.12944 .16081 Mdot
.13728 .16865 Mdot
.13336 .16865 Mdot
.13728 .16865 Mdot
.12944 .16473 Mdot
.1412 .1765 Mdot
.14905 .18826 Mdot
.14905 .18434 Mdot
.15689 .19218 Mdot
.16081 .1961 Mdot
.15689 .18826 Mdot
.14905 .1765 Mdot
.16081 .18434 Mdot
.16473 .18042 Mdot
.18042 .20394 Mdot
.17257 .19218 Mdot
.18042 .20002 Mdot
.18434 .20002 Mdot
.1765 .1961 Mdot
.18042 .1961 Mdot
.18042 .20002 Mdot
.18434 .20787 Mdot
.18042 .20002 Mdot
.1765 .1961 Mdot
.18042 .20787 Mdot
.19218 .21179 Mdot
.1961 .21571 Mdot
.19218 .21179 Mdot
.18826 .20787 Mdot
.18434 .20787 Mdot
.18042 .19218 Mdot
.17257 .18042 Mdot
.16865 .1765 Mdot
.16865 .18434 Mdot
.16865 .18434 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.18042 .20002 Mdot
.18042 .20394 Mdot
.18042 .20787 Mdot
.1765 .21179 Mdot
.18042 .21571 Mdot
.17257 .20787 Mdot
.16865 .20394 Mdot
.16081 .19218 Mdot
.16865 .20394 Mdot
.1765 .20787 Mdot
.18042 .21571 Mdot
.18434 .21963 Mdot
.18826 .22747 Mdot
.1961 .23531 Mdot
.1961 .23531 Mdot
.20394 .23531 Mdot
.20787 .23924 Mdot
.20787 .24316 Mdot
.20394 .23531 Mdot
.20787 .23924 Mdot
.1961 .22747 Mdot
.20394 .23139 Mdot
.20002 .22747 Mdot
.1961 .21571 Mdot
.1961 .21963 Mdot
.20002 .22747 Mdot
.1961 .21571 Mdot
.20002 .21179 Mdot
.20394 .21179 Mdot
.20002 .20787 Mdot
.18826 .20394 Mdot
.18826 .21179 Mdot
.18826 .21179 Mdot
.18042 .20787 Mdot
.1765 .20002 Mdot
.18042 .20002 Mdot
.18434 .20394 Mdot
.1961 .21963 Mdot
.19218 .21571 Mdot
.19218 .21571 Mdot
.20002 .21571 Mdot
.20002 .21963 Mdot
.21179 .23139 Mdot
.22747 .24316 Mdot
.21571 .23139 Mdot
.19218 .20787 Mdot
.18042 .20787 Mdot
.18826 .21571 Mdot
.18826 .21571 Mdot
.19218 .21963 Mdot
.19218 .22355 Mdot
.19218 .22355 Mdot
.20002 .23139 Mdot
.1961 .21963 Mdot
.18826 .21179 Mdot
.1765 .20002 Mdot
.18434 .20787 Mdot
.18042 .20394 Mdot
.18826 .21179 Mdot
.1765 .1961 Mdot
.17257 .18042 Mdot
.17257 .18434 Mdot
.18042 .19218 Mdot
.1765 .19218 Mdot
.18042 .1961 Mdot
.1765 .19218 Mdot
.17257 .18826 Mdot
.16865 .18826 Mdot
.17257 .18826 Mdot
.17257 .19218 Mdot
.17257 .19218 Mdot
.16865 .19218 Mdot
.16865 .19218 Mdot
.15297 .17257 Mdot
.15689 .1765 Mdot
.15689 .1765 Mdot
.16081 .18042 Mdot
.16473 .18042 Mdot
.13336 .14905 Mdot
.13336 .15297 Mdot
.13728 .15297 Mdot
.13336 .15297 Mdot
.12944 .15297 Mdot
.12944 .15689 Mdot
.12944 .16473 Mdot
.12552 .14905 Mdot
.12944 .14513 Mdot
.12552 .13336 Mdot
.12944 .13728 Mdot
.13728 .14905 Mdot
.11376 .12552 Mdot
.11768 .13336 Mdot
.12944 .14513 Mdot
.1216 .12944 Mdot
.11376 .12944 Mdot
.11376 .12944 Mdot
.10591 .11376 Mdot
.10591 .11376 Mdot
.10983 .11376 Mdot
.10983 .11768 Mdot
.10983 .11768 Mdot
.09415 .09807 Mdot
.07846 .08631 Mdot
.01572 .02357 Mdot
.02357 .03141 Mdot
.01965 .02749 Mdot
.02357 .03533 Mdot
.02357 .03533 Mdot
.04709 .06278 Mdot
.05494 .07454 Mdot
.05886 .07846 Mdot
.06278 .08239 Mdot
.05886 .0667 Mdot
.06278 .0667 Mdot
.06278 .07062 Mdot
.06278 .07062 Mdot
.05102 .05494 Mdot
.05102 .05494 Mdot
.05102 .05886 Mdot
.07846 .09415 Mdot
.10199 .11768 Mdot
.11768 .13728 Mdot
.13336 .15297 Mdot
.13728 .16473 Mdot
.1412 .1765 Mdot
.14513 .18042 Mdot
.13728 .17257 Mdot
.13336 .16865 Mdot
.13728 .17257 Mdot
.13728 .17257 Mdot
.14905 .18434 Mdot
.15297 .18826 Mdot
.15689 .19218 Mdot
.15689 .18826 Mdot
.16081 .19218 Mdot
.17257 .20002 Mdot
.1765 .1961 Mdot
.18434 .20002 Mdot
.18434 .20002 Mdot
.18434 .20002 Mdot
.18826 .20394 Mdot
.1961 .20787 Mdot
.20002 .21571 Mdot
.1961 .21179 Mdot
.19218 .21179 Mdot
.19218 .21179 Mdot
.18042 .20394 Mdot
.1765 .20787 Mdot
.18042 .21571 Mdot
.18042 .21571 Mdot
.18434 .20787 Mdot
.18826 .21179 Mdot
.19218 .21571 Mdot
.19218 .20394 Mdot
.19218 .1961 Mdot
.1765 .18042 Mdot
.1765 .18826 Mdot
.17257 .1765 Mdot
.1765 .18826 Mdot
.1765 .19218 Mdot
.18826 .20394 Mdot
.18434 .21179 Mdot
.18434 .21571 Mdot
.1765 .20787 Mdot
.17257 .20787 Mdot
.17257 .20787 Mdot
.1765 .21179 Mdot
.16081 .20002 Mdot
.17257 .21571 Mdot
.16865 .21179 Mdot
.17257 .21571 Mdot
.18042 .21963 Mdot
.19218 .22747 Mdot
.1961 .23531 Mdot
.1961 .23531 Mdot
.20787 .24316 Mdot
.21179 .24316 Mdot
.21571 .24316 Mdot
.20394 .23139 Mdot
.20002 .22747 Mdot
.20787 .23139 Mdot
.20787 .22747 Mdot
.21179 .22747 Mdot
.21179 .23531 Mdot
.20787 .23139 Mdot
.21179 .23531 Mdot
.20002 .21963 Mdot
.20394 .21571 Mdot
.20787 .21179 Mdot
.20002 .20787 Mdot
.1961 .20787 Mdot
.18826 .20787 Mdot
.18434 .20787 Mdot
.1765 .1961 Mdot
.17257 .20002 Mdot
.17257 .20002 Mdot
.1765 .20002 Mdot
.18826 .21963 Mdot
.18434 .21571 Mdot
.1961 .22355 Mdot
.20002 .22355 Mdot
.20394 .23139 Mdot
.20394 .23531 Mdot
.21179 .24316 Mdot
.21571 .23924 Mdot
.21571 .24316 Mdot
.1961 .22355 Mdot
.18434 .20787 Mdot
.1961 .21571 Mdot
.20787 .23531 Mdot
.20787 .23924 Mdot
.20394 .23139 Mdot
.20394 .23139 Mdot
.18434 .21179 Mdot
.18434 .21571 Mdot
.18042 .21179 Mdot
.17257 .20002 Mdot
.18042 .20787 Mdot
.18826 .21571 Mdot
.18042 .20002 Mdot
.1765 .20002 Mdot
.1765 .19218 Mdot
.18042 .1961 Mdot
.18042 .1961 Mdot
.18826 .20002 Mdot
.18826 .1961 Mdot
.1765 .18826 Mdot
.1765 .18434 Mdot
.18042 .19218 Mdot
.1765 .1961 Mdot
.17257 .1961 Mdot
.16473 .18826 Mdot
.15297 .1765 Mdot
.1412 .16865 Mdot
.14905 .1765 Mdot
.1412 .16081 Mdot
.15297 .16473 Mdot
.16865 .18042 Mdot
.16081 .17257 Mdot
.1412 .15689 Mdot
.14513 .15689 Mdot
.13728 .15297 Mdot
.12552 .14513 Mdot
.1216 .14905 Mdot
.12552 .15689 Mdot
.1216 .15297 Mdot
.10983 .13336 Mdot
.11768 .13336 Mdot
.11768 .13336 Mdot
.12552 .14513 Mdot
.11376 .13336 Mdot
.10591 .12552 Mdot
.12552 .13728 Mdot
.1216 .13728 Mdot
.12552 .13728 Mdot
.11376 .12552 Mdot
.09807 .10591 Mdot
.08631 .09807 Mdot
.10591 .11768 Mdot
.09415 .10983 Mdot
.09807 .11376 Mdot
.08631 .09415 Mdot
.07846 .09023 Mdot
.01572 .03533 Mdot
.02357 .04317 Mdot
.02749 .03925 Mdot
.02357 .03925 Mdot
.01572 .02749 Mdot
.01965 .03141 Mdot
.02749 .03533 Mdot
.01965 .03141 Mdot
.03533 .03533 Mdot
.06278 .0667 Mdot
.08239 .08239 Mdot
.10199 .10591 Mdot
.08631 .09023 Mdot
.0667 .07062 Mdot
.05102 .05886 Mdot
.03925 .04709 Mdot
.03141 .04709 Mdot
.05494 .07454 Mdot
.07454 .09415 Mdot
.10591 .12944 Mdot
.1216 .14905 Mdot
.13728 .17257 Mdot
.15297 .19218 Mdot
.14905 .18826 Mdot
.15297 .19218 Mdot
.14905 .18434 Mdot
.15689 .19218 Mdot
.15689 .1961 Mdot
.14905 .18434 Mdot
.14513 .18042 Mdot
.15297 .19218 Mdot
.16081 .20002 Mdot
.16081 .19218 Mdot
.17257 .1961 Mdot
.18826 .21179 Mdot
.18042 .19218 Mdot
.18434 .20002 Mdot
.18434 .20002 Mdot
.19218 .20787 Mdot
.20002 .22355 Mdot
.1961 .21963 Mdot
.20002 .22355 Mdot
.19218 .21571 Mdot
.18042 .20787 Mdot
.18042 .21179 Mdot
.18434 .21963 Mdot
.18826 .21963 Mdot
.20002 .22747 Mdot
.20002 .22747 Mdot
.1961 .21963 Mdot
.20002 .21963 Mdot
.19218 .20002 Mdot
.18042 .18042 Mdot
.18042 .18434 Mdot
.19218 .1961 Mdot
.18826 .1961 Mdot
.18826 .20787 Mdot
.19218 .21179 Mdot
.1961 .21963 Mdot
.1961 .22355 Mdot
.18042 .21963 Mdot
.1765 .21179 Mdot
.18042 .21963 Mdot
.18434 .22355 Mdot
.18826 .22747 Mdot
.18434 .21963 Mdot
.1961 .23139 Mdot
.18042 .21179 Mdot
.1765 .20787 Mdot
.18042 .20787 Mdot
.18826 .21179 Mdot
.19218 .21963 Mdot
.20394 .23531 Mdot
.20787 .23924 Mdot
.20394 .23139 Mdot
.1961 .22355 Mdot
.1961 .21963 Mdot
.20787 .22747 Mdot
.20002 .21963 Mdot
.21179 .23139 Mdot
.21963 .23531 Mdot
.21963 .23924 Mdot
.21571 .23531 Mdot
.20394 .22747 Mdot
.20787 .22747 Mdot
.21571 .22747 Mdot
.20787 .21571 Mdot
.20002 .20787 Mdot
.1961 .21571 Mdot
.18042 .20394 Mdot
.17257 .1961 Mdot
.17257 .20002 Mdot
.17257 .20002 Mdot
.17257 .20787 Mdot
.1765 .21179 Mdot
.19218 .23139 Mdot
.1961 .22747 Mdot
.18434 .21571 Mdot
.20002 .22747 Mdot
.20002 .23139 Mdot
.1961 .22355 Mdot
.21179 .23531 Mdot
.21571 .23924 Mdot
.20002 .22355 Mdot
.19218 .21179 Mdot
.18042 .1961 Mdot
.18434 .20394 Mdot
.20002 .22355 Mdot
.21179 .24316 Mdot
.20002 .22747 Mdot
.20787 .23531 Mdot
.20002 .23531 Mdot
.19218 .22747 Mdot
.19218 .22355 Mdot
.1961 .22747 Mdot
.20002 .23139 Mdot
.1765 .20787 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.18826 .20394 Mdot
.19218 .21179 Mdot
.18826 .21179 Mdot
.18826 .20394 Mdot
.18434 .20002 Mdot
.18042 .19218 Mdot
.1765 .18826 Mdot
.16865 .18434 Mdot
.17257 .18826 Mdot
.16473 .18434 Mdot
.15689 .18826 Mdot
.15297 .18434 Mdot
.1412 .17257 Mdot
.14905 .16865 Mdot
.14905 .16865 Mdot
.16473 .18042 Mdot
.16081 .1765 Mdot
.16081 .18042 Mdot
.15297 .16865 Mdot
.1412 .15689 Mdot
.1412 .16081 Mdot
.1216 .13728 Mdot
.11768 .12944 Mdot
.11376 .12944 Mdot
.1216 .14513 Mdot
.1216 .14905 Mdot
.1216 .14513 Mdot
.11768 .14905 Mdot
.11376 .1412 Mdot
.11376 .13336 Mdot
.10199 .1216 Mdot
.10199 .12552 Mdot
.11376 .13336 Mdot
.11768 .12944 Mdot
.11768 .12944 Mdot
.10591 .1216 Mdot
.09807 .11768 Mdot
.09807 .11376 Mdot
.09807 .11768 Mdot
.08239 .10199 Mdot
.0667 .08631 Mdot
.01965 .03925 Mdot
.01965 .03533 Mdot
.02749 .04317 Mdot
.03141 .04709 Mdot
.02749 .04317 Mdot
.0118 .02749 Mdot
.00788 .01965 Mdot
.01572 .02749 Mdot
.03533 .03533 Mdot
.03925 .02749 Mdot
.08239 .07846 Mdot
.09807 .10199 Mdot
.09415 .09807 Mdot
.07454 .08239 Mdot
.04709 .05494 Mdot
.04709 .05102 Mdot
.04317 .04709 Mdot
.03141 .03533 Mdot
.03533 .04709 Mdot
.0667 .08239 Mdot
.10983 .12552 Mdot
.13336 .15297 Mdot
.14905 .17257 Mdot
.16081 .18826 Mdot
.16865 .20787 Mdot
.16865 .20787 Mdot
.17257 .21571 Mdot
.16081 .20002 Mdot
.15689 .20002 Mdot
.14905 .19218 Mdot
.1412 .18434 Mdot
.14905 .19218 Mdot
.16473 .20394 Mdot
.17257 .20394 Mdot
.18434 .20394 Mdot
.20002 .20787 Mdot
.20002 .20787 Mdot
.20394 .21179 Mdot
.1961 .20394 Mdot
.19218 .20787 Mdot
.18826 .20787 Mdot
.19218 .21571 Mdot
.18434 .21571 Mdot
.18042 .21571 Mdot
.18826 .22355 Mdot
.19218 .23139 Mdot
.20002 .23531 Mdot
.20394 .22747 Mdot
.21571 .23531 Mdot
.21179 .22355 Mdot
.20787 .21963 Mdot
.20394 .21179 Mdot
.20787 .21179 Mdot
.21571 .22355 Mdot
.21179 .21963 Mdot
.20394 .21179 Mdot
.20002 .21179 Mdot
.20394 .22355 Mdot
.18826 .21179 Mdot
.1961 .22355 Mdot
.18826 .22747 Mdot
.1765 .21179 Mdot
.17257 .21179 Mdot
.18042 .21571 Mdot
.19218 .22747 Mdot
.20394 .23531 Mdot
.1961 .22747 Mdot
.20002 .22355 Mdot
.20002 .22355 Mdot
.20002 .21571 Mdot
.20002 .21571 Mdot
.1961 .21571 Mdot
.1961 .21963 Mdot
.20002 .22355 Mdot
.1961 .21963 Mdot
.20787 .23531 Mdot
.21963 .24316 Mdot
.20787 .23139 Mdot
.21963 .24708 Mdot
.21179 .23924 Mdot
.22355 .25492 Mdot
.21963 .24316 Mdot
.23139 .26276 Mdot
.22747 .24708 Mdot
.21571 .22747 Mdot
.21571 .22355 Mdot
.21571 .21963 Mdot
.20394 .21571 Mdot
.19218 .20787 Mdot
.18434 .21179 Mdot
.17257 .20002 Mdot
.16473 .20394 Mdot
.16473 .20002 Mdot
.16865 .20787 Mdot
.16865 .20787 Mdot
.18826 .23531 Mdot
.18826 .23531 Mdot
.18826 .23139 Mdot
.18434 .21571 Mdot
.19218 .22747 Mdot
.1961 .22747 Mdot
.20787 .23531 Mdot
.21571 .24708 Mdot
.20787 .23531 Mdot
.1961 .21963 Mdot
.20787 .22747 Mdot
.19218 .21179 Mdot
.18826 .21179 Mdot
.20002 .22747 Mdot
.20787 .23924 Mdot
.21179 .24316 Mdot
.20787 .24316 Mdot
.20394 .24316 Mdot
.1961 .23924 Mdot
.1961 .23139 Mdot
.1961 .22355 Mdot
.19218 .21963 Mdot
.18434 .21179 Mdot
.19218 .21571 Mdot
.1961 .21179 Mdot
.18826 .20787 Mdot
.19218 .20787 Mdot
.19218 .21179 Mdot
.18826 .20787 Mdot
.18042 .20002 Mdot
.1765 .18826 Mdot
.18042 .1961 Mdot
.15689 .1765 Mdot
.16473 .18826 Mdot
.16081 .19218 Mdot
.15689 .19218 Mdot
.16473 .18826 Mdot
.16473 .18434 Mdot
.16865 .18826 Mdot
.1765 .19218 Mdot
.18042 .18826 Mdot
.17257 .1765 Mdot
.16865 .17257 Mdot
.17257 .18042 Mdot
.16081 .16473 Mdot
.13728 .1412 Mdot
.12944 .13336 Mdot
.12552 .13336 Mdot
.12552 .13728 Mdot
.12552 .14513 Mdot
.12552 .14905 Mdot
.12944 .15297 Mdot
.13728 .15689 Mdot
.13728 .15689 Mdot
.12552 .15297 Mdot
.11376 .1412 Mdot
.11768 .14513 Mdot
.11768 .13336 Mdot
.11768 .13336 Mdot
.11768 .13336 Mdot
.10591 .1216 Mdot
.10591 .12552 Mdot
.09807 .10983 Mdot
.09415 .09807 Mdot
.07454 .08631 Mdot
.02749 .04709 Mdot
.03533 .04709 Mdot
.04317 .05494 Mdot
.05102 .06278 Mdot
.04317 .05102 Mdot
.03925 .04709 Mdot
.03141 .03925 Mdot
.03925 .05102 Mdot
.04317 .04317 Mdot
.03925 .03533 Mdot
.05102 .05102 Mdot
.05494 .05102 Mdot
.06278 .06278 Mdot
.05886 .05886 Mdot
.0667 .06278 Mdot
.05494 .05494 Mdot
.05102 .04317 Mdot
.04709 .03141 Mdot
.03533 .01965 Mdot
.03925 .02749 Mdot
.06278 .05494 Mdot
.10983 .11376 Mdot
.15297 .16081 Mdot
.16865 .18826 Mdot
.17257 .20394 Mdot
.16473 .20787 Mdot
.17257 .21963 Mdot
.16473 .21963 Mdot
.16081 .21571 Mdot
.16081 .20394 Mdot
.16473 .21179 Mdot
.16473 .20787 Mdot
.16865 .21571 Mdot
.18042 .20787 Mdot
.1765 .19218 Mdot
.18826 .1961 Mdot
.20394 .21179 Mdot
.20394 .20787 Mdot
.20394 .21179 Mdot
.18826 .20394 Mdot
.18826 .20787 Mdot
.1765 .20787 Mdot
.18042 .21571 Mdot
.18042 .21571 Mdot
.19218 .23139 Mdot
.20394 .23924 Mdot
.21179 .23924 Mdot
.21179 .23139 Mdot
.21571 .23139 Mdot
.21963 .22747 Mdot
.23924 .24316 Mdot
.22747 .23531 Mdot
.23139 .23531 Mdot
.22747 .23531 Mdot
.21963 .22747 Mdot
.20787 .21179 Mdot
.20394 .21179 Mdot
.20394 .22355 Mdot
.20394 .23139 Mdot
.20002 .23924 Mdot
.19218 .23924 Mdot
.18434 .23139 Mdot
.18042 .21571 Mdot
.19218 .22747 Mdot
.20394 .23531 Mdot
.21963 .24316 Mdot
.21963 .23924 Mdot
.23531 .24708 Mdot
.23531 .24316 Mdot
.22747 .23139 Mdot
.22747 .23139 Mdot
.21571 .22355 Mdot
.20787 .21963 Mdot
.22747 .24708 Mdot
.21571 .24316 Mdot
.21179 .24708 Mdot
.22355 .25492 Mdot
.21963 .25492 Mdot
.21179 .24708 Mdot
.20394 .23531 Mdot
.21571 .24316 Mdot
.22747 .251 Mdot
.23139 .25492 Mdot
.23531 .25492 Mdot
.22747 .23531 Mdot
.22747 .23531 Mdot
.21179 .21571 Mdot
.20002 .20787 Mdot
.1961 .20787 Mdot
.18826 .21571 Mdot
.16865 .20394 Mdot
.17257 .21179 Mdot
.17257 .21179 Mdot
.16865 .20787 Mdot
.16473 .21179 Mdot
.1765 .22355 Mdot
.18434 .23531 Mdot
.19218 .24316 Mdot
.1961 .23924 Mdot
.20002 .23531 Mdot
.21571 .24708 Mdot
.21179 .23531 Mdot
.21571 .24708 Mdot
.22355 .25492 Mdot
.22355 .24708 Mdot
.21963 .24316 Mdot
.20394 .23531 Mdot
.1961 .22355 Mdot
.1765 .20787 Mdot
.18434 .21963 Mdot
.1961 .23139 Mdot
.20394 .24316 Mdot
.20787 .251 Mdot
.20394 .24316 Mdot
.20002 .23531 Mdot
.1961 .22355 Mdot
.20787 .23139 Mdot
.20787 .22355 Mdot
.20787 .22747 Mdot
.20787 .21179 Mdot
.21179 .21963 Mdot
.20002 .21571 Mdot
.19218 .20787 Mdot
.1961 .21571 Mdot
.18826 .20787 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.16865 .1961 Mdot
.16473 .20002 Mdot
.16473 .20002 Mdot
.16081 .1961 Mdot
.16865 .20394 Mdot
.17257 .1961 Mdot
.17257 .18434 Mdot
.1765 .18434 Mdot
.18434 .18826 Mdot
.18042 .17257 Mdot
.18826 .18042 Mdot
.18434 .18042 Mdot
.17257 .16865 Mdot
.16081 .15689 Mdot
.1412 .14513 Mdot
.13728 .1412 Mdot
.12944 .1412 Mdot
.13336 .15297 Mdot
.12944 .14905 Mdot
.12944 .15689 Mdot
.13336 .16081 Mdot
.13336 .16081 Mdot
.12552 .15297 Mdot
.1216 .15297 Mdot
.1216 .14905 Mdot
.12552 .15297 Mdot
.11376 .1412 Mdot
.11768 .14905 Mdot
.1216 .15297 Mdot
.1216 .14905 Mdot
.11768 .14513 Mdot
.11768 .13336 Mdot
.09023 .09415 Mdot
.03925 .04709 Mdot
.05102 .05494 Mdot
.07062 .07062 Mdot
.06278 .0667 Mdot
.05102 .05494 Mdot
.03925 .03925 Mdot
.03141 .03533 Mdot
.04317 .04709 Mdot
.03925 .04317 Mdot
.04709 .05102 Mdot
.03925 .04709 Mdot
.02749 .03141 Mdot
.04317 .03925 Mdot
.05494 .05494 Mdot
.05886 .05494 Mdot
.05886 .05102 Mdot
.05886 .05494 Mdot
.05494 .03925 Mdot
.04317 .02357 Mdot
.03925 .01965 Mdot
.03141 .01572 Mdot
.07846 .07454 Mdot
.10591 .10983 Mdot
.13728 .15689 Mdot
.15689 .18826 Mdot
.16473 .20787 Mdot
.16081 .21179 Mdot
.16473 .22355 Mdot
.16081 .22355 Mdot
.15689 .21571 Mdot
.16473 .21179 Mdot
.17257 .21963 Mdot
.18826 .22747 Mdot
.18826 .21963 Mdot
.19218 .21179 Mdot
.20002 .21571 Mdot
.20394 .21963 Mdot
.20787 .21963 Mdot
.20002 .21963 Mdot
.1961 .21571 Mdot
.1961 .21963 Mdot
.1961 .23139 Mdot
.1961 .23531 Mdot
.19218 .23139 Mdot
.20002 .24708 Mdot
.1961 .23531 Mdot
.21571 .24316 Mdot
.23924 .26276 Mdot
.23531 .25492 Mdot
.24316 .24708 Mdot
.24708 .24316 Mdot
.24708 .24316 Mdot
.24316 .24316 Mdot
.22747 .22747 Mdot
.22747 .23531 Mdot
.21963 .23531 Mdot
.21963 .23924 Mdot
.21571 .24316 Mdot
.20787 .24316 Mdot
.20002 .23924 Mdot
.20787 .24708 Mdot
.20394 .24708 Mdot
.20394 .23531 Mdot
.21571 .24316 Mdot
.21963 .24708 Mdot
.23924 .251 Mdot
.23924 .24316 Mdot
.251 .24708 Mdot
.24316 .24316 Mdot
.23139 .22747 Mdot
.22355 .22747 Mdot
.22747 .23531 Mdot
.21963 .23924 Mdot
.20787 .23139 Mdot
.21963 .24708 Mdot
.21179 .24708 Mdot
.22355 .26668 Mdot
.22747 .26668 Mdot
.22747 .25884 Mdot
.22355 .251 Mdot
.22747 .24708 Mdot
.22747 .23924 Mdot
.23924 .25492 Mdot
.23531 .24708 Mdot
.23924 .24708 Mdot
.23531 .24708 Mdot
.21963 .23924 Mdot
.20394 .22747 Mdot
.20787 .23924 Mdot
.19218 .23139 Mdot
.18042 .21963 Mdot
.18434 .22747 Mdot
.1765 .21571 Mdot
.18042 .21963 Mdot
.16865 .20787 Mdot
.16473 .20002 Mdot
.16865 .20787 Mdot
.18042 .21571 Mdot
.19218 .22747 Mdot
.20394 .23924 Mdot
.21179 .22747 Mdot
.21179 .23139 Mdot
.21571 .24316 Mdot
.21571 .251 Mdot
.21179 .25492 Mdot
.20787 .25492 Mdot
.21179 .25492 Mdot
.20002 .24708 Mdot
.1961 .23531 Mdot
.18826 .22747 Mdot
.18434 .21963 Mdot
.19218 .22747 Mdot
.20002 .23139 Mdot
.1961 .23139 Mdot
.20394 .23139 Mdot
.21571 .22747 Mdot
.22355 .22747 Mdot
.21963 .21571 Mdot
.20787 .20394 Mdot
.20002 .20002 Mdot
.19218 .1961 Mdot
.18826 .20787 Mdot
.19218 .22355 Mdot
.17257 .20394 Mdot
.17257 .20787 Mdot
.16081 .19218 Mdot
.16473 .20002 Mdot
.16473 .19218 Mdot
.17257 .20394 Mdot
.18042 .21571 Mdot
.17257 .20394 Mdot
.1765 .20394 Mdot
.18042 .20002 Mdot
.18434 .18826 Mdot
.19218 .19218 Mdot
.1961 .19218 Mdot
.20002 .19218 Mdot
.19218 .18434 Mdot
.1765 .16473 Mdot
.17257 .17257 Mdot
.15689 .16865 Mdot
.15297 .16865 Mdot
.13336 .15297 Mdot
.11376 .13728 Mdot
.1216 .14905 Mdot
.11768 .14905 Mdot
.12552 .16081 Mdot
.12944 .16473 Mdot
.13728 .16865 Mdot
.13336 .16473 Mdot
.1216 .15689 Mdot
.12552 .16081 Mdot
.12552 .16081 Mdot
.1216 .15689 Mdot
.11768 .14513 Mdot
.12552 .14905 Mdot
.1216 .1412 Mdot
.12552 .1412 Mdot
.1216 .12944 Mdot
.11376 .10983 Mdot
.05886 .07062 Mdot
.05494 .06278 Mdot
.05494 .0667 Mdot
.04709 .05494 Mdot
.02749 .03533 Mdot
.01965 .02749 Mdot
.02357 .03141 Mdot
.04709 .05494 Mdot
.05494 .0667 Mdot
.04709 .05886 Mdot
.04317 .05886 Mdot
.03533 .04317 Mdot
.04317 .04709 Mdot
.04709 .05494 Mdot
.06278 .0667 Mdot
.05886 .05494 Mdot
.04317 .03925 Mdot
.03141 .02357 Mdot
.02749 .01572 Mdot
.03925 .02749 Mdot
.04709 .03533 Mdot
.04317 .03141 Mdot
.06278 .05886 Mdot
.09415 .10591 Mdot
.13336 .16081 Mdot
.14905 .18434 Mdot
.15689 .20002 Mdot
.15297 .20787 Mdot
.15689 .20787 Mdot
.17257 .21963 Mdot
.1765 .22355 Mdot
.1765 .21963 Mdot
.18826 .21963 Mdot
.18434 .21179 Mdot
.18826 .21571 Mdot
.18826 .20394 Mdot
.20787 .21963 Mdot
.21571 .22747 Mdot
.20002 .21571 Mdot
.20394 .22355 Mdot
.21571 .23531 Mdot
.20394 .23139 Mdot
.1961 .23531 Mdot
.18826 .23139 Mdot
.19218 .23924 Mdot
.19218 .23531 Mdot
.21179 .251 Mdot
.21963 .251 Mdot
.22355 .251 Mdot
.22747 .24708 Mdot
.22747 .23924 Mdot
.22747 .23139 Mdot
.23924 .24708 Mdot
.22747 .23531 Mdot
.23139 .24316 Mdot
.22355 .23924 Mdot
.21963 .23924 Mdot
.21179 .23531 Mdot
.20787 .23139 Mdot
.21571 .24316 Mdot
.21963 .251 Mdot
.21571 .251 Mdot
.21179 .24316 Mdot
.21963 .23924 Mdot
.22355 .23531 Mdot
.23139 .23924 Mdot
.23924 .23924 Mdot
.24316 .23924 Mdot
.23531 .22355 Mdot
.23139 .22355 Mdot
.23139 .23924 Mdot
.21571 .22355 Mdot
.20787 .22355 Mdot
.21963 .24708 Mdot
.21179 .251 Mdot
.21571 .25884 Mdot
.22355 .26668 Mdot
.23139 .27061 Mdot
.22747 .25884 Mdot
.21963 .24708 Mdot
.21963 .24316 Mdot
.22355 .23531 Mdot
.23924 .251 Mdot
.23924 .24708 Mdot
.24708 .25492 Mdot
.24316 .25884 Mdot
.22747 .25492 Mdot
.21179 .24316 Mdot
.20787 .24316 Mdot
.20394 .23924 Mdot
.20002 .24316 Mdot
.18826 .23139 Mdot
.18042 .21963 Mdot
.18434 .21963 Mdot
.1765 .20787 Mdot
.16865 .1961 Mdot
.16473 .1961 Mdot
.16865 .1961 Mdot
.17257 .20394 Mdot
.18434 .21571 Mdot
.18826 .21179 Mdot
.18826 .21179 Mdot
.20002 .22747 Mdot
.20002 .22747 Mdot
.1961 .22355 Mdot
.20002 .23139 Mdot
.20394 .24316 Mdot
.20002 .23531 Mdot
.1961 .23139 Mdot
.18826 .22747 Mdot
.18042 .21571 Mdot
.19218 .21963 Mdot
.20002 .22747 Mdot
.20394 .21963 Mdot
.21179 .22747 Mdot
.21571 .22747 Mdot
.21963 .22355 Mdot
.21963 .22355 Mdot
.21571 .21571 Mdot
.1961 .1961 Mdot
.18042 .19218 Mdot
.16865 .19218 Mdot
.15689 .18434 Mdot
.16473 .1961 Mdot
.16865 .20002 Mdot
.17257 .20394 Mdot
.18042 .21179 Mdot
.18042 .20787 Mdot
.17257 .19218 Mdot
.18042 .20394 Mdot
.18826 .20394 Mdot
.18434 .20002 Mdot
.19218 .20002 Mdot
.18826 .19218 Mdot
.1961 .19218 Mdot
.19218 .18434 Mdot
.18826 .1765 Mdot
.20002 .1961 Mdot
.18042 .18042 Mdot
.18042 .18826 Mdot
.16865 .18042 Mdot
.14905 .16865 Mdot
.13336 .15689 Mdot
.12552 .14905 Mdot
.1216 .15297 Mdot
.11768 .14513 Mdot
.12552 .15689 Mdot
.12552 .16081 Mdot
.1216 .15689 Mdot
.12944 .16473 Mdot
.12552 .16081 Mdot
.12944 .15297 Mdot
.12552 .15297 Mdot
.11768 .14513 Mdot
.10199 .12552 Mdot
.1216 .1412 Mdot
.12552 .1412 Mdot
.12552 .13336 Mdot
.1216 .12944 Mdot
.11376 .1216 Mdot
.06278 .08239 Mdot
.05102 .06278 Mdot
.04317 .05102 Mdot
.03925 .04709 Mdot
.04317 .05102 Mdot
.02749 .03925 Mdot
.02357 .03141 Mdot
.02749 .03533 Mdot
.03925 .05102 Mdot
.03141 .03533 Mdot
.02749 .03533 Mdot
.03533 .03925 Mdot
.03533 .04317 Mdot
.04317 .05102 Mdot
.03925 .03925 Mdot
.03925 .03533 Mdot
.03533 .03141 Mdot
.02357 .01965 Mdot
.01965 .00788 Mdot
.05886 .05494 Mdot
.09023 .08631 Mdot
.09415 .09023 Mdot
.09023 .08631 Mdot
.09807 .09807 Mdot
.10983 .11768 Mdot
.13336 .14905 Mdot
.14513 .18042 Mdot
.15297 .1961 Mdot
.14905 .20002 Mdot
.16473 .20787 Mdot
.17257 .20787 Mdot
.18042 .21963 Mdot
.18826 .21963 Mdot
.18826 .21571 Mdot
.19218 .21963 Mdot
.20002 .21963 Mdot
.20787 .22355 Mdot
.22747 .23139 Mdot
.22747 .23139 Mdot
.21571 .22355 Mdot
.21963 .22747 Mdot
.20787 .22355 Mdot
.20787 .23139 Mdot
.20787 .24316 Mdot
.1961 .23924 Mdot
.20002 .24316 Mdot
.20787 .25492 Mdot
.21179 .25492 Mdot
.22747 .26276 Mdot
.22355 .25884 Mdot
.22355 .25492 Mdot
.22355 .24708 Mdot
.23531 .251 Mdot
.23139 .24708 Mdot
.23531 .251 Mdot
.23531 .25492 Mdot
.22747 .24316 Mdot
.22355 .24708 Mdot
.22355 .24316 Mdot
.21571 .24316 Mdot
.20787 .23924 Mdot
.21179 .25492 Mdot
.21179 .25492 Mdot
.20394 .24316 Mdot
.20787 .23531 Mdot
.21963 .24316 Mdot
.22747 .24316 Mdot
.22747 .23531 Mdot
.23531 .23924 Mdot
.23924 .23531 Mdot
.23531 .23531 Mdot
.22355 .23531 Mdot
.21179 .22355 Mdot
.20787 .22747 Mdot
.21179 .23924 Mdot
.21963 .26276 Mdot
.22355 .26668 Mdot
.23139 .27845 Mdot
.24708 .28629 Mdot
.24316 .28237 Mdot
.23924 .27453 Mdot
.23924 .26276 Mdot
.24316 .25884 Mdot
.251 .26668 Mdot
.24708 .25884 Mdot
.251 .25884 Mdot
.24708 .26276 Mdot
.23139 .251 Mdot
.23531 .26276 Mdot
.21963 .25492 Mdot
.20787 .251 Mdot
.20002 .23924 Mdot
.18434 .21963 Mdot
.18042 .20787 Mdot
.1765 .1961 Mdot
.16081 .18434 Mdot
.16865 .1961 Mdot
.17257 .20002 Mdot
.16865 .19218 Mdot
.1765 .20394 Mdot
.1765 .20002 Mdot
.18434 .20787 Mdot
.19218 .21179 Mdot
.20787 .22747 Mdot
.21571 .23531 Mdot
.21179 .23139 Mdot
.21963 .23924 Mdot
.20394 .22747 Mdot
.20394 .22747 Mdot
.1961 .22355 Mdot
.20002 .23531 Mdot
.20002 .23531 Mdot
.19218 .22355 Mdot
.19218 .22355 Mdot
.20002 .22747 Mdot
.20787 .23139 Mdot
.21571 .23139 Mdot
.22355 .23531 Mdot
.22747 .23531 Mdot
.20787 .21179 Mdot
.19218 .20002 Mdot
.18434 .20002 Mdot
.1765 .18826 Mdot
.17257 .18434 Mdot
.1765 .19218 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.18434 .20787 Mdot
.18042 .20394 Mdot
.18826 .21179 Mdot
.18434 .20787 Mdot
.18826 .21179 Mdot
.18042 .20002 Mdot
.18434 .1961 Mdot
.18826 .1961 Mdot
.1961 .20002 Mdot
.18826 .18042 Mdot
.18826 .1765 Mdot
.19218 .18434 Mdot
.18042 .1765 Mdot
.1765 .18042 Mdot
.17257 .18434 Mdot
.16081 .17257 Mdot
.14513 .15689 Mdot
.13728 .16081 Mdot
.12552 .14513 Mdot
.12552 .14513 Mdot
.12552 .15297 Mdot
.11768 .14513 Mdot
.1216 .14905 Mdot
.12944 .16081 Mdot
.13336 .15297 Mdot
.13336 .15297 Mdot
.13336 .14905 Mdot
.1216 .1412 Mdot
.11768 .13728 Mdot
.1216 .13728 Mdot
.1216 .13336 Mdot
.11768 .12944 Mdot
.11376 .1216 Mdot
.04709 .0667 Mdot
.04709 .05886 Mdot
.03533 .04709 Mdot
.03925 .05102 Mdot
.04317 .05494 Mdot
.03141 .03925 Mdot
.02357 .03533 Mdot
.02749 .03925 Mdot
.02749 .02749 Mdot
.03141 .03533 Mdot
.03533 .04317 Mdot
.03141 .03925 Mdot
.03141 .03925 Mdot
.03533 .04317 Mdot
.02749 .03533 Mdot
.02357 .03141 Mdot
.01965 .02749 Mdot
.01965 .01965 Mdot
.01572 .0118 Mdot
.01965 .01965 Mdot
.0667 .07454 Mdot
.1216 .13336 Mdot
.18042 .1961 Mdot
.20002 .21571 Mdot
.18826 .20002 Mdot
.17257 .18826 Mdot
.16865 .19218 Mdot
.17257 .20394 Mdot
.18042 .21963 Mdot
.16473 .20002 Mdot
.16081 .1961 Mdot
.15297 .19218 Mdot
.15689 .19218 Mdot
.15689 .18826 Mdot
.16865 .19218 Mdot
.16865 .19218 Mdot
.18434 .20394 Mdot
.19218 .21571 Mdot
.20787 .21963 Mdot
.20394 .21571 Mdot
.20787 .21963 Mdot
.21179 .22747 Mdot
.20002 .21963 Mdot
.21179 .23924 Mdot
.18434 .21963 Mdot
.19218 .22747 Mdot
.19218 .23139 Mdot
.20787 .24708 Mdot
.20394 .23531 Mdot
.20787 .24316 Mdot
.20787 .23924 Mdot
.20394 .23531 Mdot
.21571 .24316 Mdot
.21571 .24316 Mdot
.22355 .251 Mdot
.22747 .25884 Mdot
.21963 .24316 Mdot
.21179 .23531 Mdot
.21963 .24708 Mdot
.21571 .23924 Mdot
.22355 .25492 Mdot
.21179 .251 Mdot
.21179 .25492 Mdot
.20787 .251 Mdot
.21571 .251 Mdot
.21571 .24708 Mdot
.21571 .24708 Mdot
.20787 .23531 Mdot
.21963 .23924 Mdot
.21571 .23531 Mdot
.22747 .24316 Mdot
.23139 .24708 Mdot
.23139 .24316 Mdot
.22747 .23924 Mdot
.21571 .23924 Mdot
.21571 .24708 Mdot
.23531 .27453 Mdot
.23924 .28237 Mdot
.23924 .27845 Mdot
.23531 .27061 Mdot
.23924 .27453 Mdot
.23139 .26276 Mdot
.23924 .26276 Mdot
.22355 .24316 Mdot
.23139 .251 Mdot
.23924 .25492 Mdot
.23924 .25884 Mdot
.23924 .26276 Mdot
.23531 .26276 Mdot
.23139 .25884 Mdot
.22747 .25884 Mdot
.21179 .24316 Mdot
.18434 .21179 Mdot
.1765 .20394 Mdot
.16865 .19218 Mdot
.16473 .19218 Mdot
.16473 .19218 Mdot
.16865 .19218 Mdot
.17257 .19218 Mdot
.1765 .20394 Mdot
.16865 .18826 Mdot
.16473 .18434 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.19218 .20394 Mdot
.1961 .21571 Mdot
.19218 .21571 Mdot
.20002 .22355 Mdot
.20394 .22747 Mdot
.20787 .23531 Mdot
.20787 .24316 Mdot
.21571 .25884 Mdot
.21179 .251 Mdot
.20002 .24316 Mdot
.20002 .23531 Mdot
.1961 .22747 Mdot
.18434 .20787 Mdot
.20394 .21963 Mdot
.22355 .24316 Mdot
.22747 .23531 Mdot
.21571 .21963 Mdot
.20394 .21179 Mdot
.19218 .20002 Mdot
.18042 .18434 Mdot
.18042 .18826 Mdot
.18042 .1961 Mdot
.18826 .20787 Mdot
.18434 .20787 Mdot
.16865 .20002 Mdot
.16865 .20002 Mdot
.16473 .20002 Mdot
.16865 .20002 Mdot
.17257 .19218 Mdot
.1765 .1961 Mdot
.18434 .20394 Mdot
.1961 .20002 Mdot
.18826 .18434 Mdot
.18042 .16865 Mdot
.18434 .1765 Mdot
.18434 .18042 Mdot
.18826 .18434 Mdot
.16865 .15689 Mdot
.18042 .1765 Mdot
.16865 .17257 Mdot
.15297 .16081 Mdot
.14513 .15297 Mdot
.13336 .14513 Mdot
.13336 .14905 Mdot
.12552 .14513 Mdot
.1216 .1412 Mdot
.1216 .1412 Mdot
.11768 .14513 Mdot
.1216 .14513 Mdot
.10983 .13336 Mdot
.11376 .13336 Mdot
.1216 .1412 Mdot
.13336 .14905 Mdot
.12552 .1412 Mdot
.1216 .12944 Mdot
.10983 .11768 Mdot
.03141 .04709 Mdot
.03533 .04709 Mdot
.03925 .05102 Mdot
.03925 .03925 Mdot
.03141 .03533 Mdot
.03533 .03533 Mdot
.04709 .05102 Mdot
.05886 .0667 Mdot
.06278 .0667 Mdot
.05494 .05494 Mdot
.06278 .0667 Mdot
.05102 .05886 Mdot
.04317 .05494 Mdot
.03533 .04709 Mdot
.02749 .03925 Mdot
.01965 .02749 Mdot
.01965 .02749 Mdot
.0118 .01965 Mdot
.0118 .01965 Mdot
.0118 .01965 Mdot
.00788 .0118 Mdot
.07062 .08631 Mdot
.22355 .27061 Mdot
.22355 .25884 Mdot
.20394 .22747 Mdot
.20394 .23139 Mdot
.20002 .22747 Mdot
.20002 .22355 Mdot
.21571 .25492 Mdot
.20002 .23924 Mdot
.15297 .18434 Mdot
.12944 .15689 Mdot
.1216 .15297 Mdot
.1216 .14513 Mdot
.12552 .14513 Mdot
.13728 .15689 Mdot
.1412 .16473 Mdot
.14513 .16473 Mdot
.16473 .18434 Mdot
.18042 .20394 Mdot
.19218 .21179 Mdot
.20394 .22355 Mdot
.21571 .23924 Mdot
.22747 .25884 Mdot
.22747 .25884 Mdot
.21179 .24708 Mdot
.21571 .251 Mdot
.22355 .251 Mdot
.21179 .23924 Mdot
.22355 .251 Mdot
.21963 .24316 Mdot
.22355 .251 Mdot
.21963 .24708 Mdot
.21963 .24708 Mdot
.21963 .24708 Mdot
.22355 .25492 Mdot
.22355 .25492 Mdot
.21963 .24708 Mdot
.21963 .251 Mdot
.21963 .24708 Mdot
.22355 .24708 Mdot
.23139 .25884 Mdot
.22747 .24708 Mdot
.22355 .251 Mdot
.22355 .25492 Mdot
.22747 .25492 Mdot
.22747 .25492 Mdot
.20787 .23924 Mdot
.21571 .24316 Mdot
.21571 .24708 Mdot
.21571 .251 Mdot
.22355 .25492 Mdot
.21963 .24708 Mdot
.22355 .251 Mdot
.21963 .24708 Mdot
.21571 .24708 Mdot
.23139 .26276 Mdot
.22747 .26276 Mdot
.23531 .26276 Mdot
.23924 .26276 Mdot
.23531 .25884 Mdot
.23531 .26276 Mdot
.22355 .24708 Mdot
.21571 .24316 Mdot
.21571 .24316 Mdot
.22355 .24708 Mdot
.22747 .25492 Mdot
.23139 .25884 Mdot
.23139 .25492 Mdot
.23531 .26276 Mdot
.23924 .27061 Mdot
.21571 .24316 Mdot
.20002 .22355 Mdot
.18042 .20787 Mdot
.17257 .20002 Mdot
.17257 .1961 Mdot
.16865 .19218 Mdot
.1765 .20394 Mdot
.1765 .20002 Mdot
.17257 .1961 Mdot
.16081 .18434 Mdot
.16473 .18042 Mdot
.16865 .18826 Mdot
.16865 .19218 Mdot
.1765 .1961 Mdot
.1765 .20002 Mdot
.1765 .20394 Mdot
.1961 .22355 Mdot
.21179 .23531 Mdot
.21571 .24316 Mdot
.21571 .23924 Mdot
.21963 .251 Mdot
.21963 .25492 Mdot
.21571 .251 Mdot
.20787 .24316 Mdot
.1961 .22355 Mdot
.18434 .20787 Mdot
.1961 .22355 Mdot
.20394 .23139 Mdot
.19218 .21963 Mdot
.20002 .21963 Mdot
.20002 .22355 Mdot
.18434 .20394 Mdot
.18042 .20002 Mdot
.18434 .1961 Mdot
.17257 .18826 Mdot
.16081 .1765 Mdot
.1765 .18826 Mdot
.18042 .20394 Mdot
.1765 .20394 Mdot
.17257 .1961 Mdot
.1765 .20002 Mdot
.1765 .1961 Mdot
.17257 .19218 Mdot
.18042 .20394 Mdot
.18826 .20787 Mdot
.18042 .18826 Mdot
.18042 .18434 Mdot
.16865 .16473 Mdot
.16473 .16081 Mdot
.17257 .1765 Mdot
.16081 .16081 Mdot
.15297 .15689 Mdot
.14513 .15297 Mdot
.15297 .16081 Mdot
.14905 .15297 Mdot
.12944 .13728 Mdot
.13728 .14513 Mdot
.12944 .13728 Mdot
.13336 .14905 Mdot
.12944 .15297 Mdot
.12552 .15297 Mdot
.11376 .13728 Mdot
.10983 .13336 Mdot
.1216 .14513 Mdot
.10983 .13336 Mdot
.11376 .13728 Mdot
.12944 .1412 Mdot
.12944 .13336 Mdot
.11376 .11768 Mdot
.02357 .04317 Mdot
.02357 .03925 Mdot
.04317 .05494 Mdot
.05494 .05494 Mdot
.04317 .03925 Mdot
.04709 .04709 Mdot
.0667 .07454 Mdot
.07846 .09415 Mdot
.09023 .10199 Mdot
.07846 .09023 Mdot
.08631 .10199 Mdot
.07846 .09415 Mdot
.07062 .08631 Mdot
.04709 .05886 Mdot
.03141 .04317 Mdot
.01965 .02749 Mdot
.02749 .03141 Mdot
.02749 .03141 Mdot
.01572 .02357 Mdot
.0118 .01572 Mdot
.01965 .03141 Mdot
.01572 .02749 Mdot
.08631 .10983 Mdot
.11376 .13728 Mdot
.18042 .20394 Mdot
.27845 .32158 Mdot
.1961 .22355 Mdot
.19218 .21571 Mdot
.21963 .25884 Mdot
.20002 .23924 Mdot
.09807 .11768 Mdot
.08631 .10199 Mdot
.0667 .08239 Mdot
.07062 .08631 Mdot
.07454 .09807 Mdot
.10199 .11768 Mdot
.11768 .12944 Mdot
.1216 .12552 Mdot
.1412 .15297 Mdot
.17257 .18826 Mdot
.1961 .21963 Mdot
.21179 .23531 Mdot
.21963 .251 Mdot
.23139 .26276 Mdot
.22355 .25492 Mdot
.22747 .26276 Mdot
.23139 .26276 Mdot
.23924 .27453 Mdot
.24316 .27061 Mdot
.25492 .27453 Mdot
.25492 .27453 Mdot
.251 .26668 Mdot
.24708 .26276 Mdot
.23531 .25884 Mdot
.23139 .25492 Mdot
.23531 .26276 Mdot
.23531 .26276 Mdot
.23924 .26276 Mdot
.24708 .27453 Mdot
.22355 .25492 Mdot
.23139 .26276 Mdot
.23139 .25884 Mdot
.24316 .25884 Mdot
.23924 .25884 Mdot
.23924 .25884 Mdot
.24708 .26668 Mdot
.24316 .26668 Mdot
.23139 .251 Mdot
.22747 .251 Mdot
.23139 .25884 Mdot
.24316 .27845 Mdot
.23531 .27061 Mdot
.23531 .27453 Mdot
.22747 .26276 Mdot
.23139 .26668 Mdot
.23531 .27061 Mdot
.23139 .27061 Mdot
.23531 .27061 Mdot
.251 .28237 Mdot
.25884 .28237 Mdot
.26668 .28629 Mdot
.25884 .27845 Mdot
.24316 .26668 Mdot
.23139 .25492 Mdot
.22355 .24316 Mdot
.21571 .23924 Mdot
.22355 .251 Mdot
.22747 .26276 Mdot
.22355 .251 Mdot
.23531 .26668 Mdot
.23139 .26276 Mdot
.23139 .26276 Mdot
.22355 .251 Mdot
.20787 .23531 Mdot
.18042 .20787 Mdot
.18042 .20002 Mdot
.18042 .20394 Mdot
.1765 .20002 Mdot
.18434 .20787 Mdot
.19218 .21963 Mdot
.18434 .20787 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.1765 .20002 Mdot
.1765 .20002 Mdot
.17257 .1961 Mdot
.18042 .21179 Mdot
.18434 .21179 Mdot
.19218 .21963 Mdot
.20002 .23139 Mdot
.20787 .23924 Mdot
.20787 .23531 Mdot
.21963 .25492 Mdot
.21963 .26276 Mdot
.21963 .25492 Mdot
.20394 .23139 Mdot
.20394 .23531 Mdot
.19218 .21963 Mdot
.1961 .21963 Mdot
.18826 .21571 Mdot
.20002 .23139 Mdot
.20002 .22747 Mdot
.1961 .22747 Mdot
.18042 .20787 Mdot
.18434 .21179 Mdot
.18434 .21571 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.20002 .22355 Mdot
.20002 .22747 Mdot
.18826 .21179 Mdot
.18434 .20787 Mdot
.16865 .18434 Mdot
.18434 .20787 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.18434 .20787 Mdot
.1765 .1961 Mdot
.17257 .18434 Mdot
.17257 .19218 Mdot
.16081 .18042 Mdot
.15689 .1765 Mdot
.15297 .16865 Mdot
.15689 .17257 Mdot
.14905 .16865 Mdot
.14905 .16473 Mdot
.1412 .15297 Mdot
.14513 .16081 Mdot
.14513 .16473 Mdot
.13728 .16081 Mdot
.12552 .14905 Mdot
.1216 .15297 Mdot
.11768 .14513 Mdot
.11768 .1412 Mdot
.11768 .14513 Mdot
.1216 .14905 Mdot
.1216 .1412 Mdot
.12944 .1412 Mdot
.11768 .12552 Mdot
.02749 .03925 Mdot
.03925 .05494 Mdot
.03533 .04709 Mdot
.03141 .03925 Mdot
.03533 .04317 Mdot
.03141 .03925 Mdot
.04317 .05886 Mdot
.05494 .0667 Mdot
.07846 .09807 Mdot
.09023 .11376 Mdot
.09415 .11376 Mdot
.09807 .12552 Mdot
.08631 .10983 Mdot
.05494 .07454 Mdot
.03925 .05494 Mdot
.02357 .03925 Mdot
.02749 .03925 Mdot
.01572 .02357 Mdot
.01965 .03141 Mdot
.00788 .01965 Mdot
.0118 .02357 Mdot
.02749 .04317 Mdot
.04317 .06278 Mdot
.04709 .06278 Mdot
.05886 .07454 Mdot
.15297 .17257 Mdot
.15689 .1765 Mdot
.16473 .18042 Mdot
.24316 .27845 Mdot
.23924 .27845 Mdot
.15297 .18042 Mdot
.10983 .13336 Mdot
.0667 .07846 Mdot
.05886 .06278 Mdot
.06278 .06278 Mdot
.07062 .07062 Mdot
.08239 .08631 Mdot
.09807 .09807 Mdot
.1412 .15297 Mdot
.17257 .18826 Mdot
.20394 .23139 Mdot
.21179 .23924 Mdot
.23139 .26276 Mdot
.23139 .26668 Mdot
.22747 .26668 Mdot
.22355 .25884 Mdot
.23531 .26668 Mdot
.23531 .27061 Mdot
.24708 .27453 Mdot
.25492 .27453 Mdot
.26276 .28237 Mdot
.25492 .27845 Mdot
.24316 .26276 Mdot
.24316 .26668 Mdot
.23924 .25884 Mdot
.24316 .26276 Mdot
.25492 .27845 Mdot
.25492 .27845 Mdot
.251 .27845 Mdot
.24316 .27453 Mdot
.23924 .27061 Mdot
.23924 .27061 Mdot
.24316 .27061 Mdot
.25492 .27453 Mdot
.251 .26668 Mdot
.251 .27061 Mdot
.23924 .25884 Mdot
.23924 .26276 Mdot
.23139 .25492 Mdot
.24316 .27453 Mdot
.23924 .27453 Mdot
.24316 .28237 Mdot
.23531 .27453 Mdot
.24316 .27845 Mdot
.23924 .27845 Mdot
.23924 .27453 Mdot
.24708 .28629 Mdot
.24708 .27845 Mdot
.26276 .29806 Mdot
.26668 .28629 Mdot
.26276 .28237 Mdot
.26668 .29021 Mdot
.26276 .29021 Mdot
.26276 .29021 Mdot
.24316 .26668 Mdot
.22747 .251 Mdot
.22355 .251 Mdot
.21571 .24708 Mdot
.21571 .24708 Mdot
.22747 .25884 Mdot
.23139 .25884 Mdot
.23924 .26668 Mdot
.24708 .27845 Mdot
.22747 .25884 Mdot
.20002 .23139 Mdot
.19218 .22355 Mdot
.18434 .21571 Mdot
.18042 .21571 Mdot
.18826 .22355 Mdot
.19218 .22355 Mdot
.19218 .22355 Mdot
.18434 .21571 Mdot
.18042 .20394 Mdot
.18042 .20394 Mdot
.18042 .20787 Mdot
.1765 .20002 Mdot
.1765 .19218 Mdot
.1765 .19218 Mdot
.1765 .1961 Mdot
.16865 .18826 Mdot
.17257 .20394 Mdot
.1765 .21571 Mdot
.1961 .23139 Mdot
.19218 .23531 Mdot
.1961 .251 Mdot
.21179 .25884 Mdot
.20394 .24316 Mdot
.20394 .24316 Mdot
.20394 .24316 Mdot
.20002 .23924 Mdot
.1961 .22355 Mdot
.18826 .21571 Mdot
.18826 .21571 Mdot
.20002 .23139 Mdot
.19218 .22355 Mdot
.18434 .21571 Mdot
.18826 .21179 Mdot
.1765 .20002 Mdot
.18042 .20002 Mdot
.18826 .21179 Mdot
.18826 .21571 Mdot
.16865 .1961 Mdot
.1765 .1961 Mdot
.18434 .20787 Mdot
.1765 .19218 Mdot
.17257 .18826 Mdot
.16865 .18826 Mdot
.17257 .1961 Mdot
.18042 .20787 Mdot
.1765 .20394 Mdot
.17257 .1961 Mdot
.16473 .18434 Mdot
.16473 .18434 Mdot
.15689 .1765 Mdot
.15689 .1765 Mdot
.15297 .17257 Mdot
.15297 .17257 Mdot
.13728 .15297 Mdot
.1412 .16081 Mdot
.13728 .15689 Mdot
.13728 .16473 Mdot
.12944 .16081 Mdot
.12944 .15689 Mdot
.1216 .14905 Mdot
.1216 .15297 Mdot
.1216 .15297 Mdot
.12944 .16081 Mdot
.13728 .16473 Mdot
.1412 .16081 Mdot
.12944 .1412 Mdot
.03533 .04709 Mdot
.03141 .04317 Mdot
.04709 .05886 Mdot
.03141 .04317 Mdot
.01965 .02749 Mdot
.01572 .01965 Mdot
.01965 .02749 Mdot
.03533 .04709 Mdot
.04317 .05494 Mdot
.06278 .07454 Mdot
.07846 .09415 Mdot
.08239 .10199 Mdot
.07846 .09807 Mdot
.05886 .07454 Mdot
.04317 .05494 Mdot
.03141 .04317 Mdot
.02357 .03141 Mdot
.01965 .02357 Mdot
.01572 .01965 Mdot
.01572 .02357 Mdot
.01572 .02357 Mdot
.03533 .04709 Mdot
.03141 .04709 Mdot
.03141 .04709 Mdot
.03141 .03925 Mdot
.03141 .04317 Mdot
.05102 .06278 Mdot
.0667 .07454 Mdot
.1412 .16865 Mdot
.18826 .22747 Mdot
.14905 .18434 Mdot
.13336 .16081 Mdot
.1216 .13728 Mdot
.11376 .1216 Mdot
.09807 .10199 Mdot
.08239 .08239 Mdot
.08239 .08631 Mdot
.08631 .08631 Mdot
.12552 .13728 Mdot
.15297 .16865 Mdot
.18434 .20787 Mdot
.20002 .22355 Mdot
.22355 .25492 Mdot
.22747 .26276 Mdot
.22355 .25884 Mdot
.21963 .25492 Mdot
.22355 .251 Mdot
.22747 .25884 Mdot
.23531 .26276 Mdot
.24316 .27453 Mdot
.24316 .27061 Mdot
.251 .28629 Mdot
.24316 .27453 Mdot
.23924 .26276 Mdot
.251 .27453 Mdot
.25492 .28237 Mdot
.25492 .28629 Mdot
.26276 .29413 Mdot
.251 .28237 Mdot
.25884 .29021 Mdot
.26276 .29806 Mdot
.25492 .29021 Mdot
.25492 .29021 Mdot
.251 .27845 Mdot
.25492 .27453 Mdot
.26276 .28237 Mdot
.24708 .26276 Mdot
.24708 .27061 Mdot
.24316 .26668 Mdot
.24316 .27061 Mdot
.23924 .27061 Mdot
.251 .28629 Mdot
.25492 .29413 Mdot
.251 .29021 Mdot
.24316 .28237 Mdot
.24708 .29413 Mdot
.251 .29413 Mdot
.24316 .28237 Mdot
.24316 .27845 Mdot
.25492 .28237 Mdot
.25884 .29021 Mdot
.26276 .28237 Mdot
.27845 .29806 Mdot
.26668 .28629 Mdot
.26668 .29413 Mdot
.25492 .28237 Mdot
.25884 .28629 Mdot
.23139 .26276 Mdot
.21963 .251 Mdot
.21963 .251 Mdot
.21963 .251 Mdot
.23531 .26276 Mdot
.24708 .27845 Mdot
.24708 .27845 Mdot
.23139 .26276 Mdot
.21571 .24316 Mdot
.21571 .24316 Mdot
.21571 .24316 Mdot
.21179 .24316 Mdot
.1961 .23139 Mdot
.1961 .23139 Mdot
.18826 .22747 Mdot
.18826 .21963 Mdot
.18826 .21571 Mdot
.18826 .21571 Mdot
.1765 .20394 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.18826 .20787 Mdot
.18042 .19218 Mdot
.18042 .20002 Mdot
.1765 .20394 Mdot
.18434 .21571 Mdot
.20002 .24316 Mdot
.19218 .23924 Mdot
.20002 .24708 Mdot
.20787 .25884 Mdot
.20002 .251 Mdot
.20002 .24708 Mdot
.1961 .23531 Mdot
.18042 .21963 Mdot
.1765 .21571 Mdot
.18042 .21571 Mdot
.19218 .22747 Mdot
.1961 .23139 Mdot
.19218 .22355 Mdot
.1961 .21963 Mdot
.18042 .20002 Mdot
.18434 .20002 Mdot
.19218 .20002 Mdot
.18826 .1961 Mdot
.19218 .20394 Mdot
.18826 .20394 Mdot
.18434 .20002 Mdot
.18826 .20787 Mdot
.1765 .19218 Mdot
.17257 .1961 Mdot
.16473 .1961 Mdot
.16473 .19218 Mdot
.16865 .20002 Mdot
.1765 .20394 Mdot
.1765 .20002 Mdot
.16865 .1961 Mdot
.16081 .18434 Mdot
.16865 .18826 Mdot
.16081 .18042 Mdot
.15689 .17257 Mdot
.14905 .16473 Mdot
.15297 .17257 Mdot
.1412 .16081 Mdot
.13728 .16081 Mdot
.13728 .16865 Mdot
.14905 .17257 Mdot
.13728 .15689 Mdot
.12944 .14905 Mdot
.1216 .14513 Mdot
.1216 .14905 Mdot
.1216 .14905 Mdot
.12552 .15297 Mdot
.11768 .13728 Mdot
.07846 .09807 Mdot
.05886 .07454 Mdot
.04709 .05494 Mdot
.03141 .03925 Mdot
.01965 .03141 Mdot
.01965 .02749 Mdot
.0118 .01965 Mdot
.03141 .04317 Mdot
.06278 .07846 Mdot
.0667 .08631 Mdot
.05886 .07846 Mdot
.0667 .07846 Mdot
.0667 .07846 Mdot
.05494 .0667 Mdot
.04317 .05494 Mdot
.04317 .05494 Mdot
.02749 .03533 Mdot
.02749 .03533 Mdot
.01965 .02357 Mdot
.02357 .02357 Mdot
.03141 .03533 Mdot
.04317 .04317 Mdot
.03141 .03925 Mdot
.01572 .01965 Mdot
.02357 .02357 Mdot
.02749 .03141 Mdot
.02749 .03141 Mdot
.03925 .04317 Mdot
.04317 .05886 Mdot
.07062 .09023 Mdot
.07454 .09415 Mdot
.07846 .09415 Mdot
.09023 .10199 Mdot
.09023 .10591 Mdot
.10199 .11768 Mdot
.13336 .14905 Mdot
.13728 .14905 Mdot
.1216 .13728 Mdot
.1216 .1412 Mdot
.13728 .16081 Mdot
.16473 .18826 Mdot
.18434 .21571 Mdot
.20394 .23924 Mdot
.21963 .25492 Mdot
.21963 .25884 Mdot
.21571 .251 Mdot
.22747 .26276 Mdot
.22355 .25884 Mdot
.21963 .24708 Mdot
.22355 .251 Mdot
.23924 .27453 Mdot
.24316 .29021 Mdot
.24708 .29413 Mdot
.251 .28629 Mdot
.26668 .30198 Mdot
.25492 .29021 Mdot
.25492 .28629 Mdot
.25884 .29413 Mdot
.26668 .29806 Mdot
.27845 .3059 Mdot
.26668 .29806 Mdot
.251 .28629 Mdot
.25492 .28629 Mdot
.251 .28629 Mdot
.25884 .29021 Mdot
.26276 .29021 Mdot
.251 .27061 Mdot
.251 .27453 Mdot
.24708 .27453 Mdot
.24708 .27845 Mdot
.25492 .28629 Mdot
.25492 .29021 Mdot
.25884 .29413 Mdot
.26276 .30198 Mdot
.25492 .29806 Mdot
.251 .29413 Mdot
.251 .29806 Mdot
.26276 .30198 Mdot
.25884 .29806 Mdot
.25492 .29413 Mdot
.25492 .29413 Mdot
.26276 .29413 Mdot
.27453 .29413 Mdot
.27453 .29413 Mdot
.27453 .29413 Mdot
.26668 .29021 Mdot
.25492 .27453 Mdot
.26276 .28629 Mdot
.24316 .26668 Mdot
.23924 .26668 Mdot
.22747 .25884 Mdot
.22747 .251 Mdot
.24708 .26668 Mdot
.24316 .26276 Mdot
.251 .27061 Mdot
.251 .27453 Mdot
.25884 .27845 Mdot
.23924 .26276 Mdot
.22355 .24316 Mdot
.20787 .23139 Mdot
.19218 .22355 Mdot
.20787 .24316 Mdot
.20787 .23924 Mdot
.1961 .22747 Mdot
.19218 .21963 Mdot
.18826 .21571 Mdot
.1961 .22355 Mdot
.18826 .21571 Mdot
.19218 .20787 Mdot
.18826 .20394 Mdot
.18826 .21179 Mdot
.1765 .1961 Mdot
.18434 .21179 Mdot
.18042 .20787 Mdot
.18042 .21571 Mdot
.18042 .21963 Mdot
.18434 .22747 Mdot
.18434 .23139 Mdot
.18826 .23139 Mdot
.20394 .24708 Mdot
.20002 .23924 Mdot
.20002 .23531 Mdot
.19218 .22355 Mdot
.18434 .21571 Mdot
.18042 .21571 Mdot
.20002 .23139 Mdot
.19218 .21571 Mdot
.18042 .20002 Mdot
.16865 .18434 Mdot
.18826 .20394 Mdot
.18042 .1961 Mdot
.18826 .1961 Mdot
.18434 .19218 Mdot
.1765 .18826 Mdot
.1765 .19218 Mdot
.18434 .20002 Mdot
.1765 .1961 Mdot
.1765 .19218 Mdot
.16865 .18042 Mdot
.1765 .1961 Mdot
.16865 .1961 Mdot
.17257 .1961 Mdot
.16865 .19218 Mdot
.16473 .18826 Mdot
.16081 .18434 Mdot
.16473 .18826 Mdot
.16473 .18042 Mdot
.15297 .16865 Mdot
.14905 .16473 Mdot
.14513 .16081 Mdot
.1412 .15689 Mdot
.13728 .14905 Mdot
.1412 .15689 Mdot
.13728 .15297 Mdot
.12552 .1412 Mdot
.1216 .14905 Mdot
.1216 .14513 Mdot
.11768 .14513 Mdot
.11768 .1412 Mdot
.10591 .13336 Mdot
.09023 .11376 Mdot
.08631 .11376 Mdot
.08239 .10591 Mdot
.0667 .07846 Mdot
.04709 .05886 Mdot
.04317 .05886 Mdot
.03533 .04317 Mdot
.05494 .07062 Mdot
.0667 .08239 Mdot
.05494 .0667 Mdot
.04317 .05494 Mdot
.05102 .06278 Mdot
.06278 .07846 Mdot
.0667 .07846 Mdot
.06278 .07062 Mdot
.05886 .06278 Mdot
.04709 .05102 Mdot
.04317 .03925 Mdot
.04709 .04317 Mdot
.03925 .03533 Mdot
.03925 .03533 Mdot
.03533 .03141 Mdot
.02357 .01965 Mdot
.01572 .01572 Mdot
.0118 .00788 Mdot
.01572 .01572 Mdot
.02749 .03533 Mdot
.04709 .05886 Mdot
.05494 .0667 Mdot
.04709 .05886 Mdot
.03925 .05494 Mdot
.05102 .06278 Mdot
.05102 .06278 Mdot
.03925 .05102 Mdot
.05494 .07062 Mdot
.09023 .11376 Mdot
.1412 .1765 Mdot
.15689 .1961 Mdot
.16865 .21179 Mdot
.17257 .21179 Mdot
.18434 .22355 Mdot
.18826 .23139 Mdot
.19218 .23531 Mdot
.19218 .23139 Mdot
.20394 .24316 Mdot
.20394 .24316 Mdot
.20002 .23531 Mdot
.20787 .23924 Mdot
.21179 .24316 Mdot
.21571 .25492 Mdot
.22355 .26276 Mdot
.22355 .27453 Mdot
.22355 .27453 Mdot
.23531 .28629 Mdot
.251 .29806 Mdot
.25884 .29413 Mdot
.26668 .30198 Mdot
.27061 .30198 Mdot
.27453 .30198 Mdot
.27845 .30198 Mdot
.27061 .29806 Mdot
.27061 .30198 Mdot
.27061 .3059 Mdot
.27453 .30982 Mdot
.27453 .30982 Mdot
.27845 .3059 Mdot
.27453 .30198 Mdot
.27061 .29806 Mdot
.25492 .28629 Mdot
.24708 .28237 Mdot
.24708 .28237 Mdot
.25884 .30198 Mdot
.25884 .30198 Mdot
.26668 .31374 Mdot
.25884 .3059 Mdot
.24708 .29413 Mdot
.24708 .29806 Mdot
.24708 .29413 Mdot
.251 .29413 Mdot
.25884 .3059 Mdot
.251 .30198 Mdot
.25492 .29806 Mdot
.25492 .29021 Mdot
.26668 .29021 Mdot
.25884 .27845 Mdot
.27061 .29021 Mdot
.26668 .28629 Mdot
.26668 .27453 Mdot
.26668 .28237 Mdot
.26276 .28237 Mdot
.24708 .27453 Mdot
.24316 .27453 Mdot
.24708 .27061 Mdot
.24708 .26276 Mdot
.24708 .26668 Mdot
.27061 .28629 Mdot
.27061 .29021 Mdot
.26276 .28237 Mdot
.25492 .27061 Mdot
.24316 .26668 Mdot
.22747 .25884 Mdot
.22747 .25492 Mdot
.21571 .251 Mdot
.20787 .23531 Mdot
.20394 .23531 Mdot
.1961 .22355 Mdot
.19218 .21179 Mdot
.20002 .21963 Mdot
.19218 .21179 Mdot
.18434 .20787 Mdot
.18042 .20787 Mdot
.1765 .20002 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.18826 .21571 Mdot
.18042 .21963 Mdot
.18434 .21963 Mdot
.18826 .22747 Mdot
.18042 .22747 Mdot
.1961 .24316 Mdot
.21179 .25492 Mdot
.21571 .251 Mdot
.21571 .251 Mdot
.20394 .23531 Mdot
.19218 .21963 Mdot
.19218 .21571 Mdot
.1961 .21963 Mdot
.19218 .21571 Mdot
.18434 .20394 Mdot
.1765 .1961 Mdot
.1765 .19218 Mdot
.18042 .20002 Mdot
.18042 .1961 Mdot
.18042 .19218 Mdot
.1765 .18042 Mdot
.18042 .19218 Mdot
.18042 .20002 Mdot
.18042 .19218 Mdot
.1765 .18826 Mdot
.18826 .21179 Mdot
.16865 .1961 Mdot
.15689 .18434 Mdot
.16865 .1961 Mdot
.16473 .18434 Mdot
.16865 .18042 Mdot
.16865 .18434 Mdot
.15297 .16865 Mdot
.15297 .16865 Mdot
.14905 .16473 Mdot
.14905 .16081 Mdot
.1412 .15297 Mdot
.12552 .14513 Mdot
.12552 .1412 Mdot
.12552 .14905 Mdot
.11768 .14513 Mdot
.11768 .1412 Mdot
.11768 .14513 Mdot
.10199 .12552 Mdot
.10983 .13728 Mdot
.10591 .12552 Mdot
.1412 .17257 Mdot
.13728 .16473 Mdot
.12944 .15297 Mdot
.11768 .1412 Mdot
.10591 .12944 Mdot
.08239 .10199 Mdot
.0667 .07846 Mdot
.07454 .08631 Mdot
.0667 .07454 Mdot
.04317 .04317 Mdot
.04317 .05102 Mdot
.05494 .0667 Mdot
.05886 .07846 Mdot
.06278 .07846 Mdot
.0667 .07454 Mdot
.05494 .06278 Mdot
.04317 .05494 Mdot
.05102 .05102 Mdot
.05102 .04709 Mdot
.05102 .05102 Mdot
.06278 .05886 Mdot
.05886 .05886 Mdot
.03925 .04317 Mdot
.01965 .01965 Mdot
.01572 .01572 Mdot
.01965 .02749 Mdot
.05494 .0667 Mdot
.07062 .08631 Mdot
.0667 .07846 Mdot
.05494 .07062 Mdot
.05102 .0667 Mdot
.04709 .05886 Mdot
.04709 .05886 Mdot
.03141 .04317 Mdot
.03141 .04317 Mdot
.03925 .05102 Mdot
.05886 .07846 Mdot
.10199 .12944 Mdot
.1765 .21179 Mdot
.20787 .24708 Mdot
.23139 .27061 Mdot
.22747 .27061 Mdot
.21571 .24708 Mdot
.21179 .24316 Mdot
.20787 .23924 Mdot
.20002 .23139 Mdot
.20002 .22747 Mdot
.18434 .21571 Mdot
.18434 .21571 Mdot
.18042 .21179 Mdot
.19218 .22747 Mdot
.20002 .24316 Mdot
.21179 .25884 Mdot
.22747 .27453 Mdot
.23531 .28237 Mdot
.24708 .28629 Mdot
.26276 .29806 Mdot
.27061 .29806 Mdot
.26668 .29806 Mdot
.27061 .30198 Mdot
.27845 .30982 Mdot
.28237 .32158 Mdot
.27845 .31766 Mdot
.28237 .32943 Mdot
.27453 .31374 Mdot
.27061 .30982 Mdot
.27061 .30982 Mdot
.27453 .30982 Mdot
.26276 .29806 Mdot
.26276 .30198 Mdot
.25492 .29021 Mdot
.25884 .30198 Mdot
.25884 .29806 Mdot
.27061 .30982 Mdot
.25492 .29806 Mdot
.24708 .29021 Mdot
.251 .29806 Mdot
.24316 .29021 Mdot
.24316 .30198 Mdot
.24708 .30198 Mdot
.251 .3059 Mdot
.251 .29806 Mdot
.251 .29021 Mdot
.25884 .29413 Mdot
.26276 .28237 Mdot
.27061 .29021 Mdot
.26668 .27845 Mdot
.26668 .27845 Mdot
.25884 .27845 Mdot
.25884 .27845 Mdot
.251 .27845 Mdot
.25492 .27845 Mdot
.251 .27845 Mdot
.23924 .26276 Mdot
.25884 .27845 Mdot
.26276 .28237 Mdot
.25884 .27453 Mdot
.26276 .28237 Mdot
.26276 .27845 Mdot
.251 .26668 Mdot
.26276 .27845 Mdot
.25884 .28629 Mdot
.23531 .27061 Mdot
.22747 .25884 Mdot
.21963 .24708 Mdot
.21179 .23531 Mdot
.20394 .22355 Mdot
.18826 .21179 Mdot
.18042 .20002 Mdot
.19218 .21179 Mdot
.19218 .20787 Mdot
.18042 .1961 Mdot
.18434 .20002 Mdot
.18042 .20002 Mdot
.19218 .21963 Mdot
.18826 .21963 Mdot
.18826 .22747 Mdot
.19218 .23531 Mdot
.18434 .22747 Mdot
.18826 .23139 Mdot
.19218 .23924 Mdot
.20394 .251 Mdot
.21571 .251 Mdot
.20787 .23924 Mdot
.19218 .21963 Mdot
.18042 .20394 Mdot
.18042 .20394 Mdot
.19218 .21571 Mdot
.18434 .20787 Mdot
.18434 .20394 Mdot
.18042 .20787 Mdot
.1765 .20002 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.17257 .18042 Mdot
.1765 .18434 Mdot
.17257 .18042 Mdot
.18042 .19218 Mdot
.18042 .1961 Mdot
.1765 .20002 Mdot
.17257 .1961 Mdot
.16473 .18434 Mdot
.16865 .18826 Mdot
.17257 .1961 Mdot
.16865 .18434 Mdot
.16865 .18042 Mdot
.16081 .1765 Mdot
.15297 .17257 Mdot
.1412 .15297 Mdot
.13336 .14513 Mdot
.13336 .15297 Mdot
.12552 .14905 Mdot
.12944 .15689 Mdot
.1216 .14513 Mdot
.1216 .14905 Mdot
.10983 .13728 Mdot
.10591 .13336 Mdot
.10591 .13728 Mdot
.11376 .13728 Mdot
.10591 .1216 Mdot
.13728 .15689 Mdot
.14905 .1765 Mdot
.1412 .16865 Mdot
.13728 .16473 Mdot
.1412 .16473 Mdot
.13728 .16081 Mdot
.12552 .14905 Mdot
.12552 .14513 Mdot
.08239 .09415 Mdot
.06278 .07062 Mdot
.05494 .06278 Mdot
.05886 .07062 Mdot
.0667 .08631 Mdot
.0667 .08631 Mdot
.0667 .08239 Mdot
.05494 .07062 Mdot
.04317 .05494 Mdot
.03925 .04709 Mdot
.05494 .0667 Mdot
.05494 .0667 Mdot
.0667 .07454 Mdot
.05886 .0667 Mdot
.05886 .0667 Mdot
.05102 .05886 Mdot
.02357 .02749 Mdot
.02749 .03141 Mdot
.06278 .07846 Mdot
.08239 .09807 Mdot
.07062 .08631 Mdot
.04709 .05494 Mdot
.03141 .03925 Mdot
.02749 .03925 Mdot
.03141 .03925 Mdot
.03533 .04317 Mdot
.03533 .04709 Mdot
.03533 .04317 Mdot
.03141 .03925 Mdot
.05886 .07846 Mdot
.10199 .11768 Mdot
.13728 .15297 Mdot
.15689 .17257 Mdot
.19218 .21571 Mdot
.22747 .25492 Mdot
.23531 .26668 Mdot
.22747 .26276 Mdot
.21963 .25492 Mdot
.20787 .24316 Mdot
.18826 .21963 Mdot
.17257 .20002 Mdot
.15297 .18434 Mdot
.1412 .16865 Mdot
.13728 .16865 Mdot
.1765 .21571 Mdot
.20394 .24708 Mdot
.22355 .27061 Mdot
.24316 .28629 Mdot
.26276 .30198 Mdot
.27061 .30198 Mdot
.26668 .29806 Mdot
.26276 .29806 Mdot
.26276 .29413 Mdot
.25492 .29021 Mdot
.26668 .30198 Mdot
.27453 .31374 Mdot
.27845 .31766 Mdot
.27453 .31374 Mdot
.29021 .33335 Mdot
.28629 .32943 Mdot
.27845 .31374 Mdot
.27061 .30198 Mdot
.27061 .30198 Mdot
.26668 .29413 Mdot
.26668 .29413 Mdot
.27453 .31374 Mdot
.26668 .30198 Mdot
.27061 .30982 Mdot
.27061 .30982 Mdot
.25884 .3059 Mdot
.251 .30198 Mdot
.26276 .3059 Mdot
.26668 .30982 Mdot
.27061 .30982 Mdot
.25884 .29021 Mdot
.27061 .29021 Mdot
.26276 .27845 Mdot
.26668 .28237 Mdot
.27061 .28237 Mdot
.26276 .27845 Mdot
.26276 .28237 Mdot
.25492 .28237 Mdot
.25492 .28629 Mdot
.26276 .3059 Mdot
.27061 .30982 Mdot
.26668 .29806 Mdot
.27061 .29806 Mdot
.27061 .29413 Mdot
.27453 .29021 Mdot
.251 .26668 Mdot
.24708 .26276 Mdot
.24316 .26276 Mdot
.25492 .28237 Mdot
.24316 .27453 Mdot
.23924 .27453 Mdot
.24316 .27845 Mdot
.23924 .27453 Mdot
.22355 .24708 Mdot
.20787 .23139 Mdot
.18434 .20787 Mdot
.18826 .20787 Mdot
.18042 .1961 Mdot
.18042 .20002 Mdot
.18826 .20002 Mdot
.18826 .20002 Mdot
.18434 .20002 Mdot
.18826 .21571 Mdot
.1961 .22747 Mdot
.18042 .21571 Mdot
.18434 .22747 Mdot
.18826 .23139 Mdot
.18826 .23139 Mdot
.18042 .22355 Mdot
.18434 .22747 Mdot
.20787 .24708 Mdot
.21179 .24708 Mdot
.20787 .23924 Mdot
.20002 .22355 Mdot
.19218 .21571 Mdot
.19218 .21571 Mdot
.19218 .21571 Mdot
.20002 .22355 Mdot
.1961 .21963 Mdot
.18826 .21179 Mdot
.17257 .19218 Mdot
.16473 .18434 Mdot
.16473 .18042 Mdot
.15689 .17257 Mdot
.16473 .18434 Mdot
.1765 .1961 Mdot
.1765 .20002 Mdot
.17257 .20002 Mdot
.17257 .18826 Mdot
.16865 .18826 Mdot
.17257 .20002 Mdot
.17257 .20394 Mdot
.1765 .20394 Mdot
.15689 .16865 Mdot
.16081 .16473 Mdot
.15689 .16081 Mdot
.1412 .14905 Mdot
.14513 .15689 Mdot
.13336 .14905 Mdot
.1216 .1412 Mdot
.13728 .16081 Mdot
.12944 .15297 Mdot
.12552 .14905 Mdot
.11768 .14513 Mdot
.1216 .1412 Mdot
.11768 .13728 Mdot
.11768 .12944 Mdot
.10591 .1216 Mdot
.16081 .18434 Mdot
.16865 .18826 Mdot
.15297 .17257 Mdot
.1412 .16473 Mdot
.14513 .16473 Mdot
.15689 .18042 Mdot
.15297 .18042 Mdot
.1412 .16473 Mdot
.13728 .15689 Mdot
.11768 .13336 Mdot
.09415 .10983 Mdot
.07846 .09807 Mdot
.08631 .10199 Mdot
.07062 .09023 Mdot
.05102 .07062 Mdot
.04709 .06278 Mdot
.04317 .05886 Mdot
.04709 .06278 Mdot
.05886 .07846 Mdot
.06278 .08239 Mdot
.05886 .07062 Mdot
.05494 .06278 Mdot
.05102 .05494 Mdot
.05886 .06278 Mdot
.05102 .05494 Mdot
.06278 .0667 Mdot
.08239 .09415 Mdot
.08631 .10199 Mdot
.07062 .08631 Mdot
.06278 .07846 Mdot
.04709 .05886 Mdot
.02357 .03533 Mdot
.02749 .03925 Mdot
.03141 .03925 Mdot
.03533 .03925 Mdot
.03533 .04709 Mdot
.03533 .04317 Mdot
.03925 .04709 Mdot
.06278 .07846 Mdot
.07846 .09023 Mdot
.09807 .10983 Mdot
.09807 .10591 Mdot
.18434 .21179 Mdot
.24708 .28629 Mdot
.26276 .3059 Mdot
.25884 .30198 Mdot
.251 .29021 Mdot
.20787 .24316 Mdot
.1765 .20787 Mdot
.1412 .16865 Mdot
.10983 .12944 Mdot
.09023 .10199 Mdot
.10199 .1216 Mdot
.14513 .1765 Mdot
.18042 .21179 Mdot
.21179 .25492 Mdot
.24316 .29021 Mdot
.26668 .3059 Mdot
.26276 .29806 Mdot
.251 .28629 Mdot
.25492 .28629 Mdot
.251 .28629 Mdot
.25884 .29021 Mdot
.26668 .29021 Mdot
.27453 .30198 Mdot
.28237 .31374 Mdot
.28237 .32158 Mdot
.27845 .32158 Mdot
.27453 .31766 Mdot
.26668 .30982 Mdot
.27453 .31766 Mdot
.27453 .31374 Mdot
.28237 .31374 Mdot
.27453 .3059 Mdot
.28237 .31374 Mdot
.27845 .30982 Mdot
.27061 .30198 Mdot
.26668 .3059 Mdot
.26668 .3059 Mdot
.26276 .3059 Mdot
.25884 .29806 Mdot
.25884 .29806 Mdot
.26276 .29413 Mdot
.27845 .30198 Mdot
.27453 .29806 Mdot
.27453 .29413 Mdot
.27453 .29021 Mdot
.27845 .29413 Mdot
.28237 .30198 Mdot
.28237 .3059 Mdot
.27845 .30982 Mdot
.27061 .3059 Mdot
.27061 .3059 Mdot
.27453 .30982 Mdot
.27453 .30982 Mdot
.26668 .30198 Mdot
.27061 .29806 Mdot
.25492 .27453 Mdot
.24316 .25884 Mdot
.23924 .26276 Mdot
.23139 .25884 Mdot
.23924 .26668 Mdot
.23924 .26668 Mdot
.24708 .28237 Mdot
.23531 .26668 Mdot
.22747 .25492 Mdot
.23531 .26668 Mdot
.21963 .251 Mdot
.20787 .22747 Mdot
.18826 .20394 Mdot
.18434 .20394 Mdot
.1961 .21963 Mdot
.19218 .21571 Mdot
.18826 .21179 Mdot
.18826 .21179 Mdot
.20394 .23139 Mdot
.18434 .21963 Mdot
.18826 .22747 Mdot
.1961 .23924 Mdot
.1961 .24316 Mdot
.19218 .23924 Mdot
.18042 .21963 Mdot
.18826 .22747 Mdot
.1961 .23531 Mdot
.20787 .23531 Mdot
.21179 .23531 Mdot
.20787 .23139 Mdot
.18434 .20787 Mdot
.18042 .20002 Mdot
.18042 .20394 Mdot
.1961 .21963 Mdot
.1961 .21963 Mdot
.20002 .22355 Mdot
.18434 .20394 Mdot
.18042 .20394 Mdot
.1765 .1961 Mdot
.16865 .18826 Mdot
.17257 .20002 Mdot
.18042 .20394 Mdot
.18042 .20787 Mdot
.17257 .19218 Mdot
.16473 .18434 Mdot
.18042 .20394 Mdot
.17257 .1961 Mdot
.16865 .18434 Mdot
.17257 .18434 Mdot
.1765 .18434 Mdot
.16473 .17257 Mdot
.15297 .16473 Mdot
.14513 .15689 Mdot
.13728 .14905 Mdot
.12944 .14513 Mdot
.13336 .15297 Mdot
.12944 .1412 Mdot
.12552 .1412 Mdot
.11768 .13728 Mdot
.12552 .1412 Mdot
.12552 .1412 Mdot
.12944 .1412 Mdot
.11768 .12944 Mdot
.16473 .18042 Mdot
.16865 .18434 Mdot
.16473 .17257 Mdot
.15689 .16865 Mdot
.14905 .16081 Mdot
.14905 .16865 Mdot
.15297 .17257 Mdot
.15689 .18042 Mdot
.15297 .17257 Mdot
.14905 .1765 Mdot
.14513 .17257 Mdot
.13336 .16081 Mdot
.11768 .1412 Mdot
.08239 .10199 Mdot
.05886 .07454 Mdot
.05102 .06278 Mdot
.0667 .07454 Mdot
.05494 .05886 Mdot
.05494 .05102 Mdot
.06278 .05886 Mdot
.06278 .06278 Mdot
.02749 .01965 Mdot
.01965 .02357 Mdot
.02357 .02749 Mdot
.02749 .03141 Mdot
.05886 .0667 Mdot
.08239 .09415 Mdot
.09807 .1216 Mdot
.09023 .11376 Mdot
.0667 .09023 Mdot
.05102 .0667 Mdot
.03925 .05102 Mdot
.04317 .05102 Mdot
.03141 .03925 Mdot
.05102 .05886 Mdot
.05102 .06278 Mdot
.04709 .05494 Mdot
.03925 .04317 Mdot
.03925 .03925 Mdot
.05886 .05494 Mdot
.07062 .07062 Mdot
.07846 .07846 Mdot
.09807 .09807 Mdot
.1412 .15689 Mdot
.20002 .22355 Mdot
.23531 .26668 Mdot
.27453 .30982 Mdot
.20394 .23139 Mdot
.16081 .18434 Mdot
.12944 .15297 Mdot
.10591 .1216 Mdot
.09807 .10591 Mdot
.09023 .09807 Mdot
.09415 .11376 Mdot
.13728 .16081 Mdot
.1765 .21179 Mdot
.20394 .24708 Mdot
.23139 .27453 Mdot
.23531 .28237 Mdot
.24316 .28629 Mdot
.25492 .29021 Mdot
.251 .28629 Mdot
.251 .28237 Mdot
.25492 .28629 Mdot
.25884 .28237 Mdot
.26276 .29413 Mdot
.26276 .30198 Mdot
.25492 .30198 Mdot
.25884 .30982 Mdot
.25884 .31374 Mdot
.26668 .30982 Mdot
.26668 .31374 Mdot
.26668 .3059 Mdot
.27453 .30982 Mdot
.27845 .31374 Mdot
.27453 .3059 Mdot
.27061 .3059 Mdot
.25492 .29021 Mdot
.25492 .29021 Mdot
.25492 .29413 Mdot
.25492 .29806 Mdot
.251 .29413 Mdot
.25884 .29806 Mdot
.26668 .30198 Mdot
.27453 .29806 Mdot
.27453 .29413 Mdot
.27061 .28629 Mdot
.27845 .29413 Mdot
.27453 .29021 Mdot
.28237 .29413 Mdot
.27453 .29806 Mdot
.25492 .28629 Mdot
.26276 .29806 Mdot
.25884 .29806 Mdot
.26668 .3059 Mdot
.25884 .29413 Mdot
.25884 .28629 Mdot
.25884 .28629 Mdot
.24316 .25884 Mdot
.23139 .24708 Mdot
.22747 .24316 Mdot
.22355 .24316 Mdot
.23139 .25884 Mdot
.23531 .26276 Mdot
.22747 .25884 Mdot
.22747 .25884 Mdot
.22355 .25492 Mdot
.21963 .25492 Mdot
.21571 .24708 Mdot
.20002 .22355 Mdot
.1961 .22355 Mdot
.20394 .22747 Mdot
.18434 .21179 Mdot
.18042 .20787 Mdot
.1765 .20787 Mdot
.18434 .21963 Mdot
.18826 .21963 Mdot
.18826 .23139 Mdot
.18826 .23531 Mdot
.18434 .23139 Mdot
.18826 .23531 Mdot
.18826 .23531 Mdot
.18042 .22355 Mdot
.18826 .22747 Mdot
.19218 .23531 Mdot
.20394 .23924 Mdot
.19218 .21571 Mdot
.19218 .21571 Mdot
.18826 .21179 Mdot
.18434 .21179 Mdot
.18434 .21179 Mdot
.1961 .22355 Mdot
.21179 .23531 Mdot
.20002 .22747 Mdot
.19218 .21571 Mdot
.18434 .20787 Mdot
.17257 .1961 Mdot
.16081 .18826 Mdot
.15689 .18042 Mdot
.16865 .19218 Mdot
.16473 .18826 Mdot
.16865 .19218 Mdot
.16473 .1765 Mdot
.17257 .18434 Mdot
.1765 .18434 Mdot
.17257 .18434 Mdot
.16865 .18042 Mdot
.16081 .16473 Mdot
.14905 .15297 Mdot
.1412 .14905 Mdot
.13336 .14513 Mdot
.12944 .13728 Mdot
.12552 .13336 Mdot
.1216 .13336 Mdot
.12552 .13728 Mdot
.11376 .12552 Mdot
.1216 .13728 Mdot
.13336 .14513 Mdot
.12552 .13728 Mdot
.10983 .12944 Mdot
.1412 .17257 Mdot
.16473 .19218 Mdot
.18042 .1961 Mdot
.18434 .1961 Mdot
.18434 .18826 Mdot
.17257 .18042 Mdot
.18434 .19218 Mdot
.17257 .18042 Mdot
.16473 .16865 Mdot
.18042 .18826 Mdot
.18434 .1961 Mdot
.18826 .20394 Mdot
.15297 .17257 Mdot
.09807 .11376 Mdot
.09023 .09415 Mdot
.07846 .07062 Mdot
.07454 .0667 Mdot
.07062 .05886 Mdot
.05886 .04709 Mdot
.05102 .04317 Mdot
.03925 .03533 Mdot
.02357 .02357 Mdot
.01965 .01965 Mdot
.02357 .02749 Mdot
.01572 .01965 Mdot
.03925 .04709 Mdot
.09023 .11376 Mdot
.10983 .13336 Mdot
.09023 .10983 Mdot
.0667 .07846 Mdot
.05102 .05886 Mdot
.03925 .04709 Mdot
.04317 .05102 Mdot
.04317 .05102 Mdot
.05886 .07062 Mdot
.07062 .08239 Mdot
.05886 .06278 Mdot
.06278 .05886 Mdot
.05102 .04709 Mdot
.05886 .05102 Mdot
.09023 .08239 Mdot
.10199 .09415 Mdot
.08631 .08239 Mdot
.09415 .09415 Mdot
.10591 .10591 Mdot
.13336 .13728 Mdot
.16865 .18042 Mdot
.15689 .17257 Mdot
.1216 .13728 Mdot
.09415 .10983 Mdot
.05886 .06278 Mdot
.09807 .11376 Mdot
.1216 .14513 Mdot
.13728 .16473 Mdot
.14513 .1765 Mdot
.14905 .18434 Mdot
.16473 .20394 Mdot
.1765 .22355 Mdot
.1961 .24316 Mdot
.21179 .26276 Mdot
.23924 .28237 Mdot
.25884 .29806 Mdot
.26668 .3059 Mdot
.25884 .29413 Mdot
.25884 .29806 Mdot
.26668 .30982 Mdot
.26668 .31374 Mdot
.26668 .31766 Mdot
.27453 .32943 Mdot
.28629 .33727 Mdot
.28237 .32943 Mdot
.28237 .3255 Mdot
.28237 .3255 Mdot
.28237 .3255 Mdot
.27453 .31766 Mdot
.26668 .3059 Mdot
.26276 .3059 Mdot
.27061 .31374 Mdot
.26668 .31374 Mdot
.26668 .31374 Mdot
.25884 .3059 Mdot
.25884 .3059 Mdot
.25492 .29413 Mdot
.26276 .30198 Mdot
.27453 .30982 Mdot
.27845 .30982 Mdot
.28629 .3059 Mdot
.28629 .3059 Mdot
.29021 .3059 Mdot
.29806 .31374 Mdot
.29806 .32158 Mdot
.29021 .31374 Mdot
.27453 .3059 Mdot
.27845 .30982 Mdot
.26668 .30198 Mdot
.26276 .29806 Mdot
.27061 .3059 Mdot
.27061 .3059 Mdot
.25884 .28629 Mdot
.25884 .27845 Mdot
.251 .26668 Mdot
.23924 .26276 Mdot
.24708 .27453 Mdot
.251 .28629 Mdot
.251 .28629 Mdot
.24316 .27845 Mdot
.23531 .27453 Mdot
.22355 .26668 Mdot
.23924 .29021 Mdot
.21571 .25884 Mdot
.21963 .25884 Mdot
.20787 .24708 Mdot
.1961 .22747 Mdot
.1961 .22747 Mdot
.18826 .21963 Mdot
.18434 .21963 Mdot
.20002 .23139 Mdot
.19218 .23139 Mdot
.1961 .24316 Mdot
.1961 .23924 Mdot
.1961 .23531 Mdot
.1961 .23924 Mdot
.20002 .23531 Mdot
.21179 .24708 Mdot
.21571 .251 Mdot
.21963 .251 Mdot
.21179 .23924 Mdot
.20787 .23139 Mdot
.18826 .21179 Mdot
.19218 .21571 Mdot
.19218 .21963 Mdot
.20394 .22747 Mdot
.22355 .24316 Mdot
.21963 .24708 Mdot
.21571 .24316 Mdot
.20002 .22747 Mdot
.18042 .21179 Mdot
.16865 .20002 Mdot
.16865 .20002 Mdot
.16865 .20002 Mdot
.17257 .1961 Mdot
.18042 .20002 Mdot
.16865 .18826 Mdot
.17257 .18826 Mdot
.17257 .19218 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.15689 .1765 Mdot
.14513 .16081 Mdot
.15689 .17257 Mdot
.15689 .16865 Mdot
.14513 .15689 Mdot
.1412 .15689 Mdot
.1412 .16081 Mdot
.13336 .15297 Mdot
.13336 .15297 Mdot
.13336 .15689 Mdot
.12552 .15297 Mdot
.12552 .14905 Mdot
.12944 .14905 Mdot
.09415 .12552 Mdot
.11768 .14513 Mdot
.1412 .16473 Mdot
.16081 .16865 Mdot
.16865 .1765 Mdot
.1765 .18434 Mdot
.18434 .1961 Mdot
.18434 .19218 Mdot
.18826 .1961 Mdot
.18434 .1961 Mdot
.19218 .21963 Mdot
.21571 .251 Mdot
.18826 .21963 Mdot
.13336 .15297 Mdot
.1216 .13336 Mdot
.11768 .11768 Mdot
.09023 .08239 Mdot
.0667 .0667 Mdot
.05494 .05886 Mdot
.05102 .05494 Mdot
.02357 .02357 Mdot
.01965 .01572 Mdot
.01572 .01572 Mdot
.00788 .01572 Mdot
.0118 .01965 Mdot
.02357 .03141 Mdot
.07062 .09023 Mdot
.10199 .12552 Mdot
.09807 .11376 Mdot
.08631 .08631 Mdot
.0667 .0667 Mdot
.05102 .05102 Mdot
.04709 .05102 Mdot
.05886 .07062 Mdot
.08239 .09023 Mdot
.09415 .10199 Mdot
.08631 .09415 Mdot
.06278 .07062 Mdot
.05102 .05102 Mdot
.06278 .07062 Mdot
.07846 .07454 Mdot
.09415 .09023 Mdot
.07846 .0667 Mdot
.07454 .07062 Mdot
.08239 .07846 Mdot
.08239 .07846 Mdot
.09807 .10199 Mdot
.10983 .1216 Mdot
.08631 .09807 Mdot
.07062 .08239 Mdot
.06278 .06278 Mdot
.05102 .04709 Mdot
.10983 .1216 Mdot
.14513 .16865 Mdot
.14513 .16865 Mdot
.11376 .13728 Mdot
.10591 .13728 Mdot
.10199 .12944 Mdot
.11768 .14905 Mdot
.14513 .18042 Mdot
.18042 .22355 Mdot
.21179 .25884 Mdot
.23139 .28237 Mdot
.24708 .29413 Mdot
.25492 .3059 Mdot
.25884 .3059 Mdot
.26668 .32158 Mdot
.27061 .33335 Mdot
.27061 .32158 Mdot
.28629 .32943 Mdot
.28237 .32158 Mdot
.27845 .31374 Mdot
.28629 .3255 Mdot
.28629 .3255 Mdot
.28237 .3255 Mdot
.27845 .32158 Mdot
.27061 .31374 Mdot
.26668 .30982 Mdot
.26668 .30982 Mdot
.27845 .31766 Mdot
.26668 .3059 Mdot
.27061 .30982 Mdot
.25884 .29413 Mdot
.25884 .29806 Mdot
.26668 .30198 Mdot
.27453 .30198 Mdot
.28237 .3059 Mdot
.28629 .3059 Mdot
.29413 .30982 Mdot
.29413 .30982 Mdot
.30198 .31766 Mdot
.32943 .34511 Mdot
.32158 .33727 Mdot
.30198 .32158 Mdot
.29021 .31374 Mdot
.28629 .30982 Mdot
.27845 .30198 Mdot
.27061 .29806 Mdot
.27061 .29806 Mdot
.27061 .29806 Mdot
.27061 .30198 Mdot
.26276 .28629 Mdot
.26276 .29021 Mdot
.26276 .29806 Mdot
.25884 .29413 Mdot
.25492 .28629 Mdot
.24708 .28237 Mdot
.23924 .27845 Mdot
.23924 .28629 Mdot
.23139 .27845 Mdot
.22355 .27453 Mdot
.21571 .26276 Mdot
.20787 .25492 Mdot
.1961 .24316 Mdot
.19218 .22747 Mdot
.1961 .22747 Mdot
.20002 .24316 Mdot
.20394 .24316 Mdot
.21571 .24708 Mdot
.21179 .24316 Mdot
.20787 .24708 Mdot
.20002 .23924 Mdot
.20394 .23139 Mdot
.21179 .23531 Mdot
.20787 .23139 Mdot
.21963 .24708 Mdot
.21571 .24708 Mdot
.21571 .251 Mdot
.20787 .24316 Mdot
.20394 .23924 Mdot
.20002 .23531 Mdot
.18042 .21179 Mdot
.18826 .20787 Mdot
.20002 .22355 Mdot
.20002 .22747 Mdot
.20394 .23531 Mdot
.19218 .22747 Mdot
.1765 .21179 Mdot
.17257 .20002 Mdot
.16473 .1961 Mdot
.15689 .1765 Mdot
.16081 .18042 Mdot
.16081 .1765 Mdot
.16865 .18434 Mdot
.18042 .1961 Mdot
.17257 .1961 Mdot
.16473 .18434 Mdot
.17257 .19218 Mdot
.15689 .17257 Mdot
.13728 .15689 Mdot
.14905 .16473 Mdot
.14513 .15689 Mdot
.14513 .16081 Mdot
.1412 .15297 Mdot
.13336 .16081 Mdot
.12944 .16081 Mdot
.13336 .16865 Mdot
.1412 .17257 Mdot
.12944 .15689 Mdot
.13728 .15689 Mdot
.10591 .12552 Mdot
.10591 .12552 Mdot
.09415 .11376 Mdot
.10591 .11768 Mdot
.1216 .13336 Mdot
.14905 .15689 Mdot
.18042 .1961 Mdot
.18826 .20002 Mdot
.1961 .21571 Mdot
.19218 .21571 Mdot
.18042 .20787 Mdot
.18434 .21571 Mdot
.19218 .22355 Mdot
.18042 .21179 Mdot
.15689 .18042 Mdot
.15297 .17257 Mdot
.13336 .14905 Mdot
.12944 .1412 Mdot
.12552 .13336 Mdot
.10591 .11768 Mdot
.08239 .09023 Mdot
.05494 .05886 Mdot
.03533 .03925 Mdot
.02357 .02749 Mdot
.01965 .02749 Mdot
.01965 .02357 Mdot
.0667 .08631 Mdot
.09415 .11376 Mdot
.09023 .10983 Mdot
.08239 .08631 Mdot
.07454 .07454 Mdot
.07846 .07454 Mdot
.07454 .07454 Mdot
.08239 .07846 Mdot
.09807 .10591 Mdot
.11768 .13336 Mdot
.12552 .14905 Mdot
.1216 .14513 Mdot
.09415 .10983 Mdot
.09023 .10591 Mdot
.09807 .11376 Mdot
.07846 .09023 Mdot
.0667 .0667 Mdot
.05886 .05886 Mdot
.05886 .06278 Mdot
.05494 .06278 Mdot
.05886 .0667 Mdot
.07846 .09023 Mdot
.0667 .07846 Mdot
.05886 .07454 Mdot
.05102 .06278 Mdot
.04317 .04709 Mdot
.14513 .17257 Mdot
.18434 .21571 Mdot
.1765 .21179 Mdot
.10591 .13336 Mdot
.09415 .1216 Mdot
.07454 .09023 Mdot
.07454 .09415 Mdot
.07846 .09807 Mdot
.09807 .11768 Mdot
.11768 .14513 Mdot
.14905 .18042 Mdot
.18042 .21571 Mdot
.20394 .24708 Mdot
.23139 .27453 Mdot
.25492 .3059 Mdot
.26668 .30982 Mdot
.27845 .3255 Mdot
.28237 .32158 Mdot
.28629 .32158 Mdot
.28629 .32943 Mdot
.29021 .33335 Mdot
.27845 .3255 Mdot
.27453 .32943 Mdot
.27845 .32943 Mdot
.28237 .33335 Mdot
.27453 .32158 Mdot
.27453 .32158 Mdot
.27061 .30982 Mdot
.27453 .31374 Mdot
.27845 .31374 Mdot
.28237 .30982 Mdot
.28629 .31374 Mdot
.28629 .30982 Mdot
.28629 .3059 Mdot
.28629 .30982 Mdot
.27845 .29806 Mdot
.28629 .3059 Mdot
.29413 .30982 Mdot
.30198 .31766 Mdot
.31374 .3255 Mdot
.31766 .32943 Mdot
.30982 .32158 Mdot
.29806 .31766 Mdot
.29806 .31766 Mdot
.28629 .30982 Mdot
.27061 .3059 Mdot
.27453 .31374 Mdot
.25884 .29806 Mdot
.26276 .30198 Mdot
.251 .28237 Mdot
.25492 .27845 Mdot
.26276 .28629 Mdot
.26276 .28237 Mdot
.26668 .28629 Mdot
.26276 .28629 Mdot
.251 .28237 Mdot
.24708 .28237 Mdot
.23531 .27061 Mdot
.21963 .25884 Mdot
.21571 .25884 Mdot
.20787 .251 Mdot
.20002 .23924 Mdot
.20002 .23531 Mdot
.19218 .22747 Mdot
.1961 .23139 Mdot
.20394 .251 Mdot
.21963 .26276 Mdot
.20002 .24316 Mdot
.20394 .24708 Mdot
.1961 .23531 Mdot
.21179 .24316 Mdot
.21179 .23531 Mdot
.21963 .23924 Mdot
.21963 .24316 Mdot
.21963 .251 Mdot
.20787 .23531 Mdot
.21571 .24708 Mdot
.21571 .251 Mdot
.21179 .24316 Mdot
.19218 .21963 Mdot
.1765 .20787 Mdot
.17257 .20787 Mdot
.1765 .21179 Mdot
.1765 .20787 Mdot
.19218 .22355 Mdot
.18042 .21179 Mdot
.16865 .1961 Mdot
.16473 .18434 Mdot
.17257 .19218 Mdot
.1765 .20002 Mdot
.16473 .18042 Mdot
.16865 .18826 Mdot
.16473 .18826 Mdot
.16081 .18434 Mdot
.16865 .18826 Mdot
.16473 .19218 Mdot
.16081 .19218 Mdot
.14905 .18042 Mdot
.13728 .16865 Mdot
.12944 .15689 Mdot
.12552 .15297 Mdot
.1412 .16081 Mdot
.1412 .16473 Mdot
.12552 .15689 Mdot
.1216 .14513 Mdot
.13336 .15689 Mdot
.12552 .14513 Mdot
.12552 .14513 Mdot
.12552 .1412 Mdot
.10983 .1216 Mdot
.09807 .11376 Mdot
.09023 .10591 Mdot
.09023 .10983 Mdot
.11376 .12552 Mdot
.12944 .13728 Mdot
.1412 .15297 Mdot
.16473 .1765 Mdot
.1765 .19218 Mdot
.18434 .20787 Mdot
.18826 .21963 Mdot
.21179 .24708 Mdot
.18042 .21571 Mdot
.16865 .20002 Mdot
.17257 .20394 Mdot
.18042 .20394 Mdot
.18826 .20787 Mdot
.18826 .20394 Mdot
.18826 .20002 Mdot
.17257 .18042 Mdot
.14513 .15689 Mdot
.11768 .12944 Mdot
.0667 .07454 Mdot
.04317 .05494 Mdot
.03141 .03533 Mdot
.05102 .06278 Mdot
.07846 .09023 Mdot
.08631 .10591 Mdot
.07846 .09415 Mdot
.07846 .07846 Mdot
.07454 .07454 Mdot
.07846 .07846 Mdot
.09415 .09807 Mdot
.11768 .12944 Mdot
.11376 .12552 Mdot
.13336 .15297 Mdot
.13728 .16473 Mdot
.14513 .17257 Mdot
.1412 .16865 Mdot
.15297 .1765 Mdot
.10199 .11768 Mdot
.07454 .08239 Mdot
.05494 .05886 Mdot
.05494 .05494 Mdot
.05494 .05886 Mdot
.06278 .0667 Mdot
.07062 .07846 Mdot
.0667 .08239 Mdot
.05886 .07062 Mdot
.05494 .0667 Mdot
.04709 .05886 Mdot
.09807 .1216 Mdot
.11376 .14513 Mdot
.12552 .15689 Mdot
.11768 .14905 Mdot
.10983 .13728 Mdot
.09023 .10983 Mdot
.07846 .08631 Mdot
.07846 .08239 Mdot
.08239 .09023 Mdot
.07846 .09023 Mdot
.07846 .09023 Mdot
.09807 .11768 Mdot
.13336 .16081 Mdot
.16865 .20394 Mdot
.21179 .251 Mdot
.251 .29021 Mdot
.26276 .30198 Mdot
.27453 .31766 Mdot
.27845 .31766 Mdot
.28629 .32158 Mdot
.28629 .32943 Mdot
.28629 .33335 Mdot
.28237 .32943 Mdot
.28629 .33335 Mdot
.29413 .34119 Mdot
.28629 .32943 Mdot
.28629 .32943 Mdot
.28237 .32943 Mdot
.27453 .32158 Mdot
.27061 .3059 Mdot
.27453 .3059 Mdot
.29806 .32158 Mdot
.29413 .32158 Mdot
.29021 .32158 Mdot
.28629 .3059 Mdot
.28629 .3059 Mdot
.28629 .30982 Mdot
.29021 .31374 Mdot
.29021 .30982 Mdot
.30982 .32943 Mdot
.30198 .31766 Mdot
.3059 .32158 Mdot
.30982 .32943 Mdot
.30198 .33335 Mdot
.29806 .3255 Mdot
.27845 .31766 Mdot
.27453 .31766 Mdot
.26668 .30982 Mdot
.27845 .32158 Mdot
.28237 .3255 Mdot
.27061 .30982 Mdot
.26668 .29806 Mdot
.26668 .29806 Mdot
.26668 .29413 Mdot
.26668 .28629 Mdot
.25492 .27845 Mdot
.25492 .28629 Mdot
.23531 .26668 Mdot
.23139 .26276 Mdot
.23531 .27061 Mdot
.21963 .25884 Mdot
.20394 .23924 Mdot
.20394 .23924 Mdot
.20787 .24708 Mdot
.20394 .23924 Mdot
.20787 .24316 Mdot
.21571 .251 Mdot
.21179 .24708 Mdot
.20787 .24316 Mdot
.21179 .24316 Mdot
.20787 .23531 Mdot
.20394 .23139 Mdot
.21571 .24316 Mdot
.21571 .23924 Mdot
.21571 .24708 Mdot
.21179 .23924 Mdot
.21179 .23924 Mdot
.21571 .24316 Mdot
.20787 .23531 Mdot
.1961 .23139 Mdot
.19218 .23531 Mdot
.18434 .22747 Mdot
.18042 .22355 Mdot
.16865 .21179 Mdot
.1765 .21179 Mdot
.18826 .21963 Mdot
.1765 .20002 Mdot
.16865 .19218 Mdot
.16473 .18042 Mdot
.1765 .1961 Mdot
.17257 .19218 Mdot
.16081 .18826 Mdot
.16081 .19218 Mdot
.16473 .19218 Mdot
.15689 .18434 Mdot
.16081 .19218 Mdot
.15689 .19218 Mdot
.13728 .17257 Mdot
.14513 .18042 Mdot
.14513 .18042 Mdot
.13728 .17257 Mdot
.1412 .17257 Mdot
.1412 .17257 Mdot
.12552 .16081 Mdot
.12552 .15689 Mdot
.1412 .16865 Mdot
.13728 .16081 Mdot
.1216 .14513 Mdot
.11376 .13728 Mdot
.1216 .13336 Mdot
.10983 .11376 Mdot
.09415 .10199 Mdot
.09807 .10983 Mdot
.10591 .10983 Mdot
.10591 .10591 Mdot
.10983 .11376 Mdot
.10983 .10983 Mdot
.1216 .1216 Mdot
.13728 .14513 Mdot
.15297 .1765 Mdot
.18434 .21571 Mdot
.19218 .22747 Mdot
.18826 .22355 Mdot
.18434 .21963 Mdot
.1765 .20394 Mdot
.18042 .20002 Mdot
.1961 .20787 Mdot
.1961 .20787 Mdot
.20394 .21571 Mdot
.1961 .21571 Mdot
.18042 .20394 Mdot
.15297 .1765 Mdot
.11376 .13728 Mdot
.09415 .11376 Mdot
.07846 .09807 Mdot
.08631 .10591 Mdot
.09807 .11768 Mdot
.08631 .10591 Mdot
.07846 .09415 Mdot
.07846 .09415 Mdot
.09023 .09807 Mdot
.10199 .11376 Mdot
.09023 .09807 Mdot
.07846 .09023 Mdot
.09415 .10591 Mdot
.11768 .13728 Mdot
.15689 .18042 Mdot
.17257 .1961 Mdot
.18434 .21179 Mdot
.17257 .20394 Mdot
.10983 .12552 Mdot
.09415 .10199 Mdot
.08239 .07454 Mdot
.0667 .05886 Mdot
.05886 .05102 Mdot
.06278 .06278 Mdot
.0667 .07062 Mdot
.07454 .08631 Mdot
.06278 .07846 Mdot
.06278 .09023 Mdot
.07062 .09807 Mdot
.09023 .1216 Mdot
.09415 .12552 Mdot
.09415 .1216 Mdot
.09415 .1216 Mdot
.08631 .10591 Mdot
.07846 .09415 Mdot
.07846 .09415 Mdot
.07454 .08631 Mdot
.0667 .08239 Mdot
.0667 .08239 Mdot
.07062 .08631 Mdot
.09807 .11768 Mdot
.09807 .10591 Mdot
.13728 .15297 Mdot
.20394 .23139 Mdot
.23924 .27061 Mdot
.26668 .3059 Mdot
.28237 .32158 Mdot
.29413 .32943 Mdot
.29021 .33335 Mdot
.28237 .32943 Mdot
.28237 .3255 Mdot
.27845 .3255 Mdot
.29021 .33727 Mdot
.29021 .33727 Mdot
.29021 .33727 Mdot
.28629 .33335 Mdot
.28237 .33335 Mdot
.27453 .31766 Mdot
.27845 .31374 Mdot
.27845 .31374 Mdot
.28629 .3255 Mdot
.28629 .32943 Mdot
.27845 .31766 Mdot
.27845 .30982 Mdot
.28237 .31374 Mdot
.29021 .30982 Mdot
.29413 .31766 Mdot
.29806 .30982 Mdot
.30198 .31766 Mdot
.29806 .31766 Mdot
.29413 .31766 Mdot
.29413 .32158 Mdot
.29021 .3255 Mdot
.27845 .31766 Mdot
.26668 .30982 Mdot
.26668 .30982 Mdot
.27061 .30982 Mdot
.27061 .30982 Mdot
.26668 .30982 Mdot
.26668 .3059 Mdot
.27453 .31374 Mdot
.27845 .31374 Mdot
.27061 .29413 Mdot
.27061 .29413 Mdot
.26668 .29413 Mdot
.24708 .27453 Mdot
.23924 .26668 Mdot
.23139 .26276 Mdot
.23139 .26668 Mdot
.21179 .24708 Mdot
.22355 .26276 Mdot
.22355 .26668 Mdot
.21963 .25884 Mdot
.21571 .24708 Mdot
.21963 .25492 Mdot
.22747 .25884 Mdot
.22747 .25884 Mdot
.22355 .251 Mdot
.21571 .24316 Mdot
.20002 .22747 Mdot
.20002 .22355 Mdot
.18826 .21179 Mdot
.20002 .22355 Mdot
.21179 .23924 Mdot
.21179 .23924 Mdot
.20787 .23924 Mdot
.1961 .22747 Mdot
.20787 .23924 Mdot
.20787 .23531 Mdot
.20787 .23924 Mdot
.20394 .23924 Mdot
.20787 .23924 Mdot
.18434 .21571 Mdot
.18826 .21179 Mdot
.18434 .20787 Mdot
.18434 .20787 Mdot
.18042 .20002 Mdot
.18042 .20002 Mdot
.18042 .20002 Mdot
.1765 .20002 Mdot
.17257 .1961 Mdot
.16865 .19218 Mdot
.15297 .17257 Mdot
.15297 .1765 Mdot
.16473 .19218 Mdot
.15297 .18434 Mdot
.14905 .18826 Mdot
.14905 .18434 Mdot
.14513 .1765 Mdot
.14905 .18042 Mdot
.13728 .16865 Mdot
.13336 .16473 Mdot
.12944 .16081 Mdot
.1216 .15689 Mdot
.13336 .16081 Mdot
.12944 .14905 Mdot
.07454 .08631 Mdot
.15689 .16865 Mdot
.12944 .12552 Mdot
.11376 .10591 Mdot
.09807 .09023 Mdot
.09415 .09023 Mdot
.09415 .09023 Mdot
.09807 .09415 Mdot
.08631 .08239 Mdot
.07846 .07846 Mdot
.07454 .08631 Mdot
.09023 .10983 Mdot
.12552 .15297 Mdot
.14905 .18042 Mdot
.16865 .20787 Mdot
.20002 .23531 Mdot
.19218 .21963 Mdot
.19218 .21179 Mdot
.18434 .1961 Mdot
.18826 .20002 Mdot
.1961 .20394 Mdot
.20394 .21963 Mdot
.20394 .22747 Mdot
.1961 .22747 Mdot
.18434 .21571 Mdot
.15689 .19218 Mdot
.13336 .16865 Mdot
.12552 .15297 Mdot
.10983 .13728 Mdot
.08631 .10199 Mdot
.09023 .10591 Mdot
.09023 .10591 Mdot
.09023 .10591 Mdot
.09807 .11376 Mdot
.08239 .09415 Mdot
.05886 .07062 Mdot
.05886 .0667 Mdot
.07062 .08631 Mdot
.1216 .1412 Mdot
.15297 .16865 Mdot
.1765 .1961 Mdot
.18826 .20787 Mdot
.18826 .20787 Mdot
.17257 .18826 Mdot
.14905 .16473 Mdot
.11768 .12552 Mdot
.09023 .09807 Mdot
.08239 .08631 Mdot
.0667 .07846 Mdot
.0667 .07846 Mdot
.09023 .10983 Mdot
.10591 .13336 Mdot
.10199 .12944 Mdot
.10199 .13336 Mdot
.09415 .12552 Mdot
.10199 .12944 Mdot
.09023 .11768 Mdot
.07846 .10199 Mdot
.07454 .09807 Mdot
.05886 .08239 Mdot
.05886 .08239 Mdot
.0667 .07846 Mdot
.07062 .08631 Mdot
.07846 .09023 Mdot
.08631 .09807 Mdot
.07062 .07846 Mdot
.08631 .08631 Mdot
.11376 .11768 Mdot
.18042 .18434 Mdot
.21963 .23531 Mdot
.26276 .29021 Mdot
.28237 .32158 Mdot
.28629 .32943 Mdot
.29413 .34119 Mdot
.29413 .34119 Mdot
.29021 .34511 Mdot
.28629 .34511 Mdot
.28629 .33727 Mdot
.28629 .32943 Mdot
.29021 .33727 Mdot
.28629 .33335 Mdot
.27845 .31766 Mdot
.27453 .31374 Mdot
.27453 .31374 Mdot
.28629 .3255 Mdot
.29021 .32943 Mdot
.29021 .33335 Mdot
.27453 .31374 Mdot
.27453 .31374 Mdot
.27845 .30982 Mdot
.27845 .30198 Mdot
.28237 .30198 Mdot
.28629 .29806 Mdot
.27845 .29413 Mdot
.28629 .30982 Mdot
.28237 .30982 Mdot
.27453 .30982 Mdot
.27453 .31374 Mdot
.27453 .31374 Mdot
.27061 .31374 Mdot
.26668 .3059 Mdot
.26668 .30198 Mdot
.26668 .30198 Mdot
.26276 .29806 Mdot
.26276 .29806 Mdot
.27845 .3059 Mdot
.26668 .28629 Mdot
.27061 .28629 Mdot
.27845 .30198 Mdot
.26668 .29413 Mdot
.24316 .27061 Mdot
.23531 .26276 Mdot
.22355 .25884 Mdot
.21179 .24708 Mdot
.21179 .25492 Mdot
.21179 .25884 Mdot
.20787 .251 Mdot
.21179 .251 Mdot
.21963 .25492 Mdot
.22747 .26276 Mdot
.21179 .23924 Mdot
.20787 .23531 Mdot
.21571 .23531 Mdot
.20002 .22355 Mdot
.20002 .22355 Mdot
.18826 .20787 Mdot
.18042 .20394 Mdot
.19218 .21963 Mdot
.1961 .22747 Mdot
.1961 .22355 Mdot
.19218 .22355 Mdot
.19218 .22747 Mdot
.19218 .21963 Mdot
.1961 .22355 Mdot
.19218 .21963 Mdot
.19218 .21963 Mdot
.18042 .20787 Mdot
.18042 .1961 Mdot
.18042 .20002 Mdot
.18042 .1961 Mdot
.18042 .1961 Mdot
.1765 .18826 Mdot
.18042 .20002 Mdot
.1765 .20002 Mdot
.18434 .20394 Mdot
.18042 .20002 Mdot
.16473 .18042 Mdot
.14905 .17257 Mdot
.15689 .1765 Mdot
.14905 .17257 Mdot
.14513 .17257 Mdot
.14513 .17257 Mdot
.15689 .17257 Mdot
.15689 .18434 Mdot
.15689 .18434 Mdot
.1412 .16865 Mdot
.12552 .15297 Mdot
.11768 .14513 Mdot
.11768 .14513 Mdot
.1216 .13728 Mdot
.43922 .47059 Mdot
.22355 .25492 Mdot
.18826 .20394 Mdot
.16473 .16865 Mdot
.15297 .15689 Mdot
.13728 .13728 Mdot
.11768 .10983 Mdot
.10983 .10199 Mdot
.09807 .09415 Mdot
.09023 .09415 Mdot
.07454 .08631 Mdot
.07454 .09023 Mdot
.07454 .09415 Mdot
.08239 .10199 Mdot
.13336 .15297 Mdot
.16081 .1765 Mdot
.18434 .20002 Mdot
.20787 .21963 Mdot
.20002 .21571 Mdot
.20002 .21179 Mdot
.20787 .21571 Mdot
.22355 .23531 Mdot
.21963 .23531 Mdot
.20787 .23531 Mdot
.1961 .22355 Mdot
.19218 .22747 Mdot
.1765 .20787 Mdot
.14905 .18042 Mdot
.12552 .14905 Mdot
.11768 .13728 Mdot
.11768 .12552 Mdot
.11768 .1216 Mdot
.10983 .11768 Mdot
.09023 .09807 Mdot
.07454 .08239 Mdot
.05886 .06278 Mdot
.05102 .05102 Mdot
.08631 .09807 Mdot
.1216 .13728 Mdot
.11768 .13336 Mdot
.11376 .1216 Mdot
.11768 .12944 Mdot
.15689 .17257 Mdot
.17257 .19218 Mdot
.18042 .20002 Mdot
.1765 .20002 Mdot
.16081 .18434 Mdot
.11768 .13728 Mdot
.09807 .11768 Mdot
.09023 .10983 Mdot
.10591 .12944 Mdot
.10983 .13728 Mdot
.11376 .14513 Mdot
.10591 .12944 Mdot
.10199 .1216 Mdot
.10591 .12944 Mdot
.10591 .1216 Mdot
.08239 .09415 Mdot
.07454 .08239 Mdot
.0667 .07454 Mdot
.06278 .07062 Mdot
.06278 .07062 Mdot
.07062 .07846 Mdot
.09023 .09415 Mdot
.09023 .09415 Mdot
.08239 .08239 Mdot
.08631 .08239 Mdot
.09023 .08239 Mdot
.11376 .10591 Mdot
.11768 .11376 Mdot
.21179 .23139 Mdot
.24708 .27845 Mdot
.27845 .31374 Mdot
.29413 .3255 Mdot
.3059 .34119 Mdot
.30198 .34511 Mdot
.29413 .34511 Mdot
.29413 .34119 Mdot
.29021 .33335 Mdot
.29021 .33727 Mdot
.29021 .33727 Mdot
.29806 .34511 Mdot
.29021 .33335 Mdot
.27845 .32158 Mdot
.27845 .31766 Mdot
.29021 .3255 Mdot
.28629 .3255 Mdot
.27453 .30982 Mdot
.27845 .31766 Mdot
.27453 .31374 Mdot
.27453 .30982 Mdot
.27845 .3059 Mdot
.27453 .29806 Mdot
.27845 .30198 Mdot
.28629 .3059 Mdot
.28629 .31374 Mdot
.27061 .29806 Mdot
.27061 .29806 Mdot
.27061 .3059 Mdot
.26668 .30198 Mdot
.26668 .29806 Mdot
.26668 .30198 Mdot
.27061 .29806 Mdot
.26668 .29413 Mdot
.27453 .29806 Mdot
.27845 .3059 Mdot
.28237 .30982 Mdot
.27845 .30198 Mdot
.27453 .29413 Mdot
.27061 .29021 Mdot
.25884 .28629 Mdot
.24708 .27453 Mdot
.23531 .26276 Mdot
.22747 .25884 Mdot
.21179 .24316 Mdot
.1961 .23924 Mdot
.20002 .24708 Mdot
.1961 .24316 Mdot
.20787 .24708 Mdot
.20787 .24708 Mdot
.20787 .24316 Mdot
.20002 .23531 Mdot
.20787 .23531 Mdot
.20002 .22355 Mdot
.18434 .20787 Mdot
.18434 .20787 Mdot
.18826 .21179 Mdot
.17257 .19218 Mdot
.18434 .21179 Mdot
.20002 .22355 Mdot
.20002 .23139 Mdot
.19218 .22355 Mdot
.1961 .22747 Mdot
.19218 .22355 Mdot
.18826 .21963 Mdot
.18434 .21571 Mdot
.17257 .20394 Mdot
.17257 .20394 Mdot
.18042 .20394 Mdot
.17257 .19218 Mdot
.16865 .18434 Mdot
.16865 .18434 Mdot
.18042 .1961 Mdot
.17257 .19218 Mdot
.16865 .18826 Mdot
.17257 .19218 Mdot
.16865 .1961 Mdot
.15689 .18434 Mdot
.14513 .1765 Mdot
.13728 .16865 Mdot
.13336 .16081 Mdot
.14513 .16473 Mdot
.16081 .18042 Mdot
.14905 .17257 Mdot
.14905 .1765 Mdot
.14513 .16865 Mdot
.13728 .16081 Mdot
.13728 .16473 Mdot
.12944 .15689 Mdot
.1216 .13728 Mdot
.63528 .65489 Mdot
.3059 .35295 Mdot
.27845 .30982 Mdot
.24708 .26668 Mdot
.21179 .22355 Mdot
.1765 .18826 Mdot
.1412 .15297 Mdot
.1216 .13336 Mdot
.11376 .12944 Mdot
.10983 .12552 Mdot
.11768 .12944 Mdot
.12944 .13728 Mdot
.1216 .12552 Mdot
.12552 .11768 Mdot
.15297 .14513 Mdot
.1765 .1765 Mdot
.18042 .18042 Mdot
.18434 .18434 Mdot
.21179 .22355 Mdot
.22355 .23924 Mdot
.22747 .24708 Mdot
.23139 .26668 Mdot
.21963 .25492 Mdot
.20394 .24316 Mdot
.18434 .21963 Mdot
.18434 .21963 Mdot
.16865 .19218 Mdot
.17257 .20394 Mdot
.18826 .21963 Mdot
.16081 .17257 Mdot
.14513 .15297 Mdot
.1216 .11768 Mdot
.08239 .07454 Mdot
.06278 .05102 Mdot
.05494 .04709 Mdot
.09023 .09023 Mdot
.10983 .12552 Mdot
.09415 .10591 Mdot
.07062 .07846 Mdot
.05494 .06278 Mdot
.07454 .09023 Mdot
.09415 .10983 Mdot
.13336 .15689 Mdot
.15689 .18434 Mdot
.16865 .20002 Mdot
.13336 .16081 Mdot
.11768 .14905 Mdot
.1412 .17257 Mdot
.13336 .16865 Mdot
.1216 .15689 Mdot
.11376 .14513 Mdot
.09415 .11768 Mdot
.09023 .11376 Mdot
.10983 .12944 Mdot
.10591 .1216 Mdot
.09807 .10199 Mdot
.07846 .08239 Mdot
.08239 .08239 Mdot
.07454 .07454 Mdot
.06278 .06278 Mdot
.0667 .06278 Mdot
.07062 .07062 Mdot
.07454 .07454 Mdot
.09023 .09023 Mdot
.09415 .09415 Mdot
.12552 .12944 Mdot
.13728 .1412 Mdot
.1412 .15297 Mdot
.16081 .18434 Mdot
.20787 .23139 Mdot
.24708 .27061 Mdot
.27453 .29806 Mdot
.29413 .32158 Mdot
.30982 .33727 Mdot
.30982 .34511 Mdot
.3059 .34903 Mdot
.29413 .33727 Mdot
.29413 .34119 Mdot
.29021 .33727 Mdot
.29021 .33335 Mdot
.29021 .32943 Mdot
.30198 .34119 Mdot
.3059 .33335 Mdot
.29413 .31766 Mdot
.30198 .32158 Mdot
.28629 .3059 Mdot
.28629 .3059 Mdot
.28629 .31374 Mdot
.27845 .30982 Mdot
.28629 .31766 Mdot
.28237 .31374 Mdot
.28629 .31766 Mdot
.27845 .30198 Mdot
.27453 .29413 Mdot
.27061 .29021 Mdot
.27845 .29806 Mdot
.28237 .30982 Mdot
.28237 .30982 Mdot
.28629 .30982 Mdot
.28237 .3059 Mdot
.27845 .29413 Mdot
.27845 .29413 Mdot
.26668 .29413 Mdot
.26276 .29413 Mdot
.27061 .30982 Mdot
.27061 .30198 Mdot
.27845 .30982 Mdot
.26668 .29021 Mdot
.27061 .28629 Mdot
.26276 .27845 Mdot
.24316 .26276 Mdot
.24316 .26668 Mdot
.22355 .24316 Mdot
.20787 .23531 Mdot
.1961 .23139 Mdot
.20002 .24708 Mdot
.1961 .24708 Mdot
.1961 .24316 Mdot
.19218 .23924 Mdot
.20002 .23531 Mdot
.21179 .24708 Mdot
.20394 .23139 Mdot
.1961 .22355 Mdot
.19218 .21963 Mdot
.20787 .23924 Mdot
.20002 .22355 Mdot
.19218 .21179 Mdot
.19218 .21179 Mdot
.1961 .21963 Mdot
.1961 .21963 Mdot
.20002 .22355 Mdot
.19218 .22355 Mdot
.18826 .22747 Mdot
.18042 .21963 Mdot
.18042 .21571 Mdot
.18042 .21963 Mdot
.1765 .21571 Mdot
.17257 .21179 Mdot
.17257 .1961 Mdot
.1765 .19218 Mdot
.17257 .18042 Mdot
.18042 .19218 Mdot
.18042 .19218 Mdot
.18042 .1961 Mdot
.1765 .1961 Mdot
.17257 .1961 Mdot
.15297 .18042 Mdot
.13728 .16865 Mdot
.1412 .17257 Mdot
.1412 .16865 Mdot
.15297 .1765 Mdot
.14513 .17257 Mdot
.13336 .16473 Mdot
.12944 .16081 Mdot
.13336 .16081 Mdot
.13728 .16473 Mdot
.13336 .16081 Mdot
.1216 .14905 Mdot
.86272 .87448 Mdot
.69802 .72155 Mdot
.43922 .50196 Mdot
.37256 .43138 Mdot
.26668 .30982 Mdot
.251 .29021 Mdot
.28237 .31766 Mdot
.29806 .33335 Mdot
.29021 .31766 Mdot
.21571 .22355 Mdot
.1765 .1765 Mdot
.1765 .17257 Mdot
.1765 .17257 Mdot
.16865 .16473 Mdot
.1412 .13336 Mdot
.13728 .12552 Mdot
.16865 .16473 Mdot
.18042 .18826 Mdot
.20787 .22355 Mdot
.21963 .23924 Mdot
.22355 .25492 Mdot
.21179 .24708 Mdot
.18434 .21571 Mdot
.17257 .20394 Mdot
.18042 .21571 Mdot
.1961 .22747 Mdot
.21179 .24708 Mdot
.21179 .24316 Mdot
.22355 .24708 Mdot
.20394 .21571 Mdot
.16081 .16081 Mdot
.1216 .11768 Mdot
.10591 .10199 Mdot
.11768 .1216 Mdot
.11768 .12944 Mdot
.07454 .08239 Mdot
.06278 .07062 Mdot
.05886 .05886 Mdot
.05494 .05494 Mdot
.0667 .07062 Mdot
.07846 .08239 Mdot
.09023 .10199 Mdot
.11376 .13336 Mdot
.1216 .15297 Mdot
.15689 .19218 Mdot
.16081 .20394 Mdot
.16081 .20394 Mdot
.14905 .19218 Mdot
.12552 .15689 Mdot
.10983 .1412 Mdot
.10591 .13336 Mdot
.10591 .12944 Mdot
.11376 .12944 Mdot
.10199 .10983 Mdot
.09023 .09023 Mdot
.09023 .09415 Mdot
.08631 .09023 Mdot
.07454 .07454 Mdot
.07454 .07062 Mdot
.07062 .07062 Mdot
.07846 .07846 Mdot
.05886 .05886 Mdot
.07062 .07062 Mdot
.23531 .27453 Mdot
.26668 .32158 Mdot
.28629 .34903 Mdot
.26276 .32158 Mdot
.25492 .30198 Mdot
.24708 .28237 Mdot
.24316 .27453 Mdot
.26276 .28629 Mdot
.27453 .29806 Mdot
.29021 .31766 Mdot
.29413 .3255 Mdot
.29413 .33335 Mdot
.29413 .34119 Mdot
.29021 .34119 Mdot
.29413 .33335 Mdot
.29021 .32158 Mdot
.3059 .33335 Mdot
.31374 .33727 Mdot
.32158 .35295 Mdot
.31374 .33727 Mdot
.31374 .32943 Mdot
.29806 .31374 Mdot
.29021 .31374 Mdot
.29806 .32158 Mdot
.29413 .32158 Mdot
.29413 .32158 Mdot
.29021 .31766 Mdot
.27845 .3059 Mdot
.27845 .30198 Mdot
.28237 .30198 Mdot
.29021 .3059 Mdot
.29413 .30982 Mdot
.28237 .30198 Mdot
.29806 .31766 Mdot
.29021 .31374 Mdot
.27453 .29806 Mdot
.26668 .29021 Mdot
.26668 .3059 Mdot
.26668 .3059 Mdot
.26668 .3059 Mdot
.26276 .30198 Mdot
.27061 .30982 Mdot
.27061 .30198 Mdot
.27453 .30198 Mdot
.27453 .29413 Mdot
.27453 .29021 Mdot
.27061 .29021 Mdot
.25492 .27453 Mdot
.23531 .251 Mdot
.22355 .24708 Mdot
.21179 .251 Mdot
.20394 .24316 Mdot
.20394 .24316 Mdot
.20787 .24316 Mdot
.21179 .24316 Mdot
.21179 .24316 Mdot
.21179 .24316 Mdot
.21179 .24316 Mdot
.21179 .23924 Mdot
.20787 .23531 Mdot
.20394 .22747 Mdot
.20787 .23531 Mdot
.1961 .21963 Mdot
.18434 .21179 Mdot
.18434 .21179 Mdot
.18042 .21571 Mdot
.1765 .21571 Mdot
.18434 .22355 Mdot
.18434 .22355 Mdot
.18434 .22355 Mdot
.18042 .21963 Mdot
.18434 .22747 Mdot
.18042 .21963 Mdot
.18042 .21179 Mdot
.17257 .19218 Mdot
.16865 .18434 Mdot
.17257 .19218 Mdot
.18042 .1961 Mdot
.1765 .18826 Mdot
.16865 .18434 Mdot
.16473 .18042 Mdot
.15689 .18042 Mdot
.14513 .17257 Mdot
.14905 .1765 Mdot
.1412 .16865 Mdot
.14905 .1765 Mdot
.1412 .16865 Mdot
.13728 .15689 Mdot
.13336 .15297 Mdot
.12944 .15689 Mdot
.12944 .16081 Mdot
.12552 .15297 Mdot
.1216 .14905 Mdot
.8784 .89801 Mdot
.6196 .67057 Mdot
.47843 .54509 Mdot
.4902 .5647 Mdot
.50588 .58431 Mdot
.49804 .57646 Mdot
.42354 .47451 Mdot
.37256 .41569 Mdot
.39609 .44706 Mdot
.28237 .30982 Mdot
.15297 .15297 Mdot
.1216 .11768 Mdot
.10199 .09415 Mdot
.09415 .08631 Mdot
.10983 .10983 Mdot
.14905 .15297 Mdot
.1765 .19218 Mdot
.20787 .22747 Mdot
.21571 .24316 Mdot
.21179 .24708 Mdot
.19218 .22355 Mdot
.22355 .26276 Mdot
.23531 .27845 Mdot
.24316 .28237 Mdot
.23924 .27453 Mdot
.24316 .27061 Mdot
.23139 .251 Mdot
.22355 .24316 Mdot
.20002 .22747 Mdot
.18434 .20787 Mdot
.17257 .19218 Mdot
.11376 .12944 Mdot
.08239 .09023 Mdot
.07062 .07454 Mdot
.0667 .06278 Mdot
.07454 .07454 Mdot
.07454 .07454 Mdot
.06278 .05886 Mdot
.06278 .06278 Mdot
.06278 .07062 Mdot
.07846 .09023 Mdot
.15689 .19218 Mdot
.15689 .19218 Mdot
.1765 .21571 Mdot
.15689 .19218 Mdot
.1412 .17257 Mdot
.12552 .15689 Mdot
.11768 .14905 Mdot
.11376 .13728 Mdot
.10983 .12944 Mdot
.09807 .11768 Mdot
.09023 .10591 Mdot
.09023 .10591 Mdot
.08239 .09415 Mdot
.08631 .09023 Mdot
.08239 .08631 Mdot
.09807 .09807 Mdot
.08239 .07846 Mdot
.09415 .09415 Mdot
.11376 .11768 Mdot
.20394 .22355 Mdot
.32158 .37256 Mdot
.34119 .40393 Mdot
.34119 .41177 Mdot
.33335 .40001 Mdot
.29806 .35687 Mdot
.27061 .3255 Mdot
.26668 .30982 Mdot
.26276 .29806 Mdot
.27061 .30982 Mdot
.27845 .31374 Mdot
.29021 .3255 Mdot
.30982 .34119 Mdot
.29806 .33335 Mdot
.30198 .33727 Mdot
.31374 .34903 Mdot
.30982 .34511 Mdot
.30198 .33727 Mdot
.30982 .34511 Mdot
.31374 .34119 Mdot
.31374 .34511 Mdot
.3059 .33727 Mdot
.3059 .33335 Mdot
.3059 .32943 Mdot
.3059 .32943 Mdot
.30198 .3255 Mdot
.29413 .32158 Mdot
.30198 .3255 Mdot
.29413 .31766 Mdot
.29021 .30982 Mdot
.28629 .3059 Mdot
.28629 .3059 Mdot
.28629 .3059 Mdot
.28237 .3059 Mdot
.28629 .30982 Mdot
.28237 .3059 Mdot
.27845 .30198 Mdot
.28237 .31374 Mdot
.27845 .30982 Mdot
.27453 .30982 Mdot
.27061 .31374 Mdot
.27845 .32158 Mdot
.27845 .31374 Mdot
.27453 .30198 Mdot
.27453 .30198 Mdot
.27453 .29806 Mdot
.27453 .29413 Mdot
.25884 .27845 Mdot
.25492 .28237 Mdot
.24316 .27061 Mdot
.23139 .25884 Mdot
.22747 .25492 Mdot
.20787 .23139 Mdot
.20394 .23139 Mdot
.20002 .23139 Mdot
.21179 .251 Mdot
.21179 .24708 Mdot
.20394 .24708 Mdot
.1961 .23924 Mdot
.20002 .24316 Mdot
.1961 .23139 Mdot
.20002 .23531 Mdot
.1961 .23924 Mdot
.19218 .23531 Mdot
.19218 .23139 Mdot
.18826 .22355 Mdot
.19218 .23139 Mdot
.18826 .22747 Mdot
.18434 .21963 Mdot
.18434 .21963 Mdot
.20394 .23924 Mdot
.20002 .23531 Mdot
.18826 .22355 Mdot
.1961 .23139 Mdot
.18434 .20787 Mdot
.1765 .1961 Mdot
.17257 .19218 Mdot
.1765 .19218 Mdot
.16865 .18826 Mdot
.16865 .19218 Mdot
.16081 .18826 Mdot
.16081 .18042 Mdot
.16865 .18826 Mdot
.16473 .18434 Mdot
.15689 .17257 Mdot
.15689 .17257 Mdot
.14513 .16081 Mdot
.13336 .14513 Mdot
.13336 .14905 Mdot
.12944 .14905 Mdot
.14513 .16081 Mdot
.1412 .16081 Mdot
.12944 .1412 Mdot
.76861 .81174 Mdot
.65881 .72547 Mdot
.54117 .63528 Mdot
.54509 .63528 Mdot
.54117 .6196 Mdot
.54902 .62744 Mdot
.43138 .48628 Mdot
.12552 .1216 Mdot
.1216 .11768 Mdot
.10591 .09807 Mdot
.09023 .08239 Mdot
.07846 .07062 Mdot
.08239 .07846 Mdot
.1216 .12552 Mdot
.1412 .15297 Mdot
.16473 .18434 Mdot
.20394 .23924 Mdot
.21179 .24708 Mdot
.26276 .30982 Mdot
.27061 .32158 Mdot
.251 .29413 Mdot
.251 .29021 Mdot
.23531 .26668 Mdot
.23531 .26668 Mdot
.22355 .25492 Mdot
.22355 .25492 Mdot
.22747 .26276 Mdot
.21963 .25884 Mdot
.21179 .24316 Mdot
.14905 .16865 Mdot
.10591 .11768 Mdot
.08631 .09807 Mdot
.07454 .07454 Mdot
.07454 .07062 Mdot
.05494 .05102 Mdot
.0667 .05886 Mdot
.07062 .06278 Mdot
.09807 .10983 Mdot
.16473 .1961 Mdot
.1412 .17257 Mdot
.14513 .17257 Mdot
.15689 .18434 Mdot
.15689 .18434 Mdot
.13728 .16865 Mdot
.13728 .16081 Mdot
.11768 .13728 Mdot
.11768 .13728 Mdot
.1216 .1412 Mdot
.1216 .14905 Mdot
.10983 .12944 Mdot
.10199 .11768 Mdot
.10199 .11768 Mdot
.09807 .11376 Mdot
.11376 .1216 Mdot
.10199 .09807 Mdot
.11376 .11376 Mdot
.16473 .16473 Mdot
.14905 .1412 Mdot
.28629 .3059 Mdot
.33335 .3804 Mdot
.30198 .3608 Mdot
.28629 .34119 Mdot
.3059 .36864 Mdot
.31766 .38432 Mdot
.3059 .37256 Mdot
.27845 .34511 Mdot
.27453 .32943 Mdot
.27845 .32158 Mdot
.28237 .31766 Mdot
.29021 .32158 Mdot
.29413 .32158 Mdot
.29021 .31766 Mdot
.29806 .32943 Mdot
.30198 .35295 Mdot
.29021 .33727 Mdot
.30198 .35295 Mdot
.30982 .3608 Mdot
.29413 .34119 Mdot
.30198 .33727 Mdot
.3059 .33335 Mdot
.3059 .33335 Mdot
.3059 .32158 Mdot
.30982 .3255 Mdot
.3059 .3255 Mdot
.30198 .31766 Mdot
.28629 .30982 Mdot
.28629 .31374 Mdot
.28237 .31766 Mdot
.28237 .31766 Mdot
.28237 .31374 Mdot
.27845 .30982 Mdot
.28237 .31374 Mdot
.27845 .30982 Mdot
.28629 .30982 Mdot
.28237 .29806 Mdot
.28237 .29806 Mdot
.27845 .29806 Mdot
.26668 .29806 Mdot
.27453 .31374 Mdot
.26276 .29806 Mdot
.26668 .30198 Mdot
.26276 .29806 Mdot
.25884 .29021 Mdot
.25884 .28629 Mdot
.25492 .29021 Mdot
.25884 .29021 Mdot
.27061 .29021 Mdot
.25884 .27845 Mdot
.24316 .27061 Mdot
.23139 .25884 Mdot
.21963 .24316 Mdot
.20394 .22747 Mdot
.20002 .23531 Mdot
.19218 .22747 Mdot
.18826 .22747 Mdot
.18826 .23531 Mdot
.18434 .23531 Mdot
.19218 .24316 Mdot
.1961 .24708 Mdot
.20394 .251 Mdot
.1961 .23924 Mdot
.1961 .23139 Mdot
.20394 .23139 Mdot
.1961 .22355 Mdot
.1961 .22355 Mdot
.18826 .21179 Mdot
.18826 .21571 Mdot
.18434 .20787 Mdot
.18434 .21571 Mdot
.19218 .22747 Mdot
.18434 .22747 Mdot
.18042 .21963 Mdot
.1765 .21179 Mdot
.16473 .1961 Mdot
.16081 .19218 Mdot
.16081 .19218 Mdot
.16473 .20002 Mdot
.17257 .20787 Mdot
.1765 .20002 Mdot
.16865 .18042 Mdot
.18434 .19218 Mdot
.17257 .18434 Mdot
.16081 .1765 Mdot
.14905 .16081 Mdot
.13336 .14513 Mdot
.13336 .14513 Mdot
.12944 .13728 Mdot
.14513 .15689 Mdot
.13728 .14513 Mdot
.12944 .13728 Mdot
.78037 .8235 Mdot
.56862 .65489 Mdot
.57254 .65881 Mdot
.53725 .6196 Mdot
.31766 .3608 Mdot
.12552 .12944 Mdot
.12944 .13336 Mdot
.10983 .10983 Mdot
.08631 .08239 Mdot
.08631 .07846 Mdot
.08239 .07454 Mdot
.09023 .08631 Mdot
.10983 .11376 Mdot
.13336 .14513 Mdot
.15297 .17257 Mdot
.1961 .22747 Mdot
.22355 .25884 Mdot
.23924 .26276 Mdot
.24316 .27061 Mdot
.24708 .27061 Mdot
.24316 .27061 Mdot
.24316 .27061 Mdot
.24316 .27845 Mdot
.251 .27845 Mdot
.24708 .27453 Mdot
.24316 .27453 Mdot
.24708 .28237 Mdot
.22747 .25884 Mdot
.19218 .21963 Mdot
.13728 .14513 Mdot
.11376 .11376 Mdot
.10199 .09807 Mdot
.08631 .07846 Mdot
.0667 .05494 Mdot
.13336 .14513 Mdot
.13336 .15297 Mdot
.11376 .13336 Mdot
.10591 .12552 Mdot
.13336 .16081 Mdot
.15297 .18434 Mdot
.14513 .16865 Mdot
.13336 .14905 Mdot
.13728 .16081 Mdot
.13336 .15689 Mdot
.1412 .16865 Mdot
.13336 .15689 Mdot
.13728 .16473 Mdot
.12552 .15297 Mdot
.12552 .15297 Mdot
.12552 .14513 Mdot
.10591 .11768 Mdot
.10199 .10199 Mdot
.08631 .08631 Mdot
.10591 .10591 Mdot
.10983 .10983 Mdot
.36472 .41961 Mdot
.36864 .4353 Mdot
.26668 .31766 Mdot
.18434 .21963 Mdot
.19218 .22747 Mdot
.20787 .251 Mdot
.30982 .38432 Mdot
.30982 .38432 Mdot
.31766 .38432 Mdot
.30982 .37256 Mdot
.28237 .33335 Mdot
.27845 .31766 Mdot
.29021 .32158 Mdot
.29021 .32158 Mdot
.28237 .32158 Mdot
.27453 .31766 Mdot
.27453 .32943 Mdot
.28629 .34119 Mdot
.3059 .35687 Mdot
.29413 .34119 Mdot
.30198 .34119 Mdot
.29806 .33727 Mdot
.30198 .32943 Mdot
.29806 .32158 Mdot
.28629 .30982 Mdot
.29021 .31766 Mdot
.29413 .32158 Mdot
.29021 .32158 Mdot
.28629 .31766 Mdot
.27845 .31374 Mdot
.27845 .31374 Mdot
.27453 .31374 Mdot
.27845 .31766 Mdot
.29021 .3255 Mdot
.28237 .31374 Mdot
.27845 .3059 Mdot
.28629 .30982 Mdot
.28237 .30198 Mdot
.27845 .3059 Mdot
.27845 .30982 Mdot
.27453 .30198 Mdot
.27061 .30198 Mdot
.27453 .30982 Mdot
.26668 .29806 Mdot
.25884 .29413 Mdot
.25884 .29021 Mdot
.26276 .29413 Mdot
.27453 .3059 Mdot
.27061 .29413 Mdot
.26276 .28237 Mdot
.26668 .28237 Mdot
.25884 .28629 Mdot
.24316 .27061 Mdot
.21963 .24708 Mdot
.20002 .23924 Mdot
.18042 .21963 Mdot
.19218 .23139 Mdot
.18826 .22747 Mdot
.19218 .23924 Mdot
.1961 .24316 Mdot
.19218 .23139 Mdot
.1961 .23139 Mdot
.20394 .23139 Mdot
.20002 .22747 Mdot
.20002 .22747 Mdot
.18826 .21571 Mdot
.1961 .22355 Mdot
.1961 .22355 Mdot
.19218 .21963 Mdot
.17257 .20394 Mdot
.1765 .21571 Mdot
.19218 .22355 Mdot
.18826 .22355 Mdot
.18826 .21963 Mdot
.19218 .21963 Mdot
.17257 .1961 Mdot
.1765 .20002 Mdot
.16081 .18042 Mdot
.16081 .18434 Mdot
.15689 .18826 Mdot
.15689 .18826 Mdot
.16473 .19218 Mdot
.1765 .19218 Mdot
.1765 .19218 Mdot
.16473 .18042 Mdot
.14513 .16081 Mdot
.12944 .14513 Mdot
.11768 .12944 Mdot
.13728 .14513 Mdot
.1412 .15689 Mdot
.12944 .1412 Mdot
.12552 .13728 Mdot
.89409 .91761 Mdot
.79213 .83919 Mdot
.48628 .56078 Mdot
.25492 .29021 Mdot
.18042 .1961 Mdot
.15297 .16081 Mdot
.11376 .10983 Mdot
.10199 .09415 Mdot
.09023 .08631 Mdot
.08631 .08239 Mdot
.09023 .09415 Mdot
.09807 .10199 Mdot
.09023 .10199 Mdot
.11376 .12552 Mdot
.13728 .14905 Mdot
.18826 .20394 Mdot
.23531 .251 Mdot
.251 .27061 Mdot
.26276 .28237 Mdot
.27061 .30198 Mdot
.27061 .30198 Mdot
.27845 .30982 Mdot
.26668 .3059 Mdot
.25884 .29806 Mdot
.25492 .30198 Mdot
.251 .29021 Mdot
.25492 .28237 Mdot
.24316 .26276 Mdot
.22355 .23531 Mdot
.20787 .21571 Mdot
.15689 .15297 Mdot
.12944 .11768 Mdot
.16865 .17257 Mdot
.12944 .13336 Mdot
.07846 .08239 Mdot
.07454 .08239 Mdot
.09415 .10591 Mdot
.09415 .11376 Mdot
.10983 .12944 Mdot
.1216 .1412 Mdot
.12552 .14513 Mdot
.12944 .15689 Mdot
.1216 .15297 Mdot
.12552 .14905 Mdot
.13336 .16081 Mdot
.13728 .16473 Mdot
.1412 .16473 Mdot
.13336 .14513 Mdot
.1216 .12944 Mdot
.10983 .11376 Mdot
.10199 .10199 Mdot
.1216 .12552 Mdot
.10591 .11768 Mdot
.21179 .251 Mdot
.23531 .27845 Mdot
.15297 .1765 Mdot
.17257 .1961 Mdot
.14513 .16081 Mdot
.11376 .12552 Mdot
.14513 .1765 Mdot
.23924 .29413 Mdot
.33335 .40785 Mdot
.34903 .42746 Mdot
.33727 .40785 Mdot
.31374 .37256 Mdot
.29021 .33727 Mdot
.28629 .32943 Mdot
.27453 .31374 Mdot
.251 .29413 Mdot
.24708 .29806 Mdot
.25884 .30982 Mdot
.27845 .32943 Mdot
.29021 .34511 Mdot
.29806 .34511 Mdot
.29806 .34119 Mdot
.29413 .33727 Mdot
.28629 .33335 Mdot
.29021 .33335 Mdot
.30198 .33727 Mdot
.29021 .33335 Mdot
.28629 .32158 Mdot
.29413 .3255 Mdot
.28237 .31374 Mdot
.27845 .30982 Mdot
.28629 .32158 Mdot
.28629 .32943 Mdot
.28629 .32943 Mdot
.27453 .31374 Mdot
.27845 .31766 Mdot
.27845 .31374 Mdot
.28237 .31374 Mdot
.27453 .30198 Mdot
.27845 .30982 Mdot
.28629 .31374 Mdot
.27453 .30198 Mdot
.27453 .30198 Mdot
.27061 .30198 Mdot
.27061 .3059 Mdot
.27061 .3059 Mdot
.25884 .29021 Mdot
.26276 .29806 Mdot
.26276 .30198 Mdot
.26276 .29806 Mdot
.25492 .28237 Mdot
.25884 .29021 Mdot
.251 .28237 Mdot
.23924 .27453 Mdot
.23139 .26276 Mdot
.22355 .251 Mdot
.20394 .23139 Mdot
.20394 .22747 Mdot
.1961 .22747 Mdot
.19218 .22747 Mdot
.20002 .23531 Mdot
.20002 .23531 Mdot
.1961 .22747 Mdot
.18042 .21179 Mdot
.17257 .20787 Mdot
.1765 .21571 Mdot
.1765 .21571 Mdot
.19218 .22747 Mdot
.18042 .21179 Mdot
.18826 .21963 Mdot
.18042 .20787 Mdot
.18042 .20787 Mdot
.18434 .21179 Mdot
.18434 .21179 Mdot
.1961 .21963 Mdot
.1961 .22355 Mdot
.18826 .21571 Mdot
.1765 .20394 Mdot
.16865 .1961 Mdot
.15689 .18826 Mdot
.15689 .19218 Mdot
.16473 .1961 Mdot
.16865 .19218 Mdot
.16473 .1961 Mdot
.15689 .18826 Mdot
.14513 .17257 Mdot
.13336 .15689 Mdot
.13336 .15689 Mdot
.1412 .16473 Mdot
.13728 .15297 Mdot
.13336 .14905 Mdot
.12552 .1412 Mdot
.73332 .76861 Mdot
.51765 .56078 Mdot
.24708 .27061 Mdot
.18434 .1961 Mdot
.14905 .14513 Mdot
.13336 .12552 Mdot
.12552 .1216 Mdot
.10983 .10591 Mdot
.10591 .10591 Mdot
.09807 .09415 Mdot
.09415 .09415 Mdot
.09415 .09415 Mdot
.09023 .08239 Mdot
.15689 .15689 Mdot
.18434 .18434 Mdot
.22355 .23531 Mdot
.24708 .27061 Mdot
.25884 .28629 Mdot
.27061 .3059 Mdot
.27453 .32158 Mdot
.251 .29413 Mdot
.24316 .28237 Mdot
.25492 .29806 Mdot
.25884 .29021 Mdot
.26668 .29021 Mdot
.27453 .29806 Mdot
.26668 .28237 Mdot
.25492 .26668 Mdot
.23531 .24316 Mdot
.21571 .22747 Mdot
.13728 .1412 Mdot
.09023 .08631 Mdot
.0667 .0667 Mdot
.06278 .07062 Mdot
.05494 .06278 Mdot
.05886 .0667 Mdot
.07062 .08239 Mdot
.10199 .1216 Mdot
.11376 .13728 Mdot
.1216 .14513 Mdot
.11768 .13728 Mdot
.12552 .15297 Mdot
.13728 .16473 Mdot
.14905 .17257 Mdot
.1412 .15297 Mdot
.14513 .15297 Mdot
.14905 .15689 Mdot
.15297 .16081 Mdot
.14905 .15689 Mdot
.12552 .14513 Mdot
.09807 .10983 Mdot
.09807 .11376 Mdot
.10199 .11376 Mdot
.12944 .13728 Mdot
.1216 .12552 Mdot
.10983 .11768 Mdot
.09807 .10983 Mdot
.09807 .11376 Mdot
.19218 .23139 Mdot
.25492 .30982 Mdot
.30982 .37648 Mdot
.34511 .41961 Mdot
.34903 .42354 Mdot
.29413 .34511 Mdot
.21179 .251 Mdot
.18434 .21963 Mdot
.18042 .21963 Mdot
.1961 .23531 Mdot
.21179 .25492 Mdot
.25492 .30198 Mdot
.26668 .31766 Mdot
.29021 .34119 Mdot
.28237 .33727 Mdot
.28629 .34119 Mdot
.29413 .34511 Mdot
.3059 .3608 Mdot
.29021 .33727 Mdot
.29806 .33727 Mdot
.29413 .32943 Mdot
.28629 .31766 Mdot
.28629 .32158 Mdot
.28237 .31374 Mdot
.27453 .31766 Mdot
.28237 .32943 Mdot
.27845 .32158 Mdot
.27453 .31766 Mdot
.27845 .31766 Mdot
.27453 .31766 Mdot
.27845 .31766 Mdot
.27845 .30982 Mdot
.27845 .30198 Mdot
.27453 .29021 Mdot
.27453 .29413 Mdot
.28629 .30982 Mdot
.27845 .3059 Mdot
.28237 .31374 Mdot
.27845 .31374 Mdot
.27061 .30198 Mdot
.27061 .30198 Mdot
.26668 .30198 Mdot
.24708 .28237 Mdot
.251 .28237 Mdot
.24708 .27845 Mdot
.25884 .29021 Mdot
.25884 .29021 Mdot
.23924 .27061 Mdot
.22747 .25492 Mdot
.21963 .23924 Mdot
.20394 .22747 Mdot
.20002 .22355 Mdot
.20394 .22747 Mdot
.21179 .23924 Mdot
.21179 .24316 Mdot
.20394 .24316 Mdot
.1765 .21571 Mdot
.16473 .20002 Mdot
.1765 .20394 Mdot
.18042 .20002 Mdot
.18042 .20002 Mdot
.18434 .20787 Mdot
.18042 .20394 Mdot
.18042 .20394 Mdot
.18826 .21963 Mdot
.1961 .22355 Mdot
.19218 .21963 Mdot
.18826 .21963 Mdot
.18434 .21571 Mdot
.18042 .21571 Mdot
.1765 .20394 Mdot
.16473 .19218 Mdot
.15689 .18434 Mdot
.14905 .18434 Mdot
.16081 .20002 Mdot
.14905 .18434 Mdot
.1412 .17257 Mdot
.15297 .18434 Mdot
.13336 .16081 Mdot
.11376 .13728 Mdot
.1216 .14905 Mdot
.13336 .14905 Mdot
.13728 .15297 Mdot
.12944 .13728 Mdot
.64705 .65881 Mdot
.41177 .41961 Mdot
.19218 .20002 Mdot
.17257 .18042 Mdot
.1412 .14513 Mdot
.11768 .1216 Mdot
.10983 .10591 Mdot
.10199 .09807 Mdot
.09023 .08239 Mdot
.09023 .07062 Mdot
.09023 .07062 Mdot
.09415 .07846 Mdot
.13336 .1216 Mdot
.20002 .1961 Mdot
.24708 .26276 Mdot
.24708 .27453 Mdot
.26276 .30198 Mdot
.26276 .3059 Mdot
.26668 .3059 Mdot
.25492 .29806 Mdot
.26276 .30198 Mdot
.27061 .30198 Mdot
.26668 .29021 Mdot
.26668 .28629 Mdot
.28629 .29806 Mdot
.28629 .29413 Mdot
.27453 .28237 Mdot
.23531 .24316 Mdot
.19218 .20394 Mdot
.1216 .13336 Mdot
.07454 .07454 Mdot
.07454 .07454 Mdot
.0667 .0667 Mdot
.0667 .07062 Mdot
.07846 .08239 Mdot
.10199 .11768 Mdot
.11768 .13728 Mdot
.1216 .1412 Mdot
.12552 .14905 Mdot
.13728 .16473 Mdot
.14905 .16865 Mdot
.14905 .16081 Mdot
.14513 .15297 Mdot
.20394 .21571 Mdot
.20394 .21571 Mdot
.19218 .20394 Mdot
.13728 .1412 Mdot
.11768 .11768 Mdot
.09023 .09023 Mdot
.09023 .09023 Mdot
.10591 .11376 Mdot
.10983 .12552 Mdot
.10199 .11376 Mdot
.10591 .12944 Mdot
.10591 .12944 Mdot
.09415 .1216 Mdot
.1216 .15297 Mdot
.1412 .1765 Mdot
.19218 .23924 Mdot
.32943 .40393 Mdot
.31374 .38432 Mdot
.16865 .20787 Mdot
.13728 .16865 Mdot
.10983 .13336 Mdot
.10199 .12944 Mdot
.10199 .12552 Mdot
.18434 .22355 Mdot
.22355 .26276 Mdot
.26668 .3059 Mdot
.28629 .32943 Mdot
.29021 .33727 Mdot
.29021 .33335 Mdot
.29806 .34511 Mdot
.29413 .34119 Mdot
.29413 .34119 Mdot
.28629 .33335 Mdot
.28237 .3255 Mdot
.29413 .33335 Mdot
.29413 .32158 Mdot
.28237 .30982 Mdot
.27453 .3059 Mdot
.28629 .32158 Mdot
.27061 .30982 Mdot
.26668 .3059 Mdot
.26668 .3059 Mdot
.27061 .31374 Mdot
.26668 .30198 Mdot
.26668 .29806 Mdot
.25884 .28629 Mdot
.27061 .29413 Mdot
.27453 .29806 Mdot
.27453 .29413 Mdot
.28237 .30198 Mdot
.27845 .30198 Mdot
.28237 .30198 Mdot
.27845 .29806 Mdot
.26668 .28629 Mdot
.25492 .28237 Mdot
.24708 .27453 Mdot
.23924 .27061 Mdot
.24316 .27453 Mdot
.24708 .28237 Mdot
.24708 .28237 Mdot
.24708 .27845 Mdot
.24708 .27453 Mdot
.23531 .25884 Mdot
.23139 .24316 Mdot
.21963 .22355 Mdot
.21179 .22355 Mdot
.20394 .22355 Mdot
.1961 .22355 Mdot
.18042 .21179 Mdot
.1765 .20787 Mdot
.1765 .20394 Mdot
.17257 .20394 Mdot
.1765 .20394 Mdot
.1765 .20787 Mdot
.16473 .20394 Mdot
.15689 .19218 Mdot
.17257 .20394 Mdot
.18434 .21571 Mdot
.1765 .21179 Mdot
.18826 .21571 Mdot
.18042 .20394 Mdot
.1765 .20394 Mdot
.17257 .20002 Mdot
.14513 .16865 Mdot
.13728 .16473 Mdot
.13728 .16865 Mdot
.14513 .1765 Mdot
.14905 .18042 Mdot
.15297 .18434 Mdot
.14513 .18042 Mdot
.13728 .16865 Mdot
.12552 .15689 Mdot
.13336 .16081 Mdot
.13336 .14905 Mdot
.12944 .1412 Mdot
.12552 .13728 Mdot
.80782 .81174 Mdot
.62352 .63528 Mdot
.22747 .251 Mdot
.15297 .17257 Mdot
.13336 .15297 Mdot
.10591 .11376 Mdot
.09807 .09807 Mdot
.09415 .07846 Mdot
.10199 .07846 Mdot
.09415 .07062 Mdot
.10199 .07846 Mdot
.11768 .09807 Mdot
.14513 .13728 Mdot
.18042 .18826 Mdot
.21179 .23139 Mdot
.23924 .27061 Mdot
.251 .28629 Mdot
.26668 .3059 Mdot
.27845 .31766 Mdot
.28629 .31766 Mdot
.27845 .30982 Mdot
.27845 .29806 Mdot
.27845 .28629 Mdot
.27061 .27453 Mdot
.27061 .27453 Mdot
.27061 .28237 Mdot
.27061 .29021 Mdot
.251 .27061 Mdot
.19218 .21571 Mdot
.11376 .1216 Mdot
.10591 .11376 Mdot
.08631 .09807 Mdot
.0667 .07062 Mdot
.08239 .09415 Mdot
.11376 .13336 Mdot
.12552 .14905 Mdot
.12944 .15689 Mdot
.13728 .16473 Mdot
.1412 .16865 Mdot
.1412 .16081 Mdot
.13336 .14513 Mdot
.20394 .21571 Mdot
.24708 .27061 Mdot
.25884 .28237 Mdot
.21179 .23139 Mdot
.16865 .18042 Mdot
.13336 .13728 Mdot
.10591 .10199 Mdot
.10983 .11376 Mdot
.10199 .11376 Mdot
.10199 .11376 Mdot
.10199 .11768 Mdot
.08631 .10591 Mdot
.07454 .09023 Mdot
.09415 .11768 Mdot
.11376 .1412 Mdot
.09415 .1216 Mdot
.14513 .18042 Mdot
.16473 .20394 Mdot
.12944 .16081 Mdot
.10591 .13336 Mdot
.10591 .12944 Mdot
.10591 .12944 Mdot
.09023 .11376 Mdot
.13728 .16473 Mdot
.16865 .1961 Mdot
.23531 .27453 Mdot
.251 .29021 Mdot
.26668 .3059 Mdot
.26668 .3059 Mdot
.29806 .34119 Mdot
.29806 .34903 Mdot
.30198 .34903 Mdot
.29806 .34511 Mdot
.28629 .32943 Mdot
.3059 .34119 Mdot
.29413 .31766 Mdot
.28629 .30982 Mdot
.29021 .31766 Mdot
.28237 .30982 Mdot
.27453 .30982 Mdot
.27061 .3059 Mdot
.27061 .30982 Mdot
.27453 .31374 Mdot
.27453 .31374 Mdot
.27061 .30198 Mdot
.25884 .29021 Mdot
.23924 .26668 Mdot
.24316 .26276 Mdot
.24708 .26276 Mdot
.25884 .27453 Mdot
.27061 .29413 Mdot
.27061 .29021 Mdot
.27845 .29806 Mdot
.27845 .30198 Mdot
.26668 .29021 Mdot
.251 .27845 Mdot
.251 .27453 Mdot
.24316 .27453 Mdot
.23924 .27061 Mdot
.23531 .26668 Mdot
.23924 .26668 Mdot
.23924 .26276 Mdot
.25492 .27061 Mdot
.23924 .251 Mdot
.23139 .23924 Mdot
.23531 .24708 Mdot
.21571 .23139 Mdot
.20002 .21963 Mdot
.19218 .21571 Mdot
.1961 .21571 Mdot
.18042 .20787 Mdot
.17257 .20394 Mdot
.18042 .21571 Mdot
.18434 .22355 Mdot
.18434 .21963 Mdot
.17257 .20787 Mdot
.17257 .1961 Mdot
.1765 .20394 Mdot
.16865 .1961 Mdot
.18434 .20787 Mdot
.1765 .20394 Mdot
.1765 .20787 Mdot
.1765 .21179 Mdot
.16473 .19218 Mdot
.14513 .1765 Mdot
.14905 .18434 Mdot
.13728 .16473 Mdot
.1412 .1765 Mdot
.14905 .18434 Mdot
.14905 .18434 Mdot
.1412 .1765 Mdot
.14513 .18042 Mdot
.15297 .18042 Mdot
.15297 .1765 Mdot
.13336 .14905 Mdot
.12552 .1412 Mdot
.80782 .81566 Mdot
.59215 .60391 Mdot
.16081 .16473 Mdot
.13728 .13728 Mdot
.1216 .11376 Mdot
.10983 .09807 Mdot
.11376 .10199 Mdot
.11376 .10591 Mdot
.11376 .10591 Mdot
.1216 .11768 Mdot
.1216 .11376 Mdot
.12944 .12944 Mdot
.14905 .15689 Mdot
.18826 .20002 Mdot
.24708 .27061 Mdot
.27845 .30982 Mdot
.29806 .32943 Mdot
.30198 .33335 Mdot
.29806 .32158 Mdot
.28629 .29806 Mdot
.27453 .28629 Mdot
.27061 .28237 Mdot
.25492 .27453 Mdot
.29413 .33727 Mdot
.25884 .29806 Mdot
.28237 .3255 Mdot
.23924 .27453 Mdot
.22747 .25492 Mdot
.19218 .20394 Mdot
.1216 .12552 Mdot
.10199 .10591 Mdot
.16081 .1765 Mdot
.15297 .1765 Mdot
.12944 .15689 Mdot
.1216 .15297 Mdot
.12552 .16081 Mdot
.1216 .15297 Mdot
.12552 .14905 Mdot
.12552 .12944 Mdot
.1765 .18826 Mdot
.21963 .24316 Mdot
.23924 .27061 Mdot
.23531 .26276 Mdot
.22355 .25492 Mdot
.19218 .20787 Mdot
.14905 .16865 Mdot
.12552 .14513 Mdot
.10983 .1216 Mdot
.09023 .10591 Mdot
.07062 .08239 Mdot
.05494 .0667 Mdot
.09023 .10983 Mdot
.10199 .12552 Mdot
.10199 .1216 Mdot
.11376 .13336 Mdot
.13728 .16473 Mdot
.14905 .1765 Mdot
.11376 .1412 Mdot
.10591 .13336 Mdot
.10983 .13728 Mdot
.11768 .14513 Mdot
.16081 .20002 Mdot
.20002 .24316 Mdot
.21963 .27061 Mdot
.24316 .28629 Mdot
.25884 .29806 Mdot
.26276 .29806 Mdot
.28629 .32158 Mdot
.28629 .31766 Mdot
.29021 .3255 Mdot
.30198 .33335 Mdot
.30198 .32943 Mdot
.30982 .34119 Mdot
.29413 .3255 Mdot
.29413 .3255 Mdot
.29021 .32943 Mdot
.28629 .3255 Mdot
.29021 .33335 Mdot
.28629 .32943 Mdot
.29021 .3255 Mdot
.29413 .32943 Mdot
.30198 .32943 Mdot
.3059 .32158 Mdot
.29021 .30982 Mdot
.27453 .29021 Mdot
.26276 .28237 Mdot
.25492 .27453 Mdot
.251 .27845 Mdot
.251 .27845 Mdot
.251 .27845 Mdot
.25492 .27845 Mdot
.26668 .29806 Mdot
.25884 .29413 Mdot
.25884 .28629 Mdot
.25884 .28629 Mdot
.251 .27845 Mdot
.23531 .26668 Mdot
.24708 .27845 Mdot
.24708 .27845 Mdot
.23531 .27061 Mdot
.24316 .27453 Mdot
.23531 .26668 Mdot
.23139 .25884 Mdot
.23531 .25884 Mdot
.22747 .251 Mdot
.22355 .251 Mdot
.22355 .25492 Mdot
.22747 .25884 Mdot
.21179 .24708 Mdot
.20394 .23531 Mdot
.21179 .23924 Mdot
.21179 .23531 Mdot
.20002 .22747 Mdot
.1961 .22747 Mdot
.18826 .21963 Mdot
.17257 .20787 Mdot
.16473 .1961 Mdot
.16081 .1961 Mdot
.16473 .20002 Mdot
.16473 .20394 Mdot
.16865 .20787 Mdot
.18042 .21963 Mdot
.16865 .20394 Mdot
.16081 .20002 Mdot
.16865 .20394 Mdot
.16081 .18434 Mdot
.16865 .18826 Mdot
.16473 .18826 Mdot
.17257 .1961 Mdot
.16865 .19218 Mdot
.16865 .18826 Mdot
.15689 .18042 Mdot
.15689 .17257 Mdot
.14905 .16081 Mdot
.62352 .63528 Mdot
.38432 .38432 Mdot
.16473 .16865 Mdot
.1765 .18434 Mdot
.1961 .20787 Mdot
.16865 .17257 Mdot
.15297 .15689 Mdot
.14513 .14905 Mdot
.13336 .1412 Mdot
.1412 .14905 Mdot
.14905 .15689 Mdot
.18826 .20394 Mdot
.20394 .21963 Mdot
.25492 .27453 Mdot
.28629 .30198 Mdot
.30982 .31766 Mdot
.30982 .32158 Mdot
.3059 .3255 Mdot
.29021 .31766 Mdot
.26276 .29413 Mdot
.25492 .29806 Mdot
.25884 .3059 Mdot
.27453 .32158 Mdot
.29413 .34119 Mdot
.29021 .32158 Mdot
.28629 .31374 Mdot
.26668 .28237 Mdot
.21963 .23531 Mdot
.20787 .23531 Mdot
.12944 .14513 Mdot
.10591 .12552 Mdot
.08631 .11376 Mdot
.07846 .10591 Mdot
.08631 .10591 Mdot
.09023 .10591 Mdot
.07846 .07846 Mdot
.09023 .08239 Mdot
.12944 .12552 Mdot
.20394 .21571 Mdot
.23531 .25884 Mdot
.251 .27845 Mdot
.25492 .28629 Mdot
.24316 .28237 Mdot
.18042 .21179 Mdot
.14513 .17257 Mdot
.11768 .13728 Mdot
.09023 .10983 Mdot
.06278 .07846 Mdot
.06278 .07846 Mdot
.07846 .08631 Mdot
.08239 .09807 Mdot
.12944 .15689 Mdot
.14513 .1765 Mdot
.16473 .1961 Mdot
.14513 .1765 Mdot
.1412 .17257 Mdot
.13336 .16473 Mdot
.11768 .1412 Mdot
.14905 .1765 Mdot
.16865 .19218 Mdot
.1961 .22355 Mdot
.20787 .23531 Mdot
.23531 .26276 Mdot
.23924 .26668 Mdot
.26668 .29021 Mdot
.28237 .30198 Mdot
.28237 .30198 Mdot
.28629 .30982 Mdot
.29806 .31766 Mdot
.29806 .32158 Mdot
.30198 .32943 Mdot
.29413 .3255 Mdot
.28629 .3255 Mdot
.28629 .32943 Mdot
.29413 .33727 Mdot
.28629 .3255 Mdot
.28629 .31766 Mdot
.29021 .31374 Mdot
.29806 .31766 Mdot
.3059 .3255 Mdot
.30198 .31766 Mdot
.29021 .30982 Mdot
.27453 .29413 Mdot
.26276 .29021 Mdot
.25884 .29021 Mdot
.26276 .30198 Mdot
.24708 .28629 Mdot
.24708 .29021 Mdot
.24316 .28237 Mdot
.23924 .27453 Mdot
.24316 .28237 Mdot
.24708 .27845 Mdot
.24316 .27453 Mdot
.22747 .25884 Mdot
.23531 .27061 Mdot
.23531 .27061 Mdot
.22355 .25884 Mdot
.21571 .25492 Mdot
.21179 .251 Mdot
.21571 .25884 Mdot
.21179 .251 Mdot
.21963 .25492 Mdot
.20787 .251 Mdot
.22355 .25884 Mdot
.21963 .25492 Mdot
.21571 .25492 Mdot
.21179 .24708 Mdot
.21963 .251 Mdot
.21963 .25492 Mdot
.21963 .24708 Mdot
.21179 .23531 Mdot
.1961 .23139 Mdot
.18826 .22355 Mdot
.18434 .22355 Mdot
.16865 .20787 Mdot
.16473 .20002 Mdot
.15689 .19218 Mdot
.15297 .18826 Mdot
.15689 .1961 Mdot
.16081 .20002 Mdot
.16865 .20394 Mdot
.17257 .21179 Mdot
.16865 .20002 Mdot
.16473 .18434 Mdot
.16473 .18434 Mdot
.14905 .16473 Mdot
.15689 .17257 Mdot
.15297 .17257 Mdot
.14513 .16473 Mdot
.15689 .16473 Mdot
.15297 .16081 Mdot
.67842 .69802 Mdot
.53333 .56078 Mdot
.30982 .32943 Mdot
.29806 .32943 Mdot
.26668 .29413 Mdot
.21963 .23924 Mdot
.20394 .21571 Mdot
.19218 .19218 Mdot
.18826 .18434 Mdot
.18826 .18042 Mdot
.20787 .20002 Mdot
.21963 .21179 Mdot
.26276 .26276 Mdot
.28237 .28629 Mdot
.30198 .32158 Mdot
.30982 .34119 Mdot
.29806 .34511 Mdot
.28629 .33727 Mdot
.27845 .32158 Mdot
.27845 .32158 Mdot
.3059 .34511 Mdot
.3059 .33335 Mdot
.3059 .3255 Mdot
.30198 .33335 Mdot
.29806 .33335 Mdot
.27845 .3255 Mdot
.20394 .24316 Mdot
.17257 .20787 Mdot
.10199 .13728 Mdot
.10983 .13728 Mdot
.09023 .10199 Mdot
.07454 .07454 Mdot
.0667 .05494 Mdot
.10199 .08239 Mdot
.10199 .07846 Mdot
.23531 .23531 Mdot
.23139 .22747 Mdot
.22355 .21963 Mdot
.21571 .22355 Mdot
.22747 .24316 Mdot
.24708 .27061 Mdot
.24316 .27845 Mdot
.22355 .26668 Mdot
.15297 .18826 Mdot
.07062 .09415 Mdot
.07062 .09023 Mdot
.06278 .07846 Mdot
.07062 .08239 Mdot
.14905 .18042 Mdot
.14905 .1765 Mdot
.16081 .18434 Mdot
.16473 .18826 Mdot
.16081 .18826 Mdot
.16081 .1961 Mdot
.16865 .19218 Mdot
.15297 .17257 Mdot
.13728 .14905 Mdot
.13336 .13728 Mdot
.1216 .12552 Mdot
.14905 .16081 Mdot
.18434 .19218 Mdot
.24708 .26276 Mdot
.27845 .3059 Mdot
.27845 .31374 Mdot
.29021 .3255 Mdot
.28629 .32158 Mdot
.28629 .31766 Mdot
.28237 .3059 Mdot
.27845 .30198 Mdot
.27845 .3059 Mdot
.28629 .31766 Mdot
.28237 .32158 Mdot
.27845 .31766 Mdot
.27845 .32158 Mdot
.28629 .3255 Mdot
.28629 .3255 Mdot
.30198 .34119 Mdot
.28629 .32158 Mdot
.27453 .31374 Mdot
.27061 .30982 Mdot
.26668 .3059 Mdot
.26668 .3059 Mdot
.26276 .3059 Mdot
.26276 .30982 Mdot
.25492 .29806 Mdot
.24708 .29413 Mdot
.23924 .28629 Mdot
.23531 .29021 Mdot
.23924 .28237 Mdot
.23924 .27453 Mdot
.23924 .27453 Mdot
.23139 .27061 Mdot
.22747 .26276 Mdot
.23139 .26668 Mdot
.22355 .26276 Mdot
.21571 .25492 Mdot
.22355 .26668 Mdot
.22747 .27061 Mdot
.21571 .25884 Mdot
.20394 .251 Mdot
.20394 .251 Mdot
.20787 .251 Mdot
.20787 .24708 Mdot
.20394 .24708 Mdot
.21963 .25884 Mdot
.21963 .25492 Mdot
.22355 .25492 Mdot
.21571 .24708 Mdot
.20787 .23139 Mdot
.20394 .23531 Mdot
.20002 .23531 Mdot
.19218 .22747 Mdot
.18434 .21963 Mdot
.17257 .21179 Mdot
.15689 .19218 Mdot
.16081 .20002 Mdot
.16865 .20787 Mdot
.17257 .21179 Mdot
.17257 .20394 Mdot
.16865 .20002 Mdot
.16865 .19218 Mdot
.17257 .20002 Mdot
.16473 .18434 Mdot
.16081 .18434 Mdot
.15689 .18042 Mdot
.14905 .16865 Mdot
.15689 .17257 Mdot
.15689 .1765 Mdot
.89017 .90585 Mdot
.77253 .8039 Mdot
.54509 .61568 Mdot
.32943 .37256 Mdot
.29413 .3255 Mdot
.27845 .30198 Mdot
.26668 .26668 Mdot
.26276 .25884 Mdot
.24708 .24708 Mdot
.21179 .20787 Mdot
.20394 .20002 Mdot
.21571 .21179 Mdot
.25492 .25492 Mdot
.29021 .30198 Mdot
.29021 .32158 Mdot
.3059 .34511 Mdot
.30982 .35295 Mdot
.3255 .37256 Mdot
.3255 .36472 Mdot
.30982 .34119 Mdot
.29413 .32158 Mdot
.30198 .3255 Mdot
.31374 .34511 Mdot
.30982 .35295 Mdot
.29806 .34511 Mdot
.28629 .33335 Mdot
.23924 .28237 Mdot
.21179 .251 Mdot
.14513 .16473 Mdot
.13728 .13728 Mdot
.11376 .09023 Mdot
.11768 .08631 Mdot
.15297 .13336 Mdot
.27453 .27061 Mdot
.17257 .15297 Mdot
.15689 .14513 Mdot
.13728 .1216 Mdot
.13728 .12552 Mdot
.18434 .1961 Mdot
.21571 .24708 Mdot
.23531 .27845 Mdot
.23924 .29806 Mdot
.13728 .18042 Mdot
.08239 .11376 Mdot
.0667 .09023 Mdot
.05102 .06278 Mdot
.07846 .09415 Mdot
.08631 .10591 Mdot
.09807 .11376 Mdot
.12944 .14513 Mdot
.1412 .16081 Mdot
.15689 .18434 Mdot
.15297 .1765 Mdot
.1412 .16081 Mdot
.12944 .14513 Mdot
.15689 .1765 Mdot
.12944 .14513 Mdot
.1216 .12944 Mdot
.11768 .1216 Mdot
.23924 .27061 Mdot
.3608 .41569 Mdot
.34511 .39609 Mdot
.34511 .39609 Mdot
.3255 .3608 Mdot
.3059 .33335 Mdot
.28629 .31374 Mdot
.27845 .30198 Mdot
.27061 .29806 Mdot
.27061 .29806 Mdot
.25884 .29413 Mdot
.25884 .29413 Mdot
.26668 .30198 Mdot
.27061 .30982 Mdot
.27845 .32158 Mdot
.28237 .32158 Mdot
.28629 .33335 Mdot
.28237 .32158 Mdot
.27061 .30982 Mdot
.26276 .30198 Mdot
.25492 .29806 Mdot
.25884 .3059 Mdot
.26276 .31766 Mdot
.25492 .30982 Mdot
.26668 .31374 Mdot
.251 .30198 Mdot
.24708 .29021 Mdot
.24316 .28237 Mdot
.251 .28237 Mdot
.25492 .28237 Mdot
.23924 .26668 Mdot
.23924 .26276 Mdot
.23139 .26276 Mdot
.22355 .25884 Mdot
.22747 .26276 Mdot
.23139 .27845 Mdot
.21571 .25884 Mdot
.21571 .26668 Mdot
.21571 .26668 Mdot
.21571 .26276 Mdot
.21571 .25884 Mdot
.21963 .25492 Mdot
.21179 .24316 Mdot
.21179 .23924 Mdot
.21179 .23531 Mdot
.21571 .24316 Mdot
.21179 .23924 Mdot
.20787 .23924 Mdot
.20394 .23924 Mdot
.20002 .23531 Mdot
.18042 .21571 Mdot
.18042 .21571 Mdot
.1765 .21179 Mdot
.16473 .20394 Mdot
.16473 .20394 Mdot
.16081 .20002 Mdot
.16865 .20002 Mdot
.17257 .1961 Mdot
.17257 .18826 Mdot
.16865 .18434 Mdot
.16865 .18434 Mdot
.16081 .18042 Mdot
.14513 .16473 Mdot
.13728 .15297 Mdot
.15297 .16865 Mdot
.14905 .16473 Mdot
.14905 .17257 Mdot
.87056 .88232 Mdot
.73724 .76469 Mdot
.44706 .47843 Mdot
.4902 .53333 Mdot
.52549 .57646 Mdot
.27453 .28237 Mdot
.27061 .27845 Mdot
.25492 .25492 Mdot
.23924 .22747 Mdot
.24316 .22747 Mdot
.23531 .22355 Mdot
.24316 .23924 Mdot
.25884 .26668 Mdot
.29413 .31766 Mdot
.31374 .34903 Mdot
.3255 .36864 Mdot
.3255 .36472 Mdot
.3059 .34119 Mdot
.3059 .32943 Mdot
.32943 .34119 Mdot
.32158 .34119 Mdot
.30198 .3255 Mdot
.3059 .33727 Mdot
.30198 .34511 Mdot
.30198 .35687 Mdot
.28237 .32943 Mdot
.251 .29021 Mdot
.20002 .20787 Mdot
.15689 .1412 Mdot
.22355 .21571 Mdot
.24708 .24708 Mdot
.14513 .12552 Mdot
.13728 .12552 Mdot
.10591 .09023 Mdot
.08631 .07062 Mdot
.08631 .08239 Mdot
.10591 .11376 Mdot
.13728 .15689 Mdot
.16081 .19218 Mdot
.15297 .19218 Mdot
.10199 .13728 Mdot
.09023 .11376 Mdot
.09023 .11768 Mdot
.07062 .09415 Mdot
.07846 .09807 Mdot
.07846 .09415 Mdot
.07846 .09023 Mdot
.09415 .10983 Mdot
.10199 .1216 Mdot
.10983 .12552 Mdot
.09023 .10983 Mdot
.07454 .08631 Mdot
.12944 .15689 Mdot
.14513 .17257 Mdot
.15689 .1765 Mdot
.15689 .17257 Mdot
.19218 .21179 Mdot
.30198 .34511 Mdot
.37256 .41961 Mdot
.38432 .43922 Mdot
.38824 .44314 Mdot
.3608 .41177 Mdot
.31374 .35295 Mdot
.28629 .30982 Mdot
.25884 .27453 Mdot
.23924 .25492 Mdot
.22747 .24708 Mdot
.23139 .25492 Mdot
.24316 .25884 Mdot
.25492 .27845 Mdot
.26668 .29806 Mdot
.27845 .31766 Mdot
.28237 .31766 Mdot
.27061 .30982 Mdot
.26668 .30982 Mdot
.24708 .29413 Mdot
.25492 .3059 Mdot
.251 .30982 Mdot
.25492 .31374 Mdot
.25492 .30982 Mdot
.25884 .30198 Mdot
.25884 .30198 Mdot
.25884 .29806 Mdot
.26668 .29806 Mdot
.25492 .27845 Mdot
.25884 .28237 Mdot
.24316 .26668 Mdot
.23924 .27061 Mdot
.23531 .27453 Mdot
.21963 .26276 Mdot
.21571 .25884 Mdot
.22355 .27453 Mdot
.21571 .26668 Mdot
.21963 .26668 Mdot
.21571 .26276 Mdot
.23139 .27061 Mdot
.22747 .25884 Mdot
.21963 .24316 Mdot
.21571 .24316 Mdot
.1961 .22355 Mdot
.18826 .21963 Mdot
.18826 .22355 Mdot
.1961 .23139 Mdot
.19218 .23531 Mdot
.19218 .23531 Mdot
.19218 .23531 Mdot
.18826 .23139 Mdot
.18434 .22355 Mdot
.18042 .21571 Mdot
.17257 .20787 Mdot
.16865 .20394 Mdot
.16081 .18826 Mdot
.16865 .18826 Mdot
.1765 .18826 Mdot
.17257 .1765 Mdot
.1765 .18434 Mdot
.1765 .18434 Mdot
.16865 .17257 Mdot
.15689 .16473 Mdot
.15297 .16473 Mdot
.15689 .16865 Mdot
.15689 .17257 Mdot
.14513 .16081 Mdot
.81566 .83527 Mdot
.72547 .76861 Mdot
.5098 .56078 Mdot
.45883 .50588 Mdot
.3255 .34511 Mdot
.33727 .34903 Mdot
.31766 .32158 Mdot
.29413 .29413 Mdot
.27061 .26668 Mdot
.251 .251 Mdot
.24316 .24708 Mdot
.25492 .26276 Mdot
.28237 .30198 Mdot
.30198 .3255 Mdot
.32158 .34903 Mdot
.32943 .3608 Mdot
.34511 .36472 Mdot
.33727 .35687 Mdot
.32158 .34119 Mdot
.31374 .34119 Mdot
.3059 .33727 Mdot
.29413 .34511 Mdot
.3059 .3608 Mdot
.32158 .37256 Mdot
.32158 .3608 Mdot
.29806 .31374 Mdot
.28629 .29021 Mdot
.23139 .22747 Mdot
.13336 .11768 Mdot
.11768 .11376 Mdot
.10199 .09807 Mdot
.07846 .07062 Mdot
.07846 .07846 Mdot
.07062 .07846 Mdot
.0667 .08239 Mdot
.07454 .09415 Mdot
.07846 .10591 Mdot
.07454 .10983 Mdot
.07846 .10983 Mdot
.09807 .12944 Mdot
.10983 .13728 Mdot
.10199 .1216 Mdot
.09415 .10983 Mdot
.09807 .10591 Mdot
.08631 .09415 Mdot
.09807 .10983 Mdot
.08239 .08239 Mdot
.0667 .07062 Mdot
.06278 .06278 Mdot
.0667 .0667 Mdot
.08631 .09023 Mdot
.09807 .10199 Mdot
.10591 .10983 Mdot
.16473 .18042 Mdot
.1961 .21179 Mdot
.28237 .31766 Mdot
.32158 .36864 Mdot
.36472 .42746 Mdot
.38432 .45491 Mdot
.40001 .47059 Mdot
.34511 .39609 Mdot
.24316 .26668 Mdot
.18042 .18434 Mdot
.15297 .14905 Mdot
.15297 .14513 Mdot
.18826 .18042 Mdot
.20787 .20787 Mdot
.22355 .22355 Mdot
.251 .26668 Mdot
.26668 .29021 Mdot
.26276 .30198 Mdot
.26276 .30982 Mdot
.24708 .29806 Mdot
.24708 .30198 Mdot
.251 .31374 Mdot
.25492 .31374 Mdot
.25492 .30982 Mdot
.26276 .30982 Mdot
.251 .29021 Mdot
.25492 .27845 Mdot
.25884 .28237 Mdot
.26276 .28237 Mdot
.24708 .27061 Mdot
.24708 .27453 Mdot
.23139 .25884 Mdot
.23139 .26668 Mdot
.21963 .26276 Mdot
.21179 .251 Mdot
.20787 .25492 Mdot
.20787 .25884 Mdot
.20787 .25492 Mdot
.22747 .26668 Mdot
.22355 .251 Mdot
.23139 .25492 Mdot
.21963 .23531 Mdot
.22747 .24316 Mdot
.21963 .23531 Mdot
.21179 .23531 Mdot
.1961 .22747 Mdot
.19218 .23139 Mdot
.1765 .21179 Mdot
.16865 .20787 Mdot
.17257 .21571 Mdot
.18042 .22747 Mdot
.18434 .22747 Mdot
.18434 .22747 Mdot
.18042 .22355 Mdot
.17257 .21179 Mdot
.1765 .21179 Mdot
.1765 .20002 Mdot
.18434 .20002 Mdot
.18434 .18826 Mdot
.19218 .1961 Mdot
.18434 .18434 Mdot
.18042 .1765 Mdot
.17257 .17257 Mdot
.16865 .1765 Mdot
.16865 .18042 Mdot
.14513 .16081 Mdot
.13336 .14513 Mdot
.81566 .83919 Mdot
.67057 .6941 Mdot
.56862 .60391 Mdot
.52157 .55294 Mdot
.48235 .5098 Mdot
.40001 .42746 Mdot
.3059 .3255 Mdot
.27453 .28629 Mdot
.251 .25884 Mdot
.22747 .22747 Mdot
.23924 .24316 Mdot
.24316 .251 Mdot
.27453 .28629 Mdot
.3059 .32158 Mdot
.32943 .35687 Mdot
.32943 .36472 Mdot
.32158 .36472 Mdot
.3059 .35295 Mdot
.29806 .34511 Mdot
.29413 .34119 Mdot
.32158 .36472 Mdot
.34511 .38432 Mdot
.3608 .38432 Mdot
.34903 .36472 Mdot
.33335 .35295 Mdot
.21963 .22355 Mdot
.1765 .18826 Mdot
.13336 .14513 Mdot
.09415 .10591 Mdot
.08239 .09415 Mdot
.07454 .09023 Mdot
.06278 .08631 Mdot
.05102 .07454 Mdot
.04317 .06278 Mdot
.07062 .09807 Mdot
.10199 .13336 Mdot
.1216 .15689 Mdot
.13728 .17257 Mdot
.13728 .16865 Mdot
.12944 .14905 Mdot
.1216 .13728 Mdot
.11768 .13336 Mdot
.10199 .10983 Mdot
.08631 .09415 Mdot
.0667 .05886 Mdot
.0667 .05494 Mdot
.07846 .0667 Mdot
.08631 .07846 Mdot
.09807 .09023 Mdot
.08631 .07454 Mdot
.07846 .07454 Mdot
.09415 .08631 Mdot
.14905 .15689 Mdot
.19218 .21179 Mdot
.25492 .29806 Mdot
.30982 .37256 Mdot
.35295 .42354 Mdot
.31374 .3804 Mdot
.35295 .41961 Mdot
.25492 .28237 Mdot
.21571 .21963 Mdot
.18434 .16865 Mdot
.18042 .15689 Mdot
.15297 .12944 Mdot
.16865 .15689 Mdot
.20002 .20002 Mdot
.22355 .24316 Mdot
.23924 .27061 Mdot
.24708 .28629 Mdot
.23531 .27845 Mdot
.23531 .28237 Mdot
.23139 .28237 Mdot
.251 .29413 Mdot
.24316 .28237 Mdot
.23924 .27061 Mdot
.23531 .25884 Mdot
.23531 .25884 Mdot
.23531 .26276 Mdot
.23139 .25884 Mdot
.22355 .251 Mdot
.22355 .25492 Mdot
.21571 .251 Mdot
.20394 .24316 Mdot
.21179 .24708 Mdot
.21963 .251 Mdot
.21963 .25492 Mdot
.21571 .25492 Mdot
.22747 .25884 Mdot
.24316 .27061 Mdot
.23924 .26668 Mdot
.23924 .26276 Mdot
.23924 .25884 Mdot
.22355 .23924 Mdot
.21571 .23531 Mdot
.21179 .24316 Mdot
.20394 .23531 Mdot
.19218 .22747 Mdot
.17257 .20787 Mdot
.17257 .20787 Mdot
.16865 .20394 Mdot
.16865 .20787 Mdot
.17257 .21571 Mdot
.18042 .21963 Mdot
.18434 .22747 Mdot
.18042 .22747 Mdot
.17257 .21571 Mdot
.17257 .20787 Mdot
.18434 .21179 Mdot
.1765 .19218 Mdot
.16865 .18042 Mdot
.16473 .1765 Mdot
.16865 .18042 Mdot
.16473 .1765 Mdot
.15689 .17257 Mdot
.15689 .17257 Mdot
.14513 .16081 Mdot
.13336 .14905 Mdot
.92154 .9333 Mdot
.83135 .85095 Mdot
.64705 .6941 Mdot
.5647 .60783 Mdot
.52549 .57646 Mdot
.31766 .33727 Mdot
.23924 .25492 Mdot
.21179 .22747 Mdot
.18434 .19218 Mdot
.17257 .1765 Mdot
.17257 .16865 Mdot
.21179 .21179 Mdot
.29413 .30982 Mdot
.3059 .33335 Mdot
.3255 .3608 Mdot
.33727 .37648 Mdot
.32943 .37256 Mdot
.31374 .35687 Mdot
.31374 .35687 Mdot
.32943 .36472 Mdot
.34903 .3804 Mdot
.35295 .3804 Mdot
.36472 .38824 Mdot
.3608 .38432 Mdot
.33335 .3608 Mdot
.24316 .26668 Mdot
.20002 .22747 Mdot
.14513 .16865 Mdot
.09807 .11768 Mdot
.0667 .08631 Mdot
.04709 .07062 Mdot
.03925 .06278 Mdot
.07062 .10199 Mdot
.10591 .13728 Mdot
.14513 .18434 Mdot
.1765 .21571 Mdot
.18434 .22747 Mdot
.16865 .20394 Mdot
.12944 .16081 Mdot
.11376 .13336 Mdot
.09807 .10591 Mdot
.07846 .08631 Mdot
.07454 .07846 Mdot
.07062 .0667 Mdot
.08631 .07454 Mdot
.10591 .09415 Mdot
.1216 .10983 Mdot
.12552 .11376 Mdot
.12944 .1216 Mdot
.13336 .11768 Mdot
.11768 .10983 Mdot
.13728 .13336 Mdot
.20002 .21179 Mdot
.251 .28237 Mdot
.31766 .36864 Mdot
.13728 .15689 Mdot
.15297 .18434 Mdot
.16473 .20002 Mdot
.26668 .31766 Mdot
.34903 .40001 Mdot
.34119 .36864 Mdot
.32158 .33727 Mdot
.28629 .29413 Mdot
.24708 .251 Mdot
.23139 .24316 Mdot
.23924 .25884 Mdot
.24708 .27061 Mdot
.24708 .27061 Mdot
.23531 .26276 Mdot
.23531 .26668 Mdot
.23531 .26276 Mdot
.23531 .27061 Mdot
.22355 .251 Mdot
.21963 .24708 Mdot
.21963 .24708 Mdot
.21571 .23924 Mdot
.20787 .23531 Mdot
.21179 .23924 Mdot
.21963 .24708 Mdot
.21963 .24708 Mdot
.20787 .23531 Mdot
.20394 .22747 Mdot
.20394 .22747 Mdot
.22355 .24316 Mdot
.23139 .25492 Mdot
.22355 .251 Mdot
.21963 .24708 Mdot
.22355 .25492 Mdot
.22355 .24708 Mdot
.21963 .251 Mdot
.21963 .251 Mdot
.21179 .23924 Mdot
.21179 .24316 Mdot
.21179 .23924 Mdot
.19218 .22355 Mdot
.1765 .20787 Mdot
.1765 .20394 Mdot
.17257 .20002 Mdot
.17257 .20002 Mdot
.16865 .20002 Mdot
.16865 .20394 Mdot
.16865 .20394 Mdot
.16865 .20787 Mdot
.17257 .21179 Mdot
.17257 .20787 Mdot
.17257 .20394 Mdot
.16081 .19218 Mdot
.16473 .18826 Mdot
.16473 .18434 Mdot
.16473 .18826 Mdot
.15297 .17257 Mdot
.16473 .18434 Mdot
.16865 .18434 Mdot
.16473 .18042 Mdot
.15297 .17257 Mdot
.91761 .92938 Mdot
.81566 .84703 Mdot
.48235 .52941 Mdot
.27845 .3059 Mdot
.24316 .26668 Mdot
.21571 .23531 Mdot
.18826 .20002 Mdot
.17257 .1765 Mdot
.16473 .15689 Mdot
.17257 .15689 Mdot
.23139 .23139 Mdot
.26276 .27061 Mdot
.29021 .30982 Mdot
.31374 .34511 Mdot
.32943 .36864 Mdot
.34511 .39217 Mdot
.36472 .41177 Mdot
.34903 .38824 Mdot
.33727 .36864 Mdot
.35295 .3804 Mdot
.34511 .37256 Mdot
.34903 .38432 Mdot
.34119 .3804 Mdot
.3255 .37256 Mdot
.29021 .34119 Mdot
.21571 .25884 Mdot
.11768 .1412 Mdot
.07846 .09415 Mdot
.05886 .07454 Mdot
.09023 .11376 Mdot
.11376 .14905 Mdot
.13336 .16865 Mdot
.15689 .1961 Mdot
.18042 .21963 Mdot
.16865 .20394 Mdot
.1412 .16865 Mdot
.11376 .12552 Mdot
.08631 .08631 Mdot
.06278 .06278 Mdot
.05494 .05494 Mdot
.0667 .07062 Mdot
.07454 .07454 Mdot
.15689 .16865 Mdot
.12944 .13336 Mdot
.11376 .10983 Mdot
.31374 .34903 Mdot
.27845 .30198 Mdot
.15689 .15297 Mdot
.26668 .29413 Mdot
.23924 .25884 Mdot
.21179 .23139 Mdot
.18434 .20394 Mdot
.14905 .16081 Mdot
.09415 .09807 Mdot
.07454 .07454 Mdot
.05886 .05886 Mdot
.22747 .26276 Mdot
.49804 .58039 Mdot
.50588 .58039 Mdot
.4902 .5647 Mdot
.33727 .37256 Mdot
.31766 .35295 Mdot
.30198 .32943 Mdot
.28629 .30982 Mdot
.27845 .29413 Mdot
.25884 .27845 Mdot
.25492 .27845 Mdot
.23924 .27453 Mdot
.24316 .28629 Mdot
.23924 .27845 Mdot
.23531 .26668 Mdot
.22747 .26276 Mdot
.21571 .24708 Mdot
.21571 .24708 Mdot
.20787 .23531 Mdot
.21179 .23139 Mdot
.22355 .24316 Mdot
.21571 .23531 Mdot
.1961 .21571 Mdot
.20394 .21963 Mdot
.20787 .22355 Mdot
.20394 .21963 Mdot
.20394 .22747 Mdot
.20394 .23139 Mdot
.20787 .23924 Mdot
.20002 .23531 Mdot
.1961 .23531 Mdot
.20002 .23924 Mdot
.20002 .24708 Mdot
.1961 .24316 Mdot
.19218 .23531 Mdot
.18042 .21963 Mdot
.18042 .21179 Mdot
.18042 .20787 Mdot
.1765 .20002 Mdot
.1765 .20002 Mdot
.16473 .1961 Mdot
.16081 .19218 Mdot
.15689 .19218 Mdot
.16473 .20394 Mdot
.16473 .20787 Mdot
.16473 .20787 Mdot
.16865 .21179 Mdot
.16865 .21179 Mdot
.16081 .20002 Mdot
.16081 .1961 Mdot
.16473 .19218 Mdot
.16081 .18826 Mdot
.16081 .18042 Mdot
.15689 .1765 Mdot
.16081 .17257 Mdot
.15689 .16865 Mdot
.73724 .76076 Mdot
.54117 .57254 Mdot
.27845 .3059 Mdot
.21963 .23924 Mdot
.21179 .23139 Mdot
.19218 .20002 Mdot
.20787 .20787 Mdot
.1961 .19218 Mdot
.1961 .18826 Mdot
.1961 .18826 Mdot
.20394 .20002 Mdot
.26276 .28237 Mdot
.30982 .34119 Mdot
.34119 .3804 Mdot
.34903 .38824 Mdot
.35687 .39609 Mdot
.34511 .38432 Mdot
.32943 .36472 Mdot
.33335 .37256 Mdot
.34511 .39609 Mdot
.33727 .38824 Mdot
.32158 .3804 Mdot
.33335 .39609 Mdot
.22747 .27061 Mdot
.10199 .1216 Mdot
.10199 .1216 Mdot
.09415 .11376 Mdot
.09415 .11768 Mdot
.10199 .12552 Mdot
.10983 .13336 Mdot
.11768 .1412 Mdot
.12944 .14513 Mdot
.1412 .16081 Mdot
.11768 .13336 Mdot
.07846 .08239 Mdot
.07454 .0667 Mdot
.0667 .06278 Mdot
.05886 .05494 Mdot
.07062 .06278 Mdot
.13728 .1412 Mdot
.08239 .07454 Mdot
.18434 .20002 Mdot
.67057 .78429 Mdot
.65881 .77253 Mdot
.41569 .48628 Mdot
.27845 .32158 Mdot
.27453 .31374 Mdot
.12944 .13728 Mdot
.11768 .1216 Mdot
.08631 .08631 Mdot
.09415 .09415 Mdot
.07454 .07062 Mdot
.07062 .06278 Mdot
.07846 .07062 Mdot
.47059 .54902 Mdot
.58431 .67842 Mdot
.54509 .62744 Mdot
.51765 .59607 Mdot
.41961 .47843 Mdot
.40393 .46275 Mdot
.39217 .44706 Mdot
.38432 .43922 Mdot
.3608 .40393 Mdot
.33335 .3804 Mdot
.31766 .36864 Mdot
.30198 .34511 Mdot
.27845 .32158 Mdot
.27061 .30982 Mdot
.26276 .29413 Mdot
.24708 .27845 Mdot
.23924 .26276 Mdot
.22747 .24708 Mdot
.22355 .23531 Mdot
.22355 .23139 Mdot
.21571 .22747 Mdot
.20394 .21571 Mdot
.20002 .21179 Mdot
.1961 .20787 Mdot
.20002 .21571 Mdot
.19218 .20787 Mdot
.18434 .20394 Mdot
.18434 .21179 Mdot
.17257 .20787 Mdot
.16081 .20002 Mdot
.1765 .21571 Mdot
.16865 .20787 Mdot
.17257 .20787 Mdot
.1765 .21963 Mdot
.1765 .21963 Mdot
.17257 .21571 Mdot
.16865 .20394 Mdot
.16865 .20002 Mdot
.16473 .1961 Mdot
.16473 .1961 Mdot
.16081 .19218 Mdot
.16473 .20394 Mdot
.16865 .20394 Mdot
.16865 .20787 Mdot
.16081 .1961 Mdot
.16865 .20394 Mdot
.16473 .1961 Mdot
.16081 .1961 Mdot
.16081 .1961 Mdot
.16865 .1961 Mdot
.15297 .18042 Mdot
.15297 .16865 Mdot
.14905 .17257 Mdot
.14905 .17257 Mdot
.1412 .16473 Mdot
.63528 .6392 Mdot
.51765 .53333 Mdot
.36472 .38824 Mdot
.29413 .3059 Mdot
.251 .251 Mdot
.23924 .23139 Mdot
.21179 .20002 Mdot
.18042 .16865 Mdot
.16081 .14905 Mdot
.17257 .16473 Mdot
.251 .26668 Mdot
.28629 .3059 Mdot
.34903 .37648 Mdot
.35295 .38824 Mdot
.35295 .39609 Mdot
.29806 .33727 Mdot
.33727 .38432 Mdot
.3059 .34903 Mdot
.29021 .34119 Mdot
.28237 .34119 Mdot
.30198 .36472 Mdot
.21963 .26668 Mdot
.14513 .17257 Mdot
.1216 .14905 Mdot
.11376 .12944 Mdot
.09415 .10983 Mdot
.09807 .10591 Mdot
.09807 .10199 Mdot
.11376 .11376 Mdot
.12552 .12944 Mdot
.1216 .12552 Mdot
.09415 .09807 Mdot
.07846 .07454 Mdot
.07846 .07454 Mdot
.07846 .07454 Mdot
.07062 .06278 Mdot
.08631 .08239 Mdot
.10983 .10983 Mdot
.11376 .11376 Mdot
.38824 .44314 Mdot
.48235 .56078 Mdot
.6941 .82743 Mdot
.41177 .4902 Mdot
.20002 .22355 Mdot
.14905 .16473 Mdot
.11768 .1216 Mdot
.08631 .08239 Mdot
.07062 .05494 Mdot
.07846 .06278 Mdot
.07846 .06278 Mdot
.06278 .05494 Mdot
.21179 .23924 Mdot
.58431 .6941 Mdot
.53333 .62352 Mdot
.52549 .61176 Mdot
.47843 .55294 Mdot
.32943 .37256 Mdot
.35295 .40001 Mdot
.37648 .42746 Mdot
.42746 .48235 Mdot
.4902 .56078 Mdot
.50196 .58039 Mdot
.4902 .56078 Mdot
.46667 .52941 Mdot
.40785 .45491 Mdot
.37648 .40393 Mdot
.35687 .37648 Mdot
.33727 .35687 Mdot
.30982 .32943 Mdot
.27845 .3059 Mdot
.24316 .26668 Mdot
.22747 .251 Mdot
.22355 .23531 Mdot
.21179 .22355 Mdot
.20787 .22355 Mdot
.21571 .23139 Mdot
.20002 .21963 Mdot
.1961 .21963 Mdot
.19218 .21963 Mdot
.18434 .21571 Mdot
.1765 .20787 Mdot
.17257 .20002 Mdot
.18042 .20787 Mdot
.17257 .20002 Mdot
.16473 .20002 Mdot
.1765 .21179 Mdot
.1765 .21179 Mdot
.16473 .19218 Mdot
.18042 .20394 Mdot
.16865 .19218 Mdot
.16473 .18826 Mdot
.16081 .18826 Mdot
.15689 .18826 Mdot
.15689 .19218 Mdot
.14905 .18042 Mdot
.15689 .18826 Mdot
.14905 .17257 Mdot
.15689 .18042 Mdot
.14905 .16865 Mdot
.15297 .17257 Mdot
.14905 .16473 Mdot
.1412 .16081 Mdot
.12944 .15297 Mdot
.1412 .17257 Mdot
.13728 .16865 Mdot
.12944 .16081 Mdot
.90977 .92154 Mdot
.73724 .749 Mdot
.40393 .41177 Mdot
.34903 .35295 Mdot
.21571 .18826 Mdot
.20787 .18434 Mdot
.18042 .16081 Mdot
.15689 .1412 Mdot
.16473 .15689 Mdot
.18826 .18826 Mdot
.22355 .23531 Mdot
.27845 .29806 Mdot
.27453 .30198 Mdot
.20787 .22747 Mdot
.21963 .24708 Mdot
.1961 .22747 Mdot
.17257 .20787 Mdot
.18826 .22355 Mdot
.23139 .27453 Mdot
.25884 .30198 Mdot
.16865 .19218 Mdot
.1765 .19218 Mdot
.1412 .15689 Mdot
.1216 .12944 Mdot
.09807 .10199 Mdot
.09415 .09415 Mdot
.11376 .11376 Mdot
.13336 .13728 Mdot
.12552 .13336 Mdot
.08631 .08631 Mdot
.07454 .08239 Mdot
.07454 .08631 Mdot
.07454 .08631 Mdot
.07846 .07846 Mdot
.11768 .1216 Mdot
.12552 .13336 Mdot
.13728 .14905 Mdot
.13336 .14905 Mdot
.19218 .21963 Mdot
.40393 .47059 Mdot
.39609 .46275 Mdot
.24316 .27845 Mdot
.11768 .1216 Mdot
.14513 .14513 Mdot
.07454 .05494 Mdot
.0667 .04709 Mdot
.05886 .03141 Mdot
.05494 .02357 Mdot
.05886 .04317 Mdot
.27845 .31374 Mdot
.50588 .59607 Mdot
.53333 .62744 Mdot
.49804 .58823 Mdot
.52549 .61176 Mdot
.47451 .54509 Mdot
.41961 .46667 Mdot
.35687 .38432 Mdot
.36472 .40001 Mdot
.54117 .61176 Mdot
.52549 .59607 Mdot
.54117 .61176 Mdot
.57254 .6392 Mdot
.52157 .58431 Mdot
.36864 .39609 Mdot
.39217 .41569 Mdot
.42354 .45491 Mdot
.42746 .46667 Mdot
.40785 .45098 Mdot
.38432 .42746 Mdot
.35687 .39609 Mdot
.3255 .36472 Mdot
.28629 .32158 Mdot
.27061 .29806 Mdot
.251 .27845 Mdot
.24316 .27453 Mdot
.23924 .26668 Mdot
.23139 .26276 Mdot
.21963 .251 Mdot
.1961 .22747 Mdot
.18434 .20002 Mdot
.18042 .20002 Mdot
.1765 .1961 Mdot
.17257 .18826 Mdot
.17257 .18826 Mdot
.1765 .1961 Mdot
.18042 .18826 Mdot
.19218 .1961 Mdot
.19218 .20394 Mdot
.18042 .20002 Mdot
.15297 .17257 Mdot
.1216 .15297 Mdot
.10199 .12552 Mdot
.09023 .11376 Mdot
.09807 .1216 Mdot
.10591 .12944 Mdot
.11768 .13728 Mdot
.1412 .16081 Mdot
.15689 .17257 Mdot
.15297 .16473 Mdot
.1412 .15297 Mdot
.14513 .15689 Mdot
.13336 .15689 Mdot
.12552 .15297 Mdot
.12944 .16081 Mdot
.85095 .85095 Mdot
.6196 .60391 Mdot
.22747 .20394 Mdot
.23139 .21571 Mdot
.21571 .20394 Mdot
.20394 .1961 Mdot
.20787 .20394 Mdot
.20394 .20787 Mdot
.18826 .18826 Mdot
.18042 .18042 Mdot
.16865 .16081 Mdot
.14513 .14513 Mdot
.12552 .13336 Mdot
.13336 .14905 Mdot
.14513 .16081 Mdot
.18826 .20787 Mdot
.21571 .23531 Mdot
.19218 .20787 Mdot
.17257 .18434 Mdot
.1412 .14905 Mdot
.11768 .1216 Mdot
.10591 .10983 Mdot
.10199 .10983 Mdot
.1216 .12552 Mdot
.1412 .14513 Mdot
.11768 .12944 Mdot
.10591 .11768 Mdot
.09023 .09807 Mdot
.09415 .10591 Mdot
.09415 .10591 Mdot
.07846 .09023 Mdot
.07846 .08239 Mdot
.13336 .1412 Mdot
.17257 .19218 Mdot
.20394 .22747 Mdot
.21571 .24708 Mdot
.26276 .29806 Mdot
.28237 .32158 Mdot
.26276 .29413 Mdot
.11376 .11768 Mdot
.12944 .13728 Mdot
.10591 .09807 Mdot
.09023 .07062 Mdot
.07846 .05494 Mdot
.0667 .04317 Mdot
.05886 .04317 Mdot
.21963 .22355 Mdot
.42746 .48235 Mdot
.44314 .51765 Mdot
.48628 .57254 Mdot
.5098 .59215 Mdot
.53725 .61176 Mdot
.54117 .61176 Mdot
.50196 .56862 Mdot
.48628 .54509 Mdot
.4902 .56078 Mdot
.5098 .58431 Mdot
.52157 .58823 Mdot
.51765 .58039 Mdot
.57646 .64705 Mdot
.51765 .57646 Mdot
.33335 .3608 Mdot
.34511 .37256 Mdot
.31766 .33727 Mdot
.45491 .50196 Mdot
.52157 .58431 Mdot
.36864 .40393 Mdot
.34903 .38432 Mdot
.35295 .39609 Mdot
.3804 .42746 Mdot
.38824 .43922 Mdot
.39217 .44314 Mdot
.3804 .4353 Mdot
.36864 .41177 Mdot
.34903 .38432 Mdot
.30982 .33727 Mdot
.27061 .29021 Mdot
.22355 .22747 Mdot
.20394 .20787 Mdot
.20394 .21179 Mdot
.19218 .20394 Mdot
.1765 .18434 Mdot
.18826 .19218 Mdot
.1961 .1961 Mdot
.18434 .18826 Mdot
.17257 .18434 Mdot
.13336 .14513 Mdot
.09807 .10983 Mdot
.05886 .07454 Mdot
.03533 .04709 Mdot
.02357 .03141 Mdot
.03533 .04317 Mdot
.03533 .04709 Mdot
.09023 .10983 Mdot
.11376 .13728 Mdot
.13336 .15297 Mdot
.1412 .15297 Mdot
.1412 .14905 Mdot
.1412 .15297 Mdot
.12552 .1412 Mdot
.11768 .13728 Mdot
.65097 .65097 Mdot
.54902 .56862 Mdot
.30198 .31374 Mdot
.28629 .30198 Mdot
.26668 .27845 Mdot
.24708 .24708 Mdot
.1961 .18826 Mdot
.18434 .1765 Mdot
.16473 .16081 Mdot
.15689 .15297 Mdot
.14905 .15689 Mdot
.15297 .16473 Mdot
.18434 .19218 Mdot
.23139 .23924 Mdot
.22355 .23139 Mdot
.19218 .19218 Mdot
.15689 .15689 Mdot
.13336 .13728 Mdot
.11376 .11768 Mdot
.11768 .12552 Mdot
.14513 .15297 Mdot
.15689 .16865 Mdot
.14513 .15297 Mdot
.13336 .14905 Mdot
.11768 .12944 Mdot
.10591 .11376 Mdot
.10591 .11768 Mdot
.07062 .07846 Mdot
.0667 .0667 Mdot
.07846 .07454 Mdot
.09807 .10591 Mdot
.15297 .1765 Mdot
.20394 .23139 Mdot
.27845 .32158 Mdot
.27061 .30982 Mdot
.21571 .24316 Mdot
.17257 .1961 Mdot
.14513 .15689 Mdot
.12552 .12944 Mdot
.11376 .11376 Mdot
.10983 .10591 Mdot
.09807 .09415 Mdot
.10199 .10199 Mdot
.09415 .09807 Mdot
.16081 .1765 Mdot
.251 .28237 Mdot
.29806 .33335 Mdot
.36472 .40001 Mdot
.60391 .67842 Mdot
.57646 .64313 Mdot
.57646 .64705 Mdot
.57254 .64313 Mdot
.56078 .62744 Mdot
.55294 .62352 Mdot
.54902 .6196 Mdot
.53725 .59999 Mdot
.53333 .59999 Mdot
.53725 .60783 Mdot
.47451 .53725 Mdot
.43138 .47843 Mdot
.39609 .43138 Mdot
.38824 .42746 Mdot
.62744 .71371 Mdot
.55686 .6392 Mdot
.35687 .40001 Mdot
.35687 .40393 Mdot
.32943 .36864 Mdot
.3255 .3608 Mdot
.43138 .49412 Mdot
.47059 .54117 Mdot
.48628 .56078 Mdot
.4902 .5647 Mdot
.47451 .54509 Mdot
.42354 .47843 Mdot
.38824 .43138 Mdot
.36864 .40393 Mdot
.33335 .3608 Mdot
.30198 .32158 Mdot
.28237 .30198 Mdot
.26668 .27845 Mdot
.23924 .24708 Mdot
.20787 .21963 Mdot
.18826 .20787 Mdot
.15689 .17257 Mdot
.09415 .10591 Mdot
.05102 .0667 Mdot
.03533 .04709 Mdot
.01965 .02749 Mdot
.01965 .02749 Mdot
.0118 .01965 Mdot
.00788 .01572 Mdot
.03533 .04317 Mdot
.05494 .0667 Mdot
.08631 .09807 Mdot
.11768 .12944 Mdot
.13728 .15297 Mdot
.13728 .16081 Mdot
.14513 .1765 Mdot
.749 .76861 Mdot
.59607 .6196 Mdot
.34903 .3608 Mdot
.26276 .26276 Mdot
.25884 .26668 Mdot
.23139 .24316 Mdot
.23531 .24708 Mdot
.21571 .22747 Mdot
.21179 .22355 Mdot
.20787 .21571 Mdot
.23531 .23139 Mdot
.24316 .23531 Mdot
.21963 .21571 Mdot
.1765 .1765 Mdot
.14905 .14905 Mdot
.1216 .1216 Mdot
.1216 .1216 Mdot
.13728 .1412 Mdot
.15689 .16081 Mdot
.16865 .18042 Mdot
.18042 .19218 Mdot
.16865 .18434 Mdot
.12552 .13728 Mdot
.10591 .11376 Mdot
.0667 .07062 Mdot
.05886 .07062 Mdot
.05494 .0667 Mdot
.07062 .08239 Mdot
.08631 .10199 Mdot
.14513 .16473 Mdot
.15689 .18434 Mdot
.16473 .18826 Mdot
.1765 .1961 Mdot
.14905 .16473 Mdot
.12944 .13336 Mdot
.11768 .11768 Mdot
.10591 .09807 Mdot
.1216 .1216 Mdot
.10591 .10591 Mdot
.23139 .26276 Mdot
.21963 .24316 Mdot
.24708 .28237 Mdot
.27061 .30982 Mdot
.28629 .32158 Mdot
.251 .26276 Mdot
.38432 .40785 Mdot
.60391 .67057 Mdot
.53333 .59215 Mdot
.57254 .6392 Mdot
.53725 .59999 Mdot
.5647 .63136 Mdot
.55686 .63136 Mdot
.54902 .62352 Mdot
.55294 .63136 Mdot
.54902 .62744 Mdot
.52549 .60783 Mdot
.52157 .59607 Mdot
.50196 .57646 Mdot
.48628 .56078 Mdot
.47843 .55294 Mdot
.49804 .57646 Mdot
.48235 .55686 Mdot
.47843 .55294 Mdot
.43922 .5098 Mdot
.42746 .4902 Mdot
.42354 .48628 Mdot
.45098 .52157 Mdot
.46667 .53333 Mdot
.47843 .54902 Mdot
.48235 .55686 Mdot
.48628 .55294 Mdot
.48235 .55294 Mdot
.49412 .56078 Mdot
.4902 .54902 Mdot
.46667 .51372 Mdot
.44314 .4902 Mdot
.42746 .47843 Mdot
.39609 .44706 Mdot
.35687 .40393 Mdot
.29413 .33727 Mdot
.15297 .1765 Mdot
.11768 .13728 Mdot
.09023 .10199 Mdot
.04317 .04709 Mdot
.02749 .03141 Mdot
.01572 .01965 Mdot
.00788 .0118 Mdot
.00788 .0118 Mdot
.00396 .0118 Mdot
.00396 .0118 Mdot
.01572 .01572 Mdot
.08631 .09415 Mdot
.12944 .14513 Mdot
.1412 .16081 Mdot
.14513 .16473 Mdot
.88232 .89017 Mdot
.62744 .62352 Mdot
.37256 .3804 Mdot
.4353 .46667 Mdot
.43922 .47451 Mdot
.35687 .3804 Mdot
.31766 .33727 Mdot
.27845 .29413 Mdot
.27061 .27845 Mdot
.26276 .26276 Mdot
.21571 .20394 Mdot
.19218 .18434 Mdot
.16865 .16473 Mdot
.14905 .14513 Mdot
.12552 .12552 Mdot
.12552 .12552 Mdot
.1412 .14513 Mdot
.15297 .15297 Mdot
.16865 .1765 Mdot
.17257 .18434 Mdot
.13728 .14513 Mdot
.11768 .11768 Mdot
.09023 .09023 Mdot
.07846 .07846 Mdot
.07062 .08239 Mdot
.07062 .08631 Mdot
.09023 .10983 Mdot
.10983 .13336 Mdot
.13728 .16865 Mdot
.15689 .18434 Mdot
.16081 .19218 Mdot
.12944 .14905 Mdot
.11768 .12552 Mdot
.10983 .10199 Mdot
.10199 .09415 Mdot
.09415 .08631 Mdot
.12552 .12552 Mdot
.24316 .26668 Mdot
.40393 .46667 Mdot
.39217 .46667 Mdot
.39609 .47059 Mdot
.41177 .47843 Mdot
.36472 .41177 Mdot
.27061 .27845 Mdot
.75292 .85095 Mdot
.46667 .52549 Mdot
.46667 .53333 Mdot
.35687 .40393 Mdot
.37256 .41569 Mdot
.48628 .56078 Mdot
.52157 .59215 Mdot
.53725 .61176 Mdot
.54902 .63136 Mdot
.53333 .61568 Mdot
.54902 .6392 Mdot
.33335 .38824 Mdot
.39609 .46275 Mdot
.5098 .58431 Mdot
.47059 .54509 Mdot
.47059 .54117 Mdot
.48628 .56862 Mdot
.50196 .58823 Mdot
.50196 .59215 Mdot
.49804 .58823 Mdot
.46667 .54509 Mdot
.46667 .53333 Mdot
.45883 .51765 Mdot
.46275 .51372 Mdot
.45098 .5098 Mdot
.45491 .51765 Mdot
.45883 .52549 Mdot
.47059 .52549 Mdot
.46667 .51765 Mdot
.47059 .52157 Mdot
.46667 .52157 Mdot
.46667 .52157 Mdot
.46667 .52549 Mdot
.48235 .55686 Mdot
.22747 .25492 Mdot
.07454 .08239 Mdot
.05102 .05494 Mdot
.00788 .00788 Mdot
.00396 .00788 Mdot
.00396 .00788 Mdot
.00396 .00788 Mdot
.00396 .00788 Mdot
.00396 .0118 Mdot
.0118 .02357 Mdot
.04317 .05102 Mdot
.06278 .07454 Mdot
.09415 .10983 Mdot
.1412 .16081 Mdot
.15297 .16865 Mdot
.90585 .91369 Mdot
.75292 .78037 Mdot
.6196 .65097 Mdot
.54117 .56862 Mdot
.46667 .48628 Mdot
.34119 .34119 Mdot
.32158 .31374 Mdot
.27453 .25884 Mdot
.22355 .21179 Mdot
.20002 .20002 Mdot
.16473 .16865 Mdot
.14905 .15297 Mdot
.15689 .15689 Mdot
.16473 .17257 Mdot
.16473 .17257 Mdot
.15689 .16473 Mdot
.13336 .13728 Mdot
.11768 .1216 Mdot
.10199 .09807 Mdot
.10199 .09807 Mdot
.07846 .08239 Mdot
.09023 .10199 Mdot
.11376 .13336 Mdot
.13728 .16473 Mdot
.14513 .17257 Mdot
.16865 .19218 Mdot
.17257 .1961 Mdot
.18042 .21179 Mdot
.16865 .19218 Mdot
.14513 .16081 Mdot
.1412 .14513 Mdot
.12552 .12944 Mdot
.11768 .11376 Mdot
.10199 .09807 Mdot
.31766 .36864 Mdot
.65489 .78037 Mdot
.46275 .55294 Mdot
.33335 .40001 Mdot
.33335 .38824 Mdot
.251 .27845 Mdot
.27453 .29806 Mdot
.53333 .60783 Mdot
.44314 .51372 Mdot
.45883 .54509 Mdot
.37648 .44314 Mdot
.35687 .41569 Mdot
.44706 .51765 Mdot
.49804 .57646 Mdot
.51372 .59607 Mdot
.52549 .60783 Mdot
.53333 .61176 Mdot
.55294 .64313 Mdot
.251 .27845 Mdot
.29806 .32943 Mdot
.64313 .74116 Mdot
.23924 .251 Mdot
.3608 .40393 Mdot
.59607 .68626 Mdot
.43922 .5098 Mdot
.42354 .50196 Mdot
.45098 .53725 Mdot
.47451 .54902 Mdot
.45883 .52157 Mdot
.44706 .50196 Mdot
.45491 .50588 Mdot
.44706 .49412 Mdot
.45491 .5098 Mdot
.45491 .51372 Mdot
.45491 .51765 Mdot
.45491 .5098 Mdot
.45491 .5098 Mdot
.4353 .48628 Mdot
.4353 .48235 Mdot
.43138 .48235 Mdot
.42354 .47843 Mdot
.20002 .21179 Mdot
.05886 .04709 Mdot
.02749 .0118 Mdot
.01965 .0118 Mdot
.0118 .00788 Mdot
.00788 .00788 Mdot
.00396 .00396 Mdot
.00396 .00788 Mdot
.00788 .01572 Mdot
.03533 .04317 Mdot
.10199 .10983 Mdot
.11768 .12944 Mdot
.13336 .15297 Mdot
.13728 .16473 Mdot
.1412 .16473 Mdot
.8588 .8784 Mdot
.75292 .77253 Mdot
.56862 .58431 Mdot
.51765 .53333 Mdot
.33335 .32943 Mdot
.27453 .27845 Mdot
.24708 .25884 Mdot
.21571 .23924 Mdot
.18826 .20394 Mdot
.18826 .19218 Mdot
.18434 .18042 Mdot
.17257 .1765 Mdot
.15689 .16081 Mdot
.13336 .13336 Mdot
.1216 .12552 Mdot
.10983 .11768 Mdot
.10199 .10591 Mdot
.09807 .10591 Mdot
.11376 .1216 Mdot
.13728 .14905 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.18826 .21179 Mdot
.18826 .20394 Mdot
.18826 .20394 Mdot
.18826 .20787 Mdot
.18042 .1961 Mdot
.1765 .19218 Mdot
.15297 .16081 Mdot
.10591 .10983 Mdot
.09807 .10199 Mdot
.08631 .09415 Mdot
.24316 .28629 Mdot
.33335 .39609 Mdot
.21963 .24708 Mdot
.22355 .24708 Mdot
.18042 .20002 Mdot
.17257 .19218 Mdot
.16865 .18826 Mdot
.14513 .16473 Mdot
.44706 .53725 Mdot
.39217 .46667 Mdot
.39217 .45883 Mdot
.43138 .49804 Mdot
.45883 .52549 Mdot
.46667 .54117 Mdot
.47451 .55294 Mdot
.48628 .5647 Mdot
.50196 .58823 Mdot
.41961 .48235 Mdot
.44706 .5098 Mdot
.58431 .67057 Mdot
.23531 .251 Mdot
.29021 .31766 Mdot
.62744 .72939 Mdot
.54509 .62744 Mdot
.40785 .46667 Mdot
.51765 .59607 Mdot
.46667 .52549 Mdot
.26668 .27453 Mdot
.34119 .36472 Mdot
.47843 .51765 Mdot
.44314 .48628 Mdot
.42354 .47451 Mdot
.4353 .49412 Mdot
.44314 .50588 Mdot
.44706 .50196 Mdot
.45883 .52157 Mdot
.4353 .50196 Mdot
.42746 .48628 Mdot
.39217 .43922 Mdot
.3059 .34511 Mdot
.18434 .20394 Mdot
.07454 .07062 Mdot
.05494 .04709 Mdot
.04317 .03141 Mdot
.02749 .01572 Mdot
.02749 .01965 Mdot
.0118 .00788 Mdot
.0118 .01572 Mdot
.03533 .04317 Mdot
.06278 .07454 Mdot
.13336 .14905 Mdot
.15689 .18042 Mdot
.16081 .18826 Mdot
.16473 .1961 Mdot
.16473 .20002 Mdot
.83527 .8588 Mdot
.58039 .6196 Mdot
.31766 .31374 Mdot
.34119 .34903 Mdot
.30982 .31766 Mdot
.28629 .29413 Mdot
.27453 .27453 Mdot
.251 .24708 Mdot
.22355 .21571 Mdot
.18826 .18042 Mdot
.15297 .15297 Mdot
.13728 .14513 Mdot
.12944 .13728 Mdot
.11768 .12944 Mdot
.11768 .12552 Mdot
.13336 .13728 Mdot
.15689 .17257 Mdot
.19218 .20787 Mdot
.21571 .22355 Mdot
.22355 .23139 Mdot
.21179 .21963 Mdot
.21571 .21963 Mdot
.20002 .20394 Mdot
.18434 .18826 Mdot
.17257 .1765 Mdot
.18434 .1961 Mdot
.15297 .16081 Mdot
.11768 .12552 Mdot
.10591 .11376 Mdot
.09023 .09415 Mdot
.09023 .09807 Mdot
.11376 .11768 Mdot
.10983 .10983 Mdot
.10591 .10983 Mdot
.12552 .13728 Mdot
.13336 .14905 Mdot
.10199 .11768 Mdot
.23139 .27453 Mdot
.3608 .42354 Mdot
.39609 .45883 Mdot
.52549 .61568 Mdot
.41961 .4902 Mdot
.33335 .38432 Mdot
.27453 .31374 Mdot
.33727 .38824 Mdot
.38824 .45883 Mdot
.44314 .52941 Mdot
.44706 .52941 Mdot
.47059 .55686 Mdot
.41569 .4902 Mdot
.41177 .48628 Mdot
.47843 .56862 Mdot
.58039 .68234 Mdot
.53725 .62744 Mdot
.53725 .61176 Mdot
.40001 .4353 Mdot
.15689 .13728 Mdot
.18042 .1765 Mdot
.56862 .65097 Mdot
.3255 .3608 Mdot
.25492 .27061 Mdot
.38824 .44314 Mdot
.45883 .53725 Mdot
.34119 .38824 Mdot
.31374 .34903 Mdot
.3804 .4353 Mdot
.40393 .46667 Mdot
.39217 .45491 Mdot
.29806 .35295 Mdot
.15297 .1765 Mdot
.09807 .10983 Mdot
.0667 .06278 Mdot
.03925 .03141 Mdot
.03141 .02357 Mdot
.02749 .01965 Mdot
.01965 .01572 Mdot
.0118 .00788 Mdot
.11376 .13728 Mdot
.16081 .18826 Mdot
.16865 .1961 Mdot
.17257 .20002 Mdot
.16865 .19218 Mdot
.15689 .17257 Mdot
.15297 .17257 Mdot
.87448 .8784 Mdot
.72939 .72547 Mdot
.5647 .57646 Mdot
.58039 .61176 Mdot
.49804 .51765 Mdot
.36472 .3608 Mdot
.26668 .251 Mdot
.23531 .23139 Mdot
.18042 .18434 Mdot
.16473 .18042 Mdot
.15689 .17257 Mdot
.15297 .16473 Mdot
.15689 .16081 Mdot
.16081 .15689 Mdot
.16865 .17257 Mdot
.20787 .21571 Mdot
.24316 .25492 Mdot
.25492 .26668 Mdot
.23924 .251 Mdot
.21571 .22747 Mdot
.18826 .20002 Mdot
.17257 .18042 Mdot
.15689 .16473 Mdot
.1412 .14905 Mdot
.14905 .16473 Mdot
.13336 .14905 Mdot
.1216 .13728 Mdot
.09807 .11376 Mdot
.11768 .12552 Mdot
.10199 .10591 Mdot
.08631 .08631 Mdot
.10591 .10983 Mdot
.1216 .12944 Mdot
.13336 .14513 Mdot
.1216 .13336 Mdot
.09415 .10983 Mdot
.1412 .16473 Mdot
.16865 .20002 Mdot
.26276 .31766 Mdot
.26668 .32158 Mdot
.26668 .31766 Mdot
.18826 .20787 Mdot
.1765 .20002 Mdot
.1765 .1961 Mdot
.27845 .32943 Mdot
.34119 .40785 Mdot
.39217 .46667 Mdot
.3255 .38824 Mdot
.29021 .34511 Mdot
.44314 .52941 Mdot
.45098 .53725 Mdot
.47059 .55686 Mdot
.48628 .56862 Mdot
.45098 .5098 Mdot
.18042 .1765 Mdot
.20394 .22355 Mdot
.45883 .54509 Mdot
.48628 .57646 Mdot
.25884 .29806 Mdot
.41569 .47843 Mdot
.44706 .51765 Mdot
.24708 .27453 Mdot
.08631 .07454 Mdot
.19218 .20394 Mdot
.43138 .49804 Mdot
.3059 .35295 Mdot
.20787 .24316 Mdot
.18826 .22355 Mdot
.10983 .12552 Mdot
.09415 .10983 Mdot
.05102 .05886 Mdot
.02749 .03533 Mdot
.02749 .03533 Mdot
.01965 .03141 Mdot
.02357 .03141 Mdot
.16473 .20787 Mdot
.251 .31374 Mdot
.24708 .29806 Mdot
.1961 .23531 Mdot
.17257 .20787 Mdot
.15689 .18042 Mdot
.14905 .16081 Mdot
.93722 .94898 Mdot
.78429 .81958 Mdot
.60783 .63528 Mdot
.27061 .24708 Mdot
.30982 .30982 Mdot
.25884 .26668 Mdot
.23924 .251 Mdot
.22747 .24708 Mdot
.23139 .251 Mdot
.23531 .24316 Mdot
.23531 .24316 Mdot
.22355 .22747 Mdot
.23531 .251 Mdot
.28629 .30982 Mdot
.30198 .32943 Mdot
.23924 .25884 Mdot
.22747 .24316 Mdot
.21571 .23531 Mdot
.18042 .1961 Mdot
.16473 .1765 Mdot
.15689 .16865 Mdot
.16473 .18042 Mdot
.16081 .1765 Mdot
.14513 .16081 Mdot
.13336 .15297 Mdot
.1412 .15297 Mdot
.1216 .12944 Mdot
.09415 .09415 Mdot
.12944 .1412 Mdot
.1412 .15689 Mdot
.15297 .16473 Mdot
.13336 .1412 Mdot
.11768 .12944 Mdot
.10199 .11376 Mdot
.09415 .10591 Mdot
.12944 .15297 Mdot
.15297 .16865 Mdot
.15689 .16473 Mdot
.14905 .16081 Mdot
.1412 .15297 Mdot
.13336 .14905 Mdot
.14513 .16081 Mdot
.16081 .18826 Mdot
.41177 .49804 Mdot
.29806 .35295 Mdot
.20787 .23139 Mdot
.16473 .18042 Mdot
.31374 .35687 Mdot
.3255 .36864 Mdot
.3608 .41177 Mdot
.45883 .52941 Mdot
.47451 .56078 Mdot
.34903 .41177 Mdot
.36864 .44314 Mdot
.41177 .48628 Mdot
.42746 .50588 Mdot
.43922 .5098 Mdot
.43138 .49804 Mdot
.31766 .35295 Mdot
.17257 .1765 Mdot
.30982 .33727 Mdot
.34119 .37648 Mdot
.34511 .38824 Mdot
.25492 .28629 Mdot
.10591 .1216 Mdot
.10983 .12944 Mdot
.08239 .10199 Mdot
.05494 .0667 Mdot
.03925 .04709 Mdot
.02749 .03533 Mdot
.03533 .04709 Mdot
.05494 .07062 Mdot
.07454 .09807 Mdot
.251 .31374 Mdot
.28629 .35687 Mdot
.23531 .28237 Mdot
.20787 .251 Mdot
.16865 .20002 Mdot
.13336 .16081 Mdot
.8039 .81566 Mdot
.59999 .60391 Mdot
.54902 .57646 Mdot
.47059 .4902 Mdot
.41177 .4353 Mdot
.39609 .41177 Mdot
.37256 .38432 Mdot
.35295 .36472 Mdot
.3059 .31766 Mdot
.27845 .30198 Mdot
.27453 .28237 Mdot
.26668 .27845 Mdot
.251 .26276 Mdot
.23531 .23924 Mdot
.21963 .22355 Mdot
.21179 .21963 Mdot
.20787 .21963 Mdot
.21179 .21963 Mdot
.19218 .20394 Mdot
.18042 .1961 Mdot
.18434 .20002 Mdot
.1765 .1961 Mdot
.16865 .18826 Mdot
.13336 .14513 Mdot
.10591 .10591 Mdot
.10983 .10983 Mdot
.12552 .13336 Mdot
.13728 .14905 Mdot
.12552 .13336 Mdot
.10983 .11768 Mdot
.08631 .09415 Mdot
.12944 .13728 Mdot
.18826 .20787 Mdot
.18042 .1961 Mdot
.16081 .1765 Mdot
.12552 .12552 Mdot
.11768 .11768 Mdot
.10983 .11768 Mdot
.11768 .1412 Mdot
.10983 .12944 Mdot
.15689 .18434 Mdot
.1961 .23139 Mdot
.20787 .23924 Mdot
.18826 .21179 Mdot
.15689 .1765 Mdot
.13728 .14513 Mdot
.13336 .1412 Mdot
.18826 .20394 Mdot
.38432 .44706 Mdot
.27453 .31766 Mdot
.24316 .28237 Mdot
.28237 .32158 Mdot
.36472 .42354 Mdot
.40001 .47059 Mdot
.41177 .48628 Mdot
.41569 .48628 Mdot
.38824 .44314 Mdot
.41569 .47059 Mdot
.33335 .3608 Mdot
.27453 .30198 Mdot
.30982 .3608 Mdot
.10591 .12552 Mdot
.09415 .11376 Mdot
.05494 .07062 Mdot
.04317 .05494 Mdot
.03533 .04317 Mdot
.03925 .03925 Mdot
.07062 .07454 Mdot
.0667 .07062 Mdot
.05494 .05886 Mdot
.07846 .09023 Mdot
.09415 .11376 Mdot
.1216 .14513 Mdot
.21571 .25884 Mdot
.20002 .23924 Mdot
.15689 .18434 Mdot
.81958 .83919 Mdot
.65097 .69018 Mdot
.53333 .55686 Mdot
.4902 .5098 Mdot
.39609 .40785 Mdot
.34511 .35687 Mdot
.3255 .33335 Mdot
.29413 .29413 Mdot
.28237 .28237 Mdot
.25884 .25884 Mdot
.251 .251 Mdot
.23924 .23531 Mdot
.30198 .31766 Mdot
.30198 .3255 Mdot
.28237 .3059 Mdot
.25492 .27061 Mdot
.21571 .22747 Mdot
.1961 .21179 Mdot
.1765 .19218 Mdot
.17257 .18826 Mdot
.15297 .16473 Mdot
.12552 .13728 Mdot
.10983 .11376 Mdot
.12944 .1412 Mdot
.1412 .15689 Mdot
.13728 .14905 Mdot
.11768 .12944 Mdot
.10199 .10591 Mdot
.14905 .15689 Mdot
.16865 .18042 Mdot
.16865 .18434 Mdot
.16473 .17257 Mdot
.15297 .15689 Mdot
.12944 .13336 Mdot
.12552 .13336 Mdot
.10591 .11768 Mdot
.10591 .11376 Mdot
.07846 .07846 Mdot
.09415 .09415 Mdot
.10983 .11768 Mdot
.13728 .14513 Mdot
.12552 .13336 Mdot
.09807 .10199 Mdot
.08631 .09415 Mdot
.08239 .08239 Mdot
.22355 .25492 Mdot
.3255 .3804 Mdot
.12552 .1412 Mdot
.14513 .17257 Mdot
.14513 .16865 Mdot
.18434 .22355 Mdot
.32158 .38432 Mdot
.3804 .45098 Mdot
.39217 .45883 Mdot
.38824 .44706 Mdot
.37256 .43922 Mdot
.20394 .24316 Mdot
.22355 .27453 Mdot
.21571 .26668 Mdot
.10199 .12552 Mdot
.0667 .08239 Mdot
.07062 .08631 Mdot
.07062 .07454 Mdot
.07062 .06278 Mdot
.07062 .06278 Mdot
.0667 .05494 Mdot
.05102 .03925 Mdot
.04709 .03533 Mdot
.04317 .03533 Mdot
.04317 .03533 Mdot
.09023 .09023 Mdot
.11376 .11768 Mdot
.14905 .16473 Mdot
.91761 .92938 Mdot
.80782 .83135 Mdot
.58431 .62744 Mdot
.45098 .46667 Mdot
.4353 .45098 Mdot
.38824 .38824 Mdot
.34119 .33335 Mdot
.3059 .30198 Mdot
.29021 .29021 Mdot
.25884 .25884 Mdot
.35295 .39217 Mdot
.40785 .47059 Mdot
.41177 .47843 Mdot
.39217 .44706 Mdot
.20002 .20787 Mdot
.17257 .17257 Mdot
.15297 .14905 Mdot
.13336 .13336 Mdot
.13728 .13728 Mdot
.13728 .13728 Mdot
.13336 .13728 Mdot
.14905 .15689 Mdot
.14905 .16081 Mdot
.13336 .15297 Mdot
.11768 .13336 Mdot
.12552 .13728 Mdot
.21571 .24708 Mdot
.21963 .24708 Mdot
.18434 .20002 Mdot
.17257 .18042 Mdot
.15297 .16081 Mdot
.15689 .15689 Mdot
.16473 .1765 Mdot
.14513 .15297 Mdot
.10591 .10983 Mdot
.08239 .08239 Mdot
.0667 .06278 Mdot
.10199 .10591 Mdot
.12552 .12552 Mdot
.10199 .09807 Mdot
.07062 .06278 Mdot
.05494 .05102 Mdot
.05102 .04709 Mdot
.10199 .10983 Mdot
.33335 .39217 Mdot
.16081 .18826 Mdot
.15689 .18826 Mdot
.1216 .14513 Mdot
.10199 .12552 Mdot
.09023 .10591 Mdot
.17257 .21571 Mdot
.21179 .25492 Mdot
.1765 .20002 Mdot
.21179 .24316 Mdot
.251 .29806 Mdot
.31374 .37648 Mdot
.27845 .32943 Mdot
.05102 .05494 Mdot
.08631 .09415 Mdot
.10591 .11768 Mdot
.09415 .10591 Mdot
.10591 .10983 Mdot
.09023 .08631 Mdot
.0667 .05494 Mdot
.04317 .02357 Mdot
.04709 .02749 Mdot
.04317 .01965 Mdot
.05102 .02357 Mdot
.05102 .03141 Mdot
.05494 .03925 Mdot
.10591 .10983 Mdot
.91761 .92546 Mdot
.70979 .73332 Mdot
.62352 .65489 Mdot
.42354 .41961 Mdot
.37256 .37256 Mdot
.34511 .34511 Mdot
.3255 .32943 Mdot
.27061 .27453 Mdot
.27453 .29413 Mdot
.32158 .3608 Mdot
.27061 .3059 Mdot
.20394 .22355 Mdot
.18042 .20394 Mdot
.16473 .18042 Mdot
.13728 .1412 Mdot
.12944 .13336 Mdot
.13728 .13728 Mdot
.16473 .1765 Mdot
.16865 .18826 Mdot
.16865 .18826 Mdot
.16865 .18826 Mdot
.13728 .15297 Mdot
.14513 .16081 Mdot
.29413 .34119 Mdot
.25884 .3059 Mdot
.21179 .251 Mdot
.1961 .22747 Mdot
.19218 .21571 Mdot
.18434 .20394 Mdot
.18434 .20394 Mdot
.1412 .14905 Mdot
.10199 .10199 Mdot
.0667 .05886 Mdot
.07062 .07062 Mdot
.09807 .10199 Mdot
.11768 .1216 Mdot
.11376 .1216 Mdot
.08631 .09023 Mdot
.0667 .06278 Mdot
.04709 .04317 Mdot
.04317 .03925 Mdot
.09023 .09415 Mdot
.09807 .10983 Mdot
.09415 .10591 Mdot
.07846 .09415 Mdot
.07454 .09415 Mdot
.07846 .10199 Mdot
.10983 .13728 Mdot
.10983 .13728 Mdot
.10199 .12944 Mdot
.09807 .11768 Mdot
.08631 .10199 Mdot
.14513 .16081 Mdot
.16081 .1765 Mdot
.11768 .12552 Mdot
.1412 .15689 Mdot
.13336 .14905 Mdot
.12944 .1412 Mdot
.21179 .23531 Mdot
.16865 .18434 Mdot
.14905 .15689 Mdot
.12552 .1216 Mdot
.12552 .10983 Mdot
.10983 .09023 Mdot
.09415 .07062 Mdot
.07454 .04709 Mdot
.06278 .03925 Mdot
.07454 .05886 Mdot
.83527 .85487 Mdot
.63528 .64705 Mdot
.40393 .40393 Mdot
.40393 .41177 Mdot
.32158 .32158 Mdot
.30198 .3059 Mdot
.28237 .28629 Mdot
.24708 .25884 Mdot
.21963 .23924 Mdot
.18434 .1961 Mdot
.16081 .16865 Mdot
.15297 .16081 Mdot
.13336 .1412 Mdot
.15297 .16865 Mdot
.1765 .1961 Mdot
.19218 .21571 Mdot
.18434 .20394 Mdot
.18042 .1961 Mdot
.1765 .18042 Mdot
.1765 .1765 Mdot
.20394 .21571 Mdot
.20394 .22355 Mdot
.20002 .22355 Mdot
.1961 .22355 Mdot
.19218 .22355 Mdot
.20002 .23531 Mdot
.18434 .21571 Mdot
.14513 .16865 Mdot
.13336 .1412 Mdot
.10983 .10983 Mdot
.09807 .10199 Mdot
.10983 .1216 Mdot
.1216 .1412 Mdot
.10591 .1216 Mdot
.09023 .10983 Mdot
.06278 .07454 Mdot
.0667 .08239 Mdot
.05886 .0667 Mdot
.07454 .07846 Mdot
.09023 .10199 Mdot
.09807 .11376 Mdot
.08239 .09807 Mdot
.0667 .08239 Mdot
.07062 .08631 Mdot
.09023 .11376 Mdot
.09023 .10983 Mdot
.08239 .10199 Mdot
.08631 .09807 Mdot
.08631 .09807 Mdot
.07454 .08239 Mdot
.09807 .10591 Mdot
.09807 .11376 Mdot
.10983 .12944 Mdot
.09807 .11376 Mdot
.10199 .11376 Mdot
.14513 .16865 Mdot
.20394 .23139 Mdot
.20394 .23139 Mdot
.16081 .17257 Mdot
.20394 .20787 Mdot
.23139 .22747 Mdot
.18434 .16865 Mdot
.17257 .16081 Mdot
.15297 .14513 Mdot
.11768 .11376 Mdot
.79998 .81958 Mdot
.51372 .54117 Mdot
.41569 .42746 Mdot
.3804 .38824 Mdot
.31374 .31766 Mdot
.28629 .29021 Mdot
.22355 .22355 Mdot
.20394 .20002 Mdot
.18826 .18042 Mdot
.16473 .16865 Mdot
.16081 .16081 Mdot
.16473 .1765 Mdot
.18434 .20002 Mdot
.18826 .20394 Mdot
.18434 .20002 Mdot
.19218 .20394 Mdot
.1961 .20394 Mdot
.16865 .16865 Mdot
.16081 .16081 Mdot
.14513 .15689 Mdot
.15297 .16473 Mdot
.1765 .19218 Mdot
.19218 .21963 Mdot
.17257 .19218 Mdot
.16865 .18826 Mdot
.16081 .18042 Mdot
.13728 .14905 Mdot
.15297 .17257 Mdot
.17257 .20394 Mdot
.13728 .16865 Mdot
.10983 .13336 Mdot
.08239 .09807 Mdot
.0667 .07846 Mdot
.05102 .06278 Mdot
.04709 .05886 Mdot
.07846 .09415 Mdot
.08631 .10591 Mdot
.10199 .1216 Mdot
.08631 .10591 Mdot
.07062 .08631 Mdot
.0667 .08631 Mdot
.08631 .10983 Mdot
.08239 .09807 Mdot
.07062 .08631 Mdot
.06278 .07454 Mdot
.05494 .07062 Mdot
.05494 .07062 Mdot
.05102 .06278 Mdot
.06278 .07454 Mdot
.08239 .08631 Mdot
.07454 .07846 Mdot
.10983 .12552 Mdot
.13336 .15297 Mdot
.15689 .18042 Mdot
.17257 .18826 Mdot
.11376 .11376 Mdot
.21179 .21571 Mdot
.12944 .10591 Mdot
.20787 .1961 Mdot
.16081 .14513 Mdot
.18434 .20002 Mdot
.1961 .22747 Mdot
.91761 .9333 Mdot
.74116 .749 Mdot
.49804 .52549 Mdot
.41569 .42746 Mdot
.29021 .27845 Mdot
.29021 .28237 Mdot
.23139 .21571 Mdot
.20787 .19218 Mdot
.20002 .18434 Mdot
.19218 .1765 Mdot
.18434 .16865 Mdot
.18826 .18042 Mdot
.1765 .16865 Mdot
.17257 .16865 Mdot
.18434 .18826 Mdot
.17257 .1765 Mdot
.15297 .15689 Mdot
.14513 .14905 Mdot
.13336 .14513 Mdot
.13728 .14905 Mdot
.13336 .14513 Mdot
.1412 .14905 Mdot
.1412 .16473 Mdot
.15689 .18434 Mdot
.14513 .17257 Mdot
.15297 .18826 Mdot
.21963 .27061 Mdot
.14513 .18042 Mdot
.10591 .13336 Mdot
.07454 .09023 Mdot
.0667 .07062 Mdot
.06278 .07062 Mdot
.06278 .07454 Mdot
.07846 .09023 Mdot
.10199 .11768 Mdot
.10591 .1216 Mdot
.10199 .12552 Mdot
.09415 .11768 Mdot
.09807 .12552 Mdot
.11376 .1412 Mdot
.09807 .1216 Mdot
.09415 .11376 Mdot
.0667 .08631 Mdot
.05886 .07454 Mdot
.05886 .08239 Mdot
.05102 .07062 Mdot
.03141 .04317 Mdot
.04317 .05102 Mdot
.04317 .04709 Mdot
.05102 .05102 Mdot
.05886 .05886 Mdot
.08239 .08239 Mdot
.11376 .11768 Mdot
.10199 .09415 Mdot
.29806 .3255 Mdot
.0667 .05102 Mdot
.40393 .44314 Mdot
.36472 .41569 Mdot
.06278 .07062 Mdot
.11768 .1412 Mdot
.90585 .91761 Mdot
.61568 .62744 Mdot
.48235 .50588 Mdot
.34119 .34511 Mdot
.32158 .32158 Mdot
.29413 .28629 Mdot
.26668 .24708 Mdot
.24708 .22355 Mdot
.24708 .22747 Mdot
.18042 .16081 Mdot
.18042 .16473 Mdot
.1765 .15689 Mdot
.16865 .15297 Mdot
.14905 .13728 Mdot
.14905 .14513 Mdot
.15689 .17257 Mdot
.14513 .16865 Mdot
.12552 .14905 Mdot
.1216 .14905 Mdot
.13728 .16473 Mdot
.12944 .16081 Mdot
.13336 .16865 Mdot
.1412 .18042 Mdot
.13728 .18434 Mdot
.1412 .18042 Mdot
.11768 .14513 Mdot
.09415 .1216 Mdot
.09023 .10983 Mdot
.08239 .09807 Mdot
.08239 .09415 Mdot
.09807 .10983 Mdot
.09415 .10983 Mdot
.10591 .1216 Mdot
.10983 .12944 Mdot
.09807 .1216 Mdot
.10591 .12944 Mdot
.11376 .1412 Mdot
.11376 .13728 Mdot
.10983 .13728 Mdot
.07062 .10591 Mdot
.05102 .07454 Mdot
.05886 .08239 Mdot
.04709 .07062 Mdot
.03925 .05494 Mdot
.03533 .04709 Mdot
.03533 .03925 Mdot
.03141 .03141 Mdot
.03925 .03141 Mdot
.03533 .02749 Mdot
.03925 .03925 Mdot
.03533 .04317 Mdot
.05102 .06278 Mdot
.08631 .10199 Mdot
.10591 .12552 Mdot
.13728 .16081 Mdot
.12944 .15297 Mdot
.09807 .10983 Mdot
.76861 .78429 Mdot
.59607 .60391 Mdot
.41569 .41961 Mdot
.34119 .33335 Mdot
.32158 .30982 Mdot
.29413 .28237 Mdot
.26668 .25884 Mdot
.23139 .22355 Mdot
.20002 .1961 Mdot
.16473 .15689 Mdot
.1412 .13336 Mdot
.13728 .13728 Mdot
.12944 .13728 Mdot
.13336 .15297 Mdot
.12944 .15689 Mdot
.11376 .1412 Mdot
.09807 .1216 Mdot
.09807 .1216 Mdot
.12944 .16081 Mdot
.10199 .12944 Mdot
.10983 .13336 Mdot
.1216 .15297 Mdot
.1216 .14513 Mdot
.1216 .1412 Mdot
.11768 .13728 Mdot
.10983 .13336 Mdot
.10199 .12552 Mdot
.09807 .11768 Mdot
.08631 .09807 Mdot
.09807 .10983 Mdot
.10591 .1216 Mdot
.11376 .13728 Mdot
.1216 .14905 Mdot
.11768 .14905 Mdot
.10983 .14905 Mdot
.10199 .14513 Mdot
.09415 .13336 Mdot
.08239 .1216 Mdot
.0667 .10199 Mdot
.05886 .08239 Mdot
.05102 .07454 Mdot
.04709 .06278 Mdot
.05102 .06278 Mdot
.04709 .05102 Mdot
.04317 .03925 Mdot
.03141 .03141 Mdot
.02749 .03533 Mdot
.02749 .03925 Mdot
.02749 .03925 Mdot
.04709 .05886 Mdot
.0667 .07846 Mdot
.09415 .10591 Mdot
.07062 .07454 Mdot
.05102 .05102 Mdot
.73724 .74508 Mdot
.42354 .42746 Mdot
.35687 .36472 Mdot
.31766 .32943 Mdot
.29021 .29413 Mdot
.24316 .24708 Mdot
.21571 .21571 Mdot
.20787 .20787 Mdot
.1961 .19218 Mdot
.17257 .17257 Mdot
.14905 .15689 Mdot
.13728 .14905 Mdot
.1216 .13728 Mdot
.10983 .12944 Mdot
.09807 .11768 Mdot
.11376 .13728 Mdot
.10199 .12552 Mdot
.10199 .12552 Mdot
.12552 .14905 Mdot
.13728 .16473 Mdot
.13336 .15689 Mdot
.12552 .15297 Mdot
.12552 .15297 Mdot
.13336 .16081 Mdot
.1216 .14905 Mdot
.10983 .13728 Mdot
.1216 .15297 Mdot
.13336 .16865 Mdot
.13728 .17257 Mdot
.15297 .18826 Mdot
.12944 .16865 Mdot
.13336 .17257 Mdot
.1216 .16081 Mdot
.1216 .15297 Mdot
.10983 .13728 Mdot
.10983 .13728 Mdot
.10591 .13336 Mdot
.08631 .10983 Mdot
.09415 .10983 Mdot
.07846 .08631 Mdot
.07454 .07454 Mdot
.07846 .08631 Mdot
.0667 .07062 Mdot
.05102 .05886 Mdot
.04709 .05886 Mdot
.04709 .0667 Mdot
.04709 .06278 Mdot
.04709 .06278 Mdot
.07062 .08239 Mdot
.06278 .0667 Mdot
.04709 .03925 Mdot
.87056 .87448 Mdot
.71763 .72939 Mdot
.40001 .40393 Mdot
.30982 .3059 Mdot
.28237 .28629 Mdot
.25884 .26668 Mdot
.23139 .23531 Mdot
.1961 .19218 Mdot
.16865 .16081 Mdot
.14513 .13728 Mdot
.12944 .12552 Mdot
.10983 .11376 Mdot
.11768 .12944 Mdot
.10983 .12944 Mdot
.09023 .10199 Mdot
.07454 .08239 Mdot
.07062 .08631 Mdot
.07846 .09415 Mdot
.08631 .10591 Mdot
.08239 .10591 Mdot
.09023 .10983 Mdot
.09807 .11768 Mdot
.09807 .1216 Mdot
.10591 .13336 Mdot
.09415 .12552 Mdot
.09023 .11768 Mdot
.10199 .12944 Mdot
.10983 .1412 Mdot
.10591 .13728 Mdot
.10591 .13336 Mdot
.09807 .1216 Mdot
.09807 .12552 Mdot
.09807 .12552 Mdot
.09415 .11768 Mdot
.09023 .11768 Mdot
.10199 .12944 Mdot
.10199 .1216 Mdot
.09807 .10591 Mdot
.08631 .08631 Mdot
.08239 .08631 Mdot
.06278 .07062 Mdot
.05494 .06278 Mdot
.04317 .05494 Mdot
.04709 .05886 Mdot
.05102 .0667 Mdot
.04709 .06278 Mdot
.05102 .05886 Mdot
.05494 .05494 Mdot
.04317 .03925 Mdot
.8784 .88232 Mdot
.59607 .61176 Mdot
.44314 .47451 Mdot
.24316 .23531 Mdot
.23531 .22355 Mdot
.1961 .17257 Mdot
.15297 .1216 Mdot
.12944 .10591 Mdot
.1216 .10591 Mdot
.12552 .12552 Mdot
.12552 .12552 Mdot
.11376 .11768 Mdot
.07846 .08239 Mdot
.05886 .0667 Mdot
.05886 .0667 Mdot
.05102 .05886 Mdot
.04317 .05102 Mdot
.06278 .07846 Mdot
.06278 .08239 Mdot
.05102 .07454 Mdot
.05494 .08239 Mdot
.05494 .07846 Mdot
.07062 .10199 Mdot
.07846 .10591 Mdot
.08239 .11768 Mdot
.07454 .10199 Mdot
.07062 .09807 Mdot
.09023 .11768 Mdot
.10199 .12552 Mdot
.08631 .10199 Mdot
.07454 .08631 Mdot
.06278 .07454 Mdot
.07062 .08239 Mdot
.07454 .07846 Mdot
.07062 .07846 Mdot
.0667 .07062 Mdot
.0667 .07846 Mdot
.05102 .05886 Mdot
.03925 .04709 Mdot
.02749 .03141 Mdot
.04317 .05102 Mdot
.05494 .0667 Mdot
.04709 .05494 Mdot
.04709 .05886 Mdot
.05494 .06278 Mdot
.04709 .04317 Mdot
.69018 .69018 Mdot
.45098 .42746 Mdot
.28629 .25884 Mdot
.18434 .15297 Mdot
.15689 .12552 Mdot
.13336 .10591 Mdot
.12552 .10199 Mdot
.10983 .09023 Mdot
.09023 .07846 Mdot
.09023 .07846 Mdot
.07846 .08239 Mdot
.06278 .07454 Mdot
.05886 .07454 Mdot
.0667 .08239 Mdot
.0667 .08631 Mdot
.06278 .08239 Mdot
.05102 .07454 Mdot
.03925 .06278 Mdot
.02749 .05102 Mdot
.0667 .10199 Mdot
.09023 .12944 Mdot
.07454 .11376 Mdot
.08239 .11376 Mdot
.07846 .11376 Mdot
.08631 .1216 Mdot
.09415 .1216 Mdot
.07846 .09415 Mdot
.08239 .09023 Mdot
.07062 .07454 Mdot
.07454 .08239 Mdot
.06278 .05886 Mdot
.06278 .06278 Mdot
.07454 .07454 Mdot
.07454 .07846 Mdot
.06278 .07062 Mdot
.04709 .05886 Mdot
.04317 .05494 Mdot
.03925 .05494 Mdot
.0667 .08239 Mdot
.04709 .05494 Mdot
.04709 .05494 Mdot
.05886 .06278 Mdot
.05886 .05886 Mdot
.57646 .55686 Mdot
.21179 .19218 Mdot
.21179 .19218 Mdot
.17257 .1412 Mdot
.13728 .10199 Mdot
.11768 .09023 Mdot
.11376 .09807 Mdot
.09807 .09023 Mdot
.09415 .09807 Mdot
.09415 .09807 Mdot
.08631 .09807 Mdot
.0667 .07846 Mdot
.07846 .09415 Mdot
.05494 .06278 Mdot
.04317 .05102 Mdot
.04317 .05102 Mdot
.05102 .0667 Mdot
.07454 .09807 Mdot
.07846 .10591 Mdot
.08239 .11768 Mdot
.0667 .10591 Mdot
.06278 .09807 Mdot
.07454 .10199 Mdot
.08631 .11768 Mdot
.08239 .10591 Mdot
.08631 .10983 Mdot
.09415 .10199 Mdot
.08631 .08631 Mdot
.07846 .07846 Mdot
.07454 .07454 Mdot
.07454 .07454 Mdot
.07846 .08239 Mdot
.05886 .07062 Mdot
.05494 .0667 Mdot
.05494 .06278 Mdot
.05886 .07062 Mdot
.0667 .07454 Mdot
.07062 .07454 Mdot
.07062 .07454 Mdot
.0667 .07062 Mdot
.81174 .8039 Mdot
.60783 .58823 Mdot
.19218 .15297 Mdot
.16473 .12552 Mdot
.1412 .10591 Mdot
.11768 .09023 Mdot
.10983 .08631 Mdot
.10983 .09415 Mdot
.10591 .09415 Mdot
.09415 .07846 Mdot
.07846 .06278 Mdot
.08239 .07062 Mdot
.07454 .06278 Mdot
.05102 .03925 Mdot
.07062 .07454 Mdot
.09415 .10983 Mdot
.09807 .11768 Mdot
.08631 .10983 Mdot
.08631 .11768 Mdot
.08239 .10983 Mdot
.09023 .11768 Mdot
.08239 .10983 Mdot
.08239 .10591 Mdot
.08239 .10591 Mdot
.08239 .10199 Mdot
.07846 .09807 Mdot
.07846 .08631 Mdot
.07062 .07846 Mdot
.0667 .07454 Mdot
.07454 .08631 Mdot
.07846 .09023 Mdot
.05886 .07454 Mdot
.04317 .05102 Mdot
.04709 .04709 Mdot
.05886 .05886 Mdot
.05494 .05102 Mdot
.05102 .05102 Mdot
.05494 .05494 Mdot
.59215 .57254 Mdot
.37256 .34511 Mdot
.14513 .10983 Mdot
.1412 .11376 Mdot
.12552 .10591 Mdot
.11376 .09415 Mdot
.10199 .07846 Mdot
.09415 .07062 Mdot
.09023 .07846 Mdot
.08631 .07846 Mdot
.06278 .05886 Mdot
.05494 .05886 Mdot
.07454 .08631 Mdot
.09023 .10983 Mdot
.10199 .12944 Mdot
.10983 .1412 Mdot
.10983 .14513 Mdot
.10983 .13728 Mdot
.09023 .11768 Mdot
.08631 .10591 Mdot
.08239 .10591 Mdot
.08239 .10591 Mdot
.07846 .09807 Mdot
.0667 .08239 Mdot
.05494 .0667 Mdot
.06278 .07846 Mdot
.07062 .08631 Mdot
.0667 .08631 Mdot
.06278 .07846 Mdot
.05886 .07454 Mdot
.06278 .0667 Mdot
.05494 .06278 Mdot
.05494 .05494 Mdot
.07062 .07846 Mdot
.06278 .07846 Mdot
.58431 .56862 Mdot
.35687 .33335 Mdot
.1216 .09807 Mdot
.13336 .11376 Mdot
.13728 .1216 Mdot
.10591 .09807 Mdot
.08239 .08239 Mdot
.06278 .07062 Mdot
.04709 .05494 Mdot
.05494 .0667 Mdot
.07062 .08631 Mdot
.09023 .11376 Mdot
.10199 .12944 Mdot
.11768 .1412 Mdot
.10983 .12944 Mdot
.09023 .10983 Mdot
.09023 .10983 Mdot
.08239 .10591 Mdot
.06278 .08239 Mdot
.05886 .07062 Mdot
.06278 .07846 Mdot
.0667 .08239 Mdot
.07846 .09415 Mdot
.0667 .08631 Mdot
.05494 .07454 Mdot
.05494 .07062 Mdot
.05494 .0667 Mdot
.05886 .07062 Mdot
.05886 .07454 Mdot
.0667 .07846 Mdot
.05494 .05886 Mdot
.03141 .03533 Mdot
.77645 .77253 Mdot
.62352 .63528 Mdot
.15689 .16473 Mdot
.1216 .12944 Mdot
.10199 .11376 Mdot
.07846 .09023 Mdot
.06278 .07062 Mdot
.05494 .07062 Mdot
.0667 .08239 Mdot
.08239 .09807 Mdot
.10199 .1216 Mdot
.1216 .13728 Mdot
.10983 .11768 Mdot
.09807 .09807 Mdot
.09807 .10199 Mdot
.10199 .11376 Mdot
.07846 .09023 Mdot
.07846 .09023 Mdot
.07846 .09023 Mdot
.08239 .10199 Mdot
.08239 .09807 Mdot
.08631 .10199 Mdot
.07062 .08239 Mdot
.05886 .0667 Mdot
.05886 .07062 Mdot
.05886 .07454 Mdot
.07062 .08631 Mdot
.05494 .0667 Mdot
.03141 .04317 Mdot
.02357 .02749 Mdot
.78037 .78429 Mdot
.56078 .5647 Mdot
.11768 .12944 Mdot
.13336 .15297 Mdot
.10591 .1216 Mdot
.10199 .10591 Mdot
.09023 .09415 Mdot
.10199 .10591 Mdot
.11376 .10983 Mdot
.11768 .10983 Mdot
.11376 .10591 Mdot
.12552 .12552 Mdot
.1216 .12552 Mdot
.10983 .11768 Mdot
.10591 .10983 Mdot
.09807 .10983 Mdot
.07454 .08631 Mdot
.09415 .10983 Mdot
.09023 .10591 Mdot
.07846 .09415 Mdot
.06278 .07454 Mdot
.04709 .05886 Mdot
.0667 .07846 Mdot
.07062 .09023 Mdot
.05494 .0667 Mdot
.03141 .03925 Mdot
.00788 .0118 Mdot
.59215 .60391 Mdot
.34903 .35687 Mdot
.12944 .13728 Mdot
.1216 .12944 Mdot
.10983 .10591 Mdot
.10983 .09415 Mdot
.11768 .10199 Mdot
.12552 .11768 Mdot
.12552 .12552 Mdot
.12552 .13336 Mdot
.11376 .12552 Mdot
.11376 .12552 Mdot
.10591 .1216 Mdot
.09415 .10591 Mdot
.09807 .11768 Mdot
.09807 .1216 Mdot
.08239 .09807 Mdot
.07846 .09415 Mdot
.06278 .07846 Mdot
.04709 .05886 Mdot
.04709 .05886 Mdot
.03925 .04709 Mdot
.02357 .02749 Mdot
.00788 .0118 Mdot
.57254 .57646 Mdot
.34903 .34511 Mdot
.10591 .08631 Mdot
.11376 .09807 Mdot
.12552 .12552 Mdot
.13728 .1412 Mdot
.13336 .15297 Mdot
.1216 .14513 Mdot
.11768 .1412 Mdot
.09807 .1216 Mdot
.09415 .11376 Mdot
.09807 .11768 Mdot
.10199 .1216 Mdot
.09807 .1216 Mdot
.07454 .09415 Mdot
.05494 .06278 Mdot
.03141 .03925 Mdot
.03141 .03925 Mdot
.02357 .02357 Mdot
.01965 .0118 Mdot
.01572 .0118 Mdot
.77253 .76861 Mdot
.54117 .53333 Mdot
.08239 .07454 Mdot
.08239 .07846 Mdot
.09807 .10199 Mdot
.09415 .10983 Mdot
.07846 .09023 Mdot
.08239 .09807 Mdot
.08239 .09023 Mdot
.09023 .09807 Mdot
.08239 .09023 Mdot
.07454 .08631 Mdot
.05494 .06278 Mdot
.03141 .02749 Mdot
.04317 .03925 Mdot
.05494 .05102 Mdot
.03533 .02749 Mdot
.03141 .01965 Mdot
.03141 .01965 Mdot
.76469 .76469 Mdot
.53333 .52941 Mdot
.08239 .07846 Mdot
.09807 .09023 Mdot
.08631 .08239 Mdot
.07846 .07846 Mdot
.08239 .08631 Mdot
.08631 .09023 Mdot
.07454 .07454 Mdot
.04709 .04709 Mdot
.04317 .03925 Mdot
.04709 .04317 Mdot
.05886 .05494 Mdot
.04709 .03925 Mdot
.03533 .02749 Mdot
.03533 .02749 Mdot
.58039 .58431 Mdot
.34903 .34511 Mdot
.11768 .11768 Mdot
.08631 .08631 Mdot
.08239 .07846 Mdot
.08239 .07846 Mdot
.07454 .07062 Mdot
.05494 .05494 Mdot
.05494 .05886 Mdot
.05886 .0667 Mdot
.05886 .0667 Mdot
.03141 .02749 Mdot
.03141 .02357 Mdot
.55686 .55686 Mdot
.33335 .33335 Mdot
.12944 .13728 Mdot
.10591 .10591 Mdot
.08239 .08631 Mdot
.05886 .06278 Mdot
.04317 .05102 Mdot
.03533 .04317 Mdot
.02749 .03533 Mdot
.02357 .02357 Mdot
.76469 .76076 Mdot
.54509 .54117 Mdot
.0667 .06278 Mdot
.03141 .03141 Mdot
.01572 .01572 Mdot
.0118 .0118 Mdot
.00788 .0118 Mdot
.01572 .01572 Mdot
.76469 .76469 Mdot
.51372 .51765 Mdot
.01965 .02749 Mdot
.01572 .01965 Mdot
.0118 .0118 Mdot
.50588 .51372 Mdot
.25492 .25492 Mdot
0 0 1 r
.83919 .8588 Mdot
.43138 .5098 Mdot
.40785 .48628 Mdot
.69802 .73724 Mdot
.4902 .56862 Mdot
.51372 .58823 Mdot
.51765 .59607 Mdot
.50196 .57254 Mdot
.63528 .68626 Mdot
.749 .78429 Mdot
.51372 .58823 Mdot
.52941 .59607 Mdot
.54509 .61176 Mdot
.54509 .60783 Mdot
.53725 .59999 Mdot
.52549 .58823 Mdot
.52549 .59215 Mdot
.65097 .70194 Mdot
.88232 .89801 Mdot
.5098 .59215 Mdot
.54117 .61176 Mdot
.54902 .61568 Mdot
.55294 .61568 Mdot
.55686 .61568 Mdot
.54902 .61176 Mdot
.54117 .59999 Mdot
.54509 .60783 Mdot
.54509 .61176 Mdot
.54902 .6196 Mdot
.77253 .81566 Mdot
.89017 .91369 Mdot
.49804 .58039 Mdot
.53725 .6196 Mdot
.54117 .6196 Mdot
.55294 .62744 Mdot
.5647 .63528 Mdot
.55686 .62744 Mdot
.55294 .62744 Mdot
.55686 .62744 Mdot
.55294 .62352 Mdot
.55686 .63136 Mdot
.55686 .6392 Mdot
.55294 .64313 Mdot
.55686 .65097 Mdot
.78429 .83135 Mdot
.52157 .61176 Mdot
.54117 .63136 Mdot
.55294 .6392 Mdot
.55294 .6392 Mdot
.55294 .63528 Mdot
.55294 .63528 Mdot
.55294 .63528 Mdot
.55686 .63528 Mdot
.54902 .62744 Mdot
.55294 .63136 Mdot
.55686 .63528 Mdot
.56078 .64313 Mdot
.5647 .65489 Mdot
.5647 .65489 Mdot
.58039 .67057 Mdot
.68626 .749 Mdot
.79213 .83527 Mdot
.5098 .59215 Mdot
.53725 .63136 Mdot
.54117 .6392 Mdot
.54117 .63136 Mdot
.54117 .63136 Mdot
.54509 .63528 Mdot
.53725 .62352 Mdot
.54117 .61568 Mdot
.55294 .63136 Mdot
.56862 .64705 Mdot
.57254 .65097 Mdot
.57646 .65489 Mdot
.57646 .65489 Mdot
.57646 .65097 Mdot
.58431 .65489 Mdot
.58039 .65097 Mdot
.59215 .66273 Mdot
.5647 .63528 Mdot
.77253 .80782 Mdot
.88232 .89801 Mdot
.52157 .60783 Mdot
.52941 .62352 Mdot
.52941 .62744 Mdot
.52549 .62744 Mdot
.52941 .62352 Mdot
.54117 .63136 Mdot
.54509 .62744 Mdot
.55294 .63136 Mdot
.55294 .63136 Mdot
.56078 .63528 Mdot
.5647 .64313 Mdot
.57254 .64705 Mdot
.58039 .65489 Mdot
.58431 .65489 Mdot
.58823 .65097 Mdot
.59999 .66273 Mdot
.59215 .65881 Mdot
.58823 .65489 Mdot
.58039 .64705 Mdot
.58039 .65097 Mdot
.46275 .52157 Mdot
.72155 .749 Mdot
.81958 .82743 Mdot
.50588 .58039 Mdot
.53725 .6196 Mdot
.54509 .63528 Mdot
.54509 .63528 Mdot
.53725 .62352 Mdot
.52549 .61176 Mdot
.53725 .6196 Mdot
.54902 .62744 Mdot
.55686 .63136 Mdot
.55686 .63136 Mdot
.5647 .64313 Mdot
.5647 .6392 Mdot
.57254 .64705 Mdot
.58823 .65489 Mdot
.58431 .64313 Mdot
.59999 .66273 Mdot
.59215 .65097 Mdot
.59999 .66273 Mdot
.59215 .65881 Mdot
.58431 .65489 Mdot
.59215 .67057 Mdot
.55686 .63136 Mdot
.44706 .50588 Mdot
.51372 .54117 Mdot
.66665 .68626 Mdot
.5098 .58039 Mdot
.54509 .62744 Mdot
.54902 .64313 Mdot
.53333 .6196 Mdot
.53333 .62352 Mdot
.52941 .61568 Mdot
.53333 .61568 Mdot
.53725 .62352 Mdot
.55294 .63136 Mdot
.56078 .63528 Mdot
.56862 .6392 Mdot
.57646 .65097 Mdot
.58039 .65489 Mdot
.59215 .65881 Mdot
.59215 .66273 Mdot
.59607 .66665 Mdot
.59607 .65881 Mdot
.59607 .65881 Mdot
.60783 .6745 Mdot
.60391 .6745 Mdot
.59607 .6745 Mdot
.58823 .67057 Mdot
.58431 .66665 Mdot
.54902 .63136 Mdot
.49412 .5647 Mdot
.41569 .48235 Mdot
.47059 .50588 Mdot
.63528 .64705 Mdot
.52941 .60783 Mdot
.55686 .6392 Mdot
.55686 .64705 Mdot
.54509 .64313 Mdot
.54117 .63528 Mdot
.54509 .63136 Mdot
.53725 .62352 Mdot
.53333 .6196 Mdot
.54509 .62744 Mdot
.55294 .63528 Mdot
.57254 .65097 Mdot
.57646 .65097 Mdot
.57646 .65097 Mdot
.58039 .65489 Mdot
.58823 .66273 Mdot
.58823 .66665 Mdot
.59999 .67057 Mdot
.60783 .6745 Mdot
.60391 .66665 Mdot
.59999 .68234 Mdot
.59999 .67842 Mdot
.59607 .6745 Mdot
.59607 .67842 Mdot
.59999 .68234 Mdot
.59215 .67842 Mdot
.58431 .66665 Mdot
.54902 .62744 Mdot
.38824 .43922 Mdot
.3608 .40393 Mdot
.72155 .75292 Mdot
.81174 .81958 Mdot
.53333 .6196 Mdot
.55294 .64313 Mdot
.55686 .64705 Mdot
.55294 .64313 Mdot
.55294 .6392 Mdot
.54902 .63528 Mdot
.54509 .62744 Mdot
.54117 .62352 Mdot
.54902 .63136 Mdot
.55686 .6392 Mdot
.5647 .64705 Mdot
.56862 .65097 Mdot
.57646 .65881 Mdot
.58431 .66665 Mdot
.58823 .66665 Mdot
.58039 .65489 Mdot
.59607 .66665 Mdot
.60783 .6745 Mdot
.60783 .67842 Mdot
.60391 .68234 Mdot
.59999 .67842 Mdot
.60783 .68626 Mdot
.59999 .67842 Mdot
.59999 .67842 Mdot
.60391 .68626 Mdot
.60391 .68626 Mdot
.61176 .6941 Mdot
.59607 .6745 Mdot
.52941 .59215 Mdot
.47059 .52941 Mdot
.36472 .39609 Mdot
.32158 .34119 Mdot
.75292 .77645 Mdot
.8784 .89017 Mdot
.51765 .60391 Mdot
.54509 .63136 Mdot
.54509 .63528 Mdot
.54902 .63136 Mdot
.53725 .6196 Mdot
.54117 .62352 Mdot
.54902 .63136 Mdot
.54509 .62744 Mdot
.54902 .63136 Mdot
.55294 .6392 Mdot
.56078 .65097 Mdot
.56862 .66273 Mdot
.57254 .66665 Mdot
.58431 .6745 Mdot
.58823 .6745 Mdot
.58431 .66273 Mdot
.59607 .67057 Mdot
.59215 .66665 Mdot
.59607 .67057 Mdot
.60391 .6745 Mdot
.60391 .67842 Mdot
.60391 .68234 Mdot
.60783 .68234 Mdot
.61176 .69018 Mdot
.62744 .70194 Mdot
.62744 .70587 Mdot
.62352 .69018 Mdot
.62744 .70194 Mdot
.48628 .54509 Mdot
.38432 .41961 Mdot
.40001 .4353 Mdot
.44706 .48235 Mdot
.59999 .65881 Mdot
.58039 .6392 Mdot
.6941 .74116 Mdot
.81174 .84703 Mdot
.52549 .59607 Mdot
.54902 .62352 Mdot
.55686 .63528 Mdot
.54509 .62352 Mdot
.53333 .61568 Mdot
.53333 .61568 Mdot
.54509 .62744 Mdot
.54902 .63136 Mdot
.54902 .63136 Mdot
.5647 .64313 Mdot
.5647 .64313 Mdot
.5647 .64705 Mdot
.57646 .66273 Mdot
.57254 .65881 Mdot
.57646 .66273 Mdot
.59215 .67057 Mdot
.60391 .68234 Mdot
.59607 .6745 Mdot
.59999 .6745 Mdot
.60783 .67842 Mdot
.61176 .67842 Mdot
.61176 .67842 Mdot
.62744 .6941 Mdot
.63528 .69802 Mdot
.63136 .69802 Mdot
.62744 .6941 Mdot
.63136 .6941 Mdot
.63528 .70979 Mdot
.53725 .59999 Mdot
.39609 .42746 Mdot
.40001 .42746 Mdot
.56078 .61568 Mdot
.60783 .66665 Mdot
.62352 .6745 Mdot
.64313 .70194 Mdot
.65097 .70979 Mdot
.65489 .71371 Mdot
.72155 .76076 Mdot
.79998 .81958 Mdot
.53333 .59999 Mdot
.55294 .62352 Mdot
.56078 .63136 Mdot
.54902 .6196 Mdot
.54509 .6196 Mdot
.55294 .62744 Mdot
.56078 .63528 Mdot
.56078 .63136 Mdot
.5647 .6392 Mdot
.56862 .6392 Mdot
.5647 .6392 Mdot
.56862 .64705 Mdot
.56862 .65097 Mdot
.56862 .65881 Mdot
.56862 .65489 Mdot
.58039 .65881 Mdot
.59607 .6745 Mdot
.58823 .67057 Mdot
.59215 .6745 Mdot
.60783 .68626 Mdot
.6196 .69018 Mdot
.6196 .67842 Mdot
.62352 .68234 Mdot
.63136 .69018 Mdot
.6392 .70194 Mdot
.6392 .70587 Mdot
.64705 .70979 Mdot
.64705 .70979 Mdot
.61176 .6745 Mdot
.58431 .6392 Mdot
.56078 .60783 Mdot
.59215 .65097 Mdot
.6392 .69802 Mdot
.64705 .69802 Mdot
.65489 .70979 Mdot
.66665 .71371 Mdot
.66665 .70979 Mdot
.67057 .70979 Mdot
.65881 .69802 Mdot
.66273 .70194 Mdot
.83135 .85487 Mdot
.91761 .9333 Mdot
.51765 .58823 Mdot
.53725 .60783 Mdot
.55294 .62744 Mdot
.55294 .62352 Mdot
.54509 .61568 Mdot
.54902 .61176 Mdot
.55294 .61568 Mdot
.55686 .62352 Mdot
.56862 .63528 Mdot
.57254 .6392 Mdot
.56078 .63136 Mdot
.57646 .65097 Mdot
.57646 .65881 Mdot
.57254 .65489 Mdot
.57254 .65489 Mdot
.58039 .65881 Mdot
.60391 .68234 Mdot
.61176 .69018 Mdot
.60391 .68234 Mdot
.60391 .67842 Mdot
.60391 .68234 Mdot
.61176 .68234 Mdot
.6196 .68234 Mdot
.62744 .68626 Mdot
.63136 .6941 Mdot
.63528 .70194 Mdot
.63136 .69802 Mdot
.64705 .70979 Mdot
.64705 .70979 Mdot
.64313 .70194 Mdot
.63136 .68626 Mdot
.6392 .69802 Mdot
.65097 .70979 Mdot
.65881 .70587 Mdot
.65881 .70979 Mdot
.6745 .72155 Mdot
.67842 .71763 Mdot
.68626 .72939 Mdot
.68234 .72155 Mdot
.67842 .72547 Mdot
.66665 .70587 Mdot
.6745 .72547 Mdot
.67057 .72547 Mdot
.83527 .8588 Mdot
.91761 .92546 Mdot
.50588 .59607 Mdot
.53333 .6196 Mdot
.54509 .62744 Mdot
.54902 .62352 Mdot
.54509 .61568 Mdot
.54509 .61176 Mdot
.54902 .61568 Mdot
.54902 .61176 Mdot
.55686 .62352 Mdot
.5647 .63528 Mdot
.5647 .6392 Mdot
.57254 .64313 Mdot
.57254 .64705 Mdot
.57646 .65097 Mdot
.57254 .65489 Mdot
.57646 .65489 Mdot
.59215 .67057 Mdot
.59607 .6745 Mdot
.61176 .68626 Mdot
.60391 .67842 Mdot
.61568 .69018 Mdot
.60391 .67842 Mdot
.6196 .69018 Mdot
.62744 .6941 Mdot
.63528 .6941 Mdot
.63528 .69802 Mdot
.63136 .6941 Mdot
.64313 .70979 Mdot
.65097 .70979 Mdot
.65097 .70194 Mdot
.65097 .70587 Mdot
.64705 .70194 Mdot
.64705 .70194 Mdot
.65881 .70979 Mdot
.66665 .71763 Mdot
.67057 .72155 Mdot
.6745 .71763 Mdot
.67842 .72939 Mdot
.67842 .73332 Mdot
.68234 .73724 Mdot
.6745 .72939 Mdot
.66665 .72939 Mdot
.68234 .74508 Mdot
.67842 .74116 Mdot
.67842 .72547 Mdot
.76076 .79998 Mdot
.84703 .87448 Mdot
.50196 .58823 Mdot
.53333 .62352 Mdot
.54902 .63528 Mdot
.54902 .63136 Mdot
.53333 .61568 Mdot
.54117 .61568 Mdot
.54902 .61568 Mdot
.55686 .62352 Mdot
.55686 .62352 Mdot
.55686 .62352 Mdot
.5647 .63528 Mdot
.57646 .64705 Mdot
.57254 .64313 Mdot
.57646 .65097 Mdot
.58039 .65489 Mdot
.58039 .65489 Mdot
.58431 .65097 Mdot
.58823 .65489 Mdot
.59999 .67057 Mdot
.60391 .67057 Mdot
.61176 .67842 Mdot
.61568 .67842 Mdot
.62352 .68626 Mdot
.63528 .70194 Mdot
.63528 .6941 Mdot
.63528 .69018 Mdot
.63528 .69018 Mdot
.63528 .6941 Mdot
.65097 .70587 Mdot
.65097 .69802 Mdot
.65881 .70979 Mdot
.66665 .71763 Mdot
.66273 .71371 Mdot
.66273 .70979 Mdot
.66665 .71371 Mdot
.6745 .72547 Mdot
.68626 .73332 Mdot
.68234 .73332 Mdot
.67842 .73332 Mdot
.67842 .73332 Mdot
.67842 .73724 Mdot
.67842 .73724 Mdot
.6941 .749 Mdot
.6941 .749 Mdot
.6941 .749 Mdot
.69802 .749 Mdot
.69018 .74116 Mdot
.69802 .74116 Mdot
.76076 .79213 Mdot
.84311 .87448 Mdot
.51372 .58823 Mdot
.53725 .6196 Mdot
.55294 .63528 Mdot
.54509 .62352 Mdot
.53725 .6196 Mdot
.54117 .6196 Mdot
.54509 .61176 Mdot
.55294 .62744 Mdot
.56078 .63136 Mdot
.55294 .6196 Mdot
.57646 .64313 Mdot
.57646 .6392 Mdot
.58039 .65097 Mdot
.57646 .64313 Mdot
.58039 .65097 Mdot
.58039 .64313 Mdot
.58431 .64313 Mdot
.58431 .6392 Mdot
.58431 .64313 Mdot
.58823 .65097 Mdot
.60391 .66273 Mdot
.60783 .66273 Mdot
.6196 .6745 Mdot
.63528 .6941 Mdot
.6392 .69802 Mdot
.64313 .6941 Mdot
.64313 .69018 Mdot
.65097 .69802 Mdot
.64313 .6941 Mdot
.65489 .70194 Mdot
.65881 .70194 Mdot
.65881 .70587 Mdot
.66273 .70979 Mdot
.67842 .72155 Mdot
.6745 .72155 Mdot
.6745 .72155 Mdot
.68234 .72547 Mdot
.68626 .72939 Mdot
.67842 .72939 Mdot
.68234 .74116 Mdot
.68234 .74116 Mdot
.68234 .74116 Mdot
.6941 .749 Mdot
.70194 .75292 Mdot
.69802 .749 Mdot
.70194 .749 Mdot
.70194 .74508 Mdot
.71371 .75292 Mdot
.70587 .749 Mdot
.6941 .749 Mdot
.67842 .73332 Mdot
.8235 .85095 Mdot
.89801 .91761 Mdot
.46275 .52549 Mdot
.54902 .62352 Mdot
.53725 .61568 Mdot
.52157 .59999 Mdot
.51765 .59215 Mdot
.52549 .60783 Mdot
.53333 .60783 Mdot
.55294 .62352 Mdot
.55686 .62744 Mdot
.56078 .62744 Mdot
.55686 .62352 Mdot
.56862 .63528 Mdot
.57254 .6392 Mdot
.57254 .64313 Mdot
.57646 .64705 Mdot
.57646 .64313 Mdot
.58823 .65097 Mdot
.59999 .65489 Mdot
.59999 .65881 Mdot
.59215 .65489 Mdot
.59215 .65489 Mdot
.60391 .65881 Mdot
.60391 .65881 Mdot
.60783 .66273 Mdot
.61568 .6745 Mdot
.63136 .68626 Mdot
.6392 .68626 Mdot
.65489 .70194 Mdot
.65097 .69802 Mdot
.65097 .6941 Mdot
.65097 .69802 Mdot
.65489 .70194 Mdot
.66273 .70194 Mdot
.6745 .71763 Mdot
.67842 .72155 Mdot
.66273 .70587 Mdot
.66665 .71371 Mdot
.67057 .72155 Mdot
.67057 .72547 Mdot
.67057 .72939 Mdot
.67057 .72547 Mdot
.69018 .749 Mdot
.69018 .749 Mdot
.69018 .74116 Mdot
.69018 .74116 Mdot
.70194 .749 Mdot
.70194 .75292 Mdot
.70979 .74508 Mdot
.70587 .749 Mdot
.70979 .75684 Mdot
.70587 .75292 Mdot
.6941 .74508 Mdot
.68626 .74116 Mdot
.59215 .64313 Mdot
.74508 .75292 Mdot
.86272 .86664 Mdot
.48628 .55686 Mdot
.51372 .59607 Mdot
.52941 .61176 Mdot
.52941 .60783 Mdot
.51765 .59215 Mdot
.51765 .59215 Mdot
.51765 .58823 Mdot
.54509 .60783 Mdot
.55686 .6196 Mdot
.55686 .62352 Mdot
.55294 .62352 Mdot
.54902 .62352 Mdot
.56078 .6392 Mdot
.55294 .63136 Mdot
.5647 .64313 Mdot
.56862 .64313 Mdot
.58039 .65097 Mdot
.58431 .65881 Mdot
.58823 .66273 Mdot
.58823 .66273 Mdot
.59607 .67057 Mdot
.59607 .66665 Mdot
.59607 .65881 Mdot
.61176 .66665 Mdot
.61568 .6745 Mdot
.62352 .69018 Mdot
.6392 .69802 Mdot
.64313 .6941 Mdot
.65489 .70587 Mdot
.66273 .70979 Mdot
.66665 .71371 Mdot
.66273 .71371 Mdot
.66273 .70979 Mdot
.65881 .70587 Mdot
.66665 .71763 Mdot
.65881 .70587 Mdot
.66273 .71371 Mdot
.66273 .71371 Mdot
.66665 .71763 Mdot
.6745 .72547 Mdot
.68626 .73332 Mdot
.68234 .73332 Mdot
.69018 .74508 Mdot
.69802 .749 Mdot
.6941 .74508 Mdot
.69802 .74508 Mdot
.70194 .749 Mdot
.70979 .75292 Mdot
.70587 .74508 Mdot
.71371 .75292 Mdot
.70979 .749 Mdot
.70979 .75292 Mdot
.71371 .75292 Mdot
.70587 .74116 Mdot
.67057 .70587 Mdot
.65489 .69018 Mdot
.74116 .76469 Mdot
.79606 .80782 Mdot
.50588 .58431 Mdot
.53725 .60783 Mdot
.54509 .6196 Mdot
.53333 .60783 Mdot
.51765 .58823 Mdot
.52157 .59215 Mdot
.52941 .60391 Mdot
.54117 .60783 Mdot
.54902 .61176 Mdot
.54902 .61568 Mdot
.55294 .6196 Mdot
.55294 .62352 Mdot
.55294 .63136 Mdot
.55686 .6392 Mdot
.56078 .63528 Mdot
.5647 .64313 Mdot
.57254 .64705 Mdot
.56862 .64705 Mdot
.5647 .64705 Mdot
.57646 .65489 Mdot
.58431 .65489 Mdot
.59215 .65881 Mdot
.60391 .65881 Mdot
.61568 .67057 Mdot
.61568 .66665 Mdot
.62352 .6745 Mdot
.63528 .68234 Mdot
.6392 .68626 Mdot
.64313 .68626 Mdot
.65489 .69802 Mdot
.65489 .69802 Mdot
.66273 .70979 Mdot
.66665 .71371 Mdot
.66665 .70979 Mdot
.66273 .70587 Mdot
.66665 .72155 Mdot
.65881 .70979 Mdot
.66665 .72155 Mdot
.66273 .71371 Mdot
.6745 .72547 Mdot
.68626 .72939 Mdot
.68234 .72547 Mdot
.69018 .73724 Mdot
.70194 .749 Mdot
.70194 .749 Mdot
.70194 .749 Mdot
.70979 .749 Mdot
.70587 .749 Mdot
.70979 .74508 Mdot
.71763 .75684 Mdot
.72155 .76469 Mdot
.71371 .76076 Mdot
.71763 .76076 Mdot
.71371 .75292 Mdot
.71371 .74508 Mdot
.70979 .74116 Mdot
.70587 .74508 Mdot
.70194 .74116 Mdot
.6745 .72155 Mdot
.74508 .78037 Mdot
.64313 .63136 Mdot
.46275 .53333 Mdot
.52549 .60783 Mdot
.53333 .61568 Mdot
.52941 .61176 Mdot
.52941 .60391 Mdot
.52549 .59999 Mdot
.53333 .61176 Mdot
.53725 .61568 Mdot
.54509 .6196 Mdot
.54902 .62352 Mdot
.54902 .62352 Mdot
.54509 .6196 Mdot
.54117 .62352 Mdot
.55294 .63528 Mdot
.56078 .6392 Mdot
.57254 .64705 Mdot
.56862 .64705 Mdot
.57254 .65881 Mdot
.5647 .65489 Mdot
.58039 .66665 Mdot
.58431 .65881 Mdot
.59999 .66273 Mdot
.60783 .67057 Mdot
.62352 .68234 Mdot
.63136 .67842 Mdot
.63528 .68234 Mdot
.65097 .69018 Mdot
.65881 .6941 Mdot
.64705 .68234 Mdot
.66273 .70194 Mdot
.66273 .70194 Mdot
.67057 .70979 Mdot
.66665 .70587 Mdot
.67057 .70979 Mdot
.67057 .70979 Mdot
.67842 .72155 Mdot
.67842 .72547 Mdot
.67057 .71763 Mdot
.67842 .72939 Mdot
.68234 .72547 Mdot
.68234 .72939 Mdot
.68626 .72547 Mdot
.6941 .73724 Mdot
.69802 .74116 Mdot
.70194 .749 Mdot
.70979 .74508 Mdot
.70587 .749 Mdot
.71371 .749 Mdot
.71371 .749 Mdot
.72155 .76076 Mdot
.71763 .75684 Mdot
.71763 .75684 Mdot
.71371 .75292 Mdot
.70979 .75292 Mdot
.72939 .76861 Mdot
.72547 .76076 Mdot
.72547 .76076 Mdot
.72939 .76469 Mdot
.72939 .76861 Mdot
.74116 .79213 Mdot
.4902 .49804 Mdot
.28629 .26276 Mdot
.65881 .65489 Mdot
.88624 .89801 Mdot
.45491 .53333 Mdot
.50196 .58431 Mdot
.52549 .60391 Mdot
.53333 .61568 Mdot
.53333 .60783 Mdot
.53725 .61176 Mdot
.53333 .60391 Mdot
.53725 .61568 Mdot
.54509 .6196 Mdot
.54117 .6196 Mdot
.55294 .63136 Mdot
.5647 .63528 Mdot
.56078 .63136 Mdot
.56862 .6392 Mdot
.56862 .64313 Mdot
.56862 .64313 Mdot
.57646 .65489 Mdot
.58823 .66273 Mdot
.58039 .65489 Mdot
.58431 .66273 Mdot
.59999 .6745 Mdot
.60391 .67057 Mdot
.61176 .67057 Mdot
.6196 .67057 Mdot
.6196 .67842 Mdot
.63136 .68234 Mdot
.64313 .6941 Mdot
.65489 .69802 Mdot
.64705 .69018 Mdot
.64705 .6941 Mdot
.65881 .71371 Mdot
.66273 .70979 Mdot
.67057 .71763 Mdot
.6745 .71371 Mdot
.6745 .71763 Mdot
.67842 .72155 Mdot
.68626 .73332 Mdot
.69018 .73332 Mdot
.6941 .74116 Mdot
.6941 .73724 Mdot
.69802 .73332 Mdot
.6941 .72939 Mdot
.70194 .74508 Mdot
.70194 .749 Mdot
.70587 .74508 Mdot
.70194 .749 Mdot
.70979 .75684 Mdot
.71371 .75684 Mdot
.72155 .75684 Mdot
.72547 .75684 Mdot
.74116 .77253 Mdot
.73332 .76076 Mdot
.73332 .76076 Mdot
.73332 .76469 Mdot
.73332 .76076 Mdot
.74116 .76469 Mdot
.74508 .77253 Mdot
.74116 .77645 Mdot
.73724 .77645 Mdot
.74508 .79213 Mdot
.71763 .76469 Mdot
.4902 .50588 Mdot
.36864 .35295 Mdot
.6941 .73724 Mdot
.59607 .6196 Mdot
.83135 .85095 Mdot
.90977 .92154 Mdot
.44314 .51765 Mdot
.5098 .58431 Mdot
.52157 .59999 Mdot
.52549 .60391 Mdot
.51765 .59215 Mdot
.52157 .59999 Mdot
.52157 .59607 Mdot
.52549 .60391 Mdot
.53333 .61568 Mdot
.54509 .62744 Mdot
.55294 .63136 Mdot
.54902 .62352 Mdot
.54902 .6196 Mdot
.55686 .63528 Mdot
.56078 .64705 Mdot
.54509 .62744 Mdot
.55294 .6392 Mdot
.56862 .65097 Mdot
.58431 .66273 Mdot
.58823 .66665 Mdot
.59215 .66273 Mdot
.59215 .66273 Mdot
.60783 .67057 Mdot
.61176 .67057 Mdot
.60783 .66665 Mdot
.6196 .67842 Mdot
.61568 .67842 Mdot
.62352 .67842 Mdot
.62744 .67842 Mdot
.6392 .69018 Mdot
.65097 .70194 Mdot
.65097 .70587 Mdot
.65881 .70979 Mdot
.65489 .70194 Mdot
.65881 .69802 Mdot
.67057 .70979 Mdot
.6745 .71371 Mdot
.6745 .70979 Mdot
.68234 .72155 Mdot
.6745 .70979 Mdot
.68626 .71371 Mdot
.69018 .72155 Mdot
.6941 .73724 Mdot
.69018 .73724 Mdot
.70194 .749 Mdot
.69802 .74116 Mdot
.70194 .74508 Mdot
.70979 .74508 Mdot
.71371 .749 Mdot
.71763 .749 Mdot
.72939 .75292 Mdot
.72939 .75292 Mdot
.73724 .76076 Mdot
.72939 .76076 Mdot
.72547 .75684 Mdot
.72547 .76076 Mdot
.72547 .76469 Mdot
.73332 .76861 Mdot
.72939 .76861 Mdot
.72155 .76469 Mdot
.72155 .76076 Mdot
.70979 .74508 Mdot
.68626 .70587 Mdot
.70587 .72939 Mdot
.71371 .74116 Mdot
.70979 .749 Mdot
.69802 .74116 Mdot
.76861 .79998 Mdot
.69018 .69018 Mdot
.47451 .53725 Mdot
.50588 .57646 Mdot
.50196 .57646 Mdot
.50196 .57646 Mdot
.50588 .58431 Mdot
.52157 .59607 Mdot
.52157 .59999 Mdot
.51765 .59607 Mdot
.52941 .60783 Mdot
.53725 .61568 Mdot
.54509 .62744 Mdot
.54117 .62352 Mdot
.54509 .62352 Mdot
.54509 .62352 Mdot
.54117 .62744 Mdot
.54509 .62744 Mdot
.54902 .62352 Mdot
.5647 .63528 Mdot
.58431 .65489 Mdot
.58039 .64705 Mdot
.58431 .65097 Mdot
.59215 .65097 Mdot
.59607 .64705 Mdot
.60391 .66273 Mdot
.61176 .67057 Mdot
.61176 .66665 Mdot
.61176 .66665 Mdot
.61568 .67057 Mdot
.62744 .68234 Mdot
.6392 .68234 Mdot
.64313 .68234 Mdot
.64313 .68626 Mdot
.67057 .70587 Mdot
.66665 .70194 Mdot
.66273 .69802 Mdot
.66665 .70194 Mdot
.6745 .70194 Mdot
.6745 .70587 Mdot
.67842 .71763 Mdot
.67842 .71371 Mdot
.68626 .71371 Mdot
.68626 .71371 Mdot
.69802 .72939 Mdot
.69802 .73332 Mdot
.70194 .73724 Mdot
.70194 .74116 Mdot
.70587 .749 Mdot
.70194 .74508 Mdot
.69802 .74116 Mdot
.70587 .74508 Mdot
.70979 .74508 Mdot
.71371 .749 Mdot
.72547 .76076 Mdot
.72155 .76076 Mdot
.71763 .76861 Mdot
.70979 .76076 Mdot
.70979 .76076 Mdot
.71371 .76469 Mdot
.71763 .76469 Mdot
.72547 .76861 Mdot
.72939 .76469 Mdot
.73724 .76469 Mdot
.72939 .75684 Mdot
.73332 .75684 Mdot
.72547 .75292 Mdot
.73332 .76469 Mdot
.74116 .76861 Mdot
.72939 .76469 Mdot
.6745 .6941 Mdot
.66273 .67842 Mdot
.75684 .77645 Mdot
.92938 .93722 Mdot
.48235 .54117 Mdot
.50588 .58039 Mdot
.51765 .59607 Mdot
.51372 .59607 Mdot
.5098 .58823 Mdot
.51372 .58823 Mdot
.51765 .59215 Mdot
.52549 .59999 Mdot
.52549 .59999 Mdot
.52941 .60391 Mdot
.54509 .61568 Mdot
.54117 .61176 Mdot
.54509 .6196 Mdot
.55686 .63136 Mdot
.54902 .62744 Mdot
.54902 .62744 Mdot
.55686 .63136 Mdot
.5647 .6392 Mdot
.57646 .64313 Mdot
.58039 .65489 Mdot
.58431 .64313 Mdot
.58823 .64313 Mdot
.60391 .65881 Mdot
.60391 .65489 Mdot
.61176 .66665 Mdot
.62352 .67057 Mdot
.62352 .6745 Mdot
.62744 .6745 Mdot
.6392 .69018 Mdot
.64313 .68626 Mdot
.65097 .69802 Mdot
.65097 .6941 Mdot
.65881 .69802 Mdot
.65881 .6941 Mdot
.65881 .6941 Mdot
.6745 .71371 Mdot
.68234 .71763 Mdot
.69018 .72547 Mdot
.69018 .72547 Mdot
.69018 .72547 Mdot
.69018 .72155 Mdot
.6941 .72547 Mdot
.70587 .74116 Mdot
.70587 .74116 Mdot
.70979 .74116 Mdot
.70587 .74116 Mdot
.70587 .74116 Mdot
.70194 .74116 Mdot
.70587 .749 Mdot
.70587 .749 Mdot
.70587 .74508 Mdot
.70979 .74508 Mdot
.71371 .749 Mdot
.70587 .74508 Mdot
.71371 .75684 Mdot
.72155 .76861 Mdot
.72155 .76469 Mdot
.72939 .77253 Mdot
.72547 .76861 Mdot
.72939 .76469 Mdot
.72547 .76469 Mdot
.72939 .76469 Mdot
.74116 .77645 Mdot
.749 .77645 Mdot
.749 .77645 Mdot
.74508 .77253 Mdot
.74508 .77253 Mdot
.74508 .77645 Mdot
.749 .78037 Mdot
.73724 .76469 Mdot
.73332 .76076 Mdot
.73332 .76469 Mdot
.72939 .76469 Mdot
.86664 .89017 Mdot
.9333 .94114 Mdot
.46275 .52941 Mdot
.50196 .58039 Mdot
.51372 .59215 Mdot
.51765 .60391 Mdot
.51372 .59215 Mdot
.52549 .59999 Mdot
.52157 .59215 Mdot
.52157 .59215 Mdot
.52549 .59999 Mdot
.53725 .60783 Mdot
.53725 .59607 Mdot
.54902 .61176 Mdot
.54902 .61568 Mdot
.55686 .62352 Mdot
.56078 .63528 Mdot
.56862 .64313 Mdot
.56078 .63136 Mdot
.5647 .63136 Mdot
.5647 .63136 Mdot
.58039 .64313 Mdot
.59607 .65097 Mdot
.59215 .64313 Mdot
.59607 .64705 Mdot
.60783 .65489 Mdot
.61176 .66665 Mdot
.61176 .67057 Mdot
.61176 .66665 Mdot
.6196 .67842 Mdot
.62744 .68626 Mdot
.62744 .67842 Mdot
.63136 .68626 Mdot
.64313 .6941 Mdot
.65489 .6941 Mdot
.66273 .69802 Mdot
.67057 .70587 Mdot
.6745 .71371 Mdot
.6745 .70587 Mdot
.67842 .71763 Mdot
.67842 .71371 Mdot
.68234 .72547 Mdot
.68234 .72547 Mdot
.68626 .73332 Mdot
.69018 .73724 Mdot
.69802 .74508 Mdot
.70194 .74116 Mdot
.69802 .73724 Mdot
.69802 .74116 Mdot
.70194 .74508 Mdot
.69802 .73724 Mdot
.72155 .76076 Mdot
.72155 .76076 Mdot
.72155 .75684 Mdot
.72547 .76076 Mdot
.72547 .76469 Mdot
.72547 .76861 Mdot
.72939 .76861 Mdot
.73724 .77253 Mdot
.73332 .76469 Mdot
.73724 .77645 Mdot
.73332 .76861 Mdot
.73724 .77253 Mdot
.72155 .76076 Mdot
.72939 .76469 Mdot
.74116 .77253 Mdot
.749 .78037 Mdot
.749 .78429 Mdot
.75292 .78037 Mdot
.75684 .78429 Mdot
.74508 .77253 Mdot
.749 .78037 Mdot
.749 .78037 Mdot
.75292 .78429 Mdot
.74508 .78429 Mdot
.73332 .77645 Mdot
.72939 .77645 Mdot
.71371 .75684 Mdot
.86272 .89017 Mdot
.43922 .50588 Mdot
.49412 .57254 Mdot
.51372 .58823 Mdot
.52157 .59215 Mdot
.51765 .58823 Mdot
.52157 .59607 Mdot
.52549 .59215 Mdot
.52941 .59607 Mdot
.52549 .59607 Mdot
.52549 .59215 Mdot
.53333 .59999 Mdot
.54902 .61176 Mdot
.54902 .60783 Mdot
.55294 .61176 Mdot
.56078 .62352 Mdot
.56078 .62352 Mdot
.5647 .63136 Mdot
.58039 .63528 Mdot
.58431 .6392 Mdot
.58431 .6392 Mdot
.58823 .6392 Mdot
.60783 .65489 Mdot
.60783 .65489 Mdot
.60391 .65097 Mdot
.60391 .65489 Mdot
.61176 .66273 Mdot
.61176 .66665 Mdot
.60783 .66273 Mdot
.61176 .66273 Mdot
.6196 .6745 Mdot
.63528 .68626 Mdot
.64313 .69018 Mdot
.65097 .69018 Mdot
.65881 .69802 Mdot
.67057 .70194 Mdot
.6745 .71371 Mdot
.6745 .70979 Mdot
.6745 .70979 Mdot
.6745 .70979 Mdot
.67842 .71371 Mdot
.67842 .72155 Mdot
.69018 .73332 Mdot
.69018 .73332 Mdot
.69018 .73332 Mdot
.70587 .74116 Mdot
.70587 .74116 Mdot
.70587 .73724 Mdot
.71371 .74116 Mdot
.72155 .749 Mdot
.72547 .74508 Mdot
.73332 .75684 Mdot
.73332 .75292 Mdot
.72547 .749 Mdot
.72939 .76076 Mdot
.72155 .75292 Mdot
.72939 .76076 Mdot
.74116 .76469 Mdot
.74116 .76861 Mdot
.72939 .75684 Mdot
.74508 .77253 Mdot
.74508 .77645 Mdot
.74116 .77645 Mdot
.73724 .77645 Mdot
.74508 .78821 Mdot
.74508 .78821 Mdot
.74116 .78037 Mdot
.749 .78429 Mdot
.75684 .78429 Mdot
.74508 .77253 Mdot
.75684 .78037 Mdot
.749 .77645 Mdot
.75292 .77253 Mdot
.75684 .78037 Mdot
.74508 .78429 Mdot
.73724 .77645 Mdot
.73332 .77645 Mdot
.73724 .78037 Mdot
.73724 .78429 Mdot
.75292 .78037 Mdot
.81566 .8235 Mdot
.45098 .51765 Mdot
.50196 .57254 Mdot
.51372 .59215 Mdot
.52157 .59215 Mdot
.51765 .58823 Mdot
.51765 .58823 Mdot
.51372 .58823 Mdot
.52941 .60783 Mdot
.52941 .60783 Mdot
.52941 .60783 Mdot
.54902 .6196 Mdot
.55294 .62352 Mdot
.55686 .6196 Mdot
.55686 .61176 Mdot
.5647 .62352 Mdot
.57646 .6392 Mdot
.58431 .63528 Mdot
.58823 .64313 Mdot
.59215 .64313 Mdot
.58823 .64313 Mdot
.59999 .65097 Mdot
.60391 .65881 Mdot
.60391 .65881 Mdot
.61176 .66665 Mdot
.60783 .66273 Mdot
.61568 .66273 Mdot
.61568 .67057 Mdot
.62744 .68234 Mdot
.6196 .67842 Mdot
.61568 .67057 Mdot
.63136 .68626 Mdot
.63528 .69802 Mdot
.64705 .70194 Mdot
.66665 .71371 Mdot
.66273 .70194 Mdot
.67842 .70979 Mdot
.67057 .70194 Mdot
.67842 .71371 Mdot
.68234 .71763 Mdot
.68234 .72547 Mdot
.68626 .72939 Mdot
.69018 .73332 Mdot
.69018 .73332 Mdot
.69802 .74508 Mdot
.70587 .74508 Mdot
.70587 .73724 Mdot
.70587 .73724 Mdot
.71371 .749 Mdot
.72939 .76469 Mdot
.72939 .749 Mdot
.74116 .76469 Mdot
.72939 .749 Mdot
.72939 .749 Mdot
.72547 .75292 Mdot
.72939 .76469 Mdot
.72939 .76076 Mdot
.749 .77645 Mdot
.749 .77253 Mdot
.74508 .76469 Mdot
.75684 .78037 Mdot
.75684 .78429 Mdot
.749 .78037 Mdot
.75292 .78429 Mdot
.749 .78429 Mdot
.74508 .78429 Mdot
.74508 .78037 Mdot
.75292 .79213 Mdot
.75684 .79606 Mdot
.74116 .78037 Mdot
.749 .78429 Mdot
.74508 .78037 Mdot
.74508 .77645 Mdot
.75292 .78821 Mdot
.75292 .78821 Mdot
.74116 .78037 Mdot
.75684 .79998 Mdot
.75684 .79606 Mdot
.749 .78821 Mdot
.74508 .78037 Mdot
.74116 .78037 Mdot
.72547 .76469 Mdot
.80782 .83527 Mdot
.93722 .94898 Mdot
.47843 .56078 Mdot
.52549 .60783 Mdot
.53725 .6196 Mdot
.53333 .59999 Mdot
.52157 .58039 Mdot
.52549 .58823 Mdot
.52157 .58823 Mdot
.52549 .59607 Mdot
.52941 .60783 Mdot
.52941 .60783 Mdot
.53333 .60783 Mdot
.55294 .6196 Mdot
.55294 .6196 Mdot
.55686 .62744 Mdot
.55294 .63136 Mdot
.56078 .63528 Mdot
.5647 .63136 Mdot
.57646 .6392 Mdot
.58039 .64313 Mdot
.57646 .64313 Mdot
.59215 .65489 Mdot
.59999 .65489 Mdot
.60391 .65489 Mdot
.60783 .66273 Mdot
.62352 .67057 Mdot
.6196 .66665 Mdot
.62352 .67057 Mdot
.62352 .67842 Mdot
.62744 .68234 Mdot
.63136 .68626 Mdot
.63136 .69018 Mdot
.6392 .69802 Mdot
.6392 .70194 Mdot
.64705 .70194 Mdot
.65097 .6941 Mdot
.66665 .70587 Mdot
.68234 .71763 Mdot
.68626 .71763 Mdot
.68234 .71763 Mdot
.68626 .72155 Mdot
.68626 .72547 Mdot
.68234 .71763 Mdot
.69018 .73332 Mdot
.69018 .73332 Mdot
.69018 .73724 Mdot
.69018 .73332 Mdot
.69802 .73332 Mdot
.70979 .74116 Mdot
.72155 .75292 Mdot
.71371 .73724 Mdot
.71763 .749 Mdot
.73332 .75684 Mdot
.73332 .76076 Mdot
.72547 .76076 Mdot
.72547 .75684 Mdot
.72939 .76469 Mdot
.73332 .76861 Mdot
.74508 .77253 Mdot
.75292 .78037 Mdot
.73724 .76861 Mdot
.74116 .76861 Mdot
.75684 .78821 Mdot
.75292 .78037 Mdot
.749 .78037 Mdot
.73332 .77253 Mdot
.73332 .77253 Mdot
.749 .78429 Mdot
.74508 .78821 Mdot
.73724 .78037 Mdot
.74116 .77645 Mdot
.74116 .77253 Mdot
.74508 .78037 Mdot
.75684 .79213 Mdot
.75684 .79606 Mdot
.75684 .79606 Mdot
.76076 .79998 Mdot
.75684 .79606 Mdot
.75292 .79213 Mdot
.74508 .78037 Mdot
.75292 .78821 Mdot
.749 .78429 Mdot
.74508 .78037 Mdot
.74116 .77645 Mdot
.72939 .77253 Mdot
.84311 .86272 Mdot
.90193 .90977 Mdot
.4902 .5647 Mdot
.51765 .58823 Mdot
.52941 .59999 Mdot
.52941 .58823 Mdot
.52941 .57646 Mdot
.53725 .58823 Mdot
.53725 .59999 Mdot
.52941 .60391 Mdot
.53725 .61568 Mdot
.53333 .61568 Mdot
.53725 .61176 Mdot
.54117 .6196 Mdot
.54117 .6196 Mdot
.54902 .62352 Mdot
.55294 .63136 Mdot
.55686 .63136 Mdot
.56862 .63528 Mdot
.56862 .63528 Mdot
.57254 .6392 Mdot
.57254 .64313 Mdot
.58823 .65881 Mdot
.59215 .65097 Mdot
.60391 .65489 Mdot
.60391 .65489 Mdot
.59999 .65097 Mdot
.61568 .66665 Mdot
.6196 .67057 Mdot
.62744 .6745 Mdot
.63136 .6745 Mdot
.62352 .66665 Mdot
.63136 .68626 Mdot
.64313 .69802 Mdot
.64705 .69802 Mdot
.64313 .69802 Mdot
.64705 .69018 Mdot
.65881 .69802 Mdot
.67057 .70587 Mdot
.6745 .70587 Mdot
.67842 .71371 Mdot
.68234 .72155 Mdot
.6745 .71371 Mdot
.67057 .70979 Mdot
.68234 .72155 Mdot
.6941 .73724 Mdot
.69018 .73332 Mdot
.69018 .73332 Mdot
.6941 .72939 Mdot
.70194 .74116 Mdot
.70194 .73724 Mdot
.70979 .74116 Mdot
.71371 .74508 Mdot
.72939 .75292 Mdot
.73332 .76076 Mdot
.72939 .749 Mdot
.72939 .74508 Mdot
.73332 .75292 Mdot
.73332 .75684 Mdot
.73332 .76076 Mdot
.72547 .75684 Mdot
.72939 .76076 Mdot
.73332 .76861 Mdot
.74116 .78037 Mdot
.74116 .77645 Mdot
.74508 .78429 Mdot
.74508 .78429 Mdot
.74508 .77645 Mdot
.749 .78037 Mdot
.749 .77645 Mdot
.749 .78037 Mdot
.749 .78037 Mdot
.75684 .78821 Mdot
.75292 .77645 Mdot
.74508 .76469 Mdot
.75292 .77645 Mdot
.75292 .78821 Mdot
.75684 .79998 Mdot
.75684 .79606 Mdot
.75292 .78821 Mdot
.74508 .78429 Mdot
.749 .78429 Mdot
.74508 .78037 Mdot
.749 .78429 Mdot
.75292 .78429 Mdot
.74116 .77253 Mdot
.73332 .76861 Mdot
.71371 .749 Mdot
.72155 .75684 Mdot
.86272 .88232 Mdot
.5098 .56862 Mdot
.52549 .58431 Mdot
.53725 .59607 Mdot
.52941 .59215 Mdot
.53333 .58823 Mdot
.52549 .58431 Mdot
.51372 .57254 Mdot
.51372 .58431 Mdot
.52941 .60783 Mdot
.53725 .61568 Mdot
.54117 .6196 Mdot
.54902 .62352 Mdot
.55294 .62744 Mdot
.55686 .63136 Mdot
.55686 .63528 Mdot
.57254 .6392 Mdot
.56862 .62744 Mdot
.58039 .63528 Mdot
.58039 .6392 Mdot
.58823 .65097 Mdot
.58431 .64705 Mdot
.60391 .65881 Mdot
.59999 .65489 Mdot
.60783 .65489 Mdot
.59999 .64705 Mdot
.59215 .64313 Mdot
.61176 .66273 Mdot
.6196 .67057 Mdot
.63136 .6745 Mdot
.63528 .68234 Mdot
.63136 .68234 Mdot
.6392 .6941 Mdot
.6392 .69018 Mdot
.64313 .69018 Mdot
.65097 .68626 Mdot
.65489 .68626 Mdot
.66273 .69802 Mdot
.66665 .70587 Mdot
.66665 .70194 Mdot
.68234 .72155 Mdot
.69018 .72939 Mdot
.68626 .72155 Mdot
.68234 .71763 Mdot
.67842 .71763 Mdot
.68234 .72547 Mdot
.6941 .72939 Mdot
.70194 .73724 Mdot
.70979 .73724 Mdot
.70979 .73724 Mdot
.71763 .73724 Mdot
.72155 .74116 Mdot
.73332 .749 Mdot
.73332 .749 Mdot
.73724 .75292 Mdot
.73332 .749 Mdot
.73724 .75684 Mdot
.72939 .75292 Mdot
.73724 .76861 Mdot
.73724 .76861 Mdot
.73332 .76861 Mdot
.72547 .76469 Mdot
.73332 .77253 Mdot
.73724 .77253 Mdot
.74116 .78037 Mdot
.74116 .78037 Mdot
.75292 .78429 Mdot
.75684 .78429 Mdot
.75292 .77645 Mdot
.749 .77645 Mdot
.74508 .77253 Mdot
.75684 .78037 Mdot
.76469 .78429 Mdot
.76469 .78037 Mdot
.76469 .78037 Mdot
.75684 .78037 Mdot
.76469 .79213 Mdot
.75684 .78037 Mdot
.76076 .79213 Mdot
.76076 .79213 Mdot
.75684 .78821 Mdot
.75292 .78429 Mdot
.75292 .78429 Mdot
.749 .77645 Mdot
.75684 .78821 Mdot
.75292 .78037 Mdot
.74116 .77253 Mdot
.73332 .76076 Mdot
.73332 .76861 Mdot
.72155 .76469 Mdot
.78429 .81566 Mdot
.84311 .86664 Mdot
.49412 .56078 Mdot
.51765 .58431 Mdot
.52549 .59607 Mdot
.51765 .58431 Mdot
.51372 .58431 Mdot
.51765 .58431 Mdot
.51372 .58823 Mdot
.52157 .59607 Mdot
.52549 .61176 Mdot
.52549 .61176 Mdot
.53333 .60783 Mdot
.54509 .61568 Mdot
.55686 .62352 Mdot
.57254 .6392 Mdot
.56862 .62744 Mdot
.57254 .62744 Mdot
.58039 .63136 Mdot
.59215 .64313 Mdot
.59999 .64313 Mdot
.59607 .64705 Mdot
.59607 .65097 Mdot
.59607 .65881 Mdot
.60391 .65881 Mdot
.60391 .65881 Mdot
.6196 .6745 Mdot
.61176 .65881 Mdot
.60783 .65881 Mdot
.61568 .66665 Mdot
.62744 .67842 Mdot
.62744 .68234 Mdot
.62352 .6745 Mdot
.62744 .67842 Mdot
.6392 .69018 Mdot
.64313 .69018 Mdot
.65489 .6941 Mdot
.65881 .69802 Mdot
.66665 .70194 Mdot
.67057 .70979 Mdot
.66665 .71371 Mdot
.67842 .72155 Mdot
.67842 .71763 Mdot
.69018 .72155 Mdot
.6941 .73332 Mdot
.69018 .72939 Mdot
.68626 .72939 Mdot
.6941 .73724 Mdot
.70979 .73724 Mdot
.71763 .74116 Mdot
.71763 .73332 Mdot
.72939 .74508 Mdot
.73332 .749 Mdot
.74116 .75684 Mdot
.73724 .75292 Mdot
.73724 .75292 Mdot
.73724 .75292 Mdot
.73724 .75292 Mdot
.72939 .749 Mdot
.73332 .76076 Mdot
.72939 .76076 Mdot
.74116 .77645 Mdot
.749 .78429 Mdot
.74508 .77253 Mdot
.74508 .77253 Mdot
.75292 .77645 Mdot
.75292 .77645 Mdot
.749 .77253 Mdot
.75292 .77645 Mdot
.75684 .78429 Mdot
.75684 .78821 Mdot
.749 .78429 Mdot
.75292 .78429 Mdot
.75684 .78429 Mdot
.76469 .78429 Mdot
.77253 .78821 Mdot
.76469 .78429 Mdot
.77253 .79213 Mdot
.76076 .78429 Mdot
.76076 .78821 Mdot
.76469 .78821 Mdot
.76469 .79606 Mdot
.76469 .79606 Mdot
.75684 .78429 Mdot
.75684 .78821 Mdot
.75684 .79213 Mdot
.75684 .78821 Mdot
.75684 .78821 Mdot
.75292 .78821 Mdot
.74508 .78037 Mdot
.74508 .78821 Mdot
.73724 .78037 Mdot
.73332 .78037 Mdot
.71763 .76469 Mdot
.77645 .81174 Mdot
.92546 .93722 Mdot
.47843 .55294 Mdot
.5098 .58431 Mdot
.52941 .60783 Mdot
.52549 .59607 Mdot
.51372 .58039 Mdot
.5098 .57646 Mdot
.51765 .58823 Mdot
.52549 .59607 Mdot
.52549 .59999 Mdot
.53333 .60783 Mdot
.54117 .61568 Mdot
.55294 .61568 Mdot
.55686 .62744 Mdot
.56862 .63528 Mdot
.57254 .63136 Mdot
.58431 .63136 Mdot
.58039 .62352 Mdot
.58823 .63528 Mdot
.58823 .63528 Mdot
.58823 .6392 Mdot
.59999 .65489 Mdot
.59607 .65097 Mdot
.59999 .65489 Mdot
.60783 .65881 Mdot
.6196 .6745 Mdot
.61176 .66665 Mdot
.62744 .67842 Mdot
.6196 .66665 Mdot
.63528 .67842 Mdot
.6392 .68626 Mdot
.65097 .6941 Mdot
.6392 .68626 Mdot
.64313 .68626 Mdot
.64705 .69018 Mdot
.64705 .6941 Mdot
.64313 .68626 Mdot
.65097 .69802 Mdot
.65489 .70194 Mdot
.66273 .71371 Mdot
.67057 .72155 Mdot
.6745 .71763 Mdot
.68626 .72547 Mdot
.67842 .71371 Mdot
.69018 .72547 Mdot
.69018 .72547 Mdot
.6941 .73332 Mdot
.70587 .73332 Mdot
.71371 .73332 Mdot
.71371 .72939 Mdot
.71763 .73724 Mdot
.72155 .74508 Mdot
.73332 .749 Mdot
.74116 .76076 Mdot
.73332 .75684 Mdot
.73332 .76076 Mdot
.72939 .75684 Mdot
.72939 .75684 Mdot
.74116 .76469 Mdot
.73724 .76076 Mdot
.749 .77645 Mdot
.76076 .79213 Mdot
.74116 .77253 Mdot
.74508 .76861 Mdot
.74508 .77253 Mdot
.74116 .76861 Mdot
.74508 .77645 Mdot
.74508 .76861 Mdot
.75292 .78037 Mdot
.75292 .78429 Mdot
.75684 .78821 Mdot
.75684 .78821 Mdot
.74508 .77645 Mdot
.75684 .78037 Mdot
.77253 .78429 Mdot
.77253 .78821 Mdot
.76861 .78037 Mdot
.76861 .78429 Mdot
.77253 .78821 Mdot
.76861 .78429 Mdot
.77253 .78821 Mdot
.76861 .78821 Mdot
.76469 .78821 Mdot
.76076 .78821 Mdot
.76469 .78821 Mdot
.76861 .78821 Mdot
.76469 .78429 Mdot
.76469 .78821 Mdot
.74508 .77253 Mdot
.74116 .76861 Mdot
.749 .78037 Mdot
.74508 .77645 Mdot
.74116 .77645 Mdot
.73332 .77253 Mdot
.72939 .76861 Mdot
.72547 .76469 Mdot
.8588 .88232 Mdot
.92546 .93722 Mdot
.4902 .55686 Mdot
.50588 .57646 Mdot
.52157 .59607 Mdot
.52549 .59215 Mdot
.51372 .58039 Mdot
.53333 .59607 Mdot
.53333 .59215 Mdot
.53725 .59999 Mdot
.52157 .58823 Mdot
.52549 .59215 Mdot
.53333 .59999 Mdot
.54117 .61176 Mdot
.54902 .6196 Mdot
.56862 .6392 Mdot
.57254 .6392 Mdot
.57254 .62744 Mdot
.58039 .63136 Mdot
.58039 .63528 Mdot
.58039 .6392 Mdot
.58431 .64313 Mdot
.59215 .64705 Mdot
.60783 .65881 Mdot
.61568 .66273 Mdot
.61568 .67057 Mdot
.60783 .65881 Mdot
.61176 .66665 Mdot
.62744 .6745 Mdot
.63136 .6745 Mdot
.63528 .67842 Mdot
.6392 .68234 Mdot
.6392 .68234 Mdot
.6392 .67842 Mdot
.63528 .6745 Mdot
.64313 .68234 Mdot
.64313 .68626 Mdot
.64705 .69018 Mdot
.65097 .6941 Mdot
.65881 .70979 Mdot
.65489 .70587 Mdot
.66273 .70587 Mdot
.6745 .70979 Mdot
.67842 .70979 Mdot
.68234 .71371 Mdot
.67842 .70979 Mdot
.69018 .72155 Mdot
.6941 .72155 Mdot
.70194 .72547 Mdot
.70979 .73724 Mdot
.70979 .73724 Mdot
.72155 .749 Mdot
.71371 .74508 Mdot
.72155 .75292 Mdot
.70587 .73724 Mdot
.71371 .75292 Mdot
.72939 .76469 Mdot
.72547 .76076 Mdot
.72155 .75292 Mdot
.74116 .76861 Mdot
.72547 .749 Mdot
.73332 .749 Mdot
.74508 .76861 Mdot
.74508 .77253 Mdot
.749 .78429 Mdot
.75684 .78429 Mdot
.749 .77253 Mdot
.75292 .78037 Mdot
.74508 .76861 Mdot
.749 .77645 Mdot
.75292 .78429 Mdot
.75684 .78429 Mdot
.75684 .78429 Mdot
.76076 .78821 Mdot
.76861 .78821 Mdot
.76861 .78821 Mdot
.77253 .79213 Mdot
.77253 .78821 Mdot
.77645 .79606 Mdot
.76469 .78037 Mdot
.77253 .78429 Mdot
.77645 .79213 Mdot
.77253 .78821 Mdot
.77645 .78821 Mdot
.77253 .78821 Mdot
.76861 .78429 Mdot
.77253 .78821 Mdot
.77645 .78821 Mdot
.77645 .79213 Mdot
.76469 .78429 Mdot
.76076 .78429 Mdot
.75292 .77645 Mdot
.75292 .78429 Mdot
.749 .77645 Mdot
.74508 .76861 Mdot
.74508 .78037 Mdot
.74508 .78037 Mdot
.72939 .77645 Mdot
.71371 .76469 Mdot
.65881 .69802 Mdot
.84311 .86664 Mdot
.47843 .54902 Mdot
.5098 .57646 Mdot
.51372 .58431 Mdot
.52157 .58823 Mdot
.52157 .58823 Mdot
.52941 .58823 Mdot
.53725 .59999 Mdot
.52941 .59215 Mdot
.52157 .58823 Mdot
.52549 .59999 Mdot
.53725 .61176 Mdot
.54117 .61568 Mdot
.54509 .62352 Mdot
.54902 .62352 Mdot
.55294 .62744 Mdot
.56078 .63136 Mdot
.5647 .62744 Mdot
.56862 .62744 Mdot
.56862 .62744 Mdot
.56862 .63136 Mdot
.59607 .65097 Mdot
.60391 .65489 Mdot
.59999 .64705 Mdot
.60391 .64705 Mdot
.60391 .64705 Mdot
.61568 .66665 Mdot
.6196 .6745 Mdot
.62744 .6745 Mdot
.63136 .67842 Mdot
.62744 .67842 Mdot
.62744 .68234 Mdot
.63528 .68626 Mdot
.6392 .68626 Mdot
.65097 .6941 Mdot
.65097 .69018 Mdot
.64705 .6941 Mdot
.64705 .6941 Mdot
.65097 .69802 Mdot
.65097 .69802 Mdot
.66665 .70194 Mdot
.6745 .70979 Mdot
.68626 .71763 Mdot
.68626 .71763 Mdot
.69802 .72547 Mdot
.69018 .71763 Mdot
.69802 .72939 Mdot
.69018 .72547 Mdot
.70194 .74116 Mdot
.70979 .749 Mdot
.71371 .74508 Mdot
.70979 .749 Mdot
.71371 .749 Mdot
.72155 .75684 Mdot
.71371 .74508 Mdot
.70587 .73724 Mdot
.71371 .74508 Mdot
.70979 .74508 Mdot
.72155 .75684 Mdot
.72547 .75684 Mdot
.73332 .76076 Mdot
.74508 .76861 Mdot
.74508 .76469 Mdot
.75292 .77645 Mdot
.75684 .77645 Mdot
.74508 .76469 Mdot
.749 .76469 Mdot
.74508 .76861 Mdot
.74508 .76469 Mdot
.75684 .78037 Mdot
.75292 .77645 Mdot
.75292 .77253 Mdot
.76469 .78821 Mdot
.78037 .79606 Mdot
.76861 .79213 Mdot
.76076 .78429 Mdot
.77253 .79998 Mdot
.77253 .79213 Mdot
.77645 .79213 Mdot
.77253 .78821 Mdot
.77253 .78429 Mdot
.77253 .78429 Mdot
.76076 .77645 Mdot
.77645 .79213 Mdot
.76469 .78037 Mdot
.76469 .77645 Mdot
.76076 .77645 Mdot
.76861 .78037 Mdot
.76469 .77253 Mdot
.77253 .78821 Mdot
.76076 .77645 Mdot
.76076 .77645 Mdot
.75684 .77253 Mdot
.75292 .77645 Mdot
.749 .77645 Mdot
.75292 .78429 Mdot
.74116 .77253 Mdot
.73332 .76861 Mdot
.72547 .76469 Mdot
.70979 .75292 Mdot
.70194 .749 Mdot
.77253 .80782 Mdot
.79998 .81958 Mdot
.47059 .54117 Mdot
.51372 .59215 Mdot
.52549 .59999 Mdot
.51765 .59215 Mdot
.52157 .59215 Mdot
.52157 .59215 Mdot
.52549 .58823 Mdot
.52549 .59607 Mdot
.51765 .58823 Mdot
.52941 .60391 Mdot
.53333 .61568 Mdot
.53725 .61568 Mdot
.53725 .6196 Mdot
.54117 .6196 Mdot
.54117 .61176 Mdot
.54509 .6196 Mdot
.55294 .6196 Mdot
.5647 .62744 Mdot
.56862 .62744 Mdot
.57646 .63528 Mdot
.58823 .6392 Mdot
.59607 .65097 Mdot
.60783 .65881 Mdot
.59999 .64705 Mdot
.60783 .65489 Mdot
.61176 .66273 Mdot
.61176 .67057 Mdot
.61568 .67057 Mdot
.6196 .67842 Mdot
.6196 .67842 Mdot
.62744 .68234 Mdot
.63528 .68234 Mdot
.65097 .69802 Mdot
.65489 .69802 Mdot
.65097 .6941 Mdot
.64705 .69018 Mdot
.65097 .6941 Mdot
.64705 .69802 Mdot
.65489 .70194 Mdot
.66273 .70194 Mdot
.66665 .69802 Mdot
.67842 .71371 Mdot
.68234 .71763 Mdot
.68234 .71763 Mdot
.68234 .71371 Mdot
.68626 .72547 Mdot
.68234 .72155 Mdot
.68626 .72155 Mdot
.69018 .72547 Mdot
.6941 .72939 Mdot
.70194 .73332 Mdot
.70587 .72939 Mdot
.70979 .73724 Mdot
.71371 .74508 Mdot
.71371 .74508 Mdot
.71371 .74508 Mdot
.71371 .74116 Mdot
.72155 .75292 Mdot
.72547 .75684 Mdot
.73332 .75684 Mdot
.73332 .749 Mdot
.73332 .749 Mdot
.74508 .76469 Mdot
.749 .76861 Mdot
.75292 .77645 Mdot
.75684 .78429 Mdot
.75292 .78037 Mdot
.74508 .76469 Mdot
.74116 .76469 Mdot
.75292 .77645 Mdot
.749 .77253 Mdot
.749 .77253 Mdot
.74116 .76076 Mdot
.75292 .77645 Mdot
.75292 .78037 Mdot
.75292 .78429 Mdot
.76469 .78821 Mdot
.76469 .78037 Mdot
.76861 .78037 Mdot
.75684 .77253 Mdot
.76469 .78037 Mdot
.75684 .78037 Mdot
.76076 .78821 Mdot
.76469 .78429 Mdot
.75684 .78037 Mdot
.76076 .77645 Mdot
.76861 .78821 Mdot
.75684 .77645 Mdot
.76861 .78821 Mdot
.76469 .77645 Mdot
.75684 .76861 Mdot
.76076 .77253 Mdot
.75292 .77253 Mdot
.74508 .77253 Mdot
.74508 .77253 Mdot
.74116 .76861 Mdot
.74508 .78037 Mdot
.73724 .78037 Mdot
.71371 .75684 Mdot
.70979 .75292 Mdot
.71371 .749 Mdot
.70979 .749 Mdot
.70194 .749 Mdot
.749 .78037 Mdot
.91761 .92546 Mdot
.49804 .57646 Mdot
.51372 .58823 Mdot
.52549 .60391 Mdot
.52157 .59607 Mdot
.52941 .60391 Mdot
.52941 .60391 Mdot
.51372 .58431 Mdot
.52157 .59999 Mdot
.52549 .60391 Mdot
.52549 .60391 Mdot
.52549 .59999 Mdot
.52941 .60783 Mdot
.54117 .62352 Mdot
.54902 .62744 Mdot
.55686 .63528 Mdot
.56078 .63528 Mdot
.56862 .6392 Mdot
.56862 .63136 Mdot
.57646 .63136 Mdot
.58431 .63136 Mdot
.58431 .63528 Mdot
.58823 .6392 Mdot
.59607 .64705 Mdot
.61176 .65881 Mdot
.60391 .65489 Mdot
.60783 .66665 Mdot
.61176 .6745 Mdot
.6196 .67842 Mdot
.63528 .68626 Mdot
.63528 .68234 Mdot
.6392 .68626 Mdot
.64313 .68626 Mdot
.64705 .68626 Mdot
.65881 .70194 Mdot
.66273 .70587 Mdot
.65881 .70587 Mdot
.65881 .70587 Mdot
.65881 .70587 Mdot
.65489 .69802 Mdot
.6745 .70979 Mdot
.6745 .70587 Mdot
.67842 .71371 Mdot
.6745 .71371 Mdot
.6745 .71371 Mdot
.67842 .71763 Mdot
.67842 .71763 Mdot
.68626 .72547 Mdot
.6941 .72547 Mdot
.69802 .72547 Mdot
.6941 .72155 Mdot
.70587 .73332 Mdot
.70979 .73332 Mdot
.71371 .73724 Mdot
.71371 .74508 Mdot
.70587 .74508 Mdot
.70587 .74508 Mdot
.71371 .74116 Mdot
.72939 .76076 Mdot
.72939 .75292 Mdot
.73332 .749 Mdot
.73724 .75684 Mdot
.73724 .75684 Mdot
.74116 .76469 Mdot
.73724 .76469 Mdot
.73332 .76469 Mdot
.73332 .76861 Mdot
.72547 .75684 Mdot
.74508 .76861 Mdot
.74508 .76861 Mdot
.74116 .76469 Mdot
.73724 .76076 Mdot
.749 .76861 Mdot
.749 .77253 Mdot
.74508 .76861 Mdot
.74116 .76469 Mdot
.75292 .77645 Mdot
.75292 .77645 Mdot
.76076 .79213 Mdot
.75684 .78429 Mdot
.75292 .78037 Mdot
.76076 .78429 Mdot
.76469 .78037 Mdot
.76076 .78037 Mdot
.76861 .78821 Mdot
.77645 .79213 Mdot
.77253 .78821 Mdot
.75684 .77645 Mdot
.76076 .77645 Mdot
.76861 .78429 Mdot
.76861 .78037 Mdot
.76076 .77645 Mdot
.75684 .77645 Mdot
.749 .77253 Mdot
.75684 .78037 Mdot
.749 .77645 Mdot
.749 .77645 Mdot
.74508 .77645 Mdot
.74508 .78037 Mdot
.74116 .77645 Mdot
.73332 .76076 Mdot
.73332 .76076 Mdot
.73332 .76076 Mdot
.72939 .76076 Mdot
.70979 .74116 Mdot
.70979 .74508 Mdot
.6941 .74116 Mdot
.83135 .85095 Mdot
.90193 .90585 Mdot
.47843 .54902 Mdot
.51372 .58823 Mdot
.52157 .59999 Mdot
.52157 .59607 Mdot
.52549 .59607 Mdot
.52549 .60391 Mdot
.52549 .60391 Mdot
.53333 .61568 Mdot
.52157 .60391 Mdot
.53725 .61568 Mdot
.53725 .61568 Mdot
.53725 .61568 Mdot
.54509 .62744 Mdot
.55686 .6392 Mdot
.5647 .64313 Mdot
.56078 .6392 Mdot
.5647 .6392 Mdot
.57646 .6392 Mdot
.58039 .64313 Mdot
.58039 .64313 Mdot
.58039 .64313 Mdot
.59215 .65489 Mdot
.59215 .65489 Mdot
.60391 .66273 Mdot
.61176 .67057 Mdot
.61568 .6745 Mdot
.62352 .68234 Mdot
.62352 .68234 Mdot
.6392 .69018 Mdot
.65097 .70194 Mdot
.65097 .69018 Mdot
.64313 .68234 Mdot
.65489 .6941 Mdot
.66273 .70587 Mdot
.66273 .70587 Mdot
.66665 .71371 Mdot
.67057 .71371 Mdot
.67057 .71763 Mdot
.66665 .71763 Mdot
.67057 .72547 Mdot
.6745 .72547 Mdot
.67842 .73332 Mdot
.66665 .71371 Mdot
.67842 .72547 Mdot
.68626 .72939 Mdot
.68234 .72939 Mdot
.68626 .72155 Mdot
.69802 .72939 Mdot
.70194 .72547 Mdot
.70587 .72547 Mdot
.70979 .73332 Mdot
.71371 .73724 Mdot
.72547 .75292 Mdot
.71763 .74116 Mdot
.71763 .74508 Mdot
.72547 .76076 Mdot
.72547 .75684 Mdot
.73724 .76861 Mdot
.72547 .76076 Mdot
.72155 .75292 Mdot
.72155 .75292 Mdot
.72939 .76076 Mdot
.73332 .76861 Mdot
.73332 .76861 Mdot
.73332 .76861 Mdot
.73332 .76469 Mdot
.74116 .76861 Mdot
.749 .78037 Mdot
.75292 .77253 Mdot
.75684 .77645 Mdot
.75684 .77645 Mdot
.76469 .78429 Mdot
.749 .76861 Mdot
.75684 .78037 Mdot
.76469 .79213 Mdot
.76076 .78821 Mdot
.75684 .78429 Mdot
.76469 .79998 Mdot
.76469 .79606 Mdot
.76861 .79998 Mdot
.77253 .8039 Mdot
.76861 .79998 Mdot
.76469 .79213 Mdot
.76076 .79213 Mdot
.76076 .78429 Mdot
.76469 .78821 Mdot
.75684 .78429 Mdot
.76076 .78821 Mdot
.76076 .78429 Mdot
.76076 .78821 Mdot
.749 .77253 Mdot
.75684 .77645 Mdot
.75292 .77645 Mdot
.76469 .78429 Mdot
.76469 .78821 Mdot
.76076 .78429 Mdot
.75684 .78429 Mdot
.75292 .77645 Mdot
.76076 .78429 Mdot
.76076 .78429 Mdot
.75684 .78037 Mdot
.749 .77645 Mdot
.749 .77645 Mdot
.74508 .76861 Mdot
.74116 .77253 Mdot
.73332 .76469 Mdot
.71763 .749 Mdot
.70587 .73724 Mdot
.66665 .70194 Mdot
.82743 .85095 Mdot
.47059 .54117 Mdot
.50196 .57254 Mdot
.51765 .58823 Mdot
.51765 .58823 Mdot
.51372 .58431 Mdot
.52941 .60391 Mdot
.52157 .59999 Mdot
.52549 .59607 Mdot
.52157 .59607 Mdot
.52941 .59999 Mdot
.54902 .6196 Mdot
.54902 .6196 Mdot
.54902 .62352 Mdot
.55686 .63528 Mdot
.57254 .64313 Mdot
.56862 .6392 Mdot
.56078 .62352 Mdot
.56078 .62352 Mdot
.56078 .62744 Mdot
.56862 .6392 Mdot
.57646 .64313 Mdot
.58431 .65097 Mdot
.59607 .65881 Mdot
.59607 .65489 Mdot
.60783 .67057 Mdot
.60783 .67057 Mdot
.61176 .6745 Mdot
.62352 .67842 Mdot
.63136 .68626 Mdot
.63528 .68626 Mdot
.65097 .69018 Mdot
.63528 .6745 Mdot
.64705 .69018 Mdot
.65881 .69802 Mdot
.66273 .70194 Mdot
.66665 .70979 Mdot
.66665 .70979 Mdot
.6745 .71371 Mdot
.6745 .71371 Mdot
.67057 .72155 Mdot
.6745 .72547 Mdot
.66665 .71763 Mdot
.66665 .71763 Mdot
.67842 .71763 Mdot
.6941 .72547 Mdot
.69802 .72939 Mdot
.70587 .73332 Mdot
.70979 .72939 Mdot
.70587 .72939 Mdot
.70979 .73332 Mdot
.71763 .73724 Mdot
.71763 .72939 Mdot
.72155 .73332 Mdot
.71371 .72939 Mdot
.72155 .73724 Mdot
.72939 .75292 Mdot
.72939 .75292 Mdot
.73332 .75684 Mdot
.73332 .75292 Mdot
.73332 .75684 Mdot
.73332 .75684 Mdot
.73332 .76076 Mdot
.73724 .77253 Mdot
.74116 .77253 Mdot
.72939 .76076 Mdot
.749 .77253 Mdot
.74116 .76076 Mdot
.75292 .77253 Mdot
.749 .76861 Mdot
.749 .76469 Mdot
.749 .76469 Mdot
.75292 .77253 Mdot
.749 .76861 Mdot
.76469 .78037 Mdot
.75684 .77645 Mdot
.75292 .77253 Mdot
.75684 .78429 Mdot
.75292 .78037 Mdot
.75684 .78429 Mdot
.76861 .78821 Mdot
.77253 .78821 Mdot
.77645 .79606 Mdot
.76469 .78429 Mdot
.76076 .78429 Mdot
.75684 .78037 Mdot
.75684 .78037 Mdot
.75684 .78821 Mdot
.75684 .78429 Mdot
.75684 .78429 Mdot
.76469 .79213 Mdot
.75684 .78037 Mdot
.75684 .78037 Mdot
.76469 .78037 Mdot
.76861 .78429 Mdot
.77253 .78821 Mdot
.77253 .78429 Mdot
.76469 .78037 Mdot
.76469 .78037 Mdot
.76861 .78429 Mdot
.76076 .77645 Mdot
.75684 .78037 Mdot
.75292 .77645 Mdot
.75292 .77645 Mdot
.749 .76861 Mdot
.74508 .76861 Mdot
.73724 .76076 Mdot
.73332 .75684 Mdot
.72155 .74508 Mdot
.71371 .73724 Mdot
.70979 .74116 Mdot
.65881 .69018 Mdot
.72155 .74508 Mdot
.77645 .78821 Mdot
.47451 .54509 Mdot
.50588 .57254 Mdot
.52549 .58823 Mdot
.52549 .58823 Mdot
.50196 .56862 Mdot
.50588 .57254 Mdot
.50196 .58039 Mdot
.51372 .58823 Mdot
.52549 .59999 Mdot
.53725 .60783 Mdot
.53725 .59999 Mdot
.53725 .60391 Mdot
.53725 .60783 Mdot
.54117 .61568 Mdot
.55294 .6196 Mdot
.56078 .6196 Mdot
.57646 .62744 Mdot
.56078 .61568 Mdot
.5647 .62352 Mdot
.5647 .63136 Mdot
.57646 .64705 Mdot
.58431 .65489 Mdot
.58431 .64705 Mdot
.59607 .65489 Mdot
.59607 .65489 Mdot
.59215 .65489 Mdot
.60783 .67057 Mdot
.62352 .67842 Mdot
.62744 .67842 Mdot
.62744 .67057 Mdot
.63136 .67057 Mdot
.63136 .67057 Mdot
.64313 .68626 Mdot
.65097 .69018 Mdot
.65881 .69018 Mdot
.66273 .6941 Mdot
.65881 .6941 Mdot
.65489 .6941 Mdot
.65489 .6941 Mdot
.66665 .70979 Mdot
.66665 .70979 Mdot
.67057 .71371 Mdot
.67842 .72155 Mdot
.68234 .71763 Mdot
.6941 .71763 Mdot
.6941 .72155 Mdot
.70194 .72547 Mdot
.70587 .72939 Mdot
.70194 .72547 Mdot
.70587 .72939 Mdot
.71371 .73332 Mdot
.71763 .74116 Mdot
.72155 .74116 Mdot
.71371 .73332 Mdot
.70979 .73332 Mdot
.70979 .73332 Mdot
.71763 .74116 Mdot
.72155 .75292 Mdot
.72155 .75292 Mdot
.72547 .75292 Mdot
.71763 .74508 Mdot
.71763 .74508 Mdot
.72939 .75684 Mdot
.72939 .74116 Mdot
.72939 .74508 Mdot
.73332 .749 Mdot
.73724 .75684 Mdot
.74116 .76076 Mdot
.74508 .76469 Mdot
.75292 .77253 Mdot
.749 .76469 Mdot
.75684 .76469 Mdot
.76469 .77253 Mdot
.76076 .77253 Mdot
.75684 .76469 Mdot
.76469 .77645 Mdot
.75684 .77645 Mdot
.75684 .78037 Mdot
.76076 .78037 Mdot
.76076 .77645 Mdot
.76469 .78429 Mdot
.76469 .78821 Mdot
.75292 .78037 Mdot
.75684 .78429 Mdot
.74508 .76861 Mdot
.74508 .76469 Mdot
.74508 .76469 Mdot
.75292 .78429 Mdot
.75684 .78037 Mdot
.749 .77253 Mdot
.75292 .78037 Mdot
.749 .77253 Mdot
.749 .77253 Mdot
.76469 .78429 Mdot
.76469 .77645 Mdot
.76076 .76861 Mdot
.76076 .77645 Mdot
.75684 .77645 Mdot
.75684 .77253 Mdot
.75684 .77253 Mdot
.75292 .77253 Mdot
.73724 .76076 Mdot
.74116 .76076 Mdot
.72547 .74508 Mdot
.72155 .74116 Mdot
.73724 .75684 Mdot
.72939 .75292 Mdot
.72939 .75292 Mdot
.72547 .74508 Mdot
.72155 .74116 Mdot
.71371 .72939 Mdot
.70194 .72155 Mdot
.6941 .71763 Mdot
.62744 .65097 Mdot
.70587 .73332 Mdot
.90585 .91761 Mdot
.45883 .54117 Mdot
.49412 .57254 Mdot
.5098 .58039 Mdot
.51372 .57646 Mdot
.5098 .57646 Mdot
.49804 .5647 Mdot
.50196 .58039 Mdot
.49804 .58039 Mdot
.51765 .59215 Mdot
.51765 .59215 Mdot
.52941 .59999 Mdot
.53333 .59999 Mdot
.52941 .60391 Mdot
.53333 .61176 Mdot
.54117 .60783 Mdot
.54902 .61176 Mdot
.55686 .6196 Mdot
.56078 .61568 Mdot
.56862 .62744 Mdot
.55686 .6196 Mdot
.56078 .62744 Mdot
.57254 .6392 Mdot
.57254 .62744 Mdot
.58823 .64313 Mdot
.58823 .64313 Mdot
.59215 .64705 Mdot
.60391 .65881 Mdot
.61568 .67057 Mdot
.62352 .67057 Mdot
.62744 .66665 Mdot
.63136 .66665 Mdot
.63528 .67057 Mdot
.63528 .6745 Mdot
.63528 .6745 Mdot
.65097 .67842 Mdot
.65881 .68626 Mdot
.66273 .6941 Mdot
.66273 .70194 Mdot
.66665 .70587 Mdot
.67057 .70587 Mdot
.6745 .70587 Mdot
.66665 .69802 Mdot
.6745 .70587 Mdot
.67842 .70587 Mdot
.69802 .72155 Mdot
.69018 .71763 Mdot
.70194 .72547 Mdot
.70194 .72547 Mdot
.70194 .72547 Mdot
.70587 .72939 Mdot
.70587 .72547 Mdot
.70979 .72939 Mdot
.72155 .74116 Mdot
.72155 .73724 Mdot
.71371 .73332 Mdot
.70587 .72155 Mdot
.70587 .72547 Mdot
.70979 .73332 Mdot
.71371 .73724 Mdot
.70979 .73724 Mdot
.70979 .74116 Mdot
.71371 .73724 Mdot
.71763 .73332 Mdot
.72939 .74116 Mdot
.73724 .75292 Mdot
.72547 .73724 Mdot
.72939 .74116 Mdot
.73724 .749 Mdot
.74508 .75684 Mdot
.749 .76076 Mdot
.749 .749 Mdot
.749 .749 Mdot
.749 .749 Mdot
.76076 .75684 Mdot
.75292 .749 Mdot
.75684 .76076 Mdot
.75292 .76076 Mdot
.74508 .75684 Mdot
.75292 .77253 Mdot
.76469 .78037 Mdot
.75684 .78037 Mdot
.75684 .77645 Mdot
.74508 .76469 Mdot
.74508 .76861 Mdot
.74508 .76861 Mdot
.74508 .76469 Mdot
.749 .76469 Mdot
.75292 .77253 Mdot
.76861 .77645 Mdot
.76469 .77253 Mdot
.75684 .77253 Mdot
.749 .76469 Mdot
.749 .77253 Mdot
.749 .77253 Mdot
.76861 .78037 Mdot
.76469 .76861 Mdot
.75684 .76469 Mdot
.75684 .77253 Mdot
.74508 .76076 Mdot
.74116 .76469 Mdot
.73332 .75684 Mdot
.72939 .75292 Mdot
.74508 .76861 Mdot
.73332 .75292 Mdot
.72939 .74508 Mdot
.72939 .749 Mdot
.73332 .749 Mdot
.73332 .75684 Mdot
.72155 .73724 Mdot
.72155 .73724 Mdot
.71371 .73332 Mdot
.70587 .72939 Mdot
.70587 .73332 Mdot
.6941 .72547 Mdot
.68234 .71371 Mdot
.67057 .70587 Mdot
.65489 .70194 Mdot
.8235 .84311 Mdot
.84311 .83919 Mdot
.47059 .55686 Mdot
.48628 .57254 Mdot
.5098 .58823 Mdot
.5098 .58431 Mdot
.50196 .57254 Mdot
.50196 .57254 Mdot
.50196 .57646 Mdot
.51372 .58823 Mdot
.51372 .58823 Mdot
.52157 .59215 Mdot
.53333 .59999 Mdot
.54902 .61568 Mdot
.54509 .60783 Mdot
.55294 .62352 Mdot
.54509 .60783 Mdot
.55294 .60783 Mdot
.56078 .6196 Mdot
.56862 .6196 Mdot
.57254 .62744 Mdot
.57646 .63136 Mdot
.58431 .6392 Mdot
.58431 .64313 Mdot
.59215 .64705 Mdot
.58431 .6392 Mdot
.58431 .64313 Mdot
.58823 .6392 Mdot
.60391 .65489 Mdot
.61568 .66665 Mdot
.62352 .6745 Mdot
.62744 .67057 Mdot
.62744 .65881 Mdot
.6392 .66273 Mdot
.64313 .66665 Mdot
.64705 .67057 Mdot
.64313 .66665 Mdot
.66665 .69018 Mdot
.6745 .70587 Mdot
.6745 .69802 Mdot
.67057 .69802 Mdot
.67057 .70194 Mdot
.67842 .70979 Mdot
.67842 .70587 Mdot
.67842 .70194 Mdot
.6941 .71371 Mdot
.68626 .70979 Mdot
.6941 .71371 Mdot
.70194 .72155 Mdot
.70587 .72155 Mdot
.70587 .71763 Mdot
.70587 .72155 Mdot
.70979 .72547 Mdot
.71763 .72939 Mdot
.71371 .72155 Mdot
.72547 .74116 Mdot
.71371 .73724 Mdot
.70979 .72939 Mdot
.71371 .73724 Mdot
.70587 .72155 Mdot
.71763 .73332 Mdot
.72155 .74508 Mdot
.72547 .75292 Mdot
.71371 .73724 Mdot
.71763 .74116 Mdot
.71763 .74116 Mdot
.72939 .749 Mdot
.73724 .75292 Mdot
.73332 .75292 Mdot
.73724 .75292 Mdot
.74116 .749 Mdot
.749 .75292 Mdot
.75684 .75684 Mdot
.75292 .75292 Mdot
.75292 .75292 Mdot
.76076 .75292 Mdot
.76076 .75684 Mdot
.75684 .75292 Mdot
.76076 .75684 Mdot
.75684 .75684 Mdot
.749 .75292 Mdot
.75292 .76469 Mdot
.75684 .76861 Mdot
.75292 .77253 Mdot
.74116 .76076 Mdot
.74508 .76469 Mdot
.74508 .76469 Mdot
.75684 .76469 Mdot
.75292 .76076 Mdot
.75684 .76469 Mdot
.76469 .76861 Mdot
.76861 .77645 Mdot
.76469 .77253 Mdot
.76076 .77253 Mdot
.76469 .77645 Mdot
.76076 .76861 Mdot
.76469 .77253 Mdot
.76469 .77253 Mdot
.76076 .76469 Mdot
.75684 .76076 Mdot
.74116 .75292 Mdot
.74116 .76076 Mdot
.74116 .76076 Mdot
.73724 .75684 Mdot
.73332 .75684 Mdot
.73332 .75292 Mdot
.73724 .75684 Mdot
.72939 .75292 Mdot
.72939 .75292 Mdot
.72547 .749 Mdot
.72939 .75292 Mdot
.72547 .74508 Mdot
.72155 .74116 Mdot
.70979 .72939 Mdot
.70587 .72939 Mdot
.70979 .72939 Mdot
.70194 .72547 Mdot
.69018 .71763 Mdot
.68234 .71763 Mdot
.68234 .71763 Mdot
.57254 .59215 Mdot
.56862 .59999 Mdot
.61176 .59999 Mdot
.45883 .52941 Mdot
.50196 .58039 Mdot
.50588 .58431 Mdot
.51372 .59215 Mdot
.49804 .57646 Mdot
.50196 .57254 Mdot
.50196 .56862 Mdot
.51372 .58431 Mdot
.51765 .58039 Mdot
.51372 .58039 Mdot
.52941 .58823 Mdot
.53725 .59215 Mdot
.53725 .59607 Mdot
.54902 .60391 Mdot
.54902 .61176 Mdot
.54902 .60783 Mdot
.55686 .60391 Mdot
.5647 .60391 Mdot
.57254 .61568 Mdot
.58431 .63136 Mdot
.59215 .6392 Mdot
.58823 .63136 Mdot
.59215 .6392 Mdot
.59215 .64313 Mdot
.59999 .65489 Mdot
.60391 .65097 Mdot
.60783 .65489 Mdot
.60783 .65489 Mdot
.60783 .64705 Mdot
.61568 .65881 Mdot
.61568 .64705 Mdot
.63528 .65489 Mdot
.64705 .66273 Mdot
.65097 .66273 Mdot
.65489 .66273 Mdot
.66273 .6745 Mdot
.67057 .68234 Mdot
.6745 .69018 Mdot
.67842 .6941 Mdot
.69018 .71371 Mdot
.68626 .71371 Mdot
.68626 .70979 Mdot
.69018 .71371 Mdot
.69802 .71763 Mdot
.69018 .70587 Mdot
.6941 .70979 Mdot
.6941 .70979 Mdot
.70194 .71763 Mdot
.70587 .71763 Mdot
.70587 .71763 Mdot
.70979 .72155 Mdot
.70587 .71763 Mdot
.70979 .72547 Mdot
.70979 .72547 Mdot
.71371 .72939 Mdot
.70587 .72547 Mdot
.71371 .73332 Mdot
.72547 .73724 Mdot
.71763 .72547 Mdot
.72547 .73724 Mdot
.72939 .74508 Mdot
.72939 .74116 Mdot
.72547 .73332 Mdot
.72547 .73332 Mdot
.72547 .73724 Mdot
.72939 .74508 Mdot
.73724 .749 Mdot
.73724 .75684 Mdot
.73724 .75684 Mdot
.74508 .76076 Mdot
.74508 .76076 Mdot
.749 .75292 Mdot
.74508 .74508 Mdot
.73332 .72547 Mdot
.75292 .75292 Mdot
.75684 .75292 Mdot
.75292 .749 Mdot
.749 .74508 Mdot
.75292 .75292 Mdot
.75292 .75684 Mdot
.749 .75292 Mdot
.74116 .75292 Mdot
.74116 .75684 Mdot
.74116 .75684 Mdot
.74508 .76469 Mdot
.73724 .75292 Mdot
.75292 .76076 Mdot
.76076 .76076 Mdot
.75684 .76076 Mdot
.75292 .75684 Mdot
.75292 .76469 Mdot
.75292 .76861 Mdot
.75684 .76469 Mdot
.75292 .76076 Mdot
.75292 .75684 Mdot
.749 .75292 Mdot
.74508 .749 Mdot
.749 .75292 Mdot
.74116 .749 Mdot
.72939 .74508 Mdot
.72939 .75684 Mdot
.73332 .76076 Mdot
.74116 .76469 Mdot
.73332 .75684 Mdot
.73332 .749 Mdot
.72939 .749 Mdot
.72939 .749 Mdot
.72939 .75292 Mdot
.73332 .76076 Mdot
.73332 .75292 Mdot
.73332 .75292 Mdot
.72547 .74508 Mdot
.72155 .73724 Mdot
.71763 .73332 Mdot
.70979 .72939 Mdot
.70587 .72155 Mdot
.69802 .71763 Mdot
.68626 .71763 Mdot
.6745 .71371 Mdot
.66665 .70587 Mdot
.56862 .59999 Mdot
.3608 .3608 Mdot
.52157 .51372 Mdot
.58039 .55686 Mdot
.45883 .52549 Mdot
.48235 .55686 Mdot
.49412 .5647 Mdot
.49412 .5647 Mdot
.4902 .56078 Mdot
.48628 .55686 Mdot
.49804 .5647 Mdot
.50196 .57254 Mdot
.5098 .58039 Mdot
.51372 .58039 Mdot
.52549 .59215 Mdot
.53333 .59215 Mdot
.53333 .58823 Mdot
.55294 .61176 Mdot
.54902 .61176 Mdot
.55686 .61568 Mdot
.56078 .61568 Mdot
.56862 .6196 Mdot
.57254 .6196 Mdot
.57254 .62744 Mdot
.58431 .63528 Mdot
.58823 .63528 Mdot
.59607 .6392 Mdot
.58823 .63528 Mdot
.59999 .64313 Mdot
.60391 .65489 Mdot
.60391 .65489 Mdot
.59607 .64313 Mdot
.60783 .65489 Mdot
.61568 .65881 Mdot
.62744 .66273 Mdot
.63136 .66665 Mdot
.64313 .67057 Mdot
.65097 .66665 Mdot
.65881 .67842 Mdot
.65097 .66665 Mdot
.65097 .66665 Mdot
.65881 .6745 Mdot
.66273 .68234 Mdot
.66665 .69018 Mdot
.66665 .6941 Mdot
.6745 .70587 Mdot
.68234 .70979 Mdot
.68626 .70979 Mdot
.69018 .71763 Mdot
.68626 .71763 Mdot
.68626 .71763 Mdot
.68626 .72155 Mdot
.6941 .72939 Mdot
.69802 .72939 Mdot
.69802 .72547 Mdot
.69802 .72155 Mdot
.69802 .72155 Mdot
.70587 .73332 Mdot
.70587 .73332 Mdot
.70194 .72547 Mdot
.70979 .73724 Mdot
.71763 .73724 Mdot
.72155 .72547 Mdot
.72547 .72939 Mdot
.72939 .73332 Mdot
.72547 .72939 Mdot
.72939 .73724 Mdot
.72155 .72939 Mdot
.72547 .73724 Mdot
.72939 .749 Mdot
.72939 .75684 Mdot
.72939 .75684 Mdot
.72939 .749 Mdot
.73332 .75684 Mdot
.73332 .75684 Mdot
.74116 .76469 Mdot
.73332 .75292 Mdot
.74116 .75684 Mdot
.74116 .75684 Mdot
.74508 .76469 Mdot
.73724 .75684 Mdot
.74116 .749 Mdot
.74116 .75684 Mdot
.74508 .76076 Mdot
.74116 .76469 Mdot
.74116 .76469 Mdot
.74116 .76469 Mdot
.72939 .749 Mdot
.73724 .75684 Mdot
.74508 .76861 Mdot
.75292 .76861 Mdot
.75292 .76076 Mdot
.75684 .75684 Mdot
.76076 .76861 Mdot
.73724 .749 Mdot
.74508 .76469 Mdot
.74116 .76076 Mdot
.75292 .77253 Mdot
.75684 .76861 Mdot
.749 .76076 Mdot
.74508 .76076 Mdot
.74116 .75292 Mdot
.74508 .76076 Mdot
.74508 .76861 Mdot
.72939 .75292 Mdot
.72547 .75684 Mdot
.72547 .76076 Mdot
.72155 .749 Mdot
.72547 .74508 Mdot
.72155 .73332 Mdot
.71763 .72939 Mdot
.71371 .72939 Mdot
.72155 .74116 Mdot
.72155 .74508 Mdot
.71763 .73332 Mdot
.71763 .73724 Mdot
.71763 .74116 Mdot
.70979 .73332 Mdot
.70587 .72939 Mdot
.70587 .72547 Mdot
.70194 .72155 Mdot
.69802 .72155 Mdot
.68626 .71371 Mdot
.6745 .70587 Mdot
.67842 .71763 Mdot
.65881 .69802 Mdot
.57254 .59999 Mdot
.19218 .14513 Mdot
.22747 .19218 Mdot
.59999 .58431 Mdot
.79606 .78821 Mdot
.47843 .54509 Mdot
.50196 .57254 Mdot
.50196 .57646 Mdot
.50196 .57254 Mdot
.49412 .56078 Mdot
.48628 .55294 Mdot
.50588 .58039 Mdot
.50588 .57646 Mdot
.5098 .58039 Mdot
.5098 .57646 Mdot
.52549 .58431 Mdot
.52549 .58039 Mdot
.54117 .59607 Mdot
.54509 .60391 Mdot
.53333 .59215 Mdot
.54902 .60391 Mdot
.56078 .61176 Mdot
.56862 .62352 Mdot
.5647 .62352 Mdot
.5647 .62352 Mdot
.5647 .62744 Mdot
.57646 .63528 Mdot
.58039 .63136 Mdot
.58039 .63136 Mdot
.58039 .63528 Mdot
.58823 .63136 Mdot
.59215 .64313 Mdot
.59607 .64705 Mdot
.60783 .65489 Mdot
.60783 .65489 Mdot
.60391 .64705 Mdot
.61176 .65097 Mdot
.63136 .66665 Mdot
.63528 .66665 Mdot
.64705 .67057 Mdot
.65097 .6745 Mdot
.65097 .6745 Mdot
.65489 .6745 Mdot
.65097 .67057 Mdot
.65881 .68626 Mdot
.65881 .69018 Mdot
.66273 .6941 Mdot
.67057 .70194 Mdot
.68234 .70979 Mdot
.6745 .70194 Mdot
.6745 .70587 Mdot
.6745 .70587 Mdot
.68626 .72547 Mdot
.69802 .73332 Mdot
.69802 .73332 Mdot
.6941 .72547 Mdot
.70194 .72939 Mdot
.70587 .72939 Mdot
.70587 .73332 Mdot
.70194 .72939 Mdot
.6941 .72939 Mdot
.69802 .72547 Mdot
.70194 .72939 Mdot
.70587 .72939 Mdot
.71371 .73332 Mdot
.71763 .73724 Mdot
.71371 .73332 Mdot
.72155 .73332 Mdot
.72547 .74116 Mdot
.71371 .73724 Mdot
.70587 .73332 Mdot
.72155 .75292 Mdot
.71763 .74508 Mdot
.71371 .74116 Mdot
.71371 .74116 Mdot
.71763 .74508 Mdot
.71763 .749 Mdot
.71763 .74508 Mdot
.72547 .74116 Mdot
.72939 .749 Mdot
.72939 .749 Mdot
.73332 .75684 Mdot
.73332 .749 Mdot
.73332 .75292 Mdot
.73332 .75292 Mdot
.73724 .76076 Mdot
.72939 .75684 Mdot
.72939 .76469 Mdot
.72155 .75684 Mdot
.72547 .75292 Mdot
.72939 .75292 Mdot
.73332 .75292 Mdot
.73332 .74508 Mdot
.749 .75292 Mdot
.74116 .74508 Mdot
.73724 .749 Mdot
.73332 .749 Mdot
.73332 .749 Mdot
.73332 .749 Mdot
.72939 .74508 Mdot
.72939 .74508 Mdot
.73332 .749 Mdot
.73332 .749 Mdot
.73332 .75292 Mdot
.73332 .76076 Mdot
.73332 .76076 Mdot
.73332 .76076 Mdot
.72155 .75684 Mdot
.72155 .74508 Mdot
.72547 .74116 Mdot
.72547 .74116 Mdot
.72547 .74508 Mdot
.72155 .74508 Mdot
.71763 .74508 Mdot
.71763 .74508 Mdot
.70979 .73724 Mdot
.70587 .73724 Mdot
.70979 .74508 Mdot
.70587 .73724 Mdot
.69802 .72547 Mdot
.69802 .72547 Mdot
.68234 .70979 Mdot
.6745 .70979 Mdot
.67057 .70587 Mdot
.66273 .70194 Mdot
.65881 .69802 Mdot
.65489 .6941 Mdot
.66273 .70587 Mdot
.44314 .44706 Mdot
.30198 .28629 Mdot
.21963 .18826 Mdot
.20787 .1765 Mdot
.19218 .15689 Mdot
.59215 .57646 Mdot
.78821 .78037 Mdot
.47059 .53333 Mdot
.4902 .55686 Mdot
.4902 .55686 Mdot
.49804 .5647 Mdot
.49412 .55686 Mdot
.48628 .54902 Mdot
.49412 .5647 Mdot
.50588 .57646 Mdot
.50196 .56862 Mdot
.51372 .57254 Mdot
.52941 .58823 Mdot
.54902 .60391 Mdot
.54117 .59607 Mdot
.54902 .60783 Mdot
.54902 .60783 Mdot
.55294 .60783 Mdot
.55686 .61176 Mdot
.56078 .6196 Mdot
.5647 .62352 Mdot
.57254 .63136 Mdot
.5647 .62744 Mdot
.57646 .6392 Mdot
.58431 .64705 Mdot
.58431 .6392 Mdot
.58431 .63528 Mdot
.58039 .62744 Mdot
.58431 .62744 Mdot
.59215 .63528 Mdot
.60391 .64705 Mdot
.61176 .66273 Mdot
.59999 .64705 Mdot
.59607 .64313 Mdot
.61176 .65489 Mdot
.62352 .66273 Mdot
.63136 .66273 Mdot
.6392 .66665 Mdot
.64705 .66665 Mdot
.65097 .6745 Mdot
.65097 .68234 Mdot
.64313 .67842 Mdot
.65097 .68234 Mdot
.64705 .68234 Mdot
.65489 .68626 Mdot
.66665 .69802 Mdot
.66665 .69802 Mdot
.67057 .70979 Mdot
.67057 .71371 Mdot
.67842 .72155 Mdot
.6745 .70587 Mdot
.68626 .71763 Mdot
.6941 .72155 Mdot
.70194 .72547 Mdot
.70979 .72155 Mdot
.70194 .71371 Mdot
.69802 .71763 Mdot
.6941 .72547 Mdot
.69018 .72547 Mdot
.69802 .73332 Mdot
.6941 .72547 Mdot
.70194 .72547 Mdot
.70194 .72939 Mdot
.6941 .72547 Mdot
.69802 .72155 Mdot
.70587 .72939 Mdot
.71371 .73332 Mdot
.70979 .73724 Mdot
.71371 .73724 Mdot
.71371 .74508 Mdot
.71371 .74116 Mdot
.71763 .74508 Mdot
.72939 .75684 Mdot
.72547 .75292 Mdot
.71763 .749 Mdot
.72155 .74508 Mdot
.72547 .74116 Mdot
.72547 .73724 Mdot
.72939 .749 Mdot
.73332 .749 Mdot
.72939 .74508 Mdot
.73724 .74116 Mdot
.73724 .74508 Mdot
.73724 .75292 Mdot
.72547 .749 Mdot
.72547 .75684 Mdot
.72155 .75292 Mdot
.72155 .75292 Mdot
.72547 .75292 Mdot
.72939 .74508 Mdot
.72939 .74116 Mdot
.73332 .74508 Mdot
.73724 .75292 Mdot
.72939 .74116 Mdot
.72939 .74116 Mdot
.72939 .74116 Mdot
.73332 .749 Mdot
.72155 .73724 Mdot
.73332 .74508 Mdot
.73724 .749 Mdot
.72547 .74116 Mdot
.72155 .74116 Mdot
.71763 .73724 Mdot
.72155 .74116 Mdot
.72939 .74508 Mdot
.72547 .74508 Mdot
.72155 .73724 Mdot
.72547 .74508 Mdot
.71371 .74116 Mdot
.70194 .73724 Mdot
.70587 .74508 Mdot
.70979 .749 Mdot
.69802 .74116 Mdot
.69802 .73724 Mdot
.6941 .73724 Mdot
.6941 .72939 Mdot
.6941 .72547 Mdot
.70587 .73724 Mdot
.6941 .72547 Mdot
.68234 .71763 Mdot
.6745 .70587 Mdot
.67057 .70194 Mdot
.66665 .70587 Mdot
.66273 .70194 Mdot
.66273 .70587 Mdot
.64313 .68626 Mdot
.55294 .58039 Mdot
.31766 .30982 Mdot
.27845 .26276 Mdot
.26668 .25492 Mdot
.23139 .21179 Mdot
.20002 .18434 Mdot
.3608 .34903 Mdot
.58431 .58431 Mdot
.45491 .51765 Mdot
.47843 .53725 Mdot
.4902 .55686 Mdot
.49804 .56078 Mdot
.49804 .55686 Mdot
.49804 .55686 Mdot
.49412 .56078 Mdot
.49412 .55686 Mdot
.50196 .56862 Mdot
.5098 .57254 Mdot
.52157 .57646 Mdot
.54509 .59999 Mdot
.54117 .59215 Mdot
.52941 .58823 Mdot
.54509 .60391 Mdot
.5647 .62352 Mdot
.57254 .6196 Mdot
.56078 .60783 Mdot
.55686 .61176 Mdot
.5647 .6196 Mdot
.5647 .62352 Mdot
.5647 .62352 Mdot
.57254 .62744 Mdot
.58039 .62744 Mdot
.58823 .63136 Mdot
.58431 .62744 Mdot
.59215 .63136 Mdot
.59607 .63528 Mdot
.61176 .65097 Mdot
.59999 .64313 Mdot
.61176 .65097 Mdot
.62352 .65881 Mdot
.62744 .66665 Mdot
.62352 .65881 Mdot
.6392 .66273 Mdot
.63528 .65881 Mdot
.64705 .67057 Mdot
.65489 .67842 Mdot
.64313 .6745 Mdot
.64313 .67842 Mdot
.64705 .68626 Mdot
.64313 .68234 Mdot
.65489 .69018 Mdot
.65881 .69018 Mdot
.66665 .70194 Mdot
.66665 .69802 Mdot
.67057 .70587 Mdot
.68234 .71371 Mdot
.68626 .71371 Mdot
.69802 .72155 Mdot
.6941 .71763 Mdot
.69802 .70979 Mdot
.69802 .70194 Mdot
.70587 .70979 Mdot
.70979 .72155 Mdot
.70587 .72547 Mdot
.69802 .72547 Mdot
.70194 .72547 Mdot
.70979 .72939 Mdot
.70979 .72155 Mdot
.70979 .72547 Mdot
.70194 .72547 Mdot
.6941 .72547 Mdot
.6941 .71763 Mdot
.69802 .72155 Mdot
.70194 .72547 Mdot
.70587 .73724 Mdot
.70587 .72939 Mdot
.70587 .72939 Mdot
.71371 .74116 Mdot
.70979 .74116 Mdot
.70979 .73724 Mdot
.70979 .72547 Mdot
.71763 .73332 Mdot
.72547 .73724 Mdot
.73332 .73724 Mdot
.73724 .74116 Mdot
.73332 .74116 Mdot
.73332 .73724 Mdot
.73724 .73724 Mdot
.73332 .73332 Mdot
.72939 .74116 Mdot
.73332 .749 Mdot
.72155 .73724 Mdot
.71371 .73724 Mdot
.71763 .74508 Mdot
.71763 .73724 Mdot
.72547 .73724 Mdot
.72939 .74116 Mdot
.73332 .75292 Mdot
.72939 .74116 Mdot
.73332 .749 Mdot
.72155 .73332 Mdot
.72939 .73332 Mdot
.73332 .74508 Mdot
.72547 .74116 Mdot
.72939 .74508 Mdot
.72547 .73724 Mdot
.72939 .73724 Mdot
.72547 .72939 Mdot
.72547 .73332 Mdot
.72547 .73724 Mdot
.71763 .72939 Mdot
.71763 .73332 Mdot
.71371 .72939 Mdot
.70979 .72939 Mdot
.70194 .73332 Mdot
.6941 .72547 Mdot
.69802 .72939 Mdot
.70194 .73724 Mdot
.70194 .73724 Mdot
.70194 .73724 Mdot
.70194 .73724 Mdot
.6941 .72939 Mdot
.6941 .72547 Mdot
.69802 .72155 Mdot
.6941 .72547 Mdot
.69018 .72155 Mdot
.68234 .71371 Mdot
.67057 .69802 Mdot
.66665 .6941 Mdot
.65881 .6941 Mdot
.65881 .6941 Mdot
.65489 .69802 Mdot
.65881 .70194 Mdot
.59607 .62744 Mdot
.48235 .48628 Mdot
.48628 .50196 Mdot
.45098 .47059 Mdot
.21963 .21963 Mdot
.18434 .1961 Mdot
.14513 .15689 Mdot
.13728 .14905 Mdot
.34511 .34903 Mdot
.56078 .56862 Mdot
.45491 .51765 Mdot
.47843 .54509 Mdot
.4902 .55294 Mdot
.48235 .54509 Mdot
.49412 .55294 Mdot
.49412 .56078 Mdot
.4902 .56078 Mdot
.49804 .56862 Mdot
.49412 .5647 Mdot
.49804 .56862 Mdot
.51765 .58431 Mdot
.52549 .58431 Mdot
.53333 .58823 Mdot
.53333 .59215 Mdot
.53333 .58823 Mdot
.54117 .59999 Mdot
.54509 .59999 Mdot
.53725 .59215 Mdot
.54902 .60391 Mdot
.55686 .61568 Mdot
.56078 .62352 Mdot
.56862 .63136 Mdot
.58039 .63136 Mdot
.58039 .62744 Mdot
.59607 .63136 Mdot
.60391 .6392 Mdot
.60783 .64705 Mdot
.60783 .64705 Mdot
.60391 .6392 Mdot
.60391 .63528 Mdot
.60391 .6392 Mdot
.6196 .66273 Mdot
.61568 .65881 Mdot
.6196 .66273 Mdot
.62744 .66273 Mdot
.64313 .67057 Mdot
.6392 .66665 Mdot
.63528 .66665 Mdot
.63136 .66273 Mdot
.63528 .66665 Mdot
.63136 .66665 Mdot
.64705 .67842 Mdot
.64705 .68234 Mdot
.64705 .68626 Mdot
.65489 .69802 Mdot
.65489 .69018 Mdot
.66273 .70194 Mdot
.6745 .70979 Mdot
.68234 .71763 Mdot
.69018 .72155 Mdot
.6941 .71763 Mdot
.70194 .71763 Mdot
.70194 .71371 Mdot
.71371 .72155 Mdot
.70587 .71371 Mdot
.70194 .71763 Mdot
.70194 .71763 Mdot
.70194 .71763 Mdot
.70979 .72155 Mdot
.71763 .72155 Mdot
.72155 .72547 Mdot
.70587 .72155 Mdot
.70194 .72547 Mdot
.69018 .72155 Mdot
.6941 .72939 Mdot
.6941 .72155 Mdot
.70194 .73724 Mdot
.70194 .73332 Mdot
.70587 .73724 Mdot
.70587 .73332 Mdot
.70979 .74116 Mdot
.71371 .74116 Mdot
.71763 .72939 Mdot
.71763 .72939 Mdot
.72155 .72939 Mdot
.72939 .74116 Mdot
.72939 .73724 Mdot
.72155 .72547 Mdot
.72939 .72547 Mdot
.74116 .73724 Mdot
.73332 .73332 Mdot
.72547 .73724 Mdot
.72155 .73724 Mdot
.72155 .73724 Mdot
.70979 .73332 Mdot
.70587 .72939 Mdot
.70979 .74116 Mdot
.70979 .73332 Mdot
.71371 .73724 Mdot
.71763 .73332 Mdot
.72547 .74116 Mdot
.72155 .74116 Mdot
.72547 .73724 Mdot
.71763 .73332 Mdot
.71371 .72939 Mdot
.71763 .72939 Mdot
.72155 .73724 Mdot
.72155 .73332 Mdot
.72547 .73332 Mdot
.72939 .72939 Mdot
.72547 .72547 Mdot
.72547 .73332 Mdot
.71371 .71763 Mdot
.71371 .72155 Mdot
.70979 .72155 Mdot
.71371 .73332 Mdot
.70194 .73332 Mdot
.6941 .72155 Mdot
.69802 .72939 Mdot
.69018 .72547 Mdot
.69018 .72547 Mdot
.69802 .73332 Mdot
.69018 .72547 Mdot
.69018 .72155 Mdot
.69018 .71371 Mdot
.6941 .72155 Mdot
.68626 .70979 Mdot
.68234 .70587 Mdot
.67842 .70587 Mdot
.6745 .70194 Mdot
.67057 .70194 Mdot
.65881 .69018 Mdot
.65489 .69018 Mdot
.65097 .68626 Mdot
.64705 .68234 Mdot
.64705 .67842 Mdot
.64705 .67842 Mdot
.63136 .67057 Mdot
.61176 .66665 Mdot
.50588 .57254 Mdot
.15297 .16081 Mdot
.16081 .18434 Mdot
.14513 .16081 Mdot
.12552 .1412 Mdot
.11768 .13728 Mdot
.12552 .13728 Mdot
.57254 .57646 Mdot
.78429 .78821 Mdot
.45491 .52549 Mdot
.47843 .55294 Mdot
.48628 .55294 Mdot
.47843 .54509 Mdot
.4902 .55686 Mdot
.48628 .55294 Mdot
.4902 .55686 Mdot
.4902 .55294 Mdot
.50196 .56862 Mdot
.5098 .57646 Mdot
.51765 .58823 Mdot
.52157 .59215 Mdot
.52157 .58823 Mdot
.53333 .58823 Mdot
.53725 .59215 Mdot
.53725 .59215 Mdot
.53333 .59215 Mdot
.54117 .59607 Mdot
.55294 .60391 Mdot
.56078 .61568 Mdot
.55686 .6196 Mdot
.56078 .6196 Mdot
.5647 .61568 Mdot
.58039 .62352 Mdot
.59215 .63528 Mdot
.60391 .64313 Mdot
.59999 .6392 Mdot
.59999 .63528 Mdot
.61176 .64705 Mdot
.61568 .65097 Mdot
.59999 .6392 Mdot
.60783 .65097 Mdot
.60783 .65097 Mdot
.60783 .65489 Mdot
.62352 .65881 Mdot
.63136 .67057 Mdot
.63136 .66665 Mdot
.62744 .65881 Mdot
.63136 .66273 Mdot
.6392 .67057 Mdot
.65097 .68234 Mdot
.64705 .6745 Mdot
.65489 .68234 Mdot
.66665 .69802 Mdot
.67057 .69802 Mdot
.6745 .70194 Mdot
.66665 .6941 Mdot
.67057 .69802 Mdot
.67057 .69802 Mdot
.68234 .70979 Mdot
.69018 .70979 Mdot
.6941 .71763 Mdot
.6941 .71763 Mdot
.69018 .71763 Mdot
.68626 .71763 Mdot
.6941 .72155 Mdot
.70194 .71763 Mdot
.69802 .71371 Mdot
.70194 .72547 Mdot
.70979 .72547 Mdot
.70587 .72155 Mdot
.69802 .72155 Mdot
.69802 .71763 Mdot
.69802 .72547 Mdot
.68234 .71371 Mdot
.68234 .71763 Mdot
.69018 .72547 Mdot
.6941 .72547 Mdot
.69802 .72939 Mdot
.70194 .72939 Mdot
.70194 .72939 Mdot
.70979 .74116 Mdot
.71763 .74508 Mdot
.71763 .73724 Mdot
.71371 .72939 Mdot
.71763 .73332 Mdot
.71371 .73332 Mdot
.70587 .72155 Mdot
.70979 .71763 Mdot
.72155 .72547 Mdot
.72155 .73332 Mdot
.71763 .73724 Mdot
.70979 .73724 Mdot
.71371 .73724 Mdot
.70979 .73332 Mdot
.70587 .72547 Mdot
.71371 .72939 Mdot
.72155 .73332 Mdot
.72547 .73724 Mdot
.71763 .73332 Mdot
.72155 .73332 Mdot
.71371 .73332 Mdot
.70587 .72939 Mdot
.70194 .72939 Mdot
.69802 .72547 Mdot
.70587 .73332 Mdot
.71371 .74508 Mdot
.72939 .75292 Mdot
.72939 .74116 Mdot
.73332 .74116 Mdot
.72939 .73332 Mdot
.72155 .72939 Mdot
.71763 .72155 Mdot
.70587 .71371 Mdot
.70587 .71371 Mdot
.70587 .72155 Mdot
.70194 .72939 Mdot
.6941 .72547 Mdot
.69018 .73332 Mdot
.69018 .73332 Mdot
.68234 .72547 Mdot
.68234 .71763 Mdot
.68626 .72155 Mdot
.68626 .71371 Mdot
.68626 .70587 Mdot
.69018 .71763 Mdot
.68234 .70194 Mdot
.68626 .71371 Mdot
.66665 .69802 Mdot
.66665 .69802 Mdot
.66273 .69802 Mdot
.65489 .6941 Mdot
.65097 .69018 Mdot
.64705 .68626 Mdot
.64705 .67842 Mdot
.6392 .66665 Mdot
.64705 .68234 Mdot
.62744 .6745 Mdot
.6196 .67057 Mdot
.61176 .68234 Mdot
.42746 .47059 Mdot
.31374 .34119 Mdot
.21963 .23924 Mdot
.18826 .20394 Mdot
.15297 .16473 Mdot
.16473 .18042 Mdot
.20394 .22747 Mdot
.28237 .31766 Mdot
.15689 .16473 Mdot
.58431 .58431 Mdot
.78429 .78429 Mdot
.46275 .54117 Mdot
.48235 .5647 Mdot
.49412 .56862 Mdot
.49412 .56078 Mdot
.48628 .55294 Mdot
.4902 .55294 Mdot
.50196 .56078 Mdot
.51372 .56862 Mdot
.51765 .57254 Mdot
.51765 .57646 Mdot
.52157 .58823 Mdot
.51372 .58431 Mdot
.51765 .58431 Mdot
.52941 .58431 Mdot
.53333 .58823 Mdot
.54117 .59999 Mdot
.54117 .60391 Mdot
.53725 .60391 Mdot
.53725 .60391 Mdot
.54902 .61176 Mdot
.55686 .6196 Mdot
.55294 .61176 Mdot
.56078 .6196 Mdot
.5647 .62352 Mdot
.57254 .62352 Mdot
.58431 .63528 Mdot
.59215 .64313 Mdot
.58823 .63528 Mdot
.59999 .64313 Mdot
.59607 .64313 Mdot
.59607 .6392 Mdot
.59999 .64705 Mdot
.59999 .64705 Mdot
.60783 .65489 Mdot
.6196 .66273 Mdot
.62744 .66665 Mdot
.63136 .66665 Mdot
.62744 .65881 Mdot
.63136 .66665 Mdot
.6392 .67057 Mdot
.64705 .6745 Mdot
.65097 .6745 Mdot
.64705 .6745 Mdot
.65097 .68234 Mdot
.65881 .68626 Mdot
.66273 .6941 Mdot
.66273 .6941 Mdot
.67057 .70194 Mdot
.6745 .70979 Mdot
.67057 .70194 Mdot
.67842 .70979 Mdot
.68626 .71371 Mdot
.68626 .71371 Mdot
.68626 .71763 Mdot
.68234 .71763 Mdot
.68626 .71763 Mdot
.6941 .72155 Mdot
.6941 .71763 Mdot
.70194 .72547 Mdot
.69802 .72155 Mdot
.69802 .71763 Mdot
.6941 .71763 Mdot
.68626 .70194 Mdot
.6941 .70979 Mdot
.6941 .71763 Mdot
.6941 .72155 Mdot
.69018 .72155 Mdot
.6941 .72547 Mdot
.6941 .72155 Mdot
.69802 .72547 Mdot
.70194 .73332 Mdot
.6941 .72547 Mdot
.69802 .72547 Mdot
.70194 .72939 Mdot
.69802 .72939 Mdot
.6941 .72155 Mdot
.6941 .72547 Mdot
.69802 .72939 Mdot
.70587 .72939 Mdot
.71371 .73332 Mdot
.71371 .73332 Mdot
.71371 .73332 Mdot
.70587 .72939 Mdot
.70587 .73332 Mdot
.70979 .72939 Mdot
.71763 .73332 Mdot
.71371 .72547 Mdot
.70979 .72155 Mdot
.70979 .72547 Mdot
.70979 .73332 Mdot
.70979 .73332 Mdot
.71371 .73724 Mdot
.70194 .72547 Mdot
.6941 .72155 Mdot
.70194 .73332 Mdot
.70979 .73332 Mdot
.71763 .73724 Mdot
.71763 .73332 Mdot
.72155 .73724 Mdot
.71371 .73724 Mdot
.70587 .72939 Mdot
.71763 .73724 Mdot
.70979 .72155 Mdot
.70979 .72155 Mdot
.70587 .72155 Mdot
.6941 .70979 Mdot
.69018 .71763 Mdot
.6941 .72155 Mdot
.69018 .72155 Mdot
.68234 .71371 Mdot
.69018 .72155 Mdot
.69018 .72155 Mdot
.69018 .71371 Mdot
.69018 .71371 Mdot
.68626 .71371 Mdot
.67842 .70979 Mdot
.67057 .70194 Mdot
.66665 .69802 Mdot
.66273 .69802 Mdot
.65489 .69018 Mdot
.65489 .69018 Mdot
.65097 .6941 Mdot
.65489 .70194 Mdot
.65881 .70194 Mdot
.64313 .68626 Mdot
.63136 .67057 Mdot
.63528 .68234 Mdot
.63136 .67842 Mdot
.62352 .67842 Mdot
.61176 .67057 Mdot
.60391 .65881 Mdot
.59607 .65097 Mdot
.44706 .47843 Mdot
.3804 .40001 Mdot
.28237 .27845 Mdot
.29021 .29021 Mdot
.57646 .6392 Mdot
.51765 .5647 Mdot
.31766 .33727 Mdot
.31766 .35295 Mdot
.11376 .10199 Mdot
.32943 .30982 Mdot
.55294 .54117 Mdot
.45491 .51765 Mdot
.48235 .54902 Mdot
.49412 .56078 Mdot
.4902 .56078 Mdot
.4902 .55686 Mdot
.48628 .54509 Mdot
.50588 .55686 Mdot
.51372 .56078 Mdot
.51765 .5647 Mdot
.51372 .5647 Mdot
.51372 .56862 Mdot
.50588 .56078 Mdot
.51372 .5647 Mdot
.52157 .57646 Mdot
.52549 .57646 Mdot
.52549 .58431 Mdot
.53333 .59999 Mdot
.53333 .59999 Mdot
.53725 .60391 Mdot
.55294 .61568 Mdot
.55686 .61176 Mdot
.54902 .59999 Mdot
.56078 .61176 Mdot
.56078 .61176 Mdot
.5647 .6196 Mdot
.56862 .62352 Mdot
.58039 .62744 Mdot
.59607 .64313 Mdot
.59215 .6392 Mdot
.59607 .64313 Mdot
.59999 .64705 Mdot
.60783 .65097 Mdot
.60391 .64705 Mdot
.60783 .64313 Mdot
.61176 .64705 Mdot
.62352 .65881 Mdot
.63136 .66273 Mdot
.63136 .66273 Mdot
.63528 .66273 Mdot
.63528 .6745 Mdot
.63136 .66273 Mdot
.6392 .6745 Mdot
.6392 .6745 Mdot
.64313 .67842 Mdot
.6392 .6745 Mdot
.65489 .69018 Mdot
.65097 .68626 Mdot
.66665 .6941 Mdot
.65489 .69018 Mdot
.65489 .69018 Mdot
.67057 .70194 Mdot
.67842 .70587 Mdot
.68626 .71371 Mdot
.68626 .71763 Mdot
.68234 .72155 Mdot
.68626 .72547 Mdot
.67842 .71371 Mdot
.68626 .71763 Mdot
.68234 .71371 Mdot
.69018 .71763 Mdot
.68626 .71371 Mdot
.67842 .70979 Mdot
.69018 .70979 Mdot
.6941 .71371 Mdot
.69802 .71763 Mdot
.69802 .71763 Mdot
.6941 .71763 Mdot
.70194 .71763 Mdot
.69802 .71371 Mdot
.70587 .71763 Mdot
.70587 .72155 Mdot
.69802 .71763 Mdot
.69018 .72547 Mdot
.69018 .72547 Mdot
.6941 .72547 Mdot
.6941 .72155 Mdot
.6941 .72547 Mdot
.69018 .72547 Mdot
.69802 .72939 Mdot
.71371 .74116 Mdot
.70979 .73332 Mdot
.70979 .73332 Mdot
.70587 .72547 Mdot
.70194 .72155 Mdot
.71371 .72547 Mdot
.70587 .71371 Mdot
.71371 .71763 Mdot
.70979 .72155 Mdot
.71371 .73724 Mdot
.71371 .73332 Mdot
.71763 .73332 Mdot
.71763 .72939 Mdot
.70979 .72547 Mdot
.71371 .73724 Mdot
.71763 .74116 Mdot
.71371 .73332 Mdot
.71371 .72939 Mdot
.71371 .73332 Mdot
.70587 .72155 Mdot
.70979 .72939 Mdot
.70587 .72547 Mdot
.71371 .72939 Mdot
.70979 .71763 Mdot
.70979 .71763 Mdot
.70979 .72155 Mdot
.70587 .72155 Mdot
.69018 .70587 Mdot
.68234 .70194 Mdot
.67842 .70587 Mdot
.68234 .71763 Mdot
.69018 .72547 Mdot
.69802 .72939 Mdot
.69802 .72547 Mdot
.6941 .71763 Mdot
.69018 .71371 Mdot
.6745 .70587 Mdot
.65489 .69018 Mdot
.66273 .69802 Mdot
.66665 .70194 Mdot
.66273 .6941 Mdot
.65881 .6941 Mdot
.66273 .69802 Mdot
.66665 .70587 Mdot
.65097 .6941 Mdot
.64313 .68234 Mdot
.63528 .67057 Mdot
.63136 .67057 Mdot
.63528 .67842 Mdot
.63136 .68234 Mdot
.62352 .6745 Mdot
.61568 .65881 Mdot
.61176 .65489 Mdot
.60783 .64313 Mdot
.59607 .63528 Mdot
.55686 .59215 Mdot
.54509 .58039 Mdot
.56078 .59999 Mdot
.57254 .6196 Mdot
.55686 .60783 Mdot
.57646 .63528 Mdot
.29806 .3059 Mdot
.08631 .06278 Mdot
.10591 .08631 Mdot
.09415 .07846 Mdot
.31374 .30198 Mdot
.52549 .52157 Mdot
.42354 .47059 Mdot
.48235 .54117 Mdot
.4902 .54902 Mdot
.48628 .54902 Mdot
.48628 .54509 Mdot
.48628 .54902 Mdot
.50196 .55686 Mdot
.50588 .55686 Mdot
.5098 .55686 Mdot
.51372 .56078 Mdot
.5098 .55686 Mdot
.51372 .56078 Mdot
.52157 .57254 Mdot
.52157 .57254 Mdot
.52549 .57646 Mdot
.52549 .58039 Mdot
.52941 .59215 Mdot
.52941 .59999 Mdot
.52549 .59215 Mdot
.53333 .60391 Mdot
.54902 .61568 Mdot
.55294 .61568 Mdot
.56078 .60783 Mdot
.5647 .60391 Mdot
.56862 .60783 Mdot
.57254 .61176 Mdot
.57646 .61568 Mdot
.58431 .6196 Mdot
.58823 .62352 Mdot
.59215 .63136 Mdot
.59999 .64313 Mdot
.61176 .65097 Mdot
.60783 .65097 Mdot
.61176 .64705 Mdot
.6196 .65881 Mdot
.61568 .65097 Mdot
.63528 .66273 Mdot
.63528 .65881 Mdot
.63528 .66273 Mdot
.64705 .67842 Mdot
.6392 .67057 Mdot
.63528 .66665 Mdot
.64313 .6745 Mdot
.6392 .6745 Mdot
.64705 .68234 Mdot
.65097 .68234 Mdot
.65097 .67842 Mdot
.66273 .68626 Mdot
.65881 .68234 Mdot
.66273 .69018 Mdot
.67057 .70194 Mdot
.67057 .70194 Mdot
.6745 .70587 Mdot
.67057 .70194 Mdot
.67842 .70979 Mdot
.6745 .70587 Mdot
.6745 .71371 Mdot
.68234 .71763 Mdot
.6745 .70194 Mdot
.6745 .70194 Mdot
.68234 .70587 Mdot
.69018 .70979 Mdot
.69802 .71763 Mdot
.69802 .71763 Mdot
.69018 .70587 Mdot
.6941 .71763 Mdot
.69018 .71763 Mdot
.6941 .71371 Mdot
.69802 .71371 Mdot
.70194 .71763 Mdot
.71371 .72547 Mdot
.69018 .70587 Mdot
.6941 .70979 Mdot
.70587 .72547 Mdot
.70587 .72155 Mdot
.70194 .72155 Mdot
.69802 .72155 Mdot
.6941 .71371 Mdot
.70194 .71763 Mdot
.70194 .72547 Mdot
.70587 .72939 Mdot
.70194 .72155 Mdot
.70194 .72547 Mdot
.6941 .71371 Mdot
.6941 .71371 Mdot
.70194 .71763 Mdot
.70194 .70979 Mdot
.70979 .71371 Mdot
.70587 .71371 Mdot
.70979 .72155 Mdot
.70194 .71763 Mdot
.70194 .71763 Mdot
.70587 .72547 Mdot
.70587 .73332 Mdot
.71371 .74116 Mdot
.70979 .74116 Mdot
.71371 .73332 Mdot
.71371 .72547 Mdot
.70979 .71371 Mdot
.70194 .70979 Mdot
.70587 .71371 Mdot
.70194 .71371 Mdot
.70979 .71763 Mdot
.70587 .71371 Mdot
.70194 .71371 Mdot
.69802 .70979 Mdot
.6941 .70979 Mdot
.69802 .72155 Mdot
.6941 .72155 Mdot
.68626 .71763 Mdot
.68234 .71763 Mdot
.67842 .71371 Mdot
.68234 .71371 Mdot
.68234 .70979 Mdot
.68626 .70587 Mdot
.68234 .70587 Mdot
.67057 .70587 Mdot
.66273 .69802 Mdot
.66273 .6941 Mdot
.66665 .69802 Mdot
.65881 .69018 Mdot
.65881 .69018 Mdot
.65489 .67842 Mdot
.65881 .68234 Mdot
.65489 .68234 Mdot
.64705 .67842 Mdot
.63528 .66665 Mdot
.63528 .6745 Mdot
.62352 .66665 Mdot
.61568 .65489 Mdot
.60783 .64705 Mdot
.61568 .65489 Mdot
.61568 .64705 Mdot
.62352 .65489 Mdot
.60783 .64313 Mdot
.59999 .6392 Mdot
.59607 .63136 Mdot
.59215 .63136 Mdot
.58823 .62352 Mdot
.56078 .60783 Mdot
.52941 .58039 Mdot
.29413 .31374 Mdot
.18434 .18434 Mdot
.14513 .14513 Mdot
.11376 .10591 Mdot
.08631 .07454 Mdot
.11768 .11376 Mdot
.60391 .60391 Mdot
.78821 .78429 Mdot
.43922 .49412 Mdot
.47843 .53725 Mdot
.49804 .55294 Mdot
.49804 .55294 Mdot
.48628 .54509 Mdot
.48235 .54117 Mdot
.4902 .55294 Mdot
.50196 .5647 Mdot
.51765 .57646 Mdot
.5098 .5647 Mdot
.5098 .56862 Mdot
.50588 .56078 Mdot
.5098 .56862 Mdot
.51765 .57646 Mdot
.51765 .57646 Mdot
.52549 .58823 Mdot
.52941 .59215 Mdot
.51372 .57646 Mdot
.51765 .58431 Mdot
.52549 .58431 Mdot
.52549 .58039 Mdot
.54117 .59607 Mdot
.54902 .59999 Mdot
.56078 .60391 Mdot
.56078 .59999 Mdot
.5647 .60783 Mdot
.56862 .6196 Mdot
.57254 .61568 Mdot
.58431 .62744 Mdot
.59999 .63528 Mdot
.59607 .63136 Mdot
.59999 .63528 Mdot
.60391 .64313 Mdot
.60391 .64313 Mdot
.61176 .65097 Mdot
.61568 .64705 Mdot
.62744 .65489 Mdot
.62744 .65097 Mdot
.6196 .64705 Mdot
.62744 .65881 Mdot
.63528 .66273 Mdot
.63136 .66665 Mdot
.6392 .6745 Mdot
.6392 .67842 Mdot
.6392 .6745 Mdot
.63528 .66665 Mdot
.65489 .68234 Mdot
.65489 .6745 Mdot
.66665 .69018 Mdot
.65881 .68234 Mdot
.65881 .68626 Mdot
.66273 .6941 Mdot
.66273 .6941 Mdot
.6745 .70194 Mdot
.66665 .6941 Mdot
.67057 .69802 Mdot
.66665 .6941 Mdot
.67057 .70194 Mdot
.67842 .6941 Mdot
.67842 .69802 Mdot
.68626 .70979 Mdot
.68234 .70587 Mdot
.6941 .71371 Mdot
.69018 .70194 Mdot
.68234 .69802 Mdot
.67842 .6941 Mdot
.69018 .70979 Mdot
.68626 .70587 Mdot
.67842 .69802 Mdot
.68234 .70587 Mdot
.69018 .70587 Mdot
.70194 .71371 Mdot
.69802 .71371 Mdot
.69018 .70194 Mdot
.6941 .70979 Mdot
.6941 .70979 Mdot
.6941 .71371 Mdot
.69018 .70587 Mdot
.70194 .71763 Mdot
.69802 .71763 Mdot
.6941 .71763 Mdot
.6941 .71371 Mdot
.69018 .71371 Mdot
.69018 .70979 Mdot
.68626 .70587 Mdot
.69802 .71371 Mdot
.70194 .70979 Mdot
.70587 .70979 Mdot
.70587 .71371 Mdot
.70979 .71763 Mdot
.70194 .71371 Mdot
.70194 .71763 Mdot
.69802 .71763 Mdot
.69802 .72155 Mdot
.6941 .71371 Mdot
.6941 .70979 Mdot
.69802 .71763 Mdot
.69018 .70587 Mdot
.69802 .70979 Mdot
.69802 .70979 Mdot
.6941 .70979 Mdot
.68234 .70587 Mdot
.67842 .70194 Mdot
.67842 .69802 Mdot
.68234 .70587 Mdot
.68234 .69802 Mdot
.67842 .70194 Mdot
.67842 .70587 Mdot
.67057 .70194 Mdot
.6745 .70194 Mdot
.68234 .71763 Mdot
.6745 .70979 Mdot
.67842 .71763 Mdot
.67057 .70194 Mdot
.68234 .70979 Mdot
.67842 .70587 Mdot
.66665 .70194 Mdot
.65489 .6941 Mdot
.65489 .69018 Mdot
.64705 .68234 Mdot
.65489 .68626 Mdot
.65881 .6745 Mdot
.65097 .65881 Mdot
.65489 .66273 Mdot
.65489 .67057 Mdot
.65097 .66665 Mdot
.65489 .67057 Mdot
.6392 .65881 Mdot
.62744 .65881 Mdot
.6196 .65881 Mdot
.62352 .65881 Mdot
.61176 .64705 Mdot
.61176 .6392 Mdot
.60783 .6392 Mdot
.59607 .63136 Mdot
.59607 .62744 Mdot
.59215 .62744 Mdot
.59607 .62352 Mdot
.59215 .62352 Mdot
.57646 .60783 Mdot
.5647 .61568 Mdot
.54509 .59607 Mdot
.52549 .58039 Mdot
.40785 .44314 Mdot
.20787 .20002 Mdot
.20002 .19218 Mdot
.16081 .14905 Mdot
.20002 .1961 Mdot
.21179 .21571 Mdot
.17257 .17257 Mdot
.57254 .57254 Mdot
.78429 .78429 Mdot
.45491 .5098 Mdot
.47059 .53333 Mdot
.48628 .54902 Mdot
.4902 .54902 Mdot
.49412 .55294 Mdot
.47843 .54117 Mdot
.48235 .54902 Mdot
.50196 .55686 Mdot
.50196 .54902 Mdot
.49804 .54902 Mdot
.4902 .54509 Mdot
.4902 .55294 Mdot
.4902 .55294 Mdot
.49804 .5647 Mdot
.50588 .57254 Mdot
.51372 .57646 Mdot
.52157 .58823 Mdot
.52157 .57646 Mdot
.52549 .58039 Mdot
.52941 .58823 Mdot
.52941 .58039 Mdot
.53333 .58431 Mdot
.55294 .59607 Mdot
.56078 .59999 Mdot
.56078 .59999 Mdot
.55294 .59215 Mdot
.55294 .58823 Mdot
.5647 .60391 Mdot
.58039 .61568 Mdot
.59215 .62352 Mdot
.59215 .6196 Mdot
.59999 .63136 Mdot
.58823 .6196 Mdot
.59999 .63528 Mdot
.61568 .65489 Mdot
.61176 .64705 Mdot
.60391 .6392 Mdot
.60783 .63528 Mdot
.60783 .64313 Mdot
.62744 .65881 Mdot
.61568 .65097 Mdot
.62352 .66273 Mdot
.62352 .66273 Mdot
.62352 .65881 Mdot
.64313 .67842 Mdot
.6392 .6745 Mdot
.64705 .67057 Mdot
.65489 .68626 Mdot
.65489 .6745 Mdot
.65097 .6745 Mdot
.64705 .6745 Mdot
.65881 .68234 Mdot
.66665 .69018 Mdot
.6745 .69802 Mdot
.6745 .69802 Mdot
.66665 .6941 Mdot
.65881 .68626 Mdot
.65881 .68626 Mdot
.66273 .68626 Mdot
.66665 .69018 Mdot
.67057 .6941 Mdot
.67057 .68626 Mdot
.66665 .68234 Mdot
.67057 .6941 Mdot
.66665 .68234 Mdot
.67057 .68234 Mdot
.67842 .6941 Mdot
.67842 .69802 Mdot
.68626 .69802 Mdot
.68626 .70194 Mdot
.67842 .69802 Mdot
.67842 .69802 Mdot
.67842 .69802 Mdot
.6745 .69018 Mdot
.67842 .69802 Mdot
.68626 .70194 Mdot
.68626 .69802 Mdot
.68234 .69802 Mdot
.68234 .70194 Mdot
.6941 .71371 Mdot
.69018 .70587 Mdot
.6941 .70587 Mdot
.68626 .6941 Mdot
.67842 .69018 Mdot
.69018 .70587 Mdot
.68626 .70587 Mdot
.69018 .70979 Mdot
.68626 .69018 Mdot
.68626 .6941 Mdot
.69018 .6941 Mdot
.69802 .69802 Mdot
.69802 .70194 Mdot
.68234 .70194 Mdot
.69018 .71371 Mdot
.69018 .70979 Mdot
.69018 .70587 Mdot
.67842 .69802 Mdot
.68234 .70194 Mdot
.68234 .70587 Mdot
.67842 .70194 Mdot
.6745 .70194 Mdot
.67057 .6941 Mdot
.67057 .6941 Mdot
.67057 .69802 Mdot
.67057 .69802 Mdot
.6745 .69018 Mdot
.68234 .70194 Mdot
.67057 .69018 Mdot
.6745 .70194 Mdot
.67842 .70194 Mdot
.67057 .6941 Mdot
.67057 .69802 Mdot
.6745 .69802 Mdot
.66665 .6941 Mdot
.66273 .68626 Mdot
.65097 .67842 Mdot
.65489 .68626 Mdot
.65097 .69018 Mdot
.64313 .68234 Mdot
.6392 .67057 Mdot
.64705 .6745 Mdot
.64705 .66665 Mdot
.65097 .66273 Mdot
.65097 .65881 Mdot
.63528 .64313 Mdot
.6392 .65097 Mdot
.63528 .65097 Mdot
.63136 .65097 Mdot
.6196 .64313 Mdot
.6196 .64705 Mdot
.60391 .6392 Mdot
.59607 .62744 Mdot
.59607 .62352 Mdot
.59215 .6196 Mdot
.59215 .6196 Mdot
.59215 .61568 Mdot
.58823 .61568 Mdot
.58039 .60783 Mdot
.5647 .59607 Mdot
.56078 .59215 Mdot
.56078 .59999 Mdot
.54509 .58823 Mdot
.54509 .58431 Mdot
.54509 .58431 Mdot
.48235 .51765 Mdot
.45491 .49804 Mdot
.40393 .43922 Mdot
.36472 .40001 Mdot
.251 .26276 Mdot
.20002 .20394 Mdot
.24316 .25884 Mdot
.31766 .35295 Mdot
.41569 .42746 Mdot
.53725 .53333 Mdot
.41961 .48628 Mdot
.47451 .54509 Mdot
.48628 .55294 Mdot
.4902 .55686 Mdot
.47843 .54117 Mdot
.48628 .55294 Mdot
.47843 .54509 Mdot
.48235 .54902 Mdot
.48628 .54509 Mdot
.50196 .55686 Mdot
.49804 .55686 Mdot
.4902 .55294 Mdot
.48628 .54902 Mdot
.49412 .56078 Mdot
.50196 .56862 Mdot
.5098 .57254 Mdot
.52157 .57646 Mdot
.52157 .57646 Mdot
.52549 .58431 Mdot
.52157 .58431 Mdot
.53333 .58823 Mdot
.54117 .59215 Mdot
.55686 .60391 Mdot
.55294 .59215 Mdot
.55686 .59999 Mdot
.55294 .59215 Mdot
.55686 .59999 Mdot
.55294 .59607 Mdot
.56078 .60783 Mdot
.58039 .62352 Mdot
.58431 .62352 Mdot
.59215 .62352 Mdot
.59215 .62744 Mdot
.58039 .6196 Mdot
.58039 .62744 Mdot
.58431 .63136 Mdot
.58823 .62744 Mdot
.59607 .63528 Mdot
.60391 .64705 Mdot
.60783 .65489 Mdot
.61176 .66273 Mdot
.61176 .66273 Mdot
.62352 .66273 Mdot
.61176 .65097 Mdot
.6196 .65881 Mdot
.63528 .67057 Mdot
.6392 .67057 Mdot
.64705 .6745 Mdot
.65489 .67842 Mdot
.65489 .67842 Mdot
.64705 .67057 Mdot
.65097 .67842 Mdot
.64705 .6745 Mdot
.65097 .6745 Mdot
.65489 .68234 Mdot
.65881 .68626 Mdot
.65489 .68626 Mdot
.65489 .68626 Mdot
.65489 .68234 Mdot
.66273 .69018 Mdot
.65881 .69018 Mdot
.65489 .68234 Mdot
.65097 .67842 Mdot
.66273 .68626 Mdot
.66273 .69018 Mdot
.66665 .6941 Mdot
.67057 .69802 Mdot
.67057 .69802 Mdot
.66273 .67842 Mdot
.67057 .68234 Mdot
.66665 .67842 Mdot
.66665 .68626 Mdot
.66273 .69018 Mdot
.67057 .68626 Mdot
.67057 .68626 Mdot
.67842 .6941 Mdot
.68234 .69802 Mdot
.68234 .70194 Mdot
.6745 .6941 Mdot
.67842 .70194 Mdot
.67842 .69802 Mdot
.68234 .70194 Mdot
.67842 .6941 Mdot
.68234 .70194 Mdot
.68234 .70194 Mdot
.67842 .69802 Mdot
.68234 .70194 Mdot
.67842 .6941 Mdot
.67842 .69018 Mdot
.68234 .6941 Mdot
.69018 .69802 Mdot
.67842 .6941 Mdot
.67057 .69018 Mdot
.67057 .6941 Mdot
.67842 .70587 Mdot
.69018 .70979 Mdot
.67842 .70194 Mdot
.67842 .69802 Mdot
.67842 .70194 Mdot
.66273 .69018 Mdot
.66273 .6941 Mdot
.67057 .70587 Mdot
.6745 .70587 Mdot
.67057 .69802 Mdot
.66273 .6941 Mdot
.66665 .6941 Mdot
.66665 .69018 Mdot
.66273 .68626 Mdot
.66273 .68234 Mdot
.66665 .68626 Mdot
.6745 .6941 Mdot
.67057 .6941 Mdot
.66273 .67842 Mdot
.67057 .69018 Mdot
.66273 .68234 Mdot
.64705 .6745 Mdot
.64313 .6745 Mdot
.65489 .68626 Mdot
.65097 .67842 Mdot
.64313 .6745 Mdot
.64313 .66665 Mdot
.63528 .65881 Mdot
.6392 .66273 Mdot
.63528 .65881 Mdot
.62744 .65097 Mdot
.63136 .65489 Mdot
.62352 .65097 Mdot
.60783 .6392 Mdot
.60783 .6392 Mdot
.60783 .64313 Mdot
.60783 .64313 Mdot
.59607 .63528 Mdot
.59607 .63528 Mdot
.59607 .6392 Mdot
.59607 .6392 Mdot
.59215 .62352 Mdot
.58431 .61568 Mdot
.58431 .62352 Mdot
.57646 .61568 Mdot
.58039 .61568 Mdot
.57254 .60783 Mdot
.56078 .59999 Mdot
.56078 .59607 Mdot
.54902 .58431 Mdot
.54117 .58039 Mdot
.52941 .5647 Mdot
.51765 .56078 Mdot
.50588 .55294 Mdot
.47451 .52549 Mdot
.47059 .51765 Mdot
.47059 .52157 Mdot
.47843 .53333 Mdot
.40785 .45883 Mdot
.14513 .15689 Mdot
.20394 .23924 Mdot
.27845 .28629 Mdot
.51372 .52157 Mdot
.42354 .48628 Mdot
.45491 .52549 Mdot
.47451 .54902 Mdot
.48628 .55686 Mdot
.47451 .54117 Mdot
.47843 .54509 Mdot
.48235 .54902 Mdot
.48235 .54902 Mdot
.48235 .54902 Mdot
.48235 .54902 Mdot
.48628 .54902 Mdot
.48235 .54902 Mdot
.48628 .55294 Mdot
.4902 .55294 Mdot
.49804 .57254 Mdot
.50196 .56862 Mdot
.51372 .57646 Mdot
.52549 .58431 Mdot
.51765 .58431 Mdot
.51372 .58431 Mdot
.52157 .58823 Mdot
.52941 .58823 Mdot
.53725 .59215 Mdot
.54117 .58431 Mdot
.53725 .58431 Mdot
.53725 .58431 Mdot
.54117 .59215 Mdot
.53725 .58823 Mdot
.54902 .60391 Mdot
.55686 .61176 Mdot
.5647 .61176 Mdot
.56862 .60783 Mdot
.57254 .61568 Mdot
.56078 .61176 Mdot
.5647 .6196 Mdot
.56862 .62352 Mdot
.5647 .6196 Mdot
.57646 .62744 Mdot
.58039 .62744 Mdot
.58431 .63528 Mdot
.58823 .64313 Mdot
.58431 .64313 Mdot
.60391 .65489 Mdot
.60783 .65097 Mdot
.60783 .65097 Mdot
.61568 .65489 Mdot
.63136 .67057 Mdot
.63136 .66273 Mdot
.6392 .66665 Mdot
.64705 .6745 Mdot
.64705 .6745 Mdot
.64313 .67057 Mdot
.64313 .67057 Mdot
.64705 .6745 Mdot
.65097 .6745 Mdot
.64313 .67057 Mdot
.64705 .67842 Mdot
.64705 .68234 Mdot
.64313 .68234 Mdot
.64705 .67842 Mdot
.65097 .68626 Mdot
.65097 .68234 Mdot
.65097 .6745 Mdot
.65881 .68234 Mdot
.65881 .68626 Mdot
.65881 .68626 Mdot
.65489 .68626 Mdot
.65489 .68626 Mdot
.65881 .69018 Mdot
.66665 .69018 Mdot
.6745 .68626 Mdot
.66665 .68234 Mdot
.66273 .68626 Mdot
.66665 .68626 Mdot
.68234 .69802 Mdot
.67842 .70194 Mdot
.67842 .69802 Mdot
.6745 .68626 Mdot
.6745 .6941 Mdot
.67057 .69802 Mdot
.67057 .69802 Mdot
.67057 .69802 Mdot
.65881 .68626 Mdot
.65881 .68626 Mdot
.66665 .6941 Mdot
.66273 .6941 Mdot
.66273 .69018 Mdot
.66665 .69018 Mdot
.66273 .67842 Mdot
.67057 .6941 Mdot
.6745 .69802 Mdot
.67057 .69802 Mdot
.67057 .6941 Mdot
.66273 .68626 Mdot
.65489 .68234 Mdot
.66273 .6941 Mdot
.66273 .69018 Mdot
.66665 .6941 Mdot
.6745 .69802 Mdot
.66665 .6941 Mdot
.66273 .68626 Mdot
.66273 .69018 Mdot
.66665 .6941 Mdot
.66665 .6941 Mdot
.66665 .6941 Mdot
.65489 .68234 Mdot
.65881 .68626 Mdot
.65881 .68626 Mdot
.65097 .67842 Mdot
.65881 .68234 Mdot
.65489 .67842 Mdot
.66273 .68234 Mdot
.66273 .69018 Mdot
.66273 .69018 Mdot
.65489 .67842 Mdot
.64705 .66665 Mdot
.64313 .66665 Mdot
.6392 .66273 Mdot
.6392 .66273 Mdot
.6392 .66665 Mdot
.63136 .65489 Mdot
.6392 .66273 Mdot
.6392 .65881 Mdot
.62744 .65881 Mdot
.62744 .66273 Mdot
.62352 .66273 Mdot
.60783 .64705 Mdot
.59607 .63528 Mdot
.59999 .64313 Mdot
.59999 .63136 Mdot
.59215 .63136 Mdot
.58823 .63136 Mdot
.58039 .63136 Mdot
.57646 .62744 Mdot
.57646 .61568 Mdot
.57646 .61176 Mdot
.57254 .60783 Mdot
.57254 .61176 Mdot
.56862 .61568 Mdot
.5647 .60783 Mdot
.55686 .59999 Mdot
.55686 .59999 Mdot
.56078 .60391 Mdot
.55294 .59607 Mdot
.54509 .58823 Mdot
.52549 .57254 Mdot
.51372 .5647 Mdot
.5098 .5647 Mdot
.50588 .56078 Mdot
.49412 .54509 Mdot
.4902 .54117 Mdot
.48235 .52941 Mdot
.47843 .53725 Mdot
.4353 .4902 Mdot
.43138 .50588 Mdot
.20002 .251 Mdot
.07454 .10199 Mdot
.04709 .07062 Mdot
.50196 .5098 Mdot
.75292 .75292 Mdot
.41569 .48628 Mdot
.47059 .54117 Mdot
.48235 .54509 Mdot
.48235 .54509 Mdot
.47451 .54117 Mdot
.47059 .53333 Mdot
.45098 .51372 Mdot
.45098 .52157 Mdot
.45883 .53333 Mdot
.47451 .54902 Mdot
.47451 .54509 Mdot
.48235 .54902 Mdot
.48235 .54509 Mdot
.4902 .55294 Mdot
.49412 .56078 Mdot
.49804 .5647 Mdot
.51372 .57646 Mdot
.52157 .58039 Mdot
.51765 .56862 Mdot
.51765 .57646 Mdot
.5098 .57646 Mdot
.51765 .58039 Mdot
.52941 .58823 Mdot
.53333 .58823 Mdot
.53725 .58431 Mdot
.53725 .58431 Mdot
.52941 .57646 Mdot
.53725 .58431 Mdot
.53725 .58823 Mdot
.54117 .59607 Mdot
.55686 .60391 Mdot
.56078 .59999 Mdot
.5647 .60783 Mdot
.56078 .60391 Mdot
.5647 .60783 Mdot
.56862 .61568 Mdot
.5647 .61568 Mdot
.56862 .6196 Mdot
.58039 .62744 Mdot
.57646 .62744 Mdot
.57254 .62744 Mdot
.57254 .63136 Mdot
.58823 .64313 Mdot
.60783 .65489 Mdot
.60783 .65097 Mdot
.61568 .65489 Mdot
.62744 .66273 Mdot
.63528 .66665 Mdot
.63528 .66273 Mdot
.6392 .66273 Mdot
.64313 .66665 Mdot
.64705 .66665 Mdot
.6392 .65881 Mdot
.64313 .66273 Mdot
.65097 .67057 Mdot
.63528 .65881 Mdot
.64705 .66273 Mdot
.65097 .6745 Mdot
.64705 .6745 Mdot
.6392 .6745 Mdot
.6392 .67842 Mdot
.6392 .6745 Mdot
.64313 .66665 Mdot
.64313 .66665 Mdot
.65097 .6745 Mdot
.65097 .6745 Mdot
.65097 .6745 Mdot
.65489 .67842 Mdot
.65097 .67057 Mdot
.65489 .6745 Mdot
.66273 .67842 Mdot
.65881 .68234 Mdot
.66273 .69018 Mdot
.66665 .6941 Mdot
.65881 .6745 Mdot
.66273 .67842 Mdot
.66665 .68234 Mdot
.6745 .68626 Mdot
.67057 .68234 Mdot
.67057 .68234 Mdot
.66273 .6745 Mdot
.65489 .67057 Mdot
.64705 .66665 Mdot
.65097 .6745 Mdot
.65489 .68234 Mdot
.66273 .68626 Mdot
.66273 .67842 Mdot
.65881 .6745 Mdot
.66665 .67842 Mdot
.66273 .67057 Mdot
.66273 .6745 Mdot
.66665 .68234 Mdot
.66273 .67842 Mdot
.65489 .67842 Mdot
.65097 .6745 Mdot
.65489 .67842 Mdot
.65881 .68626 Mdot
.65489 .68234 Mdot
.66273 .68626 Mdot
.65881 .68234 Mdot
.64313 .67057 Mdot
.65489 .68234 Mdot
.65881 .68234 Mdot
.65489 .68234 Mdot
.65097 .6745 Mdot
.64705 .67057 Mdot
.65489 .68234 Mdot
.65097 .6745 Mdot
.65097 .67842 Mdot
.65489 .6745 Mdot
.64705 .67057 Mdot
.6392 .66273 Mdot
.63528 .66273 Mdot
.63528 .65881 Mdot
.64705 .67057 Mdot
.64313 .66665 Mdot
.62744 .65097 Mdot
.62352 .64313 Mdot
.62352 .64705 Mdot
.62352 .65097 Mdot
.62352 .65097 Mdot
.63136 .65097 Mdot
.63136 .65097 Mdot
.61176 .63136 Mdot
.61568 .64313 Mdot
.59999 .63136 Mdot
.59607 .62744 Mdot
.61176 .64313 Mdot
.59999 .63528 Mdot
.59215 .63528 Mdot
.58823 .63528 Mdot
.58039 .63136 Mdot
.57646 .62744 Mdot
.57646 .6196 Mdot
.58039 .61176 Mdot
.57646 .61568 Mdot
.56078 .60391 Mdot
.56078 .60783 Mdot
.56078 .61176 Mdot
.55294 .60391 Mdot
.54902 .59999 Mdot
.55686 .59607 Mdot
.54902 .59215 Mdot
.54117 .58823 Mdot
.53725 .58431 Mdot
.5098 .55686 Mdot
.51372 .56862 Mdot
.51372 .56862 Mdot
.51765 .5647 Mdot
.5098 .54902 Mdot
.5098 .55294 Mdot
.49804 .55294 Mdot
.48628 .54117 Mdot
.47843 .53333 Mdot
.45883 .5098 Mdot
.48235 .54902 Mdot
.21571 .25492 Mdot
.03925 .04709 Mdot
.03141 .03533 Mdot
.02357 .01965 Mdot
.41961 .48628 Mdot
.47451 .54117 Mdot
.48628 .55294 Mdot
.48235 .54509 Mdot
.47843 .54117 Mdot
.46667 .53333 Mdot
.45491 .52157 Mdot
.45491 .52941 Mdot
.45883 .53333 Mdot
.46275 .53725 Mdot
.48235 .54902 Mdot
.4902 .54902 Mdot
.48628 .54902 Mdot
.49412 .56078 Mdot
.5098 .58039 Mdot
.50196 .57254 Mdot
.5098 .58039 Mdot
.51372 .57646 Mdot
.51372 .56862 Mdot
.51765 .58431 Mdot
.51372 .58039 Mdot
.51372 .58039 Mdot
.52157 .58823 Mdot
.52157 .57646 Mdot
.53333 .58431 Mdot
.52941 .57254 Mdot
.53333 .58039 Mdot
.52941 .58823 Mdot
.53725 .59607 Mdot
.55294 .60391 Mdot
.57254 .61568 Mdot
.55686 .58823 Mdot
.56862 .60391 Mdot
.56862 .60783 Mdot
.56862 .60391 Mdot
.57254 .61176 Mdot
.57254 .61176 Mdot
.57646 .6196 Mdot
.58039 .62352 Mdot
.57646 .6196 Mdot
.58431 .63528 Mdot
.58823 .63528 Mdot
.59215 .6392 Mdot
.60783 .64705 Mdot
.61176 .65097 Mdot
.60783 .6392 Mdot
.6196 .65489 Mdot
.62744 .66665 Mdot
.63528 .66665 Mdot
.64313 .66273 Mdot
.63528 .65489 Mdot
.6392 .65489 Mdot
.64705 .66273 Mdot
.64705 .66665 Mdot
.62744 .65489 Mdot
.62744 .65881 Mdot
.63528 .65881 Mdot
.64705 .66665 Mdot
.64705 .66665 Mdot
.64313 .67057 Mdot
.64313 .67842 Mdot
.65097 .6745 Mdot
.64705 .66665 Mdot
.65489 .6745 Mdot
.65097 .6745 Mdot
.64313 .67057 Mdot
.65489 .68234 Mdot
.65489 .67842 Mdot
.65489 .6745 Mdot
.65097 .6745 Mdot
.65097 .67057 Mdot
.65097 .67842 Mdot
.65489 .68234 Mdot
.65097 .6745 Mdot
.65489 .67842 Mdot
.65881 .67842 Mdot
.65881 .67842 Mdot
.65097 .67057 Mdot
.65489 .67057 Mdot
.65881 .6745 Mdot
.65097 .66665 Mdot
.65097 .67057 Mdot
.65881 .6745 Mdot
.65489 .6745 Mdot
.66273 .68234 Mdot
.66273 .68234 Mdot
.65881 .67057 Mdot
.65489 .66273 Mdot
.66273 .67842 Mdot
.66273 .67842 Mdot
.66665 .6745 Mdot
.65881 .67057 Mdot
.65881 .6745 Mdot
.65881 .68234 Mdot
.65097 .6745 Mdot
.65097 .6745 Mdot
.65489 .67842 Mdot
.65489 .67842 Mdot
.65097 .67057 Mdot
.65881 .68234 Mdot
.65881 .68234 Mdot
.65881 .68234 Mdot
.65489 .67842 Mdot
.66273 .68234 Mdot
.65881 .6745 Mdot
.65881 .67842 Mdot
.66273 .67842 Mdot
.65881 .67842 Mdot
.66273 .68234 Mdot
.65489 .6745 Mdot
.64705 .67057 Mdot
.63528 .65881 Mdot
.63528 .66665 Mdot
.62744 .66665 Mdot
.62744 .65881 Mdot
.62352 .65489 Mdot
.62352 .65097 Mdot
.62352 .65097 Mdot
.63136 .65489 Mdot
.6196 .64313 Mdot
.6196 .6392 Mdot
.63136 .65097 Mdot
.6196 .63528 Mdot
.62352 .64313 Mdot
.61176 .6392 Mdot
.60391 .63528 Mdot
.60391 .63136 Mdot
.60783 .6392 Mdot
.60783 .6392 Mdot
.59215 .62352 Mdot
.58431 .62744 Mdot
.58039 .62744 Mdot
.56862 .61176 Mdot
.57646 .6196 Mdot
.57646 .6196 Mdot
.56862 .61568 Mdot
.55294 .60783 Mdot
.54902 .60783 Mdot
.54509 .60391 Mdot
.54117 .60391 Mdot
.54117 .59607 Mdot
.54902 .59607 Mdot
.53333 .58039 Mdot
.52941 .58039 Mdot
.52941 .58823 Mdot
.5098 .5647 Mdot
.51372 .56078 Mdot
.52157 .5647 Mdot
.51765 .55686 Mdot
.5098 .54509 Mdot
.50588 .54509 Mdot
.48628 .53725 Mdot
.47843 .52549 Mdot
.48235 .52941 Mdot
.47451 .5098 Mdot
.47843 .51765 Mdot
.46667 .51765 Mdot
.18434 .1961 Mdot
.14513 .14905 Mdot
.12552 .1216 Mdot
.41569 .47843 Mdot
.47451 .54509 Mdot
.49412 .56078 Mdot
.48628 .54509 Mdot
.48235 .54117 Mdot
.47059 .52941 Mdot
.46667 .53333 Mdot
.47059 .54509 Mdot
.47843 .56078 Mdot
.4902 .5647 Mdot
.4902 .55294 Mdot
.49412 .55294 Mdot
.49804 .55686 Mdot
.50196 .56862 Mdot
.50588 .57254 Mdot
.5098 .57646 Mdot
.51372 .58431 Mdot
.52157 .58431 Mdot
.52157 .57254 Mdot
.52157 .57646 Mdot
.52157 .58039 Mdot
.51372 .58039 Mdot
.51372 .58431 Mdot
.52549 .58823 Mdot
.53333 .58823 Mdot
.54117 .59215 Mdot
.53725 .59215 Mdot
.53333 .58431 Mdot
.54509 .59607 Mdot
.56078 .61176 Mdot
.5647 .60391 Mdot
.56862 .59607 Mdot
.57254 .60391 Mdot
.57254 .60391 Mdot
.57646 .60783 Mdot
.56862 .60391 Mdot
.58823 .61568 Mdot
.58431 .61568 Mdot
.58823 .6196 Mdot
.58431 .62352 Mdot
.59215 .6392 Mdot
.59215 .6392 Mdot
.60783 .64705 Mdot
.61176 .64705 Mdot
.6196 .65489 Mdot
.6196 .65489 Mdot
.6196 .65489 Mdot
.6196 .65489 Mdot
.63136 .66273 Mdot
.64705 .67842 Mdot
.64313 .65881 Mdot
.64313 .66273 Mdot
.64705 .66273 Mdot
.64313 .66665 Mdot
.64313 .6745 Mdot
.6392 .6745 Mdot
.65097 .67842 Mdot
.64705 .67057 Mdot
.64313 .66273 Mdot
.6392 .66273 Mdot
.64705 .66665 Mdot
.64705 .66665 Mdot
.64313 .66665 Mdot
.65489 .67842 Mdot
.65881 .68626 Mdot
.65097 .67842 Mdot
.64705 .6745 Mdot
.65489 .6745 Mdot
.65489 .67842 Mdot
.6392 .66273 Mdot
.64313 .67057 Mdot
.64313 .67057 Mdot
.65097 .68234 Mdot
.64313 .66665 Mdot
.65097 .67842 Mdot
.65881 .68234 Mdot
.65881 .68626 Mdot
.65097 .67057 Mdot
.65097 .67057 Mdot
.64705 .66273 Mdot
.65489 .6745 Mdot
.65881 .67842 Mdot
.65489 .6745 Mdot
.65881 .67842 Mdot
.65881 .67842 Mdot
.66273 .68626 Mdot
.67057 .68234 Mdot
.6745 .68234 Mdot
.6745 .69018 Mdot
.67057 .68626 Mdot
.66665 .67842 Mdot
.67057 .68234 Mdot
.66665 .68626 Mdot
.66273 .6745 Mdot
.66273 .67842 Mdot
.65489 .6745 Mdot
.65489 .67842 Mdot
.65097 .6745 Mdot
.65881 .68234 Mdot
.65097 .6745 Mdot
.65097 .67842 Mdot
.65489 .67842 Mdot
.67057 .6941 Mdot
.6745 .69018 Mdot
.67842 .6941 Mdot
.66665 .68234 Mdot
.66273 .68234 Mdot
.66273 .68234 Mdot
.65489 .6745 Mdot
.64705 .67057 Mdot
.65097 .67842 Mdot
.64313 .67842 Mdot
.63528 .67057 Mdot
.63136 .67057 Mdot
.62352 .66273 Mdot
.61176 .64705 Mdot
.61568 .65097 Mdot
.6196 .65881 Mdot
.62352 .65881 Mdot
.62352 .65489 Mdot
.6196 .64705 Mdot
.62744 .65881 Mdot
.61176 .64313 Mdot
.61176 .64313 Mdot
.59999 .63136 Mdot
.60391 .6392 Mdot
.60783 .64705 Mdot
.60391 .6392 Mdot
.60391 .63528 Mdot
.59607 .63528 Mdot
.58039 .62744 Mdot
.57646 .62744 Mdot
.57646 .62352 Mdot
.57254 .61568 Mdot
.57646 .62352 Mdot
.57254 .6196 Mdot
.5647 .61176 Mdot
.54902 .61176 Mdot
.54117 .60391 Mdot
.54509 .60783 Mdot
.54117 .59999 Mdot
.55294 .61176 Mdot
.54509 .60391 Mdot
.53725 .60391 Mdot
.54117 .59999 Mdot
.52549 .58431 Mdot
.52549 .58039 Mdot
.52941 .56862 Mdot
.52549 .5647 Mdot
.52941 .57254 Mdot
.51372 .55686 Mdot
.49412 .54509 Mdot
.48235 .53333 Mdot
.4902 .53725 Mdot
.49412 .53333 Mdot
.4902 .52157 Mdot
.47843 .51372 Mdot
.45491 .50588 Mdot
.40001 .45098 Mdot
.3804 .44314 Mdot
.40785 .46667 Mdot
.46275 .53725 Mdot
.48235 .54902 Mdot
.47451 .54117 Mdot
.48628 .54902 Mdot
.47843 .54509 Mdot
.46667 .53725 Mdot
.47059 .54509 Mdot
.46275 .53725 Mdot
.47843 .54509 Mdot
.4902 .54902 Mdot
.49412 .55686 Mdot
.49412 .55686 Mdot
.49804 .56078 Mdot
.50196 .5647 Mdot
.50588 .55686 Mdot
.52157 .58039 Mdot
.52549 .58039 Mdot
.52157 .57254 Mdot
.51372 .56078 Mdot
.5098 .5647 Mdot
.51372 .56862 Mdot
.52549 .58823 Mdot
.52941 .58431 Mdot
.52941 .58823 Mdot
.53725 .59215 Mdot
.53333 .58431 Mdot
.54902 .59999 Mdot
.56078 .61176 Mdot
.55686 .60391 Mdot
.55686 .59999 Mdot
.56078 .59999 Mdot
.56862 .60391 Mdot
.56862 .60391 Mdot
.57254 .60391 Mdot
.58039 .61176 Mdot
.59607 .62352 Mdot
.58823 .6196 Mdot
.58039 .61176 Mdot
.58039 .6196 Mdot
.58431 .62744 Mdot
.58823 .63528 Mdot
.59999 .64705 Mdot
.60783 .64705 Mdot
.61176 .65097 Mdot
.60391 .64313 Mdot
.60783 .65097 Mdot
.62352 .65881 Mdot
.61568 .65097 Mdot
.61176 .64313 Mdot
.61176 .64313 Mdot
.62352 .65489 Mdot
.62744 .66273 Mdot
.62744 .66273 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.63528 .66665 Mdot
.63136 .66273 Mdot
.63528 .65881 Mdot
.6392 .66273 Mdot
.64313 .66665 Mdot
.64313 .67057 Mdot
.65097 .68234 Mdot
.64313 .6745 Mdot
.64705 .67057 Mdot
.65097 .67057 Mdot
.64705 .67057 Mdot
.64705 .6745 Mdot
.63528 .65881 Mdot
.63136 .66273 Mdot
.63528 .66665 Mdot
.64313 .6745 Mdot
.64705 .68234 Mdot
.64313 .6745 Mdot
.64313 .67842 Mdot
.6392 .66665 Mdot
.6392 .66665 Mdot
.64313 .66665 Mdot
.64705 .67057 Mdot
.65097 .67057 Mdot
.65489 .67057 Mdot
.65881 .6745 Mdot
.65881 .6745 Mdot
.65489 .6745 Mdot
.64705 .67057 Mdot
.64705 .66665 Mdot
.65881 .67057 Mdot
.66273 .6745 Mdot
.65881 .67057 Mdot
.66273 .6745 Mdot
.65881 .67057 Mdot
.65489 .66665 Mdot
.64705 .65881 Mdot
.65097 .66665 Mdot
.64705 .66273 Mdot
.65489 .6745 Mdot
.64705 .66665 Mdot
.65489 .67842 Mdot
.65489 .67842 Mdot
.65489 .67842 Mdot
.65097 .6745 Mdot
.65097 .67057 Mdot
.65097 .66665 Mdot
.65489 .67057 Mdot
.64705 .67057 Mdot
.64705 .67057 Mdot
.6392 .66273 Mdot
.64705 .67057 Mdot
.64705 .67842 Mdot
.6392 .67057 Mdot
.6392 .6745 Mdot
.63136 .66665 Mdot
.62744 .66273 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.62352 .65881 Mdot
.62352 .65881 Mdot
.6196 .65489 Mdot
.61176 .64705 Mdot
.61176 .65097 Mdot
.61176 .65097 Mdot
.60783 .64705 Mdot
.59999 .64313 Mdot
.59215 .6392 Mdot
.58431 .63136 Mdot
.59607 .63528 Mdot
.59215 .63136 Mdot
.58039 .6196 Mdot
.59215 .6392 Mdot
.59215 .6392 Mdot
.57646 .62744 Mdot
.5647 .6196 Mdot
.56862 .61568 Mdot
.56078 .60783 Mdot
.55294 .59999 Mdot
.55686 .60391 Mdot
.55294 .60391 Mdot
.55294 .61176 Mdot
.54509 .60391 Mdot
.54117 .59999 Mdot
.54509 .60783 Mdot
.53725 .59999 Mdot
.52157 .58823 Mdot
.52157 .58431 Mdot
.52157 .58039 Mdot
.51765 .57646 Mdot
.51765 .5647 Mdot
.5098 .55686 Mdot
.51372 .56078 Mdot
.50588 .55686 Mdot
.50196 .55686 Mdot
.49412 .54509 Mdot
.49412 .54509 Mdot
.49804 .54902 Mdot
.48235 .52941 Mdot
.47059 .52157 Mdot
.46275 .51765 Mdot
.44706 .5098 Mdot
.41569 .48628 Mdot
.38432 .44314 Mdot
.45883 .53725 Mdot
.46275 .54509 Mdot
.46667 .54117 Mdot
.47059 .54117 Mdot
.47451 .54117 Mdot
.47059 .53725 Mdot
.46667 .53333 Mdot
.45883 .52549 Mdot
.47059 .53725 Mdot
.48628 .54509 Mdot
.48235 .54509 Mdot
.48628 .54902 Mdot
.50196 .5647 Mdot
.51765 .56862 Mdot
.51765 .56862 Mdot
.52549 .57646 Mdot
.53725 .58823 Mdot
.52157 .57254 Mdot
.51765 .56862 Mdot
.51765 .57254 Mdot
.51765 .56862 Mdot
.51765 .56862 Mdot
.52941 .57646 Mdot
.52941 .58039 Mdot
.53333 .58039 Mdot
.53333 .58039 Mdot
.53725 .58431 Mdot
.54509 .59215 Mdot
.54117 .58431 Mdot
.55294 .59215 Mdot
.56078 .59607 Mdot
.56078 .58039 Mdot
.56862 .59607 Mdot
.57254 .60391 Mdot
.57646 .61176 Mdot
.57646 .61176 Mdot
.57254 .61176 Mdot
.56862 .60783 Mdot
.57646 .61568 Mdot
.57646 .6196 Mdot
.58431 .62744 Mdot
.58431 .6392 Mdot
.58039 .6392 Mdot
.59607 .64313 Mdot
.59215 .63528 Mdot
.59607 .64705 Mdot
.60391 .64705 Mdot
.60783 .64705 Mdot
.61176 .64313 Mdot
.62352 .65489 Mdot
.6196 .65489 Mdot
.61568 .65097 Mdot
.6196 .65097 Mdot
.6196 .65097 Mdot
.63136 .66273 Mdot
.62352 .65489 Mdot
.6196 .65489 Mdot
.6196 .65489 Mdot
.62744 .65489 Mdot
.63136 .65881 Mdot
.62352 .65489 Mdot
.64313 .66665 Mdot
.64705 .6745 Mdot
.64313 .67057 Mdot
.64705 .66665 Mdot
.64705 .67057 Mdot
.63528 .65881 Mdot
.64313 .66665 Mdot
.64313 .66273 Mdot
.62744 .65097 Mdot
.62352 .65489 Mdot
.63528 .66665 Mdot
.6392 .67057 Mdot
.63528 .67057 Mdot
.63528 .66665 Mdot
.63528 .66273 Mdot
.63136 .65881 Mdot
.63528 .65881 Mdot
.65097 .67057 Mdot
.65097 .66665 Mdot
.65489 .67057 Mdot
.64705 .66273 Mdot
.64705 .65881 Mdot
.65097 .66665 Mdot
.64313 .65881 Mdot
.64313 .65489 Mdot
.65097 .66273 Mdot
.65489 .66665 Mdot
.64705 .65881 Mdot
.65097 .66665 Mdot
.64313 .65881 Mdot
.64705 .65881 Mdot
.64705 .66273 Mdot
.64705 .66665 Mdot
.63528 .65881 Mdot
.6392 .66665 Mdot
.64313 .6745 Mdot
.64313 .67057 Mdot
.64313 .67057 Mdot
.64313 .67842 Mdot
.64705 .67842 Mdot
.63528 .66273 Mdot
.6392 .66665 Mdot
.64313 .66665 Mdot
.6392 .66273 Mdot
.63528 .65881 Mdot
.63528 .65881 Mdot
.6392 .67057 Mdot
.6392 .66665 Mdot
.6392 .66273 Mdot
.6392 .66665 Mdot
.63528 .66273 Mdot
.63136 .65881 Mdot
.62744 .64705 Mdot
.63136 .65489 Mdot
.62744 .65489 Mdot
.6196 .65097 Mdot
.61568 .64705 Mdot
.59999 .63528 Mdot
.60391 .64313 Mdot
.61176 .64705 Mdot
.60783 .64313 Mdot
.59607 .63528 Mdot
.59215 .63528 Mdot
.59607 .6392 Mdot
.59215 .62744 Mdot
.59607 .62744 Mdot
.59215 .62744 Mdot
.58039 .62352 Mdot
.58039 .6196 Mdot
.56862 .61568 Mdot
.56862 .6196 Mdot
.56862 .62352 Mdot
.56078 .61176 Mdot
.54902 .59607 Mdot
.54509 .59607 Mdot
.54902 .59607 Mdot
.54902 .59607 Mdot
.54509 .59215 Mdot
.54509 .59215 Mdot
.53725 .58431 Mdot
.52941 .58039 Mdot
.51765 .56862 Mdot
.51765 .57646 Mdot
.51765 .58039 Mdot
.51372 .57254 Mdot
.51372 .5647 Mdot
.50588 .55686 Mdot
.50588 .56078 Mdot
.50588 .55686 Mdot
.4902 .54509 Mdot
.48628 .54117 Mdot
.48235 .53333 Mdot
.47451 .52549 Mdot
.47059 .51765 Mdot
.45883 .51765 Mdot
.45491 .51372 Mdot
.44314 .50196 Mdot
.43138 .50196 Mdot
.40785 .46667 Mdot
.44706 .52157 Mdot
.45883 .54117 Mdot
.47059 .54117 Mdot
.46667 .54117 Mdot
.46667 .53725 Mdot
.45098 .52157 Mdot
.45491 .52157 Mdot
.45883 .52941 Mdot
.47843 .54902 Mdot
.47451 .54117 Mdot
.48628 .54902 Mdot
.49412 .55686 Mdot
.4902 .54902 Mdot
.5098 .56078 Mdot
.51765 .5647 Mdot
.52157 .56862 Mdot
.53333 .57646 Mdot
.5098 .55294 Mdot
.51765 .5647 Mdot
.52157 .56862 Mdot
.52157 .56862 Mdot
.51765 .56862 Mdot
.53725 .58039 Mdot
.53333 .57254 Mdot
.54117 .56862 Mdot
.54117 .57646 Mdot
.53333 .57646 Mdot
.54902 .58823 Mdot
.55686 .59215 Mdot
.56862 .59999 Mdot
.57254 .59607 Mdot
.58039 .59999 Mdot
.56862 .58823 Mdot
.57254 .59215 Mdot
.57254 .59999 Mdot
.57254 .60391 Mdot
.57254 .60783 Mdot
.57254 .61176 Mdot
.57254 .61176 Mdot
.57646 .62352 Mdot
.56862 .61568 Mdot
.58039 .63136 Mdot
.58039 .63136 Mdot
.58039 .62744 Mdot
.58823 .63136 Mdot
.59215 .63528 Mdot
.59607 .63528 Mdot
.58823 .62744 Mdot
.61568 .65097 Mdot
.61568 .64313 Mdot
.61568 .64313 Mdot
.61176 .6392 Mdot
.61568 .64705 Mdot
.60783 .64705 Mdot
.61568 .65489 Mdot
.6196 .65489 Mdot
.62744 .65489 Mdot
.62352 .65489 Mdot
.6196 .65097 Mdot
.62352 .65489 Mdot
.62352 .65097 Mdot
.63136 .65881 Mdot
.6392 .66273 Mdot
.6392 .66273 Mdot
.6392 .66273 Mdot
.63528 .65881 Mdot
.63528 .65881 Mdot
.63528 .65881 Mdot
.6392 .65881 Mdot
.64313 .66273 Mdot
.64313 .65881 Mdot
.6392 .65881 Mdot
.63528 .65881 Mdot
.63528 .65881 Mdot
.63528 .65881 Mdot
.63136 .65097 Mdot
.63528 .65489 Mdot
.63528 .65489 Mdot
.65097 .67057 Mdot
.64313 .66273 Mdot
.6392 .65881 Mdot
.64705 .66665 Mdot
.64313 .65881 Mdot
.64313 .65881 Mdot
.65097 .66665 Mdot
.65489 .67057 Mdot
.65489 .66665 Mdot
.65489 .66665 Mdot
.64705 .66665 Mdot
.64705 .66273 Mdot
.64705 .66273 Mdot
.64313 .65881 Mdot
.65489 .6745 Mdot
.64705 .66273 Mdot
.6392 .65489 Mdot
.63528 .66273 Mdot
.63136 .66273 Mdot
.6392 .67057 Mdot
.6392 .66665 Mdot
.64313 .67057 Mdot
.64313 .67057 Mdot
.63136 .65881 Mdot
.6392 .66665 Mdot
.64313 .67057 Mdot
.6392 .66665 Mdot
.63528 .65881 Mdot
.64313 .66665 Mdot
.64313 .66665 Mdot
.63528 .66273 Mdot
.63528 .65097 Mdot
.63528 .65489 Mdot
.63528 .65881 Mdot
.63136 .65097 Mdot
.6196 .64313 Mdot
.62352 .65097 Mdot
.6196 .6392 Mdot
.62744 .65097 Mdot
.61176 .64313 Mdot
.60783 .6392 Mdot
.60783 .6392 Mdot
.60783 .64313 Mdot
.60391 .6392 Mdot
.59607 .63528 Mdot
.59215 .62352 Mdot
.59607 .62744 Mdot
.59999 .63136 Mdot
.59215 .62352 Mdot
.59999 .63528 Mdot
.59215 .62744 Mdot
.58431 .6196 Mdot
.57646 .61176 Mdot
.56862 .61176 Mdot
.56078 .60391 Mdot
.56862 .61176 Mdot
.57254 .61568 Mdot
.56078 .60783 Mdot
.55686 .60783 Mdot
.54509 .59607 Mdot
.54509 .59215 Mdot
.54902 .59215 Mdot
.54509 .58823 Mdot
.53333 .57254 Mdot
.52549 .57254 Mdot
.52549 .57646 Mdot
.52157 .57646 Mdot
.52549 .58431 Mdot
.52549 .56862 Mdot
.52157 .5647 Mdot
.50588 .54902 Mdot
.4902 .53333 Mdot
.47843 .52549 Mdot
.47451 .52549 Mdot
.47059 .52941 Mdot
.47451 .53333 Mdot
.47059 .53333 Mdot
.46667 .53333 Mdot
.45491 .52549 Mdot
.45098 .52157 Mdot
.43138 .50588 Mdot
.39609 .45883 Mdot
.44706 .52157 Mdot
.45098 .53333 Mdot
.45883 .54117 Mdot
.45491 .52549 Mdot
.44314 .51765 Mdot
.4353 .5098 Mdot
.45491 .53333 Mdot
.45098 .52941 Mdot
.45883 .53333 Mdot
.46667 .54117 Mdot
.46667 .53725 Mdot
.47059 .53333 Mdot
.4902 .55294 Mdot
.4902 .53725 Mdot
.50588 .55294 Mdot
.5098 .5647 Mdot
.51765 .56862 Mdot
.51765 .56862 Mdot
.51765 .56862 Mdot
.52549 .57646 Mdot
.52941 .58431 Mdot
.52941 .58431 Mdot
.53333 .58823 Mdot
.53333 .58039 Mdot
.53725 .58431 Mdot
.52941 .57254 Mdot
.53725 .58431 Mdot
.54117 .58039 Mdot
.54902 .58823 Mdot
.55686 .59215 Mdot
.55686 .59215 Mdot
.56862 .59607 Mdot
.56862 .59999 Mdot
.5647 .59215 Mdot
.5647 .59999 Mdot
.56078 .59607 Mdot
.56862 .60391 Mdot
.5647 .60391 Mdot
.56862 .61176 Mdot
.57646 .61568 Mdot
.57254 .61568 Mdot
.57646 .6196 Mdot
.57646 .6196 Mdot
.57254 .61568 Mdot
.58039 .6196 Mdot
.59607 .6392 Mdot
.59607 .6392 Mdot
.59215 .63136 Mdot
.59215 .62744 Mdot
.59999 .63528 Mdot
.59607 .63136 Mdot
.59607 .63528 Mdot
.60391 .64705 Mdot
.60783 .65489 Mdot
.60391 .65097 Mdot
.59999 .64313 Mdot
.61176 .65881 Mdot
.60391 .65097 Mdot
.61568 .65489 Mdot
.61176 .64705 Mdot
.62352 .65881 Mdot
.62744 .66273 Mdot
.62744 .65489 Mdot
.6196 .65097 Mdot
.62352 .65097 Mdot
.63136 .65881 Mdot
.62352 .65097 Mdot
.63136 .65489 Mdot
.62744 .64705 Mdot
.63136 .65097 Mdot
.62744 .64313 Mdot
.63528 .65881 Mdot
.63136 .65881 Mdot
.62352 .65097 Mdot
.62352 .65489 Mdot
.6196 .65097 Mdot
.62352 .65097 Mdot
.63136 .66273 Mdot
.63528 .66665 Mdot
.63528 .66273 Mdot
.63528 .66665 Mdot
.63136 .66273 Mdot
.62744 .65881 Mdot
.63528 .66273 Mdot
.6392 .66665 Mdot
.64705 .67057 Mdot
.6392 .65489 Mdot
.64313 .66273 Mdot
.63528 .66273 Mdot
.63528 .66273 Mdot
.63136 .65097 Mdot
.62744 .64705 Mdot
.6392 .65489 Mdot
.63528 .65489 Mdot
.64313 .66273 Mdot
.6392 .66273 Mdot
.63136 .66273 Mdot
.63136 .66273 Mdot
.62352 .65881 Mdot
.63136 .65881 Mdot
.63136 .66665 Mdot
.63136 .66273 Mdot
.62352 .65881 Mdot
.62352 .66273 Mdot
.62352 .65097 Mdot
.62744 .65881 Mdot
.64313 .67057 Mdot
.64313 .67057 Mdot
.63528 .66665 Mdot
.62352 .65097 Mdot
.61568 .64705 Mdot
.61568 .65097 Mdot
.62744 .65489 Mdot
.6196 .64705 Mdot
.61568 .65097 Mdot
.62352 .65881 Mdot
.61568 .64705 Mdot
.60391 .63136 Mdot
.60391 .63528 Mdot
.60391 .63528 Mdot
.59999 .63528 Mdot
.59607 .63136 Mdot
.58823 .63136 Mdot
.58823 .62352 Mdot
.59215 .6196 Mdot
.59607 .62352 Mdot
.58431 .61568 Mdot
.58823 .62352 Mdot
.57646 .60783 Mdot
.57646 .61568 Mdot
.57254 .61176 Mdot
.5647 .60783 Mdot
.55294 .59607 Mdot
.54902 .59607 Mdot
.56078 .60391 Mdot
.55294 .59607 Mdot
.56078 .59999 Mdot
.55294 .59607 Mdot
.54117 .58823 Mdot
.54117 .58039 Mdot
.52941 .56862 Mdot
.52157 .56078 Mdot
.52157 .56862 Mdot
.51765 .5647 Mdot
.5098 .56862 Mdot
.50588 .5647 Mdot
.50588 .56078 Mdot
.5098 .55686 Mdot
.51372 .54902 Mdot
.5098 .55294 Mdot
.48628 .54117 Mdot
.47059 .53725 Mdot
.46667 .53725 Mdot
.46275 .52941 Mdot
.45491 .52157 Mdot
.45491 .52549 Mdot
.44706 .52157 Mdot
.4353 .5098 Mdot
.4353 .51765 Mdot
.41177 .46667 Mdot
.4353 .50196 Mdot
.4353 .51765 Mdot
.43922 .52157 Mdot
.44706 .52549 Mdot
.45491 .52941 Mdot
.44706 .52549 Mdot
.44314 .52549 Mdot
.43138 .5098 Mdot
.44706 .52549 Mdot
.45883 .54117 Mdot
.45883 .52941 Mdot
.47451 .54509 Mdot
.48628 .54902 Mdot
.48628 .54509 Mdot
.50196 .56078 Mdot
.50196 .55686 Mdot
.50588 .55686 Mdot
.49804 .54902 Mdot
.49804 .56078 Mdot
.49804 .56078 Mdot
.50588 .56862 Mdot
.5098 .57254 Mdot
.5098 .56862 Mdot
.51372 .57254 Mdot
.52157 .57646 Mdot
.53333 .58039 Mdot
.53725 .57646 Mdot
.54117 .58039 Mdot
.54509 .58823 Mdot
.53725 .57646 Mdot
.53725 .57646 Mdot
.55294 .58823 Mdot
.5647 .60391 Mdot
.56078 .59999 Mdot
.55294 .59607 Mdot
.5647 .61176 Mdot
.56078 .60391 Mdot
.56862 .61176 Mdot
.55686 .59607 Mdot
.55686 .59999 Mdot
.55686 .59999 Mdot
.55294 .59999 Mdot
.56078 .61176 Mdot
.5647 .61176 Mdot
.57646 .6196 Mdot
.58039 .62352 Mdot
.58431 .62352 Mdot
.59215 .62744 Mdot
.57646 .61176 Mdot
.58039 .61176 Mdot
.58431 .61176 Mdot
.58431 .62352 Mdot
.58823 .62744 Mdot
.58431 .62744 Mdot
.58039 .62744 Mdot
.57646 .63528 Mdot
.58431 .63528 Mdot
.58431 .62744 Mdot
.58039 .62352 Mdot
.59999 .6392 Mdot
.59215 .63136 Mdot
.59607 .6392 Mdot
.61176 .64705 Mdot
.61176 .64313 Mdot
.61176 .64313 Mdot
.61176 .64705 Mdot
.61568 .65097 Mdot
.61176 .64313 Mdot
.61176 .64705 Mdot
.60783 .6392 Mdot
.61568 .64313 Mdot
.61568 .64705 Mdot
.6196 .65489 Mdot
.61176 .65097 Mdot
.61568 .65097 Mdot
.62352 .65489 Mdot
.62352 .65097 Mdot
.6196 .65097 Mdot
.62352 .65881 Mdot
.62352 .65881 Mdot
.63136 .66273 Mdot
.6196 .65097 Mdot
.62744 .65881 Mdot
.62352 .65489 Mdot
.6196 .64705 Mdot
.62352 .64705 Mdot
.6196 .64705 Mdot
.6196 .65097 Mdot
.61568 .64705 Mdot
.62352 .65489 Mdot
.6196 .65489 Mdot
.61176 .64313 Mdot
.6196 .64313 Mdot
.62744 .65489 Mdot
.6196 .65097 Mdot
.62352 .65489 Mdot
.61568 .65097 Mdot
.61568 .65097 Mdot
.61568 .65097 Mdot
.61176 .65097 Mdot
.6196 .65489 Mdot
.62744 .66665 Mdot
.6196 .66273 Mdot
.61568 .65489 Mdot
.61176 .6392 Mdot
.61176 .64705 Mdot
.61568 .64705 Mdot
.61568 .64705 Mdot
.6196 .65097 Mdot
.6196 .64705 Mdot
.61176 .64313 Mdot
.60783 .63528 Mdot
.60783 .6392 Mdot
.60783 .6392 Mdot
.60783 .64313 Mdot
.60783 .64705 Mdot
.59999 .63528 Mdot
.58823 .62744 Mdot
.58431 .6196 Mdot
.59215 .62352 Mdot
.58823 .62352 Mdot
.58823 .63136 Mdot
.58039 .62352 Mdot
.57646 .61568 Mdot
.58039 .61176 Mdot
.56862 .60391 Mdot
.5647 .61176 Mdot
.55686 .59999 Mdot
.55686 .59999 Mdot
.56078 .60391 Mdot
.5647 .61176 Mdot
.55686 .60391 Mdot
.55686 .60391 Mdot
.54902 .59215 Mdot
.54117 .58039 Mdot
.53725 .56862 Mdot
.54117 .57646 Mdot
.53725 .57254 Mdot
.52941 .57254 Mdot
.52549 .56862 Mdot
.52157 .56862 Mdot
.50588 .55686 Mdot
.50196 .55294 Mdot
.50588 .5647 Mdot
.49804 .56078 Mdot
.4902 .55686 Mdot
.49804 .56078 Mdot
.50196 .5647 Mdot
.49412 .54902 Mdot
.4902 .54509 Mdot
.47451 .52549 Mdot
.46275 .52941 Mdot
.47059 .54117 Mdot
.45098 .51765 Mdot
.44706 .51372 Mdot
.44314 .51765 Mdot
.43922 .51372 Mdot
.43138 .50588 Mdot
.41177 .4902 Mdot
.40001 .45098 Mdot
.41961 .4902 Mdot
.43138 .51765 Mdot
.4353 .52157 Mdot
.44314 .51765 Mdot
.46275 .52941 Mdot
.45491 .52157 Mdot
.45098 .52549 Mdot
.44706 .52941 Mdot
.45491 .54117 Mdot
.45883 .54509 Mdot
.47059 .54902 Mdot
.47059 .54509 Mdot
.47843 .54902 Mdot
.48235 .54902 Mdot
.49412 .55686 Mdot
.49804 .5647 Mdot
.50196 .56862 Mdot
.5098 .56862 Mdot
.49412 .55294 Mdot
.49804 .55686 Mdot
.50588 .56862 Mdot
.50588 .56862 Mdot
.5098 .57646 Mdot
.50588 .57254 Mdot
.5098 .56862 Mdot
.52941 .58039 Mdot
.53333 .58431 Mdot
.52941 .58039 Mdot
.53333 .58431 Mdot
.54902 .59999 Mdot
.54902 .59999 Mdot
.54902 .59607 Mdot
.55294 .59215 Mdot
.55686 .59607 Mdot
.54902 .59215 Mdot
.54509 .59215 Mdot
.55294 .59999 Mdot
.56078 .60391 Mdot
.5647 .61176 Mdot
.56078 .61176 Mdot
.55294 .60783 Mdot
.55294 .60391 Mdot
.55686 .61176 Mdot
.56078 .61568 Mdot
.56862 .61568 Mdot
.58039 .6196 Mdot
.58039 .61568 Mdot
.59215 .62352 Mdot
.58823 .6196 Mdot
.58431 .61568 Mdot
.58431 .61568 Mdot
.58823 .6196 Mdot
.57646 .61176 Mdot
.58039 .63136 Mdot
.58431 .63528 Mdot
.58039 .63136 Mdot
.59215 .63528 Mdot
.60391 .64705 Mdot
.59607 .63136 Mdot
.59607 .63136 Mdot
.59215 .62744 Mdot
.60391 .63136 Mdot
.59999 .62744 Mdot
.60391 .63528 Mdot
.61568 .64705 Mdot
.6196 .65489 Mdot
.61176 .65097 Mdot
.60391 .64705 Mdot
.61568 .65489 Mdot
.61568 .65489 Mdot
.61176 .64313 Mdot
.61568 .65097 Mdot
.6196 .65489 Mdot
.6196 .65881 Mdot
.61176 .65097 Mdot
.62352 .65489 Mdot
.6196 .65097 Mdot
.62352 .65489 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.63136 .65881 Mdot
.63136 .65489 Mdot
.63136 .65881 Mdot
.62352 .65881 Mdot
.62352 .65881 Mdot
.62744 .66273 Mdot
.62744 .66273 Mdot
.6196 .66273 Mdot
.61176 .65489 Mdot
.60783 .65489 Mdot
.61568 .66273 Mdot
.61176 .65489 Mdot
.61176 .64705 Mdot
.61568 .64313 Mdot
.61568 .64705 Mdot
.60783 .64313 Mdot
.6196 .65881 Mdot
.61568 .66273 Mdot
.6196 .66273 Mdot
.6196 .66273 Mdot
.62352 .67057 Mdot
.62744 .6745 Mdot
.63136 .6745 Mdot
.63528 .67057 Mdot
.63136 .67057 Mdot
.63136 .66665 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.63136 .66273 Mdot
.62352 .65489 Mdot
.61568 .64313 Mdot
.62352 .64705 Mdot
.61568 .64313 Mdot
.62352 .65881 Mdot
.6196 .65881 Mdot
.6196 .65881 Mdot
.61176 .64705 Mdot
.60783 .64705 Mdot
.60391 .6392 Mdot
.60391 .6392 Mdot
.59215 .63136 Mdot
.59215 .62744 Mdot
.58823 .63136 Mdot
.58431 .62744 Mdot
.57254 .6196 Mdot
.56862 .61568 Mdot
.56862 .6196 Mdot
.56862 .62352 Mdot
.57254 .6196 Mdot
.57254 .61176 Mdot
.57254 .61176 Mdot
.5647 .60391 Mdot
.55686 .59999 Mdot
.55294 .59607 Mdot
.55686 .59999 Mdot
.54902 .59215 Mdot
.55686 .60391 Mdot
.54509 .59607 Mdot
.53333 .58823 Mdot
.52941 .58823 Mdot
.52549 .58039 Mdot
.51372 .5647 Mdot
.51765 .57254 Mdot
.51765 .56862 Mdot
.51765 .57646 Mdot
.49804 .5647 Mdot
.4902 .55294 Mdot
.48628 .55686 Mdot
.4902 .56078 Mdot
.4902 .55686 Mdot
.47451 .53333 Mdot
.47059 .52941 Mdot
.47843 .54509 Mdot
.46275 .52941 Mdot
.46275 .53725 Mdot
.45491 .53333 Mdot
.44706 .52549 Mdot
.44314 .52549 Mdot
.43922 .52157 Mdot
.41569 .45883 Mdot
.45883 .52157 Mdot
.46275 .53333 Mdot
.45883 .52549 Mdot
.45098 .51372 Mdot
.45883 .52549 Mdot
.46667 .53333 Mdot
.46667 .52941 Mdot
.45883 .52941 Mdot
.45098 .52941 Mdot
.46667 .54117 Mdot
.48235 .54509 Mdot
.47843 .54117 Mdot
.4902 .54902 Mdot
.49412 .56078 Mdot
.49804 .56078 Mdot
.50196 .5647 Mdot
.5098 .56078 Mdot
.51765 .56078 Mdot
.52549 .56862 Mdot
.52157 .56862 Mdot
.51765 .56078 Mdot
.51765 .5647 Mdot
.51765 .5647 Mdot
.52549 .57646 Mdot
.52549 .57646 Mdot
.52941 .57646 Mdot
.53333 .57254 Mdot
.53725 .56862 Mdot
.54117 .58039 Mdot
.54117 .58431 Mdot
.54902 .59607 Mdot
.5647 .60783 Mdot
.55294 .59215 Mdot
.56078 .59999 Mdot
.56078 .59999 Mdot
.55294 .59215 Mdot
.54902 .58431 Mdot
.54902 .58431 Mdot
.5647 .59999 Mdot
.56862 .60783 Mdot
.56078 .60391 Mdot
.55294 .59999 Mdot
.5647 .61176 Mdot
.57646 .6196 Mdot
.58039 .61176 Mdot
.58823 .61568 Mdot
.59607 .6196 Mdot
.59607 .62352 Mdot
.59215 .61568 Mdot
.59607 .6196 Mdot
.59215 .61176 Mdot
.60783 .62744 Mdot
.59215 .61176 Mdot
.59607 .62352 Mdot
.60391 .6392 Mdot
.60391 .63528 Mdot
.59607 .6196 Mdot
.60391 .62744 Mdot
.61176 .64313 Mdot
.61176 .6392 Mdot
.60391 .63136 Mdot
.61176 .63528 Mdot
.61176 .63136 Mdot
.61176 .62352 Mdot
.6196 .63136 Mdot
.6196 .6392 Mdot
.6196 .6392 Mdot
.62352 .64705 Mdot
.6196 .6392 Mdot
.62744 .65097 Mdot
.61568 .64313 Mdot
.60783 .63136 Mdot
.62352 .65097 Mdot
.63136 .65881 Mdot
.6196 .64313 Mdot
.62744 .64705 Mdot
.63528 .65489 Mdot
.63136 .64705 Mdot
.63136 .65097 Mdot
.63136 .65489 Mdot
.6392 .65881 Mdot
.6392 .65881 Mdot
.63528 .65881 Mdot
.62352 .64313 Mdot
.62352 .65097 Mdot
.62352 .65097 Mdot
.61568 .64705 Mdot
.6196 .65097 Mdot
.61568 .65097 Mdot
.61568 .65097 Mdot
.6196 .65881 Mdot
.61176 .64705 Mdot
.63136 .65881 Mdot
.63136 .65489 Mdot
.62744 .64705 Mdot
.61568 .6392 Mdot
.61568 .64313 Mdot
.61568 .6392 Mdot
.62352 .65489 Mdot
.62744 .65489 Mdot
.63136 .65489 Mdot
.6196 .65097 Mdot
.62352 .65489 Mdot
.62744 .64705 Mdot
.62744 .65097 Mdot
.62744 .65489 Mdot
.62744 .65881 Mdot
.63136 .65881 Mdot
.62352 .65097 Mdot
.62744 .65097 Mdot
.62744 .64705 Mdot
.61568 .63136 Mdot
.61568 .63136 Mdot
.61176 .63136 Mdot
.6196 .6392 Mdot
.6196 .6392 Mdot
.61176 .63136 Mdot
.60391 .63136 Mdot
.59999 .63136 Mdot
.59999 .62744 Mdot
.60391 .62744 Mdot
.59999 .62352 Mdot
.59215 .61568 Mdot
.58431 .61568 Mdot
.57646 .61176 Mdot
.57646 .61568 Mdot
.58039 .6196 Mdot
.58039 .61568 Mdot
.57646 .60783 Mdot
.56862 .59215 Mdot
.56078 .58431 Mdot
.56078 .58823 Mdot
.56078 .59215 Mdot
.54509 .57646 Mdot
.54902 .57646 Mdot
.54509 .57646 Mdot
.54509 .58823 Mdot
.54117 .58431 Mdot
.53333 .58039 Mdot
.52549 .57254 Mdot
.52549 .57646 Mdot
.51765 .56078 Mdot
.51765 .56078 Mdot
.52157 .5647 Mdot
.50196 .54902 Mdot
.48235 .53333 Mdot
.48628 .54509 Mdot
.48235 .54509 Mdot
.47843 .54117 Mdot
.47059 .52549 Mdot
.47059 .51765 Mdot
.47451 .52549 Mdot
.46667 .52157 Mdot
.45883 .5098 Mdot
.46667 .52549 Mdot
.45883 .51765 Mdot
.45491 .51765 Mdot
.43922 .50588 Mdot
.41569 .48628 Mdot
.39609 .42746 Mdot
.43922 .49412 Mdot
.44706 .50588 Mdot
.43922 .50196 Mdot
.45491 .51372 Mdot
.45098 .50588 Mdot
.45098 .50588 Mdot
.46275 .52157 Mdot
.46667 .52549 Mdot
.46667 .52941 Mdot
.46667 .52941 Mdot
.47451 .52941 Mdot
.48235 .54117 Mdot
.48628 .54902 Mdot
.48628 .54902 Mdot
.49412 .55294 Mdot
.50196 .55294 Mdot
.51765 .56862 Mdot
.5098 .55294 Mdot
.52549 .5647 Mdot
.51765 .55686 Mdot
.51765 .56078 Mdot
.51765 .56862 Mdot
.5098 .56078 Mdot
.5098 .56078 Mdot
.51765 .56862 Mdot
.52157 .57646 Mdot
.52549 .58039 Mdot
.53333 .58039 Mdot
.53725 .57646 Mdot
.54509 .58039 Mdot
.54902 .58039 Mdot
.55294 .59607 Mdot
.54902 .59607 Mdot
.55686 .59607 Mdot
.5647 .59999 Mdot
.54902 .58823 Mdot
.54509 .58823 Mdot
.55294 .59607 Mdot
.56862 .60783 Mdot
.56078 .59999 Mdot
.55294 .58823 Mdot
.56078 .59607 Mdot
.56078 .59999 Mdot
.57254 .61176 Mdot
.57646 .61568 Mdot
.57646 .61176 Mdot
.58039 .61568 Mdot
.58431 .61568 Mdot
.58823 .61568 Mdot
.59999 .62744 Mdot
.59215 .61568 Mdot
.59999 .6196 Mdot
.59607 .61568 Mdot
.59607 .6196 Mdot
.59607 .6196 Mdot
.59607 .6196 Mdot
.60391 .62744 Mdot
.61176 .63136 Mdot
.60783 .62744 Mdot
.60391 .62744 Mdot
.60783 .63136 Mdot
.61568 .63528 Mdot
.6196 .63528 Mdot
.6196 .63136 Mdot
.6196 .63528 Mdot
.61176 .63136 Mdot
.60783 .63136 Mdot
.61568 .6392 Mdot
.61176 .6392 Mdot
.61176 .63528 Mdot
.6196 .64705 Mdot
.6196 .64705 Mdot
.6196 .65097 Mdot
.62744 .64705 Mdot
.63136 .65097 Mdot
.63136 .64705 Mdot
.63136 .6392 Mdot
.6196 .62744 Mdot
.62352 .63528 Mdot
.62744 .64313 Mdot
.63528 .65097 Mdot
.62744 .64313 Mdot
.63136 .64705 Mdot
.63136 .64313 Mdot
.63136 .64313 Mdot
.62744 .6392 Mdot
.63136 .64705 Mdot
.62744 .64313 Mdot
.62744 .64313 Mdot
.63136 .65097 Mdot
.63136 .65489 Mdot
.63528 .65881 Mdot
.63528 .65881 Mdot
.62352 .6392 Mdot
.6196 .63528 Mdot
.63136 .64705 Mdot
.62744 .64705 Mdot
.61176 .63528 Mdot
.61568 .64705 Mdot
.62744 .64705 Mdot
.63136 .65097 Mdot
.6196 .63136 Mdot
.62352 .63528 Mdot
.62744 .64313 Mdot
.62352 .63136 Mdot
.63528 .64313 Mdot
.63136 .64313 Mdot
.6196 .63528 Mdot
.61568 .6392 Mdot
.60783 .63136 Mdot
.61568 .6392 Mdot
.61568 .63528 Mdot
.59999 .6196 Mdot
.60783 .63528 Mdot
.60783 .63136 Mdot
.60391 .62744 Mdot
.59999 .62744 Mdot
.59999 .63136 Mdot
.59607 .62352 Mdot
.59607 .62352 Mdot
.59999 .62352 Mdot
.59999 .61176 Mdot
.60391 .62352 Mdot
.58431 .61176 Mdot
.58039 .60783 Mdot
.57646 .60783 Mdot
.5647 .59215 Mdot
.58039 .60783 Mdot
.58431 .60783 Mdot
.57254 .58823 Mdot
.55686 .57646 Mdot
.5647 .58823 Mdot
.55686 .58039 Mdot
.55686 .58823 Mdot
.54902 .57646 Mdot
.53333 .56862 Mdot
.53725 .58039 Mdot
.52941 .57254 Mdot
.52549 .56862 Mdot
.52941 .57646 Mdot
.51372 .55294 Mdot
.52157 .56078 Mdot
.51765 .55294 Mdot
.51765 .54902 Mdot
.50588 .53725 Mdot
.4902 .53333 Mdot
.49412 .54117 Mdot
.50588 .55686 Mdot
.48628 .53333 Mdot
.48235 .52941 Mdot
.46667 .51372 Mdot
.45883 .50588 Mdot
.47059 .51765 Mdot
.46667 .5098 Mdot
.45883 .50588 Mdot
.45098 .50196 Mdot
.44314 .50196 Mdot
.4353 .50588 Mdot
.41177 .48628 Mdot
.39609 .4353 Mdot
.4353 .48628 Mdot
.45098 .51372 Mdot
.45491 .51765 Mdot
.44706 .5098 Mdot
.45491 .5098 Mdot
.45098 .5098 Mdot
.47059 .52941 Mdot
.47451 .53725 Mdot
.48235 .54509 Mdot
.47451 .54117 Mdot
.47451 .54509 Mdot
.47843 .54509 Mdot
.48628 .55294 Mdot
.4902 .55294 Mdot
.49804 .56078 Mdot
.50196 .55294 Mdot
.5098 .55686 Mdot
.49804 .54509 Mdot
.50588 .55294 Mdot
.51372 .55686 Mdot
.51765 .55686 Mdot
.5098 .56078 Mdot
.5098 .5647 Mdot
.50588 .5647 Mdot
.50196 .56862 Mdot
.50588 .57254 Mdot
.51372 .57646 Mdot
.52549 .58431 Mdot
.52941 .58039 Mdot
.52941 .58039 Mdot
.54117 .58039 Mdot
.53725 .58431 Mdot
.53725 .58431 Mdot
.54117 .58431 Mdot
.54509 .58431 Mdot
.56078 .59607 Mdot
.56078 .59607 Mdot
.55686 .59999 Mdot
.56862 .61568 Mdot
.5647 .60783 Mdot
.5647 .60391 Mdot
.55686 .59215 Mdot
.5647 .60391 Mdot
.5647 .60391 Mdot
.57254 .61568 Mdot
.5647 .61176 Mdot
.56862 .61176 Mdot
.56078 .59999 Mdot
.58039 .61568 Mdot
.59215 .62352 Mdot
.59215 .61568 Mdot
.58823 .61176 Mdot
.58823 .61568 Mdot
.59215 .61176 Mdot
.59999 .6196 Mdot
.59999 .61568 Mdot
.59215 .61176 Mdot
.60391 .62352 Mdot
.61176 .63528 Mdot
.61176 .6392 Mdot
.61176 .6392 Mdot
.61176 .63136 Mdot
.60783 .62744 Mdot
.61176 .6392 Mdot
.60783 .63136 Mdot
.60391 .63136 Mdot
.59999 .63528 Mdot
.60783 .6392 Mdot
.60783 .6392 Mdot
.60391 .63528 Mdot
.60783 .65097 Mdot
.60391 .65097 Mdot
.60391 .64313 Mdot
.60783 .63528 Mdot
.62352 .64313 Mdot
.62744 .64705 Mdot
.62744 .64313 Mdot
.6196 .6392 Mdot
.63136 .65097 Mdot
.62744 .64313 Mdot
.63528 .65097 Mdot
.63528 .65097 Mdot
.63136 .64705 Mdot
.63136 .64313 Mdot
.62744 .64313 Mdot
.63528 .65097 Mdot
.62744 .64313 Mdot
.62352 .6392 Mdot
.6196 .6392 Mdot
.6196 .65097 Mdot
.61176 .64313 Mdot
.61568 .64313 Mdot
.61568 .64313 Mdot
.61568 .6392 Mdot
.61568 .6392 Mdot
.61568 .64313 Mdot
.61568 .64705 Mdot
.61568 .64313 Mdot
.6196 .64705 Mdot
.61568 .63136 Mdot
.62352 .6392 Mdot
.62352 .6392 Mdot
.61176 .62352 Mdot
.62352 .63136 Mdot
.62352 .63528 Mdot
.62352 .63528 Mdot
.62744 .64313 Mdot
.6196 .64313 Mdot
.61176 .6392 Mdot
.59607 .6196 Mdot
.59607 .6196 Mdot
.60391 .63528 Mdot
.59999 .62352 Mdot
.59999 .62744 Mdot
.59999 .63136 Mdot
.59999 .63528 Mdot
.58823 .6196 Mdot
.58039 .61176 Mdot
.58431 .6196 Mdot
.59215 .62744 Mdot
.59215 .62352 Mdot
.58431 .61568 Mdot
.58431 .61568 Mdot
.58431 .61176 Mdot
.57254 .60391 Mdot
.5647 .59999 Mdot
.55686 .58431 Mdot
.5647 .59999 Mdot
.5647 .59215 Mdot
.56078 .58431 Mdot
.55294 .57646 Mdot
.54902 .57254 Mdot
.53333 .5647 Mdot
.53333 .5647 Mdot
.53725 .57254 Mdot
.52941 .5647 Mdot
.52941 .57646 Mdot
.52157 .57646 Mdot
.51765 .57254 Mdot
.51372 .56862 Mdot
.50196 .56078 Mdot
.51372 .56862 Mdot
.50196 .55294 Mdot
.5098 .55294 Mdot
.50588 .54902 Mdot
.49804 .54509 Mdot
.4902 .53725 Mdot
.4902 .53725 Mdot
.48235 .52941 Mdot
.47843 .51765 Mdot
.47451 .51372 Mdot
.45883 .50196 Mdot
.45883 .50588 Mdot
.46275 .51372 Mdot
.44314 .50196 Mdot
.4353 .49804 Mdot
.43138 .50196 Mdot
.41569 .4902 Mdot
.40393 .48628 Mdot
.38824 .4353 Mdot
.4353 .4902 Mdot
.45491 .50196 Mdot
.45491 .50588 Mdot
.45098 .50588 Mdot
.45098 .50196 Mdot
.46275 .51372 Mdot
.47843 .53333 Mdot
.48628 .54117 Mdot
.47843 .53725 Mdot
.47451 .53725 Mdot
.47059 .54117 Mdot
.46275 .53725 Mdot
.47451 .54117 Mdot
.48235 .54509 Mdot
.49804 .55294 Mdot
.5098 .55686 Mdot
.5098 .55294 Mdot
.50196 .54902 Mdot
.50588 .55686 Mdot
.50196 .54902 Mdot
.51765 .5647 Mdot
.52157 .57254 Mdot
.51372 .56862 Mdot
.50588 .5647 Mdot
.50588 .5647 Mdot
.50196 .56862 Mdot
.5098 .57254 Mdot
.51372 .57254 Mdot
.51765 .56862 Mdot
.52157 .5647 Mdot
.53333 .57646 Mdot
.54902 .59607 Mdot
.55294 .59607 Mdot
.55686 .59607 Mdot
.55686 .58823 Mdot
.5647 .59607 Mdot
.56078 .59607 Mdot
.5647 .60783 Mdot
.55686 .59999 Mdot
.55686 .60391 Mdot
.55294 .59215 Mdot
.5647 .59607 Mdot
.5647 .59215 Mdot
.57254 .59607 Mdot
.5647 .59607 Mdot
.55294 .59215 Mdot
.56078 .59999 Mdot
.56862 .60783 Mdot
.57254 .59999 Mdot
.58039 .61176 Mdot
.58823 .60783 Mdot
.57646 .59999 Mdot
.58431 .61176 Mdot
.58823 .61568 Mdot
.59607 .6196 Mdot
.59607 .61176 Mdot
.59215 .61176 Mdot
.59999 .6196 Mdot
.59607 .6196 Mdot
.59999 .62744 Mdot
.59607 .62352 Mdot
.60783 .63136 Mdot
.61568 .6392 Mdot
.61176 .63136 Mdot
.60783 .6392 Mdot
.60783 .64313 Mdot
.59215 .62352 Mdot
.59607 .62352 Mdot
.60391 .63528 Mdot
.60783 .63528 Mdot
.60783 .6392 Mdot
.59607 .63528 Mdot
.59999 .64313 Mdot
.60391 .64313 Mdot
.60391 .6392 Mdot
.61568 .64705 Mdot
.62352 .65097 Mdot
.62744 .65489 Mdot
.62744 .65097 Mdot
.62352 .64705 Mdot
.62352 .64313 Mdot
.62352 .63528 Mdot
.63136 .6392 Mdot
.62744 .64313 Mdot
.62744 .64705 Mdot
.62744 .65097 Mdot
.61568 .63528 Mdot
.61176 .62352 Mdot
.61568 .63528 Mdot
.61176 .63528 Mdot
.59999 .62744 Mdot
.60783 .6392 Mdot
.61176 .64313 Mdot
.61568 .64313 Mdot
.6196 .64705 Mdot
.61176 .63136 Mdot
.60391 .62744 Mdot
.61176 .6392 Mdot
.61568 .64705 Mdot
.60783 .63136 Mdot
.6196 .6392 Mdot
.62352 .64313 Mdot
.62352 .6392 Mdot
.61176 .62352 Mdot
.60783 .62352 Mdot
.60391 .6196 Mdot
.61568 .62744 Mdot
.62352 .64313 Mdot
.61176 .63528 Mdot
.59607 .6196 Mdot
.59215 .61568 Mdot
.59215 .62352 Mdot
.59607 .63136 Mdot
.59215 .6196 Mdot
.58431 .61176 Mdot
.58823 .6196 Mdot
.58823 .6196 Mdot
.57646 .61568 Mdot
.57646 .61568 Mdot
.57646 .61176 Mdot
.58039 .61176 Mdot
.56862 .59999 Mdot
.5647 .59999 Mdot
.55294 .59215 Mdot
.55294 .58431 Mdot
.54902 .58823 Mdot
.55686 .59607 Mdot
.55686 .58823 Mdot
.55294 .58431 Mdot
.55686 .58431 Mdot
.54902 .57254 Mdot
.54117 .56862 Mdot
.54509 .58039 Mdot
.53333 .56862 Mdot
.54117 .57254 Mdot
.54117 .56862 Mdot
.53333 .5647 Mdot
.52157 .56862 Mdot
.5098 .5647 Mdot
.50196 .56078 Mdot
.50196 .55686 Mdot
.50588 .56078 Mdot
.50588 .54902 Mdot
.5098 .54509 Mdot
.50196 .53725 Mdot
.49412 .53333 Mdot
.48628 .53333 Mdot
.4902 .53725 Mdot
.48235 .52549 Mdot
.47451 .5098 Mdot
.47843 .51372 Mdot
.46667 .50588 Mdot
.45491 .49804 Mdot
.45098 .50588 Mdot
.43138 .49412 Mdot
.43922 .50196 Mdot
.41569 .48628 Mdot
.41961 .49412 Mdot
.40785 .48628 Mdot
.38432 .42746 Mdot
.43138 .48235 Mdot
.44706 .49412 Mdot
.45098 .50196 Mdot
.44314 .4902 Mdot
.45098 .50196 Mdot
.46275 .51372 Mdot
.45883 .5098 Mdot
.47059 .52157 Mdot
.47843 .53333 Mdot
.47451 .53333 Mdot
.47451 .54117 Mdot
.47059 .54117 Mdot
.47451 .54509 Mdot
.47451 .54117 Mdot
.48235 .54509 Mdot
.4902 .54509 Mdot
.49804 .54902 Mdot
.50196 .54902 Mdot
.50196 .54902 Mdot
.50196 .54902 Mdot
.50196 .55294 Mdot
.51765 .5647 Mdot
.51765 .5647 Mdot
.52157 .5647 Mdot
.51372 .57254 Mdot
.51372 .57254 Mdot
.51765 .57646 Mdot
.52549 .58039 Mdot
.52157 .58039 Mdot
.52549 .57646 Mdot
.52549 .57254 Mdot
.53333 .57254 Mdot
.54509 .58431 Mdot
.54117 .57646 Mdot
.55294 .58823 Mdot
.5647 .58823 Mdot
.57254 .59215 Mdot
.5647 .58823 Mdot
.56862 .59215 Mdot
.5647 .58823 Mdot
.56078 .58431 Mdot
.57254 .59607 Mdot
.56862 .59607 Mdot
.56862 .58431 Mdot
.57254 .59607 Mdot
.57646 .59999 Mdot
.57254 .60391 Mdot
.56078 .58823 Mdot
.57646 .59607 Mdot
.57646 .59607 Mdot
.57646 .59999 Mdot
.58039 .60391 Mdot
.57254 .59999 Mdot
.57646 .60391 Mdot
.58039 .60783 Mdot
.58039 .60783 Mdot
.58039 .60391 Mdot
.58039 .59999 Mdot
.58823 .61568 Mdot
.59607 .62744 Mdot
.59607 .62352 Mdot
.59999 .62352 Mdot
.59999 .6196 Mdot
.59999 .61568 Mdot
.58823 .60391 Mdot
.59215 .6196 Mdot
.59215 .62352 Mdot
.59607 .62352 Mdot
.59999 .62352 Mdot
.60783 .62352 Mdot
.60391 .6196 Mdot
.59999 .62352 Mdot
.59999 .63136 Mdot
.59215 .6196 Mdot
.59999 .63136 Mdot
.59607 .62352 Mdot
.59999 .62744 Mdot
.59999 .62744 Mdot
.59607 .62744 Mdot
.59607 .63136 Mdot
.60783 .6392 Mdot
.6196 .64313 Mdot
.62744 .64705 Mdot
.62352 .6392 Mdot
.62352 .6392 Mdot
.62744 .64705 Mdot
.6196 .6392 Mdot
.61176 .63136 Mdot
.60391 .62744 Mdot
.60391 .63136 Mdot
.59215 .6196 Mdot
.58823 .62352 Mdot
.59215 .62744 Mdot
.59999 .6196 Mdot
.61568 .63528 Mdot
.6196 .6392 Mdot
.59999 .62352 Mdot
.60391 .63136 Mdot
.60391 .62744 Mdot
.59607 .62352 Mdot
.60391 .62744 Mdot
.61176 .63136 Mdot
.6196 .63528 Mdot
.6196 .63528 Mdot
.61176 .62352 Mdot
.60391 .6196 Mdot
.59999 .61568 Mdot
.61176 .62352 Mdot
.60391 .6196 Mdot
.60783 .62352 Mdot
.59607 .62352 Mdot
.58823 .61568 Mdot
.58823 .61176 Mdot
.58039 .60783 Mdot
.58431 .61176 Mdot
.57646 .60391 Mdot
.58039 .60783 Mdot
.58431 .61176 Mdot
.58431 .6196 Mdot
.57254 .60783 Mdot
.56078 .58823 Mdot
.5647 .59607 Mdot
.5647 .59999 Mdot
.54509 .58431 Mdot
.54117 .57646 Mdot
.54902 .58823 Mdot
.56078 .59215 Mdot
.5647 .58823 Mdot
.55686 .58431 Mdot
.55686 .58431 Mdot
.54902 .57254 Mdot
.54902 .57646 Mdot
.54509 .57254 Mdot
.53333 .5647 Mdot
.53333 .56078 Mdot
.53725 .56078 Mdot
.54117 .57254 Mdot
.52157 .55686 Mdot
.50588 .54902 Mdot
.49412 .54509 Mdot
.4902 .54117 Mdot
.50588 .55294 Mdot
.50196 .53725 Mdot
.5098 .54509 Mdot
.51372 .54117 Mdot
.50196 .52941 Mdot
.48628 .51372 Mdot
.48235 .5098 Mdot
.48235 .51372 Mdot
.47843 .50588 Mdot
.47451 .49412 Mdot
.47059 .4902 Mdot
.46275 .49412 Mdot
.45098 .49804 Mdot
.43138 .49412 Mdot
.42354 .4902 Mdot
.42354 .49412 Mdot
.42354 .50196 Mdot
.41569 .4902 Mdot
.38432 .42746 Mdot
.42746 .48235 Mdot
.44314 .50196 Mdot
.45098 .50196 Mdot
.44706 .49412 Mdot
.45098 .50196 Mdot
.45883 .51372 Mdot
.45098 .50196 Mdot
.46667 .51765 Mdot
.47059 .52549 Mdot
.46275 .51372 Mdot
.46667 .52549 Mdot
.47843 .54117 Mdot
.48628 .54902 Mdot
.48628 .54902 Mdot
.48628 .54509 Mdot
.4902 .54902 Mdot
.49804 .56078 Mdot
.50196 .55686 Mdot
.49804 .54902 Mdot
.5098 .55686 Mdot
.51372 .55294 Mdot
.51372 .55686 Mdot
.51372 .55686 Mdot
.5098 .55294 Mdot
.5098 .55686 Mdot
.50588 .55686 Mdot
.5098 .5647 Mdot
.51372 .56862 Mdot
.52157 .57646 Mdot
.52157 .58039 Mdot
.53333 .58431 Mdot
.53333 .58431 Mdot
.54117 .58431 Mdot
.54509 .58431 Mdot
.56078 .59215 Mdot
.56078 .58823 Mdot
.56078 .58431 Mdot
.55686 .58431 Mdot
.56078 .58823 Mdot
.56862 .59607 Mdot
.56078 .58823 Mdot
.55686 .58431 Mdot
.5647 .59607 Mdot
.5647 .58823 Mdot
.56862 .60391 Mdot
.57254 .60391 Mdot
.57254 .59999 Mdot
.57646 .59999 Mdot
.57646 .59999 Mdot
.58039 .59999 Mdot
.58431 .60391 Mdot
.58039 .60391 Mdot
.58039 .60783 Mdot
.58431 .61176 Mdot
.58039 .60783 Mdot
.57254 .60391 Mdot
.57646 .60391 Mdot
.57254 .59999 Mdot
.58039 .61176 Mdot
.59215 .6196 Mdot
.59215 .61568 Mdot
.58823 .60783 Mdot
.60391 .6196 Mdot
.59999 .61568 Mdot
.58431 .60783 Mdot
.59215 .6196 Mdot
.59607 .62352 Mdot
.59607 .62352 Mdot
.60391 .62352 Mdot
.61176 .62744 Mdot
.60391 .62352 Mdot
.60391 .63136 Mdot
.59999 .63136 Mdot
.59999 .62744 Mdot
.59607 .6196 Mdot
.58823 .6196 Mdot
.58823 .6196 Mdot
.58431 .61568 Mdot
.59215 .63136 Mdot
.58823 .62744 Mdot
.60783 .64313 Mdot
.60391 .63136 Mdot
.61568 .63528 Mdot
.61568 .63528 Mdot
.6196 .6392 Mdot
.6196 .63528 Mdot
.61568 .63528 Mdot
.61568 .64313 Mdot
.61176 .6392 Mdot
.60783 .63136 Mdot
.60783 .63136 Mdot
.60783 .6392 Mdot
.59999 .62744 Mdot
.59607 .61568 Mdot
.59607 .61568 Mdot
.59607 .62352 Mdot
.59607 .62352 Mdot
.59215 .62352 Mdot
.59999 .62744 Mdot
.59215 .61568 Mdot
.60391 .62744 Mdot
.60783 .62744 Mdot
.60783 .63136 Mdot
.60783 .63136 Mdot
.60783 .62352 Mdot
.61176 .62744 Mdot
.61568 .6196 Mdot
.61176 .61176 Mdot
.60783 .60783 Mdot
.60391 .61176 Mdot
.59999 .6196 Mdot
.59607 .6196 Mdot
.59215 .61568 Mdot
.58431 .61176 Mdot
.58431 .61176 Mdot
.58431 .61176 Mdot
.57646 .60391 Mdot
.57646 .60391 Mdot
.57254 .60391 Mdot
.57254 .60391 Mdot
.57254 .60783 Mdot
.55686 .59215 Mdot
.55294 .58823 Mdot
.55294 .59215 Mdot
.54509 .58039 Mdot
.55686 .59215 Mdot
.55686 .58039 Mdot
.55686 .57646 Mdot
.5647 .58431 Mdot
.54117 .5647 Mdot
.54117 .56862 Mdot
.54117 .58039 Mdot
.54902 .58431 Mdot
.52941 .56078 Mdot
.52549 .55294 Mdot
.52549 .54509 Mdot
.53333 .55686 Mdot
.52549 .55686 Mdot
.51372 .54509 Mdot
.51372 .54117 Mdot
.5098 .53725 Mdot
.50196 .53333 Mdot
.50196 .52941 Mdot
.5098 .52549 Mdot
.50588 .52157 Mdot
.49804 .51765 Mdot
.48628 .51372 Mdot
.48628 .5098 Mdot
.48235 .5098 Mdot
.47059 .49412 Mdot
.47059 .49804 Mdot
.45883 .49412 Mdot
.45883 .49804 Mdot
.45098 .49804 Mdot
.42354 .47843 Mdot
.42354 .48235 Mdot
.41569 .48235 Mdot
.40393 .47451 Mdot
.40001 .47451 Mdot
.39609 .4353 Mdot
.4353 .4902 Mdot
.44314 .50196 Mdot
.45491 .5098 Mdot
.45491 .50588 Mdot
.45098 .49804 Mdot
.45491 .50588 Mdot
.45491 .50196 Mdot
.46275 .51765 Mdot
.46275 .51372 Mdot
.47059 .52157 Mdot
.4902 .54509 Mdot
.48235 .54117 Mdot
.4902 .54902 Mdot
.48235 .54117 Mdot
.48628 .54509 Mdot
.4902 .54902 Mdot
.5098 .56862 Mdot
.50196 .55294 Mdot
.50196 .54902 Mdot
.50588 .55294 Mdot
.51765 .56078 Mdot
.5098 .55686 Mdot
.50588 .55686 Mdot
.50588 .55686 Mdot
.51372 .56078 Mdot
.51372 .56078 Mdot
.51372 .5647 Mdot
.52157 .57646 Mdot
.51765 .56862 Mdot
.52549 .57254 Mdot
.52941 .57254 Mdot
.53333 .57646 Mdot
.54509 .58431 Mdot
.55294 .59607 Mdot
.54509 .58431 Mdot
.55294 .59607 Mdot
.55294 .58431 Mdot
.54902 .58039 Mdot
.54902 .57646 Mdot
.54902 .57646 Mdot
.56078 .59215 Mdot
.56078 .58431 Mdot
.56078 .58823 Mdot
.55294 .58039 Mdot
.55686 .58823 Mdot
.5647 .58431 Mdot
.5647 .58431 Mdot
.56078 .58431 Mdot
.56862 .59215 Mdot
.57254 .59607 Mdot
.5647 .58823 Mdot
.56862 .59215 Mdot
.57254 .59607 Mdot
.58431 .60783 Mdot
.57646 .60783 Mdot
.57646 .60783 Mdot
.57646 .60391 Mdot
.58039 .61176 Mdot
.58039 .61176 Mdot
.59215 .6196 Mdot
.59607 .62352 Mdot
.59215 .6196 Mdot
.58823 .61568 Mdot
.58823 .61568 Mdot
.58431 .61176 Mdot
.58431 .61176 Mdot
.58431 .61176 Mdot
.59607 .6196 Mdot
.59215 .61568 Mdot
.58823 .60783 Mdot
.59999 .62352 Mdot
.59607 .62352 Mdot
.59215 .6196 Mdot
.58431 .61176 Mdot
.58431 .61176 Mdot
.58431 .62352 Mdot
.58039 .61176 Mdot
.59607 .62352 Mdot
.60391 .63528 Mdot
.59999 .63528 Mdot
.59999 .62744 Mdot
.59999 .62352 Mdot
.61176 .63136 Mdot
.61176 .62744 Mdot
.60783 .62352 Mdot
.61176 .62352 Mdot
.6196 .63528 Mdot
.6196 .64313 Mdot
.6196 .64313 Mdot
.62744 .64705 Mdot
.61568 .63136 Mdot
.61568 .63136 Mdot
.60783 .62352 Mdot
.60391 .62352 Mdot
.60391 .62744 Mdot
.59999 .62352 Mdot
.59999 .62744 Mdot
.59999 .62744 Mdot
.60391 .62744 Mdot
.59999 .62352 Mdot
.59999 .6196 Mdot
.61176 .62352 Mdot
.60391 .61568 Mdot
.60391 .61568 Mdot
.59999 .60783 Mdot
.60391 .61568 Mdot
.61176 .6196 Mdot
.61568 .61568 Mdot
.60783 .61176 Mdot
.60391 .61568 Mdot
.58823 .60783 Mdot
.58431 .61176 Mdot
.58823 .61568 Mdot
.58431 .61176 Mdot
.57254 .60391 Mdot
.57254 .60783 Mdot
.57254 .60391 Mdot
.56078 .59215 Mdot
.56862 .59999 Mdot
.55294 .58431 Mdot
.55294 .58823 Mdot
.55686 .59215 Mdot
.55686 .59607 Mdot
.55686 .59215 Mdot
.55686 .58823 Mdot
.55294 .57646 Mdot
.55294 .57646 Mdot
.54902 .56862 Mdot
.54117 .5647 Mdot
.54902 .57254 Mdot
.52549 .56078 Mdot
.53333 .57254 Mdot
.52549 .56078 Mdot
.53333 .5647 Mdot
.52941 .55686 Mdot
.51372 .54902 Mdot
.51372 .54117 Mdot
.52549 .55686 Mdot
.51372 .54509 Mdot
.5098 .54117 Mdot
.50588 .53333 Mdot
.49804 .52549 Mdot
.50196 .52157 Mdot
.50196 .51765 Mdot
.50196 .51765 Mdot
.48235 .50588 Mdot
.47843 .50588 Mdot
.47451 .50588 Mdot
.46275 .49804 Mdot
.45883 .49412 Mdot
.44706 .48628 Mdot
.45098 .4902 Mdot
.45491 .49804 Mdot
.44706 .49412 Mdot
.4353 .48235 Mdot
.42746 .47451 Mdot
.41569 .47059 Mdot
.40785 .47059 Mdot
.39217 .46275 Mdot
.38824 .42746 Mdot
.41961 .47059 Mdot
.43138 .4902 Mdot
.43922 .49804 Mdot
.45098 .50196 Mdot
.45098 .49804 Mdot
.45098 .49804 Mdot
.45098 .50196 Mdot
.45883 .5098 Mdot
.45883 .5098 Mdot
.47059 .52549 Mdot
.48628 .53333 Mdot
.4902 .54509 Mdot
.48235 .54509 Mdot
.48628 .54509 Mdot
.49804 .55294 Mdot
.49804 .54902 Mdot
.5098 .56078 Mdot
.50588 .56078 Mdot
.49412 .55294 Mdot
.49804 .54509 Mdot
.49412 .54117 Mdot
.51765 .5647 Mdot
.51372 .56078 Mdot
.52157 .56862 Mdot
.51765 .5647 Mdot
.51765 .5647 Mdot
.52157 .5647 Mdot
.52157 .57254 Mdot
.52157 .56078 Mdot
.52549 .56862 Mdot
.53725 .58431 Mdot
.52941 .57254 Mdot
.53333 .57646 Mdot
.52941 .57646 Mdot
.53333 .58823 Mdot
.54117 .59215 Mdot
.54117 .58039 Mdot
.54902 .58431 Mdot
.54117 .57254 Mdot
.54509 .58039 Mdot
.54509 .57646 Mdot
.55294 .58431 Mdot
.54902 .57646 Mdot
.56078 .58823 Mdot
.5647 .58431 Mdot
.5647 .58823 Mdot
.5647 .58823 Mdot
.56862 .59215 Mdot
.57646 .59607 Mdot
.58039 .60391 Mdot
.58431 .59999 Mdot
.57646 .59999 Mdot
.58039 .60391 Mdot
.58039 .59999 Mdot
.57646 .59607 Mdot
.57646 .59607 Mdot
.58039 .60391 Mdot
.57646 .60391 Mdot
.58431 .61568 Mdot
.59607 .62352 Mdot
.58823 .61176 Mdot
.58431 .60783 Mdot
.57646 .59999 Mdot
.59215 .61568 Mdot
.58823 .61176 Mdot
.59215 .6196 Mdot
.59607 .6196 Mdot
.59607 .61568 Mdot
.59607 .61568 Mdot
.60783 .62744 Mdot
.60391 .61568 Mdot
.59607 .61176 Mdot
.59999 .61568 Mdot
.59215 .6196 Mdot
.58823 .61568 Mdot
.59215 .6196 Mdot
.58431 .61176 Mdot
.58823 .61568 Mdot
.59607 .62352 Mdot
.59999 .62744 Mdot
.60391 .62744 Mdot
.59999 .62744 Mdot
.60391 .62352 Mdot
.60783 .62352 Mdot
.61176 .62352 Mdot
.60783 .62352 Mdot
.59999 .61568 Mdot
.60391 .6196 Mdot
.60783 .62744 Mdot
.61176 .62352 Mdot
.60783 .62352 Mdot
.61176 .6196 Mdot
.6196 .63136 Mdot
.61568 .63136 Mdot
.61176 .62352 Mdot
.61176 .62352 Mdot
.59999 .61568 Mdot
.60391 .62352 Mdot
.61176 .62352 Mdot
.59999 .61176 Mdot
.60391 .6196 Mdot
.60391 .61176 Mdot
.60391 .61568 Mdot
.60783 .6196 Mdot
.59999 .61176 Mdot
.59607 .60783 Mdot
.59999 .61176 Mdot
.60783 .61568 Mdot
.59215 .60391 Mdot
.58823 .60391 Mdot
.58039 .60391 Mdot
.58431 .61176 Mdot
.58039 .60391 Mdot
.58039 .60783 Mdot
.57254 .59999 Mdot
.5647 .59999 Mdot
.5647 .59999 Mdot
.57254 .60391 Mdot
.56862 .59607 Mdot
.56078 .58431 Mdot
.55686 .58039 Mdot
.56078 .58823 Mdot
.54902 .57254 Mdot
.56078 .58431 Mdot
.5647 .58431 Mdot
.55294 .57254 Mdot
.54117 .56078 Mdot
.54509 .56862 Mdot
.53725 .56078 Mdot
.52941 .55686 Mdot
.52549 .55686 Mdot
.52157 .55686 Mdot
.51372 .54509 Mdot
.53333 .55686 Mdot
.52549 .54902 Mdot
.52157 .54509 Mdot
.52157 .54117 Mdot
.51372 .53725 Mdot
.50588 .52941 Mdot
.50196 .52941 Mdot
.49412 .52157 Mdot
.49804 .51372 Mdot
.48628 .50196 Mdot
.4902 .50588 Mdot
.48235 .49804 Mdot
.48628 .5098 Mdot
.47451 .49804 Mdot
.46667 .49412 Mdot
.45883 .48628 Mdot
.45098 .48235 Mdot
.43922 .47451 Mdot
.43922 .47843 Mdot
.44314 .47451 Mdot
.44706 .48235 Mdot
.43922 .47451 Mdot
.42746 .46275 Mdot
.41569 .46275 Mdot
.40393 .46275 Mdot
.38432 .45098 Mdot
.39609 .44706 Mdot
.42746 .47843 Mdot
.43922 .49412 Mdot
.44314 .49412 Mdot
.45098 .49804 Mdot
.44706 .4902 Mdot
.44706 .4902 Mdot
.45098 .50196 Mdot
.46667 .51372 Mdot
.47059 .51765 Mdot
.47059 .51765 Mdot
.47451 .52157 Mdot
.47451 .52941 Mdot
.47843 .53725 Mdot
.48235 .54509 Mdot
.48235 .54902 Mdot
.49804 .56078 Mdot
.49804 .55294 Mdot
.49412 .55294 Mdot
.49804 .55294 Mdot
.50588 .56078 Mdot
.49804 .55686 Mdot
.5098 .5647 Mdot
.5098 .55686 Mdot
.51372 .5647 Mdot
.51372 .56078 Mdot
.51765 .55686 Mdot
.51765 .55686 Mdot
.52157 .5647 Mdot
.52157 .5647 Mdot
.51372 .56078 Mdot
.52549 .56862 Mdot
.52941 .57254 Mdot
.52549 .5647 Mdot
.51765 .56078 Mdot
.52941 .58039 Mdot
.53333 .58823 Mdot
.54117 .58823 Mdot
.55294 .58823 Mdot
.55686 .59215 Mdot
.55294 .58823 Mdot
.55686 .59999 Mdot
.54509 .58039 Mdot
.55294 .59215 Mdot
.54902 .58823 Mdot
.56862 .59607 Mdot
.5647 .58039 Mdot
.57254 .59607 Mdot
.56862 .59999 Mdot
.58039 .61176 Mdot
.58823 .61176 Mdot
.58431 .60783 Mdot
.57646 .59215 Mdot
.58431 .59999 Mdot
.57646 .59607 Mdot
.57646 .59999 Mdot
.57254 .59999 Mdot
.57646 .60391 Mdot
.58039 .61176 Mdot
.58039 .60391 Mdot
.58823 .60783 Mdot
.58431 .60783 Mdot
.57254 .59215 Mdot
.57646 .59999 Mdot
.57646 .60391 Mdot
.58431 .60783 Mdot
.58823 .61176 Mdot
.58431 .60783 Mdot
.58823 .60783 Mdot
.59607 .61176 Mdot
.60391 .6196 Mdot
.59607 .61568 Mdot
.60391 .6196 Mdot
.59215 .61176 Mdot
.58823 .61568 Mdot
.58039 .60391 Mdot
.57646 .61176 Mdot
.57646 .61568 Mdot
.58823 .6196 Mdot
.58823 .6196 Mdot
.59607 .62352 Mdot
.59215 .6196 Mdot
.59215 .6196 Mdot
.60391 .62352 Mdot
.59215 .61176 Mdot
.59215 .61176 Mdot
.60391 .61568 Mdot
.60783 .6196 Mdot
.59999 .61568 Mdot
.59607 .61568 Mdot
.59215 .61176 Mdot
.59999 .6196 Mdot
.60391 .62352 Mdot
.61568 .62352 Mdot
.60783 .61568 Mdot
.61176 .62352 Mdot
.59999 .61176 Mdot
.59607 .61568 Mdot
.60783 .62744 Mdot
.60783 .62744 Mdot
.59999 .61176 Mdot
.59999 .61568 Mdot
.59999 .61176 Mdot
.59215 .60391 Mdot
.59607 .61176 Mdot
.59607 .61568 Mdot
.59215 .61176 Mdot
.59607 .61568 Mdot
.59607 .61176 Mdot
.58431 .60783 Mdot
.58039 .60391 Mdot
.57254 .59607 Mdot
.57646 .58823 Mdot
.57646 .58823 Mdot
.58039 .59607 Mdot
.56078 .58431 Mdot
.54902 .58431 Mdot
.54902 .58431 Mdot
.54509 .58039 Mdot
.55686 .58823 Mdot
.55686 .58039 Mdot
.5647 .58431 Mdot
.56078 .58039 Mdot
.55294 .57646 Mdot
.54509 .57254 Mdot
.52941 .56078 Mdot
.54902 .57646 Mdot
.54902 .5647 Mdot
.54117 .55686 Mdot
.54509 .55686 Mdot
.54509 .56862 Mdot
.53333 .55294 Mdot
.52941 .55686 Mdot
.51765 .54509 Mdot
.51372 .54117 Mdot
.51765 .54509 Mdot
.51765 .53333 Mdot
.52157 .53333 Mdot
.51372 .52941 Mdot
.5098 .53333 Mdot
.48628 .51765 Mdot
.47451 .50588 Mdot
.4902 .51765 Mdot
.4902 .5098 Mdot
.48628 .50588 Mdot
.47843 .49804 Mdot
.47451 .50196 Mdot
.46667 .50588 Mdot
.44706 .48628 Mdot
.44706 .4902 Mdot
.45098 .4902 Mdot
.44314 .48235 Mdot
.43922 .48235 Mdot
.4353 .47059 Mdot
.42746 .46275 Mdot
.41569 .45491 Mdot
.40785 .45491 Mdot
.40393 .45491 Mdot
.39609 .45491 Mdot
.38432 .44314 Mdot
.38824 .4353 Mdot
.41961 .46667 Mdot
.44314 .49412 Mdot
.45491 .50196 Mdot
.45491 .4902 Mdot
.45883 .49412 Mdot
.45491 .48628 Mdot
.46275 .4902 Mdot
.47451 .50588 Mdot
.48235 .51372 Mdot
.47843 .5098 Mdot
.48628 .52549 Mdot
.47843 .52549 Mdot
.47843 .53333 Mdot
.48628 .54509 Mdot
.4902 .55294 Mdot
.48235 .54117 Mdot
.49412 .55294 Mdot
.4902 .55686 Mdot
.49412 .55686 Mdot
.50196 .5647 Mdot
.50588 .56078 Mdot
.49804 .55686 Mdot
.49412 .56078 Mdot
.51765 .57646 Mdot
.52157 .5647 Mdot
.53725 .57254 Mdot
.53333 .56862 Mdot
.52549 .56078 Mdot
.52941 .57646 Mdot
.52157 .56862 Mdot
.52941 .56862 Mdot
.53725 .57254 Mdot
.53333 .56862 Mdot
.52941 .5647 Mdot
.53725 .57254 Mdot
.53725 .57254 Mdot
.54509 .58039 Mdot
.56078 .59215 Mdot
.55686 .58823 Mdot
.55686 .59215 Mdot
.54902 .58431 Mdot
.54902 .58039 Mdot
.55294 .58823 Mdot
.55294 .58823 Mdot
.54902 .58823 Mdot
.55686 .58823 Mdot
.55686 .59607 Mdot
.55294 .59607 Mdot
.56862 .60391 Mdot
.57646 .60783 Mdot
.56862 .59607 Mdot
.57254 .59999 Mdot
.57646 .59607 Mdot
.57646 .59607 Mdot
.57646 .59999 Mdot
.57646 .60391 Mdot
.57646 .59607 Mdot
.58431 .60391 Mdot
.57646 .59999 Mdot
.58039 .59999 Mdot
.56862 .58823 Mdot
.5647 .58823 Mdot
.5647 .58823 Mdot
.5647 .58431 Mdot
.56862 .59607 Mdot
.57646 .60391 Mdot
.57254 .60391 Mdot
.58039 .60391 Mdot
.58039 .60391 Mdot
.58431 .61176 Mdot
.58431 .61176 Mdot
.58823 .61176 Mdot
.59607 .6196 Mdot
.58431 .60783 Mdot
.58039 .60391 Mdot
.58431 .6196 Mdot
.58431 .62352 Mdot
.58823 .62352 Mdot
.58823 .6196 Mdot
.58823 .6196 Mdot
.58039 .61176 Mdot
.59607 .62352 Mdot
.59215 .61568 Mdot
.59607 .61568 Mdot
.59215 .60783 Mdot
.59999 .61176 Mdot
.60783 .6196 Mdot
.59607 .61176 Mdot
.59215 .61568 Mdot
.58823 .61568 Mdot
.58823 .61176 Mdot
.59607 .61568 Mdot
.59999 .61568 Mdot
.59607 .60783 Mdot
.59999 .61176 Mdot
.59215 .60783 Mdot
.58431 .60391 Mdot
.58823 .61176 Mdot
.58039 .60391 Mdot
.58823 .61176 Mdot
.59215 .61176 Mdot
.58823 .60783 Mdot
.58039 .59999 Mdot
.58039 .59999 Mdot
.57646 .59607 Mdot
.58039 .59607 Mdot
.58039 .60391 Mdot
.58039 .59607 Mdot
.57646 .59215 Mdot
.56862 .58823 Mdot
.57254 .59215 Mdot
.57646 .59607 Mdot
.56862 .58431 Mdot
.56862 .58431 Mdot
.5647 .58431 Mdot
.55686 .58431 Mdot
.54509 .58039 Mdot
.54509 .58431 Mdot
.54902 .58431 Mdot
.54117 .57254 Mdot
.54509 .57646 Mdot
.54902 .57254 Mdot
.54509 .56862 Mdot
.54902 .58039 Mdot
.53725 .56862 Mdot
.53725 .57254 Mdot
.54117 .56078 Mdot
.54117 .55294 Mdot
.54117 .55686 Mdot
.53333 .54902 Mdot
.52941 .54902 Mdot
.51372 .54509 Mdot
.49804 .53725 Mdot
.50196 .54509 Mdot
.49804 .52941 Mdot
.50588 .53725 Mdot
.50588 .52941 Mdot
.49804 .52157 Mdot
.49804 .53333 Mdot
.48628 .52157 Mdot
.47451 .51765 Mdot
.47451 .51372 Mdot
.47059 .50196 Mdot
.47451 .49804 Mdot
.47451 .49412 Mdot
.46667 .48628 Mdot
.45883 .4902 Mdot
.44706 .48235 Mdot
.43922 .47451 Mdot
.43138 .46275 Mdot
.43138 .46667 Mdot
.42746 .45491 Mdot
.41569 .44706 Mdot
.41569 .44706 Mdot
.41177 .44314 Mdot
.38824 .4353 Mdot
.39609 .44706 Mdot
.38432 .44314 Mdot
.37256 .4353 Mdot
.40001 .4353 Mdot
.41177 .45098 Mdot
.4353 .48235 Mdot
.44706 .4902 Mdot
.45883 .49804 Mdot
.46667 .49412 Mdot
.46275 .47843 Mdot
.46275 .47843 Mdot
.47843 .49804 Mdot
.47059 .50196 Mdot
.47843 .51372 Mdot
.4902 .52941 Mdot
.48628 .53333 Mdot
.48628 .53725 Mdot
.49412 .54117 Mdot
.49804 .54902 Mdot
.49804 .55294 Mdot
.50196 .55686 Mdot
.50196 .55686 Mdot
.49804 .55294 Mdot
.50588 .55686 Mdot
.4902 .53725 Mdot
.49804 .54902 Mdot
.49412 .54902 Mdot
.5098 .5647 Mdot
.5098 .56078 Mdot
.52549 .5647 Mdot
.51765 .55294 Mdot
.52941 .56078 Mdot
.53333 .56078 Mdot
.53725 .56862 Mdot
.54117 .57254 Mdot
.54117 .57646 Mdot
.53725 .56862 Mdot
.54117 .56862 Mdot
.54117 .56078 Mdot
.55686 .57254 Mdot
.54509 .56078 Mdot
.54902 .56862 Mdot
.56078 .58431 Mdot
.54902 .57646 Mdot
.53333 .5647 Mdot
.55686 .58039 Mdot
.55686 .58431 Mdot
.55294 .58039 Mdot
.53725 .56862 Mdot
.53333 .57646 Mdot
.52941 .58039 Mdot
.53333 .58431 Mdot
.55294 .59999 Mdot
.56862 .60391 Mdot
.56078 .58823 Mdot
.56862 .59215 Mdot
.56862 .59215 Mdot
.56862 .59607 Mdot
.57254 .59999 Mdot
.56862 .59215 Mdot
.57646 .60391 Mdot
.57646 .60391 Mdot
.58431 .59607 Mdot
.57254 .58823 Mdot
.57254 .59607 Mdot
.58039 .60783 Mdot
.57646 .59999 Mdot
.57646 .59999 Mdot
.57646 .59999 Mdot
.56078 .58431 Mdot
.5647 .59215 Mdot
.56862 .59999 Mdot
.56862 .59215 Mdot
.56862 .59607 Mdot
.57254 .59215 Mdot
.57254 .58823 Mdot
.57646 .59607 Mdot
.57646 .59999 Mdot
.57646 .60391 Mdot
.58039 .60783 Mdot
.57254 .60391 Mdot
.58039 .61176 Mdot
.58039 .60783 Mdot
.58431 .60391 Mdot
.58039 .59999 Mdot
.58431 .60391 Mdot
.59215 .60783 Mdot
.58823 .59999 Mdot
.59215 .60391 Mdot
.59215 .59999 Mdot
.59215 .60391 Mdot
.58823 .60391 Mdot
.58039 .60391 Mdot
.58823 .61176 Mdot
.58431 .60783 Mdot
.58431 .59999 Mdot
.59607 .60783 Mdot
.59607 .60783 Mdot
.59607 .60391 Mdot
.59215 .59999 Mdot
.58431 .59607 Mdot
.58823 .60391 Mdot
.58431 .59999 Mdot
.58823 .60391 Mdot
.58431 .60391 Mdot
.58823 .59999 Mdot
.58039 .58431 Mdot
.58039 .58823 Mdot
.58039 .58431 Mdot
.58823 .59215 Mdot
.58431 .59215 Mdot
.57646 .59215 Mdot
.57646 .59215 Mdot
.58039 .58431 Mdot
.58039 .59215 Mdot
.57254 .58431 Mdot
.57254 .58823 Mdot
.56862 .58431 Mdot
.55686 .58039 Mdot
.55294 .57646 Mdot
.55686 .58431 Mdot
.55294 .57646 Mdot
.53725 .56078 Mdot
.54509 .56862 Mdot
.53725 .56078 Mdot
.54117 .56862 Mdot
.54117 .5647 Mdot
.54117 .56862 Mdot
.54902 .57646 Mdot
.54117 .56862 Mdot
.53725 .56078 Mdot
.54509 .55294 Mdot
.54509 .56078 Mdot
.53333 .54509 Mdot
.52549 .53333 Mdot
.52549 .54117 Mdot
.5098 .52941 Mdot
.50196 .53725 Mdot
.4902 .52157 Mdot
.4902 .51765 Mdot
.48628 .51372 Mdot
.49412 .51765 Mdot
.49412 .51765 Mdot
.48628 .5098 Mdot
.47451 .50196 Mdot
.46667 .49804 Mdot
.45883 .48628 Mdot
.46275 .48628 Mdot
.46667 .49412 Mdot
.45883 .47843 Mdot
.44706 .47451 Mdot
.43922 .47059 Mdot
.43922 .47059 Mdot
.43138 .45883 Mdot
.42354 .45098 Mdot
.42354 .45491 Mdot
.40785 .43922 Mdot
.40001 .42746 Mdot
.40001 .4353 Mdot
.39609 .43922 Mdot
.38824 .42746 Mdot
.3804 .4353 Mdot
.36864 .42746 Mdot
.41177 .42746 Mdot
.4353 .45491 Mdot
.45491 .47843 Mdot
.45883 .48628 Mdot
.46667 .4902 Mdot
.46667 .47843 Mdot
.46667 .47843 Mdot
.47059 .48235 Mdot
.48235 .49804 Mdot
.4902 .51372 Mdot
.49412 .53333 Mdot
.48628 .52941 Mdot
.48235 .51372 Mdot
.4902 .52549 Mdot
.48628 .52549 Mdot
.48628 .52941 Mdot
.49804 .54902 Mdot
.50196 .55686 Mdot
.5098 .56078 Mdot
.5098 .55686 Mdot
.50196 .54902 Mdot
.5098 .54902 Mdot
.51372 .55294 Mdot
.49804 .54509 Mdot
.51372 .5647 Mdot
.52549 .57254 Mdot
.53333 .56862 Mdot
.53333 .5647 Mdot
.53725 .55686 Mdot
.54902 .5647 Mdot
.55294 .57254 Mdot
.54117 .5647 Mdot
.54117 .57254 Mdot
.54117 .56862 Mdot
.54117 .56078 Mdot
.55294 .57254 Mdot
.5647 .58039 Mdot
.55686 .57254 Mdot
.54509 .56078 Mdot
.54509 .56862 Mdot
.54509 .57646 Mdot
.55686 .58039 Mdot
.54902 .56862 Mdot
.54902 .56862 Mdot
.54117 .56078 Mdot
.53333 .55294 Mdot
.51765 .54509 Mdot
.51765 .55294 Mdot
.51765 .54902 Mdot
.51765 .54117 Mdot
.53333 .54902 Mdot
.54509 .55294 Mdot
.54902 .5647 Mdot
.54509 .56862 Mdot
.53725 .56862 Mdot
.54902 .58431 Mdot
.55686 .58823 Mdot
.56078 .58823 Mdot
.5647 .58823 Mdot
.57254 .59607 Mdot
.58039 .60783 Mdot
.5647 .59215 Mdot
.57254 .60391 Mdot
.57254 .60391 Mdot
.58039 .60783 Mdot
.58039 .60783 Mdot
.57646 .59999 Mdot
.58039 .60783 Mdot
.5647 .59215 Mdot
.56862 .59215 Mdot
.57646 .60391 Mdot
.57646 .59215 Mdot
.58039 .59607 Mdot
.58431 .59999 Mdot
.59607 .61568 Mdot
.58431 .59999 Mdot
.58039 .59607 Mdot
.58823 .60783 Mdot
.58823 .60783 Mdot
.58823 .60391 Mdot
.59215 .60391 Mdot
.58431 .59215 Mdot
.58823 .60391 Mdot
.58039 .59215 Mdot
.58431 .59999 Mdot
.58823 .59607 Mdot
.59607 .60391 Mdot
.59999 .60783 Mdot
.60391 .61176 Mdot
.58823 .59999 Mdot
.58823 .60391 Mdot
.58823 .60391 Mdot
.58823 .59999 Mdot
.59607 .59999 Mdot
.59215 .59215 Mdot
.59215 .59607 Mdot
.58823 .59607 Mdot
.59215 .60391 Mdot
.58431 .59607 Mdot
.58823 .59999 Mdot
.58823 .59999 Mdot
.58823 .59607 Mdot
.58431 .59607 Mdot
.57254 .58039 Mdot
.57646 .58039 Mdot
.58039 .58823 Mdot
.57254 .57646 Mdot
.57254 .58039 Mdot
.58431 .59215 Mdot
.58431 .59215 Mdot
.57254 .57646 Mdot
.57646 .58431 Mdot
.57254 .57646 Mdot
.5647 .57254 Mdot
.56862 .58039 Mdot
.56862 .57646 Mdot
.5647 .57646 Mdot
.55294 .56862 Mdot
.54902 .56862 Mdot
.54509 .5647 Mdot
.54902 .57254 Mdot
.55294 .57646 Mdot
.52941 .55686 Mdot
.52941 .55294 Mdot
.53725 .55686 Mdot
.53725 .56078 Mdot
.53333 .55294 Mdot
.52941 .54509 Mdot
.53333 .54902 Mdot
.54509 .55686 Mdot
.53333 .53333 Mdot
.52549 .52941 Mdot
.51765 .52549 Mdot
.50196 .52157 Mdot
.49412 .51765 Mdot
.4902 .52157 Mdot
.4902 .52157 Mdot
.49412 .51765 Mdot
.49412 .51372 Mdot
.50196 .52157 Mdot
.4902 .50588 Mdot
.48628 .49804 Mdot
.48235 .50196 Mdot
.47451 .49412 Mdot
.47059 .4902 Mdot
.46667 .48235 Mdot
.45491 .47059 Mdot
.45098 .47059 Mdot
.44314 .47059 Mdot
.42746 .45491 Mdot
.41569 .44706 Mdot
.42354 .45883 Mdot
.42354 .45883 Mdot
.42354 .45491 Mdot
.40785 .44314 Mdot
.40785 .43922 Mdot
.40785 .43138 Mdot
.39609 .41961 Mdot
.37648 .41177 Mdot
.37256 .41961 Mdot
.41961 .43138 Mdot
.46275 .48235 Mdot
.47843 .50588 Mdot
.47843 .50196 Mdot
.48628 .50196 Mdot
.47843 .4902 Mdot
.47843 .48235 Mdot
.4902 .49804 Mdot
.4902 .50588 Mdot
.4902 .5098 Mdot
.49804 .52549 Mdot
.50588 .53333 Mdot
.49804 .52157 Mdot
.5098 .53333 Mdot
.5098 .53725 Mdot
.50196 .53725 Mdot
.49804 .54509 Mdot
.5098 .56078 Mdot
.5098 .5647 Mdot
.51765 .56078 Mdot
.51765 .55686 Mdot
.52549 .55686 Mdot
.52157 .54902 Mdot
.50588 .53333 Mdot
.50588 .54117 Mdot
.51765 .55686 Mdot
.52941 .56862 Mdot
.53725 .5647 Mdot
.54117 .56078 Mdot
.55294 .5647 Mdot
.54509 .56078 Mdot
.54509 .5647 Mdot
.54509 .5647 Mdot
.54117 .56078 Mdot
.54902 .56862 Mdot
.54902 .5647 Mdot
.56078 .57254 Mdot
.55294 .56862 Mdot
.54902 .5647 Mdot
.54509 .5647 Mdot
.55686 .58039 Mdot
.5647 .58823 Mdot
.55686 .57646 Mdot
.55294 .57254 Mdot
.54509 .56078 Mdot
.54117 .55686 Mdot
.53333 .55294 Mdot
.52157 .54902 Mdot
.51765 .54117 Mdot
.51765 .52941 Mdot
.52549 .52941 Mdot
.52157 .51372 Mdot
.52157 .51372 Mdot
.5098 .5098 Mdot
.49412 .50588 Mdot
.49804 .52549 Mdot
.49804 .52941 Mdot
.51372 .53725 Mdot
.52157 .54117 Mdot
.53333 .55686 Mdot
.54117 .5647 Mdot
.53333 .56862 Mdot
.54902 .58431 Mdot
.56078 .60391 Mdot
.57254 .61568 Mdot
.56862 .60783 Mdot
.58039 .60783 Mdot
.57646 .60783 Mdot
.56078 .58823 Mdot
.57254 .60391 Mdot
.57646 .60783 Mdot
.57646 .60783 Mdot
.58431 .60783 Mdot
.58823 .60391 Mdot
.59215 .61176 Mdot
.58823 .61176 Mdot
.57254 .59215 Mdot
.58431 .60783 Mdot
.59215 .61176 Mdot
.58823 .60391 Mdot
.58823 .59607 Mdot
.59215 .59999 Mdot
.58823 .60391 Mdot
.57646 .59999 Mdot
.56862 .59215 Mdot
.58431 .59999 Mdot
.59215 .60783 Mdot
.58823 .59607 Mdot
.58823 .58823 Mdot
.58039 .58431 Mdot
.58431 .59607 Mdot
.58431 .59999 Mdot
.58431 .59607 Mdot
.59607 .60391 Mdot
.59607 .59607 Mdot
.59215 .59215 Mdot
.58823 .59215 Mdot
.58431 .59607 Mdot
.58039 .58823 Mdot
.57646 .58431 Mdot
.59215 .60391 Mdot
.59215 .59999 Mdot
.59215 .60391 Mdot
.57254 .58431 Mdot
.56862 .58039 Mdot
.57254 .58039 Mdot
.57254 .58039 Mdot
.57646 .58431 Mdot
.58431 .58431 Mdot
.58039 .58039 Mdot
.57254 .57254 Mdot
.58431 .58823 Mdot
.57646 .58431 Mdot
.57254 .58431 Mdot
.56862 .57646 Mdot
.56078 .56862 Mdot
.56078 .56862 Mdot
.54902 .5647 Mdot
.54117 .5647 Mdot
.54902 .56862 Mdot
.54902 .57254 Mdot
.55686 .57646 Mdot
.55686 .56862 Mdot
.54902 .55294 Mdot
.54117 .54902 Mdot
.52549 .53725 Mdot
.53333 .55294 Mdot
.52941 .54509 Mdot
.53333 .55294 Mdot
.54117 .55294 Mdot
.53725 .54117 Mdot
.53333 .53333 Mdot
.52549 .52549 Mdot
.5098 .52157 Mdot
.49804 .51765 Mdot
.48235 .51372 Mdot
.4902 .51765 Mdot
.4902 .5098 Mdot
.4902 .50588 Mdot
.49804 .5098 Mdot
.49804 .50588 Mdot
.48628 .49804 Mdot
.47843 .49412 Mdot
.47451 .49412 Mdot
.47451 .48628 Mdot
.47843 .48628 Mdot
.47451 .48235 Mdot
.46275 .47059 Mdot
.45491 .46667 Mdot
.43922 .45491 Mdot
.41961 .44314 Mdot
.41569 .44314 Mdot
.41961 .45491 Mdot
.41177 .45098 Mdot
.41177 .4353 Mdot
.41569 .43138 Mdot
.40001 .41177 Mdot
.40393 .41569 Mdot
.39609 .41177 Mdot
.3608 .38432 Mdot
.41961 .43138 Mdot
.46667 .48628 Mdot
.46667 .4902 Mdot
.47059 .48628 Mdot
.47451 .48235 Mdot
.48235 .49412 Mdot
.48235 .4902 Mdot
.48628 .49804 Mdot
.4902 .49804 Mdot
.49804 .51372 Mdot
.50196 .52157 Mdot
.50196 .51765 Mdot
.50588 .52549 Mdot
.50588 .52941 Mdot
.51765 .54509 Mdot
.5098 .54117 Mdot
.5098 .54902 Mdot
.51372 .56078 Mdot
.51765 .56078 Mdot
.52157 .5647 Mdot
.51765 .55294 Mdot
.53333 .5647 Mdot
.52157 .55294 Mdot
.52549 .55294 Mdot
.52549 .55686 Mdot
.54117 .5647 Mdot
.54509 .57254 Mdot
.54509 .5647 Mdot
.54509 .5647 Mdot
.54902 .56078 Mdot
.54902 .55686 Mdot
.54902 .5647 Mdot
.54509 .56078 Mdot
.54509 .5647 Mdot
.54117 .56078 Mdot
.55294 .57254 Mdot
.56078 .57646 Mdot
.55294 .56862 Mdot
.55294 .57254 Mdot
.55686 .57646 Mdot
.56078 .58823 Mdot
.56078 .58431 Mdot
.56862 .58431 Mdot
.56078 .56862 Mdot
.5647 .57254 Mdot
.56078 .57646 Mdot
.56078 .57646 Mdot
.56078 .58039 Mdot
.55294 .56862 Mdot
.55686 .56862 Mdot
.54902 .55294 Mdot
.54509 .54509 Mdot
.52941 .51765 Mdot
.52549 .52157 Mdot
.5098 .5098 Mdot
.50196 .5098 Mdot
.49804 .50588 Mdot
.50196 .50588 Mdot
.50196 .50196 Mdot
.49412 .49804 Mdot
.48628 .49412 Mdot
.47059 .4902 Mdot
.47451 .49804 Mdot
.47451 .49804 Mdot
.47451 .50196 Mdot
.50588 .53333 Mdot
.52941 .55294 Mdot
.54509 .57254 Mdot
.55294 .58039 Mdot
.5647 .59999 Mdot
.57254 .60391 Mdot
.57646 .60783 Mdot
.57254 .60391 Mdot
.57646 .59999 Mdot
.56862 .59215 Mdot
.57646 .60783 Mdot
.5647 .59607 Mdot
.57646 .61176 Mdot
.57254 .60391 Mdot
.58039 .60783 Mdot
.58823 .60783 Mdot
.59607 .60783 Mdot
.58039 .58823 Mdot
.57254 .58823 Mdot
.58039 .59607 Mdot
.58431 .60391 Mdot
.58823 .59607 Mdot
.59607 .59999 Mdot
.58823 .59215 Mdot
.57646 .58039 Mdot
.57254 .58431 Mdot
.57254 .58823 Mdot
.58039 .59215 Mdot
.58039 .59215 Mdot
.57254 .58039 Mdot
.58823 .58431 Mdot
.58823 .59215 Mdot
.57646 .58823 Mdot
.58039 .59215 Mdot
.58431 .59999 Mdot
.58823 .60391 Mdot
.58039 .58823 Mdot
.58823 .59607 Mdot
.58039 .59215 Mdot
.56862 .58431 Mdot
.56862 .58039 Mdot
.58431 .59607 Mdot
.57646 .58431 Mdot
.58431 .58431 Mdot
.57254 .57254 Mdot
.58431 .58823 Mdot
.56862 .57254 Mdot
.56862 .58039 Mdot
.56862 .58039 Mdot
.56862 .58039 Mdot
.55686 .57254 Mdot
.54902 .5647 Mdot
.54902 .56862 Mdot
.54117 .56078 Mdot
.54117 .5647 Mdot
.53333 .55686 Mdot
.54509 .56862 Mdot
.55294 .56862 Mdot
.54509 .55686 Mdot
.54117 .54509 Mdot
.53725 .53725 Mdot
.52941 .53333 Mdot
.53725 .54117 Mdot
.54509 .55294 Mdot
.53725 .54117 Mdot
.53725 .53333 Mdot
.53725 .53333 Mdot
.51372 .5098 Mdot
.50588 .50588 Mdot
.50588 .51765 Mdot
.49412 .5098 Mdot
.48235 .50588 Mdot
.48628 .5098 Mdot
.4902 .5098 Mdot
.49412 .50196 Mdot
.49804 .50588 Mdot
.48628 .49412 Mdot
.47059 .47843 Mdot
.47451 .48628 Mdot
.47059 .47843 Mdot
.46667 .46667 Mdot
.46667 .46275 Mdot
.46275 .46275 Mdot
.44706 .45098 Mdot
.44706 .45491 Mdot
.42746 .44314 Mdot
.40785 .43138 Mdot
.40785 .4353 Mdot
.41177 .43922 Mdot
.41569 .4353 Mdot
.41569 .42746 Mdot
.40001 .40393 Mdot
.39609 .40785 Mdot
.39217 .40785 Mdot
.37648 .40393 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003o00<00?l0
o`3o0?l0o`00o`3ooolN0?ooo`001`00o`3o000001T000000@3oool000T00?l0o`3ooolF0?ooo`40
00000@3oool000X00?l0o`3ooolE0?ooo`4000000@3oool000/00?l0o`3ooolD0?ooo`4000000@3o
ool000D00?l00`000?l6003o0?l0oooo4@3oool100000040oooo0004003o00D0003o2000o`3o0?oo
o`h0oooo0@0000010?ooo`001000o`050000o`T00?l0o`3oool=0?ooo`4000000@3oool000@00?l0
1@000?l9003o0?l0oooo3@3oool100000040oooo0005003o00D0003o2@00o`3o0?ooo``0oooo0@00
00010?ooo`0000<00000003o0000o`000`00o`050000o`P00?l0o`3oool<0?ooo`4000000@3oool0
00030000003oool00?l000<00?l01@000?l9003o0?l0oooo2`3oool100000040oooo00000`000000
oooo003o0003003o00L0003o2P00o`3o0?ooo`P0oooo0@0000010?ooo`0000<000000?ooo`3oool0
1000o`070000o`X00?l0o`3oool70?ooo`4000000@3oool000040000003oool0oooo0?ooo`D00?l0
1@000?l:003o0?l0oooo1`3oool100000040oooo00000`000000oooo0?ooo`020?ooo`@00?l01@00
0?l:003o0?l0oooo1`3oool100000040oooo00000`000000oooo0?ooo`020?ooo`D00?l00`000?l<
003o0?l0oooo1P3oool100000040oooo00000`000000oooo0?ooo`020?oooa800?l00`000?oo0?oo
o`D0oooo0@0000010?ooo`0000<000000?ooo`3oool00`3oool@003o00D0003oo`3oool40?ooo`40
00000@3oool000030000003oool0oooo00H0oooo0`00o`030000o`L00?l01@000?l00`00o`00oooo
0?ooo`3o0?ooo`40oooo0@0000010?ooo`0000<000000?ooo`3oool01P3oool2003o00D0003o1P00
o`050000o`800?l0o`3oool20?ooo`4000000@3oool000030000003oool0oooo00L0oooo00<00?l0
0000o`000?l00`000?l6003o00H0003o0`00o`3o0?ooo`4000000@3oool000030000003oool0oooo
00P0oooo1@000?l6003o00L0003o0`00o`3n0?ooo`4000000@3oool000030000003oool0oooo00T0
oooo0`000?l7003o00L0003o0`00o`3n0?ooo`4000000@3oool000030000003oool0oooo00X0oooo
2P00o`090000o`<00?l0n`3oool100000040oooo00000`000000oooo0?ooo`0:0?ooo``00?l02000
0?l3003o0?X0oooo0@0000010?ooo`0000<000000?ooo`3oool02P3oool?003o00D0003o0`00o`3j
0?ooo`4000000@3oool000030000003oool0oooo00/0oooo3P00o`050000o`<00?l0nP3oool10000
0040oooo00000`000000oooo0?ooo`0<0?ooo`D00?l00`000?l6003o00D0003o0`00o`00103oool0
0?l0003o0000o`3e0?ooo`4000000@3oool000030000003oool0oooo00`0oooo1000o`050000o`H0
0?l01@000?l7003o0?@0oooo0@0000010?ooo`0000<000000?ooo`3oool0303oool4003o00D0003o
1P00o`050000o`P00?l0l`3oool100000040oooo00000`000000oooo0?ooo`0=0?ooo`<00?l01@00
0?l6003o00D0003o2@00o`3b0?ooo`4000000@3oool000030000003oool0oooo00d0oooo1000o`03
0000o`L00?l01@000?l9003o0?80oooo0@0000010?ooo`0000<000000?ooo`3oool03P3oool>003o
00D0003o2000o`3b0?ooo`4000000@3oool000030000003oool0oooo0100oooo3000o`060000o`P0
0?l0l@3oool100000040oooo00000`000000oooo0?ooo`0@0?ooo``00?l01`000?l;003o0>d0oooo
0@0000010?ooo`0000<000000?ooo`3oool04@3oool<003o00H0003o3000o`3/0?ooo`4000000@3o
ool000030000003oool0oooo0180oooo3000o`050000o``00?l0k03oool100000040oooo00000`00
0000oooo0?ooo`0C0?ooo`X00?l01@000?l=003o0>`0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0503oool8003o00L0003o3@00o`3[0?ooo`4000000@3oool000030000003oool0oooo01D0oooo
1`00o`070000o`h00?l0jP3oool100000040oooo00000`000000oooo0?ooo`0F0?ooo`H00?l01`00
0?l2003o00<0003o2@00o`00103oool0003o0000o`000?oV0?ooo`4000000@3oool000030000003o
ool0oooo01P0oooo1@00o`0?0000o`D00?l01@000?oU0?ooo`4000000@3oool000030000003oool0
oooo01P0oooo1`00o`0>0000o`@00?l01@000?oU0?ooo`4000000@3oool000030000003oool0oooo
01P0oooo2P00o`0;0000o`@00?l01@000?oU0?ooo`4000000@3oool000030000003oool0oooo01T0
oooo2@00o`0;0000o`@00?l01@000?oU0?ooo`4000000@3oool000030000003oool0oooo01/0oooo
2000o`090000o`D00?l01@000?oU0?ooo`4000000@3oool000030000003oool0oooo01`0oooo2000
o`080000o`D00?l01@000?oU0?ooo`4000000@3oool000030000003oool0oooo01d0oooo1`00o`08
0000o`04003o00000?l0003o0000o`800?l00`000?l2003o0>@0oooo0@0000010?ooo`0000<00000
0?ooo`3oool07P3oool7003o00`0003o1`00o`3S0?ooo`4000000@3oool000030000003oool0oooo
01l0oooo2000o`040000o`03003o00000?l0003o00<0003o1P00o`030000on40oooo0@0000010?oo
o`0000<000000?ooo`3oool0803oool;003o00H0003o1@00o`050000on00oooo0@0000010?ooo`00
00<000000?ooo`3oool08P3oool7003o00X0003o0P00o`060000on00oooo0@0000010?ooo`0000<0
00000?ooo`3oool08P3oool6003o01D0003ogP3oool100000040oooo00000`000000oooo0?ooo`0R
0?ooo`H00?l060000?oK0?ooo`4000000@3oool000030000003oool0oooo0280oooo1P00o`060000
o`03003o00000?l0003o0100003ofP3oool100000040oooo00000`000000oooo0?ooo`0S0?ooo`H0
0?l00`000?l3003o0180003ofP3oool100000040oooo00000`000000oooo0?ooo`0U0?ooo`X00?l0
4P000?oJ0?ooo`4000000@3oool000030000003oool0oooo02D0oooo2P00o`0<0000o`800?l00`00
0?l00`00o`00oooo0?ooo`3H0?ooo`4000000@3oool000030000003oool0oooo02D0oooo2`00o`0;
0000o`H00?l0fP3oool100000040oooo00000`000000oooo0?ooo`0V0?ooo`X00?l02P000?l4003o
00<0003ofP3oool100000040oooo00000`000000oooo0?ooo`0V0?ooo`/00?l00`000?l00`00o`00
003o0000o`040000o`800?l01@000?oI0?ooo`4000000@3oool000030000003oool0oooo02H0oooo
4@00o`0;0000omT0oooo0@0000010?ooo`0000<000000?ooo`3oool09`3oool@003o00/0003o0`00
o`3F0?ooo`4000000@3oool000030000003oool0oooo02L0oooo3`00o`0;0000o`D00?l0e@3oool1
00000040oooo00000`000000oooo0?ooo`0X0?ooo`d00?l02@000?l8003o0=D0oooo0@0000010?oo
o`0000<000000?ooo`3oool0:03oool=003o00P0003o2@00o`3E0?ooo`4000000@3oool000030000
003oool0oooo02T0oooo3000o`050000o``00?l0e@3oool100000040oooo00000`000000oooo0?oo
o`0_0?ooo`L00?l00`000?l01000o`00003o0000o`000?l8003o0=H0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0;`3oool6003o00T0003o1`00o`3F0?ooo`4000000@3oool000030000003oool0
oooo0300oooo1@00o`090000o`P00?l00P3oool4003o0<l0oooo0@0000010?ooo`0000<000000?oo
o`3oool0<@3oool4003o00T0003o3`00o`3>0?ooo`4000000@3oool000030000003oool0oooo0340
oooo0`00o`090000o`/00?l00`000?l2003o0<h0oooo0@0000010?ooo`0000<000000?ooo`3oool0
<P3oool2003o00T0003o1000o`030000o`<00?l01@000?l4003o0</0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0<`3oool00`00o`00003o0000o`070000o`<00?l01P000?l00`00o`00003o0000
o`070000o`03003o003oool0oooo0<P0oooo0@0000010?ooo`0000<000000?ooo`3oool0=03oool0
0`00o`00003o0000o`060000o`<00?l04@000?o:0?ooo`4000000@3oool000030000003oool0oooo
03H0oooo0`00o`030000o`@00?l01`000?l00`00o`00003o0000o`070000olX0oooo0@0000010?oo
o`0000<000000?ooo`3oool0=`3oool:003o00H0003o0`00o`070000olX0oooo0@0000010?ooo`00
00<000000?ooo`3oool0>03oool;003o00<0003o1@00o`050000ol/0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0>@3ooolC003o00<0003o0`00o`390?ooo`4000000@3oool000030000003oool0
oooo03T0oooo4P00o`050000o`<00?l0b03oool100000040oooo00000`000000oooo0?ooo`0j0?oo
oa400?l01@000?l2003o00<0003oaP3oool100000040oooo00000`000000oooo0?ooo`0k0?ooo`l0
0?l030000?o50?ooo`4000000@3oool000030000003oool0oooo03d0oooo3@00o`0<0000olD0oooo
0@0000010?ooo`0000<000000?ooo`3oool0?P3oool<003o00`0003oa@3oool100000040oooo0000
0`000000oooo0?ooo`0n0?ooo`d00?l02P000?o60?ooo`4000000@3oool000030000003oool0oooo
03l0oooo4000o`030000o`<00?l00`000?o30?ooo`4000000@3oool000030000003oool0oooo03l0
oooo4P00o`080000ol80oooo0@0000010?ooo`0000<000000?ooo`3oool0@03oool@003o00T0003o
00@00?l00000o`000?l0003o_P3oool100000040oooo00000`000000oooo0?ooo`100?oooa000?l0
3P000?nm0?ooo`4000000@3oool000030000003oool0oooo0440oooo2`00o`0B0000okd0oooo0@00
00010?ooo`0000<000000?ooo`3oool0@P3oool9003o00T0003o00<00?l00000o`000?l01`000?nm
0?ooo`4000000@3oool000030000003oool0oooo0480oooo2@00o`090000o`800?l00`000?l01000
o`00003o0000o`000?nn0?ooo`4000000@3oool000030000003oool0oooo04<0oooo2000o`080000
o`/00?l0_@3oool100000040oooo00000`000000oooo0?ooo`160?ooo`H00?l00`000?l@003o0;`0
oooo0@0000010?ooo`0000<000000?ooo`3oool0A`3ooolI003o0080oooo0`00o`2f0?ooo`400000
0@3oool000030000003oool0oooo04P0oooo3P00o`030000o`d00?l0]@3oool100000040oooo0000
0`000000oooo0?ooo`180?ooo`d00?l01P000?l;003o0;D0oooo0@0000010?ooo`0000<000000?oo
o`3oool0B03oool<003o00P0003o3@00o`2b0?ooo`4000000@3oool000030000003oool0oooo04T0
oooo2`00o`080000o`800?l00`000?l2003o00<0003o1000o`2a0?ooo`4000000@3oool000030000
003oool0oooo04X0oooo2P00o`080000o`03003o00000?l0003o00T0003o0P00o`2a0?ooo`400000
0@3oool000030000003oool0oooo04X0oooo2`00o`060000o`800?l030000?l00`00o`00oooo0?oo
o`2_0?ooo`4000000@3oool000030000003oool0oooo04/0oooo2P00o`050000o`<00?l030000?nb
0?ooo`4000000@3oool000030000003oool0oooo04`0oooo2@00o`050000o`@00?l00`000?l00`00
o`00003o0000o`050000ok80oooo0@0000010?ooo`0000<000000?ooo`3oool0C03oool:003o00<0
003o2@00o`060000ok<0oooo0@0000010?ooo`0000<000000?ooo`3oool0C@3oool3003o00030?oo
o`00o`000?l000l00?l01@000?l00`00o`00oooo0?ooo`2a0?ooo`4000000@3oool000030000003o
ool0oooo0540oooo4P00o`030000o`<00?l0/P3oool100000040oooo00000`000000oooo0?ooo`1A
0?oooaT00?l0/@3oool100000040oooo00000`000000oooo0?ooo`1B0?oooaP00?l0/@3oool10000
0040oooo00000`000000oooo0?ooo`1B0?oooa400?l00`000?l7003o0:h0oooo0@0000010?ooo`00
00<000000?ooo`3oool0D`3oool?003o00D0003o1`00o`2]0?ooo`4000000@3oool000030000003o
ool0oooo05<0oooo3`00o`050000o`P00?l0[03oool100000040oooo00000`000000oooo0?ooo`1C
0?ooo`l00?l01@000?l8003o0:`0oooo0@0000010?ooo`0000<000000?ooo`3oool0E03oool?003o
00@0003o2000o`2/0?ooo`4000000@3oool000030000003oool0oooo05T0oooo2P00o`080000o`<0
0?l0[@3oool100000040oooo00000`000000oooo0?ooo`1I0?ooo`03o`3o0000o`000?l000L00?l0
2@000?l20?ooo`<0003o00<00?l00?ooo`3oool0Y`3oool100000040oooo00000`000000oooo0?oo
o`1I0?ooo`T00?l040000?l00`00o`00oooo0?ooo`2V0?ooo`4000000@3oool000030000003oool0
oooo05T0oooo2@00o`0@0000o`03003o003oool0oooo0:H0oooo0@0000010?ooo`0000<000000?oo
o`3oool0F@3oool9003o0100003o00<00?l00?ooo`3oool0YP3oool100000040oooo00000`000000
oooo0?ooo`1J0?ooo`T00?l040000?l5003o0:<0oooo0@0000010?ooo`0000<000000?ooo`3oool0
F`3oool:003o00h0003o1P00o`2R0?ooo`4000000@3oool000030000003oool0oooo05d0oooo2000
o`0>0000o`H00?l0XP3oool100000040oooo00000`000000oooo0?ooo`1M0?ooo`P00?l04@000?l3
003o00@0oooo0`00o`2K0?ooo`4000000@3oool000030000003oool0oooo05h0oooo1P00o`0C0000
o`800?l00`3oool5003o09X0oooo0@0000010?ooo`0000<000000?ooo`3oool0GP3oool6003o01@0
003o00@00?l00?ooo`3oool0oooo1@00o`2J0?ooo`4000000@3oool000030000003oool0oooo05h0
oooo1P00o`0D0000o`04003o003oool0oooo0?ooo`D00?l0VP3oool100000040oooo00000`000000
oooo0?ooo`1O0?ooo`<00?l00P3oool00`00o`00003o0000o`0B0000o`@0oooo0`00o`2K0?ooo`40
00000@3oool000030000003oool0oooo06@0oooo00<00?l00000o`000?l05P000?nN0?ooo`400000
0@3oool000030000003oool0oooo06@0oooo0P00o`0I0000oi`0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0I03oool3003o01T0003oV`3oool100000040oooo00000`000000oooo0?ooo`1U0?oo
o`<00?l060000?nK0?ooo`4000000@3oool000030000003oool0oooo06L0oooo0P00o`0G0000oi/0
oooo0@0000010?ooo`0000<000000?ooo`3oool0J03oool2003o01X0003oU`3oool100000040oooo
00000`000000oooo0?ooo`1Z0?ooo`03003o00000?l0003o01P0003oUP3oool100000040oooo0000
0`000000oooo0?ooo`1Z0?ooo`03003o00000?l0003o01P0003oUP3oool100000040oooo00000`00
0000oooo0?ooo`1[0?oooaX0003oUP3oool100000040oooo00000`000000oooo0?ooo`1Z0?ooo`03
o`3o0000o`00003o01P0003oUP3oool100000040oooo00000`000000oooo0?ooo`1Z0?ooo`;o0?l0
00<00?l00000o`000?l06@000?nC0?ooo`4000000@3oool000030000003oool0oooo06X0oooo0ol0
o`0L0000oi80oooo0@0000010?ooo`0000<000000?ooo`3oool0J`3oool3o`3o01`0003oT@3oool1
00000040oooo00000`000000oooo0?ooo`1^0?oooa`0003oT@3oool100000040oooo00000`000000
oooo0?ooo`1^0?oooa`0003oT@3oool100000040oooo00000`000000oooo0?ooo`1_0?oooad0003o
S`3oool100000040oooo00000`000000oooo0?ooo`1`0?oooah0003oS@3oool100000040oooo0000
0`000000oooo0?ooo`1`0?ooo`03003o00000?l0003o01`0003oS03oool100000040oooo00000`00
0000oooo0?ooo`1`0?ooo`@00?l07P000?n90?ooo`4000000@3oool000030000003oool0oooo0740
oooo0`00o`0P0000ohL0oooo0@0000010?ooo`0000<000000?ooo`3oool0M@3ooolQ0000ohD0oooo
0@0000010?ooo`0000<000000?ooo`3oool0MP3ooolQ0000oh@0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0MP3ooolQ0000oh@0oooo0@0000010?ooo`0000<000000?ooo`3oool0MP3ooolQ0000
oh@0oooo0@0000010?ooo`0000<000000?ooo`3oool0M`3ooolO0000o`03003o003oool0oooo0880
oooo0@0000010?ooo`0000<000000?ooo`3oool0N03ooolP0000o`03003o003oool0oooo0800oooo
0@0000010?ooo`0000<000000?ooo`3oool0N@3ooolP0000o`03003o003oool0oooo07l0oooo0@00
00010?ooo`0000<000000?ooo`3oool0N@3oool00`00o`00003o0000o`0M0000o`04003o00000?l0
003o0000ogh0oooo0@0000010?ooo`0000<000000?ooo`3oool0NP3oool2003o0280003oO@3oool1
00000040oooo00000`000000oooo0?ooo`1k0?ooo`800?l08@000?mm0?ooo`4000000@3oool00003
0000003oool0oooo07`0oooo00<00?l00000o`000?l07`000?mm0?ooo`4000000@3oool000030000
003oool0oooo07h0oooo7`000?mn0?ooo`4000000@3oool000030000003oool0oooo07l0oooo7P00
0?l01@00o`00oooo0?ooo`3oool00?l000<0003oMP3oool100000040oooo00000`000000oooo0?oo
o`1o0?ooo`800?l070000?l2003o00030?ooo`00o`00003o00@0003oM@3oool100000040oooo0000
0`000000oooo0?ooo`200?ooo`03003o00000?l0003o01X0003o0P00o`000`3oool00?l00000o`04
0000ogD0oooo0@0000010?ooo`0000<000000?ooo`3oool0P@3ooolN0000o`800?l01@000?me0?oo
o`4000000@3oool000030000003oool0oooo0880oooo8`000?l3003o07<0oooo0@0000010?ooo`00
00<000000?ooo`3oool0P`3oool2003o01h0003o0P00o`030000o`03003o003oool0oooo0700oooo
0@0000010?ooo`0000<000000?ooo`3oool0Q03oool2003o02<0003oLP3oool100000040oooo0000
0`000000oooo0?ooo`250?ooo`03003o00000?l0003o0280003oL@3oool100000040oooo00000`00
0000oooo0?ooo`260?ooo`03003o00000?l0003o0280003oL03oool100000040oooo00000`000000
oooo0?ooo`270?ooo`800?l08P000?l2003o06h0oooo0@0000010?ooo`0000<000000?ooo`3oool0
R@3oool00`00o`00003o0000o`0O0000o`<00?l0K@3oool100000040oooo00000`000000oooo0?oo
o`290?ooo`03003o00000?l0003o01h0003o1000o`1]0?ooo`4000000@3oool000030000003oool0
oooo08T0oooo00<00?l00000o`000?l07P000?l01000o`00003o0000o`000?m]0?ooo`4000000@3o
ool000030000003oool0oooo08X0oooo00<00?l00000o`000?l08P000?l00`00o`00oooo0?ooo`1Y
0?ooo`4000000@3oool000030000003oool0oooo08/0oooo90000?l2003o06X0oooo0@0000010?oo
o`0000<000000?ooo`3oool0S03ooolS0000o`800?l0JP3oool100000040oooo00000`000000oooo
0?ooo`2?0?ooob00003o0P00o`1Z0?ooo`4000000@3oool000030000003oool0oooo0900oooo8000
0?m[0?ooo`4000000@3oool000030000003oool0oooo0900oooo80000?m[0?ooo`4000000@3oool0
00030000003oool0oooo0940oooo7`000?l2003o06T0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0T03oool2o`3o01h0003o0`00o`1X0?ooo`4000000@3oool000030000003oool0oooo0900oooo
00?o0?l00000o`000?l07P000?l2003o00040?ooo`000?l0003o0000of@0oooo0@0000010?ooo`00
00<000000?ooo`3oool0T03oool00ol0o`00003o0000o`0O0000o`03003o00000?l0003o00<0003o
H`3oool100000040oooo00000`000000oooo0?ooo`2A0?ooobL0003oH`3oool100000040oooo0000
0`000000oooo0?ooo`2B0?ooobH0003oH`3oool100000040oooo00000`000000oooo0?ooo`2E0?oo
ob80003oI03oool100000040oooo00000`000000oooo0?ooo`2E0?ooob00003oIP3oool100000040
oooo00000`000000oooo0?ooo`2F0?ooob00003o0`00o`1R0?ooo`4000000@3oool000030000003o
ool0oooo09P0oooo7`000?l01000o`00003o0000o`000?mP0?ooo`4000000@3oool000030000003o
ool0oooo09X0oooo8P000?mO0?ooo`4000000@3oool000030000003oool0oooo09X0oooo8P000?mO
0?ooo`4000000@3oool000030000003oool0oooo09/0oooo8@000?mO0?ooo`4000000@3oool00003
0000003oool0oooo09d0oooo7`000?mO0?ooo`4000000@3oool000030000003oool0oooo09d0oooo
80000?mN0?ooo`4000000@3oool000030000003oool0oooo09`0oooo0_l0o`0P0000oed0oooo0@00
00010?ooo`0000<000000?ooo`3oool0W03oool3o`3o01l0003oG@3oool100000040oooo00000`00
0000oooo0?ooo`2L0?ooo`Ko0?l07P000?mK0?ooo`4000000@3oool000030000003oool0oooo09d0
oooo0ol0o`000`3oool00?l0003o000N0000oeX0oooo0@0000010?ooo`0000<000000?ooo`3oool0
X@3oool4003o01l0003oE`3oool100000040oooo00000`000000oooo0?ooo`2Q0?ooo`D00?l07`00
0?mF0?ooo`4000000@3oool000030000003oool0oooo0:80oooo1@00o`0O0000oeD0oooo0@000001
0?ooo`0000<000000?ooo`3oool0XP3oool6003o01l0003oE03oool100000040oooo00000`000000
oooo0?ooo`2R0?ooo`D00?l00ol0o`0M0000oe@0oooo0@0000010?ooo`0000<000000?ooo`3oool0
XP3oool01?l0o`000?l0003o0000o`05o`3o01h0003oDP3oool100000040oooo00000`000000oooo
0?ooo`2R0?ooo`co0?l070000?mA0?ooo`4000000@3oool000030000003oool0oooo0:80oooo3?l0
o`0L0000oe40oooo0@0000010?ooo`0000<000000?ooo`3oool0X`3oool3o`3o00030?ooool0o`3o
0?l000Go0?l000<00?l00000o`000?l06P000?m@0?ooo`4000000@3oool000030000003oool0oooo
0:P0oooo1_l0o`03003o01/0003oC`3oool100000040oooo00000`000000oooo0?ooo`2[0?ooo`?o
0?l01@00o`030?oooa/0003oBP3oool100000040oooo00000`000000oooo0?ooo`2[0?ooo`Co0?l0
0`00o`050?oooa/0003oB@3oool100000040oooo00000`000000oooo0?ooo`2[0?ooo`?o0?l01@00
o`040?ooo`800?l06@000?m90?ooo`4000000@3oool000030000003oool0oooo0:/0oooo0ol0o`05
003o0004o`3o003oool0oooo0?ooo`800?l06P000?m80?ooo`4000000@3oool000030000003oool0
oooo0:`0oooo0_l0o`05003o0006o`3o0000o`000?l0003o003oool00?l06`000?m70?ooo`400000
0@3oool000030000003oool0oooo0:`0oooo0ol0o`03003o0003o`3o0000o`000?l000<00?l00P3o
oolJ0000odL0oooo0@0000010?ooo`0000<000000?ooo`3oool0[03oool7o`3o00D00?l01@3ooolH
0000odH0oooo0@0000010?ooo`0000<000000?ooo`3oool0[@3oool3o`3o00<0oooo1@00o`050?oo
oaT0003oA@3oool100000040oooo00000`000000oooo0?ooo`2a0?ooo`?o0?l00`00o`070?oooaX0
003o@`3oool100000040oooo00000`000000oooo0?ooo`2`0?ooo`Go0?l02@3ooolK0000od80oooo
0@0000010?ooo`0000<000000?ooo`3oool0/03oool5o`3o00X0oooo6P000?l00`00o`00oooo0?oo
o`0o0?ooo`4000000@3oool000030000003oool0oooo0;00oooo1Ol0o`0;0?oooaT0003o0P00o`10
0?ooo`4000000@3oool000030000003oool0oooo0;40oooo0ol0o`0A0?oooaD0003o0P00o`0o0?oo
o`4000000@3oool000030000003oool0oooo0;P0oooo0`00o`0;0?oooaD0003o0P00o`0n0?ooo`40
00000@3oool000030000003oool0oooo0;L0oooo1@00o`0;0?oooa@0003o0`00o`0m0?ooo`400000
0@3oool000030000003oool0oooo0;L0oooo1@00o`0<0?oooa<0003o0`00o`0m0?ooo`4000000@3o
ool000030000003oool0oooo0;L0oooo1@00o`0=0?oooa<0003o00@00?l00000o`000?l0003o>`3o
ool100000040oooo00000`000000oooo0?ooo`2f0?ooo`D00?l000@0oooo003o0000o`000?l0303o
oolF0000ocX0oooo0@0000010?ooo`0000<000000?ooo`3oool0]P3oool:003o00/0oooo60000?lh
0?ooo`4000000@3oool000030000003oool0oooo0;H0oooo2P00o`0<0?oooaP0003o=`3oool10000
0040oooo00000`000000oooo0?ooo`2g0?ooo`<00?l000<0oooo003o0000o`000`00o`0>0?oooaH0
003o=`3oool100000040oooo00000`000000oooo0?ooo`2l0?ooo`<00?l0403ooolE0000ocL0oooo
0@0000010?ooo`0000<000000?ooo`3oool0c`3oool@0000o`050?ooo`000?l0003o0000o`3oool0
0`00o`0d0?ooo`4000000@3oool000030000003oool0oooo0=00oooo3`000?l40?ooo`D00?l0<`3o
ool100000040oooo00000`000000oooo0?ooo`3C0?ooo`/0003o0P3oool30000o`D00?l0<`3oool1
00000040oooo00000`000000oooo0?ooo`3D0?ooo`T0003o0P3oool50000o`@00?l0<`3oool10000
0040oooo00000`000000oooo0?ooo`3G0?ooo`03003o00000?l0003o00X0003o0`00o`0d0?ooo`40
00000@3oool000030000003oool0oooo0=L0oooo00<00?l00000o`000?l03@000?ld0?ooo`400000
0@3oool000030000003oool0oooo0=L0oooo00<00?l00000o`000?l03P000?lc0?ooo`4000000@3o
ool000030000003oool0oooo0<80oooo0`00o`0C0?oooa40003o<P3oool100000040oooo00000`00
0000oooo0?ooo`310?ooo`D00?l04`3oool60000o`03003o00000?l0003o00P0003o<@3oool10000
0040oooo00000`000000oooo0?ooo`310?ooo`D00?l0503oool00`00o`00003o0000o`0=0000oc40
oooo0@0000010?ooo`0000<000000?ooo`3oool0`@3oool5003o01D0oooo3`000?la0?ooo`400000
0@3oool000030000003oool0oooo0<80oooo0`00o`0F0?ooo`h0003o103oool30000ob/0oooo0@00
00010?ooo`0000<000000?ooo`3oool0g03oool>0000o`80oooo1@000?lZ0?ooo`4000000@3oool0
00030000003oool0oooo0=d0oooo00H00?l00000o`000?l0003o003o003oool80000o`030?ooo`00
0?l0003o00<0003o:P3oool100000040oooo00000`000000oooo0?ooo`3C0?ooo`<00?l01`3oool5
003o00030?ooo`000?l0003o00`0003o00<00?l00?ooo`3oool09`3oool100000040oooo00000`00
0000oooo0?ooo`3B0?ooo`D00?l01`3oool3003o0080oooo3@000?l3003o02P0oooo0@0000010?oo
o`0000<000000?ooo`3oool0dP3oool5003o00`0oooo30000?l4003o02P0oooo0@0000010?ooo`00
00<000000?ooo`3oool0dP3oool5003o00d0oooo30000?l3003o02P0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0d`3oool3003o0140oooo2P000?l00`00o`00oooo0000o`020000obD0oooo0@00
00010?ooo`0000<000000?ooo`3oool0jP3oool70000o`030?ooo`000?l0003o00<0003o903oool1
00000040oooo00000`000000oooo0?ooo`3[0?ooo`H0003o00<0oooo0000o`000?l00`000?lT0?oo
o`4000000@3oool000030000003oool0oooo0>`0oooo1@000?l00`3oool0003o0000o`030000o`03
003o003oool0oooo0240oooo0@0000010?ooo`0000<000000?ooo`3oool0k03oool60000o`04003o
00000?l0003o0000o`<00?l08P3oool100000040oooo00000`000000oooo0?ooo`3/0?ooo`X0003o
1000o`0Q0?ooo`4000000@3oool000030000003oool0oooo0>`0oooo2`000?l4003o0200oooo0@00
00010?ooo`0000<000000?ooo`3oool0k@3oool=0000o`03003o003oool0oooo01h0oooo0@000001
0?ooo`0000<000000?ooo`3oool0l@3oool:0000o`03003o003oool0oooo01d0oooo0@0000010?oo
o`0000<000000?ooo`3oool0lP3oool:0000oal0oooo0@0000010?ooo`0000<000000?ooo`3oool0
lP3oool;0000oah0oooo0@0000010?ooo`0000<000000?ooo`3oool0l`3oool:0000oah0oooo0@00
00010?ooo`0000<000000?ooo`3oool0mP3oool00`00o`00003o0000o`040000o`04003o00000?l0
003o0000oaX0oooo0@0000010?ooo`0000<000000?ooo`3oool0m`3oool00`00o`00003o0000o`02
0000o`03003o00000?l0003o00<0003o6@3oool100000040oooo00000`000000oooo0?ooo`3j0?oo
o`03003o00000?l0003o00D0003o6@3oool100000040oooo00000`000000oooo0?ooo`3j0?ooo`P0
003o00<00?l00?ooo`3oool05P3oool100000040oooo00000`000000oooo0?ooo`3j0?ooo`T0003o
603oool100000040oooo00000`000000oooo0?ooo`3j0?ooo`/0003o5P3oool100000040oooo0000
0`000000oooo0?ooo`3k0?ooo`/0003o5@3oool100000040oooo00000`000000oooo0?ooo`3l0?oo
o`03003o00000?l0003o00L0003o5@3oool100000040oooo00000`000000oooo0?ooo`3o0?ooo`40
oooo1P000?l00`00o`00oooo0?ooo`0B0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo
0P3oool80000oa80oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3oool20?ooo`T0003o4@3o
ool100000040oooo00000`000000oooo0?ooo`3o0?ooo`80oooo2P000?l@0?ooo`4000000@3oool0
00030000003oool0oooo0?l0oooo0`3oool90000oa00oooo0@0000010?ooo`0000<000000?ooo`3o
ool0o`3oool60?ooo`L0003o3`3oool100000040oooo00000`000000oooo0?ooo`3o0?ooo`P0oooo
1@000?l?0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo203oool50000o`l0oooo0@00
00010?ooo`0000<000000?ooo`3oool0o`3oool90?ooo`<0003o403oool100000040oooo00000`00
0000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`40
00000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?oo
o`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool0
00030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0
oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003o
ool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@000001
0?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool00?l00000800000010?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.122445, -0.122445, 0.889355, \
0.889355}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RB plane", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[\({#[\([1]\)], #[\([3]\)]} &\)\  /@ \ d1\  // N, pr, 
          style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[\({#[\([1]\)], #[\([3]\)]} &\)\  /@ \ d2\  // N, pr, 
          style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(distRB\  = \ 
        Show[gd1, gd2, \ FrameTicks \[Rule] None, yS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 0 r
.02 w
.06278 .03141 Mdot
.06278 .02749 Mdot
.06278 .03533 Mdot
.0667 .04317 Mdot
.0667 .05102 Mdot
.07062 .05494 Mdot
.07062 .05102 Mdot
.08239 .05102 Mdot
.07846 .04709 Mdot
.08239 .05102 Mdot
.08631 .05494 Mdot
.07454 .05102 Mdot
.07846 .04709 Mdot
.07454 .04709 Mdot
.0667 .04317 Mdot
.0667 .05102 Mdot
.0667 .04709 Mdot
.07454 .05102 Mdot
.07846 .05102 Mdot
.0667 .04317 Mdot
.0667 .04317 Mdot
.06278 .04317 Mdot
.05494 .03925 Mdot
.05494 .04317 Mdot
.06278 .05102 Mdot
.06278 .05886 Mdot
.0667 .05886 Mdot
.06278 .05886 Mdot
.07062 .05886 Mdot
.07454 .05886 Mdot
.08239 .05886 Mdot
.07846 .05494 Mdot
.07846 .05102 Mdot
.07454 .04709 Mdot
.08239 .05886 Mdot
.08631 .06278 Mdot
.08631 .06278 Mdot
.07846 .05494 Mdot
.07846 .05102 Mdot
.08239 .05886 Mdot
.07846 .05494 Mdot
.07846 .05102 Mdot
.07062 .05494 Mdot
.07454 .0667 Mdot
.07846 .06278 Mdot
.07454 .05886 Mdot
.07454 .05102 Mdot
.07454 .04709 Mdot
.07846 .05102 Mdot
.08239 .05102 Mdot
.09023 .05886 Mdot
.09023 .05886 Mdot
.09023 .06278 Mdot
.09415 .07846 Mdot
.08631 .07454 Mdot
.09023 .08239 Mdot
.09023 .07846 Mdot
.08631 .07454 Mdot
.07846 .07062 Mdot
.07846 .07062 Mdot
.07846 .07062 Mdot
.07062 .06278 Mdot
.0667 .05494 Mdot
.07062 .05102 Mdot
.07062 .05102 Mdot
.07062 .04709 Mdot
.07846 .05494 Mdot
.07846 .06278 Mdot
.08239 .0667 Mdot
.08239 .07454 Mdot
.08239 .07454 Mdot
.09023 .07846 Mdot
.09023 .07846 Mdot
.07846 .06278 Mdot
.07846 .0667 Mdot
.07454 .06278 Mdot
.07846 .0667 Mdot
.08631 .07454 Mdot
.09023 .07454 Mdot
.09023 .0667 Mdot
.08239 .05886 Mdot
.08631 .07062 Mdot
.08239 .0667 Mdot
.08239 .0667 Mdot
.08239 .07062 Mdot
.08239 .0667 Mdot
.09023 .0667 Mdot
.08631 .05494 Mdot
.08631 .05886 Mdot
.08631 .0667 Mdot
.08631 .06278 Mdot
.09023 .06278 Mdot
.08631 .06278 Mdot
.08631 .07062 Mdot
.08239 .07062 Mdot
.08631 .07846 Mdot
.07846 .07454 Mdot
.07846 .07454 Mdot
.07454 .0667 Mdot
.07454 .06278 Mdot
.08631 .0667 Mdot
.07846 .05886 Mdot
.07454 .05102 Mdot
.07454 .05494 Mdot
.07062 .04709 Mdot
.07454 .05102 Mdot
.06278 .05102 Mdot
.0667 .05886 Mdot
.07062 .05102 Mdot
.0667 .05102 Mdot
.07846 .05886 Mdot
.07454 .05886 Mdot
.07062 .05494 Mdot
.0667 .05102 Mdot
.07062 .05886 Mdot
.0667 .05494 Mdot
.0667 .04709 Mdot
.05494 .03533 Mdot
.05886 .03533 Mdot
.05494 .03925 Mdot
.05494 .03925 Mdot
.05886 .03925 Mdot
.06278 .04709 Mdot
.05494 .04709 Mdot
.05102 .04317 Mdot
.04709 .03533 Mdot
.04317 .02749 Mdot
.03925 .02357 Mdot
.04709 .03141 Mdot
.04317 .03141 Mdot
.04317 .02357 Mdot
.04317 .02749 Mdot
.05494 .04317 Mdot
.04709 .05102 Mdot
.04317 .0667 Mdot
.04317 .0667 Mdot
.05102 .0667 Mdot
.04709 .05494 Mdot
.04709 .03925 Mdot
.04317 .03925 Mdot
.03533 .03925 Mdot
.03533 .04317 Mdot
.03533 .05102 Mdot
.04709 .07062 Mdot
.00396 .02749 Mdot
.00396 .01572 Mdot
.00788 .0118 Mdot
.00396 .01572 Mdot
.00788 .02357 Mdot
.00788 .02749 Mdot
.00788 .03141 Mdot
.0118 .03141 Mdot
.0118 .02357 Mdot
.0118 .01965 Mdot
.00788 .02357 Mdot
.00396 .01965 Mdot
.00788 .01572 Mdot
.01572 .01572 Mdot
.01572 .01572 Mdot
.01965 .0118 Mdot
.08631 .08631 Mdot
.10591 .10591 Mdot
.11768 .11768 Mdot
.11768 .1216 Mdot
.11376 .12944 Mdot
.11768 .14513 Mdot
.1216 .12944 Mdot
.11768 .10983 Mdot
.10591 .09023 Mdot
.10199 .08239 Mdot
.10983 .07846 Mdot
.11768 .08239 Mdot
.12552 .08631 Mdot
.1216 .08239 Mdot
.1216 .07846 Mdot
.11768 .07454 Mdot
.1216 .07846 Mdot
.11768 .07846 Mdot
.11768 .07846 Mdot
.1216 .08239 Mdot
.1216 .08631 Mdot
.11768 .08239 Mdot
.10199 .07454 Mdot
.10983 .08239 Mdot
.10591 .07846 Mdot
.10199 .07846 Mdot
.10591 .08239 Mdot
.11376 .09415 Mdot
.12552 .10199 Mdot
.12944 .10983 Mdot
.12552 .10591 Mdot
.12944 .10591 Mdot
.13336 .10199 Mdot
.13336 .09807 Mdot
.12944 .09807 Mdot
.11768 .09807 Mdot
.12552 .10199 Mdot
.13336 .10591 Mdot
.13728 .10199 Mdot
.14513 .10983 Mdot
.13728 .10199 Mdot
.14513 .10591 Mdot
.13728 .09807 Mdot
.13728 .10591 Mdot
.14905 .10983 Mdot
.1412 .10199 Mdot
.13728 .10199 Mdot
.1412 .10591 Mdot
.14905 .10983 Mdot
.15297 .10983 Mdot
.16473 .11768 Mdot
.15689 .11768 Mdot
.15689 .12944 Mdot
.1412 .1216 Mdot
.14513 .1216 Mdot
.14905 .12944 Mdot
.13728 .11376 Mdot
.14905 .1216 Mdot
.14905 .11376 Mdot
.15297 .11376 Mdot
.15689 .1216 Mdot
.14905 .11768 Mdot
.15689 .1216 Mdot
.15297 .11376 Mdot
.14905 .10983 Mdot
.14513 .10591 Mdot
.14905 .10983 Mdot
.14905 .11376 Mdot
.15297 .11768 Mdot
.14905 .12944 Mdot
.13336 .11376 Mdot
.1412 .10591 Mdot
.14905 .10983 Mdot
.14513 .10983 Mdot
.15297 .11768 Mdot
.14905 .10983 Mdot
.14513 .10983 Mdot
.16865 .12552 Mdot
.14905 .10591 Mdot
.14905 .10199 Mdot
.15689 .11376 Mdot
.17257 .12944 Mdot
.1412 .09807 Mdot
.16081 .11376 Mdot
.14905 .10983 Mdot
.15689 .11768 Mdot
.16081 .1216 Mdot
.1765 .12552 Mdot
.1765 .12944 Mdot
.17257 .12552 Mdot
.17257 .13336 Mdot
.17257 .12944 Mdot
.1765 .14513 Mdot
.16081 .12944 Mdot
.15297 .11376 Mdot
.14513 .10199 Mdot
.14905 .10591 Mdot
.14513 .10983 Mdot
.15689 .11376 Mdot
.16473 .11376 Mdot
.16473 .11376 Mdot
.16473 .11768 Mdot
.16473 .1216 Mdot
.15689 .1216 Mdot
.16081 .12552 Mdot
.16473 .13728 Mdot
.13728 .11768 Mdot
.13336 .10983 Mdot
.12944 .09415 Mdot
.1216 .09023 Mdot
.12944 .09415 Mdot
.13336 .10199 Mdot
.12552 .10591 Mdot
.12552 .10591 Mdot
.13336 .10591 Mdot
.12552 .09807 Mdot
.1216 .08631 Mdot
.10591 .07062 Mdot
.1412 .09415 Mdot
.12944 .08631 Mdot
.13336 .08631 Mdot
.13336 .08631 Mdot
.12944 .07846 Mdot
.10983 .07062 Mdot
.10591 .0667 Mdot
.11376 .0667 Mdot
.11376 .0667 Mdot
.10591 .06278 Mdot
.10199 .0667 Mdot
.10591 .07062 Mdot
.09807 .0667 Mdot
.10591 .07062 Mdot
.09807 .07454 Mdot
.09023 .08239 Mdot
.09023 .08631 Mdot
.11768 .12944 Mdot
.04709 .08631 Mdot
.05102 .07454 Mdot
.05102 .05102 Mdot
.03533 .03141 Mdot
.03533 .02749 Mdot
.07846 .06278 Mdot
.05102 .04317 Mdot
.00396 .00396 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00788 .0118 Mdot
.00788 .01572 Mdot
.00396 .01572 Mdot
.00396 .01572 Mdot
.00396 .0118 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00788 .00396 Mdot
.01572 .00396 Mdot
.01965 .00396 Mdot
.59215 .59607 Mdot
.61176 .62352 Mdot
.62352 .63528 Mdot
.62352 .63136 Mdot
.4902 .49804 Mdot
.12552 .16865 Mdot
.09807 .1216 Mdot
.09807 .10591 Mdot
.0667 .0667 Mdot
.05886 .04709 Mdot
.05886 .03533 Mdot
.07454 .04317 Mdot
.09415 .05494 Mdot
.09807 .05494 Mdot
.10199 .05886 Mdot
.10591 .05494 Mdot
.10983 .05886 Mdot
.10591 .05886 Mdot
.10983 .05886 Mdot
.11376 .06278 Mdot
.10199 .06278 Mdot
.10983 .07454 Mdot
.10983 .07846 Mdot
.1216 .08631 Mdot
.11768 .09023 Mdot
.11376 .09023 Mdot
.1216 .10199 Mdot
.11768 .09807 Mdot
.11768 .09807 Mdot
.1216 .10591 Mdot
.12552 .10591 Mdot
.12944 .10591 Mdot
.12944 .09807 Mdot
.12944 .09415 Mdot
.12552 .09023 Mdot
.11768 .08239 Mdot
.1216 .09023 Mdot
.10983 .08239 Mdot
.11768 .07846 Mdot
.13336 .08631 Mdot
.13728 .09415 Mdot
.1412 .09415 Mdot
.13336 .08631 Mdot
.13728 .09415 Mdot
.1412 .09807 Mdot
.1216 .07846 Mdot
.12552 .08239 Mdot
.12944 .08631 Mdot
.13336 .09807 Mdot
.13336 .09807 Mdot
.14513 .10199 Mdot
.14905 .11768 Mdot
.14905 .12944 Mdot
.1412 .12552 Mdot
.14905 .13336 Mdot
.1412 .12552 Mdot
.14513 .11376 Mdot
.15297 .10983 Mdot
.15689 .10591 Mdot
.16081 .09807 Mdot
.16081 .09807 Mdot
.16473 .1216 Mdot
.16081 .1216 Mdot
.16081 .11768 Mdot
.16081 .11376 Mdot
.16081 .11376 Mdot
.15297 .10591 Mdot
.16473 .11376 Mdot
.16081 .11376 Mdot
.15297 .11376 Mdot
.15297 .11376 Mdot
.16081 .11376 Mdot
.16473 .11376 Mdot
.16081 .10591 Mdot
.16081 .11768 Mdot
.14513 .10199 Mdot
.15689 .10199 Mdot
.16081 .09807 Mdot
.16865 .10199 Mdot
.16473 .09807 Mdot
.16081 .09415 Mdot
.15297 .09807 Mdot
.14513 .09023 Mdot
.14905 .09807 Mdot
.14905 .10591 Mdot
.14513 .10199 Mdot
.15297 .10591 Mdot
.15689 .11768 Mdot
.16865 .13336 Mdot
.17257 .13336 Mdot
.18042 .13336 Mdot
.18434 .13728 Mdot
.1765 .13728 Mdot
.16473 .12552 Mdot
.16865 .12552 Mdot
.17257 .12552 Mdot
.16473 .11768 Mdot
.18434 .12944 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.18042 .13336 Mdot
.19218 .14905 Mdot
.19218 .15689 Mdot
.18042 .1412 Mdot
.18434 .14513 Mdot
.18434 .14905 Mdot
.1765 .14513 Mdot
.16865 .13728 Mdot
.15689 .12552 Mdot
.16473 .13336 Mdot
.16865 .13336 Mdot
.18042 .1412 Mdot
.1765 .14513 Mdot
.15297 .12552 Mdot
.15297 .11768 Mdot
.14905 .10983 Mdot
.1412 .10199 Mdot
.14905 .10983 Mdot
.14513 .10199 Mdot
.1412 .09023 Mdot
.14513 .08239 Mdot
.15297 .09415 Mdot
.14513 .09023 Mdot
.14513 .09023 Mdot
.14513 .08631 Mdot
.13728 .08239 Mdot
.14513 .09415 Mdot
.1412 .09415 Mdot
.13336 .09023 Mdot
.13728 .09807 Mdot
.1216 .08631 Mdot
.12552 .08631 Mdot
.12552 .08239 Mdot
.12944 .07846 Mdot
.10591 .05886 Mdot
.10983 .06278 Mdot
.10591 .05102 Mdot
.09023 .04709 Mdot
.09023 .07062 Mdot
.09023 .07846 Mdot
.08239 .07846 Mdot
.09415 .08239 Mdot
.10199 .07846 Mdot
.08631 .05102 Mdot
.08239 .04709 Mdot
.08239 .05494 Mdot
.07454 .05102 Mdot
.07062 .05102 Mdot
.09023 .05886 Mdot
.09415 .06278 Mdot
.09023 .07062 Mdot
.07846 .0667 Mdot
.07846 .07062 Mdot
.07454 .06278 Mdot
.07846 .07454 Mdot
.07846 .07846 Mdot
.08239 .07454 Mdot
.08631 .07062 Mdot
.08239 .0667 Mdot
.08631 .07062 Mdot
.59215 .61176 Mdot
.61568 .64705 Mdot
.63136 .64705 Mdot
.62352 .63136 Mdot
.59999 .60391 Mdot
.25492 .28629 Mdot
.07062 .09415 Mdot
.09807 .10591 Mdot
.08631 .09023 Mdot
.07454 .07062 Mdot
.08239 .06278 Mdot
.08631 .05494 Mdot
.10199 .05886 Mdot
.10199 .05494 Mdot
.09415 .05494 Mdot
.09807 .05494 Mdot
.10591 .05886 Mdot
.11768 .07062 Mdot
.1216 .0667 Mdot
.1216 .0667 Mdot
.1216 .07846 Mdot
.1216 .08239 Mdot
.1216 .09807 Mdot
.12552 .10591 Mdot
.12944 .10591 Mdot
.12944 .10591 Mdot
.12552 .10983 Mdot
.10591 .09415 Mdot
.11376 .10199 Mdot
.11768 .10591 Mdot
.1216 .10591 Mdot
.1216 .10199 Mdot
.1216 .09415 Mdot
.1216 .09415 Mdot
.1216 .08239 Mdot
.12944 .08631 Mdot
.1412 .10199 Mdot
.1412 .09807 Mdot
.12944 .09023 Mdot
.13336 .09023 Mdot
.14513 .09023 Mdot
.14513 .09415 Mdot
.14513 .09023 Mdot
.1412 .09415 Mdot
.14513 .09807 Mdot
.1412 .09415 Mdot
.13336 .09023 Mdot
.1412 .09807 Mdot
.13728 .10591 Mdot
.13336 .10199 Mdot
.1412 .10591 Mdot
.15689 .12944 Mdot
.14905 .13336 Mdot
.1412 .12552 Mdot
.13728 .11768 Mdot
.14905 .11768 Mdot
.15297 .10591 Mdot
.16081 .09415 Mdot
.16865 .09415 Mdot
.16473 .09023 Mdot
.17257 .10591 Mdot
.1961 .13336 Mdot
.18826 .12944 Mdot
.1765 .12944 Mdot
.1961 .1412 Mdot
.18434 .13336 Mdot
.18042 .12552 Mdot
.18042 .12552 Mdot
.15689 .11376 Mdot
.14513 .10983 Mdot
.14513 .10983 Mdot
.14905 .10983 Mdot
.18826 .13728 Mdot
.16473 .11768 Mdot
.14513 .10199 Mdot
.14905 .10199 Mdot
.15297 .09415 Mdot
.16081 .09807 Mdot
.15297 .09023 Mdot
.15297 .09023 Mdot
.15689 .09415 Mdot
.16081 .10199 Mdot
.14905 .09023 Mdot
.14513 .09023 Mdot
.14905 .10591 Mdot
.14905 .11376 Mdot
.15297 .11376 Mdot
.16081 .12944 Mdot
.16081 .12944 Mdot
.16865 .1412 Mdot
.1765 .14513 Mdot
.18042 .14513 Mdot
.17257 .13728 Mdot
.17257 .12944 Mdot
.15297 .10983 Mdot
.15689 .10983 Mdot
.16865 .10983 Mdot
.1765 .11376 Mdot
.18042 .11768 Mdot
.18434 .1216 Mdot
.16865 .11768 Mdot
.18042 .13336 Mdot
.18434 .13728 Mdot
.18042 .12944 Mdot
.18042 .13728 Mdot
.20002 .14905 Mdot
.19218 .14513 Mdot
.17257 .13728 Mdot
.17257 .14513 Mdot
.16865 .14513 Mdot
.16865 .13728 Mdot
.18042 .13728 Mdot
.1765 .13728 Mdot
.16473 .12944 Mdot
.15689 .10983 Mdot
.15297 .10591 Mdot
.15297 .10591 Mdot
.14905 .10199 Mdot
.15297 .10199 Mdot
.15297 .10199 Mdot
.15689 .10199 Mdot
.15297 .10199 Mdot
.15297 .10199 Mdot
.14513 .09415 Mdot
.14513 .09415 Mdot
.15297 .10591 Mdot
.14905 .10591 Mdot
.13728 .10591 Mdot
.13336 .10199 Mdot
.13336 .10199 Mdot
.12552 .09807 Mdot
.1216 .09023 Mdot
.12552 .09023 Mdot
.12552 .09415 Mdot
.1216 .09023 Mdot
.1216 .09023 Mdot
.12944 .09415 Mdot
.11376 .08239 Mdot
.09415 .07062 Mdot
.09415 .08239 Mdot
.09023 .08239 Mdot
.08631 .07846 Mdot
.08239 .07062 Mdot
.09023 .06278 Mdot
.09415 .06278 Mdot
.09807 .0667 Mdot
.09023 .05494 Mdot
.09415 .06278 Mdot
.10199 .07062 Mdot
.09807 .07846 Mdot
.09807 .08239 Mdot
.08239 .08239 Mdot
.08239 .07846 Mdot
.08239 .08239 Mdot
.09023 .08631 Mdot
.08631 .08239 Mdot
.09023 .08239 Mdot
.09415 .08631 Mdot
.09023 .08239 Mdot
.08239 .07062 Mdot
.58039 .60783 Mdot
.62352 .65881 Mdot
.63528 .66273 Mdot
.62352 .63528 Mdot
.61568 .62744 Mdot
.42746 .44706 Mdot
.1216 .15297 Mdot
.10983 .12552 Mdot
.09023 .09415 Mdot
.07454 .07454 Mdot
.07846 .0667 Mdot
.08239 .06278 Mdot
.09023 .06278 Mdot
.10199 .0667 Mdot
.11376 .07062 Mdot
.11768 .08239 Mdot
.11768 .07454 Mdot
.12944 .08631 Mdot
.13336 .08631 Mdot
.13728 .08631 Mdot
.13728 .09807 Mdot
.13336 .10983 Mdot
.12944 .10983 Mdot
.1216 .10591 Mdot
.11768 .09807 Mdot
.10983 .09807 Mdot
.1216 .11376 Mdot
.10983 .10199 Mdot
.11376 .09807 Mdot
.11376 .09415 Mdot
.11768 .09415 Mdot
.1216 .09415 Mdot
.1216 .08239 Mdot
.1216 .07846 Mdot
.1216 .07454 Mdot
.13336 .08631 Mdot
.14513 .09023 Mdot
.13728 .07846 Mdot
.1412 .08239 Mdot
.14905 .09807 Mdot
.14905 .10199 Mdot
.14513 .09807 Mdot
.1412 .09807 Mdot
.14905 .10199 Mdot
.15297 .10983 Mdot
.14905 .10591 Mdot
.14905 .09807 Mdot
.14905 .10199 Mdot
.1412 .09807 Mdot
.14513 .10199 Mdot
.14513 .10199 Mdot
.15297 .1216 Mdot
.14513 .12552 Mdot
.13336 .1216 Mdot
.12944 .11376 Mdot
.14905 .11768 Mdot
.16081 .11376 Mdot
.1765 .10199 Mdot
.17257 .10199 Mdot
.18042 .10983 Mdot
.18042 .11376 Mdot
.18042 .11768 Mdot
.1961 .13728 Mdot
.18434 .13336 Mdot
.18826 .13728 Mdot
.18826 .1412 Mdot
.18826 .13728 Mdot
.19218 .1412 Mdot
.17257 .12944 Mdot
.16081 .12552 Mdot
.16473 .13336 Mdot
.15689 .1216 Mdot
.14905 .10199 Mdot
.14905 .10199 Mdot
.14905 .10199 Mdot
.1412 .09023 Mdot
.15297 .09415 Mdot
.15689 .09415 Mdot
.16473 .09807 Mdot
.16865 .10199 Mdot
.16865 .10983 Mdot
.16865 .11768 Mdot
.16081 .10983 Mdot
.15689 .10983 Mdot
.14513 .10983 Mdot
.14905 .1216 Mdot
.14905 .1216 Mdot
.16473 .1412 Mdot
.15689 .13336 Mdot
.16473 .1412 Mdot
.1765 .14513 Mdot
.18042 .14513 Mdot
.16865 .13336 Mdot
.16473 .12944 Mdot
.16865 .1216 Mdot
.1765 .11376 Mdot
.18042 .11376 Mdot
.19218 .12552 Mdot
.18434 .12552 Mdot
.16865 .11768 Mdot
.1765 .13336 Mdot
.1765 .13728 Mdot
.18434 .14905 Mdot
.18434 .15297 Mdot
.18434 .14513 Mdot
.18434 .1412 Mdot
.19218 .14905 Mdot
.19218 .14905 Mdot
.18826 .14905 Mdot
.18434 .15297 Mdot
.18042 .1412 Mdot
.18042 .13336 Mdot
.1765 .1216 Mdot
.18042 .12552 Mdot
.18042 .1216 Mdot
.1765 .1216 Mdot
.16865 .11768 Mdot
.16081 .11376 Mdot
.16081 .11376 Mdot
.16473 .1216 Mdot
.16473 .1216 Mdot
.15689 .12552 Mdot
.14905 .11768 Mdot
.15689 .11768 Mdot
.14905 .10983 Mdot
.14513 .10591 Mdot
.14513 .10983 Mdot
.13728 .10591 Mdot
.13728 .10591 Mdot
.1412 .10591 Mdot
.12552 .09415 Mdot
.12552 .09415 Mdot
.12552 .09023 Mdot
.1412 .09415 Mdot
.13336 .07846 Mdot
.13336 .09023 Mdot
.12552 .09023 Mdot
.11768 .08631 Mdot
.10591 .08631 Mdot
.09807 .08631 Mdot
.09023 .07846 Mdot
.09023 .07454 Mdot
.09415 .07454 Mdot
.09807 .06278 Mdot
.10591 .05886 Mdot
.10591 .05886 Mdot
.10591 .06278 Mdot
.10591 .0667 Mdot
.11376 .08239 Mdot
.10983 .07846 Mdot
.10983 .09023 Mdot
.10199 .09807 Mdot
.09023 .09023 Mdot
.09415 .08631 Mdot
.09807 .09023 Mdot
.09023 .08239 Mdot
.09415 .08239 Mdot
.10199 .07846 Mdot
.09023 .06278 Mdot
.09415 .05886 Mdot
.45491 .43922 Mdot
.59215 .57254 Mdot
.60391 .59999 Mdot
.6196 .62352 Mdot
.6196 .62352 Mdot
.5647 .55686 Mdot
.26276 .27453 Mdot
.0667 .08239 Mdot
.09807 .09807 Mdot
.06278 .05886 Mdot
.05886 .04709 Mdot
.07062 .05102 Mdot
.08239 .06278 Mdot
.09415 .0667 Mdot
.10199 .07454 Mdot
.10983 .08631 Mdot
.11768 .08631 Mdot
.12944 .10199 Mdot
.13336 .10591 Mdot
.14513 .10983 Mdot
.13728 .10199 Mdot
.13728 .10983 Mdot
.12944 .10199 Mdot
.12944 .09807 Mdot
.12944 .09415 Mdot
.1216 .08239 Mdot
.11376 .08239 Mdot
.11768 .08631 Mdot
.1216 .09023 Mdot
.11376 .07846 Mdot
.1216 .08239 Mdot
.1216 .08239 Mdot
.13728 .09415 Mdot
.14905 .10199 Mdot
.14513 .10199 Mdot
.12552 .09415 Mdot
.14513 .10983 Mdot
.14513 .10199 Mdot
.1412 .10199 Mdot
.15689 .11768 Mdot
.15689 .11376 Mdot
.15689 .10983 Mdot
.15689 .10983 Mdot
.15689 .10983 Mdot
.14513 .10199 Mdot
.15689 .10199 Mdot
.15689 .09807 Mdot
.15297 .10591 Mdot
.13728 .09023 Mdot
.13336 .09023 Mdot
.1216 .09415 Mdot
.12552 .10591 Mdot
.12944 .11768 Mdot
.12944 .12552 Mdot
.14513 .12944 Mdot
.16081 .13336 Mdot
.15297 .11768 Mdot
.16081 .10983 Mdot
.1765 .11768 Mdot
.18042 .1216 Mdot
.18042 .12944 Mdot
.18042 .12552 Mdot
.18826 .13336 Mdot
.1765 .12552 Mdot
.18434 .13728 Mdot
.18434 .14905 Mdot
.18434 .1412 Mdot
.19218 .13336 Mdot
.18826 .12552 Mdot
.18434 .1216 Mdot
.18434 .12944 Mdot
.16081 .11376 Mdot
.15689 .10591 Mdot
.15689 .10591 Mdot
.14905 .09415 Mdot
.14905 .08631 Mdot
.15689 .09023 Mdot
.16865 .10591 Mdot
.16865 .10983 Mdot
.17257 .11768 Mdot
.16081 .11768 Mdot
.16081 .11768 Mdot
.15689 .12552 Mdot
.15297 .1216 Mdot
.14513 .10983 Mdot
.14513 .10591 Mdot
.14513 .09415 Mdot
.16081 .11768 Mdot
.16865 .12552 Mdot
.17257 .12944 Mdot
.17257 .12944 Mdot
.17257 .12552 Mdot
.16865 .12552 Mdot
.18042 .13728 Mdot
.1765 .13336 Mdot
.18826 .1412 Mdot
.20002 .14905 Mdot
.1961 .14905 Mdot
.19218 .15689 Mdot
.18434 .16081 Mdot
.18826 .16865 Mdot
.1765 .15689 Mdot
.1765 .15689 Mdot
.1765 .14905 Mdot
.18042 .14905 Mdot
.18434 .15297 Mdot
.1765 .14905 Mdot
.18042 .13728 Mdot
.18042 .13336 Mdot
.18042 .13336 Mdot
.1765 .12552 Mdot
.18434 .12552 Mdot
.18826 .1216 Mdot
.19218 .12944 Mdot
.1961 .13336 Mdot
.19218 .1412 Mdot
.18826 .14905 Mdot
.1765 .14513 Mdot
.16473 .13728 Mdot
.15297 .12944 Mdot
.16473 .13728 Mdot
.14905 .12552 Mdot
.14905 .12552 Mdot
.15297 .11376 Mdot
.15689 .10983 Mdot
.15297 .10983 Mdot
.1412 .09807 Mdot
.1412 .09415 Mdot
.13728 .09415 Mdot
.13728 .09415 Mdot
.13336 .08631 Mdot
.13728 .08239 Mdot
.13728 .07846 Mdot
.13728 .07454 Mdot
.12944 .07454 Mdot
.11768 .07846 Mdot
.1216 .09023 Mdot
.11376 .09023 Mdot
.10199 .09023 Mdot
.10199 .09023 Mdot
.09807 .07454 Mdot
.09023 .0667 Mdot
.09023 .06278 Mdot
.09415 .04709 Mdot
.09023 .03925 Mdot
.09415 .04317 Mdot
.09415 .05102 Mdot
.09415 .05886 Mdot
.10591 .07846 Mdot
.10983 .08239 Mdot
.09807 .07846 Mdot
.10591 .08239 Mdot
.10591 .08631 Mdot
.10199 .08239 Mdot
.09807 .08239 Mdot
.09415 .07454 Mdot
.09023 .06278 Mdot
.09415 .06278 Mdot
.09415 .06278 Mdot
.08239 .04709 Mdot
.15689 .13336 Mdot
.25884 .23139 Mdot
.34119 .30982 Mdot
.47451 .42746 Mdot
.52157 .47843 Mdot
.58431 .54117 Mdot
.38824 .35295 Mdot
.05886 .05102 Mdot
.07062 .05886 Mdot
.05886 .04709 Mdot
.05102 .04709 Mdot
.05494 .05102 Mdot
.07454 .06278 Mdot
.08631 .06278 Mdot
.09415 .07062 Mdot
.10199 .07454 Mdot
.10983 .08239 Mdot
.12552 .09023 Mdot
.12552 .09807 Mdot
.13728 .09023 Mdot
.13336 .08631 Mdot
.12944 .08631 Mdot
.13728 .09807 Mdot
.14513 .10591 Mdot
.1412 .10591 Mdot
.14513 .10591 Mdot
.13336 .09023 Mdot
.13728 .09023 Mdot
.1412 .09415 Mdot
.13728 .08631 Mdot
.13728 .08631 Mdot
.13336 .09023 Mdot
.14513 .10199 Mdot
.13728 .10199 Mdot
.13336 .10983 Mdot
.13336 .11376 Mdot
.13336 .10591 Mdot
.13336 .10199 Mdot
.1412 .10591 Mdot
.13728 .10591 Mdot
.14513 .10591 Mdot
.14905 .10591 Mdot
.16473 .11376 Mdot
.16865 .10983 Mdot
.15689 .10199 Mdot
.14513 .09807 Mdot
.15297 .10591 Mdot
.14905 .10199 Mdot
.1412 .10199 Mdot
.13728 .10199 Mdot
.13728 .11376 Mdot
.13336 .11376 Mdot
.14905 .13336 Mdot
.13728 .11768 Mdot
.1412 .11376 Mdot
.14513 .11768 Mdot
.15689 .1216 Mdot
.15689 .10983 Mdot
.15297 .09807 Mdot
.17257 .10591 Mdot
.1765 .10983 Mdot
.17257 .11768 Mdot
.1765 .12552 Mdot
.1765 .12552 Mdot
.18042 .13728 Mdot
.18042 .1412 Mdot
.1961 .16081 Mdot
.20002 .15297 Mdot
.20002 .13336 Mdot
.20002 .12944 Mdot
.18042 .10983 Mdot
.18826 .11768 Mdot
.17257 .11768 Mdot
.16081 .10983 Mdot
.14905 .09807 Mdot
.1412 .09807 Mdot
.14905 .10199 Mdot
.1412 .10591 Mdot
.14905 .10983 Mdot
.14513 .09807 Mdot
.15689 .10983 Mdot
.15297 .11376 Mdot
.15689 .11768 Mdot
.15689 .11376 Mdot
.15689 .10983 Mdot
.15297 .10199 Mdot
.14905 .09023 Mdot
.16865 .10591 Mdot
.18042 .11768 Mdot
.17257 .11376 Mdot
.1765 .12552 Mdot
.18042 .12944 Mdot
.16865 .12552 Mdot
.17257 .13336 Mdot
.17257 .13336 Mdot
.18042 .13336 Mdot
.19218 .1412 Mdot
.19218 .14513 Mdot
.20394 .16081 Mdot
.1961 .16473 Mdot
.19218 .16865 Mdot
.18434 .16081 Mdot
.1765 .14513 Mdot
.17257 .13336 Mdot
.18042 .13728 Mdot
.17257 .13728 Mdot
.1765 .14513 Mdot
.19218 .14905 Mdot
.19218 .1412 Mdot
.18434 .13336 Mdot
.17257 .1216 Mdot
.18826 .13336 Mdot
.1961 .13336 Mdot
.20394 .12944 Mdot
.20002 .13336 Mdot
.18826 .12944 Mdot
.16473 .11768 Mdot
.1765 .12944 Mdot
.15297 .11376 Mdot
.15689 .11376 Mdot
.15689 .11376 Mdot
.14513 .10983 Mdot
.14513 .10591 Mdot
.13728 .09023 Mdot
.14513 .08631 Mdot
.15689 .09415 Mdot
.15297 .10199 Mdot
.14513 .09415 Mdot
.1412 .09023 Mdot
.14513 .09807 Mdot
.13728 .08631 Mdot
.1412 .08631 Mdot
.13336 .08239 Mdot
.12944 .07454 Mdot
.10983 .06278 Mdot
.11376 .07846 Mdot
.11768 .08631 Mdot
.10591 .08631 Mdot
.10199 .09023 Mdot
.09807 .08239 Mdot
.09415 .0667 Mdot
.09415 .06278 Mdot
.07454 .04709 Mdot
.09023 .05886 Mdot
.07846 .03925 Mdot
.07454 .03533 Mdot
.07454 .03141 Mdot
.09023 .05102 Mdot
.09415 .06278 Mdot
.09807 .0667 Mdot
.09807 .0667 Mdot
.11376 .08631 Mdot
.10591 .08239 Mdot
.10199 .07846 Mdot
.09807 .07062 Mdot
.09807 .0667 Mdot
.08631 .04317 Mdot
.08631 .03141 Mdot
.09023 .03925 Mdot
.07846 .03925 Mdot
.09807 .07454 Mdot
.12552 .10199 Mdot
.1216 .09415 Mdot
.13336 .10199 Mdot
.21963 .16473 Mdot
.32943 .26276 Mdot
.30198 .24316 Mdot
.13336 .09415 Mdot
.13728 .11376 Mdot
.11376 .09415 Mdot
.09023 .07846 Mdot
.07846 .06278 Mdot
.09415 .07454 Mdot
.09415 .07062 Mdot
.09415 .07846 Mdot
.10983 .08631 Mdot
.1216 .09023 Mdot
.12552 .09415 Mdot
.13728 .10199 Mdot
.13728 .10199 Mdot
.13728 .10199 Mdot
.13728 .10199 Mdot
.1412 .11376 Mdot
.15297 .11768 Mdot
.15297 .11768 Mdot
.15297 .11768 Mdot
.14513 .10591 Mdot
.14513 .09807 Mdot
.1412 .08631 Mdot
.12552 .07454 Mdot
.13728 .07846 Mdot
.13728 .08239 Mdot
.13728 .09023 Mdot
.1412 .10591 Mdot
.1412 .10983 Mdot
.14905 .12944 Mdot
.14513 .12552 Mdot
.13728 .11768 Mdot
.14513 .12552 Mdot
.15297 .12944 Mdot
.15689 .12552 Mdot
.15297 .11768 Mdot
.14905 .10591 Mdot
.16081 .10983 Mdot
.16473 .10591 Mdot
.15297 .09807 Mdot
.15689 .10591 Mdot
.16865 .1216 Mdot
.16081 .12552 Mdot
.16865 .12552 Mdot
.16473 .12552 Mdot
.16473 .12552 Mdot
.15689 .11768 Mdot
.15689 .10983 Mdot
.16081 .09807 Mdot
.14905 .09415 Mdot
.15297 .10591 Mdot
.1412 .09023 Mdot
.16081 .09807 Mdot
.17257 .10591 Mdot
.17257 .10199 Mdot
.18042 .10591 Mdot
.18434 .11376 Mdot
.18434 .1216 Mdot
.1765 .12944 Mdot
.18042 .13728 Mdot
.19218 .15297 Mdot
.19218 .1412 Mdot
.1961 .1412 Mdot
.18826 .13336 Mdot
.18434 .12552 Mdot
.18042 .11768 Mdot
.16473 .10591 Mdot
.16473 .10591 Mdot
.16081 .10983 Mdot
.15297 .11376 Mdot
.14513 .10591 Mdot
.12552 .09415 Mdot
.12552 .09023 Mdot
.1412 .09807 Mdot
.14513 .10983 Mdot
.16081 .11768 Mdot
.16081 .11376 Mdot
.16081 .11768 Mdot
.15689 .11376 Mdot
.15297 .10983 Mdot
.14905 .10199 Mdot
.16865 .10591 Mdot
.1765 .11376 Mdot
.17257 .10983 Mdot
.16865 .11376 Mdot
.1765 .1216 Mdot
.17257 .1216 Mdot
.1765 .1216 Mdot
.1765 .1216 Mdot
.18042 .12944 Mdot
.18042 .12944 Mdot
.1961 .14513 Mdot
.20394 .16473 Mdot
.1961 .16473 Mdot
.19218 .16865 Mdot
.19218 .16081 Mdot
.18434 .14513 Mdot
.1765 .12944 Mdot
.1765 .12944 Mdot
.18434 .13728 Mdot
.19218 .14905 Mdot
.18434 .14513 Mdot
.18434 .1412 Mdot
.19218 .14513 Mdot
.18434 .1412 Mdot
.18434 .13336 Mdot
.20002 .13336 Mdot
.20787 .13728 Mdot
.20002 .12944 Mdot
.19218 .11768 Mdot
.18042 .10983 Mdot
.1765 .10591 Mdot
.16865 .10199 Mdot
.17257 .11376 Mdot
.17257 .11376 Mdot
.16081 .11376 Mdot
.16473 .11768 Mdot
.16473 .11376 Mdot
.15689 .10199 Mdot
.16081 .10199 Mdot
.17257 .11768 Mdot
.16081 .11376 Mdot
.16081 .11768 Mdot
.1412 .10591 Mdot
.1412 .09807 Mdot
.1412 .09415 Mdot
.12944 .08239 Mdot
.1216 .07846 Mdot
.12944 .08239 Mdot
.12552 .08239 Mdot
.11768 .07454 Mdot
.11768 .08239 Mdot
.10983 .08239 Mdot
.10199 .07454 Mdot
.09807 .05886 Mdot
.09807 .05494 Mdot
.09807 .04709 Mdot
.09807 .05886 Mdot
.10199 .05886 Mdot
.09415 .05102 Mdot
.09023 .04709 Mdot
.09807 .04709 Mdot
.10983 .0667 Mdot
.10591 .06278 Mdot
.08631 .05886 Mdot
.10199 .07062 Mdot
.10591 .07846 Mdot
.10199 .07846 Mdot
.09415 .0667 Mdot
.08239 .05886 Mdot
.08239 .05102 Mdot
.07846 .03925 Mdot
.07454 .03533 Mdot
.05886 .01965 Mdot
.05886 .04317 Mdot
.07454 .0667 Mdot
.08239 .0667 Mdot
.08631 .07454 Mdot
.11376 .09415 Mdot
.12944 .10591 Mdot
.12944 .10591 Mdot
.11768 .09023 Mdot
.11376 .08239 Mdot
.10591 .07062 Mdot
.09807 .06278 Mdot
.09023 .05102 Mdot
.08631 .04709 Mdot
.09415 .06278 Mdot
.10199 .07454 Mdot
.09023 .0667 Mdot
.10591 .07846 Mdot
.11768 .08631 Mdot
.13728 .09415 Mdot
.14513 .10199 Mdot
.1412 .10199 Mdot
.13336 .09415 Mdot
.13728 .09807 Mdot
.14905 .10983 Mdot
.15297 .11376 Mdot
.15297 .11376 Mdot
.14905 .10983 Mdot
.14905 .09807 Mdot
.15297 .10199 Mdot
.14905 .09807 Mdot
.13728 .09023 Mdot
.13728 .09415 Mdot
.1412 .09807 Mdot
.14905 .10591 Mdot
.1412 .11376 Mdot
.14905 .12552 Mdot
.15297 .12944 Mdot
.15297 .12944 Mdot
.15297 .13336 Mdot
.15689 .12944 Mdot
.14513 .1216 Mdot
.13728 .10983 Mdot
.15689 .11376 Mdot
.16473 .10983 Mdot
.16865 .11376 Mdot
.16081 .10983 Mdot
.16473 .11768 Mdot
.16473 .12944 Mdot
.17257 .1412 Mdot
.16473 .13728 Mdot
.16473 .13336 Mdot
.16865 .13336 Mdot
.17257 .12944 Mdot
.16865 .11768 Mdot
.16081 .09415 Mdot
.14905 .09023 Mdot
.15297 .10199 Mdot
.16473 .11376 Mdot
.16473 .10591 Mdot
.18434 .11768 Mdot
.18434 .1216 Mdot
.18826 .12552 Mdot
.1961 .12944 Mdot
.18434 .1216 Mdot
.18826 .12944 Mdot
.1961 .14513 Mdot
.20394 .15689 Mdot
.1961 .14513 Mdot
.20787 .15297 Mdot
.18434 .13336 Mdot
.1765 .12552 Mdot
.18434 .13336 Mdot
.1765 .12552 Mdot
.1765 .1216 Mdot
.16865 .11768 Mdot
.16473 .11768 Mdot
.16081 .11768 Mdot
.14905 .10591 Mdot
.13728 .10199 Mdot
.1412 .10199 Mdot
.15297 .11376 Mdot
.14905 .10591 Mdot
.15297 .10983 Mdot
.16081 .11768 Mdot
.16473 .12552 Mdot
.14905 .11768 Mdot
.13728 .10591 Mdot
.14905 .10591 Mdot
.16473 .11376 Mdot
.16473 .10591 Mdot
.17257 .1216 Mdot
.1765 .12552 Mdot
.18042 .12944 Mdot
.1765 .12552 Mdot
.1765 .1216 Mdot
.18042 .12552 Mdot
.18434 .12944 Mdot
.18826 .13336 Mdot
.1961 .1412 Mdot
.20394 .15689 Mdot
.20787 .17257 Mdot
.1961 .16473 Mdot
.18042 .14513 Mdot
.17257 .12552 Mdot
.1765 .1216 Mdot
.18434 .12944 Mdot
.18434 .13728 Mdot
.18826 .14513 Mdot
.19218 .14905 Mdot
.19218 .14905 Mdot
.1961 .14905 Mdot
.19218 .13728 Mdot
.1961 .13336 Mdot
.1961 .13336 Mdot
.19218 .12944 Mdot
.1961 .12552 Mdot
.20394 .12944 Mdot
.18042 .11376 Mdot
.17257 .11376 Mdot
.17257 .1216 Mdot
.16865 .11768 Mdot
.17257 .11768 Mdot
.16473 .11376 Mdot
.15689 .10983 Mdot
.1765 .11768 Mdot
.16473 .10591 Mdot
.16473 .10983 Mdot
.16865 .12552 Mdot
.16865 .13336 Mdot
.15297 .11768 Mdot
.13728 .10591 Mdot
.1412 .09415 Mdot
.14513 .09415 Mdot
.13336 .08631 Mdot
.13336 .09023 Mdot
.12944 .08631 Mdot
.13336 .08631 Mdot
.12944 .08631 Mdot
.12552 .08239 Mdot
.11768 .07846 Mdot
.11768 .07454 Mdot
.11376 .06278 Mdot
.11376 .06278 Mdot
.10199 .05102 Mdot
.09415 .05102 Mdot
.09807 .05102 Mdot
.09415 .05102 Mdot
.09415 .05102 Mdot
.10591 .05494 Mdot
.10591 .05102 Mdot
.10199 .05102 Mdot
.10983 .07062 Mdot
.09807 .05886 Mdot
.09415 .05886 Mdot
.09415 .06278 Mdot
.09415 .06278 Mdot
.08239 .05494 Mdot
.07062 .03925 Mdot
.06278 .02357 Mdot
.0667 .02749 Mdot
.05494 .04317 Mdot
.0667 .04709 Mdot
.0667 .03925 Mdot
.08631 .05886 Mdot
.09023 .07062 Mdot
.10591 .09415 Mdot
.10983 .09415 Mdot
.10591 .09023 Mdot
.10199 .08239 Mdot
.10591 .07846 Mdot
.10591 .07846 Mdot
.10199 .07454 Mdot
.10199 .07062 Mdot
.10199 .0667 Mdot
.09807 .07062 Mdot
.09023 .05886 Mdot
.10983 .0667 Mdot
.11768 .07062 Mdot
.1216 .07454 Mdot
.13336 .08631 Mdot
.12552 .07846 Mdot
.13728 .09023 Mdot
.13728 .09415 Mdot
.13728 .09415 Mdot
.14513 .09415 Mdot
.14513 .09807 Mdot
.14905 .10983 Mdot
.14513 .10591 Mdot
.15297 .11768 Mdot
.14905 .1216 Mdot
.14513 .11376 Mdot
.14513 .10983 Mdot
.13728 .10983 Mdot
.13336 .10983 Mdot
.14905 .12552 Mdot
.14905 .1216 Mdot
.15689 .12552 Mdot
.15297 .1216 Mdot
.14905 .10983 Mdot
.15689 .11768 Mdot
.15297 .10983 Mdot
.15297 .10983 Mdot
.16865 .1216 Mdot
.16473 .1216 Mdot
.17257 .12552 Mdot
.16865 .11768 Mdot
.17257 .12552 Mdot
.16473 .1216 Mdot
.16473 .1216 Mdot
.16865 .12944 Mdot
.17257 .13336 Mdot
.16081 .11768 Mdot
.16081 .11768 Mdot
.16865 .12552 Mdot
.16081 .11768 Mdot
.15297 .10983 Mdot
.16865 .11768 Mdot
.17257 .11376 Mdot
.17257 .1216 Mdot
.1765 .1216 Mdot
.18434 .12552 Mdot
.19218 .12944 Mdot
.1765 .11768 Mdot
.18434 .12552 Mdot
.19218 .13336 Mdot
.20002 .15297 Mdot
.20002 .15297 Mdot
.20002 .15297 Mdot
.20787 .16865 Mdot
.20394 .16081 Mdot
.19218 .15297 Mdot
.18434 .14513 Mdot
.18434 .13728 Mdot
.18042 .13336 Mdot
.18042 .12552 Mdot
.17257 .11376 Mdot
.1765 .11376 Mdot
.16473 .10591 Mdot
.16865 .11768 Mdot
.18042 .12552 Mdot
.17257 .11376 Mdot
.16473 .10983 Mdot
.15689 .10591 Mdot
.16865 .10983 Mdot
.16865 .1216 Mdot
.16473 .12552 Mdot
.16473 .1216 Mdot
.16081 .10983 Mdot
.16081 .10591 Mdot
.15297 .09415 Mdot
.15689 .10591 Mdot
.16865 .11768 Mdot
.18042 .12944 Mdot
.18042 .13336 Mdot
.18434 .12944 Mdot
.18826 .13728 Mdot
.18434 .12944 Mdot
.18042 .1216 Mdot
.18042 .1216 Mdot
.20394 .14513 Mdot
.20787 .15689 Mdot
.21179 .16473 Mdot
.20394 .15689 Mdot
.1961 .14905 Mdot
.18826 .13336 Mdot
.18434 .1216 Mdot
.18826 .12552 Mdot
.19218 .13336 Mdot
.20394 .14905 Mdot
.20394 .15297 Mdot
.19218 .1412 Mdot
.1961 .13728 Mdot
.20787 .1412 Mdot
.19218 .12944 Mdot
.18434 .12944 Mdot
.18042 .1216 Mdot
.18826 .12944 Mdot
.18826 .12552 Mdot
.18434 .12944 Mdot
.1765 .12944 Mdot
.1765 .12944 Mdot
.18042 .13336 Mdot
.1765 .12944 Mdot
.1765 .13336 Mdot
.17257 .13336 Mdot
.16473 .1216 Mdot
.17257 .12944 Mdot
.1765 .13728 Mdot
.16473 .13336 Mdot
.16473 .13336 Mdot
.15689 .12552 Mdot
.13728 .10199 Mdot
.13336 .09807 Mdot
.12944 .08631 Mdot
.13336 .08631 Mdot
.1412 .09023 Mdot
.14513 .09807 Mdot
.13336 .09023 Mdot
.13336 .09023 Mdot
.12944 .08631 Mdot
.1216 .08239 Mdot
.12552 .08239 Mdot
.12944 .07846 Mdot
.11768 .06278 Mdot
.11768 .05886 Mdot
.11768 .06278 Mdot
.10983 .07062 Mdot
.10983 .0667 Mdot
.10199 .05102 Mdot
.10591 .05102 Mdot
.10983 .05886 Mdot
.10591 .0667 Mdot
.09023 .05886 Mdot
.09023 .05886 Mdot
.09023 .05886 Mdot
.09807 .0667 Mdot
.0667 .03533 Mdot
.0667 .03533 Mdot
.06278 .03141 Mdot
.07062 .03533 Mdot
.03141 .01572 Mdot
.04317 .01965 Mdot
.04709 .01965 Mdot
.07846 .04317 Mdot
.09415 .07454 Mdot
.09415 .08631 Mdot
.09415 .08239 Mdot
.09415 .07846 Mdot
.10983 .10199 Mdot
.1216 .10199 Mdot
.10983 .08239 Mdot
.1216 .08631 Mdot
.11376 .07846 Mdot
.09807 .07062 Mdot
.09415 .06278 Mdot
.10199 .07062 Mdot
.10983 .0667 Mdot
.11768 .07062 Mdot
.11768 .07062 Mdot
.12944 .08631 Mdot
.12944 .08239 Mdot
.13336 .09023 Mdot
.14905 .10591 Mdot
.14513 .09807 Mdot
.15297 .10591 Mdot
.15297 .10591 Mdot
.15689 .11376 Mdot
.15689 .12552 Mdot
.15297 .13336 Mdot
.14513 .12944 Mdot
.14905 .12944 Mdot
.14905 .12944 Mdot
.14905 .13728 Mdot
.14513 .12552 Mdot
.14905 .12944 Mdot
.14905 .1216 Mdot
.16473 .1216 Mdot
.15689 .10983 Mdot
.14905 .10591 Mdot
.15689 .10591 Mdot
.15297 .10591 Mdot
.15689 .10983 Mdot
.1765 .11768 Mdot
.17257 .11768 Mdot
.16865 .12552 Mdot
.17257 .1216 Mdot
.18042 .12944 Mdot
.18826 .13728 Mdot
.18434 .13336 Mdot
.16865 .12552 Mdot
.15689 .1216 Mdot
.16081 .12944 Mdot
.16865 .12552 Mdot
.16865 .12552 Mdot
.17257 .13728 Mdot
.16473 .13336 Mdot
.16473 .1216 Mdot
.16473 .1216 Mdot
.15689 .11376 Mdot
.17257 .1216 Mdot
.17257 .11768 Mdot
.17257 .12552 Mdot
.1765 .12944 Mdot
.17257 .12944 Mdot
.1765 .13728 Mdot
.18826 .14513 Mdot
.1961 .15689 Mdot
.20002 .15689 Mdot
.20002 .16473 Mdot
.1961 .16473 Mdot
.18826 .16473 Mdot
.1961 .17257 Mdot
.1765 .14905 Mdot
.17257 .13728 Mdot
.16473 .1216 Mdot
.16865 .1216 Mdot
.16865 .10983 Mdot
.16865 .10591 Mdot
.16865 .10199 Mdot
.18434 .1216 Mdot
.18434 .12552 Mdot
.19218 .13336 Mdot
.18434 .12944 Mdot
.18042 .1216 Mdot
.17257 .12552 Mdot
.17257 .12552 Mdot
.16865 .1216 Mdot
.16473 .11376 Mdot
.16081 .10199 Mdot
.16081 .09807 Mdot
.16081 .10591 Mdot
.17257 .11768 Mdot
.18042 .12944 Mdot
.18826 .13728 Mdot
.19218 .1412 Mdot
.20002 .14905 Mdot
.20002 .14513 Mdot
.19218 .13336 Mdot
.19218 .12552 Mdot
.18826 .11768 Mdot
.19218 .12552 Mdot
.20394 .1412 Mdot
.18826 .13336 Mdot
.18826 .13728 Mdot
.1961 .1412 Mdot
.19218 .12944 Mdot
.19218 .12944 Mdot
.18434 .1216 Mdot
.19218 .13336 Mdot
.18434 .12944 Mdot
.18826 .13728 Mdot
.19218 .1412 Mdot
.1961 .1412 Mdot
.1961 .13728 Mdot
.18826 .13728 Mdot
.18434 .12944 Mdot
.1765 .11768 Mdot
.1765 .1216 Mdot
.16473 .11376 Mdot
.16473 .11768 Mdot
.16473 .1216 Mdot
.16081 .12552 Mdot
.17257 .13336 Mdot
.1765 .12944 Mdot
.17257 .12552 Mdot
.16865 .12552 Mdot
.16081 .13336 Mdot
.17257 .13728 Mdot
.17257 .13728 Mdot
.16081 .12944 Mdot
.16081 .1216 Mdot
.1216 .08631 Mdot
.12552 .08631 Mdot
.1216 .07454 Mdot
.11768 .0667 Mdot
.12552 .07062 Mdot
.13728 .08631 Mdot
.14513 .09807 Mdot
.13336 .08631 Mdot
.11768 .07846 Mdot
.10591 .07454 Mdot
.10983 .07846 Mdot
.12944 .08631 Mdot
.11768 .07454 Mdot
.11376 .07454 Mdot
.11768 .08239 Mdot
.11376 .08239 Mdot
.11376 .08239 Mdot
.11376 .07846 Mdot
.11768 .07062 Mdot
.10983 .05886 Mdot
.10591 .05494 Mdot
.10983 .05886 Mdot
.10199 .05494 Mdot
.10199 .05494 Mdot
.10199 .05886 Mdot
.09807 .05494 Mdot
.07846 .04709 Mdot
.07846 .05494 Mdot
.07454 .05102 Mdot
.02749 .0118 Mdot
.03925 .01572 Mdot
.0667 .03533 Mdot
.09023 .05886 Mdot
.11376 .08239 Mdot
.10591 .07846 Mdot
.08239 .05886 Mdot
.08239 .0667 Mdot
.09807 .07846 Mdot
.08631 .0667 Mdot
.09023 .07062 Mdot
.09415 .07454 Mdot
.10199 .07846 Mdot
.10983 .08239 Mdot
.10983 .07454 Mdot
.10983 .0667 Mdot
.10591 .05886 Mdot
.11768 .0667 Mdot
.11768 .0667 Mdot
.1216 .07454 Mdot
.1216 .08239 Mdot
.12552 .09415 Mdot
.14513 .10199 Mdot
.14905 .10199 Mdot
.14513 .10199 Mdot
.15297 .10983 Mdot
.16865 .1216 Mdot
.16473 .12552 Mdot
.16081 .13728 Mdot
.14905 .13336 Mdot
.14905 .13728 Mdot
.15297 .1412 Mdot
.15689 .14905 Mdot
.16081 .14513 Mdot
.15689 .13336 Mdot
.14513 .11376 Mdot
.15689 .11768 Mdot
.15689 .10983 Mdot
.15689 .10591 Mdot
.16473 .10591 Mdot
.16473 .10591 Mdot
.15689 .09807 Mdot
.16473 .10591 Mdot
.1765 .1216 Mdot
.18434 .12552 Mdot
.18042 .11768 Mdot
.17257 .11376 Mdot
.18042 .12552 Mdot
.1765 .12552 Mdot
.1765 .12944 Mdot
.16865 .13336 Mdot
.17257 .1412 Mdot
.1765 .14513 Mdot
.17257 .1412 Mdot
.16473 .13728 Mdot
.16865 .13336 Mdot
.17257 .13336 Mdot
.1765 .13728 Mdot
.16865 .12944 Mdot
.16473 .12944 Mdot
.15689 .11768 Mdot
.16473 .1216 Mdot
.1765 .12552 Mdot
.17257 .1216 Mdot
.1765 .12552 Mdot
.18042 .12552 Mdot
.19218 .1412 Mdot
.19218 .14905 Mdot
.1961 .15689 Mdot
.18826 .15297 Mdot
.20394 .16865 Mdot
.20394 .17257 Mdot
.1961 .16865 Mdot
.18042 .15297 Mdot
.1765 .1412 Mdot
.1765 .12944 Mdot
.17257 .11376 Mdot
.16865 .10199 Mdot
.18042 .10591 Mdot
.1765 .11376 Mdot
.18434 .1216 Mdot
.18434 .12944 Mdot
.18434 .12944 Mdot
.18434 .12944 Mdot
.1765 .12552 Mdot
.18042 .12944 Mdot
.18434 .13336 Mdot
.1765 .12552 Mdot
.1765 .1216 Mdot
.17257 .11768 Mdot
.16473 .11768 Mdot
.17257 .1216 Mdot
.18826 .13336 Mdot
.18826 .13728 Mdot
.19218 .14513 Mdot
.18826 .13728 Mdot
.1961 .13336 Mdot
.1961 .1216 Mdot
.1961 .11768 Mdot
.20394 .12552 Mdot
.1961 .12944 Mdot
.20002 .13336 Mdot
.20394 .13728 Mdot
.20002 .1412 Mdot
.20002 .14905 Mdot
.1961 .1412 Mdot
.19218 .13336 Mdot
.18826 .13336 Mdot
.19218 .13336 Mdot
.19218 .1412 Mdot
.1961 .14905 Mdot
.20002 .14905 Mdot
.1961 .14513 Mdot
.18826 .13728 Mdot
.18434 .13728 Mdot
.17257 .12944 Mdot
.16473 .11768 Mdot
.16865 .12944 Mdot
.17257 .12944 Mdot
.1765 .13336 Mdot
.16473 .12552 Mdot
.17257 .12552 Mdot
.1765 .12944 Mdot
.1765 .12944 Mdot
.16865 .1216 Mdot
.1765 .13336 Mdot
.17257 .13728 Mdot
.16081 .12552 Mdot
.16473 .12552 Mdot
.16081 .1216 Mdot
.16081 .11768 Mdot
.14513 .10199 Mdot
.14905 .10199 Mdot
.13336 .08631 Mdot
.12944 .07846 Mdot
.12552 .07454 Mdot
.14513 .09415 Mdot
.14513 .10199 Mdot
.1412 .09023 Mdot
.1412 .09415 Mdot
.12944 .08631 Mdot
.11768 .07846 Mdot
.11768 .07846 Mdot
.10983 .07062 Mdot
.10591 .07062 Mdot
.10199 .07454 Mdot
.09807 .07846 Mdot
.09415 .07062 Mdot
.10199 .07454 Mdot
.12552 .08631 Mdot
.11376 .07454 Mdot
.09807 .06278 Mdot
.09807 .05102 Mdot
.10983 .05102 Mdot
.10983 .04709 Mdot
.10591 .04317 Mdot
.10591 .05494 Mdot
.08631 .04317 Mdot
.08239 .04317 Mdot
.0667 .03533 Mdot
.03533 .01572 Mdot
.05102 .02357 Mdot
.05494 .02357 Mdot
.05494 .03141 Mdot
.07062 .03925 Mdot
.08239 .04317 Mdot
.08631 .03925 Mdot
.0667 .04317 Mdot
.05494 .04317 Mdot
.03533 .02749 Mdot
.05102 .03533 Mdot
.07454 .05102 Mdot
.09023 .06278 Mdot
.09415 .06278 Mdot
.09807 .0667 Mdot
.11376 .07062 Mdot
.11376 .07062 Mdot
.11376 .07062 Mdot
.1216 .07846 Mdot
.11768 .08631 Mdot
.12552 .09807 Mdot
.12944 .09807 Mdot
.1412 .10591 Mdot
.14513 .10591 Mdot
.1412 .09807 Mdot
.16081 .10983 Mdot
.16865 .11376 Mdot
.16865 .11768 Mdot
.16865 .1216 Mdot
.16081 .12552 Mdot
.14513 .12552 Mdot
.15297 .13336 Mdot
.15297 .13336 Mdot
.14905 .12944 Mdot
.15689 .13728 Mdot
.15689 .13728 Mdot
.16081 .13728 Mdot
.16473 .12552 Mdot
.1765 .13336 Mdot
.17257 .1216 Mdot
.16865 .11768 Mdot
.16081 .11376 Mdot
.16473 .11376 Mdot
.16865 .11376 Mdot
.18042 .11768 Mdot
.18042 .11376 Mdot
.18826 .1216 Mdot
.18826 .11768 Mdot
.18826 .10983 Mdot
.18826 .11376 Mdot
.17257 .11768 Mdot
.16081 .11768 Mdot
.16865 .12552 Mdot
.1765 .13728 Mdot
.1765 .14513 Mdot
.1765 .14905 Mdot
.16865 .1412 Mdot
.1765 .14513 Mdot
.18042 .14905 Mdot
.1765 .1412 Mdot
.16081 .1216 Mdot
.15297 .10983 Mdot
.16081 .11376 Mdot
.16865 .11376 Mdot
.18042 .11768 Mdot
.18434 .11768 Mdot
.1961 .13336 Mdot
.20002 .14513 Mdot
.19218 .14513 Mdot
.18042 .13728 Mdot
.20002 .14905 Mdot
.20002 .15297 Mdot
.19218 .15689 Mdot
.18826 .14905 Mdot
.19218 .15297 Mdot
.1961 .14905 Mdot
.18434 .12944 Mdot
.18434 .12944 Mdot
.19218 .12944 Mdot
.19218 .12552 Mdot
.20002 .12944 Mdot
.18826 .11768 Mdot
.19218 .1216 Mdot
.19218 .13336 Mdot
.20002 .14513 Mdot
.1961 .14905 Mdot
.18826 .14905 Mdot
.18434 .1412 Mdot
.19218 .1412 Mdot
.18042 .1216 Mdot
.1765 .11376 Mdot
.1765 .11376 Mdot
.18042 .10983 Mdot
.18434 .11768 Mdot
.1961 .13336 Mdot
.1961 .13336 Mdot
.19218 .1216 Mdot
.20002 .11768 Mdot
.1961 .10199 Mdot
.20787 .1216 Mdot
.20394 .13336 Mdot
.1961 .13336 Mdot
.19218 .13336 Mdot
.18826 .13336 Mdot
.1961 .1412 Mdot
.1961 .13336 Mdot
.18826 .13336 Mdot
.18042 .12552 Mdot
.1961 .13336 Mdot
.20002 .14513 Mdot
.20394 .15297 Mdot
.20002 .14905 Mdot
.1961 .14905 Mdot
.19218 .14513 Mdot
.18826 .1412 Mdot
.18042 .13728 Mdot
.16473 .13336 Mdot
.16081 .13728 Mdot
.16473 .13336 Mdot
.16865 .13336 Mdot
.17257 .13728 Mdot
.17257 .13728 Mdot
.17257 .12944 Mdot
.16473 .12552 Mdot
.17257 .13336 Mdot
.17257 .13728 Mdot
.17257 .1412 Mdot
.16473 .12944 Mdot
.14905 .11376 Mdot
.15297 .11376 Mdot
.14905 .09807 Mdot
.14905 .09807 Mdot
.14513 .09415 Mdot
.14905 .09415 Mdot
.1412 .08631 Mdot
.12944 .07454 Mdot
.13728 .08631 Mdot
.1412 .08631 Mdot
.13728 .09415 Mdot
.13728 .10591 Mdot
.13336 .10983 Mdot
.12552 .10199 Mdot
.12552 .09415 Mdot
.11376 .08239 Mdot
.10591 .07454 Mdot
.09807 .06278 Mdot
.10591 .07454 Mdot
.10199 .07062 Mdot
.11768 .08631 Mdot
.12552 .09023 Mdot
.11768 .08631 Mdot
.10591 .0667 Mdot
.10591 .06278 Mdot
.10591 .05886 Mdot
.10983 .04709 Mdot
.10199 .03925 Mdot
.10199 .03925 Mdot
.09807 .03533 Mdot
.08631 .03533 Mdot
.07454 .03141 Mdot
.02357 .01572 Mdot
.02749 .01572 Mdot
.02357 .00788 Mdot
.03533 .0118 Mdot
.04317 .01572 Mdot
.05886 .01965 Mdot
.08239 .03925 Mdot
.07454 .03533 Mdot
.06278 .02749 Mdot
.03925 .01572 Mdot
.04709 .02357 Mdot
.05886 .03533 Mdot
.05102 .02749 Mdot
.04709 .02357 Mdot
.07062 .04709 Mdot
.09807 .07062 Mdot
.11376 .08239 Mdot
.11768 .08239 Mdot
.13336 .09807 Mdot
.12944 .10591 Mdot
.12944 .10983 Mdot
.13728 .11376 Mdot
.13336 .10591 Mdot
.13728 .10591 Mdot
.12944 .09415 Mdot
.1412 .09415 Mdot
.14905 .09807 Mdot
.14905 .09807 Mdot
.15689 .10591 Mdot
.16081 .11768 Mdot
.15689 .1216 Mdot
.14905 .11768 Mdot
.16081 .12552 Mdot
.16473 .12552 Mdot
.18042 .1412 Mdot
.17257 .12944 Mdot
.18042 .13336 Mdot
.18434 .13336 Mdot
.1765 .12552 Mdot
.18042 .12944 Mdot
.18042 .13336 Mdot
.18434 .13728 Mdot
.18042 .12944 Mdot
.1765 .12944 Mdot
.18042 .12944 Mdot
.19218 .13336 Mdot
.1961 .13728 Mdot
.19218 .12944 Mdot
.18826 .12552 Mdot
.18434 .12944 Mdot
.18042 .12552 Mdot
.17257 .11768 Mdot
.16865 .11768 Mdot
.16865 .12944 Mdot
.16865 .12944 Mdot
.1765 .1412 Mdot
.18042 .14513 Mdot
.18042 .14905 Mdot
.18042 .14905 Mdot
.18042 .1412 Mdot
.1765 .1412 Mdot
.18042 .1412 Mdot
.17257 .12944 Mdot
.16865 .11768 Mdot
.16081 .10199 Mdot
.16865 .11376 Mdot
.1765 .12552 Mdot
.18042 .13336 Mdot
.18434 .13728 Mdot
.18826 .13728 Mdot
.1961 .14513 Mdot
.1961 .14513 Mdot
.20394 .14513 Mdot
.20787 .15297 Mdot
.20787 .15297 Mdot
.20394 .14513 Mdot
.20787 .1412 Mdot
.1961 .12944 Mdot
.20394 .13728 Mdot
.20002 .13336 Mdot
.1961 .13728 Mdot
.1961 .13336 Mdot
.20002 .13336 Mdot
.1961 .12944 Mdot
.20002 .13336 Mdot
.20394 .1412 Mdot
.20002 .14513 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.18042 .1216 Mdot
.1765 .11376 Mdot
.18042 .10983 Mdot
.18434 .11376 Mdot
.1961 .12552 Mdot
.19218 .1216 Mdot
.19218 .1216 Mdot
.20002 .11768 Mdot
.20002 .11768 Mdot
.21179 .13336 Mdot
.22747 .15297 Mdot
.21571 .15297 Mdot
.19218 .13728 Mdot
.18042 .12552 Mdot
.18826 .12944 Mdot
.18826 .12944 Mdot
.19218 .13336 Mdot
.19218 .13728 Mdot
.19218 .13728 Mdot
.20002 .1412 Mdot
.1961 .13728 Mdot
.18826 .12944 Mdot
.1765 .1216 Mdot
.18434 .13336 Mdot
.18042 .12944 Mdot
.18826 .13728 Mdot
.1765 .13336 Mdot
.17257 .13336 Mdot
.17257 .1412 Mdot
.18042 .14513 Mdot
.1765 .1412 Mdot
.18042 .1412 Mdot
.1765 .13728 Mdot
.17257 .13336 Mdot
.16865 .12944 Mdot
.17257 .12944 Mdot
.17257 .13336 Mdot
.17257 .12552 Mdot
.16865 .1216 Mdot
.16865 .11768 Mdot
.15297 .08631 Mdot
.15689 .08631 Mdot
.15689 .08631 Mdot
.16081 .10199 Mdot
.16473 .10591 Mdot
.13336 .08239 Mdot
.13336 .09415 Mdot
.13728 .09415 Mdot
.13336 .09807 Mdot
.12944 .09807 Mdot
.12944 .10199 Mdot
.12944 .10591 Mdot
.12552 .09807 Mdot
.12944 .09023 Mdot
.12552 .08239 Mdot
.12944 .08631 Mdot
.13728 .09023 Mdot
.11376 .07062 Mdot
.11768 .07062 Mdot
.12944 .08239 Mdot
.1216 .07846 Mdot
.11376 .07454 Mdot
.11376 .07454 Mdot
.10591 .06278 Mdot
.10591 .05886 Mdot
.10983 .06278 Mdot
.10983 .06278 Mdot
.10983 .06278 Mdot
.09415 .05494 Mdot
.07846 .04317 Mdot
.01572 .02357 Mdot
.02357 .01965 Mdot
.01965 .00788 Mdot
.02357 .00396 Mdot
.02357 .00396 Mdot
.04709 .0118 Mdot
.05494 .0118 Mdot
.05886 .01572 Mdot
.06278 .0118 Mdot
.05886 .0118 Mdot
.06278 .01965 Mdot
.06278 .02749 Mdot
.06278 .03533 Mdot
.05102 .02357 Mdot
.05102 .02749 Mdot
.05102 .02749 Mdot
.07846 .05102 Mdot
.10199 .06278 Mdot
.11768 .06278 Mdot
.13336 .08631 Mdot
.13728 .09807 Mdot
.1412 .10199 Mdot
.14513 .10199 Mdot
.13728 .09415 Mdot
.13336 .09807 Mdot
.13728 .09807 Mdot
.13728 .09023 Mdot
.14905 .09807 Mdot
.15297 .10591 Mdot
.15689 .11768 Mdot
.15689 .1216 Mdot
.16081 .11768 Mdot
.17257 .1216 Mdot
.1765 .1216 Mdot
.18434 .13336 Mdot
.18434 .13336 Mdot
.18434 .13728 Mdot
.18826 .1412 Mdot
.1961 .14513 Mdot
.20002 .14513 Mdot
.1961 .1412 Mdot
.19218 .1412 Mdot
.19218 .1412 Mdot
.18042 .13728 Mdot
.1765 .13336 Mdot
.18042 .1412 Mdot
.18042 .13728 Mdot
.18434 .13336 Mdot
.18826 .13728 Mdot
.19218 .1412 Mdot
.19218 .13728 Mdot
.19218 .12552 Mdot
.1765 .10983 Mdot
.1765 .1216 Mdot
.17257 .1216 Mdot
.1765 .12552 Mdot
.1765 .12552 Mdot
.18826 .1412 Mdot
.18434 .14905 Mdot
.18434 .15297 Mdot
.1765 .14513 Mdot
.17257 .13728 Mdot
.17257 .13728 Mdot
.1765 .1412 Mdot
.16081 .12552 Mdot
.17257 .12944 Mdot
.16865 .12552 Mdot
.17257 .12552 Mdot
.18042 .12552 Mdot
.19218 .1412 Mdot
.1961 .13728 Mdot
.1961 .13336 Mdot
.20787 .13728 Mdot
.21179 .1412 Mdot
.21571 .14905 Mdot
.20394 .1412 Mdot
.20002 .13728 Mdot
.20787 .1412 Mdot
.20787 .1412 Mdot
.21179 .15297 Mdot
.21179 .15689 Mdot
.20787 .15689 Mdot
.21179 .15689 Mdot
.20002 .1412 Mdot
.20394 .13336 Mdot
.20787 .13336 Mdot
.20002 .13728 Mdot
.1961 .13336 Mdot
.18826 .13728 Mdot
.18434 .13336 Mdot
.1765 .12552 Mdot
.17257 .11768 Mdot
.17257 .11376 Mdot
.1765 .11376 Mdot
.18826 .1216 Mdot
.18434 .1216 Mdot
.1961 .13728 Mdot
.20002 .13728 Mdot
.20394 .13336 Mdot
.20394 .13336 Mdot
.21179 .14905 Mdot
.21571 .15297 Mdot
.21571 .15297 Mdot
.1961 .13728 Mdot
.18434 .12552 Mdot
.1961 .13336 Mdot
.20787 .14513 Mdot
.20787 .14513 Mdot
.20394 .13728 Mdot
.20394 .13728 Mdot
.18434 .12552 Mdot
.18434 .12552 Mdot
.18042 .11768 Mdot
.17257 .10983 Mdot
.18042 .1216 Mdot
.18826 .12944 Mdot
.18042 .12552 Mdot
.1765 .12944 Mdot
.1765 .13728 Mdot
.18042 .14513 Mdot
.18042 .14513 Mdot
.18826 .13728 Mdot
.18826 .13336 Mdot
.1765 .13728 Mdot
.1765 .1412 Mdot
.18042 .1412 Mdot
.1765 .13336 Mdot
.17257 .12552 Mdot
.16473 .11376 Mdot
.15297 .09415 Mdot
.1412 .07846 Mdot
.14905 .07846 Mdot
.1412 .07454 Mdot
.15297 .09023 Mdot
.16865 .11376 Mdot
.16081 .11376 Mdot
.1412 .10591 Mdot
.14513 .10983 Mdot
.13728 .10199 Mdot
.12552 .09415 Mdot
.1216 .09807 Mdot
.12552 .10199 Mdot
.1216 .09807 Mdot
.10983 .08239 Mdot
.11768 .08239 Mdot
.11768 .07846 Mdot
.12552 .08631 Mdot
.11376 .07454 Mdot
.10591 .05494 Mdot
.12552 .06278 Mdot
.1216 .07062 Mdot
.12552 .07062 Mdot
.11376 .0667 Mdot
.09807 .05886 Mdot
.08631 .05494 Mdot
.10591 .07454 Mdot
.09415 .07062 Mdot
.09807 .07454 Mdot
.08631 .06278 Mdot
.07846 .05494 Mdot
.01572 .02749 Mdot
.02357 .01965 Mdot
.02749 .00788 Mdot
.02357 .00788 Mdot
.01572 .00396 Mdot
.01965 .00396 Mdot
.02749 .00396 Mdot
.01965 .00396 Mdot
.03533 .00396 Mdot
.06278 .0118 Mdot
.08239 .03925 Mdot
.10199 .05494 Mdot
.08631 .04709 Mdot
.0667 .03533 Mdot
.05102 .02357 Mdot
.03925 .01965 Mdot
.03141 .01572 Mdot
.05494 .02357 Mdot
.07454 .02749 Mdot
.10591 .05102 Mdot
.1216 .0667 Mdot
.13728 .08631 Mdot
.15297 .10983 Mdot
.14905 .10199 Mdot
.15297 .11768 Mdot
.14905 .11768 Mdot
.15689 .11768 Mdot
.15689 .11768 Mdot
.14905 .11376 Mdot
.14513 .10199 Mdot
.15297 .10199 Mdot
.16081 .10591 Mdot
.16081 .09807 Mdot
.17257 .10591 Mdot
.18826 .12552 Mdot
.18042 .1216 Mdot
.18434 .13336 Mdot
.18434 .13728 Mdot
.19218 .15297 Mdot
.20002 .16473 Mdot
.1961 .15689 Mdot
.20002 .15689 Mdot
.19218 .15297 Mdot
.18042 .1412 Mdot
.18042 .14513 Mdot
.18434 .1412 Mdot
.18826 .1412 Mdot
.20002 .14513 Mdot
.20002 .1412 Mdot
.1961 .14513 Mdot
.20002 .14513 Mdot
.19218 .12552 Mdot
.18042 .10983 Mdot
.18042 .11376 Mdot
.19218 .12944 Mdot
.18826 .13336 Mdot
.18826 .13728 Mdot
.19218 .1412 Mdot
.1961 .14513 Mdot
.1961 .14905 Mdot
.18042 .14513 Mdot
.1765 .1412 Mdot
.18042 .1412 Mdot
.18434 .14513 Mdot
.18826 .1412 Mdot
.18434 .12552 Mdot
.1961 .12944 Mdot
.18042 .1216 Mdot
.1765 .11376 Mdot
.18042 .12552 Mdot
.18826 .12944 Mdot
.19218 .13336 Mdot
.20394 .1412 Mdot
.20787 .1412 Mdot
.20394 .1412 Mdot
.1961 .13336 Mdot
.1961 .12944 Mdot
.20787 .13728 Mdot
.20002 .12944 Mdot
.21179 .14513 Mdot
.21963 .15689 Mdot
.21963 .16473 Mdot
.21571 .16081 Mdot
.20394 .14905 Mdot
.20787 .1412 Mdot
.21571 .1412 Mdot
.20787 .14513 Mdot
.20002 .1412 Mdot
.1961 .14905 Mdot
.18042 .13728 Mdot
.17257 .12552 Mdot
.17257 .11376 Mdot
.17257 .11376 Mdot
.17257 .11768 Mdot
.1765 .1216 Mdot
.19218 .12944 Mdot
.1961 .12552 Mdot
.18434 .1216 Mdot
.20002 .12944 Mdot
.20002 .13336 Mdot
.1961 .13728 Mdot
.21179 .14513 Mdot
.21571 .15689 Mdot
.20002 .14513 Mdot
.19218 .1412 Mdot
.18042 .12552 Mdot
.18434 .12944 Mdot
.20002 .14905 Mdot
.21179 .16081 Mdot
.20002 .14905 Mdot
.20787 .15297 Mdot
.20002 .14513 Mdot
.19218 .13336 Mdot
.19218 .12944 Mdot
.1961 .12552 Mdot
.20002 .12944 Mdot
.1765 .11376 Mdot
.18042 .11768 Mdot
.18434 .12944 Mdot
.18826 .13728 Mdot
.19218 .14905 Mdot
.18826 .15297 Mdot
.18826 .15297 Mdot
.18434 .15297 Mdot
.18042 .15297 Mdot
.1765 .14905 Mdot
.16865 .13728 Mdot
.17257 .13336 Mdot
.16473 .11376 Mdot
.15689 .09807 Mdot
.15297 .09023 Mdot
.1412 .07846 Mdot
.14905 .08631 Mdot
.14905 .09415 Mdot
.16473 .11376 Mdot
.16081 .11768 Mdot
.16081 .12552 Mdot
.15297 .1216 Mdot
.1412 .10983 Mdot
.1412 .11768 Mdot
.1216 .10199 Mdot
.11768 .09807 Mdot
.11376 .09415 Mdot
.1216 .09023 Mdot
.1216 .08631 Mdot
.1216 .09023 Mdot
.11768 .09023 Mdot
.11376 .09023 Mdot
.11376 .08239 Mdot
.10199 .0667 Mdot
.10199 .06278 Mdot
.11376 .07454 Mdot
.11768 .07062 Mdot
.11768 .07062 Mdot
.10591 .06278 Mdot
.09807 .0667 Mdot
.09807 .07454 Mdot
.09807 .07454 Mdot
.08239 .05886 Mdot
.0667 .04317 Mdot
.01965 .02357 Mdot
.01965 .0118 Mdot
.02749 .00788 Mdot
.03141 .00788 Mdot
.02749 .00396 Mdot
.0118 .00396 Mdot
.00788 .00396 Mdot
.01572 .00396 Mdot
.03533 .00396 Mdot
.03925 .00396 Mdot
.08239 .02357 Mdot
.09807 .04317 Mdot
.09415 .04317 Mdot
.07454 .03533 Mdot
.04709 .01572 Mdot
.04709 .00788 Mdot
.04317 .00788 Mdot
.03141 .00396 Mdot
.03533 .00788 Mdot
.0667 .02357 Mdot
.10983 .05886 Mdot
.13336 .09023 Mdot
.14905 .11376 Mdot
.16081 .12944 Mdot
.16865 .15297 Mdot
.16865 .15689 Mdot
.17257 .15297 Mdot
.16081 .13336 Mdot
.15689 .1216 Mdot
.14905 .10199 Mdot
.1412 .08631 Mdot
.14905 .08239 Mdot
.16473 .09415 Mdot
.17257 .10199 Mdot
.18434 .11376 Mdot
.20002 .12944 Mdot
.20002 .1412 Mdot
.20394 .15689 Mdot
.1961 .16473 Mdot
.19218 .1765 Mdot
.18826 .17257 Mdot
.19218 .1765 Mdot
.18434 .16865 Mdot
.18042 .16473 Mdot
.18826 .15297 Mdot
.19218 .14905 Mdot
.20002 .15297 Mdot
.20394 .14513 Mdot
.21571 .14513 Mdot
.21179 .13336 Mdot
.20787 .13336 Mdot
.20394 .12552 Mdot
.20787 .12944 Mdot
.21571 .14513 Mdot
.21179 .14905 Mdot
.20394 .15689 Mdot
.20002 .16473 Mdot
.20394 .16865 Mdot
.18826 .15297 Mdot
.1961 .14905 Mdot
.18826 .14905 Mdot
.1765 .1412 Mdot
.17257 .13336 Mdot
.18042 .13728 Mdot
.19218 .13728 Mdot
.20394 .13336 Mdot
.1961 .12552 Mdot
.20002 .12552 Mdot
.20002 .12944 Mdot
.20002 .13336 Mdot
.20002 .13336 Mdot
.1961 .13336 Mdot
.1961 .14513 Mdot
.20002 .14513 Mdot
.1961 .1412 Mdot
.20787 .15297 Mdot
.21963 .15689 Mdot
.20787 .1412 Mdot
.21963 .14513 Mdot
.21179 .1412 Mdot
.22355 .16473 Mdot
.21963 .15689 Mdot
.23139 .16473 Mdot
.22747 .14905 Mdot
.21571 .1412 Mdot
.21571 .14513 Mdot
.21571 .14905 Mdot
.20394 .14513 Mdot
.19218 .14513 Mdot
.18434 .14905 Mdot
.17257 .13728 Mdot
.16473 .12552 Mdot
.16473 .1216 Mdot
.16865 .12944 Mdot
.16865 .11768 Mdot
.18826 .12944 Mdot
.18826 .11768 Mdot
.18826 .11376 Mdot
.18434 .10591 Mdot
.19218 .11768 Mdot
.1961 .12552 Mdot
.20787 .1412 Mdot
.21571 .14905 Mdot
.20787 .15297 Mdot
.1961 .14905 Mdot
.20787 .16865 Mdot
.19218 .16081 Mdot
.18826 .16081 Mdot
.20002 .16473 Mdot
.20787 .17257 Mdot
.21179 .16081 Mdot
.20787 .16081 Mdot
.20394 .15689 Mdot
.1961 .1412 Mdot
.1961 .12944 Mdot
.1961 .12552 Mdot
.19218 .1216 Mdot
.18434 .12552 Mdot
.19218 .13728 Mdot
.1961 .1412 Mdot
.18826 .14513 Mdot
.19218 .15689 Mdot
.19218 .16473 Mdot
.18826 .16081 Mdot
.18042 .16081 Mdot
.1765 .15297 Mdot
.18042 .15297 Mdot
.15689 .12944 Mdot
.16473 .1216 Mdot
.16081 .11376 Mdot
.15689 .10591 Mdot
.16473 .10199 Mdot
.16473 .09807 Mdot
.16865 .10983 Mdot
.1765 .11376 Mdot
.18042 .11376 Mdot
.17257 .11768 Mdot
.16865 .11376 Mdot
.17257 .12552 Mdot
.16081 .11768 Mdot
.13728 .09807 Mdot
.12944 .09415 Mdot
.12552 .09023 Mdot
.12552 .09415 Mdot
.12552 .10199 Mdot
.12552 .10591 Mdot
.12944 .10983 Mdot
.13728 .1216 Mdot
.13728 .11768 Mdot
.12552 .10199 Mdot
.11376 .08631 Mdot
.11768 .08631 Mdot
.11768 .07062 Mdot
.11768 .06278 Mdot
.11768 .06278 Mdot
.10591 .05494 Mdot
.10591 .06278 Mdot
.09807 .05102 Mdot
.09415 .03925 Mdot
.07454 .02749 Mdot
.02749 .0118 Mdot
.03533 .01965 Mdot
.04317 .01965 Mdot
.05102 .01572 Mdot
.04317 .0118 Mdot
.03925 .00396 Mdot
.03141 .00396 Mdot
.03925 .00788 Mdot
.04317 .00396 Mdot
.03925 .00396 Mdot
.05102 .00396 Mdot
.05494 .00788 Mdot
.06278 .01572 Mdot
.05886 .00788 Mdot
.0667 .00788 Mdot
.05494 .00788 Mdot
.05102 .00788 Mdot
.04709 .00788 Mdot
.03533 .00396 Mdot
.03925 .00788 Mdot
.06278 .03533 Mdot
.10983 .09023 Mdot
.15297 .13728 Mdot
.16865 .16081 Mdot
.17257 .1765 Mdot
.16473 .1765 Mdot
.17257 .17257 Mdot
.16473 .14905 Mdot
.16081 .13336 Mdot
.16081 .11376 Mdot
.16473 .10199 Mdot
.16473 .08631 Mdot
.16865 .08631 Mdot
.18042 .09023 Mdot
.1765 .09415 Mdot
.18826 .11376 Mdot
.20394 .14513 Mdot
.20394 .15297 Mdot
.20394 .16473 Mdot
.18826 .17257 Mdot
.18826 .18434 Mdot
.1765 .18434 Mdot
.18042 .18042 Mdot
.18042 .17257 Mdot
.19218 .16473 Mdot
.20394 .15689 Mdot
.21179 .15297 Mdot
.21179 .13728 Mdot
.21571 .13336 Mdot
.21963 .12944 Mdot
.23924 .14513 Mdot
.22747 .14905 Mdot
.23139 .15297 Mdot
.22747 .16473 Mdot
.21963 .18042 Mdot
.20787 .18042 Mdot
.20394 .18042 Mdot
.20394 .18434 Mdot
.20394 .17257 Mdot
.20002 .16081 Mdot
.19218 .14905 Mdot
.18434 .1412 Mdot
.18042 .12944 Mdot
.19218 .12944 Mdot
.20394 .13336 Mdot
.21963 .13728 Mdot
.21963 .13728 Mdot
.23531 .15297 Mdot
.23531 .16081 Mdot
.22747 .16081 Mdot
.22747 .16473 Mdot
.21571 .17257 Mdot
.20787 .16865 Mdot
.22747 .18042 Mdot
.21571 .16865 Mdot
.21179 .16473 Mdot
.22355 .16865 Mdot
.21963 .15689 Mdot
.21179 .14513 Mdot
.20394 .13336 Mdot
.21571 .1412 Mdot
.22747 .14513 Mdot
.23139 .14905 Mdot
.23531 .16081 Mdot
.22747 .16473 Mdot
.22747 .17257 Mdot
.21179 .16081 Mdot
.20002 .16081 Mdot
.1961 .16081 Mdot
.18826 .15689 Mdot
.16865 .14513 Mdot
.17257 .14513 Mdot
.17257 .1412 Mdot
.16865 .12944 Mdot
.16473 .11376 Mdot
.1765 .10983 Mdot
.18434 .10199 Mdot
.19218 .09807 Mdot
.1961 .08631 Mdot
.20002 .09807 Mdot
.21571 .13336 Mdot
.21179 .13728 Mdot
.21571 .15297 Mdot
.22355 .1765 Mdot
.22355 .18434 Mdot
.21963 .18826 Mdot
.20394 .18434 Mdot
.1961 .18042 Mdot
.1765 .15689 Mdot
.18434 .14905 Mdot
.1961 .14905 Mdot
.20394 .14513 Mdot
.20787 .14513 Mdot
.20394 .13336 Mdot
.20002 .12552 Mdot
.1961 .1216 Mdot
.20787 .13336 Mdot
.20787 .13728 Mdot
.20787 .14513 Mdot
.20787 .14905 Mdot
.21179 .16865 Mdot
.20002 .1765 Mdot
.19218 .1765 Mdot
.1961 .18042 Mdot
.18826 .17257 Mdot
.1765 .15689 Mdot
.1765 .15297 Mdot
.16865 .1412 Mdot
.16473 .13336 Mdot
.16473 .12944 Mdot
.16081 .11376 Mdot
.16865 .11376 Mdot
.17257 .10591 Mdot
.17257 .10983 Mdot
.1765 .10983 Mdot
.18434 .11376 Mdot
.18042 .10983 Mdot
.18826 .12552 Mdot
.18434 .13336 Mdot
.17257 .12944 Mdot
.16081 .12552 Mdot
.1412 .11768 Mdot
.13728 .11376 Mdot
.12944 .11376 Mdot
.13336 .11768 Mdot
.12944 .11768 Mdot
.12944 .1216 Mdot
.13336 .1216 Mdot
.13336 .1216 Mdot
.12552 .10591 Mdot
.1216 .09415 Mdot
.1216 .08239 Mdot
.12552 .07454 Mdot
.11376 .05886 Mdot
.11768 .05886 Mdot
.1216 .06278 Mdot
.1216 .05886 Mdot
.11768 .05494 Mdot
.11768 .04709 Mdot
.09023 .03141 Mdot
.03925 .01965 Mdot
.05102 .02357 Mdot
.07062 .03141 Mdot
.06278 .02357 Mdot
.05102 .01965 Mdot
.03925 .0118 Mdot
.03141 .00396 Mdot
.04317 .00788 Mdot
.03925 .00396 Mdot
.04709 .00788 Mdot
.03925 .00396 Mdot
.02749 .00396 Mdot
.04317 .00396 Mdot
.05494 .00788 Mdot
.05886 .01572 Mdot
.05886 .01572 Mdot
.05886 .02357 Mdot
.05494 .02357 Mdot
.04317 .02357 Mdot
.03925 .03141 Mdot
.03141 .03533 Mdot
.07846 .08239 Mdot
.10591 .11376 Mdot
.13728 .15297 Mdot
.15689 .16865 Mdot
.16473 .17257 Mdot
.16081 .15689 Mdot
.16473 .14513 Mdot
.16081 .12552 Mdot
.15689 .10983 Mdot
.16473 .10199 Mdot
.17257 .09415 Mdot
.18826 .09807 Mdot
.18826 .10983 Mdot
.19218 .11768 Mdot
.20002 .13336 Mdot
.20394 .15297 Mdot
.20787 .16865 Mdot
.20002 .16865 Mdot
.1961 .17257 Mdot
.1961 .18434 Mdot
.1961 .18826 Mdot
.1961 .18042 Mdot
.19218 .16865 Mdot
.20002 .16473 Mdot
.1961 .15297 Mdot
.21571 .15297 Mdot
.23924 .16473 Mdot
.23531 .15689 Mdot
.24316 .14905 Mdot
.24708 .15689 Mdot
.24708 .17257 Mdot
.24316 .18434 Mdot
.22747 .18434 Mdot
.22747 .1961 Mdot
.21963 .20002 Mdot
.21963 .20394 Mdot
.21571 .1961 Mdot
.20787 .18434 Mdot
.20002 .17257 Mdot
.20787 .16865 Mdot
.20394 .15689 Mdot
.20394 .1412 Mdot
.21571 .1412 Mdot
.21963 .1412 Mdot
.23924 .14905 Mdot
.23924 .15689 Mdot
.251 .17257 Mdot
.24316 .18434 Mdot
.23139 .18434 Mdot
.22355 .1961 Mdot
.22747 .20002 Mdot
.21963 .1961 Mdot
.20787 .18434 Mdot
.21963 .18434 Mdot
.21179 .17257 Mdot
.22355 .17257 Mdot
.22747 .15689 Mdot
.22747 .15689 Mdot
.22355 .14905 Mdot
.22747 .14905 Mdot
.22747 .14513 Mdot
.23924 .16473 Mdot
.23531 .17257 Mdot
.23924 .19218 Mdot
.23531 .20002 Mdot
.21963 .19218 Mdot
.20394 .18042 Mdot
.20787 .1765 Mdot
.19218 .16473 Mdot
.18042 .14905 Mdot
.18434 .14905 Mdot
.1765 .13336 Mdot
.18042 .1216 Mdot
.16865 .10199 Mdot
.16473 .08239 Mdot
.16865 .08239 Mdot
.18042 .08239 Mdot
.19218 .08631 Mdot
.20394 .10199 Mdot
.21179 .12552 Mdot
.21179 .13728 Mdot
.21571 .16081 Mdot
.21571 .16865 Mdot
.21179 .18042 Mdot
.20787 .18826 Mdot
.21179 .18434 Mdot
.20002 .17257 Mdot
.1961 .15297 Mdot
.18826 .12944 Mdot
.18434 .10199 Mdot
.19218 .09807 Mdot
.20002 .10199 Mdot
.1961 .10591 Mdot
.20394 .11768 Mdot
.21571 .12944 Mdot
.22355 .14905 Mdot
.21963 .14905 Mdot
.20787 .15689 Mdot
.20002 .16081 Mdot
.19218 .15689 Mdot
.18826 .17257 Mdot
.19218 .19218 Mdot
.17257 .17257 Mdot
.17257 .16473 Mdot
.16081 .14905 Mdot
.16473 .1412 Mdot
.16473 .12944 Mdot
.17257 .13336 Mdot
.18042 .1412 Mdot
.17257 .12944 Mdot
.1765 .1216 Mdot
.18042 .11768 Mdot
.18434 .1216 Mdot
.19218 .12552 Mdot
.1961 .13336 Mdot
.20002 .14513 Mdot
.19218 .14905 Mdot
.1765 .13728 Mdot
.17257 .14513 Mdot
.15689 .14513 Mdot
.15297 .14513 Mdot
.13336 .12944 Mdot
.11376 .11376 Mdot
.1216 .11768 Mdot
.11768 .10983 Mdot
.12552 .11376 Mdot
.12944 .10983 Mdot
.13728 .10983 Mdot
.13336 .09807 Mdot
.1216 .07846 Mdot
.12552 .07454 Mdot
.12552 .07062 Mdot
.1216 .05886 Mdot
.11768 .04317 Mdot
.12552 .04709 Mdot
.1216 .04317 Mdot
.12552 .05102 Mdot
.1216 .05494 Mdot
.11376 .05102 Mdot
.05886 .03925 Mdot
.05494 .03533 Mdot
.05494 .03533 Mdot
.04709 .02357 Mdot
.02749 .0118 Mdot
.01965 .0118 Mdot
.02357 .00788 Mdot
.04709 .01965 Mdot
.05494 .02357 Mdot
.04709 .00788 Mdot
.04317 .00788 Mdot
.03533 .00396 Mdot
.04317 .00396 Mdot
.04709 .0118 Mdot
.06278 .02357 Mdot
.05886 .01965 Mdot
.04317 .01572 Mdot
.03141 .00788 Mdot
.02749 .00788 Mdot
.03925 .03141 Mdot
.04709 .04317 Mdot
.04317 .04709 Mdot
.06278 .07846 Mdot
.09415 .11768 Mdot
.13336 .14905 Mdot
.14905 .15689 Mdot
.15689 .16081 Mdot
.15297 .14513 Mdot
.15689 .13336 Mdot
.17257 .12552 Mdot
.1765 .1216 Mdot
.1765 .11768 Mdot
.18826 .11768 Mdot
.18434 .10983 Mdot
.18826 .12552 Mdot
.18826 .13728 Mdot
.20787 .15689 Mdot
.21571 .1765 Mdot
.20002 .1765 Mdot
.20394 .18434 Mdot
.21571 .20002 Mdot
.20394 .19218 Mdot
.1961 .18042 Mdot
.18826 .16473 Mdot
.19218 .15689 Mdot
.19218 .1412 Mdot
.21179 .14513 Mdot
.21963 .14905 Mdot
.22355 .15297 Mdot
.22747 .15297 Mdot
.22747 .15689 Mdot
.22747 .15689 Mdot
.23924 .1765 Mdot
.22747 .18434 Mdot
.23139 .18826 Mdot
.22355 .18826 Mdot
.21963 .1961 Mdot
.21179 .18826 Mdot
.20787 .18042 Mdot
.21571 .18434 Mdot
.21963 .18042 Mdot
.21571 .17257 Mdot
.21179 .15689 Mdot
.21963 .14905 Mdot
.22355 .1412 Mdot
.23139 .14513 Mdot
.23924 .15689 Mdot
.24316 .16865 Mdot
.23531 .18042 Mdot
.23139 .18826 Mdot
.23139 .20787 Mdot
.21571 .20787 Mdot
.20787 .20002 Mdot
.21963 .20787 Mdot
.21179 .1961 Mdot
.21571 .18042 Mdot
.22355 .16865 Mdot
.23139 .16473 Mdot
.22747 .15297 Mdot
.21963 .14513 Mdot
.21963 .15297 Mdot
.22355 .16081 Mdot
.23924 .17257 Mdot
.23924 .18042 Mdot
.24708 .1961 Mdot
.24316 .20002 Mdot
.22747 .20394 Mdot
.21179 .19218 Mdot
.20787 .18434 Mdot
.20394 .16865 Mdot
.20002 .16081 Mdot
.18826 .13728 Mdot
.18042 .12552 Mdot
.18434 .10983 Mdot
.1765 .09415 Mdot
.16865 .09023 Mdot
.16473 .08631 Mdot
.16865 .08631 Mdot
.17257 .08631 Mdot
.18434 .09023 Mdot
.18826 .10983 Mdot
.18826 .11768 Mdot
.20002 .1412 Mdot
.20002 .14905 Mdot
.1961 .16081 Mdot
.20002 .1765 Mdot
.20394 .17257 Mdot
.20002 .15689 Mdot
.1961 .14513 Mdot
.18826 .12552 Mdot
.18042 .10983 Mdot
.19218 .10199 Mdot
.20002 .10591 Mdot
.20394 .10591 Mdot
.21179 .11768 Mdot
.21571 .12944 Mdot
.21963 .1412 Mdot
.21963 .15297 Mdot
.21571 .16865 Mdot
.1961 .15689 Mdot
.18042 .15297 Mdot
.16865 .15689 Mdot
.15689 .15297 Mdot
.16473 .16865 Mdot
.16865 .15689 Mdot
.17257 .14905 Mdot
.18042 .14905 Mdot
.18042 .13728 Mdot
.17257 .1216 Mdot
.18042 .13336 Mdot
.18826 .13728 Mdot
.18434 .12552 Mdot
.19218 .1216 Mdot
.18826 .11768 Mdot
.1961 .12552 Mdot
.19218 .12552 Mdot
.18826 .12944 Mdot
.20002 .15297 Mdot
.18042 .14905 Mdot
.18042 .15689 Mdot
.16865 .16081 Mdot
.14905 .14905 Mdot
.13336 .12944 Mdot
.12552 .11768 Mdot
.1216 .11376 Mdot
.11768 .10591 Mdot
.12552 .10591 Mdot
.12552 .09807 Mdot
.1216 .09023 Mdot
.12944 .09023 Mdot
.12552 .09023 Mdot
.12944 .07846 Mdot
.12552 .07062 Mdot
.11768 .05886 Mdot
.10199 .04317 Mdot
.1216 .04709 Mdot
.12552 .05886 Mdot
.12552 .05886 Mdot
.1216 .05494 Mdot
.11376 .05494 Mdot
.06278 .05494 Mdot
.05102 .05102 Mdot
.04317 .03925 Mdot
.03925 .03141 Mdot
.04317 .03925 Mdot
.02749 .02357 Mdot
.02357 .0118 Mdot
.02749 .00788 Mdot
.03925 .01572 Mdot
.03141 .00788 Mdot
.02749 .00788 Mdot
.03533 .00396 Mdot
.03533 .00396 Mdot
.04317 .00788 Mdot
.03925 .00788 Mdot
.03925 .00788 Mdot
.03533 .00788 Mdot
.02357 .00396 Mdot
.01965 .00396 Mdot
.05886 .03141 Mdot
.09023 .07062 Mdot
.09415 .08631 Mdot
.09023 .10199 Mdot
.09807 .11768 Mdot
.10983 .14513 Mdot
.13336 .16473 Mdot
.14513 .1765 Mdot
.15297 .1765 Mdot
.14905 .16473 Mdot
.16473 .15689 Mdot
.17257 .14513 Mdot
.18042 .13728 Mdot
.18826 .12944 Mdot
.18826 .12552 Mdot
.19218 .12944 Mdot
.20002 .13728 Mdot
.20787 .14905 Mdot
.22747 .17257 Mdot
.22747 .18042 Mdot
.21571 .18042 Mdot
.21963 .18826 Mdot
.20787 .18826 Mdot
.20787 .18434 Mdot
.20787 .18826 Mdot
.1961 .16865 Mdot
.20002 .16473 Mdot
.20787 .16473 Mdot
.21179 .15297 Mdot
.22747 .15689 Mdot
.22355 .15297 Mdot
.22355 .14905 Mdot
.22355 .14513 Mdot
.23531 .15689 Mdot
.23139 .16473 Mdot
.23531 .1765 Mdot
.23531 .19218 Mdot
.22747 .1961 Mdot
.22355 .20002 Mdot
.22355 .20002 Mdot
.21571 .1961 Mdot
.20787 .19218 Mdot
.21179 .1961 Mdot
.21179 .18434 Mdot
.20394 .15689 Mdot
.20787 .13728 Mdot
.21963 .1412 Mdot
.22747 .1412 Mdot
.22747 .14513 Mdot
.23531 .15689 Mdot
.23924 .16865 Mdot
.23531 .18434 Mdot
.22355 .1961 Mdot
.21179 .19218 Mdot
.20787 .19218 Mdot
.21179 .19218 Mdot
.21963 .18826 Mdot
.22355 .18434 Mdot
.23139 .18042 Mdot
.24708 .17257 Mdot
.24316 .16473 Mdot
.23924 .16865 Mdot
.23924 .16865 Mdot
.24316 .17257 Mdot
.251 .18434 Mdot
.24708 .18042 Mdot
.251 .19218 Mdot
.24708 .20002 Mdot
.23139 .20002 Mdot
.23531 .20002 Mdot
.21963 .18826 Mdot
.20787 .18042 Mdot
.20002 .16473 Mdot
.18434 .1412 Mdot
.18042 .12552 Mdot
.1765 .10983 Mdot
.16081 .09807 Mdot
.16865 .10591 Mdot
.17257 .10591 Mdot
.16865 .09807 Mdot
.1765 .10199 Mdot
.1765 .10199 Mdot
.18434 .1216 Mdot
.19218 .13336 Mdot
.20787 .14513 Mdot
.21571 .15689 Mdot
.21179 .16081 Mdot
.21963 .16865 Mdot
.20394 .15297 Mdot
.20394 .14905 Mdot
.1961 .14513 Mdot
.20002 .14513 Mdot
.20002 .13336 Mdot
.19218 .11768 Mdot
.19218 .11376 Mdot
.20002 .11768 Mdot
.20787 .1216 Mdot
.21571 .12944 Mdot
.22355 .14513 Mdot
.22747 .15689 Mdot
.20787 .14905 Mdot
.19218 .14513 Mdot
.18434 .15689 Mdot
.1765 .15689 Mdot
.17257 .15297 Mdot
.1765 .15297 Mdot
.18042 .15297 Mdot
.18434 .14513 Mdot
.18434 .14513 Mdot
.18042 .13728 Mdot
.18826 .14513 Mdot
.18434 .13728 Mdot
.18826 .13728 Mdot
.18042 .12552 Mdot
.18434 .1216 Mdot
.18826 .1216 Mdot
.1961 .12944 Mdot
.18826 .12552 Mdot
.18826 .13336 Mdot
.19218 .13728 Mdot
.18042 .13728 Mdot
.1765 .13728 Mdot
.17257 .1412 Mdot
.16081 .12944 Mdot
.14513 .11768 Mdot
.13728 .11376 Mdot
.12552 .10591 Mdot
.12552 .10199 Mdot
.12552 .10199 Mdot
.11768 .09807 Mdot
.1216 .09415 Mdot
.12944 .09807 Mdot
.13336 .09807 Mdot
.13336 .09415 Mdot
.13336 .08631 Mdot
.1216 .07454 Mdot
.11768 .0667 Mdot
.1216 .0667 Mdot
.1216 .0667 Mdot
.11768 .07062 Mdot
.11376 .07062 Mdot
.04709 .04317 Mdot
.04709 .04709 Mdot
.03533 .03141 Mdot
.03925 .03141 Mdot
.04317 .03141 Mdot
.03141 .02357 Mdot
.02357 .01572 Mdot
.02749 .01965 Mdot
.02749 .0118 Mdot
.03141 .01572 Mdot
.03533 .01572 Mdot
.03141 .0118 Mdot
.03141 .00788 Mdot
.03533 .00788 Mdot
.02749 .00396 Mdot
.02357 .00396 Mdot
.01965 .00396 Mdot
.01965 .00396 Mdot
.01572 .00396 Mdot
.01965 .00396 Mdot
.0667 .04709 Mdot
.1216 .10199 Mdot
.18042 .16865 Mdot
.20002 .1961 Mdot
.18826 .20002 Mdot
.17257 .18826 Mdot
.16865 .19218 Mdot
.17257 .1961 Mdot
.18042 .20002 Mdot
.16473 .18042 Mdot
.16081 .15689 Mdot
.15297 .13728 Mdot
.15689 .12552 Mdot
.15689 .1216 Mdot
.16865 .11768 Mdot
.16865 .11376 Mdot
.18434 .12552 Mdot
.19218 .13728 Mdot
.20787 .15689 Mdot
.20394 .16865 Mdot
.20787 .1765 Mdot
.21179 .18042 Mdot
.20002 .1765 Mdot
.21179 .18826 Mdot
.18434 .16473 Mdot
.19218 .16473 Mdot
.19218 .14905 Mdot
.20787 .15689 Mdot
.20394 .14905 Mdot
.20787 .14513 Mdot
.20787 .1412 Mdot
.20394 .13336 Mdot
.21571 .14513 Mdot
.21571 .14905 Mdot
.22355 .16865 Mdot
.22747 .1765 Mdot
.21963 .16865 Mdot
.21179 .16865 Mdot
.21963 .18434 Mdot
.21571 .18826 Mdot
.22355 .1961 Mdot
.21179 .1961 Mdot
.21179 .19218 Mdot
.20787 .18042 Mdot
.21571 .16865 Mdot
.21571 .15297 Mdot
.21571 .14905 Mdot
.20787 .13728 Mdot
.21963 .1412 Mdot
.21571 .13728 Mdot
.22747 .15297 Mdot
.23139 .16473 Mdot
.23139 .17257 Mdot
.22747 .17257 Mdot
.21571 .16865 Mdot
.21571 .17257 Mdot
.23531 .18826 Mdot
.23924 .18042 Mdot
.23924 .17257 Mdot
.23531 .16473 Mdot
.23924 .17257 Mdot
.23139 .16865 Mdot
.23924 .1765 Mdot
.22355 .16081 Mdot
.23139 .16865 Mdot
.23924 .17257 Mdot
.23924 .18042 Mdot
.23924 .19218 Mdot
.23531 .20002 Mdot
.23139 .1961 Mdot
.22747 .19218 Mdot
.21179 .17257 Mdot
.18434 .1412 Mdot
.1765 .12944 Mdot
.16865 .1216 Mdot
.16473 .11768 Mdot
.16473 .11768 Mdot
.16865 .11376 Mdot
.17257 .11376 Mdot
.1765 .11768 Mdot
.16865 .11376 Mdot
.16473 .10591 Mdot
.1765 .10983 Mdot
.18042 .11768 Mdot
.19218 .12944 Mdot
.1961 .13336 Mdot
.19218 .13336 Mdot
.20002 .1412 Mdot
.20394 .14513 Mdot
.20787 .14905 Mdot
.20787 .15689 Mdot
.21571 .16081 Mdot
.21179 .15297 Mdot
.20002 .13336 Mdot
.20002 .12552 Mdot
.1961 .1216 Mdot
.18434 .10983 Mdot
.20394 .11768 Mdot
.22355 .1412 Mdot
.22747 .14905 Mdot
.21571 .14513 Mdot
.20394 .15297 Mdot
.19218 .15689 Mdot
.18042 .14513 Mdot
.18042 .14513 Mdot
.18042 .14905 Mdot
.18826 .16081 Mdot
.18434 .15689 Mdot
.16865 .14905 Mdot
.16865 .14905 Mdot
.16473 .1412 Mdot
.16865 .12944 Mdot
.17257 .1216 Mdot
.1765 .1216 Mdot
.18434 .11768 Mdot
.1961 .11768 Mdot
.18826 .11376 Mdot
.18042 .10983 Mdot
.18434 .11768 Mdot
.18434 .11376 Mdot
.18826 .10983 Mdot
.16865 .09415 Mdot
.18042 .10983 Mdot
.16865 .11768 Mdot
.15297 .11768 Mdot
.14513 .1216 Mdot
.13336 .11376 Mdot
.13336 .11376 Mdot
.12552 .1216 Mdot
.1216 .11376 Mdot
.1216 .11376 Mdot
.11768 .10591 Mdot
.1216 .09415 Mdot
.10983 .08631 Mdot
.11376 .08239 Mdot
.1216 .08631 Mdot
.13336 .08631 Mdot
.12552 .07846 Mdot
.1216 .07846 Mdot
.10983 .07454 Mdot
.03141 .01572 Mdot
.03533 .01965 Mdot
.03925 .02357 Mdot
.03925 .01572 Mdot
.03141 .0118 Mdot
.03533 .01572 Mdot
.04709 .02357 Mdot
.05886 .04317 Mdot
.06278 .04317 Mdot
.05494 .03533 Mdot
.06278 .03925 Mdot
.05102 .02357 Mdot
.04317 .0118 Mdot
.03533 .00788 Mdot
.02749 .00396 Mdot
.01965 .00396 Mdot
.01965 .00396 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.00788 .00396 Mdot
.07062 .05494 Mdot
.22355 .1961 Mdot
.22355 .20002 Mdot
.20394 .19218 Mdot
.20394 .20002 Mdot
.20002 .20002 Mdot
.20002 .1961 Mdot
.21571 .21179 Mdot
.20002 .20002 Mdot
.15297 .15689 Mdot
.12944 .1216 Mdot
.1216 .10591 Mdot
.1216 .08631 Mdot
.12552 .07846 Mdot
.13728 .08239 Mdot
.1412 .08631 Mdot
.14513 .08631 Mdot
.16473 .10199 Mdot
.18042 .13336 Mdot
.19218 .15297 Mdot
.20394 .16473 Mdot
.21571 .17257 Mdot
.22747 .18826 Mdot
.22747 .18434 Mdot
.21179 .16865 Mdot
.21571 .16473 Mdot
.22355 .16081 Mdot
.21179 .15297 Mdot
.22355 .16473 Mdot
.21963 .15689 Mdot
.22355 .16473 Mdot
.21963 .16081 Mdot
.21963 .16473 Mdot
.21963 .16081 Mdot
.22355 .16473 Mdot
.22355 .16865 Mdot
.21963 .16473 Mdot
.21963 .16865 Mdot
.21963 .16473 Mdot
.22355 .17257 Mdot
.23139 .18826 Mdot
.22747 .19218 Mdot
.22355 .18826 Mdot
.22355 .18826 Mdot
.22747 .18042 Mdot
.22747 .17257 Mdot
.20787 .14513 Mdot
.21571 .14513 Mdot
.21571 .1412 Mdot
.21571 .1412 Mdot
.22355 .1412 Mdot
.21963 .14513 Mdot
.22355 .15689 Mdot
.21963 .16081 Mdot
.21571 .15297 Mdot
.23139 .16081 Mdot
.22747 .15297 Mdot
.23531 .16473 Mdot
.23924 .1765 Mdot
.23531 .18434 Mdot
.23531 .1961 Mdot
.22355 .18434 Mdot
.21571 .17257 Mdot
.21571 .16865 Mdot
.22355 .16865 Mdot
.22747 .16865 Mdot
.23139 .17257 Mdot
.23139 .17257 Mdot
.23531 .1765 Mdot
.23924 .18434 Mdot
.21571 .16081 Mdot
.20002 .14513 Mdot
.18042 .12944 Mdot
.17257 .12552 Mdot
.17257 .12552 Mdot
.16865 .11376 Mdot
.1765 .1216 Mdot
.1765 .1216 Mdot
.17257 .11376 Mdot
.16081 .10591 Mdot
.16473 .10983 Mdot
.16865 .11376 Mdot
.16865 .11376 Mdot
.1765 .11376 Mdot
.1765 .11376 Mdot
.1765 .11376 Mdot
.1961 .12552 Mdot
.21179 .13336 Mdot
.21571 .14513 Mdot
.21571 .15297 Mdot
.21963 .16865 Mdot
.21963 .16865 Mdot
.21571 .16473 Mdot
.20787 .14905 Mdot
.1961 .13336 Mdot
.18434 .11768 Mdot
.1961 .12552 Mdot
.20394 .13336 Mdot
.19218 .1216 Mdot
.20002 .12944 Mdot
.20002 .13728 Mdot
.18434 .13336 Mdot
.18042 .13336 Mdot
.18434 .12944 Mdot
.17257 .12552 Mdot
.16081 .11768 Mdot
.1765 .12552 Mdot
.18042 .14513 Mdot
.1765 .14905 Mdot
.17257 .14513 Mdot
.1765 .14513 Mdot
.1765 .1412 Mdot
.17257 .12944 Mdot
.18042 .12552 Mdot
.18826 .12944 Mdot
.18042 .11768 Mdot
.18042 .11768 Mdot
.16865 .10591 Mdot
.16473 .09807 Mdot
.17257 .09807 Mdot
.16081 .08239 Mdot
.15297 .07846 Mdot
.14513 .08631 Mdot
.15297 .10199 Mdot
.14905 .10591 Mdot
.12944 .10199 Mdot
.13728 .11376 Mdot
.12944 .11768 Mdot
.13336 .1216 Mdot
.12944 .1216 Mdot
.12552 .11768 Mdot
.11376 .10199 Mdot
.10983 .10199 Mdot
.1216 .10591 Mdot
.10983 .09415 Mdot
.11376 .09807 Mdot
.12944 .10591 Mdot
.12944 .10591 Mdot
.11376 .09023 Mdot
.02357 .0118 Mdot
.02357 .00396 Mdot
.04317 .0118 Mdot
.05494 .01572 Mdot
.04317 .0118 Mdot
.04709 .01965 Mdot
.0667 .03925 Mdot
.07846 .05886 Mdot
.09023 .0667 Mdot
.07846 .0667 Mdot
.08631 .07454 Mdot
.07846 .05494 Mdot
.07062 .03533 Mdot
.04709 .01965 Mdot
.03141 .0118 Mdot
.01965 .00788 Mdot
.02749 .00788 Mdot
.02749 .0118 Mdot
.01572 .00396 Mdot
.0118 .00396 Mdot
.01965 .0118 Mdot
.01572 .00788 Mdot
.08631 .06278 Mdot
.11376 .08239 Mdot
.18042 .1412 Mdot
.27845 .23139 Mdot
.1961 .15689 Mdot
.19218 .15689 Mdot
.21963 .18826 Mdot
.20002 .18042 Mdot
.09807 .09023 Mdot
.08631 .07846 Mdot
.0667 .05494 Mdot
.07062 .04709 Mdot
.07454 .04317 Mdot
.10199 .05102 Mdot
.11768 .05886 Mdot
.1216 .06278 Mdot
.1412 .08239 Mdot
.17257 .11768 Mdot
.1961 .14905 Mdot
.21179 .16865 Mdot
.21963 .18042 Mdot
.23139 .18434 Mdot
.22355 .17257 Mdot
.22747 .17257 Mdot
.23139 .16473 Mdot
.23924 .16473 Mdot
.24316 .16081 Mdot
.25492 .17257 Mdot
.25492 .18042 Mdot
.251 .18042 Mdot
.24708 .18042 Mdot
.23531 .1765 Mdot
.23139 .1765 Mdot
.23531 .1765 Mdot
.23531 .18042 Mdot
.23924 .18826 Mdot
.24708 .18826 Mdot
.22355 .17257 Mdot
.23139 .1765 Mdot
.23139 .18042 Mdot
.24316 .19218 Mdot
.23924 .19218 Mdot
.23924 .1961 Mdot
.24708 .19218 Mdot
.24316 .1765 Mdot
.23139 .16473 Mdot
.22747 .15689 Mdot
.23139 .15689 Mdot
.24316 .16473 Mdot
.23531 .16081 Mdot
.23531 .16081 Mdot
.22747 .15689 Mdot
.23139 .16081 Mdot
.23531 .16081 Mdot
.23139 .15689 Mdot
.23531 .15689 Mdot
.251 .16865 Mdot
.25884 .18826 Mdot
.26668 .20002 Mdot
.25884 .21179 Mdot
.24316 .20002 Mdot
.23139 .1961 Mdot
.22355 .18042 Mdot
.21571 .16865 Mdot
.22355 .17257 Mdot
.22747 .17257 Mdot
.22355 .16081 Mdot
.23531 .17257 Mdot
.23139 .1765 Mdot
.23139 .18042 Mdot
.22355 .17257 Mdot
.20787 .15689 Mdot
.18042 .13336 Mdot
.18042 .13336 Mdot
.18042 .12944 Mdot
.1765 .1216 Mdot
.18434 .12552 Mdot
.19218 .13336 Mdot
.18434 .12552 Mdot
.1765 .12552 Mdot
.1765 .12944 Mdot
.18042 .1216 Mdot
.1765 .11376 Mdot
.1765 .1216 Mdot
.17257 .11376 Mdot
.18042 .1216 Mdot
.18434 .12552 Mdot
.19218 .12944 Mdot
.20002 .13728 Mdot
.20787 .14513 Mdot
.20787 .15297 Mdot
.21963 .16865 Mdot
.21963 .16865 Mdot
.21963 .16081 Mdot
.20394 .1412 Mdot
.20394 .1412 Mdot
.19218 .13728 Mdot
.1961 .14513 Mdot
.18826 .1412 Mdot
.20002 .14905 Mdot
.20002 .14905 Mdot
.1961 .14905 Mdot
.18042 .13728 Mdot
.18434 .13336 Mdot
.18434 .12944 Mdot
.18042 .1216 Mdot
.18434 .13728 Mdot
.20002 .15689 Mdot
.20002 .16081 Mdot
.18826 .14905 Mdot
.18434 .1412 Mdot
.16865 .13336 Mdot
.18434 .1412 Mdot
.18042 .13336 Mdot
.18434 .13336 Mdot
.18434 .12944 Mdot
.1765 .12552 Mdot
.17257 .11768 Mdot
.17257 .11376 Mdot
.16081 .10199 Mdot
.15689 .09023 Mdot
.15297 .09415 Mdot
.15689 .10591 Mdot
.14905 .10591 Mdot
.14905 .10591 Mdot
.1412 .10591 Mdot
.14513 .1216 Mdot
.14513 .1216 Mdot
.13728 .11768 Mdot
.12552 .10591 Mdot
.1216 .10591 Mdot
.11768 .10199 Mdot
.11768 .09415 Mdot
.11768 .09415 Mdot
.1216 .09807 Mdot
.1216 .10199 Mdot
.12944 .10199 Mdot
.11768 .09415 Mdot
.02749 .02357 Mdot
.03925 .02749 Mdot
.03533 .01572 Mdot
.03141 .0118 Mdot
.03533 .0118 Mdot
.03141 .0118 Mdot
.04317 .03533 Mdot
.05494 .04709 Mdot
.07846 .06278 Mdot
.09023 .07454 Mdot
.09415 .08239 Mdot
.09807 .08239 Mdot
.08631 .0667 Mdot
.05494 .03533 Mdot
.03925 .01572 Mdot
.02357 .00788 Mdot
.02749 .00788 Mdot
.01572 .00788 Mdot
.01965 .0118 Mdot
.00788 .00788 Mdot
.0118 .00788 Mdot
.02749 .0118 Mdot
.04317 .01965 Mdot
.04709 .0118 Mdot
.05886 .01965 Mdot
.15297 .09807 Mdot
.15689 .10983 Mdot
.16473 .11768 Mdot
.24316 .1961 Mdot
.23924 .20394 Mdot
.15297 .13336 Mdot
.10983 .10591 Mdot
.0667 .0667 Mdot
.05886 .04709 Mdot
.06278 .03925 Mdot
.07062 .03925 Mdot
.08239 .05102 Mdot
.09807 .05886 Mdot
.1412 .09807 Mdot
.17257 .1216 Mdot
.20394 .15297 Mdot
.21179 .16081 Mdot
.23139 .18826 Mdot
.23139 .18434 Mdot
.22747 .1765 Mdot
.22355 .16865 Mdot
.23531 .1765 Mdot
.23531 .16865 Mdot
.24708 .17257 Mdot
.25492 .18042 Mdot
.26276 .19218 Mdot
.25492 .19218 Mdot
.24316 .1765 Mdot
.24316 .18434 Mdot
.23924 .18042 Mdot
.24316 .18434 Mdot
.25492 .1961 Mdot
.25492 .20002 Mdot
.251 .1961 Mdot
.24316 .18826 Mdot
.23924 .1961 Mdot
.23924 .20002 Mdot
.24316 .19218 Mdot
.25492 .19218 Mdot
.251 .1961 Mdot
.251 .19218 Mdot
.23924 .1765 Mdot
.23924 .18042 Mdot
.23139 .1765 Mdot
.24316 .18042 Mdot
.23924 .18042 Mdot
.24316 .18434 Mdot
.23531 .18434 Mdot
.24316 .18042 Mdot
.23924 .16865 Mdot
.23924 .16473 Mdot
.24708 .17257 Mdot
.24708 .16865 Mdot
.26276 .19218 Mdot
.26668 .20002 Mdot
.26276 .20787 Mdot
.26668 .21963 Mdot
.26276 .21963 Mdot
.26276 .21963 Mdot
.24316 .1961 Mdot
.22747 .1765 Mdot
.22355 .16865 Mdot
.21571 .16081 Mdot
.21571 .15689 Mdot
.22747 .16473 Mdot
.23139 .1765 Mdot
.23924 .1961 Mdot
.24708 .20787 Mdot
.22747 .19218 Mdot
.20002 .17257 Mdot
.19218 .16865 Mdot
.18434 .16081 Mdot
.18042 .14513 Mdot
.18826 .14513 Mdot
.19218 .14513 Mdot
.19218 .13336 Mdot
.18434 .1216 Mdot
.18042 .11376 Mdot
.18042 .10983 Mdot
.18042 .10983 Mdot
.1765 .10591 Mdot
.1765 .10591 Mdot
.1765 .10983 Mdot
.1765 .1216 Mdot
.16865 .1216 Mdot
.17257 .12944 Mdot
.1765 .13728 Mdot
.1961 .14905 Mdot
.19218 .14905 Mdot
.1961 .15689 Mdot
.21179 .16473 Mdot
.20394 .14905 Mdot
.20394 .14905 Mdot
.20394 .14905 Mdot
.20002 .15297 Mdot
.1961 .13728 Mdot
.18826 .12944 Mdot
.18826 .13728 Mdot
.20002 .14513 Mdot
.19218 .14513 Mdot
.18434 .13728 Mdot
.18826 .13728 Mdot
.1765 .12944 Mdot
.18042 .13336 Mdot
.18826 .1412 Mdot
.18826 .14513 Mdot
.16865 .12944 Mdot
.1765 .13728 Mdot
.18434 .14513 Mdot
.1765 .13336 Mdot
.17257 .1216 Mdot
.16865 .11768 Mdot
.17257 .1216 Mdot
.18042 .13336 Mdot
.1765 .1216 Mdot
.17257 .10983 Mdot
.16473 .09807 Mdot
.16473 .09415 Mdot
.15689 .09415 Mdot
.15689 .09807 Mdot
.15297 .10983 Mdot
.15297 .11768 Mdot
.13728 .11768 Mdot
.1412 .1216 Mdot
.13728 .11768 Mdot
.13728 .11768 Mdot
.12944 .10983 Mdot
.12944 .09807 Mdot
.1216 .09023 Mdot
.1216 .08631 Mdot
.1216 .09023 Mdot
.12944 .10199 Mdot
.13728 .09807 Mdot
.1412 .10591 Mdot
.12944 .09023 Mdot
.03533 .04317 Mdot
.03141 .03533 Mdot
.04709 .03533 Mdot
.03141 .01965 Mdot
.01965 .00788 Mdot
.01572 .00788 Mdot
.01965 .00788 Mdot
.03533 .03141 Mdot
.04317 .04317 Mdot
.06278 .05886 Mdot
.07846 .07062 Mdot
.08239 .07454 Mdot
.07846 .0667 Mdot
.05886 .04317 Mdot
.04317 .01572 Mdot
.03141 .00396 Mdot
.02357 .00788 Mdot
.01965 .00788 Mdot
.01572 .00788 Mdot
.01572 .0118 Mdot
.01572 .01572 Mdot
.03533 .02749 Mdot
.03141 .01965 Mdot
.03141 .0118 Mdot
.03141 .00788 Mdot
.03141 .0118 Mdot
.05102 .02749 Mdot
.0667 .03925 Mdot
.1412 .10591 Mdot
.18826 .15689 Mdot
.14905 .1216 Mdot
.13336 .10983 Mdot
.1216 .09023 Mdot
.11376 .08239 Mdot
.09807 .07454 Mdot
.08239 .0667 Mdot
.08239 .07062 Mdot
.08631 .0667 Mdot
.12552 .10199 Mdot
.15297 .12944 Mdot
.18434 .15689 Mdot
.20002 .16473 Mdot
.22355 .18826 Mdot
.22747 .19218 Mdot
.22355 .18434 Mdot
.21963 .1765 Mdot
.22355 .16865 Mdot
.22747 .17257 Mdot
.23531 .1765 Mdot
.24316 .18434 Mdot
.24316 .18434 Mdot
.251 .1961 Mdot
.24316 .18434 Mdot
.23924 .18434 Mdot
.251 .1961 Mdot
.25492 .20394 Mdot
.25492 .20394 Mdot
.26276 .21179 Mdot
.251 .20002 Mdot
.25884 .20394 Mdot
.26276 .20787 Mdot
.25492 .20787 Mdot
.25492 .20002 Mdot
.251 .18826 Mdot
.25492 .18826 Mdot
.26276 .19218 Mdot
.24708 .18826 Mdot
.24708 .20002 Mdot
.24316 .20394 Mdot
.24316 .20002 Mdot
.23924 .19218 Mdot
.251 .1961 Mdot
.25492 .20002 Mdot
.251 .19218 Mdot
.24316 .17257 Mdot
.24708 .17257 Mdot
.251 .17257 Mdot
.24316 .17257 Mdot
.24316 .18042 Mdot
.25492 .19218 Mdot
.25884 .21179 Mdot
.26276 .22355 Mdot
.27845 .23924 Mdot
.26668 .22747 Mdot
.26668 .22355 Mdot
.25492 .20787 Mdot
.25884 .21963 Mdot
.23139 .20002 Mdot
.21963 .18826 Mdot
.21963 .18042 Mdot
.21963 .1765 Mdot
.23531 .18434 Mdot
.24708 .1961 Mdot
.24708 .19218 Mdot
.23139 .18434 Mdot
.21571 .1765 Mdot
.21571 .18434 Mdot
.21571 .1765 Mdot
.21179 .17257 Mdot
.1961 .16081 Mdot
.1961 .14905 Mdot
.18826 .13728 Mdot
.18826 .12552 Mdot
.18826 .11768 Mdot
.18826 .11768 Mdot
.1765 .10591 Mdot
.18042 .10983 Mdot
.18434 .11376 Mdot
.18826 .12552 Mdot
.18042 .1216 Mdot
.18042 .1216 Mdot
.1765 .1216 Mdot
.18434 .1412 Mdot
.20002 .15689 Mdot
.19218 .15297 Mdot
.20002 .16473 Mdot
.20787 .16865 Mdot
.20002 .16081 Mdot
.20002 .15297 Mdot
.1961 .1412 Mdot
.18042 .12944 Mdot
.1765 .12944 Mdot
.18042 .12944 Mdot
.19218 .13728 Mdot
.1961 .14513 Mdot
.19218 .14513 Mdot
.1961 .14513 Mdot
.18042 .12944 Mdot
.18434 .12944 Mdot
.19218 .12944 Mdot
.18826 .12552 Mdot
.19218 .13336 Mdot
.18826 .13728 Mdot
.18434 .13728 Mdot
.18826 .14513 Mdot
.1765 .1412 Mdot
.17257 .14513 Mdot
.16473 .1412 Mdot
.16473 .13728 Mdot
.16865 .12944 Mdot
.1765 .12944 Mdot
.1765 .1216 Mdot
.16865 .10591 Mdot
.16081 .09807 Mdot
.16865 .10199 Mdot
.16081 .09807 Mdot
.15689 .10983 Mdot
.14905 .10983 Mdot
.15297 .12552 Mdot
.1412 .11768 Mdot
.13728 .11376 Mdot
.13728 .11376 Mdot
.14905 .1216 Mdot
.13728 .10591 Mdot
.12944 .09415 Mdot
.1216 .09023 Mdot
.1216 .09023 Mdot
.1216 .09023 Mdot
.12552 .09807 Mdot
.11768 .09415 Mdot
.07846 .10591 Mdot
.05886 .08239 Mdot
.04709 .05886 Mdot
.03141 .03141 Mdot
.01965 .01572 Mdot
.01965 .00788 Mdot
.0118 .00396 Mdot
.03141 .01572 Mdot
.06278 .03533 Mdot
.0667 .03925 Mdot
.05886 .03141 Mdot
.0667 .03925 Mdot
.0667 .04317 Mdot
.05494 .03141 Mdot
.04317 .02357 Mdot
.04317 .01572 Mdot
.02749 .0118 Mdot
.02749 .0118 Mdot
.01965 .00788 Mdot
.02357 .0118 Mdot
.03141 .02357 Mdot
.04317 .01965 Mdot
.03141 .0118 Mdot
.01572 .00788 Mdot
.02357 .00788 Mdot
.02749 .0118 Mdot
.02749 .01572 Mdot
.03925 .01965 Mdot
.04317 .02749 Mdot
.07062 .04709 Mdot
.07454 .05102 Mdot
.07846 .05886 Mdot
.09023 .05886 Mdot
.09023 .05494 Mdot
.10199 .0667 Mdot
.13336 .09807 Mdot
.13728 .10199 Mdot
.1216 .09023 Mdot
.1216 .10199 Mdot
.13728 .1216 Mdot
.16473 .14905 Mdot
.18434 .16473 Mdot
.20394 .1765 Mdot
.21963 .18434 Mdot
.21963 .1765 Mdot
.21571 .16865 Mdot
.22747 .1765 Mdot
.22355 .17257 Mdot
.21963 .17257 Mdot
.22355 .18042 Mdot
.23924 .19218 Mdot
.24316 .1961 Mdot
.24708 .20002 Mdot
.251 .1961 Mdot
.26668 .20394 Mdot
.25492 .1961 Mdot
.25492 .19218 Mdot
.25884 .20394 Mdot
.26668 .20787 Mdot
.27845 .21179 Mdot
.26668 .20787 Mdot
.251 .20394 Mdot
.25492 .20394 Mdot
.251 .19218 Mdot
.25884 .1961 Mdot
.26276 .1961 Mdot
.251 .18434 Mdot
.251 .18826 Mdot
.24708 .1961 Mdot
.24708 .1961 Mdot
.25492 .1961 Mdot
.25492 .1961 Mdot
.25884 .20002 Mdot
.26276 .21179 Mdot
.25492 .20002 Mdot
.251 .18826 Mdot
.251 .18826 Mdot
.26276 .20002 Mdot
.25884 .20394 Mdot
.25492 .20394 Mdot
.25492 .20787 Mdot
.26276 .21179 Mdot
.27453 .21179 Mdot
.27453 .21179 Mdot
.27453 .20787 Mdot
.26668 .20002 Mdot
.25492 .20394 Mdot
.26276 .21963 Mdot
.24316 .20394 Mdot
.23924 .1961 Mdot
.22747 .18042 Mdot
.22747 .16865 Mdot
.24708 .17257 Mdot
.24316 .16865 Mdot
.251 .18042 Mdot
.251 .19218 Mdot
.25884 .20787 Mdot
.23924 .19218 Mdot
.22355 .1765 Mdot
.20787 .16865 Mdot
.19218 .16081 Mdot
.20787 .16865 Mdot
.20787 .15689 Mdot
.1961 .13336 Mdot
.19218 .12944 Mdot
.18826 .12552 Mdot
.1961 .12944 Mdot
.18826 .12944 Mdot
.19218 .13728 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.1765 .12944 Mdot
.18434 .14513 Mdot
.18042 .1412 Mdot
.18042 .1412 Mdot
.18042 .14513 Mdot
.18434 .14513 Mdot
.18434 .1412 Mdot
.18826 .13728 Mdot
.20394 .14905 Mdot
.20002 .1412 Mdot
.20002 .1412 Mdot
.19218 .13728 Mdot
.18434 .13728 Mdot
.18042 .1412 Mdot
.20002 .15297 Mdot
.19218 .1412 Mdot
.18042 .12944 Mdot
.16865 .11768 Mdot
.18826 .13336 Mdot
.18042 .12552 Mdot
.18826 .13336 Mdot
.18434 .12944 Mdot
.1765 .12552 Mdot
.1765 .13336 Mdot
.18434 .13728 Mdot
.1765 .13728 Mdot
.1765 .14905 Mdot
.16865 .13728 Mdot
.1765 .1412 Mdot
.16865 .13336 Mdot
.17257 .12552 Mdot
.16865 .11768 Mdot
.16473 .10591 Mdot
.16081 .10591 Mdot
.16473 .11376 Mdot
.16473 .11768 Mdot
.15297 .11768 Mdot
.14905 .11376 Mdot
.14513 .11376 Mdot
.1412 .11376 Mdot
.13728 .10591 Mdot
.1412 .10983 Mdot
.13728 .10199 Mdot
.12552 .09023 Mdot
.1216 .09023 Mdot
.1216 .09023 Mdot
.11768 .08631 Mdot
.11768 .09023 Mdot
.10591 .07846 Mdot
.09023 .1412 Mdot
.08631 .13728 Mdot
.08239 .12944 Mdot
.0667 .10591 Mdot
.04709 .07454 Mdot
.04317 .06278 Mdot
.03533 .04709 Mdot
.05494 .05494 Mdot
.0667 .05886 Mdot
.05494 .03141 Mdot
.04317 .01572 Mdot
.05102 .01965 Mdot
.06278 .03533 Mdot
.0667 .04317 Mdot
.06278 .03533 Mdot
.05886 .02749 Mdot
.04709 .01965 Mdot
.04317 .0118 Mdot
.04709 .02357 Mdot
.03925 .01965 Mdot
.03925 .02749 Mdot
.03533 .02749 Mdot
.02357 .01572 Mdot
.01572 .00788 Mdot
.0118 .00788 Mdot
.01572 .0118 Mdot
.02749 .01965 Mdot
.04709 .03141 Mdot
.05494 .03533 Mdot
.04709 .02749 Mdot
.03925 .03141 Mdot
.05102 .03533 Mdot
.05102 .02749 Mdot
.03925 .0118 Mdot
.05494 .02749 Mdot
.09023 .06278 Mdot
.1412 .10591 Mdot
.15689 .11768 Mdot
.16865 .13336 Mdot
.17257 .1412 Mdot
.18434 .16081 Mdot
.18826 .17257 Mdot
.19218 .16865 Mdot
.19218 .15689 Mdot
.20394 .16473 Mdot
.20394 .16473 Mdot
.20002 .15297 Mdot
.20787 .15297 Mdot
.21179 .16473 Mdot
.21571 .16865 Mdot
.22355 .1765 Mdot
.22355 .18042 Mdot
.22355 .1765 Mdot
.23531 .18826 Mdot
.251 .1961 Mdot
.25884 .20002 Mdot
.26668 .20394 Mdot
.27061 .21571 Mdot
.27453 .22355 Mdot
.27845 .22747 Mdot
.27061 .21571 Mdot
.27061 .21571 Mdot
.27061 .21571 Mdot
.27453 .21571 Mdot
.27453 .21179 Mdot
.27845 .20787 Mdot
.27453 .21179 Mdot
.27061 .21571 Mdot
.25492 .20394 Mdot
.24708 .1961 Mdot
.24708 .19218 Mdot
.25884 .1961 Mdot
.25884 .20394 Mdot
.26668 .21179 Mdot
.25884 .20394 Mdot
.24708 .20394 Mdot
.24708 .20394 Mdot
.24708 .1961 Mdot
.251 .19218 Mdot
.25884 .20002 Mdot
.251 .19218 Mdot
.25492 .18434 Mdot
.25492 .18826 Mdot
.26668 .1961 Mdot
.25884 .18826 Mdot
.27061 .1961 Mdot
.26668 .1961 Mdot
.26668 .20002 Mdot
.26668 .20394 Mdot
.26276 .20002 Mdot
.24708 .18434 Mdot
.24316 .17257 Mdot
.24708 .16473 Mdot
.24708 .15689 Mdot
.24708 .15689 Mdot
.27061 .18434 Mdot
.27061 .1961 Mdot
.26276 .20002 Mdot
.25492 .20002 Mdot
.24316 .1961 Mdot
.22747 .18434 Mdot
.22747 .17257 Mdot
.21571 .15297 Mdot
.20787 .14513 Mdot
.20394 .1412 Mdot
.1961 .13336 Mdot
.19218 .12944 Mdot
.20002 .1412 Mdot
.19218 .12944 Mdot
.18434 .12552 Mdot
.18042 .1216 Mdot
.1765 .12944 Mdot
.1765 .13336 Mdot
.18042 .14905 Mdot
.18826 .15297 Mdot
.18042 .14513 Mdot
.18434 .14513 Mdot
.18826 .14905 Mdot
.18042 .13336 Mdot
.1961 .13728 Mdot
.21179 .1412 Mdot
.21571 .13728 Mdot
.21571 .14513 Mdot
.20394 .13728 Mdot
.19218 .13336 Mdot
.19218 .1412 Mdot
.1961 .14905 Mdot
.19218 .14513 Mdot
.18434 .13336 Mdot
.1765 .12552 Mdot
.1765 .1216 Mdot
.18042 .12552 Mdot
.18042 .12944 Mdot
.18042 .12552 Mdot
.1765 .11768 Mdot
.18042 .12944 Mdot
.18042 .13728 Mdot
.18042 .14513 Mdot
.1765 .1412 Mdot
.18826 .15297 Mdot
.16865 .13728 Mdot
.15689 .12552 Mdot
.16865 .1216 Mdot
.16473 .11376 Mdot
.16865 .11768 Mdot
.16865 .1216 Mdot
.15297 .10983 Mdot
.15297 .10983 Mdot
.14905 .10591 Mdot
.14905 .10983 Mdot
.1412 .10983 Mdot
.12552 .10199 Mdot
.12552 .09807 Mdot
.12552 .10983 Mdot
.11768 .10591 Mdot
.11768 .10199 Mdot
.11768 .09807 Mdot
.10199 .07846 Mdot
.10983 .08239 Mdot
.10591 .07454 Mdot
.1412 .19218 Mdot
.13728 .18434 Mdot
.12944 .16865 Mdot
.11768 .16081 Mdot
.10591 .14513 Mdot
.08239 .11768 Mdot
.0667 .09023 Mdot
.07454 .09023 Mdot
.0667 .07062 Mdot
.04317 .04317 Mdot
.04317 .03533 Mdot
.05494 .03533 Mdot
.05886 .03925 Mdot
.06278 .03533 Mdot
.0667 .03925 Mdot
.05494 .02749 Mdot
.04317 .01965 Mdot
.05102 .01965 Mdot
.05102 .02357 Mdot
.05102 .03141 Mdot
.06278 .05102 Mdot
.05886 .06278 Mdot
.03925 .04709 Mdot
.01965 .02357 Mdot
.01572 .01572 Mdot
.01965 .01965 Mdot
.05494 .05494 Mdot
.07062 .06278 Mdot
.0667 .05102 Mdot
.05494 .04317 Mdot
.05102 .03533 Mdot
.04709 .03141 Mdot
.04709 .03925 Mdot
.03141 .02357 Mdot
.03141 .01572 Mdot
.03925 .01965 Mdot
.05886 .03533 Mdot
.10199 .07454 Mdot
.1765 .13728 Mdot
.20787 .16473 Mdot
.23139 .18042 Mdot
.22747 .18826 Mdot
.21571 .18042 Mdot
.21179 .16865 Mdot
.20787 .16473 Mdot
.20002 .16473 Mdot
.20002 .16081 Mdot
.18434 .14905 Mdot
.18434 .16473 Mdot
.18042 .15689 Mdot
.19218 .16473 Mdot
.20002 .16865 Mdot
.21179 .1765 Mdot
.22747 .18434 Mdot
.23531 .19218 Mdot
.24708 .19218 Mdot
.26276 .21179 Mdot
.27061 .22355 Mdot
.26668 .22355 Mdot
.27061 .23531 Mdot
.27845 .23531 Mdot
.28237 .23531 Mdot
.27845 .22747 Mdot
.28237 .23139 Mdot
.27453 .21571 Mdot
.27061 .21571 Mdot
.27061 .21571 Mdot
.27453 .21963 Mdot
.26276 .21179 Mdot
.26276 .20787 Mdot
.25492 .19218 Mdot
.25884 .19218 Mdot
.25884 .20002 Mdot
.27061 .21179 Mdot
.25492 .20787 Mdot
.24708 .20787 Mdot
.251 .20002 Mdot
.24316 .18042 Mdot
.24316 .18042 Mdot
.24708 .18826 Mdot
.251 .18826 Mdot
.251 .18434 Mdot
.251 .18434 Mdot
.25884 .19218 Mdot
.26276 .19218 Mdot
.27061 .20394 Mdot
.26668 .20787 Mdot
.26668 .20787 Mdot
.25884 .20787 Mdot
.25884 .20394 Mdot
.251 .18826 Mdot
.25492 .18434 Mdot
.251 .16865 Mdot
.23924 .14905 Mdot
.25884 .16473 Mdot
.26276 .16865 Mdot
.25884 .1765 Mdot
.26276 .19218 Mdot
.26276 .20002 Mdot
.251 .20002 Mdot
.26276 .20787 Mdot
.25884 .20002 Mdot
.23531 .18434 Mdot
.22747 .16473 Mdot
.21963 .15297 Mdot
.21179 .14905 Mdot
.20394 .14905 Mdot
.18826 .13728 Mdot
.18042 .12944 Mdot
.19218 .13728 Mdot
.19218 .13336 Mdot
.18042 .11768 Mdot
.18434 .12552 Mdot
.18042 .12944 Mdot
.19218 .14905 Mdot
.18826 .15297 Mdot
.18826 .14905 Mdot
.19218 .16081 Mdot
.18434 .15297 Mdot
.18826 .14513 Mdot
.19218 .13728 Mdot
.20394 .1412 Mdot
.21571 .14513 Mdot
.20787 .1412 Mdot
.19218 .1412 Mdot
.18042 .13336 Mdot
.18042 .13728 Mdot
.19218 .15297 Mdot
.18434 .1412 Mdot
.18434 .13336 Mdot
.18042 .12552 Mdot
.1765 .1216 Mdot
.1765 .1216 Mdot
.18042 .13336 Mdot
.17257 .12552 Mdot
.1765 .13336 Mdot
.17257 .13336 Mdot
.18042 .14513 Mdot
.18042 .13336 Mdot
.1765 .12944 Mdot
.17257 .13336 Mdot
.16473 .1216 Mdot
.16865 .11768 Mdot
.17257 .11376 Mdot
.16865 .11376 Mdot
.16865 .11376 Mdot
.16081 .11768 Mdot
.15297 .1216 Mdot
.1412 .10199 Mdot
.13336 .09807 Mdot
.13336 .10983 Mdot
.12552 .10983 Mdot
.12944 .11768 Mdot
.1216 .10983 Mdot
.1216 .10591 Mdot
.10983 .09023 Mdot
.10591 .08239 Mdot
.10591 .07846 Mdot
.11376 .07454 Mdot
.10591 .06278 Mdot
.13728 .18434 Mdot
.14905 .18826 Mdot
.1412 .16865 Mdot
.13728 .16081 Mdot
.1412 .16081 Mdot
.13728 .15297 Mdot
.12552 .14513 Mdot
.12552 .14513 Mdot
.08239 .09807 Mdot
.06278 .07454 Mdot
.05494 .06278 Mdot
.05886 .05494 Mdot
.0667 .05494 Mdot
.0667 .04709 Mdot
.0667 .03925 Mdot
.05494 .02357 Mdot
.04317 .01572 Mdot
.03925 .01572 Mdot
.05494 .03141 Mdot
.05494 .03141 Mdot
.0667 .05102 Mdot
.05886 .05494 Mdot
.05886 .06278 Mdot
.05102 .05494 Mdot
.02357 .03141 Mdot
.02749 .03141 Mdot
.06278 .06278 Mdot
.08239 .07846 Mdot
.07062 .0667 Mdot
.04709 .03925 Mdot
.03141 .01965 Mdot
.02749 .01572 Mdot
.03141 .01572 Mdot
.03533 .01572 Mdot
.03533 .01572 Mdot
.03533 .0118 Mdot
.03141 .0118 Mdot
.05886 .03533 Mdot
.10199 .06278 Mdot
.13728 .09023 Mdot
.15689 .10983 Mdot
.19218 .14905 Mdot
.22747 .19218 Mdot
.23531 .20002 Mdot
.22747 .1961 Mdot
.21963 .1961 Mdot
.20787 .19218 Mdot
.18826 .1765 Mdot
.17257 .16473 Mdot
.15297 .14905 Mdot
.1412 .13336 Mdot
.13728 .1216 Mdot
.1765 .15297 Mdot
.20394 .16865 Mdot
.22355 .18042 Mdot
.24316 .18826 Mdot
.26276 .20394 Mdot
.27061 .21571 Mdot
.26668 .21963 Mdot
.26276 .22747 Mdot
.26276 .22355 Mdot
.25492 .21571 Mdot
.26668 .21963 Mdot
.27453 .22355 Mdot
.27845 .22355 Mdot
.27453 .22355 Mdot
.29021 .23531 Mdot
.28629 .22747 Mdot
.27845 .21571 Mdot
.27061 .20394 Mdot
.27061 .20394 Mdot
.26668 .1961 Mdot
.26668 .1961 Mdot
.27453 .21179 Mdot
.26668 .21179 Mdot
.27061 .22355 Mdot
.27061 .21963 Mdot
.25884 .20394 Mdot
.251 .18826 Mdot
.26276 .18826 Mdot
.26668 .18826 Mdot
.27061 .19218 Mdot
.25884 .18434 Mdot
.27061 .1961 Mdot
.26276 .20002 Mdot
.26668 .21963 Mdot
.27061 .22355 Mdot
.26276 .21963 Mdot
.26276 .21571 Mdot
.25492 .20787 Mdot
.25492 .1961 Mdot
.26276 .20002 Mdot
.27061 .1961 Mdot
.26668 .18434 Mdot
.27061 .18042 Mdot
.27061 .1765 Mdot
.27453 .1765 Mdot
.251 .17257 Mdot
.24708 .18434 Mdot
.24316 .20394 Mdot
.25492 .21179 Mdot
.24316 .18826 Mdot
.23924 .18042 Mdot
.24316 .1765 Mdot
.23924 .17257 Mdot
.22355 .15689 Mdot
.20787 .14513 Mdot
.18434 .12552 Mdot
.18826 .13728 Mdot
.18042 .12944 Mdot
.18042 .12552 Mdot
.18826 .12552 Mdot
.18826 .12944 Mdot
.18434 .13336 Mdot
.18826 .15297 Mdot
.1961 .16081 Mdot
.18042 .14905 Mdot
.18434 .15689 Mdot
.18826 .16081 Mdot
.18826 .15297 Mdot
.18042 .1412 Mdot
.18434 .13728 Mdot
.20787 .14513 Mdot
.21179 .14513 Mdot
.20787 .14513 Mdot
.20002 .14513 Mdot
.19218 .14905 Mdot
.19218 .14905 Mdot
.19218 .14513 Mdot
.20002 .15297 Mdot
.1961 .14905 Mdot
.18826 .1412 Mdot
.17257 .12552 Mdot
.16473 .12944 Mdot
.16473 .13728 Mdot
.15689 .12944 Mdot
.16473 .13336 Mdot
.1765 .13728 Mdot
.1765 .13728 Mdot
.17257 .12552 Mdot
.17257 .1216 Mdot
.16865 .11376 Mdot
.17257 .10983 Mdot
.17257 .10591 Mdot
.1765 .10591 Mdot
.15689 .09415 Mdot
.16081 .10591 Mdot
.15689 .11768 Mdot
.1412 .10591 Mdot
.14513 .10983 Mdot
.13336 .10983 Mdot
.1216 .10591 Mdot
.13728 .11768 Mdot
.12944 .10983 Mdot
.12552 .10983 Mdot
.11768 .09807 Mdot
.1216 .07846 Mdot
.11768 .07062 Mdot
.11768 .0667 Mdot
.10591 .05102 Mdot
.16081 .1961 Mdot
.16865 .20787 Mdot
.15297 .18042 Mdot
.1412 .16865 Mdot
.14513 .16081 Mdot
.15689 .16865 Mdot
.15297 .1765 Mdot
.1412 .1765 Mdot
.13728 .16473 Mdot
.11768 .14513 Mdot
.09415 .11376 Mdot
.07846 .09023 Mdot
.08631 .07454 Mdot
.07062 .04709 Mdot
.05102 .01965 Mdot
.04709 .00788 Mdot
.04317 .0118 Mdot
.04709 .01965 Mdot
.05886 .02749 Mdot
.06278 .03141 Mdot
.05886 .03533 Mdot
.05494 .04317 Mdot
.05102 .04709 Mdot
.05886 .05494 Mdot
.05102 .04709 Mdot
.06278 .04709 Mdot
.08239 .07062 Mdot
.08631 .0667 Mdot
.07062 .05102 Mdot
.06278 .04317 Mdot
.04709 .01572 Mdot
.02357 .00396 Mdot
.02749 .00396 Mdot
.03141 .00788 Mdot
.03533 .01572 Mdot
.03533 .01572 Mdot
.03533 .01965 Mdot
.03925 .03533 Mdot
.06278 .05886 Mdot
.07846 .07454 Mdot
.09807 .09023 Mdot
.09807 .09023 Mdot
.18434 .16473 Mdot
.24708 .21963 Mdot
.26276 .22747 Mdot
.25884 .22355 Mdot
.251 .22355 Mdot
.20787 .18826 Mdot
.1765 .15689 Mdot
.1412 .12552 Mdot
.10983 .09807 Mdot
.09023 .08631 Mdot
.10199 .09415 Mdot
.14513 .12944 Mdot
.18042 .15689 Mdot
.21179 .18042 Mdot
.24316 .20002 Mdot
.26668 .21179 Mdot
.26276 .20394 Mdot
.251 .20394 Mdot
.25492 .21179 Mdot
.251 .20787 Mdot
.25884 .21179 Mdot
.26668 .21963 Mdot
.27453 .23139 Mdot
.28237 .23924 Mdot
.28237 .23924 Mdot
.27845 .22355 Mdot
.27453 .21571 Mdot
.26668 .20787 Mdot
.27453 .21571 Mdot
.27453 .20394 Mdot
.28237 .20002 Mdot
.27453 .20394 Mdot
.28237 .21179 Mdot
.27845 .21963 Mdot
.27061 .21179 Mdot
.26668 .21571 Mdot
.26668 .21179 Mdot
.26276 .20394 Mdot
.25884 .1961 Mdot
.25884 .1961 Mdot
.26276 .20394 Mdot
.27845 .20787 Mdot
.27453 .21571 Mdot
.27453 .22355 Mdot
.27453 .22355 Mdot
.27845 .22747 Mdot
.28237 .23924 Mdot
.28237 .23139 Mdot
.27845 .22747 Mdot
.27061 .21571 Mdot
.27061 .21571 Mdot
.27453 .21179 Mdot
.27453 .20002 Mdot
.26668 .18826 Mdot
.27061 .19218 Mdot
.25492 .1765 Mdot
.24316 .1765 Mdot
.23924 .18826 Mdot
.23139 .19218 Mdot
.23924 .20394 Mdot
.23924 .19218 Mdot
.24708 .1961 Mdot
.23531 .18434 Mdot
.22747 .1765 Mdot
.23531 .18434 Mdot
.21963 .17257 Mdot
.20787 .16081 Mdot
.18826 .1412 Mdot
.18434 .13336 Mdot
.1961 .1412 Mdot
.19218 .13336 Mdot
.18826 .13728 Mdot
.18826 .1412 Mdot
.20394 .15689 Mdot
.18434 .14905 Mdot
.18826 .15297 Mdot
.1961 .15297 Mdot
.1961 .15297 Mdot
.19218 .14513 Mdot
.18042 .12944 Mdot
.18826 .13336 Mdot
.1961 .1412 Mdot
.20787 .14905 Mdot
.21179 .15689 Mdot
.20787 .16081 Mdot
.18434 .1412 Mdot
.18042 .13728 Mdot
.18042 .13728 Mdot
.1961 .14905 Mdot
.1961 .14905 Mdot
.20002 .14905 Mdot
.18434 .13728 Mdot
.18042 .13728 Mdot
.1765 .13336 Mdot
.16865 .12944 Mdot
.17257 .14513 Mdot
.18042 .1412 Mdot
.18042 .13336 Mdot
.17257 .1216 Mdot
.16473 .11376 Mdot
.18042 .12944 Mdot
.17257 .11768 Mdot
.16865 .10983 Mdot
.17257 .10983 Mdot
.1765 .1216 Mdot
.16473 .1216 Mdot
.15297 .12552 Mdot
.14513 .1216 Mdot
.13728 .11376 Mdot
.12944 .10591 Mdot
.13336 .11376 Mdot
.12944 .10199 Mdot
.12552 .09023 Mdot
.11768 .08239 Mdot
.12552 .08239 Mdot
.12552 .07846 Mdot
.12944 .07454 Mdot
.11768 .0667 Mdot
.16473 .17257 Mdot
.16865 .18826 Mdot
.16473 .18434 Mdot
.15689 .16865 Mdot
.14905 .15689 Mdot
.14905 .15689 Mdot
.15297 .16865 Mdot
.15689 .18826 Mdot
.15297 .19218 Mdot
.14905 .18826 Mdot
.14513 .1765 Mdot
.13336 .15297 Mdot
.11768 .1216 Mdot
.08239 .07062 Mdot
.05886 .04317 Mdot
.05102 .03141 Mdot
.0667 .03925 Mdot
.05494 .03533 Mdot
.05494 .03925 Mdot
.06278 .05102 Mdot
.06278 .04709 Mdot
.02749 .01965 Mdot
.01965 .02357 Mdot
.02357 .02749 Mdot
.02749 .02357 Mdot
.05886 .03925 Mdot
.08239 .05102 Mdot
.09807 .06278 Mdot
.09023 .05494 Mdot
.0667 .03925 Mdot
.05102 .01572 Mdot
.03925 .00396 Mdot
.04317 .0118 Mdot
.03141 .0118 Mdot
.05102 .02749 Mdot
.05102 .03925 Mdot
.04709 .03533 Mdot
.03925 .03533 Mdot
.03925 .04317 Mdot
.05886 .06278 Mdot
.07062 .07454 Mdot
.07846 .07846 Mdot
.09807 .08631 Mdot
.1412 .12552 Mdot
.20002 .17257 Mdot
.23531 .20394 Mdot
.27453 .23531 Mdot
.20394 .1765 Mdot
.16081 .13728 Mdot
.12944 .10199 Mdot
.10591 .07846 Mdot
.09807 .07454 Mdot
.09023 .07062 Mdot
.09415 .08239 Mdot
.13728 .1216 Mdot
.1765 .15689 Mdot
.20394 .17257 Mdot
.23139 .18826 Mdot
.23531 .18826 Mdot
.24316 .18826 Mdot
.25492 .1961 Mdot
.251 .20002 Mdot
.251 .20394 Mdot
.25492 .21571 Mdot
.25884 .21571 Mdot
.26276 .22355 Mdot
.26276 .22355 Mdot
.25492 .21571 Mdot
.25884 .21571 Mdot
.25884 .21179 Mdot
.26668 .20787 Mdot
.26668 .1961 Mdot
.26668 .18434 Mdot
.27453 .18826 Mdot
.27845 .19218 Mdot
.27453 .1961 Mdot
.27061 .20394 Mdot
.25492 .20002 Mdot
.25492 .20002 Mdot
.25492 .20002 Mdot
.25492 .20002 Mdot
.251 .1961 Mdot
.25884 .20394 Mdot
.26668 .21571 Mdot
.27453 .21963 Mdot
.27453 .21571 Mdot
.27061 .21571 Mdot
.27845 .23139 Mdot
.27453 .23139 Mdot
.28237 .23924 Mdot
.27453 .22747 Mdot
.25492 .20394 Mdot
.26276 .20787 Mdot
.25884 .1961 Mdot
.26668 .1961 Mdot
.25884 .18434 Mdot
.25884 .1765 Mdot
.25884 .1765 Mdot
.24316 .17257 Mdot
.23139 .16865 Mdot
.22747 .18042 Mdot
.22355 .18826 Mdot
.23139 .1961 Mdot
.23531 .1961 Mdot
.22747 .20002 Mdot
.22747 .19218 Mdot
.22355 .18434 Mdot
.21963 .16865 Mdot
.21571 .16081 Mdot
.20002 .13728 Mdot
.1961 .13336 Mdot
.20394 .13336 Mdot
.18434 .12552 Mdot
.18042 .12944 Mdot
.1765 .13728 Mdot
.18434 .14905 Mdot
.18826 .14513 Mdot
.18826 .14905 Mdot
.18826 .13336 Mdot
.18434 .12944 Mdot
.18826 .12552 Mdot
.18826 .12552 Mdot
.18042 .1216 Mdot
.18826 .12944 Mdot
.19218 .13336 Mdot
.20394 .1412 Mdot
.19218 .1412 Mdot
.19218 .14513 Mdot
.18826 .13728 Mdot
.18434 .12944 Mdot
.18434 .1216 Mdot
.1961 .13728 Mdot
.21179 .14905 Mdot
.20002 .13728 Mdot
.19218 .1412 Mdot
.18434 .13336 Mdot
.17257 .12552 Mdot
.16081 .11768 Mdot
.15689 .10983 Mdot
.16865 .11376 Mdot
.16473 .10591 Mdot
.16865 .10983 Mdot
.16473 .11376 Mdot
.17257 .12944 Mdot
.1765 .12944 Mdot
.17257 .12552 Mdot
.16865 .12944 Mdot
.16081 .12552 Mdot
.14905 .1216 Mdot
.1412 .11768 Mdot
.13336 .10983 Mdot
.12944 .10199 Mdot
.12552 .09023 Mdot
.1216 .08631 Mdot
.12552 .08631 Mdot
.11376 .07454 Mdot
.1216 .07846 Mdot
.13336 .08631 Mdot
.12552 .08631 Mdot
.10983 .07846 Mdot
.1412 .15297 Mdot
.16473 .16081 Mdot
.18042 .16865 Mdot
.18434 .16865 Mdot
.18434 .17257 Mdot
.17257 .16865 Mdot
.18434 .18434 Mdot
.17257 .18826 Mdot
.16473 .1961 Mdot
.18042 .21571 Mdot
.18434 .21571 Mdot
.18826 .21179 Mdot
.15297 .16865 Mdot
.09807 .10983 Mdot
.09023 .08631 Mdot
.07846 .07062 Mdot
.07454 .0667 Mdot
.07062 .07062 Mdot
.05886 .07062 Mdot
.05102 .0667 Mdot
.03925 .05886 Mdot
.02357 .04317 Mdot
.01965 .03141 Mdot
.02357 .02749 Mdot
.01572 .0118 Mdot
.03925 .01572 Mdot
.09023 .05102 Mdot
.10983 .06278 Mdot
.09023 .04709 Mdot
.0667 .03141 Mdot
.05102 .01965 Mdot
.03925 .0118 Mdot
.04317 .02357 Mdot
.04317 .02749 Mdot
.05886 .04317 Mdot
.07062 .04317 Mdot
.05886 .03925 Mdot
.06278 .04709 Mdot
.05102 .03925 Mdot
.05886 .05102 Mdot
.09023 .07454 Mdot
.10199 .08239 Mdot
.08631 .07454 Mdot
.09415 .08239 Mdot
.10591 .09023 Mdot
.13336 .10983 Mdot
.16865 .1412 Mdot
.15689 .13728 Mdot
.1216 .10591 Mdot
.09415 .07454 Mdot
.05886 .03533 Mdot
.09807 .07846 Mdot
.1216 .10199 Mdot
.13728 .11376 Mdot
.14513 .1216 Mdot
.14905 .12552 Mdot
.16473 .12944 Mdot
.1765 .1412 Mdot
.1961 .15689 Mdot
.21179 .16865 Mdot
.23924 .18826 Mdot
.25884 .20394 Mdot
.26668 .21571 Mdot
.25884 .21963 Mdot
.25884 .21963 Mdot
.26668 .22747 Mdot
.26668 .22355 Mdot
.26668 .21963 Mdot
.27453 .21963 Mdot
.28629 .22355 Mdot
.28237 .21963 Mdot
.28237 .21179 Mdot
.28237 .21179 Mdot
.28237 .20394 Mdot
.27453 .20394 Mdot
.26668 .20002 Mdot
.26276 .19218 Mdot
.27061 .21179 Mdot
.26668 .21571 Mdot
.26668 .21179 Mdot
.25884 .20787 Mdot
.25884 .20394 Mdot
.25492 .20002 Mdot
.26276 .20787 Mdot
.27453 .22355 Mdot
.27845 .22355 Mdot
.28629 .22747 Mdot
.28629 .22747 Mdot
.29021 .23531 Mdot
.29806 .24316 Mdot
.29806 .24316 Mdot
.29021 .23531 Mdot
.27453 .21963 Mdot
.27845 .21571 Mdot
.26668 .1961 Mdot
.26276 .19218 Mdot
.27061 .20002 Mdot
.27061 .20787 Mdot
.25884 .1961 Mdot
.25884 .20002 Mdot
.251 .1961 Mdot
.23924 .1961 Mdot
.24708 .20394 Mdot
.251 .20787 Mdot
.251 .20787 Mdot
.24316 .1961 Mdot
.23531 .18826 Mdot
.22355 .18042 Mdot
.23924 .18434 Mdot
.21571 .15689 Mdot
.21963 .15297 Mdot
.20787 .1412 Mdot
.1961 .12552 Mdot
.1961 .13336 Mdot
.18826 .13728 Mdot
.18434 .14513 Mdot
.20002 .15297 Mdot
.19218 .14905 Mdot
.1961 .14905 Mdot
.1961 .13728 Mdot
.1961 .13336 Mdot
.1961 .1412 Mdot
.20002 .1412 Mdot
.21179 .14905 Mdot
.21571 .14905 Mdot
.21963 .16081 Mdot
.21179 .16081 Mdot
.20787 .15689 Mdot
.18826 .1412 Mdot
.19218 .13728 Mdot
.19218 .12944 Mdot
.20394 .13336 Mdot
.22355 .14905 Mdot
.21963 .14905 Mdot
.21571 .15689 Mdot
.20002 .1412 Mdot
.18042 .12552 Mdot
.16865 .1216 Mdot
.16865 .11768 Mdot
.16865 .11768 Mdot
.17257 .11768 Mdot
.18042 .1216 Mdot
.16865 .11768 Mdot
.17257 .1216 Mdot
.17257 .12552 Mdot
.1765 .13336 Mdot
.18042 .13728 Mdot
.15689 .11768 Mdot
.14513 .10591 Mdot
.15689 .11768 Mdot
.15689 .12944 Mdot
.14513 .11376 Mdot
.1412 .10983 Mdot
.1412 .10983 Mdot
.13336 .10199 Mdot
.13336 .09415 Mdot
.13336 .09023 Mdot
.12552 .09023 Mdot
.12552 .09415 Mdot
.12944 .09415 Mdot
.09415 .1216 Mdot
.11768 .11376 Mdot
.1412 .1216 Mdot
.16081 .13728 Mdot
.16865 .14905 Mdot
.1765 .16081 Mdot
.18434 .18042 Mdot
.18434 .18826 Mdot
.18826 .20394 Mdot
.18434 .21571 Mdot
.19218 .23139 Mdot
.21571 .24708 Mdot
.18826 .21179 Mdot
.13336 .15297 Mdot
.1216 .13728 Mdot
.11768 .13336 Mdot
.09023 .11376 Mdot
.0667 .10199 Mdot
.05494 .09807 Mdot
.05102 .09415 Mdot
.02357 .0667 Mdot
.01965 .05886 Mdot
.01572 .03925 Mdot
.00788 .01965 Mdot
.0118 .0118 Mdot
.02357 .00788 Mdot
.07062 .03533 Mdot
.10199 .0667 Mdot
.09807 .06278 Mdot
.08631 .05102 Mdot
.0667 .03925 Mdot
.05102 .02749 Mdot
.04709 .03533 Mdot
.05886 .05494 Mdot
.08239 .07846 Mdot
.09415 .08239 Mdot
.08631 .08239 Mdot
.06278 .0667 Mdot
.05102 .05494 Mdot
.06278 .07454 Mdot
.07846 .07846 Mdot
.09415 .09023 Mdot
.07846 .07454 Mdot
.07454 .07062 Mdot
.08239 .07454 Mdot
.08239 .07454 Mdot
.09807 .08239 Mdot
.10983 .09023 Mdot
.08631 .0667 Mdot
.07062 .04709 Mdot
.06278 .03141 Mdot
.05102 .01965 Mdot
.10983 .0667 Mdot
.14513 .10983 Mdot
.14513 .1216 Mdot
.11376 .10199 Mdot
.10591 .09415 Mdot
.10199 .08631 Mdot
.11768 .09415 Mdot
.14513 .11376 Mdot
.18042 .1412 Mdot
.21179 .16865 Mdot
.23139 .18826 Mdot
.24708 .20002 Mdot
.25492 .20394 Mdot
.25884 .20002 Mdot
.26668 .20394 Mdot
.27061 .21179 Mdot
.27061 .20787 Mdot
.28629 .22355 Mdot
.28237 .21963 Mdot
.27845 .21963 Mdot
.28629 .22355 Mdot
.28629 .22355 Mdot
.28237 .21963 Mdot
.27845 .21571 Mdot
.27061 .21179 Mdot
.26668 .21179 Mdot
.26668 .21179 Mdot
.27845 .21963 Mdot
.26668 .21179 Mdot
.27061 .21179 Mdot
.25884 .20394 Mdot
.25884 .21179 Mdot
.26668 .21571 Mdot
.27453 .22355 Mdot
.28237 .22355 Mdot
.28629 .22747 Mdot
.29413 .22747 Mdot
.29413 .22355 Mdot
.30198 .23139 Mdot
.32943 .25884 Mdot
.32158 .25884 Mdot
.30198 .23924 Mdot
.29021 .22747 Mdot
.28629 .22355 Mdot
.27845 .21963 Mdot
.27061 .21963 Mdot
.27061 .21571 Mdot
.27061 .20787 Mdot
.27061 .20787 Mdot
.26276 .1961 Mdot
.26276 .1961 Mdot
.26276 .20002 Mdot
.25884 .20002 Mdot
.25492 .20002 Mdot
.24708 .19218 Mdot
.23924 .18826 Mdot
.23924 .1961 Mdot
.23139 .18434 Mdot
.22355 .17257 Mdot
.21571 .15297 Mdot
.20787 .13336 Mdot
.1961 .13336 Mdot
.19218 .1216 Mdot
.1961 .12944 Mdot
.20002 .14513 Mdot
.20394 .14513 Mdot
.21571 .15297 Mdot
.21179 .16081 Mdot
.20787 .16081 Mdot
.20002 .15689 Mdot
.20394 .14905 Mdot
.21179 .15689 Mdot
.20787 .15297 Mdot
.21963 .16473 Mdot
.21571 .16473 Mdot
.21571 .16865 Mdot
.20787 .16865 Mdot
.20394 .15297 Mdot
.20002 .13336 Mdot
.18042 .11376 Mdot
.18826 .11768 Mdot
.20002 .12552 Mdot
.20002 .12944 Mdot
.20394 .13336 Mdot
.19218 .12552 Mdot
.1765 .11376 Mdot
.17257 .10591 Mdot
.16473 .10199 Mdot
.15689 .09807 Mdot
.16081 .10199 Mdot
.16081 .10983 Mdot
.16865 .1216 Mdot
.18042 .12944 Mdot
.17257 .13336 Mdot
.16473 .12944 Mdot
.17257 .12944 Mdot
.15689 .11376 Mdot
.13728 .10591 Mdot
.14905 .11376 Mdot
.14513 .10591 Mdot
.14513 .10983 Mdot
.1412 .10983 Mdot
.13336 .11376 Mdot
.12944 .11376 Mdot
.13336 .10983 Mdot
.1412 .11376 Mdot
.12944 .10199 Mdot
.13728 .09807 Mdot
.10591 .13336 Mdot
.10591 .11376 Mdot
.09415 .09023 Mdot
.10591 .09023 Mdot
.1216 .11376 Mdot
.14905 .13336 Mdot
.18042 .16865 Mdot
.18826 .18434 Mdot
.1961 .20394 Mdot
.19218 .21179 Mdot
.18042 .21571 Mdot
.18434 .22355 Mdot
.19218 .22355 Mdot
.18042 .20787 Mdot
.15689 .18042 Mdot
.15297 .18434 Mdot
.13336 .18042 Mdot
.12944 .18042 Mdot
.12552 .18042 Mdot
.10591 .16081 Mdot
.08239 .12944 Mdot
.05494 .09807 Mdot
.03533 .07454 Mdot
.02357 .05102 Mdot
.01965 .03533 Mdot
.01965 .01965 Mdot
.0667 .05494 Mdot
.09415 .0667 Mdot
.09023 .06278 Mdot
.08239 .05494 Mdot
.07454 .05102 Mdot
.07846 .05886 Mdot
.07454 .0667 Mdot
.08239 .07454 Mdot
.09807 .09415 Mdot
.11768 .11768 Mdot
.12552 .13728 Mdot
.1216 .12944 Mdot
.09415 .10591 Mdot
.09023 .10983 Mdot
.09807 .10983 Mdot
.07846 .10199 Mdot
.0667 .08239 Mdot
.05886 .0667 Mdot
.05886 .06278 Mdot
.05494 .05494 Mdot
.05886 .04709 Mdot
.07846 .05886 Mdot
.0667 .04317 Mdot
.05886 .03141 Mdot
.05102 .01965 Mdot
.04317 .0118 Mdot
.14513 .09807 Mdot
.18434 .13336 Mdot
.1765 .13728 Mdot
.10591 .08631 Mdot
.09415 .07846 Mdot
.07454 .05494 Mdot
.07454 .05494 Mdot
.07846 .05494 Mdot
.09807 .07062 Mdot
.11768 .08631 Mdot
.14905 .10983 Mdot
.18042 .13336 Mdot
.20394 .14905 Mdot
.23139 .16865 Mdot
.25492 .18826 Mdot
.26668 .20002 Mdot
.27845 .20787 Mdot
.28237 .21963 Mdot
.28629 .22355 Mdot
.28629 .22747 Mdot
.29021 .22747 Mdot
.27845 .20787 Mdot
.27453 .20787 Mdot
.27845 .22355 Mdot
.28237 .22355 Mdot
.27453 .21963 Mdot
.27453 .22355 Mdot
.27061 .21571 Mdot
.27453 .21963 Mdot
.27845 .21963 Mdot
.28237 .22355 Mdot
.28629 .21963 Mdot
.28629 .22355 Mdot
.28629 .23139 Mdot
.28629 .23139 Mdot
.27845 .22355 Mdot
.28629 .23139 Mdot
.29413 .23139 Mdot
.30198 .23924 Mdot
.31374 .23924 Mdot
.31766 .23531 Mdot
.30982 .23139 Mdot
.29806 .23531 Mdot
.29806 .23531 Mdot
.28629 .22747 Mdot
.27061 .22747 Mdot
.27453 .22355 Mdot
.25884 .20394 Mdot
.26276 .20002 Mdot
.251 .18042 Mdot
.25492 .18826 Mdot
.26276 .19218 Mdot
.26276 .20002 Mdot
.26668 .21179 Mdot
.26276 .21179 Mdot
.251 .20394 Mdot
.24708 .20394 Mdot
.23531 .19218 Mdot
.21963 .1765 Mdot
.21571 .15689 Mdot
.20787 .13336 Mdot
.20002 .1216 Mdot
.20002 .12552 Mdot
.19218 .12552 Mdot
.1961 .13336 Mdot
.20394 .14513 Mdot
.21963 .15297 Mdot
.20002 .14513 Mdot
.20394 .15297 Mdot
.1961 .14513 Mdot
.21179 .16081 Mdot
.21179 .16473 Mdot
.21963 .17257 Mdot
.21963 .18042 Mdot
.21963 .18042 Mdot
.20787 .16473 Mdot
.21571 .16473 Mdot
.21571 .16473 Mdot
.21179 .15297 Mdot
.19218 .13728 Mdot
.1765 .11768 Mdot
.17257 .10983 Mdot
.1765 .10983 Mdot
.1765 .10983 Mdot
.19218 .1216 Mdot
.18042 .10983 Mdot
.16865 .09807 Mdot
.16473 .09023 Mdot
.17257 .10591 Mdot
.1765 .1216 Mdot
.16473 .11768 Mdot
.16865 .12944 Mdot
.16473 .13336 Mdot
.16081 .12552 Mdot
.16865 .12552 Mdot
.16473 .12552 Mdot
.16081 .12552 Mdot
.14905 .10983 Mdot
.13728 .09807 Mdot
.12944 .08631 Mdot
.12552 .08631 Mdot
.1412 .09807 Mdot
.1412 .10199 Mdot
.12552 .09807 Mdot
.1216 .09415 Mdot
.13336 .10983 Mdot
.12552 .09807 Mdot
.12552 .09023 Mdot
.12552 .1412 Mdot
.10983 .12552 Mdot
.09807 .10591 Mdot
.09023 .08631 Mdot
.09023 .08239 Mdot
.11376 .09415 Mdot
.12944 .09807 Mdot
.1412 .1216 Mdot
.16473 .15297 Mdot
.1765 .18434 Mdot
.18434 .20002 Mdot
.18826 .21571 Mdot
.21179 .23139 Mdot
.18042 .20394 Mdot
.16865 .19218 Mdot
.17257 .20002 Mdot
.18042 .21179 Mdot
.18826 .21571 Mdot
.18826 .22355 Mdot
.18826 .23139 Mdot
.17257 .21571 Mdot
.14513 .1961 Mdot
.11768 .16473 Mdot
.0667 .11376 Mdot
.04317 .08239 Mdot
.03141 .05494 Mdot
.05102 .05886 Mdot
.07846 .0667 Mdot
.08631 .07062 Mdot
.07846 .0667 Mdot
.07846 .05102 Mdot
.07454 .05494 Mdot
.07846 .05494 Mdot
.09415 .07062 Mdot
.11768 .10199 Mdot
.11376 .10983 Mdot
.13336 .1412 Mdot
.13728 .15297 Mdot
.14513 .15689 Mdot
.1412 .15297 Mdot
.15297 .15689 Mdot
.10199 .11376 Mdot
.07454 .09023 Mdot
.05494 .07062 Mdot
.05494 .06278 Mdot
.05494 .05886 Mdot
.06278 .06278 Mdot
.07062 .0667 Mdot
.0667 .06278 Mdot
.05886 .05102 Mdot
.05494 .04317 Mdot
.04709 .02749 Mdot
.09807 .0667 Mdot
.11376 .07846 Mdot
.12552 .08239 Mdot
.11768 .08239 Mdot
.10983 .07454 Mdot
.09023 .06278 Mdot
.07846 .04709 Mdot
.07846 .05102 Mdot
.08239 .05494 Mdot
.07846 .05102 Mdot
.07846 .05102 Mdot
.09807 .0667 Mdot
.13336 .08631 Mdot
.16865 .11376 Mdot
.21179 .14513 Mdot
.251 .1765 Mdot
.26276 .19218 Mdot
.27453 .20394 Mdot
.27845 .21179 Mdot
.28629 .21179 Mdot
.28629 .20394 Mdot
.28629 .21963 Mdot
.28237 .21963 Mdot
.28629 .22747 Mdot
.29413 .23531 Mdot
.28629 .23139 Mdot
.28629 .23531 Mdot
.28237 .23139 Mdot
.27453 .22355 Mdot
.27061 .21571 Mdot
.27453 .21179 Mdot
.29806 .22747 Mdot
.29413 .23139 Mdot
.29021 .23924 Mdot
.28629 .23139 Mdot
.28629 .22747 Mdot
.28629 .22355 Mdot
.29021 .23139 Mdot
.29021 .22747 Mdot
.30982 .23531 Mdot
.30198 .22355 Mdot
.3059 .22747 Mdot
.30982 .23924 Mdot
.30198 .23531 Mdot
.29806 .23139 Mdot
.27845 .21963 Mdot
.27453 .21963 Mdot
.26668 .20787 Mdot
.27845 .21179 Mdot
.28237 .21963 Mdot
.27061 .21179 Mdot
.26668 .20394 Mdot
.26668 .20787 Mdot
.26668 .21571 Mdot
.26668 .21179 Mdot
.25492 .20787 Mdot
.25492 .20787 Mdot
.23531 .19218 Mdot
.23139 .18042 Mdot
.23531 .16865 Mdot
.21963 .14905 Mdot
.20394 .12552 Mdot
.20394 .12552 Mdot
.20787 .12944 Mdot
.20394 .13336 Mdot
.20787 .13728 Mdot
.21571 .1412 Mdot
.21179 .1412 Mdot
.20787 .14513 Mdot
.21179 .14905 Mdot
.20787 .15297 Mdot
.20394 .15297 Mdot
.21571 .16865 Mdot
.21571 .16473 Mdot
.21571 .16865 Mdot
.21179 .16081 Mdot
.21179 .16081 Mdot
.21571 .16081 Mdot
.20787 .15689 Mdot
.1961 .14905 Mdot
.19218 .1412 Mdot
.18434 .12944 Mdot
.18042 .12552 Mdot
.16865 .11768 Mdot
.1765 .11768 Mdot
.18826 .12552 Mdot
.1765 .1216 Mdot
.16865 .11376 Mdot
.16473 .11768 Mdot
.1765 .13336 Mdot
.17257 .13336 Mdot
.16081 .12944 Mdot
.16081 .12944 Mdot
.16473 .12944 Mdot
.15689 .1216 Mdot
.16081 .11768 Mdot
.15689 .10983 Mdot
.13728 .09023 Mdot
.14513 .09415 Mdot
.14513 .09415 Mdot
.13728 .09023 Mdot
.1412 .09415 Mdot
.1412 .09415 Mdot
.12552 .09023 Mdot
.12552 .09415 Mdot
.1412 .10199 Mdot
.13728 .10199 Mdot
.1216 .09023 Mdot
.11376 .12944 Mdot
.1216 .12944 Mdot
.10983 .11768 Mdot
.09415 .09807 Mdot
.09807 .09023 Mdot
.10591 .08631 Mdot
.10591 .08239 Mdot
.10983 .09415 Mdot
.10983 .09807 Mdot
.1216 .11376 Mdot
.13728 .13336 Mdot
.15297 .16473 Mdot
.18434 .1961 Mdot
.19218 .20002 Mdot
.18826 .19218 Mdot
.18434 .20002 Mdot
.1765 .1961 Mdot
.18042 .20394 Mdot
.1961 .22355 Mdot
.1961 .23531 Mdot
.20394 .251 Mdot
.1961 .251 Mdot
.18042 .23531 Mdot
.15297 .20787 Mdot
.11376 .16473 Mdot
.09415 .12944 Mdot
.07846 .10591 Mdot
.08631 .09023 Mdot
.09807 .09023 Mdot
.08631 .07454 Mdot
.07846 .06278 Mdot
.07846 .05886 Mdot
.09023 .06278 Mdot
.10199 .07846 Mdot
.09023 .07062 Mdot
.07846 .07062 Mdot
.09415 .08631 Mdot
.11768 .11768 Mdot
.15689 .15297 Mdot
.17257 .16473 Mdot
.18434 .1765 Mdot
.17257 .17257 Mdot
.10983 .11376 Mdot
.09415 .09415 Mdot
.08239 .08239 Mdot
.0667 .0667 Mdot
.05886 .0667 Mdot
.06278 .07454 Mdot
.0667 .07454 Mdot
.07454 .08239 Mdot
.06278 .07062 Mdot
.06278 .06278 Mdot
.07062 .05886 Mdot
.09023 .05886 Mdot
.09415 .05102 Mdot
.09415 .04709 Mdot
.09415 .04709 Mdot
.08631 .04317 Mdot
.07846 .03533 Mdot
.07846 .03533 Mdot
.07454 .03533 Mdot
.0667 .03141 Mdot
.0667 .03141 Mdot
.07062 .03533 Mdot
.09807 .05494 Mdot
.09807 .03925 Mdot
.13728 .07454 Mdot
.20394 .12944 Mdot
.23924 .16081 Mdot
.26668 .18826 Mdot
.28237 .20002 Mdot
.29413 .21179 Mdot
.29021 .21571 Mdot
.28237 .22355 Mdot
.28237 .21963 Mdot
.27845 .22355 Mdot
.29021 .23139 Mdot
.29021 .23531 Mdot
.29021 .24316 Mdot
.28629 .24316 Mdot
.28237 .23924 Mdot
.27453 .22747 Mdot
.27845 .22747 Mdot
.27845 .23139 Mdot
.28629 .24708 Mdot
.28629 .24316 Mdot
.27845 .22747 Mdot
.27845 .21963 Mdot
.28237 .21963 Mdot
.29021 .21963 Mdot
.29413 .22355 Mdot
.29806 .21963 Mdot
.30198 .22747 Mdot
.29806 .22747 Mdot
.29413 .23924 Mdot
.29413 .24316 Mdot
.29021 .24316 Mdot
.27845 .23139 Mdot
.26668 .21571 Mdot
.26668 .21179 Mdot
.27061 .21179 Mdot
.27061 .21571 Mdot
.26668 .21179 Mdot
.26668 .21179 Mdot
.27453 .21963 Mdot
.27845 .21963 Mdot
.27061 .21571 Mdot
.27061 .21571 Mdot
.26668 .21179 Mdot
.24708 .20002 Mdot
.23924 .19218 Mdot
.23139 .18042 Mdot
.23139 .16865 Mdot
.21179 .15297 Mdot
.22355 .14905 Mdot
.22355 .1412 Mdot
.21963 .13728 Mdot
.21571 .1412 Mdot
.21963 .14513 Mdot
.22747 .15297 Mdot
.22747 .15689 Mdot
.22355 .16081 Mdot
.21571 .16081 Mdot
.20002 .15297 Mdot
.20002 .14905 Mdot
.18826 .1412 Mdot
.20002 .15297 Mdot
.21179 .16081 Mdot
.21179 .15689 Mdot
.20787 .15689 Mdot
.1961 .14513 Mdot
.20787 .15297 Mdot
.20787 .14513 Mdot
.20787 .14513 Mdot
.20394 .1412 Mdot
.20787 .1412 Mdot
.18434 .1216 Mdot
.18826 .11768 Mdot
.18434 .12944 Mdot
.18434 .13728 Mdot
.18042 .13336 Mdot
.18042 .1412 Mdot
.18042 .14905 Mdot
.1765 .14513 Mdot
.17257 .13336 Mdot
.16865 .1216 Mdot
.15297 .10199 Mdot
.15297 .09415 Mdot
.16473 .10591 Mdot
.15297 .09807 Mdot
.14905 .10199 Mdot
.14905 .10199 Mdot
.14513 .09807 Mdot
.14905 .10199 Mdot
.13728 .09023 Mdot
.13336 .09023 Mdot
.12944 .08239 Mdot
.1216 .07454 Mdot
.13336 .09415 Mdot
.12944 .09415 Mdot
.07454 .09023 Mdot
.15689 .15297 Mdot
.12944 .13728 Mdot
.11376 .1216 Mdot
.09807 .10983 Mdot
.09415 .10199 Mdot
.09415 .09415 Mdot
.09807 .09415 Mdot
.08631 .08239 Mdot
.07846 .07062 Mdot
.07454 .07454 Mdot
.09023 .08631 Mdot
.12552 .1216 Mdot
.14905 .13728 Mdot
.16865 .15297 Mdot
.20002 .18826 Mdot
.19218 .18826 Mdot
.19218 .18826 Mdot
.18434 .19218 Mdot
.18826 .21179 Mdot
.1961 .23531 Mdot
.20394 .251 Mdot
.20394 .251 Mdot
.1961 .24316 Mdot
.18434 .23139 Mdot
.15689 .20394 Mdot
.13336 .16865 Mdot
.12552 .1412 Mdot
.10983 .11768 Mdot
.08631 .09023 Mdot
.09023 .09023 Mdot
.09023 .08239 Mdot
.09023 .07846 Mdot
.09807 .08239 Mdot
.08239 .0667 Mdot
.05886 .04709 Mdot
.05886 .05102 Mdot
.07062 .06278 Mdot
.1216 .10591 Mdot
.15297 .12552 Mdot
.1765 .14905 Mdot
.18826 .16473 Mdot
.18826 .16865 Mdot
.17257 .16473 Mdot
.14905 .15297 Mdot
.11768 .13336 Mdot
.09023 .1216 Mdot
.08239 .11376 Mdot
.0667 .09807 Mdot
.0667 .09023 Mdot
.09023 .10199 Mdot
.10591 .10591 Mdot
.10199 .09415 Mdot
.10199 .07846 Mdot
.09415 .05494 Mdot
.10199 .05494 Mdot
.09023 .04709 Mdot
.07846 .03533 Mdot
.07454 .03533 Mdot
.05886 .02357 Mdot
.05886 .01965 Mdot
.0667 .01965 Mdot
.07062 .02357 Mdot
.07846 .02749 Mdot
.08631 .03925 Mdot
.07062 .02357 Mdot
.08631 .03141 Mdot
.11376 .04317 Mdot
.18042 .09807 Mdot
.21963 .14905 Mdot
.26276 .20002 Mdot
.28237 .22355 Mdot
.28629 .22747 Mdot
.29413 .23924 Mdot
.29413 .23139 Mdot
.29021 .22355 Mdot
.28629 .22355 Mdot
.28629 .22355 Mdot
.28629 .23139 Mdot
.29021 .23531 Mdot
.28629 .23924 Mdot
.27845 .23139 Mdot
.27453 .23924 Mdot
.27453 .23924 Mdot
.28629 .24708 Mdot
.29021 .24316 Mdot
.29021 .23531 Mdot
.27453 .20787 Mdot
.27453 .1961 Mdot
.27845 .20002 Mdot
.27845 .20394 Mdot
.28237 .20787 Mdot
.28629 .20787 Mdot
.27845 .21179 Mdot
.28629 .23531 Mdot
.28237 .24316 Mdot
.27453 .23531 Mdot
.27453 .22747 Mdot
.27453 .21571 Mdot
.27061 .21179 Mdot
.26668 .20787 Mdot
.26668 .20787 Mdot
.26668 .20787 Mdot
.26276 .20394 Mdot
.26276 .20787 Mdot
.27845 .21571 Mdot
.26668 .20002 Mdot
.27061 .21179 Mdot
.27845 .22355 Mdot
.26668 .21963 Mdot
.24316 .21179 Mdot
.23531 .20787 Mdot
.22355 .19218 Mdot
.21179 .1765 Mdot
.21179 .17257 Mdot
.21179 .15689 Mdot
.20787 .1412 Mdot
.21179 .1412 Mdot
.21963 .1412 Mdot
.22747 .15297 Mdot
.21179 .13728 Mdot
.20787 .1412 Mdot
.21571 .14905 Mdot
.20002 .14905 Mdot
.20002 .15297 Mdot
.18826 .15297 Mdot
.18042 .14905 Mdot
.19218 .15297 Mdot
.1961 .14905 Mdot
.1961 .14513 Mdot
.19218 .1412 Mdot
.19218 .13728 Mdot
.19218 .12944 Mdot
.1961 .12944 Mdot
.19218 .12552 Mdot
.19218 .1216 Mdot
.18042 .10983 Mdot
.18042 .10983 Mdot
.18042 .1216 Mdot
.18042 .12944 Mdot
.18042 .13728 Mdot
.1765 .14513 Mdot
.18042 .14513 Mdot
.1765 .13336 Mdot
.18434 .13728 Mdot
.18042 .13336 Mdot
.16473 .11768 Mdot
.14905 .10591 Mdot
.15689 .10983 Mdot
.14905 .09807 Mdot
.14513 .10199 Mdot
.14513 .10199 Mdot
.15689 .10591 Mdot
.15689 .10983 Mdot
.15689 .11768 Mdot
.1412 .10983 Mdot
.12552 .09023 Mdot
.11768 .07846 Mdot
.11768 .07454 Mdot
.1216 .07846 Mdot
.43922 .44314 Mdot
.22355 .21963 Mdot
.18826 .18434 Mdot
.16473 .16865 Mdot
.15297 .16473 Mdot
.13728 .14905 Mdot
.11768 .12552 Mdot
.10983 .11376 Mdot
.09807 .09415 Mdot
.09023 .07846 Mdot
.07454 .0667 Mdot
.07454 .0667 Mdot
.07454 .06278 Mdot
.08239 .06278 Mdot
.13336 .09807 Mdot
.16081 .11768 Mdot
.18434 .16081 Mdot
.20787 .18826 Mdot
.20002 .18826 Mdot
.20002 .20002 Mdot
.20787 .23139 Mdot
.22355 .25492 Mdot
.21963 .26276 Mdot
.20787 .26276 Mdot
.1961 .24708 Mdot
.19218 .23924 Mdot
.1765 .21571 Mdot
.14905 .18434 Mdot
.12552 .15689 Mdot
.11768 .14513 Mdot
.11768 .13336 Mdot
.11768 .11768 Mdot
.10983 .10983 Mdot
.09023 .09807 Mdot
.07454 .08239 Mdot
.05886 .0667 Mdot
.05102 .05102 Mdot
.08631 .08631 Mdot
.1216 .10591 Mdot
.11768 .09807 Mdot
.11376 .08239 Mdot
.11768 .09023 Mdot
.15689 .13728 Mdot
.17257 .16473 Mdot
.18042 .18042 Mdot
.1765 .19218 Mdot
.16081 .18434 Mdot
.11768 .1412 Mdot
.09807 .1216 Mdot
.09023 .11376 Mdot
.10591 .10983 Mdot
.10983 .10983 Mdot
.11376 .10591 Mdot
.10591 .08631 Mdot
.10199 .0667 Mdot
.10591 .06278 Mdot
.10591 .0667 Mdot
.08239 .04317 Mdot
.07454 .04317 Mdot
.0667 .03533 Mdot
.06278 .03925 Mdot
.06278 .03141 Mdot
.07062 .03533 Mdot
.09023 .04709 Mdot
.09023 .05494 Mdot
.08239 .04317 Mdot
.08631 .03533 Mdot
.09023 .01965 Mdot
.11376 .03925 Mdot
.11768 .05102 Mdot
.21179 .14513 Mdot
.24708 .18826 Mdot
.27845 .21179 Mdot
.29413 .21963 Mdot
.3059 .23139 Mdot
.30198 .22355 Mdot
.29413 .22747 Mdot
.29413 .22747 Mdot
.29021 .22747 Mdot
.29021 .23139 Mdot
.29021 .23139 Mdot
.29806 .24316 Mdot
.29021 .23924 Mdot
.27845 .23531 Mdot
.27845 .22355 Mdot
.29021 .22747 Mdot
.28629 .22355 Mdot
.27453 .20787 Mdot
.27845 .20787 Mdot
.27453 .20787 Mdot
.27453 .20787 Mdot
.27845 .21179 Mdot
.27453 .20394 Mdot
.27845 .20787 Mdot
.28629 .21963 Mdot
.28629 .21963 Mdot
.27061 .21963 Mdot
.27061 .21571 Mdot
.27061 .21179 Mdot
.26668 .21179 Mdot
.26668 .20787 Mdot
.26668 .20394 Mdot
.27061 .20394 Mdot
.26668 .20394 Mdot
.27453 .21179 Mdot
.27845 .21179 Mdot
.28237 .21179 Mdot
.27845 .21179 Mdot
.27453 .21963 Mdot
.27061 .22355 Mdot
.25884 .22747 Mdot
.24708 .22747 Mdot
.23531 .21179 Mdot
.22747 .20002 Mdot
.21179 .18042 Mdot
.1961 .16473 Mdot
.20002 .15689 Mdot
.1961 .1412 Mdot
.20787 .1412 Mdot
.20787 .1412 Mdot
.20787 .14513 Mdot
.20002 .15297 Mdot
.20787 .15297 Mdot
.20002 .14905 Mdot
.18434 .13728 Mdot
.18434 .1412 Mdot
.18826 .1412 Mdot
.17257 .12944 Mdot
.18434 .13336 Mdot
.20002 .14513 Mdot
.20002 .14905 Mdot
.19218 .14513 Mdot
.1961 .14513 Mdot
.19218 .1412 Mdot
.18826 .13336 Mdot
.18434 .12552 Mdot
.17257 .11768 Mdot
.17257 .11768 Mdot
.18042 .1216 Mdot
.17257 .1216 Mdot
.16865 .1216 Mdot
.16865 .12552 Mdot
.18042 .13728 Mdot
.17257 .12944 Mdot
.16865 .12552 Mdot
.17257 .12552 Mdot
.16865 .13336 Mdot
.15689 .12552 Mdot
.14513 .11376 Mdot
.13728 .09807 Mdot
.13336 .09023 Mdot
.14513 .09807 Mdot
.16081 .10983 Mdot
.14905 .10983 Mdot
.14905 .11376 Mdot
.14513 .10591 Mdot
.13728 .10199 Mdot
.13728 .10199 Mdot
.12944 .08631 Mdot
.1216 .06278 Mdot
.63528 .64705 Mdot
.3059 .3255 Mdot
.27845 .29413 Mdot
.24708 .25884 Mdot
.21179 .22355 Mdot
.1765 .18042 Mdot
.1412 .12944 Mdot
.1216 .09415 Mdot
.11376 .09023 Mdot
.10983 .09023 Mdot
.11768 .09415 Mdot
.12944 .09415 Mdot
.1216 .08239 Mdot
.12552 .09023 Mdot
.15297 .1412 Mdot
.1765 .17257 Mdot
.18042 .1765 Mdot
.18434 .19218 Mdot
.21179 .22747 Mdot
.22355 .251 Mdot
.22747 .27061 Mdot
.23139 .28237 Mdot
.21963 .27453 Mdot
.20394 .25884 Mdot
.18434 .23139 Mdot
.18434 .22355 Mdot
.16865 .20002 Mdot
.17257 .1961 Mdot
.18826 .20787 Mdot
.16081 .17257 Mdot
.14513 .17257 Mdot
.1216 .14905 Mdot
.08239 .11376 Mdot
.06278 .09023 Mdot
.05494 .08239 Mdot
.09023 .10983 Mdot
.10983 .12944 Mdot
.09415 .10591 Mdot
.07062 .07062 Mdot
.05494 .05102 Mdot
.07454 .07062 Mdot
.09415 .09415 Mdot
.13336 .13728 Mdot
.15689 .16473 Mdot
.16865 .17257 Mdot
.13336 .13728 Mdot
.11768 .1216 Mdot
.1412 .13728 Mdot
.13336 .12944 Mdot
.1216 .11768 Mdot
.11376 .10199 Mdot
.09415 .07846 Mdot
.09023 .06278 Mdot
.10983 .07062 Mdot
.10591 .06278 Mdot
.09807 .04709 Mdot
.07846 .03925 Mdot
.08239 .04317 Mdot
.07454 .04709 Mdot
.06278 .03533 Mdot
.0667 .03925 Mdot
.07062 .04317 Mdot
.07454 .04709 Mdot
.09023 .05886 Mdot
.09415 .05494 Mdot
.12552 .0667 Mdot
.13728 .07062 Mdot
.1412 .08239 Mdot
.16081 .10199 Mdot
.20787 .13336 Mdot
.24708 .16081 Mdot
.27453 .19218 Mdot
.29413 .21963 Mdot
.30982 .23139 Mdot
.30982 .24708 Mdot
.3059 .25492 Mdot
.29413 .25492 Mdot
.29413 .25884 Mdot
.29021 .24316 Mdot
.29021 .23139 Mdot
.29021 .22355 Mdot
.30198 .22747 Mdot
.3059 .22747 Mdot
.29413 .21963 Mdot
.30198 .22355 Mdot
.28629 .21571 Mdot
.28629 .22355 Mdot
.28629 .22747 Mdot
.27845 .21963 Mdot
.28629 .21963 Mdot
.28237 .20787 Mdot
.28629 .21179 Mdot
.27845 .20002 Mdot
.27453 .19218 Mdot
.27061 .1961 Mdot
.27845 .20002 Mdot
.28237 .21571 Mdot
.28237 .22355 Mdot
.28629 .22747 Mdot
.28237 .22355 Mdot
.27845 .22355 Mdot
.27845 .22355 Mdot
.26668 .22355 Mdot
.26276 .21179 Mdot
.27061 .20787 Mdot
.27061 .20002 Mdot
.27845 .20394 Mdot
.26668 .20394 Mdot
.27061 .21179 Mdot
.26276 .21571 Mdot
.24316 .20787 Mdot
.24316 .20787 Mdot
.22355 .18434 Mdot
.20787 .17257 Mdot
.1961 .16081 Mdot
.20002 .15689 Mdot
.1961 .1412 Mdot
.1961 .13728 Mdot
.19218 .13336 Mdot
.20002 .13336 Mdot
.21179 .1412 Mdot
.20394 .13336 Mdot
.1961 .12552 Mdot
.19218 .12552 Mdot
.20787 .14513 Mdot
.20002 .13728 Mdot
.19218 .12944 Mdot
.19218 .13728 Mdot
.1961 .1412 Mdot
.1961 .14513 Mdot
.20002 .15689 Mdot
.19218 .15689 Mdot
.18826 .15297 Mdot
.18042 .14513 Mdot
.18042 .1412 Mdot
.18042 .13728 Mdot
.1765 .13336 Mdot
.17257 .12552 Mdot
.17257 .11768 Mdot
.1765 .12552 Mdot
.17257 .1216 Mdot
.18042 .12944 Mdot
.18042 .12944 Mdot
.18042 .14513 Mdot
.1765 .14905 Mdot
.17257 .14905 Mdot
.15297 .13336 Mdot
.13728 .1216 Mdot
.1412 .11768 Mdot
.1412 .10983 Mdot
.15297 .11376 Mdot
.14513 .11768 Mdot
.13336 .10983 Mdot
.12944 .10983 Mdot
.13336 .10591 Mdot
.13728 .10199 Mdot
.13336 .08631 Mdot
.1216 .0667 Mdot
.86272 .87448 Mdot
.69802 .72155 Mdot
.43922 .48628 Mdot
.37256 .42354 Mdot
.26668 .30982 Mdot
.251 .28237 Mdot
.28237 .29413 Mdot
.29806 .29021 Mdot
.29021 .27061 Mdot
.21571 .20394 Mdot
.1765 .17257 Mdot
.1765 .18826 Mdot
.1765 .1961 Mdot
.16865 .18826 Mdot
.1412 .15297 Mdot
.13728 .1412 Mdot
.16865 .16865 Mdot
.18042 .1961 Mdot
.20787 .23531 Mdot
.21963 .25492 Mdot
.22355 .25884 Mdot
.21179 .25492 Mdot
.18434 .23139 Mdot
.17257 .21963 Mdot
.18042 .21963 Mdot
.1961 .22355 Mdot
.21179 .23924 Mdot
.21179 .23924 Mdot
.22355 .251 Mdot
.20394 .23531 Mdot
.16081 .20394 Mdot
.1216 .17257 Mdot
.10591 .15297 Mdot
.11768 .15689 Mdot
.11768 .14905 Mdot
.07454 .10199 Mdot
.06278 .07454 Mdot
.05886 .05494 Mdot
.05494 .05102 Mdot
.0667 .06278 Mdot
.07846 .07062 Mdot
.09023 .09023 Mdot
.11376 .11768 Mdot
.1216 .13336 Mdot
.15689 .16081 Mdot
.16081 .16473 Mdot
.16081 .16473 Mdot
.14905 .15297 Mdot
.12552 .11376 Mdot
.10983 .08631 Mdot
.10591 .07062 Mdot
.10591 .07062 Mdot
.11376 .07062 Mdot
.10199 .05494 Mdot
.09023 .04317 Mdot
.09023 .05102 Mdot
.08631 .05102 Mdot
.07454 .03925 Mdot
.07454 .04317 Mdot
.07062 .04317 Mdot
.07846 .05102 Mdot
.05886 .04709 Mdot
.07062 .06278 Mdot
.23531 .20787 Mdot
.26668 .23924 Mdot
.28629 .251 Mdot
.26276 .21963 Mdot
.25492 .20002 Mdot
.24708 .17257 Mdot
.24316 .16865 Mdot
.26276 .18434 Mdot
.27453 .20394 Mdot
.29021 .23139 Mdot
.29413 .24708 Mdot
.29413 .25492 Mdot
.29413 .251 Mdot
.29021 .24316 Mdot
.29413 .23139 Mdot
.29021 .22355 Mdot
.3059 .23139 Mdot
.31374 .23531 Mdot
.32158 .24708 Mdot
.31374 .23924 Mdot
.31374 .23531 Mdot
.29806 .23139 Mdot
.29021 .23531 Mdot
.29806 .23139 Mdot
.29413 .22355 Mdot
.29413 .21179 Mdot
.29021 .20787 Mdot
.27845 .20002 Mdot
.27845 .20002 Mdot
.28237 .20787 Mdot
.29021 .20787 Mdot
.29413 .21571 Mdot
.28237 .22355 Mdot
.29806 .23924 Mdot
.29021 .24316 Mdot
.27453 .22355 Mdot
.26668 .21571 Mdot
.26668 .22355 Mdot
.26668 .21571 Mdot
.26668 .20787 Mdot
.26276 .20394 Mdot
.27061 .20787 Mdot
.27061 .20787 Mdot
.27453 .20787 Mdot
.27453 .20787 Mdot
.27453 .21571 Mdot
.27061 .21179 Mdot
.25492 .20002 Mdot
.23531 .19218 Mdot
.22355 .18434 Mdot
.21179 .16865 Mdot
.20394 .15297 Mdot
.20394 .1412 Mdot
.20787 .13728 Mdot
.21179 .14513 Mdot
.21179 .14513 Mdot
.21179 .14513 Mdot
.21179 .14513 Mdot
.21179 .14513 Mdot
.20787 .14905 Mdot
.20394 .14905 Mdot
.20787 .15297 Mdot
.1961 .14513 Mdot
.18434 .13336 Mdot
.18434 .13728 Mdot
.18042 .1412 Mdot
.1765 .14905 Mdot
.18434 .14905 Mdot
.18434 .14905 Mdot
.18434 .15297 Mdot
.18042 .14905 Mdot
.18434 .15297 Mdot
.18042 .14905 Mdot
.18042 .14905 Mdot
.17257 .13728 Mdot
.16865 .12944 Mdot
.17257 .13728 Mdot
.18042 .14513 Mdot
.1765 .14513 Mdot
.16865 .14513 Mdot
.16473 .14513 Mdot
.15689 .14513 Mdot
.14513 .13336 Mdot
.14905 .13336 Mdot
.1412 .11768 Mdot
.14905 .11768 Mdot
.1412 .10983 Mdot
.13728 .10591 Mdot
.13336 .10199 Mdot
.12944 .09807 Mdot
.12944 .09415 Mdot
.12552 .09023 Mdot
.1216 .08631 Mdot
.8784 .89801 Mdot
.6196 .68234 Mdot
.47843 .56078 Mdot
.4902 .55686 Mdot
.50588 .56078 Mdot
.49804 .53725 Mdot
.42354 .45098 Mdot
.37256 .40001 Mdot
.39609 .42746 Mdot
.28237 .3255 Mdot
.15297 .1961 Mdot
.1216 .15297 Mdot
.10199 .11768 Mdot
.09415 .10591 Mdot
.10983 .1216 Mdot
.14905 .15297 Mdot
.1765 .18042 Mdot
.20787 .21571 Mdot
.21571 .23924 Mdot
.21179 .251 Mdot
.19218 .23924 Mdot
.22355 .26668 Mdot
.23531 .27845 Mdot
.24316 .28237 Mdot
.23924 .28629 Mdot
.24316 .29021 Mdot
.23139 .27845 Mdot
.22355 .27453 Mdot
.20002 .26668 Mdot
.18434 .24708 Mdot
.17257 .22747 Mdot
.11376 .17257 Mdot
.08239 .12944 Mdot
.07062 .10199 Mdot
.0667 .07454 Mdot
.07454 .07062 Mdot
.07454 .0667 Mdot
.06278 .05494 Mdot
.06278 .04709 Mdot
.06278 .05886 Mdot
.07846 .07454 Mdot
.15689 .15689 Mdot
.15689 .16081 Mdot
.1765 .17257 Mdot
.15689 .14905 Mdot
.1412 .13728 Mdot
.12552 .11768 Mdot
.11768 .10591 Mdot
.11376 .09807 Mdot
.10983 .09023 Mdot
.09807 .08239 Mdot
.09023 .07062 Mdot
.09023 .0667 Mdot
.08239 .05102 Mdot
.08631 .04709 Mdot
.08239 .04317 Mdot
.09807 .0667 Mdot
.08239 .05886 Mdot
.09415 .07062 Mdot
.11376 .09415 Mdot
.20394 .18042 Mdot
.32158 .29413 Mdot
.34119 .31374 Mdot
.34119 .30982 Mdot
.33335 .28629 Mdot
.29806 .24708 Mdot
.27061 .22355 Mdot
.26668 .20787 Mdot
.26276 .20002 Mdot
.27061 .20787 Mdot
.27845 .21963 Mdot
.29021 .23139 Mdot
.30982 .24708 Mdot
.29806 .23924 Mdot
.30198 .23924 Mdot
.31374 .24316 Mdot
.30982 .24316 Mdot
.30198 .24316 Mdot
.30982 .251 Mdot
.31374 .23924 Mdot
.31374 .23531 Mdot
.3059 .22747 Mdot
.3059 .22355 Mdot
.3059 .22747 Mdot
.3059 .23139 Mdot
.30198 .23139 Mdot
.29413 .23139 Mdot
.30198 .23531 Mdot
.29413 .23531 Mdot
.29021 .22747 Mdot
.28629 .21179 Mdot
.28629 .20787 Mdot
.28629 .21179 Mdot
.28237 .21571 Mdot
.28629 .22355 Mdot
.28237 .21179 Mdot
.27845 .20787 Mdot
.28237 .21571 Mdot
.27845 .21963 Mdot
.27453 .21963 Mdot
.27061 .21571 Mdot
.27845 .21963 Mdot
.27845 .21571 Mdot
.27453 .21179 Mdot
.27453 .21179 Mdot
.27453 .20787 Mdot
.27453 .20394 Mdot
.25884 .19218 Mdot
.25492 .20002 Mdot
.24316 .18826 Mdot
.23139 .18042 Mdot
.22747 .17257 Mdot
.20787 .15297 Mdot
.20394 .15297 Mdot
.20002 .15297 Mdot
.21179 .16473 Mdot
.21179 .16473 Mdot
.20394 .16473 Mdot
.1961 .15689 Mdot
.20002 .15689 Mdot
.1961 .15689 Mdot
.20002 .16473 Mdot
.1961 .15689 Mdot
.19218 .15689 Mdot
.19218 .15297 Mdot
.18826 .14905 Mdot
.19218 .14905 Mdot
.18826 .14513 Mdot
.18434 .14513 Mdot
.18434 .15297 Mdot
.20394 .1765 Mdot
.20002 .18434 Mdot
.18826 .18042 Mdot
.1961 .18434 Mdot
.18434 .16081 Mdot
.1765 .14905 Mdot
.17257 .14513 Mdot
.1765 .14513 Mdot
.16865 .1412 Mdot
.16865 .1412 Mdot
.16081 .13728 Mdot
.16081 .13336 Mdot
.16865 .13728 Mdot
.16473 .13728 Mdot
.15689 .13336 Mdot
.15689 .12552 Mdot
.14513 .10591 Mdot
.13336 .09807 Mdot
.13336 .10199 Mdot
.12944 .10199 Mdot
.14513 .10591 Mdot
.1412 .10591 Mdot
.12944 .10199 Mdot
.76861 .81174 Mdot
.65881 .70979 Mdot
.54117 .59607 Mdot
.54509 .58039 Mdot
.54117 .56862 Mdot
.54902 .57254 Mdot
.43138 .46275 Mdot
.12552 .17257 Mdot
.1216 .15297 Mdot
.10591 .1216 Mdot
.09023 .10199 Mdot
.07846 .08239 Mdot
.08239 .08631 Mdot
.1216 .1216 Mdot
.1412 .1412 Mdot
.16473 .16865 Mdot
.20394 .21963 Mdot
.21179 .23139 Mdot
.26276 .28237 Mdot
.27061 .29413 Mdot
.251 .27845 Mdot
.251 .29021 Mdot
.23531 .28237 Mdot
.23531 .29021 Mdot
.22355 .28629 Mdot
.22355 .28629 Mdot
.22747 .3059 Mdot
.21963 .29413 Mdot
.21179 .27453 Mdot
.14905 .21179 Mdot
.10591 .16081 Mdot
.08631 .12552 Mdot
.07454 .09807 Mdot
.07454 .08631 Mdot
.05494 .06278 Mdot
.0667 .05886 Mdot
.07062 .05886 Mdot
.09807 .08631 Mdot
.16473 .15689 Mdot
.1412 .1412 Mdot
.14513 .1412 Mdot
.15689 .14513 Mdot
.15689 .1412 Mdot
.13728 .12944 Mdot
.13728 .12552 Mdot
.11768 .11376 Mdot
.11768 .1216 Mdot
.1216 .1216 Mdot
.1216 .11768 Mdot
.10983 .09807 Mdot
.10199 .08239 Mdot
.10199 .07846 Mdot
.09807 .07062 Mdot
.11376 .07846 Mdot
.10199 .0667 Mdot
.11376 .08631 Mdot
.16473 .12552 Mdot
.14905 .10983 Mdot
.28629 .24316 Mdot
.33335 .29413 Mdot
.30198 .27453 Mdot
.28629 .26276 Mdot
.3059 .27845 Mdot
.31766 .27453 Mdot
.3059 .251 Mdot
.27845 .21963 Mdot
.27453 .20002 Mdot
.27845 .20394 Mdot
.28237 .20002 Mdot
.29021 .21963 Mdot
.29413 .22747 Mdot
.29021 .22355 Mdot
.29806 .23139 Mdot
.30198 .24316 Mdot
.29021 .23531 Mdot
.30198 .24316 Mdot
.30982 .24708 Mdot
.29413 .23139 Mdot
.30198 .23531 Mdot
.3059 .23139 Mdot
.3059 .23139 Mdot
.3059 .23531 Mdot
.30982 .24316 Mdot
.3059 .251 Mdot
.30198 .251 Mdot
.28629 .24708 Mdot
.28629 .251 Mdot
.28237 .24316 Mdot
.28237 .22355 Mdot
.28237 .21963 Mdot
.27845 .21571 Mdot
.28237 .21571 Mdot
.27845 .20394 Mdot
.28629 .20787 Mdot
.28237 .20787 Mdot
.28237 .21963 Mdot
.27845 .22747 Mdot
.26668 .22355 Mdot
.27453 .23531 Mdot
.26276 .22747 Mdot
.26668 .22747 Mdot
.26276 .21963 Mdot
.25884 .20002 Mdot
.25884 .19218 Mdot
.25492 .19218 Mdot
.25884 .19218 Mdot
.27061 .19218 Mdot
.25884 .19218 Mdot
.24316 .18826 Mdot
.23139 .18826 Mdot
.21963 .18434 Mdot
.20394 .16473 Mdot
.20002 .16865 Mdot
.19218 .17257 Mdot
.18826 .17257 Mdot
.18826 .16473 Mdot
.18434 .14905 Mdot
.19218 .14905 Mdot
.1961 .14905 Mdot
.20394 .14905 Mdot
.1961 .14513 Mdot
.1961 .14905 Mdot
.20394 .14905 Mdot
.1961 .14513 Mdot
.1961 .14905 Mdot
.18826 .1412 Mdot
.18826 .14513 Mdot
.18434 .14513 Mdot
.18434 .16081 Mdot
.19218 .1765 Mdot
.18434 .16865 Mdot
.18042 .15689 Mdot
.1765 .14513 Mdot
.16473 .13336 Mdot
.16081 .12944 Mdot
.16081 .12944 Mdot
.16473 .12944 Mdot
.17257 .13336 Mdot
.1765 .12944 Mdot
.16865 .1216 Mdot
.18434 .13728 Mdot
.17257 .13728 Mdot
.16081 .1216 Mdot
.14905 .10591 Mdot
.13336 .09415 Mdot
.13336 .10199 Mdot
.12944 .10983 Mdot
.14513 .1216 Mdot
.13728 .11768 Mdot
.12944 .11376 Mdot
.78037 .79606 Mdot
.56862 .59215 Mdot
.57254 .58823 Mdot
.53725 .55294 Mdot
.31766 .34511 Mdot
.12552 .16081 Mdot
.12944 .14905 Mdot
.10983 .11376 Mdot
.08631 .08631 Mdot
.08631 .08239 Mdot
.08239 .07454 Mdot
.09023 .07846 Mdot
.10983 .09807 Mdot
.13336 .12944 Mdot
.15297 .15689 Mdot
.1961 .20002 Mdot
.22355 .23139 Mdot
.23924 .23924 Mdot
.24316 .25492 Mdot
.24708 .27845 Mdot
.24316 .28629 Mdot
.24316 .29021 Mdot
.24316 .29413 Mdot
.251 .3059 Mdot
.24708 .29806 Mdot
.24316 .3059 Mdot
.24708 .30982 Mdot
.22747 .28237 Mdot
.19218 .23924 Mdot
.13728 .16473 Mdot
.11376 .13336 Mdot
.10199 .1216 Mdot
.08631 .10591 Mdot
.0667 .08239 Mdot
.13336 .14513 Mdot
.13336 .14513 Mdot
.11376 .1216 Mdot
.10591 .10591 Mdot
.13336 .1216 Mdot
.15297 .13336 Mdot
.14513 .11768 Mdot
.13336 .10591 Mdot
.13728 .1216 Mdot
.13336 .12552 Mdot
.1412 .13336 Mdot
.13336 .11768 Mdot
.13728 .1216 Mdot
.12552 .11376 Mdot
.12552 .10591 Mdot
.12552 .09807 Mdot
.10591 .08239 Mdot
.10199 .07846 Mdot
.08631 .07454 Mdot
.10591 .09023 Mdot
.10983 .09023 Mdot
.36472 .32158 Mdot
.36864 .33727 Mdot
.26668 .24708 Mdot
.18434 .17257 Mdot
.19218 .1765 Mdot
.20787 .1765 Mdot
.30982 .25884 Mdot
.30982 .24708 Mdot
.31766 .24316 Mdot
.30982 .23139 Mdot
.28237 .21179 Mdot
.27845 .21571 Mdot
.29021 .22747 Mdot
.29021 .23924 Mdot
.28237 .23531 Mdot
.27453 .22747 Mdot
.27453 .23139 Mdot
.28629 .23924 Mdot
.3059 .251 Mdot
.29413 .23924 Mdot
.30198 .24708 Mdot
.29806 .24316 Mdot
.30198 .23531 Mdot
.29806 .23924 Mdot
.28629 .23139 Mdot
.29021 .24316 Mdot
.29413 .251 Mdot
.29021 .25492 Mdot
.28629 .251 Mdot
.27845 .24708 Mdot
.27845 .24316 Mdot
.27453 .23531 Mdot
.27845 .22747 Mdot
.29021 .22355 Mdot
.28237 .20787 Mdot
.27845 .20394 Mdot
.28629 .21179 Mdot
.28237 .21571 Mdot
.27845 .21571 Mdot
.27845 .22747 Mdot
.27453 .23531 Mdot
.27061 .22747 Mdot
.27453 .23139 Mdot
.26668 .21963 Mdot
.25884 .20787 Mdot
.25884 .1961 Mdot
.26276 .1961 Mdot
.27453 .20002 Mdot
.27061 .1961 Mdot
.26276 .19218 Mdot
.26668 .20002 Mdot
.25884 .20002 Mdot
.24316 .20002 Mdot
.21963 .18042 Mdot
.20002 .17257 Mdot
.18042 .15689 Mdot
.19218 .16865 Mdot
.18826 .15689 Mdot
.19218 .14905 Mdot
.1961 .13728 Mdot
.19218 .12552 Mdot
.1961 .12944 Mdot
.20394 .1412 Mdot
.20002 .14513 Mdot
.20002 .14513 Mdot
.18826 .13336 Mdot
.1961 .13728 Mdot
.1961 .1412 Mdot
.19218 .14513 Mdot
.17257 .13336 Mdot
.1765 .13728 Mdot
.19218 .14905 Mdot
.18826 .14905 Mdot
.18826 .16081 Mdot
.19218 .14513 Mdot
.17257 .12552 Mdot
.1765 .12944 Mdot
.16081 .11376 Mdot
.16081 .11768 Mdot
.15689 .11768 Mdot
.15689 .11376 Mdot
.16473 .11376 Mdot
.1765 .12552 Mdot
.1765 .13336 Mdot
.16473 .12552 Mdot
.14513 .11768 Mdot
.12944 .10199 Mdot
.11768 .09023 Mdot
.13728 .10199 Mdot
.1412 .11768 Mdot
.12944 .11768 Mdot
.12552 .11768 Mdot
.89409 .89801 Mdot
.79213 .79998 Mdot
.48628 .49804 Mdot
.25492 .27845 Mdot
.18042 .18826 Mdot
.15297 .15689 Mdot
.11376 .1216 Mdot
.10199 .10591 Mdot
.09023 .08631 Mdot
.08631 .07846 Mdot
.09023 .08239 Mdot
.09807 .08239 Mdot
.09023 .07846 Mdot
.11376 .10199 Mdot
.13728 .12552 Mdot
.18826 .17257 Mdot
.23531 .22355 Mdot
.251 .251 Mdot
.26276 .26668 Mdot
.27061 .29021 Mdot
.27061 .30198 Mdot
.27845 .31766 Mdot
.26668 .32158 Mdot
.25884 .31374 Mdot
.25492 .3059 Mdot
.251 .29413 Mdot
.25492 .28629 Mdot
.24316 .26668 Mdot
.22355 .24708 Mdot
.20787 .23531 Mdot
.15689 .19218 Mdot
.12944 .16473 Mdot
.16865 .18434 Mdot
.12944 .14905 Mdot
.07846 .10199 Mdot
.07454 .09023 Mdot
.09415 .09023 Mdot
.09415 .08631 Mdot
.10983 .09807 Mdot
.1216 .10591 Mdot
.12552 .10983 Mdot
.12944 .10983 Mdot
.1216 .10199 Mdot
.12552 .09807 Mdot
.13336 .10199 Mdot
.13728 .10199 Mdot
.1412 .10591 Mdot
.13336 .09807 Mdot
.1216 .09023 Mdot
.10983 .09415 Mdot
.10199 .09807 Mdot
.1216 .1216 Mdot
.10591 .11376 Mdot
.21179 .20787 Mdot
.23531 .22355 Mdot
.15297 .14513 Mdot
.17257 .15689 Mdot
.14513 .12552 Mdot
.11376 .08631 Mdot
.14513 .10983 Mdot
.23924 .19218 Mdot
.33335 .27845 Mdot
.34903 .29806 Mdot
.33727 .29413 Mdot
.31374 .27061 Mdot
.29021 .24708 Mdot
.28629 .24708 Mdot
.27453 .24316 Mdot
.251 .22747 Mdot
.24708 .22747 Mdot
.25884 .23531 Mdot
.27845 .24708 Mdot
.29021 .25884 Mdot
.29806 .26276 Mdot
.29806 .25884 Mdot
.29413 .251 Mdot
.28629 .23139 Mdot
.29021 .23139 Mdot
.30198 .23139 Mdot
.29021 .22355 Mdot
.28629 .22747 Mdot
.29413 .23531 Mdot
.28237 .23924 Mdot
.27845 .24708 Mdot
.28629 .24708 Mdot
.28629 .23531 Mdot
.28629 .23139 Mdot
.27453 .20787 Mdot
.27845 .20787 Mdot
.27845 .20787 Mdot
.28237 .21179 Mdot
.27453 .21179 Mdot
.27845 .21179 Mdot
.28629 .22355 Mdot
.27453 .21963 Mdot
.27453 .23139 Mdot
.27061 .22747 Mdot
.27061 .21963 Mdot
.27061 .21963 Mdot
.25884 .20394 Mdot
.26276 .20394 Mdot
.26276 .20002 Mdot
.26276 .19218 Mdot
.25492 .18042 Mdot
.25884 .19218 Mdot
.251 .19218 Mdot
.23924 .19218 Mdot
.23139 .18826 Mdot
.22355 .18826 Mdot
.20394 .1765 Mdot
.20394 .16473 Mdot
.1961 .15297 Mdot
.19218 .14905 Mdot
.20002 .14513 Mdot
.20002 .1412 Mdot
.1961 .1412 Mdot
.18042 .12944 Mdot
.17257 .13336 Mdot
.1765 .13336 Mdot
.1765 .13336 Mdot
.19218 .14513 Mdot
.18042 .13728 Mdot
.18826 .14513 Mdot
.18042 .13728 Mdot
.18042 .13728 Mdot
.18434 .1412 Mdot
.18434 .14513 Mdot
.1961 .14905 Mdot
.1961 .1412 Mdot
.18826 .13336 Mdot
.1765 .12552 Mdot
.16865 .12552 Mdot
.15689 .1216 Mdot
.15689 .13336 Mdot
.16473 .13336 Mdot
.16865 .12944 Mdot
.16473 .12944 Mdot
.15689 .1216 Mdot
.14513 .11376 Mdot
.13336 .10983 Mdot
.13336 .10591 Mdot
.1412 .10199 Mdot
.13728 .09807 Mdot
.13336 .10199 Mdot
.12552 .10591 Mdot
.73332 .749 Mdot
.51765 .54509 Mdot
.24708 .27453 Mdot
.18434 .21179 Mdot
.14905 .17257 Mdot
.13336 .14905 Mdot
.12552 .12552 Mdot
.10983 .09807 Mdot
.10591 .08631 Mdot
.09807 .07846 Mdot
.09415 .07846 Mdot
.09415 .08239 Mdot
.09023 .07062 Mdot
.15689 .12552 Mdot
.18434 .16081 Mdot
.22355 .20787 Mdot
.24708 .24708 Mdot
.25884 .27061 Mdot
.27061 .29806 Mdot
.27453 .31766 Mdot
.251 .29806 Mdot
.24316 .29021 Mdot
.25492 .29413 Mdot
.25884 .30198 Mdot
.26668 .30198 Mdot
.27453 .3059 Mdot
.26668 .30198 Mdot
.25492 .28629 Mdot
.23531 .27845 Mdot
.21571 .25884 Mdot
.13728 .18434 Mdot
.09023 .13336 Mdot
.0667 .10591 Mdot
.06278 .09023 Mdot
.05494 .07846 Mdot
.05886 .07454 Mdot
.07062 .07454 Mdot
.10199 .09807 Mdot
.11376 .10199 Mdot
.1216 .10591 Mdot
.11768 .09415 Mdot
.12552 .09807 Mdot
.13728 .10199 Mdot
.14905 .11376 Mdot
.1412 .10591 Mdot
.14513 .1216 Mdot
.14905 .13336 Mdot
.15297 .15689 Mdot
.14905 .16473 Mdot
.12552 .15297 Mdot
.09807 .1216 Mdot
.09807 .11768 Mdot
.10199 .11376 Mdot
.12944 .1216 Mdot
.1216 .10983 Mdot
.10983 .10199 Mdot
.09807 .09415 Mdot
.09807 .09415 Mdot
.19218 .17257 Mdot
.25492 .23139 Mdot
.30982 .28237 Mdot
.34511 .30982 Mdot
.34903 .31374 Mdot
.29413 .26276 Mdot
.21179 .19218 Mdot
.18434 .16865 Mdot
.18042 .16473 Mdot
.1961 .18042 Mdot
.21179 .1961 Mdot
.25492 .22747 Mdot
.26668 .23531 Mdot
.29021 .251 Mdot
.28237 .24316 Mdot
.28629 .24708 Mdot
.29413 .23531 Mdot
.3059 .23139 Mdot
.29021 .21179 Mdot
.29806 .21179 Mdot
.29413 .21571 Mdot
.28629 .22355 Mdot
.28629 .23531 Mdot
.28237 .22747 Mdot
.27453 .21963 Mdot
.28237 .22747 Mdot
.27845 .21571 Mdot
.27453 .21179 Mdot
.27845 .21179 Mdot
.27453 .20394 Mdot
.27845 .20787 Mdot
.27845 .20787 Mdot
.27845 .20002 Mdot
.27453 .20002 Mdot
.27453 .20394 Mdot
.28629 .22355 Mdot
.27845 .21963 Mdot
.28237 .21963 Mdot
.27845 .21571 Mdot
.27061 .20787 Mdot
.27061 .20394 Mdot
.26668 .20002 Mdot
.24708 .18434 Mdot
.251 .19218 Mdot
.24708 .19218 Mdot
.25884 .20394 Mdot
.25884 .20394 Mdot
.23924 .18826 Mdot
.22747 .18434 Mdot
.21963 .1765 Mdot
.20394 .16081 Mdot
.20002 .16473 Mdot
.20394 .16473 Mdot
.21179 .16865 Mdot
.21179 .16473 Mdot
.20394 .16473 Mdot
.1765 .14905 Mdot
.16473 .13336 Mdot
.1765 .12944 Mdot
.18042 .12552 Mdot
.18042 .12552 Mdot
.18434 .12944 Mdot
.18042 .12552 Mdot
.18042 .12552 Mdot
.18826 .13728 Mdot
.1961 .13728 Mdot
.19218 .13336 Mdot
.18826 .13336 Mdot
.18434 .12944 Mdot
.18042 .13728 Mdot
.1765 .13728 Mdot
.16473 .12944 Mdot
.15689 .13336 Mdot
.14905 .12552 Mdot
.16081 .12944 Mdot
.14905 .11768 Mdot
.1412 .10983 Mdot
.15297 .11768 Mdot
.13336 .10199 Mdot
.11376 .08631 Mdot
.1216 .08631 Mdot
.13336 .08239 Mdot
.13728 .08631 Mdot
.12944 .08631 Mdot
.64705 .66273 Mdot
.41177 .43138 Mdot
.19218 .21179 Mdot
.17257 .17257 Mdot
.1412 .12944 Mdot
.11768 .10591 Mdot
.10983 .09807 Mdot
.10199 .09023 Mdot
.09023 .07454 Mdot
.09023 .0667 Mdot
.09023 .0667 Mdot
.09415 .07062 Mdot
.13336 .10591 Mdot
.20002 .17257 Mdot
.24708 .23531 Mdot
.24708 .25492 Mdot
.26276 .28629 Mdot
.26276 .29413 Mdot
.26668 .30198 Mdot
.25492 .29806 Mdot
.26276 .3059 Mdot
.27061 .30198 Mdot
.26668 .29806 Mdot
.26668 .29413 Mdot
.28629 .31374 Mdot
.28629 .3255 Mdot
.27453 .3255 Mdot
.23531 .29021 Mdot
.19218 .251 Mdot
.1216 .1765 Mdot
.07454 .12552 Mdot
.07454 .10983 Mdot
.0667 .09023 Mdot
.0667 .08239 Mdot
.07846 .08631 Mdot
.10199 .10591 Mdot
.11768 .11768 Mdot
.1216 .1216 Mdot
.12552 .10983 Mdot
.13728 .1216 Mdot
.14905 .1216 Mdot
.14905 .1216 Mdot
.14513 .1216 Mdot
.20394 .18826 Mdot
.20394 .20787 Mdot
.19218 .21571 Mdot
.13728 .16473 Mdot
.11768 .1412 Mdot
.09023 .11376 Mdot
.09023 .10983 Mdot
.10591 .11376 Mdot
.10983 .10983 Mdot
.10199 .09807 Mdot
.10591 .10591 Mdot
.10591 .10591 Mdot
.09415 .09415 Mdot
.1216 .10199 Mdot
.1412 .11376 Mdot
.19218 .16081 Mdot
.32943 .29021 Mdot
.31374 .27845 Mdot
.16865 .14513 Mdot
.13728 .11768 Mdot
.10983 .09023 Mdot
.10199 .08239 Mdot
.10199 .07846 Mdot
.18434 .14513 Mdot
.22355 .1765 Mdot
.26668 .21179 Mdot
.28629 .23531 Mdot
.29021 .251 Mdot
.29021 .24708 Mdot
.29806 .24316 Mdot
.29413 .23139 Mdot
.29413 .22747 Mdot
.28629 .21963 Mdot
.28237 .21571 Mdot
.29413 .21963 Mdot
.29413 .21571 Mdot
.28237 .21179 Mdot
.27453 .21571 Mdot
.28629 .22355 Mdot
.27061 .21571 Mdot
.26668 .21179 Mdot
.26668 .21179 Mdot
.27061 .21963 Mdot
.26668 .20394 Mdot
.26668 .18826 Mdot
.25884 .18434 Mdot
.27061 .1961 Mdot
.27453 .20002 Mdot
.27453 .1961 Mdot
.28237 .20787 Mdot
.27845 .20787 Mdot
.28237 .21963 Mdot
.27845 .22747 Mdot
.26668 .21963 Mdot
.25492 .21179 Mdot
.24708 .20394 Mdot
.23924 .1961 Mdot
.24316 .19218 Mdot
.24708 .19218 Mdot
.24708 .18826 Mdot
.24708 .18826 Mdot
.24708 .18826 Mdot
.23531 .1765 Mdot
.23139 .16865 Mdot
.21963 .16865 Mdot
.21179 .16865 Mdot
.20394 .17257 Mdot
.1961 .16865 Mdot
.18042 .15297 Mdot
.1765 .1412 Mdot
.1765 .13336 Mdot
.17257 .11768 Mdot
.1765 .11376 Mdot
.1765 .11376 Mdot
.16473 .10591 Mdot
.15689 .09807 Mdot
.17257 .10591 Mdot
.18434 .11768 Mdot
.1765 .11768 Mdot
.18826 .13336 Mdot
.18042 .13336 Mdot
.1765 .14905 Mdot
.17257 .16081 Mdot
.14513 .13728 Mdot
.13728 .13336 Mdot
.13728 .12552 Mdot
.14513 .12944 Mdot
.14905 .12944 Mdot
.15297 .1216 Mdot
.14513 .11376 Mdot
.13728 .09807 Mdot
.12552 .08631 Mdot
.13336 .08631 Mdot
.13336 .07454 Mdot
.12944 .07062 Mdot
.12552 .0667 Mdot
.80782 .81174 Mdot
.62352 .6196 Mdot
.22747 .21571 Mdot
.15297 .1412 Mdot
.13336 .1216 Mdot
.10591 .09807 Mdot
.09807 .09023 Mdot
.09415 .07454 Mdot
.10199 .07454 Mdot
.09415 .0667 Mdot
.10199 .07846 Mdot
.11768 .09023 Mdot
.14513 .12552 Mdot
.18042 .1765 Mdot
.21179 .21963 Mdot
.23924 .251 Mdot
.251 .27061 Mdot
.26668 .29021 Mdot
.27845 .30198 Mdot
.28629 .30198 Mdot
.27845 .29413 Mdot
.27845 .29021 Mdot
.27845 .29413 Mdot
.27061 .30198 Mdot
.27061 .31374 Mdot
.27061 .32158 Mdot
.27061 .32943 Mdot
.251 .3059 Mdot
.19218 .24316 Mdot
.11376 .16081 Mdot
.10591 .14513 Mdot
.08631 .11768 Mdot
.0667 .09807 Mdot
.08239 .11768 Mdot
.11376 .1412 Mdot
.12552 .14513 Mdot
.12944 .1412 Mdot
.13728 .14513 Mdot
.1412 .14513 Mdot
.1412 .13728 Mdot
.13336 .12552 Mdot
.20394 .18826 Mdot
.24708 .23924 Mdot
.25884 .26276 Mdot
.21179 .21963 Mdot
.16865 .18434 Mdot
.13336 .14905 Mdot
.10591 .1216 Mdot
.10983 .12552 Mdot
.10199 .1216 Mdot
.10199 .10983 Mdot
.10199 .10591 Mdot
.08631 .09023 Mdot
.07454 .07454 Mdot
.09415 .07454 Mdot
.11376 .08239 Mdot
.09415 .05886 Mdot
.14513 .11376 Mdot
.16473 .13336 Mdot
.12944 .10199 Mdot
.10591 .07846 Mdot
.10591 .07846 Mdot
.10591 .07846 Mdot
.09023 .0667 Mdot
.13728 .10591 Mdot
.16865 .12552 Mdot
.23531 .18434 Mdot
.251 .1961 Mdot
.26668 .21571 Mdot
.26668 .22355 Mdot
.29806 .24316 Mdot
.29806 .23924 Mdot
.30198 .23531 Mdot
.29806 .22355 Mdot
.28629 .21571 Mdot
.3059 .22355 Mdot
.29413 .20787 Mdot
.28629 .21179 Mdot
.29021 .21963 Mdot
.28237 .21963 Mdot
.27453 .22355 Mdot
.27061 .22355 Mdot
.27061 .22747 Mdot
.27453 .23139 Mdot
.27453 .23139 Mdot
.27061 .20787 Mdot
.25884 .19218 Mdot
.23924 .1765 Mdot
.24316 .16865 Mdot
.24708 .16473 Mdot
.25884 .18042 Mdot
.27061 .20002 Mdot
.27061 .20787 Mdot
.27845 .21963 Mdot
.27845 .22747 Mdot
.26668 .22355 Mdot
.251 .22355 Mdot
.251 .21963 Mdot
.24316 .20394 Mdot
.23924 .18826 Mdot
.23531 .18434 Mdot
.23924 .18826 Mdot
.23924 .18042 Mdot
.25492 .18434 Mdot
.23924 .17257 Mdot
.23139 .18042 Mdot
.23531 .18826 Mdot
.21571 .18434 Mdot
.20002 .18042 Mdot
.19218 .17257 Mdot
.1961 .16865 Mdot
.18042 .1412 Mdot
.17257 .12944 Mdot
.18042 .13336 Mdot
.18434 .12944 Mdot
.18434 .11768 Mdot
.17257 .11768 Mdot
.17257 .11376 Mdot
.1765 .1216 Mdot
.16865 .11376 Mdot
.18434 .12944 Mdot
.1765 .13728 Mdot
.1765 .15297 Mdot
.1765 .16473 Mdot
.16473 .15297 Mdot
.14513 .13728 Mdot
.14905 .1412 Mdot
.13728 .1216 Mdot
.1412 .11768 Mdot
.14905 .1216 Mdot
.14905 .11376 Mdot
.1412 .09415 Mdot
.14513 .09023 Mdot
.15297 .08631 Mdot
.15297 .07454 Mdot
.13336 .05886 Mdot
.12552 .05886 Mdot
.80782 .80782 Mdot
.59215 .59607 Mdot
.16081 .16473 Mdot
.13728 .14905 Mdot
.1216 .12552 Mdot
.10983 .09807 Mdot
.11376 .09807 Mdot
.11376 .10199 Mdot
.11376 .10199 Mdot
.1216 .10591 Mdot
.1216 .10591 Mdot
.12944 .12552 Mdot
.14905 .14513 Mdot
.18826 .18826 Mdot
.24708 .24708 Mdot
.27845 .27845 Mdot
.29806 .30198 Mdot
.30198 .31766 Mdot
.29806 .32158 Mdot
.28629 .31766 Mdot
.27453 .31766 Mdot
.27061 .31766 Mdot
.25492 .31766 Mdot
.29413 .35687 Mdot
.25884 .32158 Mdot
.28237 .3255 Mdot
.23924 .27061 Mdot
.22747 .251 Mdot
.19218 .22355 Mdot
.1216 .16865 Mdot
.10199 .15297 Mdot
.16081 .20787 Mdot
.15297 .20002 Mdot
.12944 .16865 Mdot
.1216 .14905 Mdot
.12552 .14513 Mdot
.1216 .13336 Mdot
.12552 .12552 Mdot
.12552 .11768 Mdot
.1765 .16865 Mdot
.21963 .22355 Mdot
.23924 .24316 Mdot
.23531 .23924 Mdot
.22355 .23139 Mdot
.19218 .1961 Mdot
.14905 .16865 Mdot
.12552 .14905 Mdot
.10983 .12944 Mdot
.09023 .10199 Mdot
.07062 .07454 Mdot
.05494 .05886 Mdot
.09023 .07846 Mdot
.10199 .08239 Mdot
.10199 .07454 Mdot
.11376 .08631 Mdot
.13728 .10983 Mdot
.14905 .12552 Mdot
.11376 .09415 Mdot
.10591 .08239 Mdot
.10983 .09023 Mdot
.11768 .09807 Mdot
.16081 .1412 Mdot
.20002 .16473 Mdot
.21963 .18042 Mdot
.24316 .19218 Mdot
.25884 .18826 Mdot
.26276 .18826 Mdot
.28629 .20787 Mdot
.28629 .20002 Mdot
.29021 .20787 Mdot
.30198 .22355 Mdot
.30198 .22355 Mdot
.30982 .23139 Mdot
.29413 .22355 Mdot
.29413 .22355 Mdot
.29021 .22355 Mdot
.28629 .21571 Mdot
.29021 .22355 Mdot
.28629 .22747 Mdot
.29021 .22747 Mdot
.29413 .23139 Mdot
.30198 .24316 Mdot
.3059 .23924 Mdot
.29021 .22747 Mdot
.27453 .21963 Mdot
.26276 .20787 Mdot
.25492 .19218 Mdot
.251 .18826 Mdot
.251 .18826 Mdot
.251 .18826 Mdot
.25492 .19218 Mdot
.26668 .20394 Mdot
.25884 .20394 Mdot
.25884 .20787 Mdot
.25884 .21571 Mdot
.251 .21179 Mdot
.23531 .20002 Mdot
.24708 .21179 Mdot
.24708 .21179 Mdot
.23531 .1961 Mdot
.24316 .19218 Mdot
.23531 .18826 Mdot
.23139 .19218 Mdot
.23531 .1961 Mdot
.22747 .19218 Mdot
.22355 .19218 Mdot
.22355 .18434 Mdot
.22747 .18042 Mdot
.21179 .16473 Mdot
.20394 .15297 Mdot
.21179 .16081 Mdot
.21179 .16081 Mdot
.20002 .14905 Mdot
.1961 .15297 Mdot
.18826 .15689 Mdot
.17257 .15297 Mdot
.16473 .14513 Mdot
.16081 .1412 Mdot
.16473 .1412 Mdot
.16473 .1412 Mdot
.16865 .14513 Mdot
.18042 .15689 Mdot
.16865 .14513 Mdot
.16081 .13728 Mdot
.16865 .13336 Mdot
.16081 .11768 Mdot
.16865 .1216 Mdot
.16473 .11768 Mdot
.17257 .11376 Mdot
.16865 .10199 Mdot
.16865 .09415 Mdot
.15689 .08631 Mdot
.15689 .09023 Mdot
.14905 .08239 Mdot
.62352 .63136 Mdot
.38432 .40393 Mdot
.16473 .19218 Mdot
.1765 .20002 Mdot
.1961 .21571 Mdot
.16865 .1765 Mdot
.15297 .15689 Mdot
.14513 .14513 Mdot
.13336 .12944 Mdot
.1412 .13336 Mdot
.14905 .13728 Mdot
.18826 .1765 Mdot
.20394 .1961 Mdot
.25492 .23924 Mdot
.28629 .27453 Mdot
.30982 .30982 Mdot
.30982 .3255 Mdot
.3059 .34511 Mdot
.29021 .34119 Mdot
.26276 .32158 Mdot
.25492 .30982 Mdot
.25884 .3059 Mdot
.27453 .3059 Mdot
.29413 .3255 Mdot
.29021 .32158 Mdot
.28629 .3255 Mdot
.26668 .30982 Mdot
.21963 .27453 Mdot
.20787 .26668 Mdot
.12944 .19218 Mdot
.10591 .15689 Mdot
.08631 .12552 Mdot
.07846 .10983 Mdot
.08631 .09415 Mdot
.09023 .09023 Mdot
.07846 .07846 Mdot
.09023 .09415 Mdot
.12944 .13336 Mdot
.20394 .20002 Mdot
.23531 .23531 Mdot
.251 .24708 Mdot
.25492 .251 Mdot
.24316 .251 Mdot
.18042 .20002 Mdot
.14513 .1765 Mdot
.11768 .14905 Mdot
.09023 .10983 Mdot
.06278 .07062 Mdot
.06278 .0667 Mdot
.07846 .07062 Mdot
.08239 .07062 Mdot
.12944 .11376 Mdot
.14513 .1216 Mdot
.16473 .13728 Mdot
.14513 .11768 Mdot
.1412 .10983 Mdot
.13336 .10199 Mdot
.11768 .08631 Mdot
.14905 .1216 Mdot
.16865 .12944 Mdot
.1961 .14513 Mdot
.20787 .15297 Mdot
.23531 .16081 Mdot
.23924 .16081 Mdot
.26668 .18826 Mdot
.28237 .20002 Mdot
.28237 .20002 Mdot
.28629 .20002 Mdot
.29806 .21179 Mdot
.29806 .22355 Mdot
.30198 .22747 Mdot
.29413 .22747 Mdot
.28629 .22355 Mdot
.28629 .21963 Mdot
.29413 .22355 Mdot
.28629 .21963 Mdot
.28629 .21963 Mdot
.29021 .23139 Mdot
.29806 .24708 Mdot
.3059 .25492 Mdot
.30198 .24708 Mdot
.29021 .23924 Mdot
.27453 .22747 Mdot
.26276 .21179 Mdot
.25884 .20394 Mdot
.26276 .20787 Mdot
.24708 .20002 Mdot
.24708 .20394 Mdot
.24316 .19218 Mdot
.23924 .18434 Mdot
.24316 .18826 Mdot
.24708 .19218 Mdot
.24316 .19218 Mdot
.22747 .18826 Mdot
.23531 .1961 Mdot
.23531 .1961 Mdot
.22355 .18434 Mdot
.21571 .18042 Mdot
.21179 .1765 Mdot
.21571 .18434 Mdot
.21179 .1765 Mdot
.21963 .18042 Mdot
.20787 .1765 Mdot
.22355 .18042 Mdot
.21963 .1765 Mdot
.21571 .16865 Mdot
.21179 .16865 Mdot
.21963 .1765 Mdot
.21963 .18042 Mdot
.21963 .1765 Mdot
.21179 .1765 Mdot
.1961 .18042 Mdot
.18826 .18042 Mdot
.18434 .1765 Mdot
.16865 .16473 Mdot
.16473 .15297 Mdot
.15689 .13728 Mdot
.15297 .12552 Mdot
.15689 .12552 Mdot
.16081 .12552 Mdot
.16865 .1216 Mdot
.17257 .12552 Mdot
.16865 .10983 Mdot
.16473 .09807 Mdot
.16473 .10199 Mdot
.14905 .10199 Mdot
.15689 .10591 Mdot
.15297 .09807 Mdot
.14513 .09023 Mdot
.15689 .10591 Mdot
.15297 .10591 Mdot
.67842 .6941 Mdot
.53333 .55294 Mdot
.30982 .34119 Mdot
.29806 .32158 Mdot
.26668 .26668 Mdot
.21963 .21179 Mdot
.20394 .18042 Mdot
.19218 .16473 Mdot
.18826 .16081 Mdot
.18826 .17257 Mdot
.20787 .19218 Mdot
.21963 .20394 Mdot
.26276 .251 Mdot
.28237 .28237 Mdot
.30198 .31766 Mdot
.30982 .33727 Mdot
.29806 .33335 Mdot
.28629 .31374 Mdot
.27845 .29806 Mdot
.27845 .30198 Mdot
.3059 .33335 Mdot
.3059 .34119 Mdot
.3059 .35687 Mdot
.30198 .36864 Mdot
.29806 .36472 Mdot
.27845 .34511 Mdot
.20394 .27845 Mdot
.17257 .23924 Mdot
.10199 .16081 Mdot
.10983 .1412 Mdot
.09023 .10591 Mdot
.07454 .09023 Mdot
.0667 .07846 Mdot
.10199 .09415 Mdot
.10199 .07846 Mdot
.23531 .1961 Mdot
.23139 .20394 Mdot
.22355 .20787 Mdot
.21571 .21179 Mdot
.22747 .23139 Mdot
.24708 .25492 Mdot
.24316 .26276 Mdot
.22355 .24708 Mdot
.15297 .1765 Mdot
.07062 .08631 Mdot
.07062 .07454 Mdot
.06278 .06278 Mdot
.07062 .05886 Mdot
.14905 .12552 Mdot
.14905 .1216 Mdot
.16081 .1216 Mdot
.16473 .11376 Mdot
.16081 .11376 Mdot
.16081 .11768 Mdot
.16865 .11768 Mdot
.15297 .10199 Mdot
.13728 .09023 Mdot
.13336 .08239 Mdot
.1216 .07062 Mdot
.14905 .09415 Mdot
.18434 .1216 Mdot
.24708 .17257 Mdot
.27845 .20002 Mdot
.27845 .21179 Mdot
.29021 .21571 Mdot
.28629 .20787 Mdot
.28629 .21571 Mdot
.28237 .21571 Mdot
.27845 .21179 Mdot
.27845 .21571 Mdot
.28629 .22747 Mdot
.28237 .22355 Mdot
.27845 .21963 Mdot
.27845 .22355 Mdot
.28629 .24316 Mdot
.28629 .24708 Mdot
.30198 .25884 Mdot
.28629 .24316 Mdot
.27453 .22747 Mdot
.27061 .21963 Mdot
.26668 .21179 Mdot
.26668 .21179 Mdot
.26276 .20787 Mdot
.26276 .21571 Mdot
.25492 .20787 Mdot
.24708 .20002 Mdot
.23924 .19218 Mdot
.23531 .18826 Mdot
.23924 .18042 Mdot
.23924 .18434 Mdot
.23924 .18434 Mdot
.23139 .18042 Mdot
.22747 .18826 Mdot
.23139 .19218 Mdot
.22355 .18826 Mdot
.21571 .18042 Mdot
.22355 .18826 Mdot
.22747 .19218 Mdot
.21571 .18042 Mdot
.20394 .16865 Mdot
.20394 .16865 Mdot
.20787 .16473 Mdot
.20787 .16865 Mdot
.20394 .16865 Mdot
.21963 .1765 Mdot
.21963 .16865 Mdot
.22355 .17257 Mdot
.21571 .1765 Mdot
.20787 .17257 Mdot
.20394 .1765 Mdot
.20002 .1765 Mdot
.19218 .1765 Mdot
.18434 .16865 Mdot
.17257 .15297 Mdot
.15689 .12944 Mdot
.16081 .12944 Mdot
.16865 .12944 Mdot
.17257 .12944 Mdot
.17257 .12552 Mdot
.16865 .11768 Mdot
.16865 .10983 Mdot
.17257 .11768 Mdot
.16473 .10591 Mdot
.16081 .09807 Mdot
.15689 .09415 Mdot
.14905 .09023 Mdot
.15689 .10591 Mdot
.15689 .10983 Mdot
.89017 .89409 Mdot
.77253 .77645 Mdot
.54509 .54902 Mdot
.32943 .34903 Mdot
.29413 .29806 Mdot
.27845 .27453 Mdot
.26668 .251 Mdot
.26276 .24316 Mdot
.24708 .22747 Mdot
.21179 .1961 Mdot
.20394 .1961 Mdot
.21571 .21571 Mdot
.25492 .25884 Mdot
.29021 .30198 Mdot
.29021 .30982 Mdot
.3059 .31374 Mdot
.30982 .3059 Mdot
.3255 .32158 Mdot
.3255 .33335 Mdot
.30982 .33727 Mdot
.29413 .34511 Mdot
.30198 .36472 Mdot
.31374 .3804 Mdot
.30982 .38824 Mdot
.29806 .3804 Mdot
.28629 .3608 Mdot
.23924 .30198 Mdot
.21179 .25492 Mdot
.14513 .18042 Mdot
.13728 .15297 Mdot
.11376 .11376 Mdot
.11768 .10199 Mdot
.15297 .12944 Mdot
.27453 .23924 Mdot
.17257 .15689 Mdot
.15689 .15297 Mdot
.13728 .13728 Mdot
.13728 .13728 Mdot
.18434 .18826 Mdot
.21571 .22747 Mdot
.23531 .24708 Mdot
.23924 .24708 Mdot
.13728 .14513 Mdot
.08239 .08239 Mdot
.0667 .05102 Mdot
.05102 .02749 Mdot
.07846 .05494 Mdot
.08631 .05886 Mdot
.09807 .05102 Mdot
.12944 .07454 Mdot
.1412 .09415 Mdot
.15689 .11768 Mdot
.15297 .10983 Mdot
.1412 .10591 Mdot
.12944 .09807 Mdot
.15689 .12552 Mdot
.12944 .10199 Mdot
.1216 .09415 Mdot
.11768 .08631 Mdot
.23924 .19218 Mdot
.3608 .29806 Mdot
.34511 .28237 Mdot
.34511 .27845 Mdot
.3255 .26276 Mdot
.3059 .24708 Mdot
.28629 .23924 Mdot
.27845 .22747 Mdot
.27061 .21963 Mdot
.27061 .21963 Mdot
.25884 .21179 Mdot
.25884 .21571 Mdot
.26668 .21963 Mdot
.27061 .23531 Mdot
.27845 .23924 Mdot
.28237 .23139 Mdot
.28629 .23531 Mdot
.28237 .23139 Mdot
.27061 .21571 Mdot
.26276 .20787 Mdot
.25492 .20394 Mdot
.25884 .20787 Mdot
.26276 .21179 Mdot
.25492 .20394 Mdot
.26668 .20394 Mdot
.251 .19218 Mdot
.24708 .18826 Mdot
.24316 .18042 Mdot
.251 .19218 Mdot
.25492 .19218 Mdot
.23924 .19218 Mdot
.23924 .20394 Mdot
.23139 .20394 Mdot
.22355 .1961 Mdot
.22747 .1961 Mdot
.23139 .20002 Mdot
.21571 .18042 Mdot
.21571 .18042 Mdot
.21571 .17257 Mdot
.21571 .16473 Mdot
.21571 .15689 Mdot
.21963 .15689 Mdot
.21179 .15297 Mdot
.21179 .15297 Mdot
.21179 .15689 Mdot
.21571 .16473 Mdot
.21179 .16865 Mdot
.20787 .1765 Mdot
.20394 .16865 Mdot
.20002 .16473 Mdot
.18042 .15297 Mdot
.18042 .15689 Mdot
.1765 .15297 Mdot
.16473 .1412 Mdot
.16473 .13336 Mdot
.16081 .12944 Mdot
.16865 .12552 Mdot
.17257 .1216 Mdot
.17257 .11768 Mdot
.16865 .11376 Mdot
.16865 .11376 Mdot
.16081 .10199 Mdot
.14513 .08631 Mdot
.13728 .08631 Mdot
.15297 .10199 Mdot
.14905 .09807 Mdot
.14905 .10199 Mdot
.87056 .8784 Mdot
.73724 .75292 Mdot
.44706 .47451 Mdot
.4902 .49412 Mdot
.52549 .49804 Mdot
.27453 .25884 Mdot
.27061 .251 Mdot
.25492 .23139 Mdot
.23924 .21963 Mdot
.24316 .22747 Mdot
.23531 .22747 Mdot
.24316 .24708 Mdot
.25884 .25884 Mdot
.29413 .28629 Mdot
.31374 .3059 Mdot
.3255 .32158 Mdot
.3255 .33727 Mdot
.3059 .33335 Mdot
.3059 .34511 Mdot
.32943 .36472 Mdot
.32158 .36864 Mdot
.30198 .36864 Mdot
.3059 .37648 Mdot
.30198 .37256 Mdot
.30198 .36472 Mdot
.28237 .32943 Mdot
.251 .29021 Mdot
.20002 .21179 Mdot
.15689 .15689 Mdot
.22355 .20787 Mdot
.24708 .22355 Mdot
.14513 .13728 Mdot
.13728 .1412 Mdot
.10591 .11768 Mdot
.08631 .09807 Mdot
.08631 .09415 Mdot
.10591 .11376 Mdot
.13728 .13728 Mdot
.16081 .15689 Mdot
.15297 .14513 Mdot
.10199 .09807 Mdot
.09023 .07062 Mdot
.09023 .0667 Mdot
.07062 .04709 Mdot
.07846 .05102 Mdot
.07846 .05102 Mdot
.07846 .04709 Mdot
.09415 .06278 Mdot
.10199 .07454 Mdot
.10983 .07846 Mdot
.09023 .07454 Mdot
.07454 .0667 Mdot
.12944 .11768 Mdot
.14513 .12552 Mdot
.15689 .13336 Mdot
.15689 .12944 Mdot
.19218 .15297 Mdot
.30198 .251 Mdot
.37256 .32158 Mdot
.38432 .33727 Mdot
.38824 .34903 Mdot
.3608 .3255 Mdot
.31374 .28237 Mdot
.28629 .24708 Mdot
.25884 .20787 Mdot
.23924 .19218 Mdot
.22747 .18826 Mdot
.23139 .18826 Mdot
.24316 .20002 Mdot
.25492 .21179 Mdot
.26668 .21963 Mdot
.27845 .23139 Mdot
.28237 .24316 Mdot
.27061 .24316 Mdot
.26668 .23924 Mdot
.24708 .21963 Mdot
.25492 .21571 Mdot
.251 .20394 Mdot
.25492 .1961 Mdot
.25492 .1961 Mdot
.25884 .18826 Mdot
.25884 .1961 Mdot
.25884 .19218 Mdot
.26668 .1961 Mdot
.25492 .1961 Mdot
.25884 .20787 Mdot
.24316 .20787 Mdot
.23924 .21571 Mdot
.23531 .22355 Mdot
.21963 .20787 Mdot
.21571 .18826 Mdot
.22355 .18826 Mdot
.21571 .1765 Mdot
.21963 .17257 Mdot
.21571 .16473 Mdot
.23139 .17257 Mdot
.22747 .16473 Mdot
.21963 .16473 Mdot
.21571 .16865 Mdot
.1961 .15689 Mdot
.18826 .15297 Mdot
.18826 .15297 Mdot
.1961 .15689 Mdot
.19218 .16081 Mdot
.19218 .15689 Mdot
.19218 .15297 Mdot
.18826 .14513 Mdot
.18434 .13728 Mdot
.18042 .12944 Mdot
.17257 .1216 Mdot
.16865 .11376 Mdot
.16081 .10983 Mdot
.16865 .11768 Mdot
.1765 .1216 Mdot
.17257 .11376 Mdot
.1765 .11768 Mdot
.1765 .1216 Mdot
.16865 .11376 Mdot
.15689 .10591 Mdot
.15297 .10591 Mdot
.15689 .11376 Mdot
.15689 .11768 Mdot
.14513 .11768 Mdot
.81566 .81958 Mdot
.72547 .71763 Mdot
.5098 .4902 Mdot
.45883 .42746 Mdot
.3255 .30198 Mdot
.33727 .3059 Mdot
.31766 .28629 Mdot
.29413 .27061 Mdot
.27061 .25492 Mdot
.251 .23139 Mdot
.24316 .22355 Mdot
.25492 .23139 Mdot
.28237 .26276 Mdot
.30198 .29021 Mdot
.32158 .3255 Mdot
.32943 .34511 Mdot
.34511 .36864 Mdot
.33727 .36864 Mdot
.32158 .36472 Mdot
.31374 .36472 Mdot
.3059 .35687 Mdot
.29413 .35295 Mdot
.3059 .3608 Mdot
.32158 .35687 Mdot
.32158 .34119 Mdot
.29806 .30982 Mdot
.28629 .29413 Mdot
.23139 .23924 Mdot
.13336 .16081 Mdot
.11768 .15689 Mdot
.10199 .1412 Mdot
.07846 .10983 Mdot
.07846 .10199 Mdot
.07062 .09023 Mdot
.0667 .07454 Mdot
.07454 .07454 Mdot
.07846 .07454 Mdot
.07454 .07454 Mdot
.07846 .0667 Mdot
.09807 .07062 Mdot
.10983 .07454 Mdot
.10199 .07062 Mdot
.09415 .05886 Mdot
.09807 .05886 Mdot
.08631 .05494 Mdot
.09807 .0667 Mdot
.08239 .04709 Mdot
.0667 .03533 Mdot
.06278 .03925 Mdot
.0667 .05102 Mdot
.08631 .07062 Mdot
.09807 .07062 Mdot
.10591 .08239 Mdot
.16473 .13728 Mdot
.1961 .17257 Mdot
.28237 .25492 Mdot
.32158 .29413 Mdot
.36472 .34119 Mdot
.38432 .36864 Mdot
.40001 .37648 Mdot
.34511 .31766 Mdot
.24316 .20787 Mdot
.18042 .13336 Mdot
.15297 .10591 Mdot
.15297 .10199 Mdot
.18826 .12944 Mdot
.20787 .15689 Mdot
.22355 .16865 Mdot
.251 .1961 Mdot
.26668 .21571 Mdot
.26276 .23139 Mdot
.26276 .23924 Mdot
.24708 .21963 Mdot
.24708 .20394 Mdot
.251 .18826 Mdot
.25492 .1765 Mdot
.25492 .1765 Mdot
.26276 .17257 Mdot
.251 .16081 Mdot
.25492 .16473 Mdot
.25884 .18434 Mdot
.26276 .20002 Mdot
.24708 .20787 Mdot
.24708 .21571 Mdot
.23139 .20787 Mdot
.23139 .21571 Mdot
.21963 .20787 Mdot
.21179 .18826 Mdot
.20787 .17257 Mdot
.20787 .16081 Mdot
.20787 .15297 Mdot
.22747 .15689 Mdot
.22355 .15689 Mdot
.23139 .16081 Mdot
.21963 .15689 Mdot
.22747 .16865 Mdot
.21963 .1765 Mdot
.21179 .18042 Mdot
.1961 .17257 Mdot
.19218 .18042 Mdot
.1765 .16473 Mdot
.16865 .15689 Mdot
.17257 .1412 Mdot
.18042 .13728 Mdot
.18434 .12944 Mdot
.18434 .1216 Mdot
.18042 .11376 Mdot
.17257 .10983 Mdot
.1765 .10983 Mdot
.1765 .10983 Mdot
.18434 .11376 Mdot
.18434 .1216 Mdot
.19218 .12944 Mdot
.18434 .1216 Mdot
.18042 .12552 Mdot
.17257 .12944 Mdot
.16865 .1412 Mdot
.16865 .14513 Mdot
.14513 .12552 Mdot
.13336 .11768 Mdot
.81566 .79213 Mdot
.67057 .64313 Mdot
.56862 .53725 Mdot
.52157 .49412 Mdot
.48235 .45098 Mdot
.40001 .36864 Mdot
.3059 .26276 Mdot
.27453 .22747 Mdot
.251 .20787 Mdot
.22747 .19218 Mdot
.23924 .21179 Mdot
.24316 .23139 Mdot
.27453 .27453 Mdot
.3059 .32158 Mdot
.32943 .35687 Mdot
.32943 .36864 Mdot
.32158 .3608 Mdot
.3059 .34903 Mdot
.29806 .34119 Mdot
.29413 .33727 Mdot
.32158 .35687 Mdot
.34511 .36472 Mdot
.3608 .37256 Mdot
.34903 .37256 Mdot
.33335 .37648 Mdot
.21963 .27845 Mdot
.1765 .24708 Mdot
.13336 .1961 Mdot
.09415 .15297 Mdot
.08239 .13728 Mdot
.07454 .10983 Mdot
.06278 .09023 Mdot
.05102 .06278 Mdot
.04317 .04317 Mdot
.07062 .05886 Mdot
.10199 .07454 Mdot
.1216 .07846 Mdot
.13728 .09023 Mdot
.13728 .09023 Mdot
.12944 .07846 Mdot
.1216 .07454 Mdot
.11768 .07454 Mdot
.10199 .05494 Mdot
.08631 .03533 Mdot
.0667 .01965 Mdot
.0667 .02749 Mdot
.07846 .05102 Mdot
.08631 .06278 Mdot
.09807 .08239 Mdot
.08631 .07454 Mdot
.07846 .08631 Mdot
.09415 .10199 Mdot
.14905 .14905 Mdot
.19218 .1961 Mdot
.25492 .25884 Mdot
.30982 .30198 Mdot
.35295 .3255 Mdot
.31374 .28237 Mdot
.35295 .29413 Mdot
.25492 .1961 Mdot
.21571 .15689 Mdot
.18434 .13728 Mdot
.18042 .14905 Mdot
.15297 .13336 Mdot
.16865 .14513 Mdot
.20002 .16473 Mdot
.22355 .1961 Mdot
.23924 .21179 Mdot
.24708 .20394 Mdot
.23531 .18826 Mdot
.23531 .17257 Mdot
.23139 .15689 Mdot
.251 .16473 Mdot
.24316 .16473 Mdot
.23924 .16081 Mdot
.23531 .15297 Mdot
.23531 .15689 Mdot
.23531 .1765 Mdot
.23139 .18434 Mdot
.22355 .18826 Mdot
.22355 .20002 Mdot
.21571 .20002 Mdot
.20394 .18826 Mdot
.21179 .18434 Mdot
.21963 .1765 Mdot
.21963 .16473 Mdot
.21571 .15297 Mdot
.22747 .15297 Mdot
.24316 .16473 Mdot
.23924 .16865 Mdot
.23924 .17257 Mdot
.23924 .1765 Mdot
.22355 .16865 Mdot
.21571 .17257 Mdot
.21179 .18434 Mdot
.20394 .18826 Mdot
.19218 .1765 Mdot
.17257 .15689 Mdot
.17257 .15689 Mdot
.16865 .14905 Mdot
.16865 .13728 Mdot
.17257 .13728 Mdot
.18042 .12944 Mdot
.18434 .13336 Mdot
.18042 .12944 Mdot
.17257 .1216 Mdot
.17257 .1216 Mdot
.18434 .12552 Mdot
.1765 .1216 Mdot
.16865 .11768 Mdot
.16473 .1216 Mdot
.16865 .12944 Mdot
.16473 .13728 Mdot
.15689 .13728 Mdot
.15689 .13728 Mdot
.14513 .1216 Mdot
.13336 .10983 Mdot
.92154 .91761 Mdot
.83135 .81958 Mdot
.64705 .63528 Mdot
.5647 .54902 Mdot
.52549 .49412 Mdot
.31766 .28629 Mdot
.23924 .21571 Mdot
.21179 .1961 Mdot
.18434 .16865 Mdot
.17257 .15689 Mdot
.17257 .16081 Mdot
.21179 .20002 Mdot
.29413 .28629 Mdot
.3059 .31374 Mdot
.3255 .34903 Mdot
.33727 .3608 Mdot
.32943 .3608 Mdot
.31374 .35687 Mdot
.31374 .35687 Mdot
.32943 .3608 Mdot
.34903 .36864 Mdot
.35295 .36472 Mdot
.36472 .38432 Mdot
.3608 .38824 Mdot
.33335 .37648 Mdot
.24316 .29413 Mdot
.20002 .251 Mdot
.14513 .20002 Mdot
.09807 .1412 Mdot
.0667 .10199 Mdot
.04709 .07062 Mdot
.03925 .04317 Mdot
.07062 .05494 Mdot
.10591 .0667 Mdot
.14513 .09415 Mdot
.1765 .12944 Mdot
.18434 .13336 Mdot
.16865 .10983 Mdot
.12944 .07846 Mdot
.11376 .05886 Mdot
.09807 .03925 Mdot
.07846 .02357 Mdot
.07454 .01965 Mdot
.07062 .02749 Mdot
.08631 .04317 Mdot
.10591 .05886 Mdot
.1216 .07062 Mdot
.12552 .09415 Mdot
.12944 .10983 Mdot
.13336 .10983 Mdot
.11768 .10591 Mdot
.13728 .13336 Mdot
.20002 .19218 Mdot
.251 .23924 Mdot
.31766 .28629 Mdot
.13728 .11768 Mdot
.15297 .12552 Mdot
.16473 .13728 Mdot
.26668 .22355 Mdot
.34903 .29413 Mdot
.34119 .28237 Mdot
.32158 .27061 Mdot
.28629 .23531 Mdot
.24708 .20394 Mdot
.23139 .20002 Mdot
.23924 .20787 Mdot
.24708 .21179 Mdot
.24708 .20394 Mdot
.23531 .18434 Mdot
.23531 .16865 Mdot
.23531 .15689 Mdot
.23531 .16081 Mdot
.22355 .15689 Mdot
.21963 .15297 Mdot
.21963 .16081 Mdot
.21571 .16081 Mdot
.20787 .15689 Mdot
.21179 .16081 Mdot
.21963 .18042 Mdot
.21963 .18826 Mdot
.20787 .18042 Mdot
.20394 .16865 Mdot
.20394 .16081 Mdot
.22355 .16865 Mdot
.23139 .18434 Mdot
.22355 .1765 Mdot
.21963 .17257 Mdot
.22355 .1765 Mdot
.22355 .1765 Mdot
.21963 .18042 Mdot
.21963 .16865 Mdot
.21179 .15689 Mdot
.21179 .16081 Mdot
.21179 .16473 Mdot
.19218 .15297 Mdot
.1765 .14905 Mdot
.1765 .14905 Mdot
.17257 .14513 Mdot
.17257 .14513 Mdot
.16865 .14905 Mdot
.16865 .15297 Mdot
.16865 .15297 Mdot
.16865 .14905 Mdot
.17257 .1412 Mdot
.17257 .13728 Mdot
.17257 .12944 Mdot
.16081 .11768 Mdot
.16473 .1216 Mdot
.16473 .11376 Mdot
.16473 .10983 Mdot
.15297 .10199 Mdot
.16473 .11376 Mdot
.16865 .1216 Mdot
.16473 .10983 Mdot
.15297 .10591 Mdot
.91761 .91761 Mdot
.81566 .81566 Mdot
.48235 .48628 Mdot
.27845 .30198 Mdot
.24316 .24708 Mdot
.21571 .20394 Mdot
.18826 .16473 Mdot
.17257 .13728 Mdot
.16473 .12552 Mdot
.17257 .13728 Mdot
.23139 .20394 Mdot
.26276 .251 Mdot
.29021 .29413 Mdot
.31374 .3255 Mdot
.32943 .35295 Mdot
.34511 .36472 Mdot
.36472 .3804 Mdot
.34903 .3608 Mdot
.33727 .34119 Mdot
.35295 .35295 Mdot
.34511 .35295 Mdot
.34903 .36864 Mdot
.34119 .37256 Mdot
.3255 .3608 Mdot
.29021 .33335 Mdot
.21571 .25884 Mdot
.11768 .15297 Mdot
.07846 .09415 Mdot
.05886 .05886 Mdot
.09023 .0667 Mdot
.11376 .08631 Mdot
.13336 .09415 Mdot
.15689 .10591 Mdot
.18042 .12944 Mdot
.16865 .11376 Mdot
.1412 .08239 Mdot
.11376 .05886 Mdot
.08631 .03925 Mdot
.06278 .02357 Mdot
.05494 .02749 Mdot
.0667 .03925 Mdot
.07454 .05494 Mdot
.15689 .12552 Mdot
.12944 .09415 Mdot
.11376 .07062 Mdot
.31374 .23924 Mdot
.27845 .20394 Mdot
.15689 .12552 Mdot
.26668 .251 Mdot
.23924 .22355 Mdot
.21179 .20394 Mdot
.18434 .1765 Mdot
.14905 .12944 Mdot
.09415 .07454 Mdot
.07454 .05102 Mdot
.05886 .03533 Mdot
.22747 .18826 Mdot
.49804 .43922 Mdot
.50588 .45098 Mdot
.4902 .44706 Mdot
.33727 .31766 Mdot
.31766 .3059 Mdot
.30198 .29021 Mdot
.28629 .26276 Mdot
.27845 .24316 Mdot
.25884 .21963 Mdot
.25492 .1961 Mdot
.23924 .1765 Mdot
.24316 .17257 Mdot
.23924 .16865 Mdot
.23531 .16473 Mdot
.22747 .16081 Mdot
.21571 .14513 Mdot
.21571 .14905 Mdot
.20787 .15297 Mdot
.21179 .15689 Mdot
.22355 .16865 Mdot
.21571 .17257 Mdot
.1961 .16081 Mdot
.20394 .16081 Mdot
.20787 .16865 Mdot
.20394 .17257 Mdot
.20394 .18042 Mdot
.20394 .18042 Mdot
.20787 .18826 Mdot
.20002 .18042 Mdot
.1961 .16865 Mdot
.20002 .15689 Mdot
.20002 .14905 Mdot
.1961 .1412 Mdot
.19218 .13336 Mdot
.18042 .1216 Mdot
.18042 .12944 Mdot
.18042 .13336 Mdot
.1765 .12944 Mdot
.1765 .13336 Mdot
.16473 .1412 Mdot
.16081 .14905 Mdot
.15689 .15297 Mdot
.16473 .15689 Mdot
.16473 .14513 Mdot
.16473 .1412 Mdot
.16865 .12944 Mdot
.16865 .1216 Mdot
.16081 .11768 Mdot
.16081 .10983 Mdot
.16473 .09415 Mdot
.16081 .09023 Mdot
.16081 .09415 Mdot
.15689 .09807 Mdot
.16081 .09807 Mdot
.15689 .09807 Mdot
.73724 .74116 Mdot
.54117 .54117 Mdot
.27845 .27845 Mdot
.21963 .20394 Mdot
.21179 .17257 Mdot
.19218 .14905 Mdot
.20787 .16473 Mdot
.1961 .16865 Mdot
.1961 .18434 Mdot
.1961 .18826 Mdot
.20394 .20002 Mdot
.26276 .25884 Mdot
.30982 .3059 Mdot
.34119 .33335 Mdot
.34903 .34119 Mdot
.35687 .34119 Mdot
.34511 .33335 Mdot
.32943 .3255 Mdot
.33335 .33335 Mdot
.34511 .34903 Mdot
.33727 .35687 Mdot
.32158 .35687 Mdot
.33335 .3608 Mdot
.22747 .251 Mdot
.10199 .1216 Mdot
.10199 .10199 Mdot
.09415 .08239 Mdot
.09415 .07846 Mdot
.10199 .07062 Mdot
.10983 .07062 Mdot
.11768 .07454 Mdot
.12944 .08631 Mdot
.1412 .09415 Mdot
.11768 .07454 Mdot
.07846 .05102 Mdot
.07454 .05494 Mdot
.0667 .05886 Mdot
.05886 .05494 Mdot
.07062 .06278 Mdot
.13728 .1216 Mdot
.08239 .07454 Mdot
.18434 .18042 Mdot
.67057 .6196 Mdot
.65881 .62744 Mdot
.41569 .41569 Mdot
.27845 .28629 Mdot
.27453 .27061 Mdot
.12944 .12552 Mdot
.11768 .10591 Mdot
.08631 .07454 Mdot
.09415 .07454 Mdot
.07454 .05886 Mdot
.07062 .05494 Mdot
.07846 .0667 Mdot
.47059 .42746 Mdot
.58431 .54117 Mdot
.54509 .5098 Mdot
.51765 .49804 Mdot
.41961 .42354 Mdot
.40393 .40785 Mdot
.39217 .3804 Mdot
.38432 .3608 Mdot
.3608 .33727 Mdot
.33335 .30198 Mdot
.31766 .27453 Mdot
.30198 .251 Mdot
.27845 .22747 Mdot
.27061 .21963 Mdot
.26276 .21179 Mdot
.24708 .1961 Mdot
.23924 .18434 Mdot
.22747 .16865 Mdot
.22355 .16865 Mdot
.22355 .17257 Mdot
.21571 .16473 Mdot
.20394 .16865 Mdot
.20002 .16473 Mdot
.1961 .16081 Mdot
.20002 .16473 Mdot
.19218 .15689 Mdot
.18434 .16081 Mdot
.18434 .16081 Mdot
.17257 .15297 Mdot
.16081 .1412 Mdot
.1765 .14905 Mdot
.16865 .1412 Mdot
.17257 .1412 Mdot
.1765 .1412 Mdot
.1765 .12944 Mdot
.17257 .1216 Mdot
.16865 .11768 Mdot
.16865 .1216 Mdot
.16473 .12552 Mdot
.16473 .12944 Mdot
.16081 .12944 Mdot
.16473 .14513 Mdot
.16865 .14513 Mdot
.16865 .1412 Mdot
.16081 .12552 Mdot
.16865 .12552 Mdot
.16473 .10983 Mdot
.16081 .11376 Mdot
.16081 .10591 Mdot
.16865 .10199 Mdot
.15297 .09415 Mdot
.15297 .09023 Mdot
.14905 .10199 Mdot
.14905 .11376 Mdot
.1412 .10591 Mdot
.63528 .63136 Mdot
.51765 .49804 Mdot
.36472 .34119 Mdot
.29413 .27453 Mdot
.251 .23924 Mdot
.23924 .22355 Mdot
.21179 .19218 Mdot
.18042 .15689 Mdot
.16081 .13728 Mdot
.17257 .14513 Mdot
.251 .21571 Mdot
.28629 .25492 Mdot
.34903 .3059 Mdot
.35295 .31766 Mdot
.35295 .3255 Mdot
.29806 .28629 Mdot
.33727 .31374 Mdot
.3059 .28237 Mdot
.29021 .28237 Mdot
.28237 .28237 Mdot
.30198 .29806 Mdot
.21963 .21571 Mdot
.14513 .12944 Mdot
.1216 .09415 Mdot
.11376 .07846 Mdot
.09415 .05494 Mdot
.09807 .05494 Mdot
.09807 .05102 Mdot
.11376 .07062 Mdot
.12552 .09415 Mdot
.1216 .09023 Mdot
.09415 .07062 Mdot
.07846 .05102 Mdot
.07846 .05102 Mdot
.07846 .06278 Mdot
.07062 .05886 Mdot
.08631 .07846 Mdot
.10983 .10591 Mdot
.11376 .1216 Mdot
.38824 .37648 Mdot
.48235 .47059 Mdot
.6941 .66665 Mdot
.41177 .39609 Mdot
.20002 .17257 Mdot
.14905 .11376 Mdot
.11768 .08239 Mdot
.08631 .05102 Mdot
.07062 .04317 Mdot
.07846 .05494 Mdot
.07846 .06278 Mdot
.06278 .05494 Mdot
.21179 .20002 Mdot
.58431 .55686 Mdot
.53333 .5098 Mdot
.52549 .50588 Mdot
.47843 .45883 Mdot
.32943 .3255 Mdot
.35295 .33335 Mdot
.37648 .35687 Mdot
.42746 .40785 Mdot
.4902 .47451 Mdot
.50196 .48235 Mdot
.4902 .46275 Mdot
.46667 .42746 Mdot
.40785 .3608 Mdot
.37648 .3255 Mdot
.35687 .31766 Mdot
.33727 .31766 Mdot
.30982 .29021 Mdot
.27845 .26276 Mdot
.24316 .21963 Mdot
.22747 .20787 Mdot
.22355 .20394 Mdot
.21179 .19218 Mdot
.20787 .18826 Mdot
.21571 .18042 Mdot
.20002 .16865 Mdot
.1961 .16081 Mdot
.19218 .15689 Mdot
.18434 .16081 Mdot
.1765 .16081 Mdot
.17257 .15689 Mdot
.18042 .16081 Mdot
.17257 .15297 Mdot
.16473 .14513 Mdot
.1765 .13728 Mdot
.1765 .1216 Mdot
.16473 .10199 Mdot
.18042 .11376 Mdot
.16865 .10983 Mdot
.16473 .11768 Mdot
.16081 .1216 Mdot
.15689 .1216 Mdot
.15689 .13336 Mdot
.14905 .1216 Mdot
.15689 .1216 Mdot
.14905 .10591 Mdot
.15689 .10591 Mdot
.14905 .09807 Mdot
.15297 .10199 Mdot
.14905 .10591 Mdot
.1412 .09807 Mdot
.12944 .09415 Mdot
.1412 .11768 Mdot
.13728 .12552 Mdot
.12944 .11768 Mdot
.90977 .90193 Mdot
.73724 .72939 Mdot
.40393 .38432 Mdot
.34903 .32943 Mdot
.21571 .1961 Mdot
.20787 .18042 Mdot
.18042 .15689 Mdot
.15689 .13336 Mdot
.16473 .13336 Mdot
.18826 .15297 Mdot
.22355 .18042 Mdot
.27845 .22747 Mdot
.27453 .22747 Mdot
.20787 .18042 Mdot
.21963 .18826 Mdot
.1961 .16473 Mdot
.17257 .14513 Mdot
.18826 .15689 Mdot
.23139 .19218 Mdot
.25884 .20394 Mdot
.16865 .12552 Mdot
.1765 .12944 Mdot
.1412 .09807 Mdot
.1216 .08239 Mdot
.09807 .06278 Mdot
.09415 .05886 Mdot
.11376 .08239 Mdot
.13336 .10983 Mdot
.12552 .10983 Mdot
.08631 .07454 Mdot
.07454 .06278 Mdot
.07454 .06278 Mdot
.07454 .06278 Mdot
.07846 .06278 Mdot
.11768 .10591 Mdot
.12552 .12944 Mdot
.13728 .13728 Mdot
.13336 .1412 Mdot
.19218 .20002 Mdot
.40393 .39217 Mdot
.39609 .3804 Mdot
.24316 .22355 Mdot
.11768 .09023 Mdot
.14513 .10199 Mdot
.07454 .04317 Mdot
.0667 .03925 Mdot
.05886 .04317 Mdot
.05494 .04709 Mdot
.05886 .0667 Mdot
.27845 .28237 Mdot
.50588 .50588 Mdot
.53333 .53725 Mdot
.49804 .49804 Mdot
.52549 .50196 Mdot
.47451 .44706 Mdot
.41961 .38824 Mdot
.35687 .33335 Mdot
.36472 .34511 Mdot
.54117 .5098 Mdot
.52549 .49412 Mdot
.54117 .50196 Mdot
.57254 .52157 Mdot
.52157 .47059 Mdot
.36864 .33335 Mdot
.39217 .36864 Mdot
.42354 .41177 Mdot
.42746 .42354 Mdot
.40785 .40785 Mdot
.38432 .37256 Mdot
.35687 .34511 Mdot
.3255 .32158 Mdot
.28629 .29021 Mdot
.27061 .27845 Mdot
.251 .24708 Mdot
.24316 .23139 Mdot
.23924 .21963 Mdot
.23139 .20787 Mdot
.21963 .20394 Mdot
.1961 .19218 Mdot
.18434 .17257 Mdot
.18042 .16473 Mdot
.1765 .15297 Mdot
.17257 .13728 Mdot
.17257 .11768 Mdot
.1765 .11376 Mdot
.18042 .10591 Mdot
.19218 .10983 Mdot
.19218 .11376 Mdot
.18042 .1216 Mdot
.15297 .10591 Mdot
.1216 .08631 Mdot
.10199 .07454 Mdot
.09023 .06278 Mdot
.09807 .07062 Mdot
.10591 .07846 Mdot
.11768 .08239 Mdot
.1412 .09807 Mdot
.15689 .10983 Mdot
.15297 .11376 Mdot
.1412 .10591 Mdot
.14513 .11376 Mdot
.13336 .11376 Mdot
.12552 .11768 Mdot
.12944 .1216 Mdot
.85095 .84703 Mdot
.6196 .61176 Mdot
.22747 .20394 Mdot
.23139 .20002 Mdot
.21571 .18042 Mdot
.20394 .16473 Mdot
.20787 .15689 Mdot
.20394 .14905 Mdot
.18826 .12944 Mdot
.18042 .11768 Mdot
.16865 .10983 Mdot
.14513 .09807 Mdot
.12552 .08239 Mdot
.13336 .08631 Mdot
.14513 .09415 Mdot
.18826 .12552 Mdot
.21571 .14905 Mdot
.19218 .13728 Mdot
.17257 .12552 Mdot
.1412 .10983 Mdot
.11768 .09807 Mdot
.10591 .09415 Mdot
.10199 .09023 Mdot
.1216 .11376 Mdot
.1412 .13336 Mdot
.11768 .11376 Mdot
.10591 .09807 Mdot
.09023 .08239 Mdot
.09415 .07846 Mdot
.09415 .07062 Mdot
.07846 .06278 Mdot
.07846 .0667 Mdot
.13336 .11376 Mdot
.17257 .14905 Mdot
.20394 .1765 Mdot
.21571 .1961 Mdot
.26276 .23531 Mdot
.28237 .251 Mdot
.26276 .22747 Mdot
.11376 .09023 Mdot
.12944 .10983 Mdot
.10591 .09023 Mdot
.09023 .07846 Mdot
.07846 .07846 Mdot
.0667 .07454 Mdot
.05886 .07454 Mdot
.21963 .22747 Mdot
.42746 .43138 Mdot
.44314 .45491 Mdot
.48628 .48235 Mdot
.5098 .48628 Mdot
.53725 .49804 Mdot
.54117 .49804 Mdot
.50196 .47059 Mdot
.48628 .45098 Mdot
.4902 .45883 Mdot
.5098 .47451 Mdot
.52157 .48235 Mdot
.51765 .47843 Mdot
.57646 .54117 Mdot
.51765 .49804 Mdot
.33335 .34119 Mdot
.34511 .34511 Mdot
.31766 .31766 Mdot
.45491 .43138 Mdot
.52157 .4902 Mdot
.36864 .36472 Mdot
.34903 .35687 Mdot
.35295 .36864 Mdot
.3804 .39217 Mdot
.38824 .40001 Mdot
.39217 .40001 Mdot
.3804 .3804 Mdot
.36864 .34903 Mdot
.34903 .32158 Mdot
.30982 .28237 Mdot
.27061 .24708 Mdot
.22355 .1961 Mdot
.20394 .17257 Mdot
.20394 .16081 Mdot
.19218 .13728 Mdot
.1765 .11768 Mdot
.18826 .11768 Mdot
.1961 .1216 Mdot
.18434 .1216 Mdot
.17257 .12552 Mdot
.13336 .09415 Mdot
.09807 .06278 Mdot
.05886 .03141 Mdot
.03533 .01572 Mdot
.02357 .00788 Mdot
.03533 .01965 Mdot
.03533 .01965 Mdot
.09023 .05886 Mdot
.11376 .07846 Mdot
.13336 .09415 Mdot
.1412 .09807 Mdot
.1412 .10983 Mdot
.1412 .11376 Mdot
.12552 .10591 Mdot
.11768 .09807 Mdot
.65097 .63528 Mdot
.54902 .50588 Mdot
.30198 .251 Mdot
.28629 .23139 Mdot
.26668 .20787 Mdot
.24708 .18434 Mdot
.1961 .13728 Mdot
.18434 .13336 Mdot
.16473 .11768 Mdot
.15689 .10591 Mdot
.14905 .09415 Mdot
.15297 .09807 Mdot
.18434 .12552 Mdot
.23139 .17257 Mdot
.22355 .1765 Mdot
.19218 .15689 Mdot
.15689 .13336 Mdot
.13336 .11768 Mdot
.11376 .10199 Mdot
.11768 .10983 Mdot
.14513 .1412 Mdot
.15689 .15297 Mdot
.14513 .13336 Mdot
.13336 .12552 Mdot
.11768 .10983 Mdot
.10591 .10199 Mdot
.10591 .09023 Mdot
.07062 .05494 Mdot
.0667 .05102 Mdot
.07846 .05494 Mdot
.09807 .07062 Mdot
.15297 .1216 Mdot
.20394 .16081 Mdot
.27845 .22747 Mdot
.27061 .21571 Mdot
.21571 .16473 Mdot
.17257 .13336 Mdot
.14513 .11376 Mdot
.12552 .10591 Mdot
.11376 .09807 Mdot
.10983 .10591 Mdot
.09807 .09415 Mdot
.10199 .10199 Mdot
.09415 .09807 Mdot
.16081 .16081 Mdot
.251 .23924 Mdot
.29806 .28237 Mdot
.36472 .32943 Mdot
.60391 .55294 Mdot
.57646 .53725 Mdot
.57646 .53725 Mdot
.57254 .52941 Mdot
.56078 .51372 Mdot
.55294 .5098 Mdot
.54902 .51372 Mdot
.53725 .5098 Mdot
.53333 .51765 Mdot
.53725 .52549 Mdot
.47451 .47451 Mdot
.43138 .42746 Mdot
.39609 .38432 Mdot
.38824 .37256 Mdot
.62744 .59215 Mdot
.55686 .53725 Mdot
.35687 .3608 Mdot
.35687 .36472 Mdot
.32943 .33727 Mdot
.3255 .32943 Mdot
.43138 .42746 Mdot
.47059 .46275 Mdot
.48628 .47059 Mdot
.4902 .47059 Mdot
.47451 .45098 Mdot
.42354 .40001 Mdot
.38824 .3608 Mdot
.36864 .33727 Mdot
.33335 .29413 Mdot
.30198 .25492 Mdot
.28237 .23139 Mdot
.26668 .20394 Mdot
.23924 .17257 Mdot
.20787 .16473 Mdot
.18826 .16473 Mdot
.15689 .13728 Mdot
.09415 .07062 Mdot
.05102 .03533 Mdot
.03533 .01965 Mdot
.01965 .00396 Mdot
.01965 .00788 Mdot
.0118 .00396 Mdot
.00788 .00396 Mdot
.03533 .01965 Mdot
.05494 .02357 Mdot
.08631 .04317 Mdot
.11768 .07454 Mdot
.13728 .09023 Mdot
.13728 .09807 Mdot
.14513 .11376 Mdot
.749 .72939 Mdot
.59607 .56078 Mdot
.34903 .29806 Mdot
.26276 .20394 Mdot
.25884 .1961 Mdot
.23139 .16865 Mdot
.23531 .16473 Mdot
.21571 .13728 Mdot
.21179 .13336 Mdot
.20787 .14905 Mdot
.23531 .1765 Mdot
.24316 .18826 Mdot
.21963 .1765 Mdot
.1765 .14513 Mdot
.14905 .1216 Mdot
.1216 .09807 Mdot
.1216 .09807 Mdot
.13728 .11768 Mdot
.15689 .13336 Mdot
.16865 .15689 Mdot
.18042 .16473 Mdot
.16865 .16473 Mdot
.12552 .13728 Mdot
.10591 .10591 Mdot
.0667 .06278 Mdot
.05886 .05494 Mdot
.05494 .05102 Mdot
.07062 .05886 Mdot
.08631 .07454 Mdot
.14513 .11376 Mdot
.15689 .1216 Mdot
.16473 .1216 Mdot
.1765 .12552 Mdot
.14905 .09807 Mdot
.12944 .08239 Mdot
.11768 .09415 Mdot
.10591 .09807 Mdot
.1216 .12552 Mdot
.10591 .11768 Mdot
.23139 .23924 Mdot
.21963 .22747 Mdot
.24708 .251 Mdot
.27061 .27061 Mdot
.28629 .27453 Mdot
.251 .23531 Mdot
.38432 .3608 Mdot
.60391 .57254 Mdot
.53333 .51372 Mdot
.57254 .54509 Mdot
.53725 .5098 Mdot
.5647 .53725 Mdot
.55686 .53725 Mdot
.54902 .53725 Mdot
.55294 .54509 Mdot
.54902 .54117 Mdot
.52549 .52157 Mdot
.52157 .50196 Mdot
.50196 .47451 Mdot
.48628 .46275 Mdot
.47843 .45098 Mdot
.49804 .47059 Mdot
.48235 .46667 Mdot
.47843 .45883 Mdot
.43922 .42354 Mdot
.42746 .41569 Mdot
.42354 .41961 Mdot
.45098 .44706 Mdot
.46667 .46275 Mdot
.47843 .47059 Mdot
.48235 .47059 Mdot
.48628 .46667 Mdot
.48235 .46275 Mdot
.49412 .46275 Mdot
.4902 .45491 Mdot
.46667 .44314 Mdot
.44314 .42746 Mdot
.42746 .41569 Mdot
.39609 .38824 Mdot
.35687 .35687 Mdot
.29413 .29413 Mdot
.15297 .16081 Mdot
.11768 .11376 Mdot
.09023 .07846 Mdot
.04317 .02749 Mdot
.02749 .0118 Mdot
.01572 .00788 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.01572 .00396 Mdot
.08631 .03533 Mdot
.12944 .07062 Mdot
.1412 .08239 Mdot
.14513 .09807 Mdot
.88232 .87056 Mdot
.62744 .6196 Mdot
.37256 .33727 Mdot
.4353 .3804 Mdot
.43922 .37648 Mdot
.35687 .29806 Mdot
.31766 .26276 Mdot
.27845 .23531 Mdot
.27061 .22747 Mdot
.26276 .21571 Mdot
.21571 .17257 Mdot
.19218 .15297 Mdot
.16865 .12944 Mdot
.14905 .11768 Mdot
.12552 .09807 Mdot
.12552 .09807 Mdot
.1412 .10983 Mdot
.15297 .12552 Mdot
.16865 .14513 Mdot
.17257 .15689 Mdot
.13728 .13336 Mdot
.11768 .11376 Mdot
.09023 .09023 Mdot
.07846 .07846 Mdot
.07062 .07454 Mdot
.07062 .07454 Mdot
.09023 .09023 Mdot
.10983 .10199 Mdot
.13728 .1216 Mdot
.15689 .12552 Mdot
.16081 .1216 Mdot
.12944 .08631 Mdot
.11768 .07846 Mdot
.10983 .08631 Mdot
.10199 .09023 Mdot
.09415 .09807 Mdot
.12552 .14513 Mdot
.24316 .26668 Mdot
.40393 .41961 Mdot
.39217 .41177 Mdot
.39609 .40785 Mdot
.41177 .39609 Mdot
.36472 .34511 Mdot
.27061 .25884 Mdot
.75292 .70587 Mdot
.46667 .46275 Mdot
.46667 .47059 Mdot
.35687 .36472 Mdot
.37256 .36864 Mdot
.48628 .47451 Mdot
.52157 .50196 Mdot
.53725 .51765 Mdot
.54902 .54117 Mdot
.53333 .52941 Mdot
.54902 .53725 Mdot
.33335 .34119 Mdot
.39609 .38432 Mdot
.5098 .47059 Mdot
.47059 .43922 Mdot
.47059 .45491 Mdot
.48628 .48235 Mdot
.50196 .50196 Mdot
.50196 .50196 Mdot
.49804 .4902 Mdot
.46667 .45491 Mdot
.46667 .45883 Mdot
.45883 .45883 Mdot
.46275 .46275 Mdot
.45098 .46275 Mdot
.45491 .45883 Mdot
.45883 .45098 Mdot
.47059 .45098 Mdot
.46667 .45098 Mdot
.47059 .44706 Mdot
.46667 .45098 Mdot
.46667 .45491 Mdot
.46667 .45098 Mdot
.48235 .46667 Mdot
.22747 .23924 Mdot
.07454 .09415 Mdot
.05102 .05102 Mdot
.00788 .00788 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.0118 .00396 Mdot
.04317 .0118 Mdot
.06278 .01965 Mdot
.09415 .04317 Mdot
.1412 .08239 Mdot
.15297 .09415 Mdot
.90585 .89409 Mdot
.75292 .70194 Mdot
.6196 .56078 Mdot
.54117 .48628 Mdot
.46667 .41177 Mdot
.34119 .29806 Mdot
.32158 .27061 Mdot
.27453 .21571 Mdot
.22355 .17257 Mdot
.20002 .16081 Mdot
.16473 .13336 Mdot
.14905 .1216 Mdot
.15689 .11768 Mdot
.16473 .12944 Mdot
.16473 .13728 Mdot
.15689 .12944 Mdot
.13336 .11768 Mdot
.11768 .10591 Mdot
.10199 .09807 Mdot
.10199 .10199 Mdot
.07846 .09023 Mdot
.09023 .09807 Mdot
.11376 .10983 Mdot
.13728 .12552 Mdot
.14513 .12944 Mdot
.16865 .14513 Mdot
.17257 .14905 Mdot
.18042 .15689 Mdot
.16865 .12552 Mdot
.14513 .10591 Mdot
.1412 .11768 Mdot
.12552 .10983 Mdot
.11768 .10983 Mdot
.10199 .11376 Mdot
.31766 .32943 Mdot
.65489 .63528 Mdot
.46275 .45098 Mdot
.33335 .3255 Mdot
.33335 .3059 Mdot
.251 .23139 Mdot
.27453 .25884 Mdot
.53333 .50588 Mdot
.44314 .43922 Mdot
.45883 .45883 Mdot
.37648 .37648 Mdot
.35687 .34511 Mdot
.44706 .42354 Mdot
.49804 .47843 Mdot
.51372 .49804 Mdot
.52549 .51765 Mdot
.53333 .52549 Mdot
.55294 .54117 Mdot
.251 .26276 Mdot
.29806 .29806 Mdot
.64313 .59999 Mdot
.23924 .23531 Mdot
.3608 .36864 Mdot
.59607 .58823 Mdot
.43922 .45098 Mdot
.42354 .44314 Mdot
.45098 .46667 Mdot
.47451 .47843 Mdot
.45883 .46275 Mdot
.44706 .45491 Mdot
.45491 .47059 Mdot
.44706 .47451 Mdot
.45491 .47843 Mdot
.45491 .46667 Mdot
.45491 .45491 Mdot
.45491 .44314 Mdot
.45491 .4353 Mdot
.4353 .40785 Mdot
.4353 .40393 Mdot
.43138 .39609 Mdot
.42354 .39217 Mdot
.20002 .1961 Mdot
.05886 .0667 Mdot
.02749 .02357 Mdot
.01965 .01572 Mdot
.0118 .00788 Mdot
.00788 .0118 Mdot
.00396 .00788 Mdot
.00396 .00396 Mdot
.00788 .00396 Mdot
.03533 .0118 Mdot
.10199 .05886 Mdot
.11768 .07062 Mdot
.13336 .09023 Mdot
.13728 .09023 Mdot
.1412 .09023 Mdot
.8588 .81174 Mdot
.75292 .67842 Mdot
.56862 .48235 Mdot
.51765 .44706 Mdot
.33335 .28237 Mdot
.27453 .21179 Mdot
.24708 .18434 Mdot
.21571 .16865 Mdot
.18826 .14905 Mdot
.18826 .1412 Mdot
.18434 .12944 Mdot
.17257 .12552 Mdot
.15689 .11768 Mdot
.13336 .10591 Mdot
.1216 .10199 Mdot
.10983 .09415 Mdot
.10199 .09415 Mdot
.09807 .09415 Mdot
.11376 .10983 Mdot
.13728 .12944 Mdot
.1765 .15297 Mdot
.18042 .15297 Mdot
.18826 .16081 Mdot
.18826 .16473 Mdot
.18826 .15689 Mdot
.18826 .15689 Mdot
.18042 .14905 Mdot
.1765 .14905 Mdot
.15297 .12552 Mdot
.10591 .08239 Mdot
.09807 .07454 Mdot
.08631 .0667 Mdot
.24316 .21179 Mdot
.33335 .29021 Mdot
.21963 .18434 Mdot
.22355 .18434 Mdot
.18042 .15689 Mdot
.17257 .15297 Mdot
.16865 .15689 Mdot
.14513 .13728 Mdot
.44706 .41569 Mdot
.39217 .3608 Mdot
.39217 .3608 Mdot
.43138 .40393 Mdot
.45883 .4353 Mdot
.46667 .45098 Mdot
.47451 .47059 Mdot
.48628 .4902 Mdot
.50196 .50588 Mdot
.41961 .42354 Mdot
.44706 .43138 Mdot
.58431 .54902 Mdot
.23531 .24708 Mdot
.29021 .30982 Mdot
.62744 .62352 Mdot
.54509 .54117 Mdot
.40785 .41569 Mdot
.51765 .5098 Mdot
.46667 .46275 Mdot
.26668 .27453 Mdot
.34119 .35295 Mdot
.47843 .4902 Mdot
.44314 .47059 Mdot
.42354 .45098 Mdot
.4353 .45098 Mdot
.44314 .44314 Mdot
.44706 .4353 Mdot
.45883 .43138 Mdot
.4353 .40785 Mdot
.42746 .39609 Mdot
.39217 .35687 Mdot
.3059 .28237 Mdot
.18434 .1765 Mdot
.07454 .07454 Mdot
.05494 .05102 Mdot
.04317 .03925 Mdot
.02749 .02357 Mdot
.02749 .01965 Mdot
.0118 .00788 Mdot
.0118 .00788 Mdot
.03533 .02749 Mdot
.06278 .05102 Mdot
.13336 .09807 Mdot
.15689 .11376 Mdot
.16081 .12552 Mdot
.16473 .12944 Mdot
.16473 .12944 Mdot
.83527 .78429 Mdot
.58039 .48235 Mdot
.31766 .22747 Mdot
.34119 .251 Mdot
.30982 .23531 Mdot
.28629 .22747 Mdot
.27453 .21571 Mdot
.251 .1961 Mdot
.22355 .1765 Mdot
.18826 .14513 Mdot
.15297 .11768 Mdot
.13728 .10983 Mdot
.12944 .10199 Mdot
.11768 .09807 Mdot
.11768 .09415 Mdot
.13336 .10591 Mdot
.15689 .12944 Mdot
.19218 .15689 Mdot
.21571 .16865 Mdot
.22355 .18042 Mdot
.21179 .17257 Mdot
.21571 .1765 Mdot
.20002 .16473 Mdot
.18434 .14905 Mdot
.17257 .1412 Mdot
.18434 .16081 Mdot
.15297 .12944 Mdot
.11768 .09807 Mdot
.10591 .09023 Mdot
.09023 .07846 Mdot
.09023 .07454 Mdot
.11376 .09023 Mdot
.10983 .08631 Mdot
.10591 .09023 Mdot
.12552 .11376 Mdot
.13336 .1216 Mdot
.10199 .09807 Mdot
.23139 .21179 Mdot
.3608 .31374 Mdot
.39609 .34903 Mdot
.52549 .47059 Mdot
.41961 .38432 Mdot
.33335 .3059 Mdot
.27453 .27061 Mdot
.33727 .35687 Mdot
.38824 .41961 Mdot
.44314 .46667 Mdot
.44706 .45883 Mdot
.47059 .47451 Mdot
.41569 .43922 Mdot
.41177 .43922 Mdot
.47843 .4902 Mdot
.58039 .57254 Mdot
.53725 .52157 Mdot
.53725 .51765 Mdot
.40001 .38824 Mdot
.15689 .18042 Mdot
.18042 .21963 Mdot
.56862 .57254 Mdot
.3255 .3608 Mdot
.25492 .29021 Mdot
.38824 .40393 Mdot
.45883 .45491 Mdot
.34119 .33727 Mdot
.31374 .29806 Mdot
.3804 .34903 Mdot
.40393 .37648 Mdot
.39217 .36472 Mdot
.29806 .28237 Mdot
.15297 .15297 Mdot
.09807 .10199 Mdot
.0667 .06278 Mdot
.03925 .03925 Mdot
.03141 .03141 Mdot
.02749 .01965 Mdot
.01965 .0118 Mdot
.0118 .00788 Mdot
.11376 .09023 Mdot
.16081 .12944 Mdot
.16865 .12944 Mdot
.17257 .12944 Mdot
.16865 .13728 Mdot
.15689 .12944 Mdot
.15297 .12552 Mdot
.87448 .85095 Mdot
.72939 .68234 Mdot
.5647 .47059 Mdot
.58039 .48235 Mdot
.49804 .40785 Mdot
.36472 .29413 Mdot
.26668 .21963 Mdot
.23531 .1961 Mdot
.18042 .14513 Mdot
.16473 .12944 Mdot
.15689 .1216 Mdot
.15297 .1216 Mdot
.15689 .11376 Mdot
.16081 .11768 Mdot
.16865 .1412 Mdot
.20787 .17257 Mdot
.24316 .1961 Mdot
.25492 .21179 Mdot
.23924 .20787 Mdot
.21571 .1961 Mdot
.18826 .16865 Mdot
.17257 .15689 Mdot
.15689 .14513 Mdot
.1412 .13336 Mdot
.14905 .13336 Mdot
.13336 .11376 Mdot
.1216 .09807 Mdot
.09807 .07846 Mdot
.11768 .09415 Mdot
.10199 .07846 Mdot
.08631 .06278 Mdot
.10591 .07846 Mdot
.1216 .09415 Mdot
.13336 .11376 Mdot
.1216 .11376 Mdot
.09415 .09023 Mdot
.1412 .12944 Mdot
.16865 .15689 Mdot
.26276 .23531 Mdot
.26668 .23139 Mdot
.26668 .23139 Mdot
.18826 .15689 Mdot
.1765 .14905 Mdot
.1765 .16473 Mdot
.27845 .27453 Mdot
.34119 .32943 Mdot
.39217 .37648 Mdot
.3255 .31766 Mdot
.29021 .29806 Mdot
.44314 .43922 Mdot
.45098 .45098 Mdot
.47059 .46667 Mdot
.48628 .48628 Mdot
.45098 .45098 Mdot
.18042 .21179 Mdot
.20394 .24316 Mdot
.45883 .47451 Mdot
.48628 .49412 Mdot
.25884 .27845 Mdot
.41569 .40785 Mdot
.44706 .43138 Mdot
.24708 .23924 Mdot
.08631 .08631 Mdot
.19218 .18042 Mdot
.43138 .40393 Mdot
.3059 .29021 Mdot
.20787 .21179 Mdot
.18826 .18826 Mdot
.10983 .10983 Mdot
.09415 .09415 Mdot
.05102 .05102 Mdot
.02749 .02749 Mdot
.02749 .01965 Mdot
.01965 .00788 Mdot
.02357 .0118 Mdot
.16473 .12944 Mdot
.251 .20787 Mdot
.24708 .20394 Mdot
.1961 .16081 Mdot
.17257 .1412 Mdot
.15689 .12552 Mdot
.14905 .1216 Mdot
.93722 .91369 Mdot
.78429 .72155 Mdot
.60783 .52549 Mdot
.27061 .23139 Mdot
.30982 .27061 Mdot
.25884 .22747 Mdot
.23924 .20002 Mdot
.22747 .18434 Mdot
.23139 .18434 Mdot
.23531 .18826 Mdot
.23531 .18826 Mdot
.22355 .18434 Mdot
.23531 .20002 Mdot
.28629 .24316 Mdot
.30198 .25884 Mdot
.23924 .21963 Mdot
.22747 .21571 Mdot
.21571 .20787 Mdot
.18042 .1765 Mdot
.16473 .16865 Mdot
.15689 .15689 Mdot
.16473 .15689 Mdot
.16081 .14513 Mdot
.14513 .12944 Mdot
.13336 .11376 Mdot
.1412 .11768 Mdot
.1216 .10199 Mdot
.09415 .07062 Mdot
.12944 .09415 Mdot
.1412 .10983 Mdot
.15297 .12552 Mdot
.13336 .10983 Mdot
.11768 .10591 Mdot
.10199 .09415 Mdot
.09415 .08631 Mdot
.12944 .11376 Mdot
.15297 .12552 Mdot
.15689 .12552 Mdot
.14905 .1216 Mdot
.1412 .10983 Mdot
.13336 .10199 Mdot
.14513 .11376 Mdot
.16081 .13728 Mdot
.41177 .36864 Mdot
.29806 .25884 Mdot
.20787 .17257 Mdot
.16473 .14905 Mdot
.31374 .29021 Mdot
.3255 .31766 Mdot
.3608 .37256 Mdot
.45883 .47059 Mdot
.47451 .49412 Mdot
.34903 .3804 Mdot
.36864 .38432 Mdot
.41177 .41177 Mdot
.42746 .41569 Mdot
.43922 .42354 Mdot
.43138 .42746 Mdot
.31766 .32943 Mdot
.17257 .1961 Mdot
.30982 .3059 Mdot
.34119 .33335 Mdot
.34511 .34119 Mdot
.25492 .25492 Mdot
.10591 .1216 Mdot
.10983 .11376 Mdot
.08239 .07454 Mdot
.05494 .04709 Mdot
.03925 .03141 Mdot
.02749 .01965 Mdot
.03533 .02749 Mdot
.05494 .03925 Mdot
.07454 .05102 Mdot
.251 .20787 Mdot
.28629 .251 Mdot
.23531 .21179 Mdot
.20787 .20002 Mdot
.16865 .15689 Mdot
.13336 .12552 Mdot
.8039 .76076 Mdot
.59999 .55294 Mdot
.54902 .48628 Mdot
.47059 .40785 Mdot
.41177 .35295 Mdot
.39609 .33335 Mdot
.37256 .31374 Mdot
.35295 .30198 Mdot
.3059 .26668 Mdot
.27845 .24708 Mdot
.27453 .23531 Mdot
.26668 .22747 Mdot
.251 .21963 Mdot
.23531 .21179 Mdot
.21963 .21179 Mdot
.21179 .20787 Mdot
.20787 .20394 Mdot
.21179 .21179 Mdot
.19218 .1961 Mdot
.18042 .1765 Mdot
.18434 .1765 Mdot
.1765 .16865 Mdot
.16865 .16081 Mdot
.13336 .11768 Mdot
.10591 .09023 Mdot
.10983 .09415 Mdot
.12552 .10199 Mdot
.13728 .10591 Mdot
.12552 .10591 Mdot
.10983 .09415 Mdot
.08631 .07454 Mdot
.12944 .10983 Mdot
.18826 .16473 Mdot
.18042 .15297 Mdot
.16081 .13728 Mdot
.12552 .10199 Mdot
.11768 .09023 Mdot
.10983 .08239 Mdot
.11768 .09415 Mdot
.10983 .08239 Mdot
.15689 .11768 Mdot
.1961 .15297 Mdot
.20787 .15689 Mdot
.18826 .13728 Mdot
.15689 .11768 Mdot
.13728 .10983 Mdot
.13336 .12552 Mdot
.18826 .18434 Mdot
.38432 .37256 Mdot
.27453 .28237 Mdot
.24316 .25492 Mdot
.28237 .28237 Mdot
.36472 .35295 Mdot
.40001 .40001 Mdot
.41177 .42746 Mdot
.41569 .42746 Mdot
.38824 .39609 Mdot
.41569 .41569 Mdot
.33335 .33727 Mdot
.27453 .29021 Mdot
.30982 .30982 Mdot
.10591 .11768 Mdot
.09415 .10199 Mdot
.05494 .05102 Mdot
.04317 .02749 Mdot
.03533 .01572 Mdot
.03925 .02357 Mdot
.07062 .05886 Mdot
.0667 .05886 Mdot
.05494 .05886 Mdot
.07846 .08631 Mdot
.09415 .09807 Mdot
.1216 .11768 Mdot
.21571 .20394 Mdot
.20002 .19218 Mdot
.15689 .15297 Mdot
.81958 .78821 Mdot
.65097 .57254 Mdot
.53333 .45883 Mdot
.4902 .41569 Mdot
.39609 .33335 Mdot
.34511 .29806 Mdot
.3255 .27845 Mdot
.29413 .25492 Mdot
.28237 .23924 Mdot
.25884 .21963 Mdot
.251 .21963 Mdot
.23924 .20787 Mdot
.30198 .26668 Mdot
.30198 .28237 Mdot
.28237 .26668 Mdot
.25492 .23531 Mdot
.21571 .1961 Mdot
.1961 .18042 Mdot
.1765 .16081 Mdot
.17257 .16081 Mdot
.15297 .14513 Mdot
.12552 .10983 Mdot
.10983 .08631 Mdot
.12944 .10199 Mdot
.1412 .10983 Mdot
.13728 .10591 Mdot
.11768 .09023 Mdot
.10199 .07846 Mdot
.14905 .12944 Mdot
.16865 .14905 Mdot
.16865 .14513 Mdot
.16473 .13728 Mdot
.15297 .12944 Mdot
.12944 .10983 Mdot
.12552 .10199 Mdot
.10591 .08239 Mdot
.10591 .07454 Mdot
.07846 .04317 Mdot
.09415 .05494 Mdot
.10983 .07062 Mdot
.13728 .09023 Mdot
.12552 .08239 Mdot
.09807 .06278 Mdot
.08631 .0667 Mdot
.08239 .0667 Mdot
.22355 .20002 Mdot
.3255 .3059 Mdot
.12552 .13336 Mdot
.14513 .15689 Mdot
.14513 .16865 Mdot
.18434 .20394 Mdot
.32158 .32943 Mdot
.3804 .37648 Mdot
.39217 .38432 Mdot
.38824 .38824 Mdot
.37256 .38432 Mdot
.20394 .22747 Mdot
.22355 .23139 Mdot
.21571 .20787 Mdot
.10199 .09807 Mdot
.0667 .06278 Mdot
.07062 .05886 Mdot
.07062 .04709 Mdot
.07062 .04709 Mdot
.07062 .05494 Mdot
.0667 .05494 Mdot
.05102 .04709 Mdot
.04709 .04317 Mdot
.04317 .04317 Mdot
.04317 .04709 Mdot
.09023 .09023 Mdot
.11376 .10983 Mdot
.14905 .1412 Mdot
.91761 .89409 Mdot
.80782 .77253 Mdot
.58431 .51372 Mdot
.45098 .3804 Mdot
.4353 .36472 Mdot
.38824 .33727 Mdot
.34119 .3059 Mdot
.3059 .27845 Mdot
.29021 .26668 Mdot
.25884 .23139 Mdot
.35295 .31766 Mdot
.40785 .37256 Mdot
.41177 .36864 Mdot
.39217 .33727 Mdot
.20002 .15689 Mdot
.17257 .13728 Mdot
.15297 .1216 Mdot
.13336 .11376 Mdot
.13728 .12944 Mdot
.13728 .12944 Mdot
.13336 .12944 Mdot
.14905 .13728 Mdot
.14905 .13336 Mdot
.13336 .13336 Mdot
.11768 .1216 Mdot
.12552 .12944 Mdot
.21571 .21179 Mdot
.21963 .20787 Mdot
.18434 .16473 Mdot
.17257 .14513 Mdot
.15297 .12552 Mdot
.15689 .1216 Mdot
.16473 .13728 Mdot
.14513 .11768 Mdot
.10591 .07846 Mdot
.08239 .04317 Mdot
.0667 .02357 Mdot
.10199 .05102 Mdot
.12552 .06278 Mdot
.10199 .04709 Mdot
.07062 .03141 Mdot
.05494 .03141 Mdot
.05102 .03141 Mdot
.10199 .08239 Mdot
.33335 .29806 Mdot
.16081 .15297 Mdot
.15689 .16473 Mdot
.1216 .13728 Mdot
.10199 .11768 Mdot
.09023 .10199 Mdot
.17257 .16473 Mdot
.21179 .18042 Mdot
.1765 .1412 Mdot
.21179 .18042 Mdot
.251 .22747 Mdot
.31374 .29413 Mdot
.27845 .24708 Mdot
.05102 .03533 Mdot
.08631 .07062 Mdot
.10591 .09023 Mdot
.09415 .08239 Mdot
.10591 .09023 Mdot
.09023 .07846 Mdot
.0667 .0667 Mdot
.04317 .05102 Mdot
.04709 .05494 Mdot
.04317 .04317 Mdot
.05102 .05102 Mdot
.05102 .0667 Mdot
.05494 .07062 Mdot
.10591 .11376 Mdot
.91761 .89801 Mdot
.70979 .65881 Mdot
.62352 .55686 Mdot
.42354 .3804 Mdot
.37256 .34511 Mdot
.34511 .31374 Mdot
.3255 .29021 Mdot
.27061 .23924 Mdot
.27453 .23924 Mdot
.32158 .27453 Mdot
.27061 .23924 Mdot
.20394 .1765 Mdot
.18042 .15689 Mdot
.16473 .14513 Mdot
.13728 .1216 Mdot
.12944 .12552 Mdot
.13728 .13728 Mdot
.16473 .16473 Mdot
.16865 .17257 Mdot
.16865 .1765 Mdot
.16865 .1765 Mdot
.13728 .15297 Mdot
.14513 .16473 Mdot
.29413 .29806 Mdot
.25884 .26668 Mdot
.21179 .21571 Mdot
.1961 .18826 Mdot
.19218 .17257 Mdot
.18434 .16473 Mdot
.18434 .16473 Mdot
.1412 .12552 Mdot
.10199 .09023 Mdot
.0667 .05102 Mdot
.07062 .03533 Mdot
.09807 .05494 Mdot
.11768 .0667 Mdot
.11376 .07062 Mdot
.08631 .05102 Mdot
.0667 .04317 Mdot
.04709 .03533 Mdot
.04317 .03533 Mdot
.09023 .07454 Mdot
.09807 .09415 Mdot
.09415 .09415 Mdot
.07846 .09023 Mdot
.07454 .08631 Mdot
.07846 .09023 Mdot
.10983 .10983 Mdot
.10983 .09023 Mdot
.10199 .07062 Mdot
.09807 .05886 Mdot
.08631 .05494 Mdot
.14513 .10199 Mdot
.16081 .11768 Mdot
.11768 .08631 Mdot
.1412 .10983 Mdot
.13336 .11376 Mdot
.12944 .10591 Mdot
.21179 .1765 Mdot
.16865 .1412 Mdot
.14905 .12944 Mdot
.12552 .11376 Mdot
.12552 .10983 Mdot
.10983 .09415 Mdot
.09415 .08239 Mdot
.07454 .07454 Mdot
.06278 .07846 Mdot
.07454 .09023 Mdot
.83527 .80782 Mdot
.63528 .60391 Mdot
.40393 .37256 Mdot
.40393 .36864 Mdot
.32158 .29021 Mdot
.30198 .27453 Mdot
.28237 .24708 Mdot
.24708 .21963 Mdot
.21963 .20002 Mdot
.18434 .1765 Mdot
.16081 .15297 Mdot
.15297 .14905 Mdot
.13336 .13728 Mdot
.15297 .15689 Mdot
.1765 .17257 Mdot
.19218 .18434 Mdot
.18434 .17257 Mdot
.18042 .16473 Mdot
.1765 .16473 Mdot
.1765 .17257 Mdot
.20394 .20394 Mdot
.20394 .20787 Mdot
.20002 .19218 Mdot
.1961 .18826 Mdot
.19218 .18042 Mdot
.20002 .18826 Mdot
.18434 .18042 Mdot
.14513 .14513 Mdot
.13336 .13336 Mdot
.10983 .10199 Mdot
.09807 .08631 Mdot
.10983 .09023 Mdot
.1216 .09415 Mdot
.10591 .07846 Mdot
.09023 .0667 Mdot
.06278 .04709 Mdot
.0667 .04317 Mdot
.05886 .03141 Mdot
.07454 .05102 Mdot
.09023 .07062 Mdot
.09807 .09415 Mdot
.08239 .08631 Mdot
.0667 .0667 Mdot
.07062 .06278 Mdot
.09023 .07846 Mdot
.09023 .06278 Mdot
.08239 .05494 Mdot
.08631 .05494 Mdot
.08631 .05494 Mdot
.07454 .04709 Mdot
.09807 .07454 Mdot
.09807 .08239 Mdot
.10983 .09807 Mdot
.09807 .09415 Mdot
.10199 .09415 Mdot
.14513 .1216 Mdot
.20394 .15689 Mdot
.20394 .14513 Mdot
.16081 .09807 Mdot
.20394 .12944 Mdot
.23139 .16081 Mdot
.18434 .12944 Mdot
.17257 .13336 Mdot
.15297 .13336 Mdot
.11768 .10983 Mdot
.79998 .77253 Mdot
.51372 .46667 Mdot
.41569 .37648 Mdot
.3804 .34119 Mdot
.31374 .27845 Mdot
.28629 .251 Mdot
.22355 .20394 Mdot
.20394 .18826 Mdot
.18826 .18042 Mdot
.16473 .16865 Mdot
.16081 .16473 Mdot
.16473 .16865 Mdot
.18434 .18434 Mdot
.18826 .18042 Mdot
.18434 .17257 Mdot
.19218 .16865 Mdot
.1961 .16865 Mdot
.16865 .14513 Mdot
.16081 .1412 Mdot
.14513 .13336 Mdot
.15297 .13728 Mdot
.1765 .15297 Mdot
.19218 .17257 Mdot
.17257 .15689 Mdot
.16865 .15689 Mdot
.16081 .15689 Mdot
.13728 .13336 Mdot
.15297 .1412 Mdot
.17257 .15689 Mdot
.13728 .12944 Mdot
.10983 .09807 Mdot
.08239 .07062 Mdot
.0667 .05494 Mdot
.05102 .04317 Mdot
.04709 .03925 Mdot
.07846 .07062 Mdot
.08631 .07846 Mdot
.10199 .09807 Mdot
.08631 .08239 Mdot
.07062 .0667 Mdot
.0667 .05886 Mdot
.08631 .07062 Mdot
.08239 .05886 Mdot
.07062 .04709 Mdot
.06278 .04317 Mdot
.05494 .03925 Mdot
.05494 .03925 Mdot
.05102 .03141 Mdot
.06278 .04317 Mdot
.08239 .06278 Mdot
.07454 .05886 Mdot
.10983 .09415 Mdot
.13336 .10591 Mdot
.15689 .11376 Mdot
.17257 .10199 Mdot
.11376 .03533 Mdot
.21179 .1216 Mdot
.12944 .07062 Mdot
.20787 .16865 Mdot
.16081 .1412 Mdot
.18434 .16865 Mdot
.1961 .18434 Mdot
.91761 .90585 Mdot
.74116 .72547 Mdot
.49804 .47451 Mdot
.41569 .39217 Mdot
.29021 .27453 Mdot
.29021 .27061 Mdot
.23139 .21963 Mdot
.20787 .1961 Mdot
.20002 .18434 Mdot
.19218 .1765 Mdot
.18434 .1765 Mdot
.18826 .18042 Mdot
.1765 .16473 Mdot
.17257 .15297 Mdot
.18434 .16473 Mdot
.17257 .14905 Mdot
.15297 .13336 Mdot
.14513 .12552 Mdot
.13336 .1216 Mdot
.13728 .1216 Mdot
.13336 .11768 Mdot
.1412 .12552 Mdot
.1412 .13728 Mdot
.15689 .14905 Mdot
.14513 .1412 Mdot
.15297 .14905 Mdot
.21963 .19218 Mdot
.14513 .1216 Mdot
.10591 .09023 Mdot
.07454 .07062 Mdot
.0667 .05886 Mdot
.06278 .05102 Mdot
.06278 .05102 Mdot
.07846 .06278 Mdot
.10199 .08631 Mdot
.10591 .09415 Mdot
.10199 .08631 Mdot
.09415 .07062 Mdot
.09807 .07846 Mdot
.11376 .08631 Mdot
.09807 .07062 Mdot
.09415 .0667 Mdot
.0667 .05494 Mdot
.05886 .05494 Mdot
.05886 .05886 Mdot
.05102 .04317 Mdot
.03141 .01572 Mdot
.04317 .02357 Mdot
.04317 .02357 Mdot
.05102 .01965 Mdot
.05886 .02749 Mdot
.08239 .04317 Mdot
.11376 .07062 Mdot
.10199 .05886 Mdot
.29806 .23139 Mdot
.0667 .04317 Mdot
.40393 .36472 Mdot
.36472 .33335 Mdot
.06278 .06278 Mdot
.11768 .10983 Mdot
.90585 .89409 Mdot
.61568 .58823 Mdot
.48235 .4353 Mdot
.34119 .29021 Mdot
.32158 .26276 Mdot
.29413 .23139 Mdot
.26668 .20787 Mdot
.24708 .20002 Mdot
.24708 .20002 Mdot
.18042 .15689 Mdot
.18042 .15297 Mdot
.1765 .14513 Mdot
.16865 .1412 Mdot
.14905 .12552 Mdot
.14905 .12944 Mdot
.15689 .1412 Mdot
.14513 .13336 Mdot
.12552 .10983 Mdot
.1216 .10983 Mdot
.13728 .1216 Mdot
.12944 .1216 Mdot
.13336 .11768 Mdot
.1412 .11376 Mdot
.13728 .11376 Mdot
.1412 .11376 Mdot
.11768 .08631 Mdot
.09415 .07062 Mdot
.09023 .06278 Mdot
.08239 .05494 Mdot
.08239 .05494 Mdot
.09807 .0667 Mdot
.09415 .06278 Mdot
.10591 .07846 Mdot
.10983 .08631 Mdot
.09807 .07846 Mdot
.10591 .09415 Mdot
.11376 .09807 Mdot
.11376 .09415 Mdot
.10983 .09415 Mdot
.07062 .0667 Mdot
.05102 .05102 Mdot
.05886 .05886 Mdot
.04709 .04709 Mdot
.03925 .02357 Mdot
.03533 .01572 Mdot
.03533 .01965 Mdot
.03141 .01572 Mdot
.03925 .02749 Mdot
.03533 .01965 Mdot
.03925 .01965 Mdot
.03533 .0118 Mdot
.05102 .01572 Mdot
.08631 .04317 Mdot
.10591 .05886 Mdot
.13728 .08239 Mdot
.12944 .07846 Mdot
.09807 .05494 Mdot
.76861 .73724 Mdot
.59607 .55294 Mdot
.41569 .3608 Mdot
.34119 .28629 Mdot
.32158 .25884 Mdot
.29413 .23924 Mdot
.26668 .21571 Mdot
.23139 .18434 Mdot
.20002 .16473 Mdot
.16473 .13728 Mdot
.1412 .11768 Mdot
.13728 .1216 Mdot
.12944 .12552 Mdot
.13336 .12944 Mdot
.12944 .11768 Mdot
.11376 .09807 Mdot
.09807 .08239 Mdot
.09807 .07846 Mdot
.12944 .10591 Mdot
.10199 .07062 Mdot
.10983 .0667 Mdot
.1216 .07846 Mdot
.1216 .08239 Mdot
.1216 .08631 Mdot
.11768 .09023 Mdot
.10983 .09023 Mdot
.10199 .09023 Mdot
.09807 .08239 Mdot
.08631 .0667 Mdot
.09807 .07846 Mdot
.10591 .08239 Mdot
.11376 .09023 Mdot
.1216 .09807 Mdot
.11768 .09807 Mdot
.10983 .09415 Mdot
.10199 .09415 Mdot
.09415 .08239 Mdot
.08239 .06278 Mdot
.0667 .05102 Mdot
.05886 .03925 Mdot
.05102 .02749 Mdot
.04709 .01965 Mdot
.05102 .02749 Mdot
.04709 .01965 Mdot
.04317 .01965 Mdot
.03141 .01572 Mdot
.02749 .01572 Mdot
.02749 .0118 Mdot
.02749 .00396 Mdot
.04709 .00788 Mdot
.0667 .02357 Mdot
.09415 .03925 Mdot
.07062 .01965 Mdot
.05102 .0118 Mdot
.73724 .71371 Mdot
.42354 .37648 Mdot
.35687 .3059 Mdot
.31766 .26668 Mdot
.29021 .24316 Mdot
.24316 .21571 Mdot
.21571 .1961 Mdot
.20787 .18434 Mdot
.1961 .17257 Mdot
.17257 .16473 Mdot
.14905 .15297 Mdot
.13728 .14513 Mdot
.1216 .12944 Mdot
.10983 .11376 Mdot
.09807 .09415 Mdot
.11376 .10199 Mdot
.10199 .09023 Mdot
.10199 .07846 Mdot
.12552 .09807 Mdot
.13728 .11376 Mdot
.13336 .10983 Mdot
.12552 .11376 Mdot
.12552 .11376 Mdot
.13336 .1216 Mdot
.1216 .10591 Mdot
.10983 .09023 Mdot
.1216 .09023 Mdot
.13336 .09023 Mdot
.13728 .09415 Mdot
.15297 .10199 Mdot
.12944 .08239 Mdot
.13336 .08239 Mdot
.1216 .08239 Mdot
.1216 .09023 Mdot
.10983 .07846 Mdot
.10983 .07454 Mdot
.10591 .06278 Mdot
.08631 .05102 Mdot
.09415 .05102 Mdot
.07846 .04317 Mdot
.07454 .03533 Mdot
.07846 .04709 Mdot
.0667 .04709 Mdot
.05102 .03533 Mdot
.04709 .03141 Mdot
.04709 .02749 Mdot
.04709 .02357 Mdot
.04709 .02749 Mdot
.07062 .03925 Mdot
.06278 .03533 Mdot
.04709 .01965 Mdot
.87056 .86272 Mdot
.71763 .70587 Mdot
.40001 .38824 Mdot
.30982 .29806 Mdot
.28237 .27061 Mdot
.25884 .23531 Mdot
.23139 .20002 Mdot
.1961 .17257 Mdot
.16865 .16081 Mdot
.14513 .15297 Mdot
.12944 .13728 Mdot
.10983 .12552 Mdot
.11768 .12944 Mdot
.10983 .11376 Mdot
.09023 .09023 Mdot
.07454 .07062 Mdot
.07062 .07062 Mdot
.07846 .07454 Mdot
.08631 .08239 Mdot
.08239 .07454 Mdot
.09023 .07846 Mdot
.09807 .08239 Mdot
.09807 .07846 Mdot
.10591 .08631 Mdot
.09415 .06278 Mdot
.09023 .05102 Mdot
.10199 .05886 Mdot
.10983 .06278 Mdot
.10591 .05886 Mdot
.10591 .05886 Mdot
.09807 .05102 Mdot
.09807 .05494 Mdot
.09807 .05886 Mdot
.09415 .04709 Mdot
.09023 .04317 Mdot
.10199 .05494 Mdot
.10199 .05494 Mdot
.09807 .05886 Mdot
.08631 .05102 Mdot
.08239 .05102 Mdot
.06278 .04317 Mdot
.05494 .04317 Mdot
.04317 .04709 Mdot
.04709 .04709 Mdot
.05102 .04709 Mdot
.04709 .04317 Mdot
.05102 .04709 Mdot
.05494 .04709 Mdot
.04317 .03141 Mdot
.8784 .87056 Mdot
.59607 .56862 Mdot
.44314 .39217 Mdot
.24316 .20394 Mdot
.23531 .21179 Mdot
.1961 .18826 Mdot
.15297 .15689 Mdot
.12944 .14513 Mdot
.1216 .1412 Mdot
.12552 .14513 Mdot
.12552 .14513 Mdot
.11376 .13336 Mdot
.07846 .09807 Mdot
.05886 .08239 Mdot
.05886 .07454 Mdot
.05102 .05494 Mdot
.04317 .03141 Mdot
.06278 .04709 Mdot
.06278 .04317 Mdot
.05102 .03533 Mdot
.05494 .04317 Mdot
.05494 .02749 Mdot
.07062 .03533 Mdot
.07846 .03141 Mdot
.08239 .03533 Mdot
.07454 .01965 Mdot
.07062 .00788 Mdot
.09023 .01965 Mdot
.10199 .03141 Mdot
.08631 .02749 Mdot
.07454 .01965 Mdot
.06278 .0118 Mdot
.07062 .02749 Mdot
.07454 .03533 Mdot
.07062 .03925 Mdot
.0667 .05102 Mdot
.0667 .06278 Mdot
.05102 .05102 Mdot
.03925 .04317 Mdot
.02749 .02749 Mdot
.04317 .03925 Mdot
.05494 .05102 Mdot
.04709 .05102 Mdot
.04709 .05102 Mdot
.05494 .04709 Mdot
.04709 .03533 Mdot
.69018 .68234 Mdot
.45098 .45491 Mdot
.28629 .3059 Mdot
.18434 .21963 Mdot
.15689 .18826 Mdot
.13336 .16081 Mdot
.12552 .1412 Mdot
.10983 .12552 Mdot
.09023 .11376 Mdot
.09023 .10983 Mdot
.07846 .10199 Mdot
.06278 .08239 Mdot
.05886 .0667 Mdot
.0667 .06278 Mdot
.0667 .05886 Mdot
.06278 .05494 Mdot
.05102 .04709 Mdot
.03925 .03533 Mdot
.02749 .02357 Mdot
.0667 .05102 Mdot
.09023 .05102 Mdot
.07454 .03141 Mdot
.08239 .02357 Mdot
.07846 .0118 Mdot
.08631 .01965 Mdot
.09415 .02749 Mdot
.07846 .01965 Mdot
.08239 .02357 Mdot
.07062 .02357 Mdot
.07454 .02749 Mdot
.06278 .02749 Mdot
.06278 .03925 Mdot
.07454 .05102 Mdot
.07454 .05886 Mdot
.06278 .04709 Mdot
.04709 .03925 Mdot
.04317 .03141 Mdot
.03925 .03141 Mdot
.0667 .05886 Mdot
.04709 .05102 Mdot
.04709 .05102 Mdot
.05886 .05886 Mdot
.05886 .04709 Mdot
.57646 .60783 Mdot
.21179 .24316 Mdot
.21179 .21571 Mdot
.17257 .15689 Mdot
.13728 .1216 Mdot
.11768 .10591 Mdot
.11376 .10199 Mdot
.09807 .09415 Mdot
.09415 .10199 Mdot
.09415 .09807 Mdot
.08631 .09023 Mdot
.0667 .07454 Mdot
.07846 .08631 Mdot
.05494 .06278 Mdot
.04317 .05102 Mdot
.04317 .04709 Mdot
.05102 .04709 Mdot
.07454 .05102 Mdot
.07846 .04709 Mdot
.08239 .05102 Mdot
.0667 .03533 Mdot
.06278 .02357 Mdot
.07454 .02749 Mdot
.08631 .03925 Mdot
.08239 .03925 Mdot
.08631 .05494 Mdot
.09415 .05886 Mdot
.08631 .04317 Mdot
.07846 .04709 Mdot
.07454 .04317 Mdot
.07454 .04709 Mdot
.07846 .04709 Mdot
.05886 .03141 Mdot
.05494 .03141 Mdot
.05494 .02749 Mdot
.05886 .04317 Mdot
.0667 .05494 Mdot
.07062 .0667 Mdot
.07062 .0667 Mdot
.0667 .05886 Mdot
.81174 .8039 Mdot
.60783 .58823 Mdot
.19218 .15689 Mdot
.16473 .13336 Mdot
.1412 .11768 Mdot
.11768 .09807 Mdot
.10983 .09415 Mdot
.10983 .09415 Mdot
.10591 .09415 Mdot
.09415 .09023 Mdot
.07846 .07846 Mdot
.08239 .08239 Mdot
.07454 .07062 Mdot
.05102 .04709 Mdot
.07062 .0667 Mdot
.09415 .09023 Mdot
.09807 .08239 Mdot
.08631 .0667 Mdot
.08631 .0667 Mdot
.08239 .05494 Mdot
.09023 .05102 Mdot
.08239 .04317 Mdot
.08239 .05102 Mdot
.08239 .05494 Mdot
.08239 .05886 Mdot
.07846 .05102 Mdot
.07846 .05102 Mdot
.07062 .05102 Mdot
.0667 .05494 Mdot
.07454 .05494 Mdot
.07846 .04709 Mdot
.05886 .02357 Mdot
.04317 .0118 Mdot
.04709 .01572 Mdot
.05886 .03141 Mdot
.05494 .03141 Mdot
.05102 .03141 Mdot
.05494 .03141 Mdot
.59215 .57646 Mdot
.37256 .34511 Mdot
.14513 .10983 Mdot
.1412 .11768 Mdot
.12552 .10983 Mdot
.11376 .09415 Mdot
.10199 .08239 Mdot
.09415 .07846 Mdot
.09023 .09023 Mdot
.08631 .07846 Mdot
.06278 .05494 Mdot
.05494 .04317 Mdot
.07454 .05102 Mdot
.09023 .06278 Mdot
.10199 .07454 Mdot
.10983 .07846 Mdot
.10983 .07454 Mdot
.10983 .0667 Mdot
.09023 .05494 Mdot
.08631 .05886 Mdot
.08239 .05886 Mdot
.08239 .05886 Mdot
.07846 .05494 Mdot
.0667 .05102 Mdot
.05494 .03925 Mdot
.06278 .05494 Mdot
.07062 .06278 Mdot
.0667 .04317 Mdot
.06278 .03533 Mdot
.05886 .02749 Mdot
.06278 .02357 Mdot
.05494 .01572 Mdot
.05494 .0118 Mdot
.07062 .03141 Mdot
.06278 .03141 Mdot
.58431 .57646 Mdot
.35687 .3608 Mdot
.1216 .13336 Mdot
.13336 .14513 Mdot
.13728 .14905 Mdot
.10591 .12944 Mdot
.08239 .10199 Mdot
.06278 .0667 Mdot
.04709 .04709 Mdot
.05494 .05102 Mdot
.07062 .05886 Mdot
.09023 .07846 Mdot
.10199 .08631 Mdot
.11768 .09023 Mdot
.10983 .08239 Mdot
.09023 .07062 Mdot
.09023 .07454 Mdot
.08239 .07846 Mdot
.06278 .06278 Mdot
.05886 .05102 Mdot
.06278 .05494 Mdot
.0667 .05886 Mdot
.07846 .0667 Mdot
.0667 .05886 Mdot
.05494 .03925 Mdot
.05494 .03533 Mdot
.05494 .03533 Mdot
.05886 .03925 Mdot
.05886 .03533 Mdot
.0667 .03533 Mdot
.05494 .01965 Mdot
.03141 .00788 Mdot
.77645 .78429 Mdot
.62352 .63528 Mdot
.15689 .18826 Mdot
.1216 .16081 Mdot
.10199 .13728 Mdot
.07846 .09807 Mdot
.06278 .0667 Mdot
.05494 .05886 Mdot
.0667 .06278 Mdot
.08239 .07454 Mdot
.10199 .10199 Mdot
.1216 .11376 Mdot
.10983 .09415 Mdot
.09807 .07454 Mdot
.09807 .07454 Mdot
.10199 .09415 Mdot
.07846 .07846 Mdot
.07846 .07454 Mdot
.07846 .07062 Mdot
.08239 .0667 Mdot
.08239 .0667 Mdot
.08631 .07454 Mdot
.07062 .05886 Mdot
.05886 .04709 Mdot
.05886 .05102 Mdot
.05886 .05886 Mdot
.07062 .06278 Mdot
.05494 .04317 Mdot
.03141 .01965 Mdot
.02357 .00788 Mdot
.78037 .78821 Mdot
.56078 .57254 Mdot
.11768 .10983 Mdot
.13336 .10983 Mdot
.10591 .08239 Mdot
.10199 .07062 Mdot
.09023 .06278 Mdot
.10199 .08239 Mdot
.11376 .09415 Mdot
.11768 .09415 Mdot
.11376 .09415 Mdot
.12552 .11376 Mdot
.1216 .11376 Mdot
.10983 .10591 Mdot
.10591 .09415 Mdot
.09807 .09023 Mdot
.07454 .0667 Mdot
.09415 .07846 Mdot
.09023 .07846 Mdot
.07846 .07454 Mdot
.06278 .0667 Mdot
.04709 .05494 Mdot
.0667 .07454 Mdot
.07062 .07846 Mdot
.05494 .05494 Mdot
.03141 .02749 Mdot
.00788 .00788 Mdot
.59215 .56862 Mdot
.34903 .31374 Mdot
.12944 .08239 Mdot
.1216 .08239 Mdot
.10983 .08631 Mdot
.10983 .08631 Mdot
.11768 .09023 Mdot
.12552 .10591 Mdot
.12552 .10983 Mdot
.12552 .11768 Mdot
.11376 .11376 Mdot
.11376 .10983 Mdot
.10591 .10591 Mdot
.09415 .09023 Mdot
.09807 .09023 Mdot
.09807 .09023 Mdot
.08239 .07454 Mdot
.07846 .07062 Mdot
.06278 .06278 Mdot
.04709 .05102 Mdot
.04709 .04709 Mdot
.03925 .03533 Mdot
.02357 .01965 Mdot
.00788 .00396 Mdot
.57254 .56078 Mdot
.34903 .34119 Mdot
.10591 .10199 Mdot
.11376 .10591 Mdot
.12552 .11376 Mdot
.13728 .11768 Mdot
.13336 .11768 Mdot
.1216 .11768 Mdot
.11768 .11376 Mdot
.09807 .09807 Mdot
.09415 .09415 Mdot
.09807 .09415 Mdot
.10199 .09023 Mdot
.09807 .08631 Mdot
.07454 .07062 Mdot
.05494 .04709 Mdot
.03141 .03141 Mdot
.03141 .03141 Mdot
.02357 .01572 Mdot
.01965 .00788 Mdot
.01572 .00396 Mdot
.77253 .77645 Mdot
.54117 .54902 Mdot
.08239 .09023 Mdot
.08239 .07454 Mdot
.09807 .08239 Mdot
.09415 .08631 Mdot
.07846 .07846 Mdot
.08239 .08239 Mdot
.08239 .07846 Mdot
.09023 .07846 Mdot
.08239 .06278 Mdot
.07454 .04709 Mdot
.05494 .03141 Mdot
.03141 .01572 Mdot
.04317 .03141 Mdot
.05494 .03925 Mdot
.03533 .02357 Mdot
.03141 .01572 Mdot
.03141 .0118 Mdot
.76469 .76861 Mdot
.53333 .53333 Mdot
.08239 .07454 Mdot
.09807 .08631 Mdot
.08631 .07454 Mdot
.07846 .05886 Mdot
.08239 .05102 Mdot
.08631 .05102 Mdot
.07454 .04317 Mdot
.04709 .02749 Mdot
.04317 .01965 Mdot
.04709 .02357 Mdot
.05886 .03141 Mdot
.04709 .01965 Mdot
.03533 .0118 Mdot
.03533 .01572 Mdot
.58039 .57646 Mdot
.34903 .33727 Mdot
.11768 .10591 Mdot
.08631 .06278 Mdot
.08239 .05494 Mdot
.08239 .07454 Mdot
.07454 .07062 Mdot
.05494 .05886 Mdot
.05494 .05494 Mdot
.05886 .05102 Mdot
.05886 .03925 Mdot
.03141 .0118 Mdot
.03141 .00396 Mdot
.55686 .55686 Mdot
.33335 .33727 Mdot
.12944 .13728 Mdot
.10591 .11768 Mdot
.08239 .10983 Mdot
.05886 .08631 Mdot
.04317 .05886 Mdot
.03533 .03925 Mdot
.02749 .01572 Mdot
.02357 .00788 Mdot
.76469 .77253 Mdot
.54509 .55686 Mdot
.0667 .09415 Mdot
.03141 .0667 Mdot
.01572 .04317 Mdot
.0118 .01965 Mdot
.00788 .00788 Mdot
.01572 .0118 Mdot
.76469 .77645 Mdot
.51372 .53725 Mdot
.01965 .04317 Mdot
.01572 .02357 Mdot
.0118 .0118 Mdot
.50588 .51765 Mdot
.25492 .26668 Mdot
0 0 1 r
.83919 .84703 Mdot
.43138 .47451 Mdot
.40785 .44314 Mdot
.69802 .72155 Mdot
.4902 .53725 Mdot
.51372 .5647 Mdot
.51765 .5647 Mdot
.50196 .54902 Mdot
.63528 .67057 Mdot
.749 .77645 Mdot
.51372 .54902 Mdot
.52941 .57646 Mdot
.54509 .60391 Mdot
.54509 .61568 Mdot
.53725 .61568 Mdot
.52549 .60391 Mdot
.52549 .59607 Mdot
.65097 .70194 Mdot
.88232 .90193 Mdot
.5098 .56078 Mdot
.54117 .59215 Mdot
.54902 .61568 Mdot
.55294 .62744 Mdot
.55686 .6392 Mdot
.54902 .64313 Mdot
.54117 .6196 Mdot
.54509 .6196 Mdot
.54509 .6196 Mdot
.54902 .6196 Mdot
.77253 .81566 Mdot
.89017 .90977 Mdot
.49804 .55294 Mdot
.53725 .60391 Mdot
.54117 .61568 Mdot
.55294 .63136 Mdot
.5647 .64705 Mdot
.55686 .64705 Mdot
.55294 .62744 Mdot
.55686 .6196 Mdot
.55294 .61568 Mdot
.55686 .62352 Mdot
.55686 .62352 Mdot
.55294 .61568 Mdot
.55686 .60783 Mdot
.78429 .79998 Mdot
.52157 .57254 Mdot
.54117 .60783 Mdot
.55294 .62352 Mdot
.55294 .63136 Mdot
.55294 .62744 Mdot
.55294 .62744 Mdot
.55294 .62352 Mdot
.55686 .61568 Mdot
.54902 .60783 Mdot
.55294 .61176 Mdot
.55686 .60391 Mdot
.56078 .60783 Mdot
.5647 .60783 Mdot
.5647 .60783 Mdot
.58039 .61568 Mdot
.68626 .70194 Mdot
.79213 .8039 Mdot
.5098 .56078 Mdot
.53725 .59607 Mdot
.54117 .60391 Mdot
.54117 .60783 Mdot
.54117 .60783 Mdot
.54509 .60783 Mdot
.53725 .59607 Mdot
.54117 .58431 Mdot
.55294 .59607 Mdot
.56862 .61176 Mdot
.57254 .61568 Mdot
.57646 .62352 Mdot
.57646 .61568 Mdot
.57646 .61176 Mdot
.58431 .61568 Mdot
.58039 .61176 Mdot
.59215 .6196 Mdot
.5647 .59215 Mdot
.77253 .79213 Mdot
.88232 .88624 Mdot
.52157 .57646 Mdot
.52941 .59607 Mdot
.52941 .59999 Mdot
.52549 .60391 Mdot
.52941 .59215 Mdot
.54117 .59215 Mdot
.54509 .59215 Mdot
.55294 .59999 Mdot
.55294 .60391 Mdot
.56078 .61568 Mdot
.5647 .61568 Mdot
.57254 .61568 Mdot
.58039 .6196 Mdot
.58431 .6196 Mdot
.58823 .62352 Mdot
.59999 .63136 Mdot
.59215 .62352 Mdot
.58823 .6196 Mdot
.58039 .60783 Mdot
.58039 .60391 Mdot
.46275 .49804 Mdot
.72155 .73724 Mdot
.81958 .83135 Mdot
.50588 .55294 Mdot
.53725 .58823 Mdot
.54509 .60783 Mdot
.54509 .61176 Mdot
.53725 .61176 Mdot
.52549 .59999 Mdot
.53725 .60783 Mdot
.54902 .6196 Mdot
.55686 .62352 Mdot
.55686 .62744 Mdot
.5647 .62744 Mdot
.5647 .61568 Mdot
.57254 .6196 Mdot
.58823 .62352 Mdot
.58431 .6196 Mdot
.59999 .63528 Mdot
.59215 .62744 Mdot
.59999 .63136 Mdot
.59215 .6196 Mdot
.58431 .6196 Mdot
.59215 .62744 Mdot
.55686 .58431 Mdot
.44706 .46667 Mdot
.51372 .52549 Mdot
.66665 .66665 Mdot
.5098 .53725 Mdot
.54509 .59607 Mdot
.54902 .61568 Mdot
.53333 .61568 Mdot
.53333 .6196 Mdot
.52941 .62744 Mdot
.53333 .62744 Mdot
.53725 .62744 Mdot
.55294 .62744 Mdot
.56078 .63136 Mdot
.56862 .6392 Mdot
.57646 .64313 Mdot
.58039 .64313 Mdot
.59215 .6392 Mdot
.59215 .63136 Mdot
.59607 .62744 Mdot
.59607 .62744 Mdot
.59607 .63136 Mdot
.60783 .64313 Mdot
.60391 .6392 Mdot
.59607 .63528 Mdot
.58823 .63136 Mdot
.58431 .6196 Mdot
.54902 .58431 Mdot
.49412 .51765 Mdot
.41569 .42354 Mdot
.47059 .47843 Mdot
.63528 .63528 Mdot
.52941 .56862 Mdot
.55686 .61568 Mdot
.55686 .6392 Mdot
.54509 .64313 Mdot
.54117 .65097 Mdot
.54509 .64705 Mdot
.53725 .63136 Mdot
.53333 .62744 Mdot
.54509 .62744 Mdot
.55294 .63528 Mdot
.57254 .64313 Mdot
.57646 .64313 Mdot
.57646 .6392 Mdot
.58039 .6392 Mdot
.58823 .63136 Mdot
.58823 .62744 Mdot
.59999 .63136 Mdot
.60783 .6392 Mdot
.60391 .65097 Mdot
.59999 .65489 Mdot
.59999 .65489 Mdot
.59607 .64313 Mdot
.59607 .64313 Mdot
.59999 .64705 Mdot
.59215 .6392 Mdot
.58431 .61568 Mdot
.54902 .5647 Mdot
.38824 .40785 Mdot
.3608 .37648 Mdot
.72155 .72939 Mdot
.81174 .8235 Mdot
.53333 .58823 Mdot
.55294 .6196 Mdot
.55686 .64313 Mdot
.55294 .65097 Mdot
.55294 .65489 Mdot
.54902 .65489 Mdot
.54509 .65097 Mdot
.54117 .6392 Mdot
.54902 .63528 Mdot
.55686 .6392 Mdot
.5647 .64313 Mdot
.56862 .6392 Mdot
.57646 .63528 Mdot
.58431 .63528 Mdot
.58823 .63528 Mdot
.58039 .62744 Mdot
.59607 .6392 Mdot
.60783 .65097 Mdot
.60783 .66665 Mdot
.60391 .67057 Mdot
.59999 .66665 Mdot
.60783 .6745 Mdot
.59999 .66665 Mdot
.59999 .66665 Mdot
.60391 .66665 Mdot
.60391 .65489 Mdot
.61176 .65097 Mdot
.59607 .62352 Mdot
.52941 .55686 Mdot
.47059 .50196 Mdot
.36472 .40785 Mdot
.32158 .36864 Mdot
.75292 .76076 Mdot
.8784 .8784 Mdot
.51765 .57646 Mdot
.54509 .60783 Mdot
.54509 .6196 Mdot
.54902 .62744 Mdot
.53725 .62744 Mdot
.54117 .6392 Mdot
.54902 .64705 Mdot
.54509 .6392 Mdot
.54902 .6392 Mdot
.55294 .63528 Mdot
.56078 .64705 Mdot
.56862 .65489 Mdot
.57254 .64705 Mdot
.58431 .64705 Mdot
.58823 .6392 Mdot
.58431 .64705 Mdot
.59607 .66273 Mdot
.59215 .66273 Mdot
.59607 .65881 Mdot
.60391 .67057 Mdot
.60391 .67057 Mdot
.60391 .67057 Mdot
.60783 .6745 Mdot
.61176 .67842 Mdot
.62744 .68234 Mdot
.62744 .67842 Mdot
.62352 .65489 Mdot
.62744 .65097 Mdot
.48628 .51372 Mdot
.38432 .41569 Mdot
.40001 .43138 Mdot
.44706 .47451 Mdot
.59999 .60783 Mdot
.58039 .59215 Mdot
.6941 .70587 Mdot
.81174 .81958 Mdot
.52549 .58431 Mdot
.54902 .62352 Mdot
.55686 .64705 Mdot
.54509 .64705 Mdot
.53333 .63528 Mdot
.53333 .63136 Mdot
.54509 .63528 Mdot
.54902 .63136 Mdot
.54902 .62744 Mdot
.5647 .64313 Mdot
.5647 .65489 Mdot
.5647 .66665 Mdot
.57646 .6745 Mdot
.57254 .66273 Mdot
.57646 .65097 Mdot
.59215 .65881 Mdot
.60391 .67842 Mdot
.59607 .67842 Mdot
.59999 .6745 Mdot
.60783 .6745 Mdot
.61176 .67057 Mdot
.61176 .66665 Mdot
.62744 .68626 Mdot
.63528 .69018 Mdot
.63136 .67842 Mdot
.62744 .67057 Mdot
.63136 .67057 Mdot
.63528 .6745 Mdot
.53725 .57254 Mdot
.39609 .4353 Mdot
.40001 .43138 Mdot
.56078 .58039 Mdot
.60783 .62744 Mdot
.62352 .6392 Mdot
.64313 .65489 Mdot
.65097 .66273 Mdot
.65489 .67057 Mdot
.72155 .73724 Mdot
.79998 .81566 Mdot
.53333 .59999 Mdot
.55294 .64705 Mdot
.56078 .66665 Mdot
.54902 .65881 Mdot
.54509 .65489 Mdot
.55294 .65881 Mdot
.56078 .65489 Mdot
.56078 .6392 Mdot
.5647 .64313 Mdot
.56862 .65097 Mdot
.5647 .65881 Mdot
.56862 .66273 Mdot
.56862 .66273 Mdot
.56862 .66273 Mdot
.56862 .65881 Mdot
.58039 .66273 Mdot
.59607 .68234 Mdot
.58823 .68626 Mdot
.59215 .67842 Mdot
.60783 .67842 Mdot
.6196 .6745 Mdot
.6196 .6745 Mdot
.62352 .68626 Mdot
.63136 .69018 Mdot
.6392 .69802 Mdot
.6392 .69802 Mdot
.64705 .68626 Mdot
.64705 .68626 Mdot
.61176 .65881 Mdot
.58431 .62744 Mdot
.56078 .59215 Mdot
.59215 .6196 Mdot
.6392 .65489 Mdot
.64705 .66665 Mdot
.65489 .68234 Mdot
.66665 .68626 Mdot
.66665 .69018 Mdot
.67057 .69018 Mdot
.65881 .67842 Mdot
.66273 .6745 Mdot
.83135 .83527 Mdot
.91761 .92154 Mdot
.51765 .59215 Mdot
.53725 .63528 Mdot
.55294 .66665 Mdot
.55294 .67057 Mdot
.54509 .66273 Mdot
.54902 .65097 Mdot
.55294 .65097 Mdot
.55686 .64313 Mdot
.56862 .65489 Mdot
.57254 .65881 Mdot
.56078 .65097 Mdot
.57646 .65881 Mdot
.57646 .66273 Mdot
.57254 .65881 Mdot
.57254 .66273 Mdot
.58039 .66273 Mdot
.60391 .68626 Mdot
.61176 .6941 Mdot
.60391 .67842 Mdot
.60391 .68234 Mdot
.60391 .67842 Mdot
.61176 .67842 Mdot
.6196 .6745 Mdot
.62744 .68234 Mdot
.63136 .68626 Mdot
.63528 .68626 Mdot
.63136 .6745 Mdot
.64705 .68234 Mdot
.64705 .67842 Mdot
.64313 .66665 Mdot
.63136 .65489 Mdot
.6392 .66273 Mdot
.65097 .67057 Mdot
.65881 .67842 Mdot
.65881 .69018 Mdot
.6745 .70587 Mdot
.67842 .70194 Mdot
.68626 .71371 Mdot
.68234 .70194 Mdot
.67842 .69802 Mdot
.66665 .6745 Mdot
.6745 .67057 Mdot
.67057 .64313 Mdot
.83527 .81958 Mdot
.91761 .90585 Mdot
.50588 .59999 Mdot
.53333 .62744 Mdot
.54509 .64705 Mdot
.54902 .65881 Mdot
.54509 .65881 Mdot
.54509 .64313 Mdot
.54902 .6392 Mdot
.54902 .6392 Mdot
.55686 .64705 Mdot
.5647 .65489 Mdot
.5647 .65489 Mdot
.57254 .64705 Mdot
.57254 .65097 Mdot
.57646 .66273 Mdot
.57254 .66665 Mdot
.57646 .66273 Mdot
.59215 .67057 Mdot
.59607 .6745 Mdot
.61176 .68234 Mdot
.60391 .68234 Mdot
.61568 .69018 Mdot
.60391 .68234 Mdot
.6196 .69018 Mdot
.62744 .70194 Mdot
.63528 .70979 Mdot
.63528 .70587 Mdot
.63136 .6941 Mdot
.64313 .69802 Mdot
.65097 .69018 Mdot
.65097 .68234 Mdot
.65097 .68234 Mdot
.64705 .67842 Mdot
.64705 .68234 Mdot
.65881 .68234 Mdot
.66665 .6941 Mdot
.67057 .70194 Mdot
.6745 .70587 Mdot
.67842 .71371 Mdot
.67842 .70979 Mdot
.68234 .70979 Mdot
.6745 .69018 Mdot
.66665 .6745 Mdot
.68234 .67057 Mdot
.67842 .66665 Mdot
.67842 .65881 Mdot
.76076 .749 Mdot
.84703 .83919 Mdot
.50196 .59215 Mdot
.53333 .63528 Mdot
.54902 .65881 Mdot
.54902 .66273 Mdot
.53333 .65097 Mdot
.54117 .64705 Mdot
.54902 .64705 Mdot
.55686 .65881 Mdot
.55686 .66273 Mdot
.55686 .65881 Mdot
.5647 .66273 Mdot
.57646 .67057 Mdot
.57254 .66665 Mdot
.57646 .67842 Mdot
.58039 .67842 Mdot
.58039 .6745 Mdot
.58431 .67057 Mdot
.58823 .6745 Mdot
.59999 .68626 Mdot
.60391 .6941 Mdot
.61176 .69802 Mdot
.61568 .70587 Mdot
.62352 .70979 Mdot
.63528 .72155 Mdot
.63528 .71763 Mdot
.63528 .70979 Mdot
.63528 .70979 Mdot
.63528 .70587 Mdot
.65097 .71371 Mdot
.65097 .70194 Mdot
.65881 .70979 Mdot
.66665 .71371 Mdot
.66273 .70587 Mdot
.66273 .69018 Mdot
.66665 .69018 Mdot
.6745 .70979 Mdot
.68626 .72155 Mdot
.68234 .72155 Mdot
.67842 .71371 Mdot
.67842 .70587 Mdot
.67842 .6941 Mdot
.67842 .67842 Mdot
.6941 .67842 Mdot
.6941 .67842 Mdot
.6941 .68234 Mdot
.69802 .68626 Mdot
.69018 .68626 Mdot
.69802 .6941 Mdot
.76076 .76076 Mdot
.84311 .84703 Mdot
.51372 .59999 Mdot
.53725 .6392 Mdot
.55294 .66273 Mdot
.54509 .66273 Mdot
.53725 .65489 Mdot
.54117 .65097 Mdot
.54509 .64313 Mdot
.55294 .65097 Mdot
.56078 .66273 Mdot
.55294 .65489 Mdot
.57646 .67057 Mdot
.57646 .67057 Mdot
.58039 .67842 Mdot
.57646 .6745 Mdot
.58039 .67842 Mdot
.58039 .6745 Mdot
.58431 .6745 Mdot
.58431 .6745 Mdot
.58431 .6745 Mdot
.58823 .67842 Mdot
.60391 .69018 Mdot
.60783 .69018 Mdot
.6196 .70194 Mdot
.63528 .71763 Mdot
.6392 .72155 Mdot
.64313 .71371 Mdot
.64313 .70979 Mdot
.65097 .71371 Mdot
.64313 .70979 Mdot
.65489 .70587 Mdot
.65881 .70194 Mdot
.65881 .70194 Mdot
.66273 .69802 Mdot
.67842 .70587 Mdot
.6745 .71371 Mdot
.6745 .71371 Mdot
.68234 .71763 Mdot
.68626 .72155 Mdot
.67842 .71763 Mdot
.68234 .70979 Mdot
.68234 .70194 Mdot
.68234 .68626 Mdot
.6941 .69018 Mdot
.70194 .69018 Mdot
.69802 .68234 Mdot
.70194 .68234 Mdot
.70194 .68234 Mdot
.71371 .6941 Mdot
.70587 .69018 Mdot
.6941 .69018 Mdot
.67842 .67842 Mdot
.8235 .81958 Mdot
.89801 .89801 Mdot
.46275 .54902 Mdot
.54902 .63136 Mdot
.53725 .64313 Mdot
.52157 .64313 Mdot
.51765 .6392 Mdot
.52549 .64313 Mdot
.53333 .6392 Mdot
.55294 .65097 Mdot
.55686 .65881 Mdot
.56078 .66273 Mdot
.55686 .65489 Mdot
.56862 .66273 Mdot
.57254 .67057 Mdot
.57254 .67057 Mdot
.57646 .67057 Mdot
.57646 .66665 Mdot
.58823 .67842 Mdot
.59999 .68234 Mdot
.59999 .68626 Mdot
.59215 .68234 Mdot
.59215 .68234 Mdot
.60391 .68626 Mdot
.60391 .68626 Mdot
.60783 .68626 Mdot
.61568 .68626 Mdot
.63136 .68234 Mdot
.6392 .68234 Mdot
.65489 .70194 Mdot
.65097 .70979 Mdot
.65097 .70587 Mdot
.65097 .6941 Mdot
.65489 .68626 Mdot
.66273 .69018 Mdot
.6745 .70587 Mdot
.67842 .71763 Mdot
.66273 .70194 Mdot
.66665 .71371 Mdot
.67057 .71371 Mdot
.67057 .70587 Mdot
.67057 .69802 Mdot
.67057 .69018 Mdot
.69018 .69802 Mdot
.69018 .69018 Mdot
.69018 .67842 Mdot
.69018 .6745 Mdot
.70194 .67842 Mdot
.70194 .67842 Mdot
.70979 .6745 Mdot
.70587 .6745 Mdot
.70979 .68626 Mdot
.70587 .69018 Mdot
.6941 .67842 Mdot
.68626 .66665 Mdot
.59215 .56862 Mdot
.74508 .72939 Mdot
.86272 .85487 Mdot
.48628 .5647 Mdot
.51372 .59999 Mdot
.52941 .63136 Mdot
.52941 .64313 Mdot
.51765 .6392 Mdot
.51765 .64313 Mdot
.51765 .6392 Mdot
.54509 .65489 Mdot
.55686 .67057 Mdot
.55686 .6745 Mdot
.55294 .66273 Mdot
.54902 .65881 Mdot
.56078 .67057 Mdot
.55294 .65881 Mdot
.5647 .65881 Mdot
.56862 .65881 Mdot
.58039 .66665 Mdot
.58431 .67057 Mdot
.58823 .66665 Mdot
.58823 .66665 Mdot
.59607 .67057 Mdot
.59607 .6745 Mdot
.59607 .67057 Mdot
.61176 .68234 Mdot
.61568 .68234 Mdot
.62352 .6745 Mdot
.6392 .68234 Mdot
.64313 .67842 Mdot
.65489 .69018 Mdot
.66273 .6941 Mdot
.66665 .6941 Mdot
.66273 .6941 Mdot
.66273 .68626 Mdot
.65881 .68626 Mdot
.66665 .70194 Mdot
.65881 .70194 Mdot
.66273 .71371 Mdot
.66273 .70979 Mdot
.66665 .70194 Mdot
.6745 .70587 Mdot
.68626 .70979 Mdot
.68234 .6941 Mdot
.69018 .6941 Mdot
.69802 .6941 Mdot
.6941 .68626 Mdot
.69802 .68234 Mdot
.70194 .6745 Mdot
.70979 .6745 Mdot
.70587 .6745 Mdot
.71371 .68626 Mdot
.70979 .69018 Mdot
.70979 .68626 Mdot
.71371 .68234 Mdot
.70587 .6745 Mdot
.67057 .6392 Mdot
.65489 .6196 Mdot
.74116 .71763 Mdot
.79606 .78429 Mdot
.50588 .56862 Mdot
.53725 .60391 Mdot
.54509 .63528 Mdot
.53333 .6392 Mdot
.51765 .63528 Mdot
.52157 .63528 Mdot
.52941 .6392 Mdot
.54117 .63528 Mdot
.54902 .6392 Mdot
.54902 .64705 Mdot
.55294 .65097 Mdot
.55294 .65097 Mdot
.55294 .65881 Mdot
.55686 .65881 Mdot
.56078 .64705 Mdot
.5647 .65097 Mdot
.57254 .66273 Mdot
.56862 .65489 Mdot
.5647 .65097 Mdot
.57646 .65489 Mdot
.58431 .65489 Mdot
.59215 .66273 Mdot
.60391 .67057 Mdot
.61568 .6745 Mdot
.61568 .67057 Mdot
.62352 .6745 Mdot
.63528 .68626 Mdot
.6392 .69018 Mdot
.64313 .68626 Mdot
.65489 .68626 Mdot
.65489 .68626 Mdot
.66273 .6941 Mdot
.66665 .6941 Mdot
.66665 .69018 Mdot
.66273 .6941 Mdot
.66665 .70587 Mdot
.65881 .70587 Mdot
.66665 .70587 Mdot
.66273 .69018 Mdot
.6745 .69802 Mdot
.68626 .69802 Mdot
.68234 .68626 Mdot
.69018 .6941 Mdot
.70194 .69802 Mdot
.70194 .69802 Mdot
.70194 .6941 Mdot
.70979 .69018 Mdot
.70587 .67842 Mdot
.70979 .67842 Mdot
.71763 .68626 Mdot
.72155 .6941 Mdot
.71371 .69018 Mdot
.71763 .68234 Mdot
.71371 .67057 Mdot
.71371 .6745 Mdot
.70979 .6745 Mdot
.70587 .66665 Mdot
.70194 .65881 Mdot
.6745 .63528 Mdot
.74508 .71763 Mdot
.64313 .6392 Mdot
.46275 .52549 Mdot
.52549 .60391 Mdot
.53333 .63136 Mdot
.52941 .6392 Mdot
.52941 .64313 Mdot
.52549 .65097 Mdot
.53333 .65881 Mdot
.53725 .65097 Mdot
.54509 .65097 Mdot
.54902 .64705 Mdot
.54902 .64705 Mdot
.54509 .64705 Mdot
.54117 .65097 Mdot
.55294 .65097 Mdot
.56078 .64705 Mdot
.57254 .65489 Mdot
.56862 .65881 Mdot
.57254 .6745 Mdot
.5647 .65881 Mdot
.58039 .66273 Mdot
.58431 .65097 Mdot
.59999 .65881 Mdot
.60783 .66273 Mdot
.62352 .6745 Mdot
.63136 .68234 Mdot
.63528 .68234 Mdot
.65097 .69802 Mdot
.65881 .69802 Mdot
.64705 .69018 Mdot
.66273 .69802 Mdot
.66273 .69018 Mdot
.67057 .69802 Mdot
.66665 .69018 Mdot
.67057 .69802 Mdot
.67057 .69802 Mdot
.67842 .70979 Mdot
.67842 .70587 Mdot
.67057 .6941 Mdot
.67842 .69802 Mdot
.68234 .69802 Mdot
.68234 .69802 Mdot
.68626 .69018 Mdot
.6941 .69802 Mdot
.69802 .69802 Mdot
.70194 .70194 Mdot
.70979 .70194 Mdot
.70587 .69018 Mdot
.71371 .68626 Mdot
.71371 .67842 Mdot
.72155 .68234 Mdot
.71763 .68234 Mdot
.71763 .68234 Mdot
.71371 .68626 Mdot
.70979 .68234 Mdot
.72939 .6941 Mdot
.72547 .68234 Mdot
.72547 .67842 Mdot
.72939 .67842 Mdot
.72939 .6745 Mdot
.74116 .67842 Mdot
.4902 .45098 Mdot
.28629 .26276 Mdot
.65881 .6392 Mdot
.88624 .87056 Mdot
.45491 .52549 Mdot
.50196 .59215 Mdot
.52549 .63136 Mdot
.53333 .65489 Mdot
.53333 .65881 Mdot
.53725 .66665 Mdot
.53333 .66273 Mdot
.53725 .66665 Mdot
.54509 .66665 Mdot
.54117 .65489 Mdot
.55294 .65881 Mdot
.5647 .66273 Mdot
.56078 .66273 Mdot
.56862 .67057 Mdot
.56862 .66665 Mdot
.56862 .65881 Mdot
.57646 .66665 Mdot
.58823 .68234 Mdot
.58039 .67842 Mdot
.58431 .68234 Mdot
.59999 .68626 Mdot
.60391 .68234 Mdot
.61176 .68234 Mdot
.6196 .68234 Mdot
.6196 .68626 Mdot
.63136 .69018 Mdot
.64313 .69802 Mdot
.65489 .69802 Mdot
.64705 .6941 Mdot
.64705 .69802 Mdot
.65881 .70587 Mdot
.66273 .69802 Mdot
.67057 .70587 Mdot
.6745 .71763 Mdot
.6745 .72155 Mdot
.67842 .72547 Mdot
.68626 .72155 Mdot
.69018 .71763 Mdot
.6941 .71371 Mdot
.6941 .71763 Mdot
.69802 .71371 Mdot
.6941 .70979 Mdot
.70194 .71763 Mdot
.70194 .71763 Mdot
.70587 .70979 Mdot
.70194 .70194 Mdot
.70979 .70194 Mdot
.71371 .69018 Mdot
.72155 .68234 Mdot
.72547 .67842 Mdot
.74116 .6941 Mdot
.73332 .69802 Mdot
.73332 .70587 Mdot
.73332 .71371 Mdot
.73332 .70979 Mdot
.74116 .71371 Mdot
.74508 .70587 Mdot
.74116 .6941 Mdot
.73724 .67842 Mdot
.74508 .6745 Mdot
.71763 .64313 Mdot
.4902 .4353 Mdot
.36864 .33335 Mdot
.6941 .63136 Mdot
.59607 .54902 Mdot
.83135 .80782 Mdot
.90977 .89801 Mdot
.44314 .52157 Mdot
.5098 .60783 Mdot
.52157 .6392 Mdot
.52549 .65097 Mdot
.51765 .64705 Mdot
.52157 .64705 Mdot
.52157 .64705 Mdot
.52549 .64705 Mdot
.53333 .65097 Mdot
.54509 .65881 Mdot
.55294 .65489 Mdot
.54902 .65489 Mdot
.54902 .66273 Mdot
.55686 .67057 Mdot
.56078 .67057 Mdot
.54509 .65097 Mdot
.55294 .65097 Mdot
.56862 .66273 Mdot
.58431 .68234 Mdot
.58823 .6941 Mdot
.59215 .70194 Mdot
.59215 .69802 Mdot
.60783 .69802 Mdot
.61176 .69018 Mdot
.60783 .68626 Mdot
.6196 .6941 Mdot
.61568 .69018 Mdot
.62352 .6941 Mdot
.62744 .69802 Mdot
.6392 .70194 Mdot
.65097 .70587 Mdot
.65097 .70587 Mdot
.65881 .71763 Mdot
.65489 .71763 Mdot
.65881 .71371 Mdot
.67057 .72155 Mdot
.6745 .72939 Mdot
.6745 .72155 Mdot
.68234 .71763 Mdot
.6745 .70587 Mdot
.68626 .70979 Mdot
.69018 .70979 Mdot
.6941 .72547 Mdot
.69018 .72155 Mdot
.70194 .72155 Mdot
.69802 .70979 Mdot
.70194 .70979 Mdot
.70979 .69802 Mdot
.71371 .70194 Mdot
.71763 .69802 Mdot
.72939 .6941 Mdot
.72939 .70587 Mdot
.73724 .72155 Mdot
.72939 .72547 Mdot
.72547 .71763 Mdot
.72547 .70587 Mdot
.72547 .70587 Mdot
.73332 .69802 Mdot
.72939 .6745 Mdot
.72155 .66273 Mdot
.72155 .66665 Mdot
.70979 .66273 Mdot
.68626 .6392 Mdot
.70587 .65489 Mdot
.71371 .67057 Mdot
.70979 .66665 Mdot
.69802 .65097 Mdot
.76861 .72939 Mdot
.69018 .68234 Mdot
.47451 .54902 Mdot
.50588 .61568 Mdot
.50196 .63136 Mdot
.50196 .63528 Mdot
.50588 .63528 Mdot
.52157 .6392 Mdot
.52157 .63528 Mdot
.51765 .63136 Mdot
.52941 .64313 Mdot
.53725 .64705 Mdot
.54509 .65881 Mdot
.54117 .65881 Mdot
.54509 .66273 Mdot
.54509 .65489 Mdot
.54117 .65881 Mdot
.54509 .65881 Mdot
.54902 .65097 Mdot
.5647 .66273 Mdot
.58431 .68234 Mdot
.58039 .69018 Mdot
.58431 .69802 Mdot
.59215 .69802 Mdot
.59607 .68626 Mdot
.60391 .6941 Mdot
.61176 .69802 Mdot
.61176 .6941 Mdot
.61176 .69802 Mdot
.61568 .70194 Mdot
.62744 .70587 Mdot
.6392 .70194 Mdot
.64313 .70194 Mdot
.64313 .70587 Mdot
.67057 .72155 Mdot
.66665 .71763 Mdot
.66273 .71763 Mdot
.66665 .72547 Mdot
.6745 .73332 Mdot
.6745 .72547 Mdot
.67842 .72155 Mdot
.67842 .71371 Mdot
.68626 .70587 Mdot
.68626 .70194 Mdot
.69802 .71371 Mdot
.69802 .71763 Mdot
.70194 .71371 Mdot
.70194 .71371 Mdot
.70587 .70587 Mdot
.70194 .69802 Mdot
.69802 .69018 Mdot
.70587 .69018 Mdot
.70979 .69018 Mdot
.71371 .69802 Mdot
.72547 .71371 Mdot
.72155 .71371 Mdot
.71763 .71371 Mdot
.70979 .70979 Mdot
.70979 .69802 Mdot
.71371 .68626 Mdot
.71763 .68234 Mdot
.72547 .68234 Mdot
.72939 .67842 Mdot
.73724 .68234 Mdot
.72939 .67057 Mdot
.73332 .67842 Mdot
.72547 .6745 Mdot
.73332 .67842 Mdot
.74116 .67057 Mdot
.72939 .66273 Mdot
.6745 .61568 Mdot
.66273 .60391 Mdot
.75684 .70979 Mdot
.92938 .90977 Mdot
.48235 .5647 Mdot
.50588 .6196 Mdot
.51765 .64313 Mdot
.51372 .6392 Mdot
.5098 .63528 Mdot
.51372 .63136 Mdot
.51765 .63528 Mdot
.52549 .64313 Mdot
.52549 .65097 Mdot
.52941 .65097 Mdot
.54509 .67057 Mdot
.54117 .66273 Mdot
.54509 .65881 Mdot
.55686 .66273 Mdot
.54902 .65881 Mdot
.54902 .65881 Mdot
.55686 .66273 Mdot
.5647 .66665 Mdot
.57646 .6745 Mdot
.58039 .67842 Mdot
.58431 .68234 Mdot
.58823 .6941 Mdot
.60391 .70587 Mdot
.60391 .70979 Mdot
.61176 .71371 Mdot
.62352 .70587 Mdot
.62352 .70979 Mdot
.62744 .71763 Mdot
.6392 .72547 Mdot
.64313 .71763 Mdot
.65097 .71371 Mdot
.65097 .70587 Mdot
.65881 .70194 Mdot
.65881 .70194 Mdot
.65881 .70587 Mdot
.6745 .71763 Mdot
.68234 .72547 Mdot
.69018 .72547 Mdot
.69018 .72155 Mdot
.69018 .71763 Mdot
.69018 .70194 Mdot
.6941 .70194 Mdot
.70587 .70979 Mdot
.70587 .70587 Mdot
.70979 .70979 Mdot
.70587 .70194 Mdot
.70587 .69802 Mdot
.70194 .68626 Mdot
.70587 .68626 Mdot
.70587 .68626 Mdot
.70587 .68234 Mdot
.70979 .69018 Mdot
.71371 .69018 Mdot
.70587 .69018 Mdot
.71371 .69802 Mdot
.72155 .70587 Mdot
.72155 .70194 Mdot
.72939 .70194 Mdot
.72547 .70194 Mdot
.72939 .69802 Mdot
.72547 .67842 Mdot
.72939 .6745 Mdot
.74116 .6745 Mdot
.749 .67842 Mdot
.749 .6745 Mdot
.74508 .6745 Mdot
.74508 .66273 Mdot
.74508 .66273 Mdot
.749 .66273 Mdot
.73724 .65881 Mdot
.73332 .65097 Mdot
.73332 .64705 Mdot
.72939 .6392 Mdot
.86664 .8235 Mdot
.9333 .90585 Mdot
.46275 .54902 Mdot
.50196 .60391 Mdot
.51372 .6196 Mdot
.51765 .62744 Mdot
.51372 .62744 Mdot
.52549 .64313 Mdot
.52157 .6392 Mdot
.52157 .65097 Mdot
.52549 .65097 Mdot
.53725 .65489 Mdot
.53725 .64705 Mdot
.54902 .66665 Mdot
.54902 .66665 Mdot
.55686 .65881 Mdot
.56078 .66273 Mdot
.56862 .66665 Mdot
.56078 .66273 Mdot
.5647 .66665 Mdot
.5647 .68234 Mdot
.58039 .69018 Mdot
.59607 .69018 Mdot
.59215 .6941 Mdot
.59607 .70194 Mdot
.60783 .70979 Mdot
.61176 .71371 Mdot
.61176 .70587 Mdot
.61176 .70194 Mdot
.6196 .71371 Mdot
.62744 .71763 Mdot
.62744 .70587 Mdot
.63136 .69802 Mdot
.64313 .69802 Mdot
.65489 .6941 Mdot
.66273 .6941 Mdot
.67057 .70587 Mdot
.6745 .71371 Mdot
.6745 .71371 Mdot
.67842 .71763 Mdot
.67842 .71371 Mdot
.68234 .71371 Mdot
.68234 .70587 Mdot
.68626 .69802 Mdot
.69018 .6941 Mdot
.69802 .6941 Mdot
.70194 .70194 Mdot
.69802 .69802 Mdot
.69802 .70194 Mdot
.70194 .70194 Mdot
.69802 .6941 Mdot
.72155 .70587 Mdot
.72155 .70194 Mdot
.72155 .70194 Mdot
.72547 .70194 Mdot
.72547 .69018 Mdot
.72547 .6941 Mdot
.72939 .69802 Mdot
.73724 .70587 Mdot
.73332 .70587 Mdot
.73724 .71763 Mdot
.73332 .71371 Mdot
.73724 .70587 Mdot
.72155 .68234 Mdot
.72939 .67842 Mdot
.74116 .6745 Mdot
.749 .67057 Mdot
.749 .66665 Mdot
.75292 .65881 Mdot
.75684 .65489 Mdot
.74508 .65097 Mdot
.749 .65881 Mdot
.749 .65097 Mdot
.75292 .64705 Mdot
.74508 .6392 Mdot
.73332 .63136 Mdot
.72939 .6196 Mdot
.71371 .60391 Mdot
.86272 .80782 Mdot
.43922 .53333 Mdot
.49412 .59607 Mdot
.51372 .6196 Mdot
.52157 .62352 Mdot
.51765 .6196 Mdot
.52157 .62744 Mdot
.52549 .63136 Mdot
.52941 .63528 Mdot
.52549 .63528 Mdot
.52549 .62744 Mdot
.53333 .63528 Mdot
.54902 .64705 Mdot
.54902 .65489 Mdot
.55294 .66665 Mdot
.56078 .67057 Mdot
.56078 .65881 Mdot
.5647 .66665 Mdot
.58039 .6745 Mdot
.58431 .68234 Mdot
.58431 .68234 Mdot
.58823 .68234 Mdot
.60783 .6941 Mdot
.60783 .70194 Mdot
.60391 .69802 Mdot
.60391 .70194 Mdot
.61176 .70194 Mdot
.61176 .69802 Mdot
.60783 .69802 Mdot
.61176 .70194 Mdot
.6196 .70194 Mdot
.63528 .70587 Mdot
.64313 .70194 Mdot
.65097 .6941 Mdot
.65881 .69018 Mdot
.67057 .69802 Mdot
.6745 .71371 Mdot
.6745 .72155 Mdot
.6745 .71763 Mdot
.6745 .72155 Mdot
.67842 .71763 Mdot
.67842 .70979 Mdot
.69018 .70587 Mdot
.69018 .70194 Mdot
.69018 .69802 Mdot
.70587 .70194 Mdot
.70587 .70587 Mdot
.70587 .70979 Mdot
.71371 .70979 Mdot
.72155 .70979 Mdot
.72547 .70587 Mdot
.73332 .70979 Mdot
.73332 .71371 Mdot
.72547 .70979 Mdot
.72939 .70587 Mdot
.72155 .68626 Mdot
.72939 .68626 Mdot
.74116 .70194 Mdot
.74116 .70979 Mdot
.72939 .70587 Mdot
.74508 .71371 Mdot
.74508 .70194 Mdot
.74116 .69018 Mdot
.73724 .68234 Mdot
.74508 .67842 Mdot
.74508 .67057 Mdot
.74116 .65097 Mdot
.749 .64313 Mdot
.75684 .64705 Mdot
.74508 .64705 Mdot
.75684 .65881 Mdot
.749 .65097 Mdot
.75292 .64705 Mdot
.75684 .64705 Mdot
.74508 .6392 Mdot
.73724 .63528 Mdot
.73332 .63136 Mdot
.73724 .62744 Mdot
.73724 .62352 Mdot
.75292 .67842 Mdot
.81566 .76469 Mdot
.45098 .54902 Mdot
.50196 .60391 Mdot
.51372 .62744 Mdot
.52157 .63136 Mdot
.51765 .62744 Mdot
.51765 .6392 Mdot
.51372 .63528 Mdot
.52941 .64313 Mdot
.52941 .63528 Mdot
.52941 .63136 Mdot
.54902 .64705 Mdot
.55294 .65489 Mdot
.55686 .66273 Mdot
.55686 .65881 Mdot
.5647 .67842 Mdot
.57646 .68626 Mdot
.58431 .68234 Mdot
.58823 .68626 Mdot
.59215 .68626 Mdot
.58823 .68234 Mdot
.59999 .68234 Mdot
.60391 .68234 Mdot
.60391 .6941 Mdot
.61176 .70979 Mdot
.60783 .70979 Mdot
.61568 .70587 Mdot
.61568 .70979 Mdot
.62744 .71763 Mdot
.6196 .70587 Mdot
.61568 .6941 Mdot
.63136 .6941 Mdot
.63528 .69018 Mdot
.64705 .69018 Mdot
.66665 .69802 Mdot
.66273 .69018 Mdot
.67842 .70194 Mdot
.67057 .70587 Mdot
.67842 .72155 Mdot
.68234 .73332 Mdot
.68234 .73332 Mdot
.68626 .73332 Mdot
.69018 .72939 Mdot
.69018 .71763 Mdot
.69802 .72155 Mdot
.70587 .71371 Mdot
.70587 .70194 Mdot
.70587 .70194 Mdot
.71371 .72155 Mdot
.72939 .73332 Mdot
.72939 .71763 Mdot
.74116 .72547 Mdot
.72939 .71763 Mdot
.72939 .70587 Mdot
.72547 .70194 Mdot
.72939 .70194 Mdot
.72939 .6941 Mdot
.749 .70587 Mdot
.749 .70587 Mdot
.74508 .70587 Mdot
.75684 .70979 Mdot
.75684 .69802 Mdot
.749 .68234 Mdot
.75292 .69018 Mdot
.749 .68626 Mdot
.74508 .67057 Mdot
.74508 .65881 Mdot
.75292 .65489 Mdot
.75684 .65489 Mdot
.74116 .64705 Mdot
.749 .65881 Mdot
.74508 .65489 Mdot
.74508 .65489 Mdot
.75292 .66273 Mdot
.75292 .65097 Mdot
.74116 .63528 Mdot
.75684 .64705 Mdot
.75684 .64705 Mdot
.749 .64313 Mdot
.74508 .63528 Mdot
.74116 .63528 Mdot
.72547 .62744 Mdot
.80782 .73724 Mdot
.93722 .91369 Mdot
.47843 .55686 Mdot
.52549 .61176 Mdot
.53725 .6392 Mdot
.53333 .64313 Mdot
.52157 .6392 Mdot
.52549 .65489 Mdot
.52157 .65489 Mdot
.52549 .65489 Mdot
.52941 .65881 Mdot
.52941 .64313 Mdot
.53333 .64313 Mdot
.55294 .65881 Mdot
.55294 .67057 Mdot
.55686 .67057 Mdot
.55294 .67842 Mdot
.56078 .67842 Mdot
.5647 .67842 Mdot
.57646 .68626 Mdot
.58039 .67842 Mdot
.57646 .6745 Mdot
.59215 .68234 Mdot
.59999 .68626 Mdot
.60391 .69018 Mdot
.60783 .70194 Mdot
.62352 .70587 Mdot
.6196 .69802 Mdot
.62352 .70194 Mdot
.62352 .70194 Mdot
.62744 .70587 Mdot
.63136 .6941 Mdot
.63136 .6941 Mdot
.6392 .70587 Mdot
.6392 .69802 Mdot
.64705 .69018 Mdot
.65097 .68626 Mdot
.66665 .69018 Mdot
.68234 .70587 Mdot
.68626 .71371 Mdot
.68234 .71763 Mdot
.68626 .71763 Mdot
.68626 .71763 Mdot
.68234 .70979 Mdot
.69018 .71763 Mdot
.69018 .71763 Mdot
.69018 .71763 Mdot
.69018 .71371 Mdot
.69802 .71371 Mdot
.70979 .72155 Mdot
.72155 .73332 Mdot
.71371 .72155 Mdot
.71763 .72939 Mdot
.73332 .73332 Mdot
.73332 .72155 Mdot
.72547 .71371 Mdot
.72547 .70587 Mdot
.72939 .70194 Mdot
.73332 .70194 Mdot
.74508 .70979 Mdot
.75292 .71763 Mdot
.73724 .69802 Mdot
.74116 .69018 Mdot
.75684 .69802 Mdot
.75292 .69018 Mdot
.749 .68626 Mdot
.73332 .67057 Mdot
.73332 .66665 Mdot
.749 .66665 Mdot
.74508 .66273 Mdot
.73724 .65881 Mdot
.74116 .65881 Mdot
.74116 .65489 Mdot
.74508 .65881 Mdot
.75684 .66273 Mdot
.75684 .65881 Mdot
.75684 .65097 Mdot
.76076 .65881 Mdot
.75684 .65097 Mdot
.75292 .65097 Mdot
.74508 .6392 Mdot
.75292 .64705 Mdot
.749 .65489 Mdot
.74508 .65489 Mdot
.74116 .65097 Mdot
.72939 .64313 Mdot
.84311 .79998 Mdot
.90193 .88232 Mdot
.4902 .57254 Mdot
.51765 .6196 Mdot
.52941 .6392 Mdot
.52941 .64313 Mdot
.52941 .65489 Mdot
.53725 .6745 Mdot
.53725 .68234 Mdot
.52941 .6745 Mdot
.53725 .66273 Mdot
.53333 .64313 Mdot
.53725 .6392 Mdot
.54117 .64313 Mdot
.54117 .65489 Mdot
.54902 .65881 Mdot
.55294 .66273 Mdot
.55686 .66665 Mdot
.56862 .6745 Mdot
.56862 .68234 Mdot
.57254 .67842 Mdot
.57254 .6745 Mdot
.58823 .68626 Mdot
.59215 .68234 Mdot
.60391 .68626 Mdot
.60391 .6941 Mdot
.59999 .69018 Mdot
.61568 .69802 Mdot
.6196 .6941 Mdot
.62744 .69802 Mdot
.63136 .6941 Mdot
.62352 .68626 Mdot
.63136 .6941 Mdot
.64313 .70587 Mdot
.64705 .70587 Mdot
.64313 .70587 Mdot
.64705 .69802 Mdot
.65881 .69802 Mdot
.67057 .70979 Mdot
.6745 .71371 Mdot
.67842 .71371 Mdot
.68234 .71371 Mdot
.6745 .70979 Mdot
.67057 .70587 Mdot
.68234 .71371 Mdot
.6941 .72939 Mdot
.69018 .72547 Mdot
.69018 .72155 Mdot
.6941 .71763 Mdot
.70194 .72939 Mdot
.70194 .72547 Mdot
.70979 .72547 Mdot
.71371 .72547 Mdot
.72939 .72547 Mdot
.73332 .72547 Mdot
.72939 .71371 Mdot
.72939 .72155 Mdot
.73332 .72155 Mdot
.73332 .72155 Mdot
.73332 .72155 Mdot
.72547 .71763 Mdot
.72939 .71371 Mdot
.73332 .70194 Mdot
.74116 .70194 Mdot
.74116 .6941 Mdot
.74508 .6941 Mdot
.74508 .68626 Mdot
.74508 .67842 Mdot
.749 .68234 Mdot
.749 .67842 Mdot
.749 .68234 Mdot
.749 .68626 Mdot
.75684 .69018 Mdot
.75292 .67842 Mdot
.74508 .67057 Mdot
.75292 .66665 Mdot
.75292 .66665 Mdot
.75684 .65881 Mdot
.75684 .65489 Mdot
.75292 .65881 Mdot
.74508 .65489 Mdot
.749 .66273 Mdot
.74508 .66665 Mdot
.749 .66665 Mdot
.75292 .66273 Mdot
.74116 .65881 Mdot
.73332 .65489 Mdot
.71371 .64313 Mdot
.72155 .65097 Mdot
.86272 .82743 Mdot
.5098 .58431 Mdot
.52549 .62744 Mdot
.53725 .65881 Mdot
.52941 .66665 Mdot
.53333 .6745 Mdot
.52549 .6745 Mdot
.51372 .66273 Mdot
.51372 .66273 Mdot
.52941 .66273 Mdot
.53725 .65881 Mdot
.54117 .65489 Mdot
.54902 .66273 Mdot
.55294 .66665 Mdot
.55686 .67057 Mdot
.55686 .6745 Mdot
.57254 .67842 Mdot
.56862 .67057 Mdot
.58039 .68234 Mdot
.58039 .69018 Mdot
.58823 .69802 Mdot
.58431 .68234 Mdot
.60391 .68626 Mdot
.59999 .67842 Mdot
.60783 .67842 Mdot
.59999 .68234 Mdot
.59215 .67842 Mdot
.61176 .69018 Mdot
.6196 .6941 Mdot
.63136 .6941 Mdot
.63528 .70194 Mdot
.63136 .6941 Mdot
.6392 .70194 Mdot
.6392 .69018 Mdot
.64313 .69802 Mdot
.65097 .69802 Mdot
.65489 .69802 Mdot
.66273 .70587 Mdot
.66665 .70587 Mdot
.66665 .70194 Mdot
.68234 .71371 Mdot
.69018 .73332 Mdot
.68626 .72939 Mdot
.68234 .72155 Mdot
.67842 .71763 Mdot
.68234 .72547 Mdot
.6941 .73332 Mdot
.70194 .73724 Mdot
.70979 .73724 Mdot
.70979 .74116 Mdot
.71763 .74116 Mdot
.72155 .73724 Mdot
.73332 .74116 Mdot
.73332 .74116 Mdot
.73724 .73724 Mdot
.73332 .72939 Mdot
.73724 .73332 Mdot
.72939 .72939 Mdot
.73724 .73724 Mdot
.73724 .72939 Mdot
.73332 .71763 Mdot
.72547 .69802 Mdot
.73332 .70194 Mdot
.73724 .69802 Mdot
.74116 .70194 Mdot
.74116 .70194 Mdot
.75292 .71371 Mdot
.75684 .70979 Mdot
.75292 .70587 Mdot
.749 .70587 Mdot
.74508 .69802 Mdot
.75684 .69802 Mdot
.76469 .69802 Mdot
.76469 .69018 Mdot
.76469 .69018 Mdot
.75684 .6745 Mdot
.76469 .67842 Mdot
.75684 .66273 Mdot
.76076 .6745 Mdot
.76076 .68234 Mdot
.75684 .68626 Mdot
.75292 .67842 Mdot
.75292 .6745 Mdot
.749 .66665 Mdot
.75684 .6745 Mdot
.75292 .6745 Mdot
.74116 .66665 Mdot
.73332 .65881 Mdot
.73332 .65881 Mdot
.72155 .65097 Mdot
.78429 .72547 Mdot
.84311 .81174 Mdot
.49412 .58431 Mdot
.51765 .63136 Mdot
.52549 .65489 Mdot
.51765 .66665 Mdot
.51372 .6745 Mdot
.51765 .67057 Mdot
.51372 .66665 Mdot
.52157 .66273 Mdot
.52549 .66665 Mdot
.52549 .65881 Mdot
.53333 .65881 Mdot
.54509 .66665 Mdot
.55686 .6745 Mdot
.57254 .68626 Mdot
.56862 .67842 Mdot
.57254 .67842 Mdot
.58039 .67842 Mdot
.59215 .6941 Mdot
.59999 .70194 Mdot
.59607 .70194 Mdot
.59607 .70194 Mdot
.59607 .69018 Mdot
.60391 .68626 Mdot
.60391 .68234 Mdot
.6196 .6941 Mdot
.61176 .69018 Mdot
.60783 .68626 Mdot
.61568 .69018 Mdot
.62744 .69802 Mdot
.62744 .69802 Mdot
.62352 .69802 Mdot
.62744 .70194 Mdot
.6392 .70979 Mdot
.64313 .70979 Mdot
.65489 .71371 Mdot
.65881 .70979 Mdot
.66665 .71763 Mdot
.67057 .71763 Mdot
.66665 .70979 Mdot
.67842 .71371 Mdot
.67842 .71763 Mdot
.69018 .72939 Mdot
.6941 .74508 Mdot
.69018 .73724 Mdot
.68626 .71763 Mdot
.6941 .72155 Mdot
.70979 .73332 Mdot
.71763 .73724 Mdot
.71763 .73332 Mdot
.72939 .74508 Mdot
.73332 .75684 Mdot
.74116 .76469 Mdot
.73724 .76469 Mdot
.73724 .75684 Mdot
.73724 .75292 Mdot
.73724 .749 Mdot
.72939 .73724 Mdot
.73332 .74116 Mdot
.72939 .73332 Mdot
.74116 .72939 Mdot
.749 .72547 Mdot
.74508 .71371 Mdot
.74508 .70979 Mdot
.75292 .71763 Mdot
.75292 .71763 Mdot
.749 .71371 Mdot
.75292 .71763 Mdot
.75684 .72155 Mdot
.75684 .72547 Mdot
.749 .72155 Mdot
.75292 .71763 Mdot
.75684 .71371 Mdot
.76469 .70587 Mdot
.77253 .70587 Mdot
.76469 .6941 Mdot
.77253 .68626 Mdot
.76076 .67842 Mdot
.76076 .68626 Mdot
.76469 .6941 Mdot
.76469 .6941 Mdot
.76469 .69802 Mdot
.75684 .68626 Mdot
.75684 .67842 Mdot
.75684 .67842 Mdot
.75684 .68234 Mdot
.75684 .69018 Mdot
.75292 .68626 Mdot
.74508 .6745 Mdot
.74508 .67842 Mdot
.73724 .67057 Mdot
.73332 .66665 Mdot
.71763 .65097 Mdot
.77645 .72547 Mdot
.92546 .90977 Mdot
.47843 .58039 Mdot
.5098 .63136 Mdot
.52941 .66273 Mdot
.52549 .66273 Mdot
.51372 .67057 Mdot
.5098 .66665 Mdot
.51765 .66665 Mdot
.52549 .67057 Mdot
.52549 .6745 Mdot
.53333 .67842 Mdot
.54117 .68626 Mdot
.55294 .68626 Mdot
.55686 .69018 Mdot
.56862 .68626 Mdot
.57254 .68234 Mdot
.58431 .68626 Mdot
.58039 .68626 Mdot
.58823 .6941 Mdot
.58823 .6941 Mdot
.58823 .6941 Mdot
.59999 .69802 Mdot
.59607 .68626 Mdot
.59999 .68626 Mdot
.60783 .68626 Mdot
.6196 .6941 Mdot
.61176 .69018 Mdot
.62744 .69802 Mdot
.6196 .6941 Mdot
.63528 .70587 Mdot
.6392 .71371 Mdot
.65097 .71763 Mdot
.6392 .71763 Mdot
.64313 .73332 Mdot
.64705 .74116 Mdot
.64705 .72939 Mdot
.64313 .71763 Mdot
.65097 .72155 Mdot
.65489 .72155 Mdot
.66273 .72547 Mdot
.67057 .72939 Mdot
.6745 .72155 Mdot
.68626 .72939 Mdot
.67842 .72939 Mdot
.69018 .74508 Mdot
.69018 .73724 Mdot
.6941 .73724 Mdot
.70587 .74116 Mdot
.71371 .74508 Mdot
.71371 .74116 Mdot
.71763 .74508 Mdot
.72155 .75684 Mdot
.73332 .76076 Mdot
.74116 .76076 Mdot
.73332 .75292 Mdot
.73332 .75292 Mdot
.72939 .74508 Mdot
.72939 .73724 Mdot
.74116 .73724 Mdot
.73724 .72547 Mdot
.749 .72547 Mdot
.76076 .72939 Mdot
.74116 .70979 Mdot
.74508 .70194 Mdot
.74508 .70194 Mdot
.74116 .69802 Mdot
.74508 .70587 Mdot
.74508 .71371 Mdot
.75292 .72155 Mdot
.75292 .72547 Mdot
.75684 .72547 Mdot
.75684 .71371 Mdot
.74508 .70194 Mdot
.75684 .70194 Mdot
.77253 .69802 Mdot
.77253 .68626 Mdot
.76861 .6745 Mdot
.76861 .6745 Mdot
.77253 .69018 Mdot
.76861 .6941 Mdot
.77253 .70194 Mdot
.76861 .69802 Mdot
.76469 .69018 Mdot
.76076 .68234 Mdot
.76469 .67842 Mdot
.76861 .68234 Mdot
.76469 .68234 Mdot
.76469 .68626 Mdot
.74508 .68234 Mdot
.74116 .67842 Mdot
.749 .68234 Mdot
.74508 .6745 Mdot
.74116 .66665 Mdot
.73332 .66665 Mdot
.72939 .65881 Mdot
.72547 .65097 Mdot
.8588 .8235 Mdot
.92546 .90977 Mdot
.4902 .56862 Mdot
.50588 .60783 Mdot
.52157 .6392 Mdot
.52549 .65489 Mdot
.51372 .65097 Mdot
.53333 .66665 Mdot
.53333 .66665 Mdot
.53725 .68234 Mdot
.52157 .68234 Mdot
.52549 .68234 Mdot
.53333 .69018 Mdot
.54117 .69802 Mdot
.54902 .68626 Mdot
.56862 .69018 Mdot
.57254 .68626 Mdot
.57254 .68234 Mdot
.58039 .69018 Mdot
.58039 .69802 Mdot
.58039 .6941 Mdot
.58431 .69802 Mdot
.59215 .70194 Mdot
.60783 .70979 Mdot
.61568 .71371 Mdot
.61568 .71763 Mdot
.60783 .70979 Mdot
.61176 .70587 Mdot
.62744 .69802 Mdot
.63136 .69802 Mdot
.63528 .70194 Mdot
.6392 .70587 Mdot
.6392 .71371 Mdot
.6392 .71763 Mdot
.63528 .72547 Mdot
.64313 .74116 Mdot
.64313 .74116 Mdot
.64705 .73724 Mdot
.65097 .73724 Mdot
.65881 .74116 Mdot
.65489 .73724 Mdot
.66273 .74116 Mdot
.6745 .74116 Mdot
.67842 .74116 Mdot
.68234 .74508 Mdot
.67842 .74508 Mdot
.69018 .75684 Mdot
.6941 .75292 Mdot
.70194 .74508 Mdot
.70979 .749 Mdot
.70979 .75292 Mdot
.72155 .76076 Mdot
.71371 .76076 Mdot
.72155 .75684 Mdot
.70587 .74116 Mdot
.71371 .749 Mdot
.72939 .75684 Mdot
.72547 .749 Mdot
.72155 .74116 Mdot
.74116 .74508 Mdot
.72547 .72547 Mdot
.73332 .72155 Mdot
.74508 .72155 Mdot
.74508 .71763 Mdot
.749 .72155 Mdot
.75684 .71371 Mdot
.749 .70587 Mdot
.75292 .71371 Mdot
.74508 .71371 Mdot
.749 .71763 Mdot
.75292 .72155 Mdot
.75684 .72939 Mdot
.75684 .72939 Mdot
.76076 .71371 Mdot
.76861 .69802 Mdot
.76861 .69018 Mdot
.77253 .68626 Mdot
.77253 .67842 Mdot
.77645 .68234 Mdot
.76469 .67842 Mdot
.77253 .6941 Mdot
.77645 .70979 Mdot
.77253 .70979 Mdot
.77645 .70587 Mdot
.77253 .6941 Mdot
.76861 .68626 Mdot
.77253 .68626 Mdot
.77645 .6941 Mdot
.77645 .70194 Mdot
.76469 .70194 Mdot
.76076 .70587 Mdot
.75292 .6941 Mdot
.75292 .69018 Mdot
.749 .67842 Mdot
.74508 .66273 Mdot
.74508 .66273 Mdot
.74508 .65489 Mdot
.72939 .65097 Mdot
.71371 .65097 Mdot
.65881 .60391 Mdot
.84311 .81566 Mdot
.47843 .56078 Mdot
.5098 .60783 Mdot
.51372 .63136 Mdot
.52157 .65097 Mdot
.52157 .64705 Mdot
.52941 .65097 Mdot
.53725 .65489 Mdot
.52941 .65881 Mdot
.52157 .66665 Mdot
.52549 .67057 Mdot
.53725 .68234 Mdot
.54117 .68626 Mdot
.54509 .67842 Mdot
.54902 .67842 Mdot
.55294 .67842 Mdot
.56078 .68234 Mdot
.5647 .68234 Mdot
.56862 .69802 Mdot
.56862 .6941 Mdot
.56862 .6941 Mdot
.59607 .70587 Mdot
.60391 .70979 Mdot
.59999 .70979 Mdot
.60391 .71371 Mdot
.60391 .72155 Mdot
.61568 .72155 Mdot
.6196 .71371 Mdot
.62744 .70979 Mdot
.63136 .70587 Mdot
.62744 .71371 Mdot
.62744 .71371 Mdot
.63528 .70979 Mdot
.6392 .72155 Mdot
.65097 .74116 Mdot
.65097 .74116 Mdot
.64705 .74508 Mdot
.64705 .749 Mdot
.65097 .749 Mdot
.65097 .749 Mdot
.66665 .75292 Mdot
.6745 .749 Mdot
.68626 .75292 Mdot
.68626 .75292 Mdot
.69802 .76076 Mdot
.69018 .76076 Mdot
.69802 .76469 Mdot
.69018 .75292 Mdot
.70194 .75684 Mdot
.70979 .76076 Mdot
.71371 .76076 Mdot
.70979 .75684 Mdot
.71371 .75292 Mdot
.72155 .749 Mdot
.71371 .73724 Mdot
.70587 .72939 Mdot
.71371 .73724 Mdot
.70979 .73332 Mdot
.72155 .74116 Mdot
.72547 .73332 Mdot
.73332 .72547 Mdot
.74508 .72547 Mdot
.74508 .72547 Mdot
.75292 .74116 Mdot
.75684 .74508 Mdot
.74508 .72939 Mdot
.749 .72547 Mdot
.74508 .72939 Mdot
.74508 .72547 Mdot
.75684 .73332 Mdot
.75292 .72939 Mdot
.75292 .72939 Mdot
.76469 .72547 Mdot
.78037 .72547 Mdot
.76861 .70194 Mdot
.76076 .69018 Mdot
.77253 .68626 Mdot
.77253 .6745 Mdot
.77645 .68234 Mdot
.77253 .6941 Mdot
.77253 .69802 Mdot
.77253 .69802 Mdot
.76076 .69802 Mdot
.77645 .70587 Mdot
.76469 .69802 Mdot
.76469 .69802 Mdot
.76076 .6941 Mdot
.76861 .6941 Mdot
.76469 .69802 Mdot
.77253 .71371 Mdot
.76076 .70194 Mdot
.76076 .69018 Mdot
.75684 .68234 Mdot
.75292 .6745 Mdot
.749 .66273 Mdot
.75292 .66273 Mdot
.74116 .66273 Mdot
.73332 .66665 Mdot
.72547 .66273 Mdot
.70979 .65489 Mdot
.70194 .65881 Mdot
.77253 .74116 Mdot
.79998 .78429 Mdot
.47059 .57254 Mdot
.51372 .62744 Mdot
.52549 .65489 Mdot
.51765 .65489 Mdot
.52157 .65881 Mdot
.52157 .65097 Mdot
.52549 .65097 Mdot
.52549 .65881 Mdot
.51765 .66665 Mdot
.52941 .6745 Mdot
.53333 .67057 Mdot
.53725 .67057 Mdot
.53725 .6745 Mdot
.54117 .6745 Mdot
.54117 .66665 Mdot
.54509 .66665 Mdot
.55294 .6745 Mdot
.5647 .6941 Mdot
.56862 .70194 Mdot
.57646 .71371 Mdot
.58823 .71371 Mdot
.59607 .71371 Mdot
.60783 .71763 Mdot
.59999 .70979 Mdot
.60783 .71763 Mdot
.61176 .71763 Mdot
.61176 .71371 Mdot
.61568 .71371 Mdot
.6196 .71763 Mdot
.6196 .71763 Mdot
.62744 .72155 Mdot
.63528 .72155 Mdot
.65097 .72939 Mdot
.65489 .73332 Mdot
.65097 .73332 Mdot
.64705 .72939 Mdot
.65097 .74116 Mdot
.64705 .74116 Mdot
.65489 .74116 Mdot
.66273 .74508 Mdot
.66665 .74508 Mdot
.67842 .75292 Mdot
.68234 .749 Mdot
.68234 .74508 Mdot
.68234 .74508 Mdot
.68626 .75292 Mdot
.68234 .74508 Mdot
.68626 .749 Mdot
.69018 .75292 Mdot
.6941 .75292 Mdot
.70194 .75292 Mdot
.70587 .74508 Mdot
.70979 .749 Mdot
.71371 .749 Mdot
.71371 .749 Mdot
.71371 .74508 Mdot
.71371 .74116 Mdot
.72155 .73332 Mdot
.72547 .73332 Mdot
.73332 .72939 Mdot
.73332 .72547 Mdot
.73332 .72939 Mdot
.74508 .74116 Mdot
.749 .74508 Mdot
.75292 .74508 Mdot
.75684 .74508 Mdot
.75292 .74508 Mdot
.74508 .74116 Mdot
.74116 .73332 Mdot
.75292 .73724 Mdot
.749 .72547 Mdot
.749 .71371 Mdot
.74116 .6941 Mdot
.75292 .69802 Mdot
.75292 .69802 Mdot
.75292 .69018 Mdot
.76469 .68626 Mdot
.76469 .68626 Mdot
.76861 .6941 Mdot
.75684 .6941 Mdot
.76469 .70194 Mdot
.75684 .70194 Mdot
.76076 .70587 Mdot
.76469 .70194 Mdot
.75684 .70194 Mdot
.76076 .69802 Mdot
.76861 .70587 Mdot
.75684 .70194 Mdot
.76861 .71371 Mdot
.76469 .70587 Mdot
.75684 .6941 Mdot
.76076 .6941 Mdot
.75292 .6941 Mdot
.74508 .67842 Mdot
.74508 .6745 Mdot
.74116 .66665 Mdot
.74508 .68234 Mdot
.73724 .67842 Mdot
.71371 .65881 Mdot
.70979 .66273 Mdot
.71371 .66273 Mdot
.70979 .65881 Mdot
.70194 .65097 Mdot
.749 .71763 Mdot
.91761 .90585 Mdot
.49804 .59999 Mdot
.51372 .62744 Mdot
.52549 .65097 Mdot
.52157 .65881 Mdot
.52941 .67057 Mdot
.52941 .67057 Mdot
.51372 .65881 Mdot
.52157 .67057 Mdot
.52549 .66665 Mdot
.52549 .66273 Mdot
.52549 .65489 Mdot
.52941 .65881 Mdot
.54117 .6745 Mdot
.54902 .67842 Mdot
.55686 .68626 Mdot
.56078 .68626 Mdot
.56862 .6941 Mdot
.56862 .69802 Mdot
.57646 .70979 Mdot
.58431 .71763 Mdot
.58431 .71371 Mdot
.58823 .70979 Mdot
.59607 .70979 Mdot
.61176 .72939 Mdot
.60391 .72155 Mdot
.60783 .71763 Mdot
.61176 .71371 Mdot
.6196 .71371 Mdot
.63528 .71763 Mdot
.63528 .71371 Mdot
.6392 .72547 Mdot
.64313 .72939 Mdot
.64705 .73332 Mdot
.65881 .73332 Mdot
.66273 .73332 Mdot
.65881 .73332 Mdot
.65881 .73332 Mdot
.65881 .73724 Mdot
.65489 .73724 Mdot
.6745 .749 Mdot
.6745 .74508 Mdot
.67842 .749 Mdot
.6745 .76469 Mdot
.6745 .76076 Mdot
.67842 .749 Mdot
.67842 .74508 Mdot
.68626 .75292 Mdot
.6941 .76076 Mdot
.69802 .75292 Mdot
.6941 .749 Mdot
.70587 .75292 Mdot
.70979 .75292 Mdot
.71371 .75684 Mdot
.71371 .76076 Mdot
.70587 .75684 Mdot
.70587 .75292 Mdot
.71371 .75292 Mdot
.72939 .76076 Mdot
.72939 .75292 Mdot
.73332 .749 Mdot
.73724 .749 Mdot
.73724 .74116 Mdot
.74116 .74116 Mdot
.73724 .73724 Mdot
.73332 .73724 Mdot
.73332 .73724 Mdot
.72547 .73724 Mdot
.74508 .75292 Mdot
.74508 .74508 Mdot
.74116 .74116 Mdot
.73724 .73724 Mdot
.749 .73724 Mdot
.749 .72155 Mdot
.74508 .70979 Mdot
.74116 .70979 Mdot
.75292 .71371 Mdot
.75292 .6941 Mdot
.76076 .70194 Mdot
.75684 .6941 Mdot
.75292 .6941 Mdot
.76076 .70194 Mdot
.76469 .70194 Mdot
.76076 .70194 Mdot
.76861 .70587 Mdot
.77645 .71371 Mdot
.77253 .71371 Mdot
.75684 .70587 Mdot
.76076 .70587 Mdot
.76861 .70979 Mdot
.76861 .71371 Mdot
.76076 .70587 Mdot
.75684 .70587 Mdot
.749 .69802 Mdot
.75684 .69018 Mdot
.749 .69018 Mdot
.749 .68626 Mdot
.74508 .68234 Mdot
.74508 .68234 Mdot
.74116 .67842 Mdot
.73332 .67057 Mdot
.73332 .67057 Mdot
.73332 .67057 Mdot
.72939 .6745 Mdot
.70979 .66273 Mdot
.70979 .66665 Mdot
.6941 .64313 Mdot
.83135 .80782 Mdot
.90193 .89017 Mdot
.47843 .59215 Mdot
.51372 .63136 Mdot
.52157 .65881 Mdot
.52157 .67842 Mdot
.52549 .67842 Mdot
.52549 .68234 Mdot
.52549 .67842 Mdot
.53333 .6745 Mdot
.52157 .65881 Mdot
.53725 .67057 Mdot
.53725 .67842 Mdot
.53725 .67057 Mdot
.54509 .6745 Mdot
.55686 .67842 Mdot
.5647 .69018 Mdot
.56078 .68626 Mdot
.5647 .6941 Mdot
.57646 .70587 Mdot
.58039 .71763 Mdot
.58039 .72155 Mdot
.58039 .71371 Mdot
.59215 .71371 Mdot
.59215 .70979 Mdot
.60391 .72155 Mdot
.61176 .72547 Mdot
.61568 .71763 Mdot
.62352 .72155 Mdot
.62352 .71763 Mdot
.6392 .72155 Mdot
.65097 .72939 Mdot
.65097 .73332 Mdot
.64313 .72939 Mdot
.65489 .73724 Mdot
.66273 .74116 Mdot
.66273 .73332 Mdot
.66665 .74116 Mdot
.67057 .75292 Mdot
.67057 .75292 Mdot
.66665 .749 Mdot
.67057 .75292 Mdot
.6745 .75292 Mdot
.67842 .76076 Mdot
.66665 .749 Mdot
.67842 .76861 Mdot
.68626 .76861 Mdot
.68234 .76076 Mdot
.68626 .75292 Mdot
.69802 .76469 Mdot
.70194 .75684 Mdot
.70587 .75292 Mdot
.70979 .76076 Mdot
.71371 .76076 Mdot
.72547 .77253 Mdot
.71763 .77253 Mdot
.71763 .77253 Mdot
.72547 .78037 Mdot
.72547 .76861 Mdot
.73724 .76861 Mdot
.72547 .75292 Mdot
.72155 .75292 Mdot
.72155 .74508 Mdot
.72939 .74116 Mdot
.73332 .74116 Mdot
.73332 .73724 Mdot
.73332 .72939 Mdot
.73332 .73724 Mdot
.74116 .74116 Mdot
.749 .75292 Mdot
.75292 .76076 Mdot
.75684 .76076 Mdot
.75684 .76076 Mdot
.76469 .77253 Mdot
.749 .749 Mdot
.75684 .74116 Mdot
.76469 .74508 Mdot
.76076 .74508 Mdot
.75684 .72547 Mdot
.76469 .72939 Mdot
.76469 .71371 Mdot
.76861 .70979 Mdot
.77253 .71371 Mdot
.76861 .70979 Mdot
.76469 .70979 Mdot
.76076 .71371 Mdot
.76076 .71763 Mdot
.76469 .72939 Mdot
.75684 .72547 Mdot
.76076 .72547 Mdot
.76076 .72155 Mdot
.76076 .72547 Mdot
.749 .71763 Mdot
.75684 .71763 Mdot
.75292 .71371 Mdot
.76469 .70979 Mdot
.76469 .70979 Mdot
.76076 .70979 Mdot
.75684 .71371 Mdot
.75292 .70194 Mdot
.76076 .69802 Mdot
.76076 .6941 Mdot
.75684 .6941 Mdot
.749 .68626 Mdot
.749 .68626 Mdot
.74508 .68234 Mdot
.74116 .6941 Mdot
.73332 .69018 Mdot
.71763 .67842 Mdot
.70587 .66665 Mdot
.66665 .62352 Mdot
.82743 .81174 Mdot
.47059 .58823 Mdot
.50196 .63528 Mdot
.51765 .66665 Mdot
.51765 .67842 Mdot
.51372 .68234 Mdot
.52941 .6941 Mdot
.52157 .6745 Mdot
.52549 .66273 Mdot
.52157 .65489 Mdot
.52941 .65881 Mdot
.54902 .6745 Mdot
.54902 .67057 Mdot
.54902 .66665 Mdot
.55686 .67057 Mdot
.57254 .69018 Mdot
.56862 .69018 Mdot
.56078 .69018 Mdot
.56078 .69802 Mdot
.56078 .70194 Mdot
.56862 .70587 Mdot
.57646 .70194 Mdot
.58431 .69802 Mdot
.59607 .70587 Mdot
.59607 .69802 Mdot
.60783 .71371 Mdot
.60783 .71371 Mdot
.61176 .70979 Mdot
.62352 .70979 Mdot
.63136 .71763 Mdot
.63528 .72939 Mdot
.65097 .73332 Mdot
.63528 .71763 Mdot
.64705 .72547 Mdot
.65881 .73332 Mdot
.66273 .73332 Mdot
.66665 .73724 Mdot
.66665 .74116 Mdot
.6745 .749 Mdot
.6745 .75292 Mdot
.67057 .75684 Mdot
.6745 .749 Mdot
.66665 .73724 Mdot
.66665 .74116 Mdot
.67842 .749 Mdot
.6941 .75684 Mdot
.69802 .76469 Mdot
.70587 .76861 Mdot
.70979 .76469 Mdot
.70587 .76469 Mdot
.70979 .76469 Mdot
.71763 .76469 Mdot
.71763 .76076 Mdot
.72155 .76861 Mdot
.71371 .76469 Mdot
.72155 .76861 Mdot
.72939 .76469 Mdot
.72939 .76469 Mdot
.73332 .76076 Mdot
.73332 .75292 Mdot
.73332 .75292 Mdot
.73332 .75684 Mdot
.73332 .75684 Mdot
.73724 .75684 Mdot
.74116 .75292 Mdot
.72939 .72939 Mdot
.749 .73332 Mdot
.74116 .72547 Mdot
.75292 .74116 Mdot
.749 .74116 Mdot
.749 .74116 Mdot
.749 .749 Mdot
.75292 .75684 Mdot
.749 .749 Mdot
.76469 .74508 Mdot
.75684 .73724 Mdot
.75292 .72939 Mdot
.75684 .72939 Mdot
.75292 .71371 Mdot
.75684 .70979 Mdot
.76861 .70587 Mdot
.77253 .71371 Mdot
.77645 .72547 Mdot
.76469 .72155 Mdot
.76076 .72155 Mdot
.75684 .72939 Mdot
.75684 .73724 Mdot
.75684 .74116 Mdot
.75684 .73724 Mdot
.75684 .72939 Mdot
.76469 .72939 Mdot
.75684 .72155 Mdot
.75684 .71371 Mdot
.76469 .70194 Mdot
.76861 .70194 Mdot
.77253 .71371 Mdot
.77253 .71763 Mdot
.76469 .72155 Mdot
.76469 .71763 Mdot
.76861 .70979 Mdot
.76076 .69802 Mdot
.75684 .69802 Mdot
.75292 .69018 Mdot
.75292 .69018 Mdot
.749 .6941 Mdot
.74508 .70194 Mdot
.73724 .6941 Mdot
.73332 .69018 Mdot
.72155 .68234 Mdot
.71371 .68234 Mdot
.70979 .67842 Mdot
.65881 .62744 Mdot
.72155 .69802 Mdot
.77645 .76861 Mdot
.47451 .58823 Mdot
.50588 .63528 Mdot
.52549 .65881 Mdot
.52549 .67842 Mdot
.50196 .66665 Mdot
.50588 .66665 Mdot
.50196 .65097 Mdot
.51372 .65097 Mdot
.52549 .64705 Mdot
.53725 .65097 Mdot
.53725 .65489 Mdot
.53725 .65881 Mdot
.53725 .66273 Mdot
.54117 .67057 Mdot
.55294 .6745 Mdot
.56078 .67842 Mdot
.57646 .69018 Mdot
.56078 .69018 Mdot
.5647 .69802 Mdot
.5647 .70194 Mdot
.57646 .70587 Mdot
.58431 .69802 Mdot
.58431 .69018 Mdot
.59607 .70587 Mdot
.59607 .71763 Mdot
.59215 .70979 Mdot
.60783 .71371 Mdot
.62352 .71763 Mdot
.62744 .72155 Mdot
.62744 .71763 Mdot
.63136 .72155 Mdot
.63136 .71763 Mdot
.64313 .72155 Mdot
.65097 .72547 Mdot
.65881 .72939 Mdot
.66273 .72939 Mdot
.65881 .73724 Mdot
.65489 .74508 Mdot
.65489 .74116 Mdot
.66665 .749 Mdot
.66665 .749 Mdot
.67057 .749 Mdot
.67842 .749 Mdot
.68234 .74116 Mdot
.6941 .74116 Mdot
.6941 .73724 Mdot
.70194 .75684 Mdot
.70587 .76076 Mdot
.70194 .75684 Mdot
.70587 .76076 Mdot
.71371 .76076 Mdot
.71763 .75292 Mdot
.72155 .76469 Mdot
.71371 .76076 Mdot
.70979 .75292 Mdot
.70979 .74508 Mdot
.71763 .749 Mdot
.72155 .749 Mdot
.72155 .74508 Mdot
.72547 .749 Mdot
.71763 .74116 Mdot
.71763 .74508 Mdot
.72939 .75684 Mdot
.72939 .74508 Mdot
.72939 .73724 Mdot
.73332 .73332 Mdot
.73724 .73332 Mdot
.74116 .73332 Mdot
.74508 .74116 Mdot
.75292 .749 Mdot
.749 .749 Mdot
.75684 .74508 Mdot
.76469 .749 Mdot
.76076 .74116 Mdot
.75684 .73332 Mdot
.76469 .74116 Mdot
.75684 .73332 Mdot
.75684 .72155 Mdot
.76076 .71371 Mdot
.76076 .70194 Mdot
.76469 .70979 Mdot
.76469 .71371 Mdot
.75292 .70587 Mdot
.75684 .72155 Mdot
.74508 .72155 Mdot
.74508 .72939 Mdot
.74508 .72547 Mdot
.75292 .72547 Mdot
.75684 .72547 Mdot
.749 .71763 Mdot
.75292 .71763 Mdot
.749 .70979 Mdot
.749 .69802 Mdot
.76469 .69802 Mdot
.76469 .69018 Mdot
.76076 .6941 Mdot
.76076 .69802 Mdot
.75684 .6941 Mdot
.75684 .69018 Mdot
.75684 .69018 Mdot
.75292 .69802 Mdot
.73724 .69018 Mdot
.74116 .6941 Mdot
.72547 .68626 Mdot
.72155 .68234 Mdot
.73724 .6941 Mdot
.72939 .6941 Mdot
.72939 .69802 Mdot
.72547 .69802 Mdot
.72155 .69018 Mdot
.71371 .6745 Mdot
.70194 .66665 Mdot
.6941 .66665 Mdot
.62744 .59999 Mdot
.70587 .68626 Mdot
.90585 .89801 Mdot
.45883 .57254 Mdot
.49412 .61568 Mdot
.5098 .6392 Mdot
.51372 .65489 Mdot
.5098 .66665 Mdot
.49804 .66273 Mdot
.50196 .66665 Mdot
.49804 .65489 Mdot
.51765 .65097 Mdot
.51765 .65489 Mdot
.52941 .67057 Mdot
.53333 .6745 Mdot
.52941 .67057 Mdot
.53333 .67057 Mdot
.54117 .66665 Mdot
.54902 .66273 Mdot
.55686 .67842 Mdot
.56078 .68234 Mdot
.56862 .69802 Mdot
.55686 .6941 Mdot
.56078 .70587 Mdot
.57254 .70979 Mdot
.57254 .70194 Mdot
.58823 .70979 Mdot
.58823 .70979 Mdot
.59215 .70587 Mdot
.60391 .71371 Mdot
.61568 .72155 Mdot
.62352 .71763 Mdot
.62744 .72155 Mdot
.63136 .72547 Mdot
.63528 .72547 Mdot
.63528 .71763 Mdot
.63528 .70587 Mdot
.65097 .70979 Mdot
.65881 .72155 Mdot
.66273 .73332 Mdot
.66273 .74508 Mdot
.66665 .75292 Mdot
.67057 .75684 Mdot
.6745 .76861 Mdot
.66665 .75684 Mdot
.6745 .76076 Mdot
.67842 .76469 Mdot
.69802 .76469 Mdot
.69018 .749 Mdot
.70194 .75684 Mdot
.70194 .76076 Mdot
.70194 .76076 Mdot
.70587 .76469 Mdot
.70587 .75684 Mdot
.70979 .75684 Mdot
.72155 .77253 Mdot
.72155 .77645 Mdot
.71371 .76861 Mdot
.70587 .75292 Mdot
.70587 .75684 Mdot
.70979 .75684 Mdot
.71371 .75684 Mdot
.70979 .75292 Mdot
.70979 .75292 Mdot
.71371 .749 Mdot
.71763 .74508 Mdot
.72939 .75292 Mdot
.73724 .76076 Mdot
.72547 .74116 Mdot
.72939 .73724 Mdot
.73724 .74508 Mdot
.74508 .74508 Mdot
.749 .75684 Mdot
.749 .75684 Mdot
.749 .75292 Mdot
.749 .749 Mdot
.76076 .75292 Mdot
.75292 .749 Mdot
.75684 .749 Mdot
.75292 .749 Mdot
.74508 .74116 Mdot
.75292 .74508 Mdot
.76469 .74116 Mdot
.75684 .73724 Mdot
.75684 .73724 Mdot
.74508 .72547 Mdot
.74508 .72547 Mdot
.74508 .72547 Mdot
.74508 .72155 Mdot
.749 .71371 Mdot
.75292 .71371 Mdot
.76861 .72155 Mdot
.76469 .72155 Mdot
.75684 .71371 Mdot
.749 .70587 Mdot
.749 .70194 Mdot
.749 .69802 Mdot
.76861 .70194 Mdot
.76469 .70194 Mdot
.75684 .70587 Mdot
.75684 .72155 Mdot
.74508 .70979 Mdot
.74116 .70979 Mdot
.73332 .70587 Mdot
.72939 .70587 Mdot
.74508 .70979 Mdot
.73332 .69802 Mdot
.72939 .6941 Mdot
.72939 .6941 Mdot
.73332 .70194 Mdot
.73332 .70979 Mdot
.72155 .69802 Mdot
.72155 .6941 Mdot
.71371 .68626 Mdot
.70587 .68234 Mdot
.70587 .69018 Mdot
.6941 .69018 Mdot
.68234 .67057 Mdot
.67057 .65881 Mdot
.65489 .63528 Mdot
.8235 .81566 Mdot
.84311 .84703 Mdot
.47059 .57646 Mdot
.48628 .60783 Mdot
.5098 .63136 Mdot
.5098 .64313 Mdot
.50196 .64705 Mdot
.50196 .65881 Mdot
.50196 .66273 Mdot
.51372 .67057 Mdot
.51372 .66665 Mdot
.52157 .66665 Mdot
.53333 .68234 Mdot
.54902 .69802 Mdot
.54509 .6941 Mdot
.55294 .6941 Mdot
.54509 .67842 Mdot
.55294 .68234 Mdot
.56078 .69018 Mdot
.56862 .69018 Mdot
.57254 .6941 Mdot
.57646 .70587 Mdot
.58431 .71371 Mdot
.58431 .71763 Mdot
.59215 .71371 Mdot
.58431 .70587 Mdot
.58431 .70587 Mdot
.58823 .70587 Mdot
.60391 .72155 Mdot
.61568 .72547 Mdot
.62352 .72939 Mdot
.62744 .72939 Mdot
.62744 .73332 Mdot
.6392 .73332 Mdot
.64313 .72547 Mdot
.64705 .72547 Mdot
.64313 .71371 Mdot
.66665 .73332 Mdot
.6745 .749 Mdot
.6745 .75684 Mdot
.67057 .75292 Mdot
.67057 .76076 Mdot
.67842 .76469 Mdot
.67842 .76076 Mdot
.67842 .77253 Mdot
.6941 .78037 Mdot
.68626 .77253 Mdot
.6941 .76861 Mdot
.70194 .76469 Mdot
.70587 .76469 Mdot
.70587 .76861 Mdot
.70587 .76861 Mdot
.70979 .76469 Mdot
.71763 .76469 Mdot
.71371 .75684 Mdot
.72547 .77645 Mdot
.71371 .77253 Mdot
.70979 .76469 Mdot
.71371 .77253 Mdot
.70587 .76076 Mdot
.71763 .76469 Mdot
.72155 .77645 Mdot
.72547 .78429 Mdot
.71371 .76861 Mdot
.71763 .76469 Mdot
.71763 .75684 Mdot
.72939 .76076 Mdot
.73724 .76469 Mdot
.73332 .75684 Mdot
.73724 .749 Mdot
.74116 .74116 Mdot
.749 .749 Mdot
.75684 .76076 Mdot
.75292 .76076 Mdot
.75292 .76469 Mdot
.76076 .76076 Mdot
.76076 .76861 Mdot
.75684 .76469 Mdot
.76076 .76469 Mdot
.75684 .75684 Mdot
.749 .75292 Mdot
.75292 .76076 Mdot
.75684 .76076 Mdot
.75292 .75292 Mdot
.74116 .74116 Mdot
.74508 .74116 Mdot
.74508 .72547 Mdot
.75684 .72547 Mdot
.75292 .71763 Mdot
.75684 .71763 Mdot
.76469 .71763 Mdot
.76861 .72155 Mdot
.76469 .71371 Mdot
.76076 .70979 Mdot
.76469 .71371 Mdot
.76076 .70979 Mdot
.76469 .71371 Mdot
.76469 .70979 Mdot
.76076 .71763 Mdot
.75684 .72939 Mdot
.74116 .73332 Mdot
.74116 .73332 Mdot
.74116 .73332 Mdot
.73724 .72155 Mdot
.73332 .71371 Mdot
.73332 .70194 Mdot
.73724 .70587 Mdot
.72939 .69802 Mdot
.72939 .69018 Mdot
.72547 .68626 Mdot
.72939 .69802 Mdot
.72547 .6941 Mdot
.72155 .6941 Mdot
.70979 .68626 Mdot
.70587 .69018 Mdot
.70979 .6941 Mdot
.70194 .69018 Mdot
.69018 .67842 Mdot
.68234 .6745 Mdot
.68234 .68626 Mdot
.57254 .59215 Mdot
.56862 .58431 Mdot
.61176 .63528 Mdot
.45883 .58039 Mdot
.50196 .62744 Mdot
.50588 .6392 Mdot
.51372 .65489 Mdot
.49804 .6392 Mdot
.50196 .6392 Mdot
.50196 .64705 Mdot
.51372 .65881 Mdot
.51765 .66665 Mdot
.51372 .67057 Mdot
.52941 .68234 Mdot
.53725 .69018 Mdot
.53725 .68626 Mdot
.54902 .69018 Mdot
.54902 .6941 Mdot
.54902 .69018 Mdot
.55686 .69018 Mdot
.5647 .6941 Mdot
.57254 .70194 Mdot
.58431 .70587 Mdot
.59215 .71371 Mdot
.58823 .70979 Mdot
.59215 .71371 Mdot
.59215 .70979 Mdot
.59999 .70979 Mdot
.60391 .70979 Mdot
.60783 .71763 Mdot
.60783 .71371 Mdot
.60783 .71371 Mdot
.61568 .72547 Mdot
.61568 .72547 Mdot
.63528 .73332 Mdot
.64705 .74116 Mdot
.65097 .73724 Mdot
.65489 .74508 Mdot
.66273 .749 Mdot
.67057 .75292 Mdot
.6745 .76076 Mdot
.67842 .76469 Mdot
.69018 .76861 Mdot
.68626 .76469 Mdot
.68626 .76469 Mdot
.69018 .77645 Mdot
.69802 .78037 Mdot
.69018 .76861 Mdot
.6941 .76469 Mdot
.6941 .76076 Mdot
.70194 .76076 Mdot
.70587 .75292 Mdot
.70587 .75292 Mdot
.70979 .76076 Mdot
.70587 .75292 Mdot
.70979 .75292 Mdot
.70979 .75684 Mdot
.71371 .75684 Mdot
.70587 .75684 Mdot
.71371 .76076 Mdot
.72547 .76469 Mdot
.71763 .75684 Mdot
.72547 .76469 Mdot
.72939 .76861 Mdot
.72939 .76469 Mdot
.72547 .76076 Mdot
.72547 .76076 Mdot
.72547 .749 Mdot
.72939 .749 Mdot
.73724 .74508 Mdot
.73724 .73724 Mdot
.73724 .73332 Mdot
.74508 .73332 Mdot
.74508 .72939 Mdot
.749 .73332 Mdot
.74508 .73332 Mdot
.73332 .71763 Mdot
.75292 .73724 Mdot
.75684 .74508 Mdot
.75292 .74116 Mdot
.749 .74116 Mdot
.75292 .74508 Mdot
.75292 .75684 Mdot
.749 .749 Mdot
.74116 .74508 Mdot
.74116 .73724 Mdot
.74116 .72939 Mdot
.74508 .72155 Mdot
.73724 .70587 Mdot
.75292 .71371 Mdot
.76076 .71371 Mdot
.75684 .71371 Mdot
.75292 .71371 Mdot
.75292 .71371 Mdot
.75292 .70979 Mdot
.75684 .70194 Mdot
.75292 .6941 Mdot
.75292 .69018 Mdot
.749 .68234 Mdot
.74508 .69018 Mdot
.749 .70194 Mdot
.74116 .70979 Mdot
.72939 .71763 Mdot
.72939 .72155 Mdot
.73332 .72155 Mdot
.74116 .71763 Mdot
.73332 .69802 Mdot
.73332 .6941 Mdot
.72939 .68626 Mdot
.72939 .67842 Mdot
.72939 .6745 Mdot
.73332 .68234 Mdot
.73332 .6745 Mdot
.73332 .67842 Mdot
.72547 .68626 Mdot
.72155 .69018 Mdot
.71763 .68626 Mdot
.70979 .6745 Mdot
.70587 .67057 Mdot
.69802 .67842 Mdot
.68626 .67842 Mdot
.6745 .66665 Mdot
.66665 .65489 Mdot
.56862 .55294 Mdot
.3608 .34511 Mdot
.52157 .4902 Mdot
.58039 .5647 Mdot
.45883 .57254 Mdot
.48235 .6196 Mdot
.49412 .6392 Mdot
.49412 .65097 Mdot
.4902 .64705 Mdot
.48628 .6392 Mdot
.49804 .65489 Mdot
.50196 .65881 Mdot
.5098 .66665 Mdot
.51372 .67842 Mdot
.52549 .68626 Mdot
.53333 .69018 Mdot
.53333 .6941 Mdot
.55294 .70587 Mdot
.54902 .69802 Mdot
.55686 .70979 Mdot
.56078 .70979 Mdot
.56862 .70979 Mdot
.57254 .71371 Mdot
.57254 .71763 Mdot
.58431 .72155 Mdot
.58823 .72155 Mdot
.59607 .72939 Mdot
.58823 .72547 Mdot
.59999 .72547 Mdot
.60391 .72155 Mdot
.60391 .71763 Mdot
.59607 .70587 Mdot
.60783 .71763 Mdot
.61568 .72547 Mdot
.62744 .73724 Mdot
.63136 .74508 Mdot
.64313 .749 Mdot
.65097 .749 Mdot
.65881 .76076 Mdot
.65097 .75684 Mdot
.65097 .75684 Mdot
.65881 .75684 Mdot
.66273 .76076 Mdot
.66665 .76076 Mdot
.66665 .76076 Mdot
.6745 .76861 Mdot
.68234 .76861 Mdot
.68626 .77253 Mdot
.69018 .78037 Mdot
.68626 .76861 Mdot
.68626 .76076 Mdot
.68626 .76076 Mdot
.6941 .76469 Mdot
.69802 .76076 Mdot
.69802 .75684 Mdot
.69802 .75684 Mdot
.69802 .75292 Mdot
.70587 .75684 Mdot
.70587 .75292 Mdot
.70194 .75684 Mdot
.70979 .76861 Mdot
.71763 .76469 Mdot
.72155 .76469 Mdot
.72547 .76469 Mdot
.72939 .76861 Mdot
.72547 .76076 Mdot
.72939 .76469 Mdot
.72155 .75292 Mdot
.72547 .749 Mdot
.72939 .75292 Mdot
.72939 .749 Mdot
.72939 .73332 Mdot
.72939 .72547 Mdot
.73332 .72939 Mdot
.73332 .72547 Mdot
.74116 .72547 Mdot
.73332 .72939 Mdot
.74116 .73724 Mdot
.74116 .73724 Mdot
.74508 .749 Mdot
.73724 .73724 Mdot
.74116 .73332 Mdot
.74116 .74116 Mdot
.74508 .75292 Mdot
.74116 .75684 Mdot
.74116 .75292 Mdot
.74116 .74508 Mdot
.72939 .72547 Mdot
.73724 .72939 Mdot
.74508 .72939 Mdot
.75292 .72939 Mdot
.75292 .72939 Mdot
.75684 .73332 Mdot
.76076 .74116 Mdot
.73724 .72547 Mdot
.74508 .72939 Mdot
.74116 .71763 Mdot
.75292 .71371 Mdot
.75684 .70979 Mdot
.749 .70194 Mdot
.74508 .70587 Mdot
.74116 .71371 Mdot
.74508 .73332 Mdot
.74508 .74116 Mdot
.72939 .73332 Mdot
.72547 .72155 Mdot
.72547 .72155 Mdot
.72155 .71371 Mdot
.72547 .71371 Mdot
.72155 .70587 Mdot
.71763 .6941 Mdot
.71371 .69018 Mdot
.72155 .68626 Mdot
.72155 .68626 Mdot
.71763 .68234 Mdot
.71763 .6941 Mdot
.71763 .70194 Mdot
.70979 .6941 Mdot
.70587 .68626 Mdot
.70587 .68626 Mdot
.70194 .6941 Mdot
.69802 .6941 Mdot
.68626 .68626 Mdot
.6745 .67057 Mdot
.67842 .65881 Mdot
.65881 .63528 Mdot
.57254 .53725 Mdot
.19218 .16865 Mdot
.22747 .1961 Mdot
.59999 .58431 Mdot
.79606 .79213 Mdot
.47843 .59607 Mdot
.50196 .6392 Mdot
.50196 .66273 Mdot
.50196 .66665 Mdot
.49412 .66273 Mdot
.48628 .65097 Mdot
.50588 .66273 Mdot
.50588 .65881 Mdot
.5098 .65881 Mdot
.5098 .66665 Mdot
.52549 .67842 Mdot
.52549 .67842 Mdot
.54117 .68626 Mdot
.54509 .69018 Mdot
.53333 .67842 Mdot
.54902 .6941 Mdot
.56078 .70194 Mdot
.56862 .70979 Mdot
.5647 .70979 Mdot
.5647 .70979 Mdot
.5647 .71371 Mdot
.57646 .72155 Mdot
.58039 .72547 Mdot
.58039 .72155 Mdot
.58039 .72155 Mdot
.58823 .72155 Mdot
.59215 .71763 Mdot
.59607 .71371 Mdot
.60783 .72155 Mdot
.60783 .72155 Mdot
.60391 .72547 Mdot
.61176 .72939 Mdot
.63136 .74116 Mdot
.63528 .73724 Mdot
.64705 .74116 Mdot
.65097 .75292 Mdot
.65097 .76076 Mdot
.65489 .75684 Mdot
.65097 .75292 Mdot
.65881 .76076 Mdot
.65881 .76076 Mdot
.66273 .76076 Mdot
.67057 .76861 Mdot
.68234 .77645 Mdot
.6745 .76861 Mdot
.6745 .76861 Mdot
.6745 .75684 Mdot
.68626 .77253 Mdot
.69802 .77645 Mdot
.69802 .76861 Mdot
.6941 .749 Mdot
.70194 .749 Mdot
.70587 .75292 Mdot
.70587 .75292 Mdot
.70194 .75292 Mdot
.6941 .75292 Mdot
.69802 .749 Mdot
.70194 .76469 Mdot
.70587 .76469 Mdot
.71371 .76861 Mdot
.71763 .76861 Mdot
.71371 .76469 Mdot
.72155 .76469 Mdot
.72547 .76861 Mdot
.71371 .76076 Mdot
.70587 .74508 Mdot
.72155 .75292 Mdot
.71763 .73724 Mdot
.71371 .73332 Mdot
.71371 .72939 Mdot
.71763 .73332 Mdot
.71763 .73724 Mdot
.71763 .73724 Mdot
.72547 .73724 Mdot
.72939 .74116 Mdot
.72939 .74508 Mdot
.73332 .74508 Mdot
.73332 .74116 Mdot
.73332 .74116 Mdot
.73332 .75292 Mdot
.73724 .76469 Mdot
.72939 .76076 Mdot
.72939 .749 Mdot
.72155 .73724 Mdot
.72547 .73332 Mdot
.72939 .72939 Mdot
.73332 .73332 Mdot
.73332 .73332 Mdot
.749 .749 Mdot
.74116 .75292 Mdot
.73724 .76076 Mdot
.73332 .75292 Mdot
.73332 .74116 Mdot
.73332 .72939 Mdot
.72939 .72155 Mdot
.72939 .72155 Mdot
.73332 .72155 Mdot
.73332 .73724 Mdot
.73332 .73724 Mdot
.73332 .74508 Mdot
.73332 .749 Mdot
.73332 .74508 Mdot
.72155 .72939 Mdot
.72155 .72547 Mdot
.72547 .72155 Mdot
.72547 .72155 Mdot
.72547 .72155 Mdot
.72155 .71763 Mdot
.71763 .70587 Mdot
.71763 .70587 Mdot
.70979 .69802 Mdot
.70587 .69802 Mdot
.70979 .71371 Mdot
.70587 .70979 Mdot
.69802 .70194 Mdot
.69802 .69802 Mdot
.68234 .6941 Mdot
.6745 .69018 Mdot
.67057 .68626 Mdot
.66273 .6745 Mdot
.65881 .66665 Mdot
.65489 .65881 Mdot
.66273 .65489 Mdot
.44314 .4353 Mdot
.30198 .29413 Mdot
.21963 .20002 Mdot
.20787 .18042 Mdot
.19218 .17257 Mdot
.59215 .58823 Mdot
.78821 .78821 Mdot
.47059 .59999 Mdot
.4902 .6392 Mdot
.4902 .65881 Mdot
.49804 .6745 Mdot
.49412 .67057 Mdot
.48628 .67057 Mdot
.49412 .66273 Mdot
.50588 .67057 Mdot
.50196 .66273 Mdot
.51372 .66273 Mdot
.52941 .67842 Mdot
.54902 .6941 Mdot
.54117 .69018 Mdot
.54902 .6941 Mdot
.54902 .69018 Mdot
.55294 .68626 Mdot
.55686 .6941 Mdot
.56078 .70587 Mdot
.5647 .71371 Mdot
.57254 .71763 Mdot
.5647 .70979 Mdot
.57646 .71763 Mdot
.58431 .72547 Mdot
.58431 .72547 Mdot
.58431 .73332 Mdot
.58039 .72939 Mdot
.58431 .72155 Mdot
.59215 .71763 Mdot
.60391 .72547 Mdot
.61176 .73332 Mdot
.59999 .72939 Mdot
.59607 .72939 Mdot
.61176 .73332 Mdot
.62352 .73332 Mdot
.63136 .72939 Mdot
.6392 .74508 Mdot
.64705 .75684 Mdot
.65097 .76861 Mdot
.65097 .77645 Mdot
.64313 .76861 Mdot
.65097 .75684 Mdot
.64705 .75292 Mdot
.65489 .75292 Mdot
.66665 .76076 Mdot
.66665 .76076 Mdot
.67057 .76469 Mdot
.67057 .76861 Mdot
.67842 .76469 Mdot
.6745 .749 Mdot
.68626 .75684 Mdot
.6941 .75292 Mdot
.70194 .749 Mdot
.70979 .749 Mdot
.70194 .749 Mdot
.69802 .749 Mdot
.6941 .76076 Mdot
.69018 .76469 Mdot
.69802 .77253 Mdot
.6941 .76076 Mdot
.70194 .76469 Mdot
.70194 .77253 Mdot
.6941 .77253 Mdot
.69802 .76076 Mdot
.70587 .76076 Mdot
.71371 .77253 Mdot
.70979 .76861 Mdot
.71371 .76469 Mdot
.71371 .75684 Mdot
.71371 .75292 Mdot
.71763 .75684 Mdot
.72939 .76469 Mdot
.72547 .76861 Mdot
.71763 .76076 Mdot
.72155 .749 Mdot
.72547 .74508 Mdot
.72547 .73724 Mdot
.72939 .73724 Mdot
.73332 .74508 Mdot
.72939 .74116 Mdot
.73724 .73724 Mdot
.73724 .749 Mdot
.73724 .75684 Mdot
.72547 .75684 Mdot
.72547 .75292 Mdot
.72155 .74116 Mdot
.72155 .74116 Mdot
.72547 .74116 Mdot
.72939 .74508 Mdot
.72939 .749 Mdot
.73332 .749 Mdot
.73724 .75292 Mdot
.72939 .74508 Mdot
.72939 .749 Mdot
.72939 .74116 Mdot
.73332 .74508 Mdot
.72155 .72547 Mdot
.73332 .72939 Mdot
.73724 .73724 Mdot
.72547 .73724 Mdot
.72155 .74508 Mdot
.71763 .74116 Mdot
.72155 .73724 Mdot
.72939 .73724 Mdot
.72547 .72155 Mdot
.72155 .71371 Mdot
.72547 .70979 Mdot
.71371 .70194 Mdot
.70194 .6941 Mdot
.70587 .70194 Mdot
.70979 .71371 Mdot
.69802 .70587 Mdot
.69802 .70194 Mdot
.6941 .69802 Mdot
.6941 .69802 Mdot
.6941 .70587 Mdot
.70587 .71763 Mdot
.6941 .70194 Mdot
.68234 .69018 Mdot
.6745 .67842 Mdot
.67057 .68626 Mdot
.66665 .68626 Mdot
.66273 .68626 Mdot
.66273 .68234 Mdot
.64313 .65881 Mdot
.55294 .56078 Mdot
.31766 .32158 Mdot
.27845 .26668 Mdot
.26668 .25492 Mdot
.23139 .23139 Mdot
.20002 .21571 Mdot
.3608 .38432 Mdot
.58431 .59999 Mdot
.45491 .60783 Mdot
.47843 .64705 Mdot
.4902 .67057 Mdot
.49804 .68234 Mdot
.49804 .67842 Mdot
.49804 .67842 Mdot
.49412 .66273 Mdot
.49412 .64705 Mdot
.50196 .64705 Mdot
.5098 .64705 Mdot
.52157 .65489 Mdot
.54509 .68234 Mdot
.54117 .68234 Mdot
.52941 .66665 Mdot
.54509 .67057 Mdot
.5647 .68626 Mdot
.57254 .69018 Mdot
.56078 .6941 Mdot
.55686 .70979 Mdot
.5647 .71763 Mdot
.5647 .71371 Mdot
.5647 .70587 Mdot
.57254 .70587 Mdot
.58039 .71371 Mdot
.58823 .72547 Mdot
.58431 .72155 Mdot
.59215 .71763 Mdot
.59607 .71371 Mdot
.61176 .71763 Mdot
.59999 .71763 Mdot
.61176 .72939 Mdot
.62352 .74116 Mdot
.62744 .74116 Mdot
.62352 .72939 Mdot
.6392 .73332 Mdot
.63528 .73332 Mdot
.64705 .749 Mdot
.65489 .76469 Mdot
.64313 .76469 Mdot
.64313 .76076 Mdot
.64705 .76469 Mdot
.64313 .749 Mdot
.65489 .75292 Mdot
.65881 .75292 Mdot
.66665 .76076 Mdot
.66665 .75292 Mdot
.67057 .749 Mdot
.68234 .75292 Mdot
.68626 .749 Mdot
.69802 .75684 Mdot
.6941 .75292 Mdot
.69802 .74508 Mdot
.69802 .73724 Mdot
.70587 .749 Mdot
.70979 .75684 Mdot
.70587 .76076 Mdot
.69802 .76469 Mdot
.70194 .76469 Mdot
.70979 .76861 Mdot
.70979 .76861 Mdot
.70979 .77253 Mdot
.70194 .77253 Mdot
.6941 .77253 Mdot
.6941 .75292 Mdot
.69802 .75684 Mdot
.70194 .76076 Mdot
.70587 .76469 Mdot
.70587 .76076 Mdot
.70587 .75292 Mdot
.71371 .75684 Mdot
.70979 .75684 Mdot
.70979 .75292 Mdot
.70979 .74116 Mdot
.71763 .72939 Mdot
.72547 .72547 Mdot
.73332 .72155 Mdot
.73724 .72547 Mdot
.73332 .73724 Mdot
.73332 .73332 Mdot
.73724 .73332 Mdot
.73332 .73332 Mdot
.72939 .74508 Mdot
.73332 .75684 Mdot
.72155 .74116 Mdot
.71371 .72547 Mdot
.71763 .72939 Mdot
.71763 .73332 Mdot
.72547 .74508 Mdot
.72939 .749 Mdot
.73332 .749 Mdot
.72939 .74116 Mdot
.73332 .749 Mdot
.72155 .73332 Mdot
.72939 .73332 Mdot
.73332 .73332 Mdot
.72547 .72155 Mdot
.72939 .72155 Mdot
.72547 .71763 Mdot
.72939 .72155 Mdot
.72547 .72547 Mdot
.72547 .72547 Mdot
.72547 .72939 Mdot
.71763 .72155 Mdot
.71763 .71371 Mdot
.71371 .70587 Mdot
.70979 .69802 Mdot
.70194 .69802 Mdot
.6941 .69018 Mdot
.69802 .6941 Mdot
.70194 .70587 Mdot
.70194 .70194 Mdot
.70194 .6941 Mdot
.70194 .69018 Mdot
.6941 .68234 Mdot
.6941 .68234 Mdot
.69802 .69018 Mdot
.6941 .69018 Mdot
.69018 .69018 Mdot
.68234 .68234 Mdot
.67057 .6745 Mdot
.66665 .68234 Mdot
.65881 .67842 Mdot
.65881 .67057 Mdot
.65489 .66273 Mdot
.65881 .66665 Mdot
.59607 .60783 Mdot
.48235 .5098 Mdot
.48628 .51372 Mdot
.45098 .47843 Mdot
.21963 .26276 Mdot
.18434 .21963 Mdot
.14513 .1765 Mdot
.13728 .16865 Mdot
.34511 .36472 Mdot
.56078 .56862 Mdot
.45491 .59999 Mdot
.47843 .64313 Mdot
.4902 .65881 Mdot
.48235 .66665 Mdot
.49412 .6745 Mdot
.49412 .6745 Mdot
.4902 .66273 Mdot
.49804 .65489 Mdot
.49412 .64313 Mdot
.49804 .6392 Mdot
.51765 .64313 Mdot
.52549 .64705 Mdot
.53333 .66273 Mdot
.53333 .65881 Mdot
.53333 .65489 Mdot
.54117 .6745 Mdot
.54509 .67842 Mdot
.53725 .69018 Mdot
.54902 .70194 Mdot
.55686 .70587 Mdot
.56078 .70194 Mdot
.56862 .70587 Mdot
.58039 .70587 Mdot
.58039 .70194 Mdot
.59607 .71763 Mdot
.60391 .72939 Mdot
.60783 .72547 Mdot
.60783 .71371 Mdot
.60391 .70979 Mdot
.60391 .71371 Mdot
.60391 .72547 Mdot
.6196 .74116 Mdot
.61568 .73332 Mdot
.6196 .73332 Mdot
.62744 .73332 Mdot
.64313 .73724 Mdot
.6392 .74508 Mdot
.63528 .749 Mdot
.63136 .75292 Mdot
.63528 .76076 Mdot
.63136 .75684 Mdot
.64705 .75684 Mdot
.64705 .75292 Mdot
.64705 .75292 Mdot
.65489 .75684 Mdot
.65489 .74116 Mdot
.66273 .74508 Mdot
.6745 .75292 Mdot
.68234 .75292 Mdot
.69018 .75292 Mdot
.6941 .75292 Mdot
.70194 .75292 Mdot
.70194 .75292 Mdot
.71371 .75684 Mdot
.70587 .75292 Mdot
.70194 .75292 Mdot
.70194 .75292 Mdot
.70194 .75684 Mdot
.70979 .76076 Mdot
.71763 .76861 Mdot
.72155 .77253 Mdot
.70587 .76861 Mdot
.70194 .77645 Mdot
.69018 .76861 Mdot
.6941 .76861 Mdot
.6941 .76076 Mdot
.70194 .76469 Mdot
.70194 .76469 Mdot
.70587 .76076 Mdot
.70587 .749 Mdot
.70979 .75292 Mdot
.71371 .75292 Mdot
.71763 .74508 Mdot
.71763 .73724 Mdot
.72155 .73724 Mdot
.72939 .74508 Mdot
.72939 .749 Mdot
.72155 .749 Mdot
.72939 .749 Mdot
.74116 .749 Mdot
.73332 .74116 Mdot
.72547 .74116 Mdot
.72155 .74116 Mdot
.72155 .73724 Mdot
.70979 .73332 Mdot
.70587 .73724 Mdot
.70979 .74508 Mdot
.70979 .74508 Mdot
.71371 .75292 Mdot
.71763 .75292 Mdot
.72547 .75292 Mdot
.72155 .74508 Mdot
.72547 .74116 Mdot
.71763 .73724 Mdot
.71371 .73332 Mdot
.71763 .72547 Mdot
.72155 .72939 Mdot
.72155 .72155 Mdot
.72547 .72155 Mdot
.72939 .72547 Mdot
.72547 .72547 Mdot
.72547 .72547 Mdot
.71371 .70979 Mdot
.71371 .70979 Mdot
.70979 .70979 Mdot
.71371 .72155 Mdot
.70194 .71371 Mdot
.6941 .70587 Mdot
.69802 .70587 Mdot
.69018 .69802 Mdot
.69018 .69802 Mdot
.69802 .6941 Mdot
.69018 .68626 Mdot
.69018 .67842 Mdot
.69018 .67842 Mdot
.6941 .70194 Mdot
.68626 .70979 Mdot
.68234 .70194 Mdot
.67842 .6941 Mdot
.6745 .69018 Mdot
.67057 .69018 Mdot
.65881 .68234 Mdot
.65489 .68626 Mdot
.65097 .6745 Mdot
.64705 .6745 Mdot
.64705 .67842 Mdot
.64705 .69018 Mdot
.63136 .68234 Mdot
.61176 .66273 Mdot
.50588 .56078 Mdot
.15297 .22355 Mdot
.16081 .21571 Mdot
.14513 .18434 Mdot
.12552 .16081 Mdot
.11768 .13728 Mdot
.12552 .10591 Mdot
.57254 .54902 Mdot
.78429 .77253 Mdot
.45491 .58823 Mdot
.47843 .6392 Mdot
.48628 .65881 Mdot
.47843 .66273 Mdot
.4902 .66665 Mdot
.48628 .65881 Mdot
.4902 .65881 Mdot
.4902 .65489 Mdot
.50196 .66665 Mdot
.5098 .66665 Mdot
.51765 .65881 Mdot
.52157 .65881 Mdot
.52157 .65489 Mdot
.53333 .66273 Mdot
.53725 .67057 Mdot
.53725 .67057 Mdot
.53333 .67057 Mdot
.54117 .68234 Mdot
.55294 .69018 Mdot
.56078 .6941 Mdot
.55686 .6941 Mdot
.56078 .69018 Mdot
.5647 .6941 Mdot
.58039 .70587 Mdot
.59215 .71763 Mdot
.60391 .72155 Mdot
.59999 .71763 Mdot
.59999 .72155 Mdot
.61176 .72939 Mdot
.61568 .73724 Mdot
.59999 .73724 Mdot
.60783 .73724 Mdot
.60783 .73332 Mdot
.60783 .72939 Mdot
.62352 .72939 Mdot
.63136 .73332 Mdot
.63136 .74116 Mdot
.62744 .749 Mdot
.63136 .749 Mdot
.6392 .76076 Mdot
.65097 .76469 Mdot
.64705 .76076 Mdot
.65489 .76469 Mdot
.66665 .77645 Mdot
.67057 .77253 Mdot
.6745 .76861 Mdot
.66665 .76076 Mdot
.67057 .75684 Mdot
.67057 .75684 Mdot
.68234 .76469 Mdot
.69018 .76076 Mdot
.6941 .75684 Mdot
.6941 .75292 Mdot
.69018 .75292 Mdot
.68626 .749 Mdot
.6941 .75292 Mdot
.70194 .749 Mdot
.69802 .74508 Mdot
.70194 .75684 Mdot
.70979 .75292 Mdot
.70587 .749 Mdot
.69802 .75292 Mdot
.69802 .749 Mdot
.69802 .749 Mdot
.68234 .74116 Mdot
.68234 .749 Mdot
.69018 .75292 Mdot
.6941 .749 Mdot
.69802 .75292 Mdot
.70194 .74508 Mdot
.70194 .73724 Mdot
.70979 .75292 Mdot
.71763 .75684 Mdot
.71763 .75292 Mdot
.71371 .74508 Mdot
.71763 .749 Mdot
.71371 .749 Mdot
.70587 .749 Mdot
.70979 .74508 Mdot
.72155 .749 Mdot
.72155 .74508 Mdot
.71763 .749 Mdot
.70979 .749 Mdot
.71371 .74508 Mdot
.70979 .74508 Mdot
.70587 .74116 Mdot
.71371 .749 Mdot
.72155 .75292 Mdot
.72547 .74508 Mdot
.71763 .74116 Mdot
.72155 .74508 Mdot
.71371 .74116 Mdot
.70587 .73332 Mdot
.70194 .73332 Mdot
.69802 .72547 Mdot
.70587 .72939 Mdot
.71371 .73724 Mdot
.72939 .74116 Mdot
.72939 .73724 Mdot
.73332 .74116 Mdot
.72939 .72939 Mdot
.72155 .72547 Mdot
.71763 .71763 Mdot
.70587 .71371 Mdot
.70587 .71763 Mdot
.70587 .72155 Mdot
.70194 .72939 Mdot
.6941 .72155 Mdot
.69018 .71763 Mdot
.69018 .71371 Mdot
.68234 .70587 Mdot
.68234 .70194 Mdot
.68626 .70587 Mdot
.68626 .70194 Mdot
.68626 .6941 Mdot
.69018 .71371 Mdot
.68234 .70979 Mdot
.68626 .71763 Mdot
.66665 .70587 Mdot
.66665 .70587 Mdot
.66273 .70587 Mdot
.65489 .70194 Mdot
.65097 .69802 Mdot
.64705 .68234 Mdot
.64705 .67842 Mdot
.6392 .6745 Mdot
.64705 .68234 Mdot
.62744 .6745 Mdot
.6196 .6745 Mdot
.61176 .67057 Mdot
.42746 .49412 Mdot
.31374 .38432 Mdot
.21963 .28629 Mdot
.18826 .251 Mdot
.15297 .20394 Mdot
.16473 .19218 Mdot
.20394 .20787 Mdot
.28237 .26276 Mdot
.15689 .14513 Mdot
.58431 .58823 Mdot
.78429 .78821 Mdot
.46275 .59607 Mdot
.48235 .6392 Mdot
.49412 .66273 Mdot
.49412 .66273 Mdot
.48628 .65881 Mdot
.4902 .65489 Mdot
.50196 .65881 Mdot
.51372 .66665 Mdot
.51765 .6745 Mdot
.51765 .67842 Mdot
.52157 .68234 Mdot
.51372 .66665 Mdot
.51765 .65881 Mdot
.52941 .66273 Mdot
.53333 .67842 Mdot
.54117 .68626 Mdot
.54117 .68626 Mdot
.53725 .68626 Mdot
.53725 .68626 Mdot
.54902 .69018 Mdot
.55686 .70194 Mdot
.55294 .70587 Mdot
.56078 .70979 Mdot
.5647 .71371 Mdot
.57254 .70979 Mdot
.58431 .71763 Mdot
.59215 .72547 Mdot
.58823 .72547 Mdot
.59999 .73724 Mdot
.59607 .73724 Mdot
.59607 .73724 Mdot
.59999 .73724 Mdot
.59999 .72939 Mdot
.60783 .72939 Mdot
.6196 .72547 Mdot
.62744 .72939 Mdot
.63136 .73332 Mdot
.62744 .72939 Mdot
.63136 .73724 Mdot
.6392 .75684 Mdot
.64705 .76861 Mdot
.65097 .77645 Mdot
.64705 .77253 Mdot
.65097 .77253 Mdot
.65881 .76861 Mdot
.66273 .76861 Mdot
.66273 .76861 Mdot
.67057 .77253 Mdot
.6745 .77253 Mdot
.67057 .76469 Mdot
.67842 .76861 Mdot
.68626 .76469 Mdot
.68626 .76861 Mdot
.68626 .76861 Mdot
.68234 .749 Mdot
.68626 .74116 Mdot
.6941 .74116 Mdot
.6941 .73724 Mdot
.70194 .749 Mdot
.69802 .75292 Mdot
.69802 .749 Mdot
.6941 .73724 Mdot
.68626 .73724 Mdot
.6941 .74508 Mdot
.6941 .75292 Mdot
.6941 .75684 Mdot
.69018 .75684 Mdot
.6941 .76076 Mdot
.6941 .75684 Mdot
.69802 .75684 Mdot
.70194 .75684 Mdot
.6941 .74508 Mdot
.69802 .74116 Mdot
.70194 .74508 Mdot
.69802 .749 Mdot
.6941 .74116 Mdot
.6941 .749 Mdot
.69802 .749 Mdot
.70587 .749 Mdot
.71371 .75684 Mdot
.71371 .76076 Mdot
.71371 .76469 Mdot
.70587 .75292 Mdot
.70587 .75292 Mdot
.70979 .74508 Mdot
.71763 .749 Mdot
.71371 .74508 Mdot
.70979 .73724 Mdot
.70979 .73724 Mdot
.70979 .74116 Mdot
.70979 .74508 Mdot
.71371 .749 Mdot
.70194 .72939 Mdot
.6941 .71763 Mdot
.70194 .72155 Mdot
.70979 .72939 Mdot
.71763 .74116 Mdot
.71763 .73724 Mdot
.72155 .74508 Mdot
.71371 .749 Mdot
.70587 .73724 Mdot
.71763 .73724 Mdot
.70979 .72939 Mdot
.70979 .72939 Mdot
.70587 .73724 Mdot
.6941 .72939 Mdot
.69018 .72939 Mdot
.6941 .73332 Mdot
.69018 .72547 Mdot
.68234 .71763 Mdot
.69018 .72155 Mdot
.69018 .72547 Mdot
.69018 .72155 Mdot
.69018 .72547 Mdot
.68626 .71763 Mdot
.67842 .70587 Mdot
.67057 .69802 Mdot
.66665 .6941 Mdot
.66273 .69802 Mdot
.65489 .69018 Mdot
.65489 .69802 Mdot
.65097 .69802 Mdot
.65489 .69802 Mdot
.65881 .69802 Mdot
.64313 .68626 Mdot
.63136 .6745 Mdot
.63528 .6745 Mdot
.63136 .6745 Mdot
.62352 .67842 Mdot
.61176 .66665 Mdot
.60391 .65489 Mdot
.59607 .6392 Mdot
.44706 .50196 Mdot
.3804 .44706 Mdot
.28237 .36472 Mdot
.29021 .36864 Mdot
.57646 .61568 Mdot
.51765 .54509 Mdot
.31766 .35687 Mdot
.31766 .34119 Mdot
.11376 .13728 Mdot
.32943 .34119 Mdot
.55294 .56078 Mdot
.45491 .59215 Mdot
.48235 .6392 Mdot
.49412 .65881 Mdot
.4902 .66665 Mdot
.4902 .66665 Mdot
.48628 .65881 Mdot
.50588 .66273 Mdot
.51372 .67057 Mdot
.51765 .67842 Mdot
.51372 .6745 Mdot
.51372 .67842 Mdot
.50588 .66665 Mdot
.51372 .66273 Mdot
.52157 .67842 Mdot
.52549 .6941 Mdot
.52549 .69802 Mdot
.53333 .70587 Mdot
.53333 .70587 Mdot
.53725 .69802 Mdot
.55294 .70194 Mdot
.55686 .70979 Mdot
.54902 .71371 Mdot
.56078 .72155 Mdot
.56078 .71763 Mdot
.5647 .71371 Mdot
.56862 .71371 Mdot
.58039 .71371 Mdot
.59607 .73332 Mdot
.59215 .74508 Mdot
.59607 .74508 Mdot
.59999 .74508 Mdot
.60783 .74508 Mdot
.60391 .73332 Mdot
.60783 .72547 Mdot
.61176 .73724 Mdot
.62352 .73724 Mdot
.63136 .73724 Mdot
.63136 .749 Mdot
.63528 .749 Mdot
.63528 .76076 Mdot
.63136 .76861 Mdot
.6392 .78037 Mdot
.6392 .77645 Mdot
.64313 .76861 Mdot
.6392 .76076 Mdot
.65489 .76861 Mdot
.65097 .77253 Mdot
.66665 .77645 Mdot
.65489 .77253 Mdot
.65489 .77253 Mdot
.67057 .78037 Mdot
.67842 .77645 Mdot
.68626 .77645 Mdot
.68626 .76861 Mdot
.68234 .75684 Mdot
.68626 .749 Mdot
.67842 .73332 Mdot
.68626 .749 Mdot
.68234 .749 Mdot
.69018 .75292 Mdot
.68626 .749 Mdot
.67842 .74508 Mdot
.69018 .74508 Mdot
.6941 .75292 Mdot
.69802 .76469 Mdot
.69802 .75684 Mdot
.6941 .75292 Mdot
.70194 .749 Mdot
.69802 .74508 Mdot
.70587 .749 Mdot
.70587 .75292 Mdot
.69802 .74508 Mdot
.69018 .74508 Mdot
.69018 .74116 Mdot
.6941 .749 Mdot
.6941 .74116 Mdot
.6941 .74116 Mdot
.69018 .73724 Mdot
.69802 .74508 Mdot
.71371 .75292 Mdot
.70979 .75292 Mdot
.70979 .76076 Mdot
.70587 .75292 Mdot
.70194 .75292 Mdot
.71371 .75292 Mdot
.70587 .74116 Mdot
.71371 .74508 Mdot
.70979 .74116 Mdot
.71371 .74116 Mdot
.71371 .73724 Mdot
.71763 .73724 Mdot
.71763 .73332 Mdot
.70979 .73724 Mdot
.71371 .74116 Mdot
.71763 .73332 Mdot
.71371 .72939 Mdot
.71371 .73724 Mdot
.71371 .749 Mdot
.70587 .74116 Mdot
.70979 .74508 Mdot
.70587 .73724 Mdot
.71371 .73332 Mdot
.70979 .73332 Mdot
.70979 .73724 Mdot
.70979 .74116 Mdot
.70587 .74116 Mdot
.69018 .73724 Mdot
.68234 .73332 Mdot
.67842 .72939 Mdot
.68234 .72547 Mdot
.69018 .71763 Mdot
.69802 .71763 Mdot
.69802 .71763 Mdot
.6941 .70587 Mdot
.69018 .70587 Mdot
.6745 .69802 Mdot
.65489 .68626 Mdot
.66273 .6941 Mdot
.66665 .70587 Mdot
.66273 .70979 Mdot
.65881 .70979 Mdot
.66273 .70979 Mdot
.66665 .70979 Mdot
.65097 .70194 Mdot
.64313 .69802 Mdot
.63528 .68626 Mdot
.63136 .68234 Mdot
.63528 .6941 Mdot
.63136 .6941 Mdot
.62352 .68626 Mdot
.61568 .6745 Mdot
.61176 .6745 Mdot
.60783 .67057 Mdot
.59607 .65881 Mdot
.55686 .6196 Mdot
.54509 .60391 Mdot
.56078 .61176 Mdot
.57254 .61176 Mdot
.55686 .59607 Mdot
.57646 .58823 Mdot
.29806 .31766 Mdot
.08631 .1216 Mdot
.10591 .13728 Mdot
.09415 .11376 Mdot
.31374 .3255 Mdot
.52549 .53333 Mdot
.42354 .56862 Mdot
.48235 .64705 Mdot
.4902 .66273 Mdot
.48628 .66665 Mdot
.48628 .67057 Mdot
.48628 .66273 Mdot
.50196 .66665 Mdot
.50588 .66273 Mdot
.5098 .66665 Mdot
.51372 .66665 Mdot
.5098 .66273 Mdot
.51372 .66665 Mdot
.52157 .67057 Mdot
.52157 .67057 Mdot
.52549 .67842 Mdot
.52549 .68234 Mdot
.52941 .69802 Mdot
.52941 .69802 Mdot
.52549 .68626 Mdot
.53333 .69018 Mdot
.54902 .70194 Mdot
.55294 .70194 Mdot
.56078 .70587 Mdot
.5647 .70194 Mdot
.56862 .70587 Mdot
.57254 .71371 Mdot
.57646 .72547 Mdot
.58431 .73332 Mdot
.58823 .74508 Mdot
.59215 .74508 Mdot
.59999 .749 Mdot
.61176 .749 Mdot
.60783 .74508 Mdot
.61176 .74116 Mdot
.6196 .73724 Mdot
.61568 .72547 Mdot
.63528 .74508 Mdot
.63528 .75292 Mdot
.63528 .75684 Mdot
.64705 .77253 Mdot
.6392 .76861 Mdot
.63528 .76861 Mdot
.64313 .77253 Mdot
.6392 .76861 Mdot
.64705 .76076 Mdot
.65097 .75684 Mdot
.65097 .75684 Mdot
.66273 .76861 Mdot
.65881 .76469 Mdot
.66273 .76076 Mdot
.67057 .76469 Mdot
.67057 .75684 Mdot
.6745 .75292 Mdot
.67057 .74508 Mdot
.67842 .749 Mdot
.6745 .74116 Mdot
.6745 .74508 Mdot
.68234 .749 Mdot
.6745 .74508 Mdot
.6745 .74508 Mdot
.68234 .749 Mdot
.69018 .749 Mdot
.69802 .75292 Mdot
.69802 .76469 Mdot
.69018 .76469 Mdot
.6941 .76469 Mdot
.69018 .76076 Mdot
.6941 .75292 Mdot
.69802 .749 Mdot
.70194 .74508 Mdot
.71371 .75292 Mdot
.69018 .73332 Mdot
.6941 .74116 Mdot
.70587 .75292 Mdot
.70587 .75292 Mdot
.70194 .74508 Mdot
.69802 .74116 Mdot
.6941 .73332 Mdot
.70194 .74116 Mdot
.70194 .74508 Mdot
.70587 .74508 Mdot
.70194 .73332 Mdot
.70194 .74508 Mdot
.6941 .74116 Mdot
.6941 .74116 Mdot
.70194 .74116 Mdot
.70194 .74116 Mdot
.70979 .74116 Mdot
.70587 .72939 Mdot
.70979 .72939 Mdot
.70194 .72547 Mdot
.70194 .73332 Mdot
.70587 .73724 Mdot
.70587 .74116 Mdot
.71371 .74116 Mdot
.70979 .74116 Mdot
.71371 .74116 Mdot
.71371 .73724 Mdot
.70979 .73724 Mdot
.70194 .74116 Mdot
.70587 .74116 Mdot
.70194 .73724 Mdot
.70979 .74116 Mdot
.70587 .73724 Mdot
.70194 .74116 Mdot
.69802 .73332 Mdot
.6941 .72939 Mdot
.69802 .72939 Mdot
.6941 .72547 Mdot
.68626 .71763 Mdot
.68234 .70194 Mdot
.67842 .69018 Mdot
.68234 .68626 Mdot
.68234 .68234 Mdot
.68626 .6941 Mdot
.68234 .69802 Mdot
.67057 .70587 Mdot
.66273 .69802 Mdot
.66273 .69802 Mdot
.66665 .70979 Mdot
.65881 .70979 Mdot
.65881 .71371 Mdot
.65489 .70587 Mdot
.65881 .70587 Mdot
.65489 .70194 Mdot
.64705 .69802 Mdot
.63528 .69018 Mdot
.63528 .70194 Mdot
.62352 .6941 Mdot
.61568 .68234 Mdot
.60783 .6745 Mdot
.61568 .68234 Mdot
.61568 .67842 Mdot
.62352 .68234 Mdot
.60783 .66665 Mdot
.59999 .65881 Mdot
.59607 .65097 Mdot
.59215 .64313 Mdot
.58823 .63528 Mdot
.56078 .61176 Mdot
.52941 .56078 Mdot
.29413 .33335 Mdot
.18434 .21571 Mdot
.14513 .16865 Mdot
.11376 .13336 Mdot
.08631 .10199 Mdot
.11768 .12552 Mdot
.60391 .59999 Mdot
.78821 .78821 Mdot
.43922 .57254 Mdot
.47843 .63136 Mdot
.49804 .66273 Mdot
.49804 .6745 Mdot
.48628 .67057 Mdot
.48235 .66273 Mdot
.4902 .65489 Mdot
.50196 .65097 Mdot
.51765 .65489 Mdot
.5098 .64705 Mdot
.5098 .65881 Mdot
.50588 .65881 Mdot
.5098 .67057 Mdot
.51765 .6745 Mdot
.51765 .6745 Mdot
.52549 .68234 Mdot
.52941 .69018 Mdot
.51372 .68234 Mdot
.51765 .68626 Mdot
.52549 .68234 Mdot
.52549 .6745 Mdot
.54117 .68234 Mdot
.54902 .67842 Mdot
.56078 .68234 Mdot
.56078 .69018 Mdot
.5647 .70194 Mdot
.56862 .71763 Mdot
.57254 .71371 Mdot
.58431 .72155 Mdot
.59999 .73724 Mdot
.59607 .73332 Mdot
.59999 .73332 Mdot
.60391 .72155 Mdot
.60391 .70979 Mdot
.61176 .70979 Mdot
.61568 .71763 Mdot
.62744 .72939 Mdot
.62744 .73724 Mdot
.6196 .74116 Mdot
.62744 .749 Mdot
.63528 .749 Mdot
.63136 .75292 Mdot
.6392 .76076 Mdot
.6392 .76076 Mdot
.6392 .75292 Mdot
.63528 .73724 Mdot
.65489 .74508 Mdot
.65489 .74116 Mdot
.66665 .749 Mdot
.65881 .749 Mdot
.65881 .74508 Mdot
.66273 .73724 Mdot
.66273 .72547 Mdot
.6745 .73332 Mdot
.66665 .73332 Mdot
.67057 .74116 Mdot
.66665 .73724 Mdot
.67057 .74508 Mdot
.67842 .73724 Mdot
.67842 .73724 Mdot
.68626 .74508 Mdot
.68234 .74508 Mdot
.6941 .75684 Mdot
.69018 .75684 Mdot
.68234 .75684 Mdot
.67842 .75292 Mdot
.69018 .75684 Mdot
.68626 .75292 Mdot
.67842 .74508 Mdot
.68234 .74116 Mdot
.69018 .73724 Mdot
.70194 .74116 Mdot
.69802 .74508 Mdot
.69018 .74116 Mdot
.6941 .74116 Mdot
.6941 .74116 Mdot
.6941 .74116 Mdot
.69018 .74116 Mdot
.70194 .74508 Mdot
.69802 .74116 Mdot
.6941 .73724 Mdot
.6941 .73724 Mdot
.69018 .73332 Mdot
.69018 .74116 Mdot
.68626 .73724 Mdot
.69802 .74508 Mdot
.70194 .74508 Mdot
.70587 .74116 Mdot
.70587 .73332 Mdot
.70979 .73724 Mdot
.70194 .73724 Mdot
.70194 .73332 Mdot
.69802 .73332 Mdot
.69802 .73332 Mdot
.6941 .72939 Mdot
.6941 .73332 Mdot
.69802 .74116 Mdot
.69018 .73724 Mdot
.69802 .73724 Mdot
.69802 .73332 Mdot
.6941 .73332 Mdot
.68234 .72939 Mdot
.67842 .72155 Mdot
.67842 .72155 Mdot
.68234 .72939 Mdot
.68234 .72939 Mdot
.67842 .72547 Mdot
.67842 .71763 Mdot
.67057 .70587 Mdot
.6745 .70587 Mdot
.68234 .70587 Mdot
.6745 .68626 Mdot
.67842 .68234 Mdot
.67057 .68626 Mdot
.68234 .69802 Mdot
.67842 .70194 Mdot
.66665 .70587 Mdot
.65489 .69802 Mdot
.65489 .6941 Mdot
.64705 .68626 Mdot
.65489 .70194 Mdot
.65881 .70587 Mdot
.65097 .70587 Mdot
.65489 .70587 Mdot
.65489 .69802 Mdot
.65097 .69802 Mdot
.65489 .70979 Mdot
.6392 .70587 Mdot
.62744 .70587 Mdot
.6196 .70194 Mdot
.62352 .69018 Mdot
.61176 .67842 Mdot
.61176 .6745 Mdot
.60783 .67057 Mdot
.59607 .66273 Mdot
.59607 .66273 Mdot
.59215 .65881 Mdot
.59607 .65881 Mdot
.59215 .65881 Mdot
.57646 .6392 Mdot
.5647 .62352 Mdot
.54509 .58823 Mdot
.52549 .54902 Mdot
.40785 .43138 Mdot
.20787 .24316 Mdot
.20002 .22747 Mdot
.16081 .18042 Mdot
.20002 .20787 Mdot
.21179 .21963 Mdot
.17257 .19218 Mdot
.57254 .58823 Mdot
.78429 .79213 Mdot
.45491 .5647 Mdot
.47059 .61176 Mdot
.48628 .64705 Mdot
.4902 .65881 Mdot
.49412 .66273 Mdot
.47843 .64705 Mdot
.48235 .6392 Mdot
.50196 .6392 Mdot
.50196 .63136 Mdot
.49804 .63528 Mdot
.4902 .63136 Mdot
.4902 .64705 Mdot
.4902 .65097 Mdot
.49804 .65881 Mdot
.50588 .66665 Mdot
.51372 .6745 Mdot
.52157 .68626 Mdot
.52157 .67842 Mdot
.52549 .67842 Mdot
.52941 .67842 Mdot
.52941 .67057 Mdot
.53333 .67057 Mdot
.55294 .68234 Mdot
.56078 .69018 Mdot
.56078 .6941 Mdot
.55294 .68626 Mdot
.55294 .68626 Mdot
.5647 .69802 Mdot
.58039 .70587 Mdot
.59215 .71371 Mdot
.59215 .70979 Mdot
.59999 .71763 Mdot
.58823 .70587 Mdot
.59999 .70587 Mdot
.61568 .71371 Mdot
.61176 .71371 Mdot
.60391 .71763 Mdot
.60783 .72155 Mdot
.60783 .72547 Mdot
.62744 .73724 Mdot
.61568 .72939 Mdot
.62352 .73724 Mdot
.62352 .749 Mdot
.62352 .74508 Mdot
.64313 .749 Mdot
.6392 .74116 Mdot
.64705 .72939 Mdot
.65489 .73724 Mdot
.65489 .73724 Mdot
.65097 .73332 Mdot
.64705 .72547 Mdot
.65881 .72939 Mdot
.66665 .72547 Mdot
.6745 .72939 Mdot
.6745 .72939 Mdot
.66665 .73332 Mdot
.65881 .73332 Mdot
.65881 .74116 Mdot
.66273 .73724 Mdot
.66665 .73724 Mdot
.67057 .73724 Mdot
.67057 .74116 Mdot
.66665 .74116 Mdot
.67057 .749 Mdot
.66665 .73332 Mdot
.67057 .74116 Mdot
.67842 .74508 Mdot
.67842 .74116 Mdot
.68626 .749 Mdot
.68626 .749 Mdot
.67842 .73724 Mdot
.67842 .73724 Mdot
.67842 .73724 Mdot
.6745 .72939 Mdot
.67842 .72939 Mdot
.68626 .72939 Mdot
.68626 .72155 Mdot
.68234 .72547 Mdot
.68234 .72547 Mdot
.6941 .73332 Mdot
.69018 .73724 Mdot
.6941 .73724 Mdot
.68626 .72939 Mdot
.67842 .72547 Mdot
.69018 .72939 Mdot
.68626 .72939 Mdot
.69018 .73332 Mdot
.68626 .72155 Mdot
.68626 .72155 Mdot
.69018 .72547 Mdot
.69802 .72939 Mdot
.69802 .72547 Mdot
.68234 .71763 Mdot
.69018 .72939 Mdot
.69018 .72939 Mdot
.69018 .73724 Mdot
.67842 .73332 Mdot
.68234 .74116 Mdot
.68234 .73724 Mdot
.67842 .72547 Mdot
.6745 .71763 Mdot
.67057 .71371 Mdot
.67057 .71371 Mdot
.67057 .71763 Mdot
.67057 .72155 Mdot
.6745 .72547 Mdot
.68234 .73332 Mdot
.67057 .71763 Mdot
.6745 .71763 Mdot
.67842 .71763 Mdot
.67057 .70587 Mdot
.67057 .70194 Mdot
.6745 .69802 Mdot
.66665 .69018 Mdot
.66273 .68234 Mdot
.65097 .6745 Mdot
.65489 .68626 Mdot
.65097 .68626 Mdot
.64313 .68234 Mdot
.6392 .68234 Mdot
.64705 .6941 Mdot
.64705 .6941 Mdot
.65097 .69802 Mdot
.65097 .6941 Mdot
.63528 .67842 Mdot
.6392 .68626 Mdot
.63528 .68626 Mdot
.63136 .69018 Mdot
.6196 .68626 Mdot
.6196 .6745 Mdot
.60391 .65881 Mdot
.59607 .65881 Mdot
.59607 .65881 Mdot
.59215 .65489 Mdot
.59215 .65489 Mdot
.59215 .65097 Mdot
.58823 .64313 Mdot
.58039 .62744 Mdot
.5647 .62352 Mdot
.56078 .62744 Mdot
.56078 .62352 Mdot
.54509 .60391 Mdot
.54509 .59607 Mdot
.54509 .58823 Mdot
.48235 .52941 Mdot
.45491 .50196 Mdot
.40393 .45491 Mdot
.36472 .41569 Mdot
.251 .30198 Mdot
.20002 .26276 Mdot
.24316 .30198 Mdot
.31766 .35687 Mdot
.41569 .43922 Mdot
.53725 .55686 Mdot
.41961 .52549 Mdot
.47451 .60391 Mdot
.48628 .6392 Mdot
.4902 .65097 Mdot
.47843 .64705 Mdot
.48628 .64705 Mdot
.47843 .63528 Mdot
.48235 .63136 Mdot
.48628 .63136 Mdot
.50196 .65097 Mdot
.49804 .65489 Mdot
.4902 .65489 Mdot
.48628 .65489 Mdot
.49412 .65489 Mdot
.50196 .65881 Mdot
.5098 .66665 Mdot
.52157 .67842 Mdot
.52157 .68234 Mdot
.52549 .68234 Mdot
.52157 .6745 Mdot
.53333 .6745 Mdot
.54117 .67842 Mdot
.55686 .6941 Mdot
.55294 .69018 Mdot
.55686 .6941 Mdot
.55294 .6941 Mdot
.55686 .70194 Mdot
.55294 .69802 Mdot
.56078 .70194 Mdot
.58039 .70979 Mdot
.58431 .71371 Mdot
.59215 .71763 Mdot
.59215 .71371 Mdot
.58039 .70587 Mdot
.58039 .70587 Mdot
.58431 .70979 Mdot
.58823 .71371 Mdot
.59607 .71763 Mdot
.60391 .72939 Mdot
.60783 .72939 Mdot
.61176 .72939 Mdot
.61176 .73332 Mdot
.62352 .74116 Mdot
.61176 .74508 Mdot
.6196 .749 Mdot
.63528 .75292 Mdot
.6392 .74508 Mdot
.64705 .74116 Mdot
.65489 .74508 Mdot
.65489 .74508 Mdot
.64705 .73724 Mdot
.65097 .73724 Mdot
.64705 .72939 Mdot
.65097 .72547 Mdot
.65489 .73724 Mdot
.65881 .749 Mdot
.65489 .74508 Mdot
.65489 .74508 Mdot
.65489 .73724 Mdot
.66273 .74116 Mdot
.65881 .74116 Mdot
.65489 .73724 Mdot
.65097 .74116 Mdot
.66273 .749 Mdot
.66273 .749 Mdot
.66665 .75292 Mdot
.67057 .749 Mdot
.67057 .749 Mdot
.66273 .74508 Mdot
.67057 .74116 Mdot
.66665 .73724 Mdot
.66665 .74116 Mdot
.66273 .73332 Mdot
.67057 .72939 Mdot
.67057 .72939 Mdot
.67842 .73724 Mdot
.68234 .73724 Mdot
.68234 .73724 Mdot
.6745 .72939 Mdot
.67842 .72939 Mdot
.67842 .73332 Mdot
.68234 .73724 Mdot
.67842 .73332 Mdot
.68234 .72939 Mdot
.68234 .72939 Mdot
.67842 .72547 Mdot
.68234 .72939 Mdot
.67842 .73724 Mdot
.67842 .73724 Mdot
.68234 .73332 Mdot
.69018 .73724 Mdot
.67842 .72939 Mdot
.67057 .72155 Mdot
.67057 .72547 Mdot
.67842 .73724 Mdot
.69018 .749 Mdot
.67842 .74116 Mdot
.67842 .75292 Mdot
.67842 .74508 Mdot
.66273 .72939 Mdot
.66273 .71763 Mdot
.67057 .72155 Mdot
.6745 .72939 Mdot
.67057 .73332 Mdot
.66273 .73332 Mdot
.66665 .73332 Mdot
.66665 .72547 Mdot
.66273 .71371 Mdot
.66273 .70979 Mdot
.66665 .70979 Mdot
.6745 .72155 Mdot
.67057 .71763 Mdot
.66273 .70194 Mdot
.67057 .70587 Mdot
.66273 .70194 Mdot
.64705 .69802 Mdot
.64313 .69802 Mdot
.65489 .69802 Mdot
.65097 .68626 Mdot
.64313 .68626 Mdot
.64313 .69018 Mdot
.63528 .69018 Mdot
.6392 .69802 Mdot
.63528 .6941 Mdot
.62744 .69018 Mdot
.63136 .6941 Mdot
.62352 .6941 Mdot
.60783 .67842 Mdot
.60783 .6745 Mdot
.60783 .6745 Mdot
.60783 .6745 Mdot
.59607 .66665 Mdot
.59607 .66665 Mdot
.59607 .66665 Mdot
.59607 .66273 Mdot
.59215 .65489 Mdot
.58431 .64705 Mdot
.58431 .64705 Mdot
.57646 .63528 Mdot
.58039 .62744 Mdot
.57254 .6196 Mdot
.56078 .61176 Mdot
.56078 .61176 Mdot
.54902 .60783 Mdot
.54117 .60391 Mdot
.52941 .58823 Mdot
.51765 .58039 Mdot
.50588 .57254 Mdot
.47451 .54902 Mdot
.47059 .54902 Mdot
.47059 .55686 Mdot
.47843 .56078 Mdot
.40785 .47843 Mdot
.14513 .22747 Mdot
.20394 .25884 Mdot
.27845 .32943 Mdot
.51372 .54117 Mdot
.42354 .52549 Mdot
.45491 .58431 Mdot
.47451 .61568 Mdot
.48628 .6392 Mdot
.47451 .64705 Mdot
.47843 .65489 Mdot
.48235 .65489 Mdot
.48235 .65489 Mdot
.48235 .65097 Mdot
.48235 .64705 Mdot
.48628 .64705 Mdot
.48235 .65097 Mdot
.48628 .65881 Mdot
.4902 .65489 Mdot
.49804 .65881 Mdot
.50196 .65881 Mdot
.51372 .66665 Mdot
.52549 .6745 Mdot
.51765 .67842 Mdot
.51372 .6745 Mdot
.52157 .6745 Mdot
.52941 .6745 Mdot
.53725 .68234 Mdot
.54117 .68234 Mdot
.53725 .69018 Mdot
.53725 .6941 Mdot
.54117 .70194 Mdot
.53725 .70587 Mdot
.54902 .70587 Mdot
.55686 .70979 Mdot
.5647 .70979 Mdot
.56862 .72547 Mdot
.57254 .72547 Mdot
.56078 .71763 Mdot
.5647 .72547 Mdot
.56862 .71763 Mdot
.5647 .71371 Mdot
.57646 .72155 Mdot
.58039 .72939 Mdot
.58431 .74116 Mdot
.58823 .74116 Mdot
.58431 .73332 Mdot
.60391 .74116 Mdot
.60783 .74508 Mdot
.60783 .749 Mdot
.61568 .74508 Mdot
.63136 .749 Mdot
.63136 .72939 Mdot
.6392 .74116 Mdot
.64705 .749 Mdot
.64705 .749 Mdot
.64313 .74508 Mdot
.64313 .74116 Mdot
.64705 .74508 Mdot
.65097 .749 Mdot
.64313 .74508 Mdot
.64705 .749 Mdot
.64705 .74508 Mdot
.64313 .74508 Mdot
.64705 .74116 Mdot
.65097 .74508 Mdot
.65097 .75292 Mdot
.65097 .75684 Mdot
.65881 .76076 Mdot
.65881 .76076 Mdot
.65881 .75684 Mdot
.65489 .75684 Mdot
.65489 .749 Mdot
.65881 .749 Mdot
.66665 .749 Mdot
.6745 .74116 Mdot
.66665 .72939 Mdot
.66273 .72547 Mdot
.66665 .72939 Mdot
.68234 .74116 Mdot
.67842 .74116 Mdot
.67842 .74508 Mdot
.6745 .749 Mdot
.6745 .76076 Mdot
.67057 .76076 Mdot
.67057 .75684 Mdot
.67057 .75292 Mdot
.65881 .73332 Mdot
.65881 .72547 Mdot
.66665 .73332 Mdot
.66273 .72939 Mdot
.66273 .72547 Mdot
.66665 .73724 Mdot
.66273 .74116 Mdot
.67057 .749 Mdot
.6745 .75684 Mdot
.67057 .75292 Mdot
.67057 .749 Mdot
.66273 .73724 Mdot
.65489 .72939 Mdot
.66273 .73332 Mdot
.66273 .73332 Mdot
.66665 .73724 Mdot
.6745 .73724 Mdot
.66665 .73332 Mdot
.66273 .73332 Mdot
.66273 .73332 Mdot
.66665 .74116 Mdot
.66665 .74116 Mdot
.66665 .749 Mdot
.65489 .73332 Mdot
.65881 .72939 Mdot
.65881 .72155 Mdot
.65097 .70979 Mdot
.65881 .70979 Mdot
.65489 .71371 Mdot
.66273 .71763 Mdot
.66273 .71763 Mdot
.66273 .72155 Mdot
.65489 .72155 Mdot
.64705 .70979 Mdot
.64313 .70587 Mdot
.6392 .70194 Mdot
.6392 .69802 Mdot
.6392 .6941 Mdot
.63136 .69802 Mdot
.6392 .71371 Mdot
.6392 .71763 Mdot
.62744 .71371 Mdot
.62744 .71371 Mdot
.62352 .70979 Mdot
.60783 .70194 Mdot
.59607 .69018 Mdot
.59999 .68626 Mdot
.59999 .67842 Mdot
.59215 .6745 Mdot
.58823 .6745 Mdot
.58039 .66273 Mdot
.57646 .66273 Mdot
.57646 .65881 Mdot
.57646 .66665 Mdot
.57254 .65881 Mdot
.57254 .65097 Mdot
.56862 .64705 Mdot
.5647 .63528 Mdot
.55686 .6196 Mdot
.55686 .61176 Mdot
.56078 .6196 Mdot
.55294 .61568 Mdot
.54509 .60391 Mdot
.52549 .58431 Mdot
.51372 .57646 Mdot
.5098 .57646 Mdot
.50588 .57254 Mdot
.49412 .57254 Mdot
.4902 .58039 Mdot
.48235 .57254 Mdot
.47843 .56862 Mdot
.4353 .52157 Mdot
.43138 .50588 Mdot
.20002 .28237 Mdot
.07454 .15297 Mdot
.04709 .09807 Mdot
.50196 .52157 Mdot
.75292 .75684 Mdot
.41569 .51372 Mdot
.47059 .58431 Mdot
.48235 .61176 Mdot
.48235 .62744 Mdot
.47451 .64705 Mdot
.47059 .65097 Mdot
.45098 .64313 Mdot
.45098 .65097 Mdot
.45883 .65489 Mdot
.47451 .65489 Mdot
.47451 .64313 Mdot
.48235 .64705 Mdot
.48235 .65489 Mdot
.4902 .65489 Mdot
.49412 .65097 Mdot
.49804 .64313 Mdot
.51372 .6392 Mdot
.52157 .64313 Mdot
.51765 .64705 Mdot
.51765 .67057 Mdot
.5098 .67057 Mdot
.51765 .6745 Mdot
.52941 .67842 Mdot
.53333 .68234 Mdot
.53725 .69018 Mdot
.53725 .70194 Mdot
.52941 .70194 Mdot
.53725 .70979 Mdot
.53725 .69802 Mdot
.54117 .69802 Mdot
.55686 .70587 Mdot
.56078 .71371 Mdot
.5647 .72547 Mdot
.56078 .72547 Mdot
.5647 .73332 Mdot
.56862 .72939 Mdot
.5647 .70979 Mdot
.56862 .71371 Mdot
.58039 .72547 Mdot
.57646 .72939 Mdot
.57254 .72547 Mdot
.57254 .72547 Mdot
.58823 .72939 Mdot
.60783 .74508 Mdot
.60783 .74116 Mdot
.61568 .74116 Mdot
.62744 .74116 Mdot
.63528 .74116 Mdot
.63528 .73724 Mdot
.6392 .73724 Mdot
.64313 .74508 Mdot
.64705 .75292 Mdot
.6392 .749 Mdot
.64313 .75292 Mdot
.65097 .75684 Mdot
.63528 .74508 Mdot
.64705 .75684 Mdot
.65097 .75684 Mdot
.64705 .75684 Mdot
.6392 .749 Mdot
.6392 .73724 Mdot
.6392 .74508 Mdot
.64313 .749 Mdot
.64313 .75292 Mdot
.65097 .749 Mdot
.65097 .74508 Mdot
.65097 .73724 Mdot
.65489 .749 Mdot
.65097 .74116 Mdot
.65489 .73724 Mdot
.66273 .73332 Mdot
.65881 .72547 Mdot
.66273 .72155 Mdot
.66665 .73332 Mdot
.65881 .72155 Mdot
.66273 .73724 Mdot
.66665 .75684 Mdot
.6745 .76861 Mdot
.67057 .76469 Mdot
.67057 .76469 Mdot
.66273 .75684 Mdot
.65489 .75292 Mdot
.64705 .74508 Mdot
.65097 .73332 Mdot
.65489 .73332 Mdot
.66273 .73724 Mdot
.66273 .72547 Mdot
.65881 .72547 Mdot
.66665 .72939 Mdot
.66273 .73332 Mdot
.66273 .74508 Mdot
.66665 .74116 Mdot
.66273 .73724 Mdot
.65489 .73332 Mdot
.65097 .72547 Mdot
.65489 .72939 Mdot
.65881 .73332 Mdot
.65489 .72547 Mdot
.66273 .72939 Mdot
.65881 .73332 Mdot
.64313 .71763 Mdot
.65489 .72547 Mdot
.65881 .72939 Mdot
.65489 .72939 Mdot
.65097 .72547 Mdot
.64705 .72155 Mdot
.65489 .72155 Mdot
.65097 .71371 Mdot
.65097 .71371 Mdot
.65489 .70979 Mdot
.64705 .70979 Mdot
.6392 .71371 Mdot
.63528 .71371 Mdot
.63528 .70194 Mdot
.64705 .70979 Mdot
.64313 .71371 Mdot
.62744 .70587 Mdot
.62352 .70194 Mdot
.62352 .68626 Mdot
.62352 .68234 Mdot
.62352 .68234 Mdot
.63136 .70194 Mdot
.63136 .71763 Mdot
.61176 .70979 Mdot
.61568 .71371 Mdot
.59999 .69802 Mdot
.59607 .68626 Mdot
.61176 .70587 Mdot
.59999 .69802 Mdot
.59215 .6941 Mdot
.58823 .68626 Mdot
.58039 .67057 Mdot
.57646 .65881 Mdot
.57646 .65489 Mdot
.58039 .66273 Mdot
.57646 .66273 Mdot
.56078 .65489 Mdot
.56078 .64313 Mdot
.56078 .62744 Mdot
.55294 .61176 Mdot
.54902 .60783 Mdot
.55686 .6196 Mdot
.54902 .62744 Mdot
.54117 .61568 Mdot
.53725 .60783 Mdot
.5098 .57646 Mdot
.51372 .58431 Mdot
.51372 .58431 Mdot
.51765 .59215 Mdot
.5098 .58823 Mdot
.5098 .58431 Mdot
.49804 .57646 Mdot
.48628 .55686 Mdot
.47843 .54509 Mdot
.45883 .52157 Mdot
.48235 .53333 Mdot
.21571 .27845 Mdot
.03925 .09415 Mdot
.03141 .0667 Mdot
.02357 .04709 Mdot
.41961 .53333 Mdot
.47451 .59607 Mdot
.48628 .62352 Mdot
.48235 .64705 Mdot
.47843 .66665 Mdot
.46667 .66273 Mdot
.45491 .65097 Mdot
.45491 .64705 Mdot
.45883 .64313 Mdot
.46275 .6392 Mdot
.48235 .64705 Mdot
.4902 .65097 Mdot
.48628 .66273 Mdot
.49412 .67057 Mdot
.5098 .6745 Mdot
.50196 .65097 Mdot
.5098 .65097 Mdot
.51372 .64705 Mdot
.51372 .65489 Mdot
.51765 .67842 Mdot
.51372 .69018 Mdot
.51372 .69018 Mdot
.52157 .68626 Mdot
.52157 .6745 Mdot
.53333 .69018 Mdot
.52941 .70194 Mdot
.53333 .71371 Mdot
.52941 .70979 Mdot
.53725 .69802 Mdot
.55294 .6941 Mdot
.57254 .70979 Mdot
.55686 .6941 Mdot
.56862 .71763 Mdot
.56862 .72547 Mdot
.56862 .72547 Mdot
.57254 .72155 Mdot
.57254 .70587 Mdot
.57646 .70587 Mdot
.58039 .70587 Mdot
.57646 .70194 Mdot
.58431 .70979 Mdot
.58823 .71371 Mdot
.59215 .71763 Mdot
.60783 .72547 Mdot
.61176 .73332 Mdot
.60783 .72547 Mdot
.6196 .73724 Mdot
.62744 .72939 Mdot
.63528 .72547 Mdot
.64313 .73332 Mdot
.63528 .73724 Mdot
.6392 .74508 Mdot
.64705 .75684 Mdot
.64705 .75292 Mdot
.62744 .74116 Mdot
.62744 .74116 Mdot
.63528 .73724 Mdot
.64705 .75292 Mdot
.64705 .76076 Mdot
.64313 .75684 Mdot
.64313 .749 Mdot
.65097 .74508 Mdot
.64705 .749 Mdot
.65489 .75292 Mdot
.65097 .74116 Mdot
.64313 .73332 Mdot
.65489 .73724 Mdot
.65489 .73724 Mdot
.65489 .73724 Mdot
.65097 .72939 Mdot
.65097 .71763 Mdot
.65097 .70979 Mdot
.65489 .71371 Mdot
.65097 .71763 Mdot
.65489 .72939 Mdot
.65881 .74508 Mdot
.65881 .75684 Mdot
.65097 .75292 Mdot
.65489 .75684 Mdot
.65881 .76469 Mdot
.65097 .75684 Mdot
.65097 .75684 Mdot
.65881 .75292 Mdot
.65489 .73724 Mdot
.66273 .73724 Mdot
.66273 .72939 Mdot
.65881 .72547 Mdot
.65489 .72155 Mdot
.66273 .72547 Mdot
.66273 .72547 Mdot
.66665 .73724 Mdot
.65881 .72939 Mdot
.65881 .72939 Mdot
.65881 .73332 Mdot
.65097 .72939 Mdot
.65097 .72939 Mdot
.65489 .72547 Mdot
.65489 .72547 Mdot
.65097 .72939 Mdot
.65881 .73332 Mdot
.65881 .72939 Mdot
.65881 .72547 Mdot
.65489 .71763 Mdot
.66273 .71763 Mdot
.65881 .72547 Mdot
.65881 .72547 Mdot
.66273 .72155 Mdot
.65881 .71763 Mdot
.66273 .71763 Mdot
.65489 .70979 Mdot
.64705 .71371 Mdot
.63528 .70587 Mdot
.63528 .70587 Mdot
.62744 .70587 Mdot
.62744 .70587 Mdot
.62352 .70979 Mdot
.62352 .70587 Mdot
.62352 .70587 Mdot
.63136 .70587 Mdot
.6196 .6941 Mdot
.6196 .69018 Mdot
.63136 .70194 Mdot
.6196 .70979 Mdot
.62352 .72547 Mdot
.61176 .71763 Mdot
.60391 .70194 Mdot
.60391 .6941 Mdot
.60783 .69802 Mdot
.60783 .70194 Mdot
.59215 .68234 Mdot
.58431 .68234 Mdot
.58039 .67842 Mdot
.56862 .66665 Mdot
.57646 .6745 Mdot
.57646 .67057 Mdot
.56862 .6745 Mdot
.55294 .66273 Mdot
.54902 .64705 Mdot
.54509 .63136 Mdot
.54117 .62352 Mdot
.54117 .61568 Mdot
.54902 .62352 Mdot
.53333 .6196 Mdot
.52941 .6196 Mdot
.52941 .61568 Mdot
.5098 .58431 Mdot
.51372 .57646 Mdot
.52157 .58431 Mdot
.51765 .59215 Mdot
.5098 .59215 Mdot
.50588 .58823 Mdot
.48628 .5647 Mdot
.47843 .54117 Mdot
.48235 .54117 Mdot
.47451 .52549 Mdot
.47843 .52941 Mdot
.46667 .51765 Mdot
.18434 .26668 Mdot
.14513 .21963 Mdot
.12552 .18434 Mdot
.41569 .54509 Mdot
.47451 .6196 Mdot
.49412 .64705 Mdot
.48628 .65097 Mdot
.48235 .66273 Mdot
.47059 .66273 Mdot
.46667 .65881 Mdot
.47059 .65489 Mdot
.47843 .65097 Mdot
.4902 .64705 Mdot
.4902 .65097 Mdot
.49412 .65881 Mdot
.49804 .66273 Mdot
.50196 .67057 Mdot
.50588 .66665 Mdot
.5098 .65881 Mdot
.51372 .65489 Mdot
.52157 .66665 Mdot
.52157 .67057 Mdot
.52157 .68234 Mdot
.52157 .6941 Mdot
.51372 .6941 Mdot
.51372 .68626 Mdot
.52549 .68234 Mdot
.53333 .68234 Mdot
.54117 .69802 Mdot
.53725 .69802 Mdot
.53333 .69018 Mdot
.54509 .69018 Mdot
.56078 .6941 Mdot
.5647 .68626 Mdot
.56862 .68626 Mdot
.57254 .70194 Mdot
.57254 .70979 Mdot
.57646 .71763 Mdot
.56862 .70587 Mdot
.58823 .70979 Mdot
.58431 .70979 Mdot
.58823 .70979 Mdot
.58431 .71371 Mdot
.59215 .71763 Mdot
.59215 .70194 Mdot
.60783 .70194 Mdot
.61176 .71371 Mdot
.6196 .73332 Mdot
.6196 .74508 Mdot
.6196 .74116 Mdot
.6196 .73332 Mdot
.63136 .73724 Mdot
.64705 .75292 Mdot
.64313 .74508 Mdot
.64313 .75292 Mdot
.64705 .749 Mdot
.64313 .749 Mdot
.64313 .75292 Mdot
.6392 .749 Mdot
.65097 .75292 Mdot
.64705 .75684 Mdot
.64313 .76076 Mdot
.6392 .75684 Mdot
.64705 .75292 Mdot
.64705 .74116 Mdot
.64313 .73332 Mdot
.65489 .73724 Mdot
.65881 .749 Mdot
.65097 .74116 Mdot
.64705 .73724 Mdot
.65489 .74116 Mdot
.65489 .74508 Mdot
.6392 .73332 Mdot
.64313 .72939 Mdot
.64313 .72155 Mdot
.65097 .72155 Mdot
.64313 .71763 Mdot
.65097 .72547 Mdot
.65881 .74508 Mdot
.65881 .75684 Mdot
.65097 .75292 Mdot
.65097 .75684 Mdot
.64705 .75292 Mdot
.65489 .75684 Mdot
.65881 .76861 Mdot
.65489 .76469 Mdot
.65881 .75292 Mdot
.65881 .74116 Mdot
.66273 .74508 Mdot
.67057 .749 Mdot
.6745 .75292 Mdot
.6745 .75292 Mdot
.67057 .749 Mdot
.66665 .74116 Mdot
.67057 .73332 Mdot
.66665 .72939 Mdot
.66273 .72939 Mdot
.66273 .73332 Mdot
.65489 .73332 Mdot
.65489 .72939 Mdot
.65097 .72939 Mdot
.65881 .74508 Mdot
.65097 .73332 Mdot
.65097 .72939 Mdot
.65489 .73332 Mdot
.67057 .749 Mdot
.6745 .74508 Mdot
.67842 .74508 Mdot
.66665 .74116 Mdot
.66273 .73724 Mdot
.66273 .72939 Mdot
.65489 .71371 Mdot
.64705 .70979 Mdot
.65097 .71763 Mdot
.64313 .71763 Mdot
.63528 .70979 Mdot
.63136 .71371 Mdot
.62352 .70587 Mdot
.61176 .69802 Mdot
.61568 .70194 Mdot
.6196 .70587 Mdot
.62352 .70587 Mdot
.62352 .70587 Mdot
.6196 .69802 Mdot
.62744 .70979 Mdot
.61176 .70979 Mdot
.61176 .72155 Mdot
.59999 .70979 Mdot
.60391 .70587 Mdot
.60783 .70587 Mdot
.60391 .6941 Mdot
.60391 .69802 Mdot
.59607 .70587 Mdot
.58039 .6941 Mdot
.57646 .68626 Mdot
.57646 .67842 Mdot
.57254 .67057 Mdot
.57646 .6745 Mdot
.57254 .67842 Mdot
.5647 .6745 Mdot
.54902 .65881 Mdot
.54117 .63528 Mdot
.54509 .62744 Mdot
.54117 .60783 Mdot
.55294 .61568 Mdot
.54509 .6196 Mdot
.53725 .61568 Mdot
.54117 .60391 Mdot
.52549 .58431 Mdot
.52549 .58039 Mdot
.52941 .58431 Mdot
.52549 .58823 Mdot
.52941 .60391 Mdot
.51372 .60391 Mdot
.49412 .59607 Mdot
.48235 .58431 Mdot
.4902 .57646 Mdot
.49412 .56078 Mdot
.4902 .54902 Mdot
.47843 .54117 Mdot
.45491 .52941 Mdot
.40001 .48235 Mdot
.3804 .45491 Mdot
.40785 .54509 Mdot
.46275 .6196 Mdot
.48235 .64313 Mdot
.47451 .64313 Mdot
.48628 .65881 Mdot
.47843 .65881 Mdot
.46667 .65097 Mdot
.47059 .64313 Mdot
.46275 .6392 Mdot
.47843 .64705 Mdot
.4902 .65097 Mdot
.49412 .65097 Mdot
.49412 .65881 Mdot
.49804 .66273 Mdot
.50196 .66273 Mdot
.50588 .65097 Mdot
.52157 .65881 Mdot
.52549 .67057 Mdot
.52157 .6745 Mdot
.51372 .6745 Mdot
.5098 .6745 Mdot
.51372 .67842 Mdot
.52549 .69802 Mdot
.52941 .70194 Mdot
.52941 .69802 Mdot
.53725 .70194 Mdot
.53333 .69802 Mdot
.54902 .69802 Mdot
.56078 .70194 Mdot
.55686 .6941 Mdot
.55686 .6941 Mdot
.56078 .70194 Mdot
.56862 .70194 Mdot
.56862 .70587 Mdot
.57254 .70979 Mdot
.58039 .70979 Mdot
.59607 .71763 Mdot
.58823 .71763 Mdot
.58039 .71371 Mdot
.58039 .70979 Mdot
.58431 .70587 Mdot
.58823 .70194 Mdot
.59999 .70587 Mdot
.60783 .70587 Mdot
.61176 .72547 Mdot
.60391 .73332 Mdot
.60783 .73724 Mdot
.62352 .74116 Mdot
.61568 .73332 Mdot
.61176 .73332 Mdot
.61176 .73724 Mdot
.62352 .74508 Mdot
.62744 .749 Mdot
.62744 .75292 Mdot
.62744 .75292 Mdot
.62744 .76076 Mdot
.62744 .76861 Mdot
.63528 .77253 Mdot
.63136 .77253 Mdot
.63528 .76469 Mdot
.6392 .76469 Mdot
.64313 .75292 Mdot
.64313 .749 Mdot
.65097 .75292 Mdot
.64313 .73724 Mdot
.64705 .73724 Mdot
.65097 .74116 Mdot
.64705 .749 Mdot
.64705 .75684 Mdot
.63528 .75292 Mdot
.63136 .749 Mdot
.63528 .74508 Mdot
.64313 .73724 Mdot
.64705 .73724 Mdot
.64313 .72547 Mdot
.64313 .73724 Mdot
.6392 .74116 Mdot
.6392 .749 Mdot
.64313 .749 Mdot
.64705 .749 Mdot
.65097 .749 Mdot
.65489 .76076 Mdot
.65881 .77253 Mdot
.65881 .76469 Mdot
.65489 .75292 Mdot
.64705 .75292 Mdot
.64705 .75292 Mdot
.65881 .75684 Mdot
.66273 .76076 Mdot
.65881 .76076 Mdot
.66273 .75684 Mdot
.65881 .74116 Mdot
.65489 .73724 Mdot
.64705 .74116 Mdot
.65097 .74116 Mdot
.64705 .73724 Mdot
.65489 .74116 Mdot
.64705 .73724 Mdot
.65489 .75292 Mdot
.65489 .75684 Mdot
.65489 .75292 Mdot
.65097 .74508 Mdot
.65097 .74116 Mdot
.65097 .749 Mdot
.65489 .749 Mdot
.64705 .749 Mdot
.64705 .74508 Mdot
.6392 .72939 Mdot
.64705 .72547 Mdot
.64705 .72939 Mdot
.6392 .73332 Mdot
.6392 .73332 Mdot
.63136 .72155 Mdot
.62744 .71371 Mdot
.62744 .71763 Mdot
.62744 .71763 Mdot
.62352 .71371 Mdot
.62352 .71763 Mdot
.6196 .70979 Mdot
.61176 .70194 Mdot
.61176 .70194 Mdot
.61176 .70587 Mdot
.60783 .69802 Mdot
.59999 .6941 Mdot
.59215 .70194 Mdot
.58431 .69802 Mdot
.59607 .70194 Mdot
.59215 .70194 Mdot
.58039 .69018 Mdot
.59215 .70587 Mdot
.59215 .70587 Mdot
.57646 .69802 Mdot
.5647 .68234 Mdot
.56862 .67842 Mdot
.56078 .65489 Mdot
.55294 .65097 Mdot
.55686 .65489 Mdot
.55294 .65489 Mdot
.55294 .65097 Mdot
.54509 .63528 Mdot
.54117 .61568 Mdot
.54509 .60783 Mdot
.53725 .61176 Mdot
.52157 .60391 Mdot
.52157 .59607 Mdot
.52157 .59215 Mdot
.51765 .58823 Mdot
.51765 .58431 Mdot
.5098 .58431 Mdot
.51372 .59607 Mdot
.50588 .59999 Mdot
.50196 .59999 Mdot
.49412 .59215 Mdot
.49412 .58431 Mdot
.49804 .59215 Mdot
.48235 .57254 Mdot
.47059 .54902 Mdot
.46275 .54117 Mdot
.44706 .52157 Mdot
.41569 .48235 Mdot
.38432 .53725 Mdot
.45883 .63136 Mdot
.46275 .65097 Mdot
.46667 .64705 Mdot
.47059 .65489 Mdot
.47451 .65097 Mdot
.47059 .65097 Mdot
.46667 .64705 Mdot
.45883 .64705 Mdot
.47059 .65097 Mdot
.48628 .65881 Mdot
.48235 .65097 Mdot
.48628 .65097 Mdot
.50196 .66273 Mdot
.51765 .66665 Mdot
.51765 .66273 Mdot
.52549 .66665 Mdot
.53725 .67842 Mdot
.52157 .66665 Mdot
.51765 .66665 Mdot
.51765 .66665 Mdot
.51765 .66665 Mdot
.51765 .68234 Mdot
.52941 .70194 Mdot
.52941 .70194 Mdot
.53333 .70587 Mdot
.53333 .70194 Mdot
.53725 .70587 Mdot
.54509 .70979 Mdot
.54117 .69802 Mdot
.55294 .69802 Mdot
.56078 .70587 Mdot
.56078 .69802 Mdot
.56862 .70979 Mdot
.57254 .71371 Mdot
.57646 .72155 Mdot
.57646 .71371 Mdot
.57254 .71371 Mdot
.56862 .71371 Mdot
.57646 .71371 Mdot
.57646 .71371 Mdot
.58431 .71371 Mdot
.58431 .70979 Mdot
.58039 .70587 Mdot
.59607 .72547 Mdot
.59215 .72939 Mdot
.59607 .73724 Mdot
.60391 .749 Mdot
.60783 .73724 Mdot
.61176 .73332 Mdot
.62352 .749 Mdot
.6196 .75684 Mdot
.61568 .75684 Mdot
.6196 .75292 Mdot
.6196 .75292 Mdot
.63136 .76076 Mdot
.62352 .76469 Mdot
.6196 .76469 Mdot
.6196 .76469 Mdot
.62744 .76469 Mdot
.63136 .76861 Mdot
.62352 .75292 Mdot
.64313 .75684 Mdot
.64705 .75292 Mdot
.64313 .74116 Mdot
.64705 .73724 Mdot
.64705 .74116 Mdot
.63528 .74116 Mdot
.64313 .76076 Mdot
.64313 .76861 Mdot
.62744 .76469 Mdot
.62352 .76076 Mdot
.63528 .75292 Mdot
.6392 .749 Mdot
.63528 .74508 Mdot
.63528 .749 Mdot
.63528 .74508 Mdot
.63136 .74508 Mdot
.63528 .749 Mdot
.65097 .75684 Mdot
.65097 .75292 Mdot
.65489 .75684 Mdot
.64705 .76469 Mdot
.64705 .76469 Mdot
.65097 .76861 Mdot
.64313 .76469 Mdot
.64313 .76469 Mdot
.65097 .77253 Mdot
.65489 .77645 Mdot
.64705 .77645 Mdot
.65097 .77645 Mdot
.64313 .76469 Mdot
.64705 .76469 Mdot
.64705 .76469 Mdot
.64705 .76469 Mdot
.63528 .75684 Mdot
.6392 .75292 Mdot
.64313 .75292 Mdot
.64313 .75292 Mdot
.64313 .75684 Mdot
.64313 .76076 Mdot
.64705 .76076 Mdot
.63528 .74508 Mdot
.6392 .74508 Mdot
.64313 .74116 Mdot
.6392 .74116 Mdot
.63528 .74116 Mdot
.63528 .74116 Mdot
.6392 .74116 Mdot
.6392 .73724 Mdot
.6392 .73332 Mdot
.6392 .73332 Mdot
.63528 .73724 Mdot
.63136 .72547 Mdot
.62744 .71763 Mdot
.63136 .72547 Mdot
.62744 .72547 Mdot
.6196 .72155 Mdot
.61568 .71763 Mdot
.59999 .70194 Mdot
.60391 .70194 Mdot
.61176 .70587 Mdot
.60783 .70194 Mdot
.59607 .6941 Mdot
.59215 .6941 Mdot
.59607 .6941 Mdot
.59215 .6941 Mdot
.59607 .70194 Mdot
.59215 .69018 Mdot
.58039 .68234 Mdot
.58039 .68626 Mdot
.56862 .67842 Mdot
.56862 .68234 Mdot
.56862 .67842 Mdot
.56078 .66665 Mdot
.54902 .65097 Mdot
.54509 .64705 Mdot
.54902 .64705 Mdot
.54902 .6392 Mdot
.54509 .63136 Mdot
.54509 .62744 Mdot
.53725 .6196 Mdot
.52941 .61568 Mdot
.51765 .61176 Mdot
.51765 .61568 Mdot
.51765 .60783 Mdot
.51372 .59607 Mdot
.51372 .58823 Mdot
.50588 .58823 Mdot
.50588 .59999 Mdot
.50588 .59999 Mdot
.4902 .58823 Mdot
.48628 .58039 Mdot
.48235 .58039 Mdot
.47451 .57254 Mdot
.47059 .55686 Mdot
.45883 .54902 Mdot
.45491 .53725 Mdot
.44314 .5098 Mdot
.43138 .4902 Mdot
.40785 .54509 Mdot
.44706 .62352 Mdot
.45883 .65489 Mdot
.47059 .6745 Mdot
.46667 .6745 Mdot
.46667 .67057 Mdot
.45098 .65489 Mdot
.45491 .65489 Mdot
.45883 .65489 Mdot
.47843 .65881 Mdot
.47451 .64705 Mdot
.48628 .65097 Mdot
.49412 .65489 Mdot
.4902 .65097 Mdot
.5098 .65881 Mdot
.51765 .65881 Mdot
.52157 .66273 Mdot
.53333 .68234 Mdot
.5098 .67057 Mdot
.51765 .67057 Mdot
.52157 .67057 Mdot
.52157 .67057 Mdot
.51765 .67057 Mdot
.53725 .69018 Mdot
.53333 .6941 Mdot
.54117 .69802 Mdot
.54117 .70194 Mdot
.53333 .69802 Mdot
.54902 .70194 Mdot
.55686 .70194 Mdot
.56862 .70587 Mdot
.57254 .71371 Mdot
.58039 .72547 Mdot
.56862 .71763 Mdot
.57254 .72547 Mdot
.57254 .72547 Mdot
.57254 .71763 Mdot
.57254 .71371 Mdot
.57254 .72547 Mdot
.57254 .72155 Mdot
.57646 .72155 Mdot
.56862 .71763 Mdot
.58039 .71371 Mdot
.58039 .70979 Mdot
.58039 .71371 Mdot
.58823 .72155 Mdot
.59215 .73724 Mdot
.59607 .74508 Mdot
.58823 .73332 Mdot
.61568 .749 Mdot
.61568 .74116 Mdot
.61568 .74508 Mdot
.61176 .75292 Mdot
.61568 .75684 Mdot
.60783 .75684 Mdot
.61568 .76076 Mdot
.6196 .76076 Mdot
.62744 .75684 Mdot
.62352 .75292 Mdot
.6196 .75292 Mdot
.62352 .75684 Mdot
.62352 .749 Mdot
.63136 .749 Mdot
.6392 .74508 Mdot
.6392 .74508 Mdot
.6392 .74508 Mdot
.63528 .74116 Mdot
.63528 .74116 Mdot
.63528 .74508 Mdot
.6392 .749 Mdot
.64313 .76076 Mdot
.64313 .75684 Mdot
.6392 .75292 Mdot
.63528 .75292 Mdot
.63528 .749 Mdot
.63528 .75292 Mdot
.63136 .75684 Mdot
.63528 .76469 Mdot
.63528 .75684 Mdot
.65097 .76469 Mdot
.64313 .75292 Mdot
.6392 .75292 Mdot
.64705 .75684 Mdot
.64313 .75292 Mdot
.64313 .76469 Mdot
.65097 .77645 Mdot
.65489 .78429 Mdot
.65489 .77645 Mdot
.65489 .77645 Mdot
.64705 .77253 Mdot
.64705 .76469 Mdot
.64705 .76469 Mdot
.64313 .76469 Mdot
.65489 .77253 Mdot
.64705 .76469 Mdot
.6392 .76469 Mdot
.63528 .76861 Mdot
.63136 .76469 Mdot
.6392 .76469 Mdot
.6392 .75684 Mdot
.64313 .75292 Mdot
.64313 .75292 Mdot
.63136 .74508 Mdot
.6392 .74116 Mdot
.64313 .73724 Mdot
.6392 .74116 Mdot
.63528 .73724 Mdot
.64313 .749 Mdot
.64313 .74508 Mdot
.63528 .73724 Mdot
.63528 .72939 Mdot
.63528 .73332 Mdot
.63528 .73332 Mdot
.63136 .72155 Mdot
.6196 .71371 Mdot
.62352 .71763 Mdot
.6196 .70979 Mdot
.62744 .71763 Mdot
.61176 .70979 Mdot
.60783 .70979 Mdot
.60783 .70587 Mdot
.60783 .70587 Mdot
.60391 .70587 Mdot
.59607 .70194 Mdot
.59215 .69018 Mdot
.59607 .68626 Mdot
.59999 .6941 Mdot
.59215 .6941 Mdot
.59999 .70194 Mdot
.59215 .69018 Mdot
.58431 .67842 Mdot
.57646 .6745 Mdot
.56862 .67842 Mdot
.56078 .67057 Mdot
.56862 .6745 Mdot
.57254 .67057 Mdot
.56078 .65489 Mdot
.55686 .65489 Mdot
.54509 .64313 Mdot
.54509 .64313 Mdot
.54902 .64705 Mdot
.54509 .6392 Mdot
.53333 .62744 Mdot
.52549 .63136 Mdot
.52549 .62744 Mdot
.52157 .61568 Mdot
.52549 .61176 Mdot
.52549 .61176 Mdot
.52157 .61568 Mdot
.50588 .6196 Mdot
.4902 .61568 Mdot
.47843 .60391 Mdot
.47451 .59215 Mdot
.47059 .58431 Mdot
.47451 .57646 Mdot
.47059 .56862 Mdot
.46667 .55686 Mdot
.45491 .54117 Mdot
.45098 .51765 Mdot
.43138 .48628 Mdot
.39609 .54117 Mdot
.44706 .61568 Mdot
.45098 .64313 Mdot
.45883 .65881 Mdot
.45491 .66273 Mdot
.44314 .65881 Mdot
.4353 .65097 Mdot
.45491 .66665 Mdot
.45098 .65881 Mdot
.45883 .65881 Mdot
.46667 .65489 Mdot
.46667 .65097 Mdot
.47059 .64313 Mdot
.4902 .65489 Mdot
.4902 .65881 Mdot
.50588 .67057 Mdot
.5098 .67057 Mdot
.51765 .6745 Mdot
.51765 .6745 Mdot
.51765 .67057 Mdot
.52549 .67057 Mdot
.52941 .67842 Mdot
.52941 .67842 Mdot
.53333 .6745 Mdot
.53333 .67057 Mdot
.53725 .67842 Mdot
.52941 .67842 Mdot
.53725 .68626 Mdot
.54117 .68626 Mdot
.54902 .68626 Mdot
.55686 .69018 Mdot
.55686 .69802 Mdot
.56862 .71371 Mdot
.56862 .72155 Mdot
.5647 .72155 Mdot
.5647 .72547 Mdot
.56078 .72155 Mdot
.56862 .71371 Mdot
.5647 .70587 Mdot
.56862 .71371 Mdot
.57646 .72547 Mdot
.57254 .72155 Mdot
.57646 .71763 Mdot
.57646 .70587 Mdot
.57254 .70194 Mdot
.58039 .70979 Mdot
.59607 .72939 Mdot
.59607 .73724 Mdot
.59215 .72939 Mdot
.59215 .73724 Mdot
.59999 .74508 Mdot
.59607 .74116 Mdot
.59607 .74508 Mdot
.60391 .76076 Mdot
.60783 .76469 Mdot
.60391 .76076 Mdot
.59999 .75292 Mdot
.61176 .75292 Mdot
.60391 .74508 Mdot
.61568 .749 Mdot
.61176 .74116 Mdot
.62352 .74508 Mdot
.62744 .74116 Mdot
.62744 .73332 Mdot
.6196 .72939 Mdot
.62352 .73724 Mdot
.63136 .74116 Mdot
.62352 .73724 Mdot
.63136 .74116 Mdot
.62744 .73724 Mdot
.63136 .74508 Mdot
.62744 .74116 Mdot
.63528 .75292 Mdot
.63136 .749 Mdot
.62352 .74116 Mdot
.62352 .74508 Mdot
.6196 .749 Mdot
.62352 .75684 Mdot
.63136 .77253 Mdot
.63528 .77253 Mdot
.63528 .76076 Mdot
.63528 .75684 Mdot
.63136 .75292 Mdot
.62744 .75292 Mdot
.63528 .75292 Mdot
.6392 .76469 Mdot
.64705 .77253 Mdot
.6392 .76469 Mdot
.64313 .75684 Mdot
.63528 .749 Mdot
.63528 .75684 Mdot
.63136 .75292 Mdot
.62744 .749 Mdot
.6392 .75292 Mdot
.63528 .76076 Mdot
.64313 .76469 Mdot
.6392 .76469 Mdot
.63136 .76076 Mdot
.63136 .75684 Mdot
.62352 .75292 Mdot
.63136 .749 Mdot
.63136 .74508 Mdot
.63136 .74508 Mdot
.62352 .73332 Mdot
.62352 .73332 Mdot
.62352 .73332 Mdot
.62744 .74116 Mdot
.64313 .75292 Mdot
.64313 .75684 Mdot
.63528 .74508 Mdot
.62352 .73332 Mdot
.61568 .72547 Mdot
.61568 .72155 Mdot
.62744 .72155 Mdot
.6196 .70979 Mdot
.61568 .70979 Mdot
.62352 .71763 Mdot
.61568 .72547 Mdot
.60391 .71763 Mdot
.60391 .71371 Mdot
.60391 .70979 Mdot
.59999 .6941 Mdot
.59607 .69018 Mdot
.58823 .68626 Mdot
.58823 .68626 Mdot
.59215 .68626 Mdot
.59607 .69018 Mdot
.58431 .69018 Mdot
.58823 .69018 Mdot
.57646 .69018 Mdot
.57646 .6941 Mdot
.57254 .68626 Mdot
.5647 .6745 Mdot
.55294 .65881 Mdot
.54902 .65489 Mdot
.56078 .66665 Mdot
.55294 .65489 Mdot
.56078 .65489 Mdot
.55294 .65097 Mdot
.54117 .64313 Mdot
.54117 .64313 Mdot
.52941 .63136 Mdot
.52157 .62352 Mdot
.52157 .62352 Mdot
.51765 .61568 Mdot
.5098 .60391 Mdot
.50588 .59999 Mdot
.50588 .59607 Mdot
.5098 .59999 Mdot
.51372 .61568 Mdot
.5098 .62744 Mdot
.48628 .61568 Mdot
.47059 .59999 Mdot
.46667 .58823 Mdot
.46275 .57646 Mdot
.45491 .55294 Mdot
.45491 .54117 Mdot
.44706 .52549 Mdot
.4353 .50196 Mdot
.4353 .48628 Mdot
.41177 .54902 Mdot
.4353 .60783 Mdot
.4353 .63136 Mdot
.43922 .6392 Mdot
.44706 .65097 Mdot
.45491 .65881 Mdot
.44706 .65489 Mdot
.44314 .65881 Mdot
.43138 .64705 Mdot
.44706 .65881 Mdot
.45883 .66273 Mdot
.45883 .65097 Mdot
.47451 .65881 Mdot
.48628 .65881 Mdot
.48628 .65881 Mdot
.50196 .66273 Mdot
.50196 .65881 Mdot
.50588 .66273 Mdot
.49804 .65881 Mdot
.49804 .65881 Mdot
.49804 .65881 Mdot
.50588 .66665 Mdot
.5098 .66665 Mdot
.5098 .66273 Mdot
.51372 .66273 Mdot
.52157 .67057 Mdot
.53333 .67842 Mdot
.53725 .68626 Mdot
.54117 .6941 Mdot
.54509 .6941 Mdot
.53725 .68234 Mdot
.53725 .69018 Mdot
.55294 .70194 Mdot
.5647 .71371 Mdot
.56078 .72155 Mdot
.55294 .71763 Mdot
.5647 .72155 Mdot
.56078 .70194 Mdot
.56862 .70194 Mdot
.55686 .69802 Mdot
.55686 .71763 Mdot
.55686 .71763 Mdot
.55294 .70587 Mdot
.56078 .70587 Mdot
.5647 .70587 Mdot
.57646 .70979 Mdot
.58039 .71371 Mdot
.58431 .71763 Mdot
.59215 .72547 Mdot
.57646 .72155 Mdot
.58039 .73332 Mdot
.58431 .72939 Mdot
.58431 .72939 Mdot
.58823 .73332 Mdot
.58431 .73332 Mdot
.58039 .73724 Mdot
.57646 .74116 Mdot
.58431 .74116 Mdot
.58431 .72939 Mdot
.58039 .72939 Mdot
.59999 .749 Mdot
.59215 .74116 Mdot
.59607 .72939 Mdot
.61176 .73332 Mdot
.61176 .72939 Mdot
.61176 .72939 Mdot
.61176 .73332 Mdot
.61568 .74116 Mdot
.61176 .72939 Mdot
.61176 .72939 Mdot
.60783 .72547 Mdot
.61568 .72939 Mdot
.61568 .73724 Mdot
.6196 .73724 Mdot
.61176 .72547 Mdot
.61568 .73332 Mdot
.62352 .749 Mdot
.62352 .75684 Mdot
.6196 .75292 Mdot
.62352 .76469 Mdot
.62352 .76469 Mdot
.63136 .76469 Mdot
.6196 .75292 Mdot
.62744 .75292 Mdot
.62352 .74508 Mdot
.6196 .749 Mdot
.62352 .74508 Mdot
.6196 .73724 Mdot
.6196 .73724 Mdot
.61568 .73332 Mdot
.62352 .74508 Mdot
.6196 .74116 Mdot
.61176 .72939 Mdot
.6196 .74116 Mdot
.62744 .75292 Mdot
.6196 .75292 Mdot
.62352 .75292 Mdot
.61568 .749 Mdot
.61568 .749 Mdot
.61568 .74116 Mdot
.61176 .72939 Mdot
.6196 .72547 Mdot
.62744 .72939 Mdot
.6196 .73332 Mdot
.61568 .72939 Mdot
.61176 .72155 Mdot
.61176 .72155 Mdot
.61568 .72939 Mdot
.61568 .72547 Mdot
.6196 .72939 Mdot
.6196 .72939 Mdot
.61176 .71763 Mdot
.60783 .71371 Mdot
.60783 .71763 Mdot
.60783 .71371 Mdot
.60783 .72155 Mdot
.60783 .72155 Mdot
.59999 .72155 Mdot
.58823 .71371 Mdot
.58431 .70587 Mdot
.59215 .70587 Mdot
.58823 .6941 Mdot
.58823 .68626 Mdot
.58039 .67842 Mdot
.57646 .67842 Mdot
.58039 .67842 Mdot
.56862 .67842 Mdot
.5647 .67842 Mdot
.55686 .66665 Mdot
.55686 .66665 Mdot
.56078 .6745 Mdot
.5647 .68626 Mdot
.55686 .67842 Mdot
.55686 .67057 Mdot
.54902 .66273 Mdot
.54117 .65097 Mdot
.53725 .64313 Mdot
.54117 .64705 Mdot
.53725 .64705 Mdot
.52941 .6392 Mdot
.52549 .63528 Mdot
.52157 .63528 Mdot
.50588 .62352 Mdot
.50196 .62352 Mdot
.50588 .62744 Mdot
.49804 .6196 Mdot
.4902 .60783 Mdot
.49804 .60783 Mdot
.50196 .61176 Mdot
.49412 .59607 Mdot
.4902 .59607 Mdot
.47451 .59215 Mdot
.46275 .58823 Mdot
.47059 .59215 Mdot
.45098 .56862 Mdot
.44706 .55294 Mdot
.44314 .53725 Mdot
.43922 .51372 Mdot
.43138 .49804 Mdot
.41177 .46667 Mdot
.40001 .5647 Mdot
.41961 .61568 Mdot
.43138 .64705 Mdot
.4353 .65097 Mdot
.44314 .65097 Mdot
.46275 .66273 Mdot
.45491 .66273 Mdot
.45098 .67057 Mdot
.44706 .66665 Mdot
.45491 .66665 Mdot
.45883 .65881 Mdot
.47059 .65881 Mdot
.47059 .65881 Mdot
.47843 .65881 Mdot
.48235 .65881 Mdot
.49412 .66273 Mdot
.49804 .66273 Mdot
.50196 .66273 Mdot
.5098 .66273 Mdot
.49412 .65489 Mdot
.49804 .65881 Mdot
.50588 .66665 Mdot
.50588 .67057 Mdot
.5098 .67057 Mdot
.50588 .66665 Mdot
.5098 .65881 Mdot
.52941 .67842 Mdot
.53333 .6941 Mdot
.52941 .69802 Mdot
.53333 .6941 Mdot
.54902 .6941 Mdot
.54902 .6941 Mdot
.54902 .69018 Mdot
.55294 .70194 Mdot
.55686 .72155 Mdot
.54902 .72155 Mdot
.54509 .72155 Mdot
.55294 .72547 Mdot
.56078 .71763 Mdot
.5647 .72547 Mdot
.56078 .73332 Mdot
.55294 .72939 Mdot
.55294 .71763 Mdot
.55686 .70979 Mdot
.56078 .70979 Mdot
.56862 .70979 Mdot
.58039 .71763 Mdot
.58039 .72547 Mdot
.59215 .73332 Mdot
.58823 .73332 Mdot
.58431 .72939 Mdot
.58431 .73332 Mdot
.58823 .73332 Mdot
.57646 .72547 Mdot
.58039 .73724 Mdot
.58431 .74116 Mdot
.58039 .74116 Mdot
.59215 .74508 Mdot
.60391 .75292 Mdot
.59607 .749 Mdot
.59607 .749 Mdot
.59215 .74116 Mdot
.60391 .74116 Mdot
.59999 .73724 Mdot
.60391 .749 Mdot
.61568 .75684 Mdot
.6196 .75292 Mdot
.61176 .74508 Mdot
.60391 .73724 Mdot
.61568 .73724 Mdot
.61568 .73332 Mdot
.61176 .72547 Mdot
.61568 .73332 Mdot
.6196 .74508 Mdot
.6196 .73724 Mdot
.61176 .72547 Mdot
.62352 .74116 Mdot
.6196 .76076 Mdot
.62352 .76469 Mdot
.62744 .76861 Mdot
.62744 .76861 Mdot
.63136 .76861 Mdot
.63136 .76861 Mdot
.63136 .76861 Mdot
.62352 .76861 Mdot
.62352 .76469 Mdot
.62744 .76076 Mdot
.62744 .75684 Mdot
.6196 .749 Mdot
.61176 .74116 Mdot
.60783 .749 Mdot
.61568 .75684 Mdot
.61176 .749 Mdot
.61176 .74116 Mdot
.61568 .74116 Mdot
.61568 .75292 Mdot
.60783 .75292 Mdot
.6196 .76076 Mdot
.61568 .75684 Mdot
.6196 .749 Mdot
.6196 .73724 Mdot
.62352 .73332 Mdot
.62744 .72547 Mdot
.63136 .72547 Mdot
.63528 .72547 Mdot
.63136 .72939 Mdot
.63136 .73724 Mdot
.62744 .74116 Mdot
.62744 .74508 Mdot
.63136 .74508 Mdot
.62352 .73724 Mdot
.61568 .72939 Mdot
.62352 .72939 Mdot
.61568 .72939 Mdot
.62352 .74508 Mdot
.6196 .73724 Mdot
.6196 .73724 Mdot
.61176 .72547 Mdot
.60783 .72939 Mdot
.60391 .72155 Mdot
.60391 .72155 Mdot
.59215 .71371 Mdot
.59215 .71371 Mdot
.58823 .71371 Mdot
.58431 .70979 Mdot
.57254 .69802 Mdot
.56862 .69802 Mdot
.56862 .6941 Mdot
.56862 .68234 Mdot
.57254 .68626 Mdot
.57254 .67842 Mdot
.57254 .69018 Mdot
.5647 .6941 Mdot
.55686 .68234 Mdot
.55294 .67842 Mdot
.55686 .68234 Mdot
.54902 .66665 Mdot
.55686 .6745 Mdot
.54509 .66273 Mdot
.53333 .65097 Mdot
.52941 .65097 Mdot
.52549 .65097 Mdot
.51372 .6392 Mdot
.51765 .65489 Mdot
.51765 .65881 Mdot
.51765 .65489 Mdot
.49804 .6392 Mdot
.4902 .63528 Mdot
.48628 .63136 Mdot
.4902 .6196 Mdot
.4902 .61176 Mdot
.47451 .60783 Mdot
.47059 .61176 Mdot
.47843 .61568 Mdot
.46275 .58823 Mdot
.46275 .57646 Mdot
.45491 .55294 Mdot
.44706 .52549 Mdot
.44314 .50588 Mdot
.43922 .48235 Mdot
.41569 .58039 Mdot
.45883 .65489 Mdot
.46275 .67057 Mdot
.45883 .66665 Mdot
.45098 .65489 Mdot
.45883 .66273 Mdot
.46667 .67842 Mdot
.46667 .68234 Mdot
.45883 .67057 Mdot
.45098 .66273 Mdot
.46667 .65881 Mdot
.48235 .66665 Mdot
.47843 .66273 Mdot
.4902 .66665 Mdot
.49412 .66665 Mdot
.49804 .66273 Mdot
.50196 .65489 Mdot
.5098 .65489 Mdot
.51765 .66273 Mdot
.52549 .6745 Mdot
.52157 .67842 Mdot
.51765 .68626 Mdot
.51765 .69018 Mdot
.51765 .69018 Mdot
.52549 .69802 Mdot
.52549 .69802 Mdot
.52941 .69802 Mdot
.53333 .69802 Mdot
.53725 .69018 Mdot
.54117 .6941 Mdot
.54117 .69018 Mdot
.54902 .69802 Mdot
.5647 .70587 Mdot
.55294 .70194 Mdot
.56078 .72547 Mdot
.56078 .73724 Mdot
.55294 .72939 Mdot
.54902 .71371 Mdot
.54902 .71371 Mdot
.5647 .73332 Mdot
.56862 .73332 Mdot
.56078 .73332 Mdot
.55294 .72155 Mdot
.5647 .70979 Mdot
.57646 .70979 Mdot
.58039 .70587 Mdot
.58823 .71371 Mdot
.59607 .71763 Mdot
.59607 .71371 Mdot
.59215 .70587 Mdot
.59607 .71371 Mdot
.59215 .71763 Mdot
.60783 .72547 Mdot
.59215 .72155 Mdot
.59607 .72547 Mdot
.60391 .73724 Mdot
.60391 .73724 Mdot
.59607 .73332 Mdot
.60391 .74116 Mdot
.61176 .74508 Mdot
.61176 .73724 Mdot
.60391 .73332 Mdot
.61176 .73332 Mdot
.61176 .74116 Mdot
.61176 .74508 Mdot
.6196 .75292 Mdot
.6196 .75684 Mdot
.6196 .75292 Mdot
.62352 .76076 Mdot
.6196 .75292 Mdot
.62744 .74508 Mdot
.61568 .72939 Mdot
.60783 .71763 Mdot
.62352 .73332 Mdot
.63136 .74116 Mdot
.6196 .72939 Mdot
.62744 .73332 Mdot
.63528 .749 Mdot
.63136 .76076 Mdot
.63136 .76861 Mdot
.63136 .76861 Mdot
.6392 .76469 Mdot
.6392 .76469 Mdot
.63528 .76469 Mdot
.62352 .76076 Mdot
.62352 .76076 Mdot
.62352 .76469 Mdot
.61568 .75684 Mdot
.6196 .75292 Mdot
.61568 .75292 Mdot
.61568 .76076 Mdot
.6196 .76076 Mdot
.61176 .749 Mdot
.63136 .74116 Mdot
.63136 .73724 Mdot
.62744 .73724 Mdot
.61568 .74116 Mdot
.61568 .749 Mdot
.61568 .74508 Mdot
.62352 .749 Mdot
.62744 .749 Mdot
.63136 .74508 Mdot
.6196 .72547 Mdot
.62352 .72155 Mdot
.62744 .71763 Mdot
.62744 .71763 Mdot
.62744 .72547 Mdot
.62744 .72547 Mdot
.63136 .73724 Mdot
.62352 .73724 Mdot
.62744 .73332 Mdot
.62744 .72939 Mdot
.61568 .71371 Mdot
.61568 .70979 Mdot
.61176 .71371 Mdot
.6196 .72155 Mdot
.6196 .72155 Mdot
.61176 .70979 Mdot
.60391 .70979 Mdot
.59999 .70587 Mdot
.59999 .70979 Mdot
.60391 .70979 Mdot
.59999 .70979 Mdot
.59215 .71371 Mdot
.58431 .71371 Mdot
.57646 .70979 Mdot
.57646 .69802 Mdot
.58039 .6941 Mdot
.58039 .68626 Mdot
.57646 .69018 Mdot
.56862 .68234 Mdot
.56078 .67057 Mdot
.56078 .67057 Mdot
.56078 .6745 Mdot
.54509 .66273 Mdot
.54902 .67057 Mdot
.54509 .65489 Mdot
.54509 .65489 Mdot
.54117 .64705 Mdot
.53333 .63528 Mdot
.52549 .63528 Mdot
.52549 .64705 Mdot
.51765 .64313 Mdot
.51765 .64705 Mdot
.52157 .66273 Mdot
.50196 .65097 Mdot
.48235 .63136 Mdot
.48628 .63136 Mdot
.48235 .62352 Mdot
.47843 .60783 Mdot
.47059 .59607 Mdot
.47059 .59215 Mdot
.47451 .59999 Mdot
.46667 .59607 Mdot
.45883 .57646 Mdot
.46667 .56862 Mdot
.45883 .55686 Mdot
.45491 .53333 Mdot
.43922 .50196 Mdot
.41569 .46667 Mdot
.39609 .54117 Mdot
.43922 .61568 Mdot
.44706 .64705 Mdot
.43922 .64313 Mdot
.45491 .65489 Mdot
.45098 .65881 Mdot
.45098 .65881 Mdot
.46275 .66273 Mdot
.46667 .66273 Mdot
.46667 .66273 Mdot
.46667 .65881 Mdot
.47451 .66273 Mdot
.48235 .66273 Mdot
.48628 .66273 Mdot
.48628 .65489 Mdot
.49412 .65097 Mdot
.50196 .65097 Mdot
.51765 .66665 Mdot
.5098 .65881 Mdot
.52549 .6745 Mdot
.51765 .68234 Mdot
.51765 .6941 Mdot
.51765 .70979 Mdot
.5098 .70587 Mdot
.5098 .70587 Mdot
.51765 .70194 Mdot
.52157 .70194 Mdot
.52549 .69802 Mdot
.53333 .6941 Mdot
.53725 .69802 Mdot
.54509 .70194 Mdot
.54902 .70587 Mdot
.55294 .71371 Mdot
.54902 .71763 Mdot
.55686 .72547 Mdot
.5647 .72939 Mdot
.54902 .71371 Mdot
.54509 .71763 Mdot
.55294 .72155 Mdot
.56862 .72547 Mdot
.56078 .71371 Mdot
.55294 .70194 Mdot
.56078 .70587 Mdot
.56078 .70587 Mdot
.57254 .70979 Mdot
.57646 .70979 Mdot
.57646 .70587 Mdot
.58039 .70587 Mdot
.58431 .70194 Mdot
.58823 .69802 Mdot
.59999 .70587 Mdot
.59215 .70587 Mdot
.59999 .71371 Mdot
.59607 .70979 Mdot
.59607 .71763 Mdot
.59607 .72155 Mdot
.59607 .72547 Mdot
.60391 .73332 Mdot
.61176 .74508 Mdot
.60783 .74508 Mdot
.60391 .72939 Mdot
.60783 .73332 Mdot
.61568 .73724 Mdot
.6196 .74116 Mdot
.6196 .749 Mdot
.6196 .75292 Mdot
.61176 .749 Mdot
.60783 .74508 Mdot
.61568 .75292 Mdot
.61176 .74508 Mdot
.61176 .73332 Mdot
.6196 .72939 Mdot
.6196 .72939 Mdot
.6196 .72939 Mdot
.62744 .72155 Mdot
.63136 .72547 Mdot
.63136 .72939 Mdot
.63136 .72939 Mdot
.6196 .72547 Mdot
.62352 .73724 Mdot
.62744 .749 Mdot
.63528 .75292 Mdot
.62744 .74508 Mdot
.63136 .75684 Mdot
.63136 .76076 Mdot
.63136 .76469 Mdot
.62744 .76076 Mdot
.63136 .76469 Mdot
.62744 .75292 Mdot
.62744 .75292 Mdot
.63136 .75292 Mdot
.63136 .74508 Mdot
.63528 .73724 Mdot
.63528 .72939 Mdot
.62352 .71763 Mdot
.6196 .72155 Mdot
.63136 .73724 Mdot
.62744 .74116 Mdot
.61176 .73724 Mdot
.61568 .74116 Mdot
.62744 .749 Mdot
.63136 .74508 Mdot
.6196 .72547 Mdot
.62352 .72547 Mdot
.62744 .72547 Mdot
.62352 .71763 Mdot
.63528 .72547 Mdot
.63136 .72155 Mdot
.6196 .71763 Mdot
.61568 .71763 Mdot
.60783 .71763 Mdot
.61568 .72155 Mdot
.61568 .71371 Mdot
.59999 .69802 Mdot
.60783 .70587 Mdot
.60783 .71371 Mdot
.60391 .71371 Mdot
.59999 .70979 Mdot
.59999 .71371 Mdot
.59607 .70587 Mdot
.59607 .6941 Mdot
.59999 .68626 Mdot
.59999 .68626 Mdot
.60391 .70194 Mdot
.58431 .70194 Mdot
.58039 .6941 Mdot
.57646 .69018 Mdot
.5647 .67842 Mdot
.58039 .69018 Mdot
.58431 .6941 Mdot
.57254 .67842 Mdot
.55686 .66273 Mdot
.5647 .66273 Mdot
.55686 .65489 Mdot
.55686 .66665 Mdot
.54902 .65881 Mdot
.53333 .64313 Mdot
.53725 .6392 Mdot
.52941 .6196 Mdot
.52549 .61568 Mdot
.52941 .62352 Mdot
.51372 .6196 Mdot
.52157 .62744 Mdot
.51765 .63136 Mdot
.51765 .64313 Mdot
.50588 .64313 Mdot
.4902 .6392 Mdot
.49412 .63136 Mdot
.50588 .62744 Mdot
.48628 .60783 Mdot
.48235 .60391 Mdot
.46667 .58823 Mdot
.45883 .57646 Mdot
.47059 .58823 Mdot
.46667 .58431 Mdot
.45883 .57254 Mdot
.45098 .56078 Mdot
.44314 .53725 Mdot
.4353 .50588 Mdot
.41177 .46275 Mdot
.39609 .54509 Mdot
.4353 .60783 Mdot
.45098 .64313 Mdot
.45491 .65881 Mdot
.44706 .65097 Mdot
.45491 .65097 Mdot
.45098 .65097 Mdot
.47059 .66665 Mdot
.47451 .67057 Mdot
.48235 .6745 Mdot
.47451 .66665 Mdot
.47451 .65881 Mdot
.47843 .65097 Mdot
.48628 .64705 Mdot
.4902 .64313 Mdot
.49804 .65097 Mdot
.50196 .65489 Mdot
.5098 .66665 Mdot
.49804 .66273 Mdot
.50588 .67842 Mdot
.51372 .68626 Mdot
.51765 .69018 Mdot
.5098 .69018 Mdot
.5098 .69802 Mdot
.50588 .69018 Mdot
.50196 .68234 Mdot
.50588 .67842 Mdot
.51372 .67842 Mdot
.52549 .68234 Mdot
.52941 .68234 Mdot
.52941 .69018 Mdot
.54117 .70194 Mdot
.53725 .70194 Mdot
.53725 .70194 Mdot
.54117 .69802 Mdot
.54509 .6941 Mdot
.56078 .71371 Mdot
.56078 .71763 Mdot
.55686 .71371 Mdot
.56862 .72155 Mdot
.5647 .70194 Mdot
.5647 .70194 Mdot
.55686 .69802 Mdot
.5647 .70979 Mdot
.5647 .70587 Mdot
.57254 .70979 Mdot
.5647 .70194 Mdot
.56862 .70194 Mdot
.56078 .69802 Mdot
.58039 .70587 Mdot
.59215 .70979 Mdot
.59215 .71371 Mdot
.58823 .72155 Mdot
.58823 .72547 Mdot
.59215 .72547 Mdot
.59999 .72939 Mdot
.59999 .72547 Mdot
.59215 .72547 Mdot
.60391 .73724 Mdot
.61176 .74508 Mdot
.61176 .74116 Mdot
.61176 .73332 Mdot
.61176 .72547 Mdot
.60783 .72939 Mdot
.61176 .74508 Mdot
.60783 .74116 Mdot
.60391 .73724 Mdot
.59999 .72939 Mdot
.60783 .72939 Mdot
.60783 .72547 Mdot
.60391 .71371 Mdot
.60783 .71763 Mdot
.60391 .71371 Mdot
.60391 .70587 Mdot
.60783 .69802 Mdot
.62352 .70979 Mdot
.62744 .72547 Mdot
.62744 .72547 Mdot
.6196 .71763 Mdot
.63136 .72547 Mdot
.62744 .72939 Mdot
.63528 .74508 Mdot
.63528 .74508 Mdot
.63136 .75292 Mdot
.63136 .76469 Mdot
.62744 .76076 Mdot
.63528 .76861 Mdot
.62744 .76076 Mdot
.62352 .75684 Mdot
.6196 .749 Mdot
.6196 .74116 Mdot
.61176 .72155 Mdot
.61568 .71371 Mdot
.61568 .71763 Mdot
.61568 .71371 Mdot
.61568 .71371 Mdot
.61568 .72939 Mdot
.61568 .74116 Mdot
.61568 .74116 Mdot
.6196 .73724 Mdot
.61568 .72155 Mdot
.62352 .72155 Mdot
.62352 .72155 Mdot
.61176 .71371 Mdot
.62352 .72547 Mdot
.62352 .72547 Mdot
.62352 .72155 Mdot
.62744 .72939 Mdot
.6196 .72547 Mdot
.61176 .72547 Mdot
.59607 .70979 Mdot
.59607 .70979 Mdot
.60391 .71763 Mdot
.59999 .70587 Mdot
.59999 .70194 Mdot
.59999 .70979 Mdot
.59999 .71763 Mdot
.58823 .71371 Mdot
.58039 .70587 Mdot
.58431 .70194 Mdot
.59215 .70194 Mdot
.59215 .6941 Mdot
.58431 .68626 Mdot
.58431 .69018 Mdot
.58431 .70194 Mdot
.57254 .6941 Mdot
.5647 .68626 Mdot
.55686 .66665 Mdot
.5647 .6745 Mdot
.5647 .67057 Mdot
.56078 .66273 Mdot
.55294 .65097 Mdot
.54902 .65489 Mdot
.53333 .64313 Mdot
.53333 .6392 Mdot
.53725 .6392 Mdot
.52941 .63528 Mdot
.52941 .64313 Mdot
.52157 .63136 Mdot
.51765 .6196 Mdot
.51372 .60783 Mdot
.50196 .60391 Mdot
.51372 .62352 Mdot
.50196 .62352 Mdot
.5098 .62744 Mdot
.50588 .63528 Mdot
.49804 .63136 Mdot
.4902 .62352 Mdot
.4902 .61568 Mdot
.48235 .59999 Mdot
.47843 .58431 Mdot
.47451 .57646 Mdot
.45883 .57254 Mdot
.45883 .58039 Mdot
.46275 .59215 Mdot
.44314 .56862 Mdot
.4353 .54902 Mdot
.43138 .52941 Mdot
.41569 .49804 Mdot
.40393 .46275 Mdot
.38824 .54117 Mdot
.4353 .60783 Mdot
.45491 .6392 Mdot
.45491 .65097 Mdot
.45098 .65097 Mdot
.45098 .64313 Mdot
.46275 .64313 Mdot
.47843 .65881 Mdot
.48628 .67057 Mdot
.47843 .67057 Mdot
.47451 .66665 Mdot
.47059 .65097 Mdot
.46275 .64705 Mdot
.47451 .64705 Mdot
.48235 .64313 Mdot
.49804 .64705 Mdot
.5098 .66273 Mdot
.5098 .67842 Mdot
.50196 .67842 Mdot
.50588 .67842 Mdot
.50196 .65881 Mdot
.51765 .67057 Mdot
.52157 .68234 Mdot
.51372 .68626 Mdot
.50588 .68626 Mdot
.50588 .67842 Mdot
.50196 .66665 Mdot
.5098 .66273 Mdot
.51372 .65881 Mdot
.51765 .67057 Mdot
.52157 .69018 Mdot
.53333 .70587 Mdot
.54902 .71371 Mdot
.55294 .70194 Mdot
.55686 .6941 Mdot
.55686 .69018 Mdot
.5647 .70587 Mdot
.56078 .71763 Mdot
.5647 .72939 Mdot
.55686 .72155 Mdot
.55686 .71371 Mdot
.55294 .69802 Mdot
.5647 .6941 Mdot
.5647 .69018 Mdot
.57254 .69802 Mdot
.5647 .6941 Mdot
.55294 .69018 Mdot
.56078 .6941 Mdot
.56862 .70194 Mdot
.57254 .70194 Mdot
.58039 .71763 Mdot
.58823 .72547 Mdot
.57646 .72155 Mdot
.58431 .72939 Mdot
.58823 .72939 Mdot
.59607 .72939 Mdot
.59607 .73332 Mdot
.59215 .73724 Mdot
.59999 .73724 Mdot
.59607 .72547 Mdot
.59999 .71763 Mdot
.59607 .70979 Mdot
.60783 .71371 Mdot
.61568 .72155 Mdot
.61176 .72547 Mdot
.60783 .73332 Mdot
.60783 .73724 Mdot
.59215 .71763 Mdot
.59607 .70979 Mdot
.60391 .70587 Mdot
.60783 .70194 Mdot
.60783 .70194 Mdot
.59607 .69802 Mdot
.59999 .70194 Mdot
.60391 .70194 Mdot
.60391 .70194 Mdot
.61568 .71371 Mdot
.62352 .72547 Mdot
.62744 .73332 Mdot
.62744 .72155 Mdot
.62352 .70979 Mdot
.62352 .70979 Mdot
.62352 .71371 Mdot
.63136 .72547 Mdot
.62744 .73724 Mdot
.62744 .74116 Mdot
.62744 .74508 Mdot
.61568 .73332 Mdot
.61176 .73332 Mdot
.61568 .74116 Mdot
.61176 .74116 Mdot
.59999 .72155 Mdot
.60783 .71763 Mdot
.61176 .71763 Mdot
.61568 .72155 Mdot
.6196 .72939 Mdot
.61176 .72939 Mdot
.60391 .73332 Mdot
.61176 .73332 Mdot
.61568 .72547 Mdot
.60783 .71371 Mdot
.6196 .70979 Mdot
.62352 .71763 Mdot
.62352 .72547 Mdot
.61176 .71371 Mdot
.60783 .70587 Mdot
.60391 .69802 Mdot
.61568 .70587 Mdot
.62352 .71371 Mdot
.61176 .70587 Mdot
.59607 .70194 Mdot
.59215 .70979 Mdot
.59215 .70587 Mdot
.59607 .6941 Mdot
.59215 .69018 Mdot
.58431 .6941 Mdot
.58823 .70979 Mdot
.58823 .70979 Mdot
.57646 .70194 Mdot
.57646 .70194 Mdot
.57646 .6941 Mdot
.58039 .6941 Mdot
.56862 .68626 Mdot
.5647 .6941 Mdot
.55294 .68234 Mdot
.55294 .66273 Mdot
.54902 .65489 Mdot
.55686 .65489 Mdot
.55686 .65097 Mdot
.55294 .65097 Mdot
.55686 .64705 Mdot
.54902 .64313 Mdot
.54117 .63136 Mdot
.54509 .6392 Mdot
.53333 .63136 Mdot
.54117 .63136 Mdot
.54117 .6392 Mdot
.53333 .63528 Mdot
.52157 .63528 Mdot
.5098 .61568 Mdot
.50196 .60391 Mdot
.50196 .59999 Mdot
.50588 .61176 Mdot
.50588 .61568 Mdot
.5098 .62744 Mdot
.50196 .62352 Mdot
.49412 .62352 Mdot
.48628 .63136 Mdot
.4902 .62352 Mdot
.48235 .59999 Mdot
.47451 .57646 Mdot
.47843 .58431 Mdot
.46667 .58823 Mdot
.45491 .58823 Mdot
.45098 .59607 Mdot
.43138 .56862 Mdot
.43922 .54902 Mdot
.41569 .5098 Mdot
.41961 .49412 Mdot
.40785 .46667 Mdot
.38432 .52157 Mdot
.43138 .59607 Mdot
.44706 .62352 Mdot
.45098 .64313 Mdot
.44314 .6392 Mdot
.45098 .64313 Mdot
.46275 .63528 Mdot
.45883 .6392 Mdot
.47059 .65489 Mdot
.47843 .66665 Mdot
.47451 .65881 Mdot
.47451 .65489 Mdot
.47059 .65489 Mdot
.47451 .65097 Mdot
.47451 .64705 Mdot
.48235 .64705 Mdot
.4902 .65097 Mdot
.49804 .65881 Mdot
.50196 .66665 Mdot
.50196 .66273 Mdot
.50196 .64705 Mdot
.50196 .6392 Mdot
.51765 .65097 Mdot
.51765 .65881 Mdot
.52157 .67057 Mdot
.51372 .67057 Mdot
.51372 .66665 Mdot
.51765 .66273 Mdot
.52549 .66273 Mdot
.52157 .66273 Mdot
.52549 .6745 Mdot
.52549 .68234 Mdot
.53333 .68234 Mdot
.54509 .68234 Mdot
.54117 .67057 Mdot
.55294 .67842 Mdot
.5647 .69018 Mdot
.57254 .70587 Mdot
.5647 .71371 Mdot
.56862 .71763 Mdot
.5647 .70587 Mdot
.56078 .6941 Mdot
.57254 .6941 Mdot
.56862 .6941 Mdot
.56862 .68234 Mdot
.57254 .68626 Mdot
.57646 .69802 Mdot
.57254 .69018 Mdot
.56078 .6745 Mdot
.57646 .69018 Mdot
.57646 .6941 Mdot
.57646 .70587 Mdot
.58039 .72939 Mdot
.57254 .73332 Mdot
.57646 .72547 Mdot
.58039 .71371 Mdot
.58039 .71371 Mdot
.58039 .71371 Mdot
.58039 .71763 Mdot
.58823 .72547 Mdot
.59607 .72155 Mdot
.59607 .70979 Mdot
.59999 .70194 Mdot
.59999 .70587 Mdot
.59999 .71763 Mdot
.58823 .72155 Mdot
.59215 .71763 Mdot
.59215 .70587 Mdot
.59607 .69018 Mdot
.59999 .68626 Mdot
.60783 .68626 Mdot
.60391 .6941 Mdot
.59999 .69802 Mdot
.59999 .69802 Mdot
.59215 .68626 Mdot
.59999 .69018 Mdot
.59607 .69018 Mdot
.59999 .70979 Mdot
.59999 .71763 Mdot
.59607 .71371 Mdot
.59607 .69802 Mdot
.60783 .6941 Mdot
.6196 .6941 Mdot
.62744 .70194 Mdot
.62352 .70979 Mdot
.62352 .71763 Mdot
.62744 .72547 Mdot
.6196 .71763 Mdot
.61176 .71371 Mdot
.60391 .70979 Mdot
.60391 .72155 Mdot
.59215 .70587 Mdot
.58823 .70587 Mdot
.59215 .70979 Mdot
.59999 .70979 Mdot
.61568 .72547 Mdot
.6196 .73332 Mdot
.59999 .71763 Mdot
.60391 .72547 Mdot
.60391 .71763 Mdot
.59607 .70194 Mdot
.60391 .70194 Mdot
.61176 .69802 Mdot
.6196 .71371 Mdot
.6196 .71371 Mdot
.61176 .70587 Mdot
.60391 .69802 Mdot
.59999 .6941 Mdot
.61176 .70587 Mdot
.60391 .69802 Mdot
.60783 .70979 Mdot
.59607 .71371 Mdot
.58823 .70194 Mdot
.58823 .68626 Mdot
.58039 .67842 Mdot
.58431 .68626 Mdot
.57646 .69018 Mdot
.58039 .70194 Mdot
.58431 .69802 Mdot
.58431 .6941 Mdot
.57254 .67842 Mdot
.56078 .66665 Mdot
.5647 .67842 Mdot
.5647 .68626 Mdot
.54509 .6745 Mdot
.54117 .65097 Mdot
.54902 .64313 Mdot
.56078 .6392 Mdot
.5647 .63136 Mdot
.55686 .63136 Mdot
.55686 .6392 Mdot
.54902 .63528 Mdot
.54902 .6392 Mdot
.54509 .63136 Mdot
.53333 .6196 Mdot
.53333 .61568 Mdot
.53725 .6196 Mdot
.54117 .6392 Mdot
.52157 .63136 Mdot
.50588 .6196 Mdot
.49412 .60783 Mdot
.4902 .59215 Mdot
.50588 .60391 Mdot
.50196 .60391 Mdot
.5098 .61568 Mdot
.51372 .6196 Mdot
.50196 .62352 Mdot
.48628 .6196 Mdot
.48235 .6196 Mdot
.48235 .60783 Mdot
.47843 .59607 Mdot
.47451 .59215 Mdot
.47059 .59999 Mdot
.46275 .59607 Mdot
.45098 .58823 Mdot
.43138 .5647 Mdot
.42354 .52941 Mdot
.42354 .51372 Mdot
.42354 .49412 Mdot
.41569 .46667 Mdot
.38432 .53725 Mdot
.42746 .59999 Mdot
.44314 .62352 Mdot
.45098 .63136 Mdot
.44706 .6392 Mdot
.45098 .64313 Mdot
.45883 .65097 Mdot
.45098 .64313 Mdot
.46667 .65881 Mdot
.47059 .66273 Mdot
.46275 .65489 Mdot
.46667 .65881 Mdot
.47843 .66273 Mdot
.48628 .66665 Mdot
.48628 .66665 Mdot
.48628 .66273 Mdot
.4902 .65881 Mdot
.49804 .66273 Mdot
.50196 .65881 Mdot
.49804 .65097 Mdot
.5098 .65489 Mdot
.51372 .65097 Mdot
.51372 .65489 Mdot
.51372 .66273 Mdot
.5098 .65881 Mdot
.5098 .65881 Mdot
.50588 .65881 Mdot
.5098 .66665 Mdot
.51372 .66273 Mdot
.52157 .67057 Mdot
.52157 .6745 Mdot
.53333 .68234 Mdot
.53333 .67842 Mdot
.54117 .6745 Mdot
.54509 .66665 Mdot
.56078 .67842 Mdot
.56078 .67842 Mdot
.56078 .6745 Mdot
.55686 .68234 Mdot
.56078 .68626 Mdot
.56862 .6941 Mdot
.56078 .69018 Mdot
.55686 .69018 Mdot
.5647 .70194 Mdot
.5647 .69018 Mdot
.56862 .69018 Mdot
.57254 .68626 Mdot
.57254 .69018 Mdot
.57646 .69018 Mdot
.57646 .69802 Mdot
.58039 .70587 Mdot
.58431 .71371 Mdot
.58039 .72939 Mdot
.58039 .73332 Mdot
.58431 .73724 Mdot
.58039 .72939 Mdot
.57254 .72547 Mdot
.57646 .72547 Mdot
.57254 .71763 Mdot
.58039 .71371 Mdot
.59215 .71371 Mdot
.59215 .70587 Mdot
.58823 .70194 Mdot
.60391 .71371 Mdot
.59999 .71371 Mdot
.58431 .71763 Mdot
.59215 .72547 Mdot
.59607 .71763 Mdot
.59607 .70587 Mdot
.60391 .70979 Mdot
.61176 .71371 Mdot
.60391 .70194 Mdot
.60391 .6941 Mdot
.59999 .69018 Mdot
.59999 .68626 Mdot
.59607 .68234 Mdot
.58823 .68234 Mdot
.58823 .69802 Mdot
.58431 .70587 Mdot
.59215 .70979 Mdot
.58823 .70194 Mdot
.60783 .70587 Mdot
.60391 .69802 Mdot
.61568 .70979 Mdot
.61568 .70979 Mdot
.6196 .72155 Mdot
.6196 .72547 Mdot
.61568 .72155 Mdot
.61568 .72939 Mdot
.61176 .72547 Mdot
.60783 .71763 Mdot
.60783 .72155 Mdot
.60783 .72155 Mdot
.59999 .71763 Mdot
.59607 .70979 Mdot
.59607 .70979 Mdot
.59607 .71371 Mdot
.59607 .71763 Mdot
.59215 .71763 Mdot
.59999 .72155 Mdot
.59215 .70979 Mdot
.60391 .71371 Mdot
.60783 .70979 Mdot
.60783 .71371 Mdot
.60783 .70979 Mdot
.60783 .70587 Mdot
.61176 .70587 Mdot
.61568 .70587 Mdot
.61176 .70979 Mdot
.60783 .71371 Mdot
.60391 .71371 Mdot
.59999 .70979 Mdot
.59607 .69018 Mdot
.59215 .68234 Mdot
.58431 .6745 Mdot
.58431 .6745 Mdot
.58431 .68234 Mdot
.57646 .68234 Mdot
.57646 .68234 Mdot
.57254 .68234 Mdot
.57254 .68626 Mdot
.57254 .68234 Mdot
.55686 .67057 Mdot
.55294 .66665 Mdot
.55294 .66665 Mdot
.54509 .64705 Mdot
.55686 .64705 Mdot
.55686 .63528 Mdot
.55686 .62744 Mdot
.5647 .6392 Mdot
.54117 .62744 Mdot
.54117 .62352 Mdot
.54117 .62352 Mdot
.54902 .62744 Mdot
.52941 .61176 Mdot
.52549 .6196 Mdot
.52549 .62352 Mdot
.53333 .63136 Mdot
.52549 .63136 Mdot
.51372 .62744 Mdot
.51372 .62744 Mdot
.5098 .6196 Mdot
.50196 .61176 Mdot
.50196 .61176 Mdot
.5098 .6196 Mdot
.50588 .6196 Mdot
.49804 .61568 Mdot
.48628 .61568 Mdot
.48628 .6196 Mdot
.48235 .61568 Mdot
.47059 .60391 Mdot
.47059 .60783 Mdot
.45883 .60391 Mdot
.45883 .59999 Mdot
.45098 .58039 Mdot
.42354 .54902 Mdot
.42354 .54117 Mdot
.41569 .51372 Mdot
.40393 .4902 Mdot
.40001 .47059 Mdot
.39609 .53333 Mdot
.4353 .60783 Mdot
.44314 .62352 Mdot
.45491 .63528 Mdot
.45491 .63136 Mdot
.45098 .63528 Mdot
.45491 .64313 Mdot
.45491 .64705 Mdot
.46275 .65489 Mdot
.46275 .64705 Mdot
.47059 .65489 Mdot
.4902 .67057 Mdot
.48235 .67057 Mdot
.4902 .6745 Mdot
.48235 .66665 Mdot
.48628 .67057 Mdot
.4902 .67057 Mdot
.5098 .68234 Mdot
.50196 .66665 Mdot
.50196 .67057 Mdot
.50588 .66665 Mdot
.51765 .66665 Mdot
.5098 .66273 Mdot
.50588 .66273 Mdot
.50588 .66665 Mdot
.51372 .66665 Mdot
.51372 .66273 Mdot
.51372 .66273 Mdot
.52157 .67057 Mdot
.51765 .66273 Mdot
.52549 .67057 Mdot
.52941 .6745 Mdot
.53333 .6745 Mdot
.54509 .67842 Mdot
.55294 .68626 Mdot
.54509 .66665 Mdot
.55294 .67057 Mdot
.55294 .66273 Mdot
.54902 .6745 Mdot
.54902 .67842 Mdot
.54902 .67842 Mdot
.56078 .69802 Mdot
.56078 .69802 Mdot
.56078 .69802 Mdot
.55294 .68234 Mdot
.55686 .68626 Mdot
.5647 .69018 Mdot
.5647 .68626 Mdot
.56078 .68626 Mdot
.56862 .70194 Mdot
.57254 .70979 Mdot
.5647 .70979 Mdot
.56862 .71371 Mdot
.57254 .71763 Mdot
.58431 .73332 Mdot
.57646 .73332 Mdot
.57646 .73332 Mdot
.57646 .72939 Mdot
.58039 .72939 Mdot
.58039 .72155 Mdot
.59215 .71763 Mdot
.59607 .71371 Mdot
.59215 .70587 Mdot
.58823 .69802 Mdot
.58823 .70194 Mdot
.58431 .70587 Mdot
.58431 .71371 Mdot
.58431 .71763 Mdot
.59607 .72547 Mdot
.59215 .72155 Mdot
.58823 .70979 Mdot
.59999 .70979 Mdot
.59607 .70194 Mdot
.59215 .69018 Mdot
.58431 .67842 Mdot
.58431 .67842 Mdot
.58431 .68626 Mdot
.58039 .69018 Mdot
.59607 .71371 Mdot
.60391 .72155 Mdot
.59999 .72155 Mdot
.59999 .71763 Mdot
.59999 .70979 Mdot
.61176 .71371 Mdot
.61176 .70979 Mdot
.60783 .71763 Mdot
.61176 .72155 Mdot
.6196 .74116 Mdot
.6196 .74116 Mdot
.6196 .73724 Mdot
.62744 .72939 Mdot
.61568 .70587 Mdot
.61568 .70194 Mdot
.60783 .69802 Mdot
.60391 .70587 Mdot
.60391 .71371 Mdot
.59999 .71371 Mdot
.59999 .71763 Mdot
.59999 .71763 Mdot
.60391 .72939 Mdot
.59999 .72547 Mdot
.59999 .71763 Mdot
.61176 .72155 Mdot
.60391 .71763 Mdot
.60391 .72155 Mdot
.59999 .71371 Mdot
.60391 .70587 Mdot
.61176 .70979 Mdot
.61568 .70979 Mdot
.60783 .71371 Mdot
.60391 .71371 Mdot
.58823 .69018 Mdot
.58431 .67842 Mdot
.58823 .68626 Mdot
.58431 .68626 Mdot
.57254 .6745 Mdot
.57254 .6745 Mdot
.57254 .67842 Mdot
.56078 .67057 Mdot
.56862 .67842 Mdot
.55294 .67057 Mdot
.55294 .66665 Mdot
.55686 .66665 Mdot
.55686 .67057 Mdot
.55686 .67057 Mdot
.55686 .65489 Mdot
.55294 .64313 Mdot
.55294 .64313 Mdot
.54902 .63528 Mdot
.54117 .63528 Mdot
.54902 .64313 Mdot
.52549 .62352 Mdot
.53333 .61568 Mdot
.52549 .60391 Mdot
.53333 .6196 Mdot
.52941 .62352 Mdot
.51372 .6196 Mdot
.51372 .6196 Mdot
.52549 .63136 Mdot
.51372 .62352 Mdot
.5098 .62352 Mdot
.50588 .6196 Mdot
.49804 .62352 Mdot
.50196 .62352 Mdot
.50196 .62744 Mdot
.50196 .63136 Mdot
.48235 .62352 Mdot
.47843 .6196 Mdot
.47451 .61568 Mdot
.46275 .60783 Mdot
.45883 .59607 Mdot
.44706 .58431 Mdot
.45098 .58823 Mdot
.45491 .58823 Mdot
.44706 .5647 Mdot
.4353 .54902 Mdot
.42746 .54117 Mdot
.41569 .52941 Mdot
.40785 .5098 Mdot
.39217 .48235 Mdot
.38824 .52941 Mdot
.41961 .58823 Mdot
.43138 .61568 Mdot
.43922 .63136 Mdot
.45098 .64313 Mdot
.45098 .6392 Mdot
.45098 .6392 Mdot
.45098 .6392 Mdot
.45883 .64705 Mdot
.45883 .6392 Mdot
.47059 .64705 Mdot
.48628 .66273 Mdot
.4902 .66665 Mdot
.48235 .65489 Mdot
.48628 .65489 Mdot
.49804 .66273 Mdot
.49804 .65881 Mdot
.5098 .6745 Mdot
.50588 .67842 Mdot
.49412 .68234 Mdot
.49804 .6745 Mdot
.49412 .66273 Mdot
.51765 .67842 Mdot
.51372 .6745 Mdot
.52157 .68234 Mdot
.51765 .68234 Mdot
.51765 .6745 Mdot
.52157 .6745 Mdot
.52157 .68234 Mdot
.52157 .6745 Mdot
.52549 .68234 Mdot
.53725 .6941 Mdot
.52941 .68234 Mdot
.53333 .68626 Mdot
.52941 .67842 Mdot
.53333 .67842 Mdot
.54117 .68234 Mdot
.54117 .67842 Mdot
.54902 .68234 Mdot
.54117 .6745 Mdot
.54509 .67842 Mdot
.54509 .68626 Mdot
.55294 .6941 Mdot
.54902 .68234 Mdot
.56078 .69018 Mdot
.5647 .69802 Mdot
.5647 .69802 Mdot
.5647 .69802 Mdot
.56862 .69802 Mdot
.57646 .6941 Mdot
.58039 .69802 Mdot
.58431 .70587 Mdot
.57646 .70587 Mdot
.58039 .70979 Mdot
.58039 .71763 Mdot
.57646 .72155 Mdot
.57646 .72547 Mdot
.58039 .72547 Mdot
.57646 .71763 Mdot
.58431 .72155 Mdot
.59607 .72155 Mdot
.58823 .71371 Mdot
.58431 .70979 Mdot
.57646 .70194 Mdot
.59215 .70587 Mdot
.58823 .70587 Mdot
.59215 .71371 Mdot
.59607 .72155 Mdot
.59607 .72547 Mdot
.59607 .70979 Mdot
.60783 .70587 Mdot
.60391 .6941 Mdot
.59607 .69802 Mdot
.59999 .70194 Mdot
.59215 .69802 Mdot
.58823 .6941 Mdot
.59215 .6941 Mdot
.58431 .6941 Mdot
.58823 .70194 Mdot
.59607 .71371 Mdot
.59999 .72547 Mdot
.60391 .72547 Mdot
.59999 .72547 Mdot
.60391 .72155 Mdot
.60783 .71763 Mdot
.61176 .71763 Mdot
.60783 .72155 Mdot
.59999 .72155 Mdot
.60391 .72155 Mdot
.60783 .71371 Mdot
.61176 .70587 Mdot
.60783 .69802 Mdot
.61176 .6941 Mdot
.6196 .70587 Mdot
.61568 .72155 Mdot
.61176 .72155 Mdot
.61176 .72155 Mdot
.59999 .71763 Mdot
.60391 .72155 Mdot
.61176 .72547 Mdot
.59999 .71371 Mdot
.60391 .71763 Mdot
.60391 .72547 Mdot
.60391 .72155 Mdot
.60783 .71763 Mdot
.59999 .70979 Mdot
.59607 .70194 Mdot
.59999 .69802 Mdot
.60783 .70194 Mdot
.59215 .69802 Mdot
.58823 .69802 Mdot
.58039 .68626 Mdot
.58431 .68234 Mdot
.58039 .69018 Mdot
.58039 .69802 Mdot
.57254 .69018 Mdot
.5647 .69018 Mdot
.5647 .68626 Mdot
.57254 .67842 Mdot
.56862 .6745 Mdot
.56078 .66665 Mdot
.55686 .6745 Mdot
.56078 .68234 Mdot
.54902 .65881 Mdot
.56078 .66665 Mdot
.5647 .66273 Mdot
.55294 .65881 Mdot
.54117 .64705 Mdot
.54509 .65097 Mdot
.53725 .64313 Mdot
.52941 .6392 Mdot
.52549 .6392 Mdot
.52157 .63528 Mdot
.51372 .62352 Mdot
.53333 .6392 Mdot
.52549 .63136 Mdot
.52157 .63136 Mdot
.52157 .6392 Mdot
.51372 .63528 Mdot
.50588 .63528 Mdot
.50196 .63136 Mdot
.49412 .62352 Mdot
.49804 .62352 Mdot
.48628 .61176 Mdot
.4902 .6196 Mdot
.48235 .61568 Mdot
.48628 .6196 Mdot
.47451 .60391 Mdot
.46667 .59215 Mdot
.45883 .58431 Mdot
.45098 .57254 Mdot
.43922 .55686 Mdot
.43922 .55686 Mdot
.44314 .5647 Mdot
.44706 .5647 Mdot
.43922 .56078 Mdot
.42746 .54902 Mdot
.41569 .53333 Mdot
.40393 .5098 Mdot
.38432 .47843 Mdot
.39609 .54509 Mdot
.42746 .59607 Mdot
.43922 .62352 Mdot
.44314 .6392 Mdot
.45098 .64705 Mdot
.44706 .64313 Mdot
.44706 .6392 Mdot
.45098 .64313 Mdot
.46667 .65097 Mdot
.47059 .64313 Mdot
.47059 .63528 Mdot
.47451 .65097 Mdot
.47451 .65881 Mdot
.47843 .65881 Mdot
.48235 .65097 Mdot
.48235 .65097 Mdot
.49804 .66273 Mdot
.49804 .65881 Mdot
.49412 .6745 Mdot
.49804 .68626 Mdot
.50588 .68626 Mdot
.49804 .66273 Mdot
.5098 .65881 Mdot
.5098 .65489 Mdot
.51372 .65881 Mdot
.51372 .66665 Mdot
.51765 .6745 Mdot
.51765 .6745 Mdot
.52157 .68234 Mdot
.52157 .67057 Mdot
.51372 .66273 Mdot
.52549 .67842 Mdot
.52941 .68234 Mdot
.52549 .6745 Mdot
.51765 .66665 Mdot
.52941 .6745 Mdot
.53333 .67842 Mdot
.54117 .67842 Mdot
.55294 .68626 Mdot
.55686 .69018 Mdot
.55294 .69018 Mdot
.55686 .70979 Mdot
.54509 .69018 Mdot
.55294 .6941 Mdot
.54902 .68234 Mdot
.56862 .6941 Mdot
.5647 .6941 Mdot
.57254 .70587 Mdot
.56862 .69802 Mdot
.58039 .69802 Mdot
.58823 .6941 Mdot
.58431 .69018 Mdot
.57646 .69018 Mdot
.58431 .70587 Mdot
.57646 .70979 Mdot
.57646 .71371 Mdot
.57254 .71371 Mdot
.57646 .70979 Mdot
.58039 .70979 Mdot
.58039 .70194 Mdot
.58823 .70587 Mdot
.58431 .70587 Mdot
.57254 .70194 Mdot
.57646 .70979 Mdot
.57646 .70587 Mdot
.58431 .70979 Mdot
.58823 .71371 Mdot
.58431 .71763 Mdot
.58823 .72155 Mdot
.59607 .70979 Mdot
.60391 .70979 Mdot
.59607 .70194 Mdot
.60391 .70587 Mdot
.59215 .69802 Mdot
.58823 .70194 Mdot
.58039 .69018 Mdot
.57646 .69018 Mdot
.57646 .68626 Mdot
.58823 .69018 Mdot
.58823 .69802 Mdot
.59607 .70979 Mdot
.59215 .70979 Mdot
.59215 .71371 Mdot
.60391 .71371 Mdot
.59215 .70194 Mdot
.59215 .69802 Mdot
.60391 .70979 Mdot
.60783 .71763 Mdot
.59999 .70979 Mdot
.59607 .70194 Mdot
.59215 .69018 Mdot
.59999 .6941 Mdot
.60391 .70587 Mdot
.61568 .70979 Mdot
.60783 .71371 Mdot
.61176 .72155 Mdot
.59999 .71371 Mdot
.59607 .70979 Mdot
.60783 .71371 Mdot
.60783 .70587 Mdot
.59999 .6941 Mdot
.59999 .69802 Mdot
.59999 .70194 Mdot
.59215 .69802 Mdot
.59607 .69802 Mdot
.59607 .69802 Mdot
.59215 .6941 Mdot
.59607 .70194 Mdot
.59607 .70194 Mdot
.58431 .70194 Mdot
.58039 .70194 Mdot
.57254 .69018 Mdot
.57646 .67842 Mdot
.57646 .68234 Mdot
.58039 .6941 Mdot
.56078 .6941 Mdot
.54902 .68626 Mdot
.54902 .67842 Mdot
.54509 .65881 Mdot
.55686 .66273 Mdot
.55686 .65881 Mdot
.5647 .6745 Mdot
.56078 .68234 Mdot
.55294 .6745 Mdot
.54509 .66665 Mdot
.52941 .64313 Mdot
.54902 .65097 Mdot
.54902 .65097 Mdot
.54117 .65097 Mdot
.54509 .65881 Mdot
.54509 .66665 Mdot
.53333 .65881 Mdot
.52941 .65489 Mdot
.51765 .6392 Mdot
.51372 .63136 Mdot
.51765 .63136 Mdot
.51765 .63528 Mdot
.52157 .64313 Mdot
.51372 .64313 Mdot
.5098 .65097 Mdot
.48628 .63136 Mdot
.47451 .61176 Mdot
.4902 .60783 Mdot
.4902 .60391 Mdot
.48628 .60783 Mdot
.47843 .61176 Mdot
.47451 .60783 Mdot
.46667 .60783 Mdot
.44706 .59215 Mdot
.44706 .58431 Mdot
.45098 .58431 Mdot
.44314 .57646 Mdot
.43922 .5647 Mdot
.4353 .5647 Mdot
.42746 .55686 Mdot
.41569 .55294 Mdot
.40785 .54509 Mdot
.40393 .52941 Mdot
.39609 .50588 Mdot
.38432 .47451 Mdot
.38824 .53725 Mdot
.41961 .58039 Mdot
.44314 .61568 Mdot
.45491 .64705 Mdot
.45491 .64705 Mdot
.45883 .64705 Mdot
.45491 .6392 Mdot
.46275 .6392 Mdot
.47451 .64313 Mdot
.48235 .64313 Mdot
.47843 .6392 Mdot
.48628 .65881 Mdot
.47843 .65097 Mdot
.47843 .65489 Mdot
.48628 .65881 Mdot
.4902 .65881 Mdot
.48235 .65097 Mdot
.49412 .65881 Mdot
.4902 .65489 Mdot
.49412 .65881 Mdot
.50196 .66273 Mdot
.50588 .65489 Mdot
.49804 .6392 Mdot
.49412 .63528 Mdot
.51765 .64313 Mdot
.52157 .64313 Mdot
.53725 .65881 Mdot
.53333 .65489 Mdot
.52549 .65881 Mdot
.52941 .67057 Mdot
.52157 .66273 Mdot
.52941 .65881 Mdot
.53725 .67057 Mdot
.53333 .67057 Mdot
.52941 .67842 Mdot
.53725 .68626 Mdot
.53725 .68626 Mdot
.54509 .68626 Mdot
.56078 .69802 Mdot
.55686 .70587 Mdot
.55686 .70979 Mdot
.54902 .69802 Mdot
.54902 .69802 Mdot
.55294 .70587 Mdot
.55294 .70194 Mdot
.54902 .68626 Mdot
.55686 .6941 Mdot
.55686 .69802 Mdot
.55294 .69018 Mdot
.56862 .69018 Mdot
.57646 .69018 Mdot
.56862 .67842 Mdot
.57254 .67842 Mdot
.57646 .69018 Mdot
.57646 .69802 Mdot
.57646 .70587 Mdot
.57646 .69802 Mdot
.57646 .69018 Mdot
.58431 .69802 Mdot
.57646 .69802 Mdot
.58039 .70194 Mdot
.56862 .69018 Mdot
.5647 .6941 Mdot
.5647 .70587 Mdot
.5647 .70194 Mdot
.56862 .70587 Mdot
.57646 .71763 Mdot
.57254 .72155 Mdot
.58039 .70979 Mdot
.58039 .70194 Mdot
.58431 .70194 Mdot
.58431 .69802 Mdot
.58823 .70587 Mdot
.59607 .71371 Mdot
.58431 .70587 Mdot
.58039 .6941 Mdot
.58431 .68626 Mdot
.58431 .68234 Mdot
.58823 .68234 Mdot
.58823 .6941 Mdot
.58823 .70587 Mdot
.58039 .70587 Mdot
.59607 .71371 Mdot
.59215 .70979 Mdot
.59607 .70194 Mdot
.59215 .68626 Mdot
.59999 .70194 Mdot
.60783 .71763 Mdot
.59607 .70587 Mdot
.59215 .70194 Mdot
.58823 .6941 Mdot
.58823 .68234 Mdot
.59607 .6941 Mdot
.59999 .69802 Mdot
.59607 .69802 Mdot
.59999 .71763 Mdot
.59215 .70979 Mdot
.58431 .70194 Mdot
.58823 .69018 Mdot
.58039 .6745 Mdot
.58823 .67842 Mdot
.59215 .6745 Mdot
.58823 .68234 Mdot
.58039 .69018 Mdot
.58039 .6941 Mdot
.57646 .6941 Mdot
.58039 .6941 Mdot
.58039 .70194 Mdot
.58039 .70587 Mdot
.57646 .70194 Mdot
.56862 .6941 Mdot
.57254 .69018 Mdot
.57646 .69018 Mdot
.56862 .6745 Mdot
.56862 .67842 Mdot
.5647 .67842 Mdot
.55686 .68234 Mdot
.54509 .67057 Mdot
.54509 .67057 Mdot
.54902 .66665 Mdot
.54117 .65097 Mdot
.54509 .66273 Mdot
.54902 .66665 Mdot
.54509 .66273 Mdot
.54902 .66665 Mdot
.53725 .65097 Mdot
.53725 .63528 Mdot
.54117 .62352 Mdot
.54117 .63136 Mdot
.54117 .64705 Mdot
.53333 .64705 Mdot
.52941 .65489 Mdot
.51372 .64705 Mdot
.49804 .6196 Mdot
.50196 .61568 Mdot
.49804 .60391 Mdot
.50588 .61568 Mdot
.50588 .62352 Mdot
.49804 .62352 Mdot
.49804 .6392 Mdot
.48628 .62744 Mdot
.47451 .61176 Mdot
.47451 .59999 Mdot
.47059 .58823 Mdot
.47451 .59607 Mdot
.47451 .59999 Mdot
.46667 .60391 Mdot
.45883 .61176 Mdot
.44706 .59999 Mdot
.43922 .58823 Mdot
.43138 .57254 Mdot
.43138 .56862 Mdot
.42746 .56078 Mdot
.41569 .56078 Mdot
.41569 .5647 Mdot
.41177 .55294 Mdot
.38824 .53333 Mdot
.39609 .53333 Mdot
.38432 .50588 Mdot
.37256 .45883 Mdot
.40001 .52157 Mdot
.41177 .57254 Mdot
.4353 .60783 Mdot
.44706 .62352 Mdot
.45883 .63136 Mdot
.46667 .63528 Mdot
.46275 .6392 Mdot
.46275 .63528 Mdot
.47843 .64705 Mdot
.47059 .6392 Mdot
.47843 .64313 Mdot
.4902 .64313 Mdot
.48628 .6392 Mdot
.48628 .6392 Mdot
.49412 .6392 Mdot
.49804 .64313 Mdot
.49804 .65489 Mdot
.50196 .65881 Mdot
.50196 .65097 Mdot
.49804 .64313 Mdot
.50588 .64313 Mdot
.4902 .63136 Mdot
.49804 .63528 Mdot
.49412 .63528 Mdot
.5098 .64313 Mdot
.5098 .63136 Mdot
.52549 .63528 Mdot
.51765 .63136 Mdot
.52941 .65489 Mdot
.53333 .67057 Mdot
.53725 .68234 Mdot
.54117 .68234 Mdot
.54117 .67842 Mdot
.53725 .67057 Mdot
.54117 .67842 Mdot
.54117 .68234 Mdot
.55686 .70587 Mdot
.54509 .69802 Mdot
.54902 .69802 Mdot
.56078 .70194 Mdot
.54902 .67842 Mdot
.53333 .67057 Mdot
.55686 .68626 Mdot
.55686 .6941 Mdot
.55294 .69802 Mdot
.53725 .68234 Mdot
.53333 .68234 Mdot
.52941 .67842 Mdot
.53333 .6745 Mdot
.55294 .67057 Mdot
.56862 .6745 Mdot
.56078 .67057 Mdot
.56862 .6745 Mdot
.56862 .67057 Mdot
.56862 .6745 Mdot
.57254 .6745 Mdot
.56862 .66665 Mdot
.57646 .6745 Mdot
.57646 .6745 Mdot
.58431 .67842 Mdot
.57254 .68234 Mdot
.57254 .68626 Mdot
.58039 .6941 Mdot
.57646 .68626 Mdot
.57646 .68626 Mdot
.57646 .69018 Mdot
.56078 .68626 Mdot
.5647 .6941 Mdot
.56862 .69018 Mdot
.56862 .68234 Mdot
.56862 .67057 Mdot
.57254 .66665 Mdot
.57254 .66273 Mdot
.57646 .6745 Mdot
.57646 .68234 Mdot
.57646 .67842 Mdot
.58039 .6745 Mdot
.57254 .65881 Mdot
.58039 .66665 Mdot
.58039 .6745 Mdot
.58431 .68626 Mdot
.58039 .69018 Mdot
.58431 .6941 Mdot
.59215 .6941 Mdot
.58823 .68626 Mdot
.59215 .69018 Mdot
.59215 .69018 Mdot
.59215 .6941 Mdot
.58823 .69018 Mdot
.58039 .68234 Mdot
.58823 .6745 Mdot
.58431 .65881 Mdot
.58431 .65881 Mdot
.59607 .68626 Mdot
.59607 .69802 Mdot
.59607 .70194 Mdot
.59215 .69018 Mdot
.58431 .67842 Mdot
.58823 .67842 Mdot
.58431 .67057 Mdot
.58823 .66665 Mdot
.58431 .66665 Mdot
.58823 .66665 Mdot
.58039 .67057 Mdot
.58039 .68234 Mdot
.58039 .69018 Mdot
.58823 .70194 Mdot
.58431 .70194 Mdot
.57646 .69802 Mdot
.57646 .69802 Mdot
.58039 .69018 Mdot
.58039 .69018 Mdot
.57254 .68234 Mdot
.57254 .68234 Mdot
.56862 .67842 Mdot
.55686 .66665 Mdot
.55294 .66273 Mdot
.55686 .6745 Mdot
.55294 .66665 Mdot
.53725 .64705 Mdot
.54509 .65097 Mdot
.53725 .64705 Mdot
.54117 .65881 Mdot
.54117 .64705 Mdot
.54117 .6392 Mdot
.54902 .64313 Mdot
.54117 .63136 Mdot
.53725 .62352 Mdot
.54509 .62744 Mdot
.54509 .63528 Mdot
.53333 .63136 Mdot
.52549 .64313 Mdot
.52549 .65097 Mdot
.5098 .63136 Mdot
.50196 .62352 Mdot
.4902 .60391 Mdot
.4902 .59607 Mdot
.48628 .59607 Mdot
.49412 .60391 Mdot
.49412 .60783 Mdot
.48628 .59999 Mdot
.47451 .59999 Mdot
.46667 .59999 Mdot
.45883 .58823 Mdot
.46275 .59215 Mdot
.46667 .59607 Mdot
.45883 .59607 Mdot
.44706 .59607 Mdot
.43922 .59215 Mdot
.43922 .58823 Mdot
.43138 .57646 Mdot
.42354 .57254 Mdot
.42354 .58039 Mdot
.40785 .56078 Mdot
.40001 .54509 Mdot
.40001 .54509 Mdot
.39609 .54117 Mdot
.38824 .52157 Mdot
.3804 .50196 Mdot
.36864 .46275 Mdot
.41177 .5098 Mdot
.4353 .5647 Mdot
.45491 .59607 Mdot
.45883 .60391 Mdot
.46667 .61568 Mdot
.46667 .61568 Mdot
.46667 .63136 Mdot
.47059 .64313 Mdot
.48235 .65097 Mdot
.4902 .64705 Mdot
.49412 .6392 Mdot
.48628 .63136 Mdot
.48235 .62744 Mdot
.4902 .63136 Mdot
.48628 .62744 Mdot
.48628 .62744 Mdot
.49804 .64705 Mdot
.50196 .65097 Mdot
.5098 .64313 Mdot
.5098 .63528 Mdot
.50196 .6392 Mdot
.5098 .65097 Mdot
.51372 .65489 Mdot
.49804 .65097 Mdot
.51372 .65881 Mdot
.52549 .65097 Mdot
.53333 .64705 Mdot
.53333 .64705 Mdot
.53725 .65881 Mdot
.54902 .68234 Mdot
.55294 .6941 Mdot
.54117 .68234 Mdot
.54117 .67842 Mdot
.54117 .67057 Mdot
.54117 .67842 Mdot
.55294 .69018 Mdot
.5647 .70587 Mdot
.55686 .70587 Mdot
.54509 .68626 Mdot
.54509 .68626 Mdot
.54509 .6745 Mdot
.55686 .67057 Mdot
.54902 .66665 Mdot
.54902 .66273 Mdot
.54117 .67057 Mdot
.53333 .66273 Mdot
.51765 .65489 Mdot
.51765 .65097 Mdot
.51765 .63528 Mdot
.51765 .62352 Mdot
.53333 .6392 Mdot
.54509 .65097 Mdot
.54902 .65097 Mdot
.54509 .64705 Mdot
.53725 .64313 Mdot
.54902 .64313 Mdot
.55686 .64313 Mdot
.56078 .64313 Mdot
.5647 .65097 Mdot
.57254 .65881 Mdot
.58039 .6745 Mdot
.5647 .66273 Mdot
.57254 .67057 Mdot
.57254 .67057 Mdot
.58039 .67057 Mdot
.58039 .67057 Mdot
.57646 .67842 Mdot
.58039 .69018 Mdot
.5647 .6745 Mdot
.56862 .66273 Mdot
.57646 .66665 Mdot
.57646 .65489 Mdot
.58039 .65881 Mdot
.58431 .66665 Mdot
.59607 .67842 Mdot
.58431 .66665 Mdot
.58039 .65881 Mdot
.58823 .66273 Mdot
.58823 .66665 Mdot
.58823 .67057 Mdot
.59215 .68234 Mdot
.58431 .67842 Mdot
.58823 .69018 Mdot
.58039 .68234 Mdot
.58431 .68626 Mdot
.58823 .68626 Mdot
.59607 .69018 Mdot
.59999 .69802 Mdot
.60391 .69802 Mdot
.58823 .68234 Mdot
.58823 .6745 Mdot
.58823 .66273 Mdot
.58823 .65881 Mdot
.59607 .66665 Mdot
.59215 .67057 Mdot
.59215 .68234 Mdot
.58823 .67842 Mdot
.59215 .68234 Mdot
.58431 .67057 Mdot
.58823 .66665 Mdot
.58823 .67057 Mdot
.58823 .66665 Mdot
.58431 .67057 Mdot
.57254 .66665 Mdot
.57646 .6745 Mdot
.58039 .68234 Mdot
.57254 .6745 Mdot
.57254 .68234 Mdot
.58431 .69018 Mdot
.58431 .69018 Mdot
.57254 .67842 Mdot
.57646 .68234 Mdot
.57254 .67842 Mdot
.5647 .66273 Mdot
.56862 .66273 Mdot
.56862 .65097 Mdot
.5647 .64705 Mdot
.55294 .64705 Mdot
.54902 .64313 Mdot
.54509 .63528 Mdot
.54902 .63528 Mdot
.55294 .64313 Mdot
.52941 .63136 Mdot
.52941 .63528 Mdot
.53725 .6392 Mdot
.53725 .6392 Mdot
.53333 .63136 Mdot
.52941 .61568 Mdot
.53333 .61568 Mdot
.54509 .62352 Mdot
.53333 .6196 Mdot
.52549 .63136 Mdot
.51765 .6392 Mdot
.50196 .63528 Mdot
.49412 .62352 Mdot
.4902 .60391 Mdot
.4902 .59215 Mdot
.49412 .58823 Mdot
.49412 .59215 Mdot
.50196 .59999 Mdot
.4902 .59215 Mdot
.48628 .59999 Mdot
.48235 .60391 Mdot
.47451 .59999 Mdot
.47059 .58823 Mdot
.46667 .58039 Mdot
.45491 .57646 Mdot
.45098 .58431 Mdot
.44314 .59215 Mdot
.42746 .59215 Mdot
.41569 .58039 Mdot
.42354 .57646 Mdot
.42354 .56862 Mdot
.42354 .56078 Mdot
.40785 .54117 Mdot
.40785 .54117 Mdot
.40785 .53333 Mdot
.39609 .51372 Mdot
.37648 .48628 Mdot
.37256 .46275 Mdot
.41961 .5098 Mdot
.46275 .57646 Mdot
.47843 .60783 Mdot
.47843 .61568 Mdot
.48628 .6196 Mdot
.47843 .61176 Mdot
.47843 .6196 Mdot
.4902 .6392 Mdot
.4902 .64705 Mdot
.4902 .64313 Mdot
.49804 .63136 Mdot
.50588 .6196 Mdot
.49804 .61176 Mdot
.5098 .62744 Mdot
.5098 .63528 Mdot
.50196 .6392 Mdot
.49804 .64313 Mdot
.5098 .64313 Mdot
.5098 .63528 Mdot
.51765 .63136 Mdot
.51765 .62744 Mdot
.52549 .6392 Mdot
.52157 .65097 Mdot
.50588 .64705 Mdot
.50588 .64313 Mdot
.51765 .6392 Mdot
.52941 .63528 Mdot
.53725 .63528 Mdot
.54117 .64705 Mdot
.55294 .67057 Mdot
.54509 .68234 Mdot
.54509 .68234 Mdot
.54509 .68234 Mdot
.54117 .67057 Mdot
.54902 .67057 Mdot
.54902 .67057 Mdot
.56078 .68234 Mdot
.55294 .69018 Mdot
.54902 .67842 Mdot
.54509 .67057 Mdot
.55686 .66273 Mdot
.5647 .66273 Mdot
.55686 .65097 Mdot
.55294 .64705 Mdot
.54509 .65097 Mdot
.54117 .66273 Mdot
.53333 .66273 Mdot
.52157 .64313 Mdot
.51765 .6196 Mdot
.51765 .60783 Mdot
.52549 .61568 Mdot
.52157 .61568 Mdot
.52157 .62352 Mdot
.5098 .61568 Mdot
.49412 .59999 Mdot
.49804 .59999 Mdot
.49804 .58431 Mdot
.51372 .58823 Mdot
.52157 .59607 Mdot
.53333 .60783 Mdot
.54117 .6196 Mdot
.53333 .62352 Mdot
.54902 .63528 Mdot
.56078 .65097 Mdot
.57254 .65881 Mdot
.56862 .65489 Mdot
.58039 .66273 Mdot
.57646 .67057 Mdot
.56078 .66273 Mdot
.57254 .66665 Mdot
.57646 .65489 Mdot
.57646 .64705 Mdot
.58431 .65097 Mdot
.58823 .66273 Mdot
.59215 .6745 Mdot
.58823 .67842 Mdot
.57254 .65881 Mdot
.58431 .65881 Mdot
.59215 .65489 Mdot
.58823 .65489 Mdot
.58823 .66273 Mdot
.59215 .67842 Mdot
.58823 .68234 Mdot
.57646 .67842 Mdot
.56862 .67057 Mdot
.58431 .67842 Mdot
.59215 .68234 Mdot
.58823 .67057 Mdot
.58823 .67842 Mdot
.58039 .6745 Mdot
.58431 .67057 Mdot
.58431 .66273 Mdot
.58431 .66273 Mdot
.59607 .67057 Mdot
.59607 .66273 Mdot
.59215 .67057 Mdot
.58823 .67057 Mdot
.58431 .67057 Mdot
.58039 .66273 Mdot
.57646 .65489 Mdot
.59215 .66665 Mdot
.59215 .67057 Mdot
.59215 .68626 Mdot
.57254 .67057 Mdot
.56862 .65881 Mdot
.57254 .65489 Mdot
.57254 .65881 Mdot
.57646 .65881 Mdot
.58431 .66273 Mdot
.58039 .66665 Mdot
.57254 .67057 Mdot
.58431 .67842 Mdot
.57646 .65881 Mdot
.57254 .64705 Mdot
.56862 .64705 Mdot
.56078 .6392 Mdot
.56078 .6392 Mdot
.54902 .63136 Mdot
.54117 .62744 Mdot
.54902 .62744 Mdot
.54902 .62352 Mdot
.55686 .62744 Mdot
.55686 .63136 Mdot
.54902 .63528 Mdot
.54117 .6392 Mdot
.52549 .62352 Mdot
.53333 .63136 Mdot
.52941 .62352 Mdot
.53333 .62352 Mdot
.54117 .61568 Mdot
.53725 .61568 Mdot
.53333 .62352 Mdot
.52549 .63136 Mdot
.5098 .63136 Mdot
.49804 .6196 Mdot
.48235 .59215 Mdot
.4902 .58431 Mdot
.4902 .58431 Mdot
.4902 .58431 Mdot
.49804 .59607 Mdot
.49804 .60391 Mdot
.48628 .59999 Mdot
.47843 .58823 Mdot
.47451 .58431 Mdot
.47451 .57254 Mdot
.47843 .57254 Mdot
.47451 .57254 Mdot
.46275 .57254 Mdot
.45491 .58039 Mdot
.43922 .58039 Mdot
.41961 .57254 Mdot
.41569 .56078 Mdot
.41961 .54509 Mdot
.41177 .52549 Mdot
.41177 .52157 Mdot
.41569 .52157 Mdot
.40001 .50588 Mdot
.40393 .51372 Mdot
.39609 .4902 Mdot
.3608 .43922 Mdot
.41961 .5098 Mdot
.46667 .56862 Mdot
.46667 .58431 Mdot
.47059 .58823 Mdot
.47451 .58823 Mdot
.48235 .59607 Mdot
.48235 .59999 Mdot
.48628 .61176 Mdot
.4902 .6196 Mdot
.49804 .62352 Mdot
.50196 .62352 Mdot
.50196 .60391 Mdot
.50588 .60783 Mdot
.50588 .6196 Mdot
.51765 .63528 Mdot
.5098 .63136 Mdot
.5098 .63136 Mdot
.51372 .63136 Mdot
.51765 .61568 Mdot
.52157 .61568 Mdot
.51765 .61568 Mdot
.53333 .63528 Mdot
.52157 .63136 Mdot
.52549 .6392 Mdot
.52549 .63528 Mdot
.54117 .63136 Mdot
.54509 .63528 Mdot
.54509 .64313 Mdot
.54509 .65097 Mdot
.54902 .65881 Mdot
.54902 .65881 Mdot
.54902 .66273 Mdot
.54509 .65881 Mdot
.54509 .65881 Mdot
.54117 .65097 Mdot
.55294 .65489 Mdot
.56078 .65881 Mdot
.55294 .66665 Mdot
.55294 .6745 Mdot
.55686 .66665 Mdot
.56078 .66273 Mdot
.56078 .64705 Mdot
.56862 .64313 Mdot
.56078 .6392 Mdot
.5647 .65097 Mdot
.56078 .65881 Mdot
.56078 .65881 Mdot
.56078 .65881 Mdot
.55294 .64705 Mdot
.55686 .64313 Mdot
.54902 .63136 Mdot
.54509 .63528 Mdot
.52941 .62352 Mdot
.52549 .61568 Mdot
.5098 .59999 Mdot
.50196 .58039 Mdot
.49804 .56078 Mdot
.50196 .55686 Mdot
.50196 .56078 Mdot
.49412 .5647 Mdot
.48628 .5647 Mdot
.47059 .55686 Mdot
.47451 .56078 Mdot
.47451 .56078 Mdot
.47451 .56078 Mdot
.50588 .57646 Mdot
.52941 .58823 Mdot
.54509 .60783 Mdot
.55294 .61568 Mdot
.5647 .62744 Mdot
.57254 .62352 Mdot
.57646 .62352 Mdot
.57254 .63136 Mdot
.57646 .64705 Mdot
.56862 .64705 Mdot
.57646 .65097 Mdot
.5647 .6392 Mdot
.57646 .65097 Mdot
.57254 .63528 Mdot
.58039 .63136 Mdot
.58823 .6392 Mdot
.59607 .65097 Mdot
.58039 .64705 Mdot
.57254 .64705 Mdot
.58039 .65097 Mdot
.58431 .66273 Mdot
.58823 .66273 Mdot
.59607 .66273 Mdot
.58823 .66273 Mdot
.57646 .65489 Mdot
.57254 .65097 Mdot
.57254 .64705 Mdot
.58039 .64705 Mdot
.58039 .64313 Mdot
.57254 .63528 Mdot
.58823 .65097 Mdot
.58823 .65881 Mdot
.57646 .65489 Mdot
.58039 .65881 Mdot
.58431 .65881 Mdot
.58823 .65881 Mdot
.58039 .65489 Mdot
.58823 .67057 Mdot
.58039 .67057 Mdot
.56862 .65489 Mdot
.56862 .65097 Mdot
.58431 .65489 Mdot
.57646 .6392 Mdot
.58431 .6392 Mdot
.57254 .63528 Mdot
.58431 .64705 Mdot
.56862 .63528 Mdot
.56862 .62352 Mdot
.56862 .61568 Mdot
.56862 .61568 Mdot
.55686 .61176 Mdot
.54902 .60783 Mdot
.54902 .61568 Mdot
.54117 .61568 Mdot
.54117 .60783 Mdot
.53333 .59607 Mdot
.54509 .59215 Mdot
.55294 .59607 Mdot
.54509 .59999 Mdot
.54117 .61568 Mdot
.53725 .62744 Mdot
.52941 .61568 Mdot
.53725 .61568 Mdot
.54509 .61568 Mdot
.53725 .59999 Mdot
.53725 .59607 Mdot
.53725 .60783 Mdot
.51372 .59999 Mdot
.50588 .60391 Mdot
.50588 .61176 Mdot
.49412 .59607 Mdot
.48235 .58039 Mdot
.48628 .57254 Mdot
.4902 .57254 Mdot
.49412 .58039 Mdot
.49804 .58431 Mdot
.48628 .57646 Mdot
.47059 .55686 Mdot
.47451 .56078 Mdot
.47059 .55686 Mdot
.46667 .54509 Mdot
.46667 .54509 Mdot
.46275 .55294 Mdot
.44706 .55294 Mdot
.44706 .55686 Mdot
.42746 .54902 Mdot
.40785 .52941 Mdot
.40785 .51765 Mdot
.41177 .51372 Mdot
.41569 .50588 Mdot
.41569 .49412 Mdot
.40001 .48235 Mdot
.39609 .47843 Mdot
.39217 .46667 Mdot
.37648 .44314 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo000Ho`3o0?oooooo1oooool1o`00007ooooo000Io`3o0?oooooo
1_ooool1o`00007ooooo000Io`3o0?oooooo1_ooool1o`00007ooooo000Ko`3o0?oooooo1?ooool1
o`00007ooooo000Lo`3o0?oooooo0oooool1o`00007ooooo000Lo`3o0?oooooo0oooool1o`00007o
oooo000Oo`3o0?oooooo0Ol00001ooooo`008_l0o`3looooo`7o00000Oooool002?o0?l0noooool1
o`00007ooooo000To`3o0?[ooooo0Ol00001ooooo`001Ol0o`03o`00oago0?l0nOooool1o`00007o
oooo00001?l0003oooooo`3o0?l0o`05o`00oago0?l0n?ooool1o`00007ooooo00001?l0003ooooo
o`3o0?l0o`05o`00oago0?l0n?ooool1o`00007ooooo00001?l0003oooooooooool0o`05o`00oago
0?l0n?ooool1o`00007ooooo00001Ol0003ooooooooooooooooo0?l000?o003o8?l0o`3fooooo`7o
00000Oooool00003o`000?oooooooooo02Ko0?l0mOooool1o`00007ooooo00000ol0003ooooooooo
o`04o`3o00?o003o7ol0o`3eooooo`7o00000Oooool00003o`000?oooooooooo00?o0?l01Ol00?lN
o`3o0?Gooooo0Ol00001ooooo`0000Co0000oooooooooooooooo0_l0o`05o`00ob;o0?l0lOooool1
o`00007ooooo00001?l0003oooooooooooooool2o`3o00Go003o8ol0o`3`ooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo0_l0o`03o`00obCo0?l0l?ooool1o`00007ooooo00000ol0003o
ooooooooo`04ooooobko0?l0jOooool1o`00007ooooo00000ol0003oooooooooo`05oooooc;o0?l0
i?ooool1o`00007ooooo00000ol0003oooooooooo`07oooooc7o0?l0hoooool1o`00007ooooo0000
0ol0003oooooooooo`07ooooo`?o003o;_l0o`3Sooooo`7o00000Oooool00003o`000?oooooooooo
00Kooooo1_l00?l/o`3o0>?ooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool7o`00o`Oo
0?l00ol00?lRo`3o0>;ooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool7o`00o`Ko0?l0
1Ol00?l7o`3o00?o003o6?l0o`3Qooooo`7o00000Oooool00003o`000?oooooooooo00Oooooo1_l0
0?l6o`3o00Go003o1_l0o`05o`00oaOo0?l0hOooool1o`00007ooooo00000ol0003oooooooooo`09
ooooo`?o003o1ol0o`05o`00o`Ko0?l01Ol00?lGo`3o0>7ooooo0Ol00001ooooo`0000?o0000oooo
ooooool03Oooool7o`3o00Go003o1Ol0o`05o`00oaOo0?l0hOooool1o`00007ooooo00000ol0003o
ooooooooo`0=ooooo`So0?l01Ol00?l5o`3o00?o003o6Ol0o`3Pooooo`7o00000Oooool00003o`00
0?oooooooooo00gooooo1ol0o`06o`00ob;o0?l0goooool1o`00007ooooo00000ol0003ooooooooo
o`0=ooooo`Ko0?l01ol00?l3o`3o00?o003o7?l0o`3Oooooo`7o00000Oooool00003o`000?oooooo
oooo00kooooo1Ol0o`06o`00o`?o0?l01Ol00?lLo`3o0=kooooo0Ol00001ooooo`0000?o0000oooo
ooooool04?ooool3o`3o00Go003o1?l0o`05o`00oago0?l0gOooool1o`00007ooooo00000ol0003o
ooooooooo`0@ooooo`Co0?l00ol00?l3o`3o00Oo003o7Ol0o`3Mooooo`7o00000Oooool00003o`00
0?oooooooooo017ooooo2?l0o`08o`00oaoo0?l0foooool1o`00007ooooo00000ol0003ooooooooo
o`0Booooo`Oo0?l02?l00?lPo`3o0=[ooooo0Ol00001ooooo`0000?o0000ooooooooool04_ooool7
o`3o00So003o1ol0o`03o`00oaSo0?l0f?ooool1o`00007ooooo00000ol0003oooooooooo`0Coooo
o`Oo0?l01_l00?l7o`3o00Go003o6?l0o`3Gooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo0ol00?l00ooooooo0?l0o`3o000@o`3o00Go003o6Ol0o`3Fooooo`7o00000Oooool00003o`00
0?oooooooooo013ooooo1Ol00?lBo`3o00Go003o6Ol0o`3Fooooo`7o00000Oooool00003o`000?oo
oooooooo013ooooo1Ol00?l:o`3o00?o003o1_l0o`03o`00oa_o0?l0eOooool1o`00007ooooo0000
0ol0003oooooooooo`0@ooooo`Go003o2Ol0o`05o`00obKo0?l0d_ooool1o`00007ooooo00000ol0
003oooooooooo`0Aooooo`?o003o0_ooool8o`3o00[o003o2_l0o`03o`00oaGo0?l0dOooool1o`00
007ooooo00000ol0003oooooooooo`0Hooooo`Ko0?l02ol00?l8o`3o00Go003o5Ol0o`3@ooooo`7o
00000Oooool00003o`000?oooooooooo01Wooooo1_l0o`0:o`00o`So0?l01Ol00?lEo`3o0=3ooooo
0Ol00001ooooo`0000?o0000ooooooooool06oooool7o`3o00Oo003o2?l0o`05o`00oaOo0?l0c_oo
ool1o`00007ooooo00000ol0003oooooooooo`0Kooooo`So0?l02Ol00?l5o`3o00Go003o00Co0?l0
o`00ool00?oo003o5?l0o`3=ooooo`7o00000Oooool00003o`000?oooooooooo01cooooo0ol0o`03
o`00o`;o0?l02Ol00?l5o`3o00?o003o00?o0?l0o`00ool00?l00ol00?lCo`3o0<gooooo0Ol00001
ooooo`0000?o0000ooooooooool07Oooool00ol0o`3o003oo`00o`03o`00o`03o`3o0?l00?oo003o
00Oo003o2Ol0o`05o`00oa?o0?l0cOooool1o`00007ooooo00000ol0003oooooooooo`0Nooooo`Go
003o00?o0?l0o`00ool00?l02_l00?l6o`3o00Go003o4ol0o`3=ooooo`7o00000Oooool00003o`00
0?oooooooooo01kooooo1Ol00?l00ol0o`3o003oo`00o`0;o`00o`Ko0?l00ol00?l3o`3o00?o003o
3ol0o`3<ooooo`7o00000Oooool00003o`000?oooooooooo01oooooo0ol00?l3o`3o00?o003o0_l0
o`07o`00o`Wo0?l01ol00?l?o`3o0<_ooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool8
o`3o00[o003o2?l0o`08o`00oa3o0?l0b_ooool1o`00007ooooo00000ol0003oooooooooo`0Poooo
o`Ko0?l02_l00?l9o`3o00So003o4?l0o`3:ooooo`7o00000Oooool00003o`000?oooooooooo02;o
oooo1?l0o`05o`00o`[o0?l02ol00?lCo`3o0<Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
9Oooool00ol0o`3o003oo`00o`03o`00o`Wo0?l02Ol00?lGo`3o0<Oooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool2o`3o00Go003o1?l0o`03o`00o`03o`3o0?l00?oo003o00Co003o6ol0
o`36ooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo2?l00?l2o`3o00co003o6_l0o`36
ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo2Ol00?l2o`3o00go003o6_l0o`35oooo
o`7o00000Oooool00003o`000?oooooooooo02Cooooo2Ol00?l2o`3o00go003o7Ol0o`32ooooo`7o
00000Oooool00003o`000?oooooooooo02Cooooo2?l00?l3o`3o00go003o0_l0o`03o`00oaWo0?l0
`Oooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`Oo003o00?oooooo`3o0?l0o`000_l0
o`03o`00o`03o`3o0?l00?oo003o00Go003o0_l0o`05o`00oaSo0?l0`Oooool1o`00007ooooo0000
0ol0003oooooooooo`0Tooooo`Ko003o0_ooool8o`3o00Go003o1?l0o`05o`00oaSo0?l0`Oooool1
o`00007ooooo00000ol0003oooooooooo`0Uooooo`?o003o1Oooool8o`3o00?o003o1Ol0o`05o`00
oaSo0?l0`Oooool1o`00007ooooo00000ol0003oooooooooo`0/ooooo`_o0?l00ol00?l4o`3o00?o
003o6Ol0o`31ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo2_l0o`05o`00ob3o0?l0
`?ooool1o`00007ooooo00000ol0003oooooooooo`0/ooooo`Go0?l00ol00?l2o`3o00Go003o8Ol0
o`001?oooooo0?l0o`3o0?l0o`2kooooo`7o00000Oooool00003o`000?oooooooooo02gooooo0ol0
o`05o`00o`03o`3o0?l00?oo003o00?o003o3Ol0o`03o`00oaKo0?l0^_ooool1o`00007ooooo0000
0ol0003oooooooooo`0]ooooo`?o0?l01Ol00?l00ol0o`3o003oo`00o`02o`00o`go0?l01Ol00?lE
o`3o0;[ooooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool2o`3o00go003o2_l0o`09o`00
oa7o0?l0^_ooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`ko003o2Ol0o`0:o`00o`oo
0?l0^oooool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`oo003o00?o0?l0ooooool0o`00
1ol0o`09o`00o`go0?l0_Oooool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`oo003o3?l0
o`07o`00o`go0?l0_Oooool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`Go003o00Co0?l0
o`00ool00?oo003o0_l0o`03o`00o`go0?l01_l00?l=o`3o0;kooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool3o`00o`;ooooo1?l0o`03o`00o`oo0?l00ol00?lCo`3o0;[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0=Oooool8o`00obGo0?l0^Oooool1o`00007ooooo00000ol0003o
ooooooooo`0dooooo`Wo003o9Ol0o`2iooooo`7o00000Oooool00003o`000?oooooooooo03Cooooo
2_l00?lTo`3o0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool:o`00oaCo0?l00ol0
0?lBo`3o0;Cooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool3o`00o`03ooooool00?oo
003o00?o003o4ol0o`05o`00oa;o0?l0/oooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`04o`3o0?l00?oo003oo`00oaCo0?l01Ol00?lBo`3o0;?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0>Oooool5o`3o0003ooooool0o`3o0?l000Go003o2ol0o`05o`00oa;o0?l0/oooool1o`00
007ooooo00000ol0003oooooooooo`0jooooo`Ko0?l01ol00?l;o`3o00?o003o4_l0o`2dooooo`7o
00000Oooool00003o`000?oooooooooo03cooooo1?l0o`07o`00oaoo0?l0]Oooool1o`00007ooooo
00000ol0003oooooooooo`0looooo`Co0?l01ol00?lRo`3o0;;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0??ooool5o`3o00Go003o2ol0o`03o`00oaKo0?l0/Oooool1o`00007ooooo00000ol0
003oooooooooo`0mooooo`?o0?l000?oooooo`3o0?l0o`003Ol0o`05o`00o`04o`3o0?l00?oo003o
o`00oa7o0?l0/Oooool1o`00007ooooo00000ol0003oooooooooo`12ooooo`ko0?l02_l00?l@o`3o
0;7ooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool8o`3o00?o003o0_l0o`0:o`00oa7o
0?l0/?ooool1o`00007ooooo00000ol0003oooooooooo`14ooooo`Ko0?l01Ol00?l2o`3o00Wo003o
4Ol0o`2`ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo1?l0o`05o`00o`05o`3o0?l0
0?oo003oo`00ool0o`001Ol00?l<o`3o00?o003o0ol0o`02ooooo`?o0?l0Zoooool1o`00007ooooo
00000ol0003oooooooooo`18ooooo`;o0?l02_l00?l01?l0o`3o003oo`00ool00?l<o`3o00Go003o
2?l0o`2Zooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0_l0o`03o`00o`03o`3o0?l0
0?oo003o00?o003o0_l0o`03o`00o`04o`3o0?l00?oo003oo`00o`Oo0?l01Ol00?l8o`3o0:[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Boooool4o`3o00Go003o00?o0?l0o`00ool00?l01ol0
0?l5o`3o00Ko003o2?l0o`2Zooooo`7o00000Oooool00003o`000?oooooooooo04[ooooo1_l0o`03
o`00o`;o0?l02Ol00?l4o`3o00Ko003o2?l0o`2[ooooo`7o00000Oooool00003o`000?oooooooooo
04[ooooo2ol0o`09o`00o`Co0?l01Ol00?l=o`3o0:Oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0B_ooool<o`3o00?o003o00Co0?l0o`00ool00?oo003o1Ol0o`05o`00o`ko0?l0Y_ooool1o`00
007ooooo00000ol0003oooooooooo`1;ooooo`[o0?l01Ol00?l9o`3o00?o003o4?l0o`2Uooooo`7o
00000Oooool00003o`000?oooooooooo04cooooo2Ol0o`05o`00oago0?l0Y?ooool1o`00007ooooo
00000ol0003oooooooooo`1<ooooo`?o003o1_l0o`05o`00o`Co0?l00ol00?lFo`3o0004ooooool0
o`3o0?l0o`3o0:3ooooo0Ol00001ooooo`0000?o0000ooooooooool0Boooool7o`00o`Co0?l01Ol0
0?l2o`3o00Go003o6_l0o`2Oooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo2?l00?l4
o`3o00Go003o00?o0?l0o`00ool00?l00ol00?lDo`3o0003ooooool0o`3o0?l000?o0?l0Woooool1
o`00007ooooo00000ol0003oooooooooo`1;ooooo`So003o1?l0o`05o`00o`03o`3o0?l00?oo003o
00?o003o00Co0?l0o`00ool00?oo003o5_l0o`2Oooooo`7o00000Oooool00003o`000?oooooooooo
04cooooo1ol00?l4o`3o00Go003o0_l0o`03o`00o`03o`3o0?l00?oo003o00?o003o6Ol0o`2Koooo
o`7o00000Oooool00003o`000?oooooooooo04oooooo0ol00?l3o`3o00Ko003o1ol0o`05o`00oa[o
0?l0V_ooool1o`00007ooooo00000ol0003oooooooooo`1@ooooo`Co0?l01Ol00?l00ooooooo0?l0
o`3o0006o`3o00Go003o6_l0o`2Jooooo`7o00000Oooool00003o`000?oooooooooo053ooooo1?l0
o`05o`00o`;ooooo1ol0o`05o`00oa[o0?l0V_ooool1o`00007ooooo00000ol0003oooooooooo`1A
ooooo`?o0?l01Ol00?l6ooooo`?o0?l01Ol00?lIo`3o09_ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Doooool2o`3o00?o003o2_ooool01?l0o`3o003oo`00ool00?lHo`3o09gooooo0Ol00001
ooooo`0000?o0000ooooooooool0E?ooool3o`3o00cooooo6ol0o`2Mooooo`7o00000Oooool00003
o`000?oooooooooo06Gooooo6?l0o`2Nooooo`7o00000Oooool00003o`000?oooooooooo06Cooooo
0ol00?l4o`3o00?o003o3_l0o`06ooooo`?o0?l01Oooool3o`3o08kooooo0Ol00001ooooo`0000?o
0000ooooooooool0Hoooool5o`00o`;o0?l01Ol00?l=o`3o00Gooooo1Ol0o`03ooooo`Go0?l0SOoo
ool1o`00007ooooo00000ol0003oooooooooo`1Sooooo`Go003o0_l0o`05o`00oa3o0?l000?ooooo
o`3o0?l0o`001?l0o`02ooooo`Ko0?l0SOooool1o`00007ooooo00000ol0003oooooooooo`1Soooo
o`Go003o00?oooooo`00ool00?l01?l00?lGo`3o0003ooooool0o`3o0?l000Go0?l0SOooool1o`00
007ooooo00000ol0003oooooooooo`1Sooooo`Go003o00?o0?l0o`00ool00?l00ol00?l5o`3o00?o
003o3ol0o`02ooooo`Ko0?l0S_ooool1o`00007ooooo00000ol0003oooooooooo`1Sooooo`Go003o
00?o0?l0o`00ool00?l00ol00?l4o`3o00Go003o2Ol0o`001?oooooo0?l0o`3o0?l0o`03ooooo`Go
0?l0Soooool1o`00007ooooo00000ol0003oooooooooo`1Tooooo`?o003o0ol0o`03o`00o`Go0?l0
1Ol00?l?o`3o00;ooooo0ol0o`2@ooooo`7o00000Oooool00003o`000?oooooooooo06Gooooo1Ol0
o`001?oooooo0?l0o`3o0?l0o`09o`00oa3o0?l0U?ooool1o`00007ooooo00000ol0003ooooooooo
o`1Vooooo`?o0?l00oooool00ol0o`3o003oo`00o`07o`00o`Co0?l00ol00?l;o`3o00?o003oT?oo
ool1o`00007ooooo00000ol0003oooooooooo`1Sooooo`?o003o1_ooool:o`00o`?o0?l01Ol00?l9
o`3o00Go003o00?o0?l0ooooooooool0S?ooool1o`00007ooooo00000ol0003oooooooooo`1Roooo
o`So003o0_ooool;o`00o`;o0?l01Ol00?l9o`3o00Go003o0_l0o`2=ooooo`7o00000Oooool00003
o`000?oooooooooo06;ooooo2Ol00?l00ooooooo003oo`00o`09o`00o`;o0?l01Ol00?l9o`3o00Go
003o0_l0o`02ooooo`?o0?l0R?ooool1o`00007ooooo00000ol0003oooooooooo`1Rooooo`[o003o
00?oooooo`00ool00?l02?l00?l3o`3o00?o003o2ol0o`03o`00o`Wo0?l0Qoooool1o`00007ooooo
00000ol0003oooooooooo`1Sooooo`Wo003o0oooool7o`00oa7o0?l01Ol00?l8o`3o08Oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Ioooool5o`00o`;ooooo1Ol00?l00ooooooo0?l0o`3o000A
o`3o00Go003o2?l0o`27ooooo`7o00000Oooool00003o`000?oooooooooo06Kooooo1_l00?l2oooo
o`Go003o00?oooooo`3o0?l0o`004Ol0o`05o`00o`Oo0?l000Coooooo`3o0?l0o`3o0?l0Q?ooool1
o`00007ooooo00000ol0003oooooooooo`1Uooooo`Oo003o0_ooool6o`00o`03ooooool0o`3o0?l0
017o0?l00ol00?l4o`3o00Cooooo1Ol0o`23ooooo`7o00000Oooool00003o`000?oooooooooo06Co
oooo1ol00?l00ooooooo003oo`00o`08o`00o`Ko0?l00ol00?l>o`3o00;ooooo0ol0o`000ooooooo
0?l0o`3o0003o`3o08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0I?ooool6o`00o`03oooo
ool00?oo003o00[o003o1?l0o`05o`00oaSo0?l01Oooool3o`3o07_ooooo0Ol00001ooooo`0000?o
0000ooooooooool0I?oooolFo`00o`03o`3o0?l00?oo003o00?o003o5ol0o`05ooooo`Go0?l0N_oo
ool1o`00007ooooo00000ol0003oooooooooo`1Uoooooa_o003o0_l0o`03o`00oa7o0?l01_ooool5
o`3o07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0JOoooolMo`00oa3o0?l01_ooool5o`3o
0004ooooool0o`3o0?l0o`3o07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0IooooolOo`00
o`oo0?l000?oooooo`3o0?l0o`001?l0o`000ooooooo0?l0o`3o0007o`3o07Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0I_oooolPo`00ob3o0?l0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`1Voooooa[o003o00?o0?l0ooooool00?l00_l00?l<o`3o00?o003o4_l0o`1eooooo`7o0000
0Oooool00003o`000?oooooooooo06Kooooo1Ol00?l00ooooooo003oo`00o`0>o`00o`03o`3o0?oo
oooooooo00Cooooo3Ol0o`05o`00o`So0?l000Goooooo`3o0?l0o`3o0?l0ooooo`03o`3o07Kooooo
0Ol00001ooooo`0000?o0000ooooooooool0Ioooool3o`00o`;ooooo3ol00?l00ol0o`3ooooooooo
o`02ooooo`?o003o3Ol0o`05o`00o`Oo0?l0Ooooool1o`00007ooooo00000ol0003oooooooooo`1X
ooooo`?o003o00?oooooo`00ool00?l05ol00?l;o`3o00Go003o1Ol0o`21ooooo`7o00000Oooool0
0003o`000?oooooooooo06Oooooo7ol00?l;o`3o00?o003o2?l0o`1oooooo`7o00000Oooool00003
o`000?oooooooooo06Oooooo8_l00?lDo`3o07kooooo0Ol00001ooooo`0000?o0000ooooooooool0
IooooolSo`00oaGo0?l01?ooool3o`3o07Gooooo0Ol00001ooooo`0000?o0000ooooooooool0J?oo
oolTo`00oaCo0?l00_ooool5o`3o07Cooooo0Ol00001ooooo`0000?o0000ooooooooool0J_oooolT
o`00oaWo0?l0M?ooool1o`00007ooooo00000ol0003oooooooooo`1Yoooooaco003o00?oooooo`00
ool00?l01ol00?lHo`3o07Cooooo0Ol00001ooooo`0000?o0000ooooooooool0JOoooolMo`00o`03
ooooool00?oo003o00Wo003o5?l0o`04ooooo`?o0?l0K_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1Yooooob[o003o1_l0o`05ooooo`Go0?l01_ooool5o`3o06gooooo0Ol00001ooooo`0000?o
0000ooooooooool0J_oooolPo`00o`03ooooool00?oo003o00So003o1?l0o`05ooooo`Go0?l01_oo
ool5o`3o06gooooo0Ol00001ooooo`0000?o0000ooooooooool0J_oooolQo`00o`;o0?l02Ol00?l9
o`3o00?o003o0_l0o`05ooooo`Go0?l0KOooool1o`00007ooooo00000ol0003oooooooooo`1Yoooo
obgo003o2?l0o`05o`00o`?o0?l01?ooool3o`3o06kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0JOooool]o`00o`So0?l01Ol00?l4o`3o07Cooooo0Ol00001ooooo`0000?o0000ooooooooool0
JOooool/o`00o`Wo0?l01Ol00?l3o`3o00?o003oL_ooool1o`00007ooooo00000ol0003ooooooooo
o`1Zooooobco003o2?l0o`05o`00o`;o0?l01Ol00?l00ol0o`3oooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo06_ooooo:ol00?l7o`3o00Ko003o0_l0o`05o`00o`;o0?l0Koooool1
o`00007ooooo00000ol0003oooooooooo`1]ooooob_o003o1Ol0o`06o`00o`;o0?l01Ol00?l2o`3o
00;ooooo0ol0o`1Zooooo`7o00000Oooool00003o`000?oooooooooo073ooooo:Ol00?l00ol0o`3o
003oo`00o`06o`00o`Co0?l00ol00?l3o`3o0003ooooool0o`3o0?l000?o0?l0JOooool1o`00007o
oooo00000ol0003oooooooooo`1^oooooc?o003o00Co0?l0o`00ool00?oo003o1_l0o`000ooooooo
0?l0o`3o0004o`3o06Wooooo0Ol00001ooooo`0000?o0000ooooooooool0KOoooolbo`00o`;o0?l0
1ol00?l2o`3o00;ooooo1_l0o`1Yooooo`7o00000Oooool00003o`000?oooooooooo06gooooo<ol0
0?l00ol0o`3o003oo`00o`06o`00o`;o0?l000?oooooo`3o0?l0o`000ol0o`05ooooo`?o0?l0H_oo
ool1o`00007ooooo00000ol0003oooooooooo`1]oooooc?o003o00?o0?l0o`00ool00?l01_l00?l3
o`3o0004ooooool0o`3o0?l0o`3o00Gooooo1Ol0o`1Qooooo`7o00000Oooool00003o`000?oooooo
oooo06kooooo<_l00?l2o`3o00Oo003o0ol0o`09ooooo`Go0?l0HOooool1o`00007ooooo00000ol0
003oooooooooo`1`oooooc7o003o1?l0o`05o`00o`;o0?l02Oooool5o`3o067ooooo0Ol00001oooo
o`0000?o0000ooooooooool0LOoooolao`00o`Co0?l01Ol00?l;ooooo`?o0?l0H_ooool1o`00007o
oooo00000ol0003oooooooooo`1booooocWo003o1?l0o`1/ooooo`7o00000Oooool00003o`000?oo
oooooooo07?ooooo>?l00?l7o`3o06Wooooo0Ol00001ooooo`0000?o0000ooooooooool0Looooolg
o`00o`Wo0?l0J?ooool1o`00007ooooo00000ol0003oooooooooo`1cooooocSo003o1?l0o`03o`00
o`03o`3o0?oooooo0?l000;o0?l0I?ooool1o`00007ooooo00000ol0003oooooooooo`1dooooocSo
003o0_l0o`05o`00o`Go0?l01?l00?l<ooooo`?o003oD?ooool1o`00007ooooo00000ol0003ooooo
ooooo`1eooooocOo003o0_ooool5o`00o`Co0?l01_l00?l:ooooo`Go003oCoooool1o`00007ooooo
00000ol0003oooooooooo`1eooooocOo003o00?oooooo`3o0?l00?l01?l00?l4o`3o00Ko003o2_oo
ool5o`00odoooooo0Ol00001ooooo`0000?o0000ooooooooool0M?oooolgo`00o`04ooooool0o`3o
0?l0o`3o00?o003o1Ol0o`09o`00o`Oooooo1Ol00?m?ooooo`7o00000Oooool00003o`000?oooooo
oooo07?ooooo>?l00?l00ooooooo0?l0o`3o0006o`3o00Cooooo2Ol00?l7ooooo`?o003oD?ooool1
o`00007ooooo00000ol0003oooooooooo`1cooooocOo003o0_ooool6o`3o00Gooooo0ol00?l2oooo
o`Go003o2oooool3o`00odcooooo0Ol00001ooooo`0000?o0000ooooooooool0Looooolfo`00o`;o
oooo2?l0o`03ooooo`_o003o2_ooool7o`00odWooooo0Ol00001ooooo`0000?o0000ooooooooool0
M?oooolio`00o`Ko0?l00oooool:o`00o`_ooooo2?l00?m8ooooo`7o00000Oooool00003o`000?oo
oooooooo07Sooooo=_l00?l6o`3o00;ooooo2?l00?l2o`3o00;ooooo0ol00?l5ooooo`Wo003oB?oo
ool1o`00007ooooo00000ol0003oooooooooo`1gooooocOo003o0ol0o`03o`00o`?o0?l02Ol00?l0
0ooooooo003oo`00o`03o`00o`Cooooo2_l00?m7ooooo`7o00000Oooool00003o`000?oooooooooo
07OoooooCol00?l4ooooo`_o003oA_ooool1o`00007ooooo00000ol0003oooooooooo`1gooooodoo
003o0_ooool=o`00odKooooo0Ol00001ooooo`0000?o0000ooooooooool0Mooooom?o`00o`03oooo
ool00?oo003o00ko003oA?ooool1o`00007ooooo00000ol0003oooooooooo`1foooooe3o003o00?o
ooooo`00ool00?l03ol00?m3ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo??l00?l2
o`3o00?o003o00?oooooo`00ool00?l07_l00?m3ooooo`7o00000Oooool00003o`000?oooooooooo
07Kooooo@Ol00?l2ooooo`Ko003o0ooooolFo`00od?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Mooooom:o`00o`03ooooool00?oo003o01Co003o@oooool1o`00007ooooo00000ol0003ooooo
ooooo`1gooooof;o003o@_ooool1o`00007ooooo00000ol0003oooooooooo`1hooooof7o003o@_oo
ool1o`00007ooooo00000ol0003oooooooooo`1iooooof3o003o@_ooool1o`00007ooooo00000ol0
003oooooooooo`1jooooof;o003o?oooool1o`00007ooooo00000ol0003oooooooooo`1kooooof;o
003o?_ooool1o`00007ooooo00000ol0003oooooooooo`1looooof7o003o?_ooool1o`00007ooooo
00000ol0003oooooooooo`1mooooof3o003o?_ooool1o`00007ooooo00000ol0003oooooooooo`20
ooooo`Go003o00?oooooo`00ool00?l0E_l00?lmooooo`7o00000Oooool00003o`000?oooooooooo
083ooooo1Ol00?l3oooooeKo003o?Oooool1o`00007ooooo00000ol0003oooooooooo`20ooooo`Go
003o0ooooomFo`00ocgooooo0Ol00001ooooo`0000?o0000ooooooooool0POooool3o`00o`Gooooo
EOl00?lmooooo`7o00000Oooool00003o`000?oooooooooo08[oooooE?l00?lmooooo`7o00000Ooo
ool00003o`000?oooooooooo08coooooD_l00?lmooooo`7o00000Oooool00003o`000?oooooooooo
08coooooD_l00?lmooooo`7o00000Oooool00003o`000?oooooooooo08coooooD_l00?lmooooo`7o
00000Oooool00003o`000?oooooooooo08coooooD_l00?lmooooo`7o00000Oooool00003o`000?oo
oooooooo08goooooDOl00?lmooooo`7o00000Oooool00003o`000?oooooooooo093oooooC_l00?l0
0ol0o`3oooooooooo`0jooooo`7o00000Oooool00003o`000?oooooooooo09?oooooC?l00?l00ol0
o`3oooooooooo`0iooooo`7o00000Oooool00003o`000?oooooooooo09CoooooC?l00?lkooooo`7o
00000Oooool00003o`000?oooooooooo09OoooooBOl00?lkooooo`7o00000Oooool00003o`000?oo
oooooooo09SoooooB?l00?l3ooooo`?o003o=Oooool1o`00007ooooo00000ol0003oooooooooo`2I
ooooodKo003o0oooool5o`00ocCooooo0Ol00001ooooo`0000?o0000ooooooooool0V_oooom3o`00
o`Gooooo1Ol00?ldooooo`7o00000Oooool00003o`000?oooooooooo09_ooooo@_l00?l5ooooo`Go
003o=?ooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`?o003o00?oooooo`00ool00?l0
>ol00?l6ooooo`?o003o=Oooool1o`00007ooooo00000ol0003oooooooooo`2Qoooooc_o003o?ooo
ool1o`00007ooooo00000ol0003oooooooooo`2SooooocSo003o@?ooool1o`00007ooooo00000ol0
003oooooooooo`2TooooocOo003o1oooool3o`3o03Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Y_ooooldo`00o`Oooooo1?l0o`03o`00oc?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
Yooooolbo`00o`04o`3o0?l00?oo003oo`00o`Cooooo0ol0o`05o`00oc;ooooo0Ol00001ooooo`00
00?o0000ooooooooool0Yooooolho`00o`;ooooo0ol0o`05o`00oc;ooooo0Ol00001ooooo`0000?o
0000ooooooooool0Z?oooolho`00o`Co0?l01Ol00?lbooooo`7o00000Oooool00003o`000?oooooo
oooo0:[ooooo=_l00?l5o`3o00?o003o<oooool1o`00007ooooo00000ol0003oooooooooo`2^oooo
oc;o003o1ol0o`0dooooo`7o00000Oooool00003o`000?oooooooooo0;3ooooo7ol00?l2ooooo`Go
003o00Co0?l0o`00ool00?oo003o0_l0o`03o`00o`03ooooool00?oo003o00;o003o0_l0o`05oooo
o`?o0?l0;Oooool1o`00007ooooo00000ol0003oooooooooo`2boooooago003o0_ooool5o`00o`Ko
0?l02Ol00?l01Ooooooo0?l0o`3o0?l0o`3ooooo00Go0?l0;?ooool1o`00007ooooo00000ol0003o
ooooooooo`2boooooaKo003o0_ooool5o`00o`?ooooo0ol00?l2ooooo`;o0?l03?l00?l:o`3o02co
oooo0Ol00001ooooo`0000?o0000ooooooooool0/oooool8o`00o`04ooooool00?oo003oo`00o`;o
oooo1Ol00?l4ooooo`Go003o2Oooool=o`00o`[o0?l0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`2gooooo`?o003o4Oooool3o`00o`[ooooo3?l00?l6o`3o0003ooooool0o`3o0?l000?o003o
:oooool1o`00007ooooo00000ol0003oooooooooo`3Hooooo`co003o1Ol0o`03ooooo`Go003o:_oo
ool1o`00007ooooo00000ol0003oooooooooo`3Iooooo`[o003o1Ol0o`04ooooo`Go003o:_ooool1
o`00007ooooo00000ol0003oooooooooo`3Kooooo`Oo003o00?oooooo`3o0?l0o`000ol0o`02oooo
o`Oo003o0_ooool3o`00obGooooo0Ol00001ooooo`0000?o0000ooooooooool0f?ooool3o`3o0003
ooooool00?oo003o00Co003o1_l0o`000ooooooo003oo`00o`05o`00o`;ooooo1Ol00?lTooooo`7o
00000Oooool00003o`000?oooooooooo0=Oooooo0_l0o`03o`00o`;ooooo1_l00?l3o`3o00[o003o
00?o0?l0o`00ool00?l00ol00?lTooooo`7o00000Oooool00003o`000?oooooooooo0=Oooooo00?o
0?l0o`00ool00?l00ol00?l3oooooa7o003o00?o0?l0o`00ool00?l00ol00?lTooooo`7o00000Ooo
ool00003o`000?oooooooooo0=Oooooo00?o0?l0o`00ool00?l00ol00?l3oooooa7o003o00?o0?l0
o`00ool00?l00ol00?lTooooo`7o00000Oooool00003o`000?oooooooooo0=Sooooo1Ol00?l3oooo
oaSo003o8oooool1o`00007ooooo00000ol0003oooooooooo`3Iooooo`?o003o1Oooool?o`00o`03
ooooool00?oo003o00Go003o8oooool1o`00007ooooo00000ol0003oooooooooo`3Sooooo`_o003o
0oooool7o`00ob?ooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool:o`00o`Cooooo1Ol0
0?lTooooo`7o00000Oooool00003o`000?oooooooooo0>Gooooo3?l00?l2ooooo`?o003o9Oooool1
o`00007ooooo00000ol0003oooooooooo`3Vooooo`co003o:Oooool1o`00007ooooo00000ol0003o
ooooooooo`3Zooooo`So003o:Oooool1o`00007ooooo00000ol0003oooooooooo`3[ooooo`Oo003o
00Co0?l0oooooooooooooooo0ol0o`0Rooooo`7o00000Oooool00003o`000?oooooooooo0>_ooooo
1_l00?l2o`3o00?o003o1?l0o`0Qooooo`7o00000Oooool00003o`000?oooooooooo0>_ooooo1_l0
0?l00ol0o`3o003oo`00o`03o`00o`?o0?l08Oooool1o`00007ooooo00000ol0003oooooooooo`3/
ooooo`Co003o0_l0o`05o`00o`?o0?l08Oooool1o`00007ooooo00000ol0003oooooooooo`3boooo
o`Go003o0_l0o`0Rooooo`7o00000Oooool00003o`000?oooooooooo0??ooooo0ol00?l3o`3o02;o
oooo0Ol00001ooooo`0000?o0000ooooooooool0m?ooool5o`3o00?o003o7oooool1o`00007ooooo
00000ol0003oooooooooo`3cooooo`Go0?l01Ol00?lNooooo`7o00000Oooool00003o`000?oooooo
oooo0?;ooooo1Ol0o`06o`00oakooooo0Ol00001ooooo`0000?o0000ooooooooool0l_ooool4o`3o
00Oo003o00Coooooo`00ool00?oo003o6_ooool1o`00007ooooo00000ol0003oooooooooo`3boooo
o`Co0?l01_l00?l00ooooooo003oo`00o`03o`00oaWooooo0Ol00001ooooo`0000?o0000oooooooo
ool0loooool3o`3o00Ko003o00?oooooo`00ool00?l00ol00?lIooooo`7o00000Oooool00003o`00
0?oooooooooo0?Gooooo0_l0o`05o`00o`03o`3o0?l00?oo003o00?o003o0ol0o`0Fooooo`7o0000
0Oooool00003o`000?oooooooooo0?Oooooo1Ol00?l00ol0o`3o003oo`00o`04o`00o`?o0?l05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`3fooooo`;o0?l00ol00?l00ol0o`3o003oo`00o`06
o`00o`;o0?l05Oooool1o`00007ooooo00000ol0003oooooooooo`3fooooo`;o0?l00ol00?l00ol0
o`3o003oo`00o`06o`00o`;o0?l05Oooool1o`00007ooooo00000ol0003oooooooooo`3fooooo`03
o`3o0?l00?oo003o00co003o00?o0?l0ooooool00?l00_l00?lAooooo`7o00000Oooool00003o`00
0?oooooooooo0?Oooooo5?l00?l@ooooo`7o00000Oooool00003o`000?oooooooooo0?Oooooo2?l0
0?l2o`3o00[o003o4?ooool1o`00007ooooo00000ol0003oooooooooo`3hooooo`Oo003o00?ooooo
o`3o0?l00?l02_l00?l?ooooo`7o00000Oooool00003o`000?oooooooooo0?[ooooo1Ol00?l2oooo
o`03o`3o0?l00?oo003o00So003o3oooool1o`00007ooooo00000ol0003oooooooooo`3kooooo`?o
003o0oooool;o`00o`oooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool2ooooo`Go003o
0_l0o`03o`00oa3ooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool2ooooo`Go003o00?o
0?l0ooooooooool04_ooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`?ooooo0ol00?lF
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003o
o`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.122445, -0.122445, 0.889355, \
0.889355}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["GB plane", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[\({#[\([2]\)], #[\([3]\)]} &\)\  /@ \ d1\  // N, pr, 
          style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[\({#[\([2]\)], #[\([3]\)]} &\)\  /@ \ d2\  // N, pr, 
          style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(distGB\  = \ 
        Show[gd1, gd2, \ FrameTicks \[Rule] None, yS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 0 r
.02 w
.06278 .03141 Mdot
.05886 .02749 Mdot
.05886 .03533 Mdot
.06278 .04317 Mdot
.06278 .05102 Mdot
.0667 .05494 Mdot
.0667 .05102 Mdot
.07454 .05102 Mdot
.07454 .04709 Mdot
.07846 .05102 Mdot
.07454 .05494 Mdot
.07062 .05102 Mdot
.07454 .04709 Mdot
.07846 .04709 Mdot
.07062 .04317 Mdot
.07062 .05102 Mdot
.07454 .04709 Mdot
.07846 .05102 Mdot
.08239 .05102 Mdot
.07062 .04317 Mdot
.07062 .04317 Mdot
.07062 .04317 Mdot
.06278 .03925 Mdot
.06278 .04317 Mdot
.07454 .05102 Mdot
.07846 .05886 Mdot
.07454 .05886 Mdot
.07062 .05886 Mdot
.07846 .05886 Mdot
.07846 .05886 Mdot
.07846 .05886 Mdot
.07846 .05494 Mdot
.07846 .05102 Mdot
.07454 .04709 Mdot
.08631 .05886 Mdot
.09023 .06278 Mdot
.09023 .06278 Mdot
.08631 .05494 Mdot
.08631 .05102 Mdot
.09415 .05886 Mdot
.08631 .05494 Mdot
.08239 .05102 Mdot
.07846 .05494 Mdot
.08631 .0667 Mdot
.09023 .06278 Mdot
.08631 .05886 Mdot
.08239 .05102 Mdot
.07846 .04709 Mdot
.08239 .05102 Mdot
.08239 .05102 Mdot
.09023 .05886 Mdot
.09023 .05886 Mdot
.08631 .06278 Mdot
.09415 .07846 Mdot
.09023 .07454 Mdot
.09807 .08239 Mdot
.09807 .07846 Mdot
.09023 .07454 Mdot
.08239 .07062 Mdot
.08631 .07062 Mdot
.08631 .07062 Mdot
.07846 .06278 Mdot
.07846 .05494 Mdot
.08239 .05102 Mdot
.08239 .05102 Mdot
.07454 .04709 Mdot
.08239 .05494 Mdot
.08631 .06278 Mdot
.09023 .0667 Mdot
.09023 .07454 Mdot
.09023 .07454 Mdot
.09807 .07846 Mdot
.09807 .07846 Mdot
.08239 .06278 Mdot
.08239 .0667 Mdot
.07454 .06278 Mdot
.07846 .0667 Mdot
.09023 .07454 Mdot
.09807 .07454 Mdot
.09807 .0667 Mdot
.09023 .05886 Mdot
.09415 .07062 Mdot
.09415 .0667 Mdot
.09415 .0667 Mdot
.09415 .07062 Mdot
.09415 .0667 Mdot
.09807 .0667 Mdot
.08239 .05494 Mdot
.08631 .05886 Mdot
.08631 .0667 Mdot
.08239 .06278 Mdot
.08631 .06278 Mdot
.08631 .06278 Mdot
.08631 .07062 Mdot
.08631 .07062 Mdot
.09023 .07846 Mdot
.08239 .07454 Mdot
.08239 .07454 Mdot
.07846 .0667 Mdot
.07062 .06278 Mdot
.08239 .0667 Mdot
.07846 .05886 Mdot
.07454 .05102 Mdot
.07454 .05494 Mdot
.07062 .04709 Mdot
.07454 .05102 Mdot
.0667 .05102 Mdot
.07062 .05886 Mdot
.07454 .05102 Mdot
.07062 .05102 Mdot
.07454 .05886 Mdot
.07454 .05886 Mdot
.07062 .05494 Mdot
.0667 .05102 Mdot
.07062 .05886 Mdot
.0667 .05494 Mdot
.05886 .04709 Mdot
.04709 .03533 Mdot
.05494 .03533 Mdot
.05494 .03925 Mdot
.05886 .03925 Mdot
.0667 .03925 Mdot
.07454 .04709 Mdot
.07062 .04709 Mdot
.06278 .04317 Mdot
.05886 .03533 Mdot
.05102 .02749 Mdot
.05102 .02357 Mdot
.05494 .03141 Mdot
.05102 .03141 Mdot
.04317 .02357 Mdot
.03925 .02749 Mdot
.05886 .04317 Mdot
.05494 .05102 Mdot
.05494 .0667 Mdot
.04709 .0667 Mdot
.04317 .0667 Mdot
.03533 .05494 Mdot
.03925 .03925 Mdot
.05102 .03925 Mdot
.03925 .03925 Mdot
.04317 .04317 Mdot
.04709 .05102 Mdot
.05886 .07062 Mdot
.00788 .02749 Mdot
.00788 .01572 Mdot
.00788 .0118 Mdot
.00788 .01572 Mdot
.00396 .02357 Mdot
.00396 .02749 Mdot
.00396 .03141 Mdot
.00788 .03141 Mdot
.00788 .02357 Mdot
.00788 .01965 Mdot
.00396 .02357 Mdot
.00396 .01965 Mdot
.00396 .01572 Mdot
.00788 .01572 Mdot
.00788 .01572 Mdot
.00788 .0118 Mdot
.09807 .08631 Mdot
.1216 .10591 Mdot
.12944 .11768 Mdot
.12944 .1216 Mdot
.1216 .12944 Mdot
.13336 .14513 Mdot
.1412 .12944 Mdot
.13728 .10983 Mdot
.12552 .09023 Mdot
.1216 .08239 Mdot
.12944 .07846 Mdot
.1412 .08239 Mdot
.14513 .08631 Mdot
.1412 .08239 Mdot
.13728 .07846 Mdot
.12944 .07454 Mdot
.13336 .07846 Mdot
.12552 .07846 Mdot
.13336 .07846 Mdot
.1412 .08239 Mdot
.1412 .08631 Mdot
.1412 .08239 Mdot
.1216 .07454 Mdot
.12944 .08239 Mdot
.12944 .07846 Mdot
.12944 .07846 Mdot
.12944 .08239 Mdot
.13728 .09415 Mdot
.1412 .10199 Mdot
.1412 .10983 Mdot
.13728 .10591 Mdot
.14513 .10591 Mdot
.14905 .10199 Mdot
.15297 .09807 Mdot
.14905 .09807 Mdot
.1412 .09807 Mdot
.14905 .10199 Mdot
.16473 .10591 Mdot
.17257 .10199 Mdot
.1765 .10983 Mdot
.16865 .10199 Mdot
.16473 .10591 Mdot
.14905 .09807 Mdot
.15297 .10591 Mdot
.16473 .10983 Mdot
.16473 .10199 Mdot
.15689 .10199 Mdot
.16865 .10591 Mdot
.17257 .10983 Mdot
.1765 .10983 Mdot
.18434 .11768 Mdot
.17257 .11768 Mdot
.16865 .12944 Mdot
.15297 .1216 Mdot
.16081 .1216 Mdot
.17257 .12944 Mdot
.16865 .11376 Mdot
.18434 .1216 Mdot
.18042 .11376 Mdot
.1765 .11376 Mdot
.18434 .1216 Mdot
.16865 .11768 Mdot
.17257 .1216 Mdot
.16865 .11376 Mdot
.16865 .10983 Mdot
.16865 .10591 Mdot
.1765 .10983 Mdot
.17257 .11376 Mdot
.1765 .11768 Mdot
.18042 .12944 Mdot
.16473 .11376 Mdot
.16865 .10591 Mdot
.1765 .10983 Mdot
.17257 .10983 Mdot
.18434 .11768 Mdot
.17257 .10983 Mdot
.16865 .10983 Mdot
.1961 .12552 Mdot
.17257 .10591 Mdot
.1765 .10199 Mdot
.18434 .11376 Mdot
.19218 .12944 Mdot
.16081 .09807 Mdot
.18042 .11376 Mdot
.16473 .10983 Mdot
.17257 .11768 Mdot
.18042 .1216 Mdot
.19218 .12552 Mdot
.19218 .12944 Mdot
.18434 .12552 Mdot
.18434 .13336 Mdot
.18434 .12944 Mdot
.19218 .14513 Mdot
.1765 .12944 Mdot
.16865 .11376 Mdot
.16473 .10199 Mdot
.17257 .10591 Mdot
.17257 .10983 Mdot
.1765 .11376 Mdot
.18434 .11376 Mdot
.18434 .11376 Mdot
.18042 .11768 Mdot
.16865 .1216 Mdot
.16473 .1216 Mdot
.1765 .12552 Mdot
.1765 .13728 Mdot
.14513 .11768 Mdot
.1412 .10983 Mdot
.13728 .09415 Mdot
.12944 .09023 Mdot
.13336 .09415 Mdot
.1412 .10199 Mdot
.12944 .10591 Mdot
.13336 .10591 Mdot
.13728 .10591 Mdot
.13728 .09807 Mdot
.12552 .08631 Mdot
.11376 .07062 Mdot
.15297 .09415 Mdot
.13728 .08631 Mdot
.1412 .08631 Mdot
.14513 .08631 Mdot
.1412 .07846 Mdot
.12552 .07062 Mdot
.12552 .0667 Mdot
.12552 .0667 Mdot
.12552 .0667 Mdot
.11768 .06278 Mdot
.11376 .0667 Mdot
.11768 .07062 Mdot
.10983 .0667 Mdot
.11768 .07062 Mdot
.1216 .07454 Mdot
.11768 .08239 Mdot
.1216 .08631 Mdot
.15297 .12944 Mdot
.05494 .08631 Mdot
.04709 .07454 Mdot
.05102 .05102 Mdot
.04317 .03141 Mdot
.04317 .02749 Mdot
.10199 .06278 Mdot
.0667 .04317 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.01572 .00396 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.00788 .0118 Mdot
.00788 .01572 Mdot
.00788 .01572 Mdot
.01572 .01572 Mdot
.01572 .0118 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.01572 .00396 Mdot
.01572 .00396 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.68234 .59607 Mdot
.70587 .62352 Mdot
.72547 .63528 Mdot
.72939 .63136 Mdot
.56862 .49804 Mdot
.1412 .16865 Mdot
.10591 .1216 Mdot
.11376 .10591 Mdot
.07846 .0667 Mdot
.07062 .04709 Mdot
.07062 .03533 Mdot
.09415 .04317 Mdot
.10983 .05494 Mdot
.11376 .05494 Mdot
.11768 .05886 Mdot
.11376 .05494 Mdot
.1216 .05886 Mdot
.1216 .05886 Mdot
.12552 .05886 Mdot
.12552 .06278 Mdot
.11376 .06278 Mdot
.12552 .07454 Mdot
.12552 .07846 Mdot
.13336 .08631 Mdot
.13728 .09023 Mdot
.13728 .09023 Mdot
.14513 .10199 Mdot
.13728 .09807 Mdot
.13728 .09807 Mdot
.1412 .10591 Mdot
.1412 .10591 Mdot
.14513 .10591 Mdot
.14513 .09807 Mdot
.15297 .09415 Mdot
.14513 .09023 Mdot
.13336 .08239 Mdot
.14513 .09023 Mdot
.1412 .08239 Mdot
.14905 .07846 Mdot
.15297 .08631 Mdot
.15297 .09415 Mdot
.15297 .09415 Mdot
.1412 .08631 Mdot
.14905 .09415 Mdot
.14905 .09807 Mdot
.12944 .07846 Mdot
.13336 .08239 Mdot
.1412 .08631 Mdot
.15689 .09807 Mdot
.15297 .09807 Mdot
.16473 .10199 Mdot
.16473 .11768 Mdot
.16081 .12944 Mdot
.14905 .12552 Mdot
.16081 .13336 Mdot
.16473 .12552 Mdot
.16865 .11376 Mdot
.1765 .10983 Mdot
.18042 .10591 Mdot
.18042 .09807 Mdot
.1765 .09807 Mdot
.18042 .1216 Mdot
.16473 .1216 Mdot
.17257 .11768 Mdot
.1765 .11376 Mdot
.18042 .11376 Mdot
.17257 .10591 Mdot
.18826 .11376 Mdot
.18434 .11376 Mdot
.1765 .11376 Mdot
.1765 .11376 Mdot
.18042 .11376 Mdot
.18434 .11376 Mdot
.18434 .10591 Mdot
.18826 .11768 Mdot
.16865 .10199 Mdot
.1765 .10199 Mdot
.18042 .09807 Mdot
.18826 .10199 Mdot
.18434 .09807 Mdot
.18042 .09415 Mdot
.17257 .09807 Mdot
.16473 .09023 Mdot
.16865 .09807 Mdot
.16865 .10591 Mdot
.15689 .10199 Mdot
.16081 .10591 Mdot
.16473 .11768 Mdot
.18042 .13336 Mdot
.18434 .13336 Mdot
.19218 .13336 Mdot
.1961 .13728 Mdot
.19218 .13728 Mdot
.18434 .12552 Mdot
.18826 .12552 Mdot
.1961 .12552 Mdot
.1961 .11768 Mdot
.21179 .12944 Mdot
.21179 .13728 Mdot
.20787 .13728 Mdot
.1961 .13336 Mdot
.21179 .14905 Mdot
.20787 .15689 Mdot
.1961 .1412 Mdot
.20394 .14513 Mdot
.1961 .14905 Mdot
.18434 .14513 Mdot
.18042 .13728 Mdot
.16865 .12552 Mdot
.18434 .13336 Mdot
.18042 .13336 Mdot
.18826 .1412 Mdot
.18434 .14513 Mdot
.16865 .12552 Mdot
.16473 .11768 Mdot
.15689 .10983 Mdot
.14905 .10199 Mdot
.16081 .10983 Mdot
.16081 .10199 Mdot
.15297 .09023 Mdot
.15297 .08239 Mdot
.16081 .09415 Mdot
.15689 .09023 Mdot
.16473 .09023 Mdot
.15689 .08631 Mdot
.14905 .08239 Mdot
.16081 .09415 Mdot
.15689 .09415 Mdot
.14905 .09023 Mdot
.15689 .09807 Mdot
.13728 .08631 Mdot
.1412 .08631 Mdot
.1412 .08239 Mdot
.1412 .07846 Mdot
.1216 .05886 Mdot
.13336 .06278 Mdot
.12552 .05102 Mdot
.10591 .04709 Mdot
.10983 .07062 Mdot
.10591 .07846 Mdot
.09807 .07846 Mdot
.11768 .08239 Mdot
.1216 .07846 Mdot
.10591 .05102 Mdot
.09807 .04709 Mdot
.09807 .05494 Mdot
.08631 .05102 Mdot
.08239 .05102 Mdot
.10199 .05886 Mdot
.10591 .06278 Mdot
.10591 .07062 Mdot
.09023 .0667 Mdot
.09807 .07062 Mdot
.09023 .06278 Mdot
.09415 .07454 Mdot
.09415 .07846 Mdot
.10199 .07454 Mdot
.10983 .07062 Mdot
.10199 .0667 Mdot
.10199 .07062 Mdot
.68234 .61176 Mdot
.71763 .64705 Mdot
.73332 .64705 Mdot
.72547 .63136 Mdot
.69802 .60391 Mdot
.29413 .28629 Mdot
.07846 .09415 Mdot
.11768 .10591 Mdot
.10199 .09023 Mdot
.09023 .07062 Mdot
.10199 .06278 Mdot
.10983 .05494 Mdot
.12552 .05886 Mdot
.12944 .05494 Mdot
.1216 .05494 Mdot
.11768 .05494 Mdot
.12944 .05886 Mdot
.1412 .07062 Mdot
.13728 .0667 Mdot
.13336 .0667 Mdot
.12944 .07846 Mdot
.1216 .08239 Mdot
.12944 .09807 Mdot
.13336 .10591 Mdot
.13728 .10591 Mdot
.1412 .10591 Mdot
.1412 .10983 Mdot
.12552 .09415 Mdot
.1412 .10199 Mdot
.14513 .10591 Mdot
.14905 .10591 Mdot
.15297 .10199 Mdot
.14905 .09415 Mdot
.15297 .09415 Mdot
.14513 .08239 Mdot
.14905 .08631 Mdot
.16473 .10199 Mdot
.16865 .09807 Mdot
.16081 .09023 Mdot
.16081 .09023 Mdot
.16473 .09023 Mdot
.16473 .09415 Mdot
.16081 .09023 Mdot
.14905 .09415 Mdot
.15297 .09807 Mdot
.14905 .09415 Mdot
.1412 .09023 Mdot
.15297 .09807 Mdot
.14905 .10591 Mdot
.15689 .10199 Mdot
.16473 .10591 Mdot
.1765 .12944 Mdot
.16865 .13336 Mdot
.15689 .12552 Mdot
.15689 .11768 Mdot
.17257 .11768 Mdot
.18042 .10591 Mdot
.18042 .09415 Mdot
.18826 .09415 Mdot
.1765 .09023 Mdot
.18826 .10591 Mdot
.20394 .13336 Mdot
.18826 .12944 Mdot
.18042 .12944 Mdot
.1961 .1412 Mdot
.19218 .13336 Mdot
.18826 .12552 Mdot
.18826 .12552 Mdot
.16473 .11376 Mdot
.15297 .10983 Mdot
.16081 .10983 Mdot
.16865 .10983 Mdot
.22355 .13728 Mdot
.20002 .11768 Mdot
.18434 .10199 Mdot
.1765 .10199 Mdot
.18042 .09415 Mdot
.18434 .09807 Mdot
.1765 .09023 Mdot
.1765 .09023 Mdot
.1765 .09415 Mdot
.18042 .10199 Mdot
.16865 .09023 Mdot
.15689 .09023 Mdot
.16081 .10591 Mdot
.16081 .11376 Mdot
.15689 .11376 Mdot
.16081 .12944 Mdot
.16081 .12944 Mdot
.18042 .1412 Mdot
.18826 .14513 Mdot
.1961 .14513 Mdot
.1961 .13728 Mdot
.1961 .12944 Mdot
.18042 .10983 Mdot
.19218 .10983 Mdot
.20002 .10983 Mdot
.20002 .11376 Mdot
.20394 .11768 Mdot
.20787 .1216 Mdot
.19218 .11768 Mdot
.20394 .13336 Mdot
.20394 .13728 Mdot
.1961 .12944 Mdot
.1961 .13728 Mdot
.20787 .14905 Mdot
.20394 .14513 Mdot
.18826 .13728 Mdot
.18434 .14513 Mdot
.18434 .14513 Mdot
.18434 .13728 Mdot
.19218 .13728 Mdot
.19218 .13728 Mdot
.18042 .12944 Mdot
.17257 .10983 Mdot
.16865 .10591 Mdot
.16081 .10591 Mdot
.16081 .10199 Mdot
.16865 .10199 Mdot
.17257 .10199 Mdot
.16865 .10199 Mdot
.16473 .10199 Mdot
.16081 .10199 Mdot
.14905 .09415 Mdot
.15297 .09415 Mdot
.16081 .10591 Mdot
.15297 .10591 Mdot
.1412 .10591 Mdot
.1412 .10199 Mdot
.14513 .10199 Mdot
.1412 .09807 Mdot
.1412 .09023 Mdot
.1412 .09023 Mdot
.14905 .09415 Mdot
.14905 .09023 Mdot
.14513 .09023 Mdot
.14905 .09415 Mdot
.13336 .08239 Mdot
.11376 .07062 Mdot
.1216 .08239 Mdot
.10983 .08239 Mdot
.10591 .07846 Mdot
.09807 .07062 Mdot
.10591 .06278 Mdot
.10983 .06278 Mdot
.10591 .0667 Mdot
.09415 .05494 Mdot
.10199 .06278 Mdot
.10199 .07062 Mdot
.10199 .07846 Mdot
.09807 .08239 Mdot
.09023 .08239 Mdot
.09023 .07846 Mdot
.09415 .08239 Mdot
.10199 .08631 Mdot
.09807 .08239 Mdot
.10591 .08239 Mdot
.11376 .08631 Mdot
.10983 .08239 Mdot
.09807 .07062 Mdot
.67842 .60783 Mdot
.73332 .65881 Mdot
.75292 .66273 Mdot
.72939 .63528 Mdot
.72547 .62744 Mdot
.50588 .44706 Mdot
.1412 .15297 Mdot
.12944 .12552 Mdot
.10591 .09415 Mdot
.09415 .07454 Mdot
.09807 .0667 Mdot
.10591 .06278 Mdot
.11376 .06278 Mdot
.12944 .0667 Mdot
.1412 .07062 Mdot
.1412 .08239 Mdot
.12944 .07454 Mdot
.1412 .08631 Mdot
.14513 .08631 Mdot
.13728 .08631 Mdot
.13728 .09807 Mdot
.13728 .10983 Mdot
.13336 .10983 Mdot
.12552 .10591 Mdot
.12552 .09807 Mdot
.12552 .09807 Mdot
.14513 .11376 Mdot
.13728 .10199 Mdot
.14513 .09807 Mdot
.14513 .09415 Mdot
.14905 .09415 Mdot
.15689 .09415 Mdot
.15297 .08239 Mdot
.15297 .07846 Mdot
.14905 .07454 Mdot
.16081 .08631 Mdot
.16473 .09023 Mdot
.15297 .07846 Mdot
.16081 .08239 Mdot
.16865 .09807 Mdot
.16081 .10199 Mdot
.15689 .09807 Mdot
.15689 .09807 Mdot
.16473 .10199 Mdot
.17257 .10983 Mdot
.17257 .10591 Mdot
.16473 .09807 Mdot
.16473 .10199 Mdot
.16081 .09807 Mdot
.16081 .10199 Mdot
.16081 .10199 Mdot
.16865 .1216 Mdot
.16473 .12552 Mdot
.15689 .1216 Mdot
.15297 .11376 Mdot
.18042 .11768 Mdot
.20002 .11376 Mdot
.20394 .10199 Mdot
.19218 .10199 Mdot
.18826 .10983 Mdot
.18434 .11376 Mdot
.18042 .11768 Mdot
.19218 .13728 Mdot
.18434 .13336 Mdot
.19218 .13728 Mdot
.19218 .1412 Mdot
.19218 .13728 Mdot
.20002 .1412 Mdot
.18434 .12944 Mdot
.17257 .12552 Mdot
.1765 .13336 Mdot
.17257 .1216 Mdot
.17257 .10199 Mdot
.18434 .10199 Mdot
.18434 .10199 Mdot
.17257 .09023 Mdot
.18826 .09415 Mdot
.18042 .09415 Mdot
.18434 .09807 Mdot
.19218 .10199 Mdot
.18434 .10983 Mdot
.18042 .11768 Mdot
.16865 .10983 Mdot
.17257 .10983 Mdot
.16081 .10983 Mdot
.15689 .1216 Mdot
.15297 .1216 Mdot
.1765 .1412 Mdot
.16865 .13336 Mdot
.1765 .1412 Mdot
.1961 .14513 Mdot
.20002 .14513 Mdot
.19218 .13336 Mdot
.1961 .12944 Mdot
.20002 .1216 Mdot
.20394 .11376 Mdot
.20787 .11376 Mdot
.21571 .12552 Mdot
.20394 .12552 Mdot
.18434 .11768 Mdot
.1961 .13336 Mdot
.1961 .13728 Mdot
.20002 .14905 Mdot
.20394 .15297 Mdot
.20002 .14513 Mdot
.20002 .1412 Mdot
.20787 .14905 Mdot
.20787 .14905 Mdot
.20394 .14905 Mdot
.20787 .15297 Mdot
.20394 .1412 Mdot
.20002 .13336 Mdot
.1961 .1216 Mdot
.20394 .12552 Mdot
.20002 .1216 Mdot
.19218 .1216 Mdot
.18042 .11768 Mdot
.17257 .11376 Mdot
.18042 .11376 Mdot
.18434 .1216 Mdot
.18042 .1216 Mdot
.17257 .12552 Mdot
.16081 .11768 Mdot
.16865 .11768 Mdot
.16081 .10983 Mdot
.15297 .10591 Mdot
.14905 .10983 Mdot
.1412 .10591 Mdot
.14513 .10591 Mdot
.15297 .10591 Mdot
.15297 .09415 Mdot
.15297 .09415 Mdot
.15297 .09023 Mdot
.16473 .09415 Mdot
.15689 .07846 Mdot
.15689 .09023 Mdot
.14513 .09023 Mdot
.13728 .08631 Mdot
.13336 .08631 Mdot
.1216 .08631 Mdot
.11376 .07846 Mdot
.11376 .07454 Mdot
.1216 .07454 Mdot
.12552 .06278 Mdot
.1216 .05886 Mdot
.11376 .05886 Mdot
.10199 .06278 Mdot
.10591 .0667 Mdot
.1216 .08239 Mdot
.11768 .07846 Mdot
.11376 .09023 Mdot
.11376 .09807 Mdot
.10591 .09023 Mdot
.10591 .08631 Mdot
.11376 .09023 Mdot
.10591 .08239 Mdot
.11376 .08239 Mdot
.12552 .07846 Mdot
.10591 .06278 Mdot
.10199 .05886 Mdot
.5098 .43922 Mdot
.68234 .57254 Mdot
.70979 .59999 Mdot
.73332 .62352 Mdot
.73724 .62352 Mdot
.6745 .55686 Mdot
.31766 .27453 Mdot
.08631 .08239 Mdot
.11768 .09807 Mdot
.07846 .05886 Mdot
.07454 .04709 Mdot
.08631 .05102 Mdot
.09807 .06278 Mdot
.11768 .0667 Mdot
.12944 .07454 Mdot
.13336 .08631 Mdot
.13336 .08631 Mdot
.14513 .10199 Mdot
.14905 .10591 Mdot
.16473 .10983 Mdot
.15297 .10199 Mdot
.14513 .10983 Mdot
.1412 .10199 Mdot
.1412 .09807 Mdot
.1412 .09415 Mdot
.13728 .08239 Mdot
.13336 .08239 Mdot
.13728 .08631 Mdot
.14513 .09023 Mdot
.13728 .07846 Mdot
.14905 .08239 Mdot
.15297 .08239 Mdot
.16081 .09415 Mdot
.16865 .10199 Mdot
.16473 .10199 Mdot
.15297 .09415 Mdot
.17257 .10983 Mdot
.16473 .10199 Mdot
.16473 .10199 Mdot
.1765 .11768 Mdot
.17257 .11376 Mdot
.17257 .10983 Mdot
.17257 .10983 Mdot
.17257 .10983 Mdot
.16081 .10199 Mdot
.17257 .10199 Mdot
.17257 .09807 Mdot
.16473 .10591 Mdot
.14905 .09023 Mdot
.14905 .09023 Mdot
.14513 .09415 Mdot
.14905 .10591 Mdot
.15297 .11768 Mdot
.16081 .12552 Mdot
.16865 .12944 Mdot
.18434 .13336 Mdot
.18434 .11768 Mdot
.18826 .10983 Mdot
.20002 .11768 Mdot
.20394 .1216 Mdot
.20002 .12944 Mdot
.18826 .12552 Mdot
.20002 .13336 Mdot
.18826 .12552 Mdot
.20394 .13728 Mdot
.20394 .14905 Mdot
.20002 .1412 Mdot
.20002 .13336 Mdot
.19218 .12552 Mdot
.18826 .1216 Mdot
.18826 .12944 Mdot
.17257 .11376 Mdot
.18042 .10591 Mdot
.18434 .10591 Mdot
.1765 .09415 Mdot
.17257 .08631 Mdot
.1765 .09023 Mdot
.18826 .10591 Mdot
.19218 .10983 Mdot
.20002 .11768 Mdot
.18826 .11768 Mdot
.18042 .11768 Mdot
.1765 .12552 Mdot
.1765 .1216 Mdot
.16865 .10983 Mdot
.16865 .10591 Mdot
.16081 .09415 Mdot
.1765 .11768 Mdot
.18434 .12552 Mdot
.18042 .12944 Mdot
.18826 .12944 Mdot
.18826 .12552 Mdot
.18826 .12552 Mdot
.20787 .13728 Mdot
.20394 .13336 Mdot
.21571 .1412 Mdot
.22747 .14905 Mdot
.21571 .14905 Mdot
.20787 .15689 Mdot
.1961 .16081 Mdot
.20394 .16865 Mdot
.19218 .15689 Mdot
.20002 .15689 Mdot
.20002 .14905 Mdot
.20394 .14905 Mdot
.20787 .15297 Mdot
.20394 .14905 Mdot
.20394 .13728 Mdot
.20394 .13336 Mdot
.20394 .13336 Mdot
.20002 .12552 Mdot
.21179 .12552 Mdot
.21179 .1216 Mdot
.20787 .12944 Mdot
.20002 .13336 Mdot
.1961 .1412 Mdot
.1961 .14905 Mdot
.18826 .14513 Mdot
.18042 .13728 Mdot
.1765 .12944 Mdot
.18826 .13728 Mdot
.1765 .12552 Mdot
.18042 .12552 Mdot
.18042 .11376 Mdot
.1765 .10983 Mdot
.16865 .10983 Mdot
.15297 .09807 Mdot
.14905 .09415 Mdot
.14905 .09415 Mdot
.14905 .09415 Mdot
.14513 .08631 Mdot
.15689 .08239 Mdot
.15689 .07846 Mdot
.15689 .07454 Mdot
.14513 .07454 Mdot
.12944 .07846 Mdot
.13336 .09023 Mdot
.12552 .09023 Mdot
.1216 .09023 Mdot
.12552 .09023 Mdot
.1216 .07454 Mdot
.11376 .0667 Mdot
.11376 .06278 Mdot
.11768 .04709 Mdot
.11376 .03925 Mdot
.11376 .04317 Mdot
.10983 .05102 Mdot
.10983 .05886 Mdot
.12552 .07846 Mdot
.12552 .08239 Mdot
.1216 .07846 Mdot
.12944 .08239 Mdot
.12944 .08631 Mdot
.12552 .08239 Mdot
.1216 .08239 Mdot
.11768 .07454 Mdot
.11768 .06278 Mdot
.11768 .06278 Mdot
.11376 .06278 Mdot
.09415 .04709 Mdot
.1765 .13336 Mdot
.29806 .23139 Mdot
.39217 .30982 Mdot
.55686 .42746 Mdot
.62352 .47843 Mdot
.70587 .54117 Mdot
.47451 .35295 Mdot
.07062 .05102 Mdot
.08631 .05886 Mdot
.07846 .04709 Mdot
.06278 .04709 Mdot
.06278 .05102 Mdot
.09023 .06278 Mdot
.10983 .06278 Mdot
.11768 .07062 Mdot
.12944 .07454 Mdot
.13336 .08239 Mdot
.14905 .09023 Mdot
.15297 .09807 Mdot
.15297 .09023 Mdot
.14905 .08631 Mdot
.14513 .08631 Mdot
.14513 .09807 Mdot
.16081 .10591 Mdot
.15689 .10591 Mdot
.16081 .10591 Mdot
.14513 .09023 Mdot
.14905 .09023 Mdot
.15689 .09415 Mdot
.15297 .08631 Mdot
.15689 .08631 Mdot
.15689 .09023 Mdot
.16081 .10199 Mdot
.14905 .10199 Mdot
.15297 .10983 Mdot
.16081 .11376 Mdot
.16081 .10591 Mdot
.16081 .10199 Mdot
.16865 .10591 Mdot
.16473 .10591 Mdot
.16473 .10591 Mdot
.17257 .10591 Mdot
.18434 .11376 Mdot
.18826 .10983 Mdot
.1765 .10199 Mdot
.16081 .09807 Mdot
.16473 .10591 Mdot
.16081 .10199 Mdot
.15689 .10199 Mdot
.16081 .10199 Mdot
.16081 .11376 Mdot
.16081 .11376 Mdot
.18042 .13336 Mdot
.16473 .11768 Mdot
.17257 .11376 Mdot
.17257 .11768 Mdot
.18826 .1216 Mdot
.1961 .10983 Mdot
.18826 .09807 Mdot
.20002 .10591 Mdot
.20002 .10983 Mdot
.19218 .11768 Mdot
.20002 .12552 Mdot
.1961 .12552 Mdot
.20787 .13728 Mdot
.20002 .1412 Mdot
.21571 .16081 Mdot
.21179 .15297 Mdot
.20394 .13336 Mdot
.20002 .12944 Mdot
.18042 .10983 Mdot
.1961 .11768 Mdot
.19218 .11768 Mdot
.18434 .10983 Mdot
.17257 .09807 Mdot
.1765 .09807 Mdot
.18042 .10199 Mdot
.17257 .10591 Mdot
.18434 .10983 Mdot
.18042 .09807 Mdot
.19218 .10983 Mdot
.18042 .11376 Mdot
.18042 .11768 Mdot
.1765 .11376 Mdot
.18042 .10983 Mdot
.17257 .10199 Mdot
.15689 .09023 Mdot
.17257 .10591 Mdot
.18434 .11768 Mdot
.1765 .11376 Mdot
.18042 .12552 Mdot
.18826 .12944 Mdot
.18434 .12552 Mdot
.1961 .13336 Mdot
.20002 .13336 Mdot
.20394 .13336 Mdot
.21571 .1412 Mdot
.21179 .14513 Mdot
.21571 .16081 Mdot
.20787 .16473 Mdot
.21179 .16865 Mdot
.20394 .16081 Mdot
.19218 .14513 Mdot
.19218 .13336 Mdot
.20002 .13728 Mdot
.1961 .13728 Mdot
.20002 .14513 Mdot
.21963 .14905 Mdot
.21571 .1412 Mdot
.20787 .13336 Mdot
.19218 .1216 Mdot
.21179 .13336 Mdot
.21179 .13336 Mdot
.20787 .12944 Mdot
.20394 .13336 Mdot
.19218 .12944 Mdot
.18042 .11768 Mdot
.1961 .12944 Mdot
.17257 .11376 Mdot
.1765 .11376 Mdot
.18042 .11376 Mdot
.17257 .10983 Mdot
.1765 .10591 Mdot
.16865 .09023 Mdot
.16865 .08631 Mdot
.1765 .09415 Mdot
.16865 .10199 Mdot
.15297 .09415 Mdot
.14905 .09023 Mdot
.15689 .09807 Mdot
.14905 .08631 Mdot
.15689 .08631 Mdot
.14905 .08239 Mdot
.14513 .07454 Mdot
.13336 .06278 Mdot
.13728 .07846 Mdot
.13728 .08631 Mdot
.12552 .08631 Mdot
.12552 .09023 Mdot
.12552 .08239 Mdot
.11376 .0667 Mdot
.10983 .06278 Mdot
.09023 .04709 Mdot
.11376 .05886 Mdot
.09807 .03925 Mdot
.09415 .03533 Mdot
.08631 .03141 Mdot
.10591 .05102 Mdot
.11376 .06278 Mdot
.11768 .0667 Mdot
.1216 .0667 Mdot
.1412 .08631 Mdot
.13336 .08239 Mdot
.12944 .07846 Mdot
.1216 .07062 Mdot
.11768 .0667 Mdot
.10591 .04317 Mdot
.09807 .03141 Mdot
.09807 .03925 Mdot
.08631 .03925 Mdot
.1216 .07454 Mdot
.14905 .10199 Mdot
.1412 .09415 Mdot
.16081 .10199 Mdot
.26276 .16473 Mdot
.39609 .26276 Mdot
.36472 .24316 Mdot
.14905 .09415 Mdot
.15689 .11376 Mdot
.13336 .09415 Mdot
.10983 .07846 Mdot
.09415 .06278 Mdot
.11768 .07454 Mdot
.11768 .07062 Mdot
.1216 .07846 Mdot
.13728 .08631 Mdot
.15297 .09023 Mdot
.14905 .09415 Mdot
.15689 .10199 Mdot
.15689 .10199 Mdot
.15689 .10199 Mdot
.14905 .10199 Mdot
.14513 .11376 Mdot
.15297 .11768 Mdot
.16081 .11768 Mdot
.16473 .11768 Mdot
.16081 .10591 Mdot
.14905 .09807 Mdot
.14513 .08631 Mdot
.1412 .07454 Mdot
.15297 .07846 Mdot
.14905 .08239 Mdot
.14905 .09023 Mdot
.16081 .10591 Mdot
.15689 .10983 Mdot
.16473 .12944 Mdot
.16865 .12552 Mdot
.16081 .11768 Mdot
.17257 .12552 Mdot
.18042 .12944 Mdot
.18042 .12552 Mdot
.18042 .11768 Mdot
.18042 .10591 Mdot
.18826 .10983 Mdot
.18434 .10591 Mdot
.16865 .09807 Mdot
.16865 .10591 Mdot
.18434 .1216 Mdot
.1765 .12552 Mdot
.18042 .12552 Mdot
.18434 .12552 Mdot
.18826 .12552 Mdot
.18042 .11768 Mdot
.18042 .10983 Mdot
.18434 .09807 Mdot
.18434 .09415 Mdot
.18826 .10591 Mdot
.17257 .09023 Mdot
.18826 .09807 Mdot
.1961 .10591 Mdot
.18826 .10199 Mdot
.18826 .10591 Mdot
.1961 .11376 Mdot
.20002 .1216 Mdot
.1961 .12944 Mdot
.20394 .13728 Mdot
.21179 .15297 Mdot
.1961 .1412 Mdot
.20002 .1412 Mdot
.19218 .13336 Mdot
.19218 .12552 Mdot
.19218 .11768 Mdot
.18042 .10591 Mdot
.18826 .10591 Mdot
.19218 .10983 Mdot
.18434 .11376 Mdot
.1765 .10591 Mdot
.15689 .09415 Mdot
.15689 .09023 Mdot
.17257 .09807 Mdot
.17257 .10983 Mdot
.18434 .11768 Mdot
.1765 .11376 Mdot
.1765 .11768 Mdot
.17257 .11376 Mdot
.16865 .10983 Mdot
.16473 .10199 Mdot
.18042 .10591 Mdot
.19218 .11376 Mdot
.18826 .10983 Mdot
.18042 .11376 Mdot
.18826 .1216 Mdot
.18826 .1216 Mdot
.1961 .1216 Mdot
.20002 .1216 Mdot
.20002 .12944 Mdot
.20002 .12944 Mdot
.21571 .14513 Mdot
.22747 .16473 Mdot
.21179 .16473 Mdot
.21179 .16865 Mdot
.21571 .16081 Mdot
.21179 .14513 Mdot
.20394 .12944 Mdot
.20394 .12944 Mdot
.21179 .13728 Mdot
.22355 .14905 Mdot
.21963 .14513 Mdot
.21571 .1412 Mdot
.22355 .14513 Mdot
.20787 .1412 Mdot
.20002 .13336 Mdot
.21179 .13336 Mdot
.21571 .13728 Mdot
.20394 .12944 Mdot
.1961 .11768 Mdot
.18826 .10983 Mdot
.18826 .10591 Mdot
.18434 .10199 Mdot
.19218 .11376 Mdot
.19218 .11376 Mdot
.18042 .11376 Mdot
.18434 .11768 Mdot
.18434 .11376 Mdot
.1765 .10199 Mdot
.18042 .10199 Mdot
.19218 .11768 Mdot
.18042 .11376 Mdot
.18434 .11768 Mdot
.16473 .10591 Mdot
.15689 .09807 Mdot
.16081 .09415 Mdot
.14513 .08239 Mdot
.12944 .07846 Mdot
.1412 .08239 Mdot
.14513 .08239 Mdot
.13336 .07454 Mdot
.13336 .08239 Mdot
.12944 .08239 Mdot
.12552 .07454 Mdot
.1216 .05886 Mdot
.1216 .05494 Mdot
.10591 .04709 Mdot
.10591 .05886 Mdot
.10591 .05886 Mdot
.10199 .05102 Mdot
.09807 .04709 Mdot
.10591 .04709 Mdot
.1216 .0667 Mdot
.1216 .06278 Mdot
.10591 .05886 Mdot
.1216 .07062 Mdot
.12552 .07846 Mdot
.1216 .07846 Mdot
.10591 .0667 Mdot
.09807 .05886 Mdot
.09807 .05102 Mdot
.09415 .03925 Mdot
.08239 .03533 Mdot
.06278 .01965 Mdot
.07454 .04317 Mdot
.09415 .0667 Mdot
.09807 .0667 Mdot
.09807 .07454 Mdot
.12944 .09415 Mdot
.15297 .10591 Mdot
.16081 .10591 Mdot
.13728 .09023 Mdot
.13728 .08239 Mdot
.12944 .07062 Mdot
.12552 .06278 Mdot
.11768 .05102 Mdot
.11376 .04709 Mdot
.1216 .06278 Mdot
.12552 .07454 Mdot
.11376 .0667 Mdot
.13336 .07846 Mdot
.14513 .08631 Mdot
.15297 .09415 Mdot
.16473 .10199 Mdot
.16081 .10199 Mdot
.14905 .09415 Mdot
.14905 .09807 Mdot
.16473 .10983 Mdot
.16865 .11376 Mdot
.16473 .11376 Mdot
.16473 .10983 Mdot
.15689 .09807 Mdot
.16865 .10199 Mdot
.16865 .09807 Mdot
.15689 .09023 Mdot
.14905 .09415 Mdot
.15689 .09807 Mdot
.16865 .10591 Mdot
.15689 .11376 Mdot
.16473 .12552 Mdot
.17257 .12944 Mdot
.17257 .12944 Mdot
.1765 .13336 Mdot
.17257 .12944 Mdot
.16473 .1216 Mdot
.15689 .10983 Mdot
.1765 .11376 Mdot
.18434 .10983 Mdot
.19218 .11376 Mdot
.18042 .10983 Mdot
.18042 .11768 Mdot
.17257 .12944 Mdot
.18434 .1412 Mdot
.1765 .13728 Mdot
.1765 .13336 Mdot
.18826 .13336 Mdot
.18826 .12944 Mdot
.18826 .11768 Mdot
.18042 .09415 Mdot
.16865 .09023 Mdot
.18042 .10199 Mdot
.18826 .11376 Mdot
.19218 .10591 Mdot
.20787 .11768 Mdot
.20394 .1216 Mdot
.20394 .12552 Mdot
.20002 .12944 Mdot
.18826 .1216 Mdot
.19218 .12944 Mdot
.20787 .14513 Mdot
.21571 .15689 Mdot
.20394 .14513 Mdot
.21571 .15297 Mdot
.19218 .13336 Mdot
.18434 .12552 Mdot
.20002 .13336 Mdot
.1961 .12552 Mdot
.1961 .1216 Mdot
.1961 .11768 Mdot
.1961 .11768 Mdot
.1961 .11768 Mdot
.18042 .10591 Mdot
.17257 .10199 Mdot
.17257 .10199 Mdot
.18042 .11376 Mdot
.16865 .10591 Mdot
.17257 .10983 Mdot
.18042 .11768 Mdot
.18434 .12552 Mdot
.17257 .11768 Mdot
.16081 .10591 Mdot
.1765 .10591 Mdot
.1961 .11376 Mdot
.18434 .10591 Mdot
.19218 .1216 Mdot
.1961 .12552 Mdot
.1961 .12944 Mdot
.20002 .12552 Mdot
.19218 .1216 Mdot
.20002 .12552 Mdot
.20394 .12944 Mdot
.21571 .13336 Mdot
.21571 .1412 Mdot
.21963 .15689 Mdot
.22747 .17257 Mdot
.22355 .16473 Mdot
.20394 .14513 Mdot
.1961 .12552 Mdot
.20394 .1216 Mdot
.21179 .12944 Mdot
.21179 .13728 Mdot
.21571 .14513 Mdot
.21963 .14905 Mdot
.21571 .14905 Mdot
.20787 .14905 Mdot
.1961 .13728 Mdot
.1961 .13336 Mdot
.20394 .13336 Mdot
.1961 .12944 Mdot
.20002 .12552 Mdot
.20787 .12944 Mdot
.18826 .11376 Mdot
.18434 .11376 Mdot
.18826 .1216 Mdot
.18826 .11768 Mdot
.18826 .11768 Mdot
.18042 .11376 Mdot
.1765 .10983 Mdot
.19218 .11768 Mdot
.18826 .10591 Mdot
.18434 .10983 Mdot
.18826 .12552 Mdot
.1961 .13336 Mdot
.18042 .11768 Mdot
.16865 .10591 Mdot
.15689 .09415 Mdot
.16081 .09415 Mdot
.14513 .08631 Mdot
.1412 .09023 Mdot
.13728 .08631 Mdot
.1412 .08631 Mdot
.13728 .08631 Mdot
.13728 .08239 Mdot
.12944 .07846 Mdot
.12944 .07454 Mdot
.12552 .06278 Mdot
.13336 .06278 Mdot
.10983 .05102 Mdot
.10199 .05102 Mdot
.10199 .05102 Mdot
.09807 .05102 Mdot
.10199 .05102 Mdot
.11376 .05494 Mdot
.11376 .05102 Mdot
.10983 .05102 Mdot
.1216 .07062 Mdot
.10983 .05886 Mdot
.10591 .05886 Mdot
.10199 .06278 Mdot
.10199 .06278 Mdot
.09415 .05494 Mdot
.08631 .03925 Mdot
.0667 .02357 Mdot
.07454 .02749 Mdot
.07062 .04317 Mdot
.07846 .04709 Mdot
.07062 .03925 Mdot
.09415 .05886 Mdot
.09807 .07062 Mdot
.12552 .09415 Mdot
.13336 .09415 Mdot
.13336 .09023 Mdot
.12944 .08239 Mdot
.12944 .07846 Mdot
.13336 .07846 Mdot
.12944 .07454 Mdot
.12552 .07062 Mdot
.12944 .0667 Mdot
.1216 .07062 Mdot
.11768 .05886 Mdot
.13728 .0667 Mdot
.1412 .07062 Mdot
.14513 .07454 Mdot
.14905 .08631 Mdot
.1412 .07846 Mdot
.14905 .09023 Mdot
.14905 .09415 Mdot
.14905 .09415 Mdot
.15297 .09415 Mdot
.15689 .09807 Mdot
.16473 .10983 Mdot
.16081 .10591 Mdot
.1765 .11768 Mdot
.17257 .1216 Mdot
.17257 .11376 Mdot
.16865 .10983 Mdot
.16081 .10983 Mdot
.15689 .10983 Mdot
.16865 .12552 Mdot
.16081 .1216 Mdot
.1765 .12552 Mdot
.16865 .1216 Mdot
.16473 .10983 Mdot
.1765 .11768 Mdot
.17257 .10983 Mdot
.16473 .10983 Mdot
.18042 .1216 Mdot
.18042 .1216 Mdot
.19218 .12552 Mdot
.18826 .11768 Mdot
.19218 .12552 Mdot
.18434 .1216 Mdot
.18434 .1216 Mdot
.18826 .12944 Mdot
.1961 .13336 Mdot
.18042 .11768 Mdot
.18042 .11768 Mdot
.18826 .12552 Mdot
.18042 .11768 Mdot
.18042 .10983 Mdot
.18826 .11768 Mdot
.1961 .11376 Mdot
.19218 .1216 Mdot
.20002 .1216 Mdot
.20002 .12552 Mdot
.20787 .12944 Mdot
.18434 .11768 Mdot
.19218 .12552 Mdot
.20002 .13336 Mdot
.21571 .15297 Mdot
.21571 .15297 Mdot
.21571 .15297 Mdot
.22355 .16865 Mdot
.22355 .16081 Mdot
.21179 .15297 Mdot
.20787 .14513 Mdot
.20787 .13728 Mdot
.20394 .13336 Mdot
.21179 .12552 Mdot
.20787 .11376 Mdot
.20394 .11376 Mdot
.1961 .10591 Mdot
.20394 .11768 Mdot
.20787 .12552 Mdot
.1961 .11376 Mdot
.18434 .10983 Mdot
.1765 .10591 Mdot
.18826 .10983 Mdot
.18826 .1216 Mdot
.18826 .12552 Mdot
.19218 .1216 Mdot
.20002 .10983 Mdot
.20394 .10591 Mdot
.18826 .09415 Mdot
.19218 .10591 Mdot
.20394 .11768 Mdot
.20394 .12944 Mdot
.20394 .13336 Mdot
.20002 .12944 Mdot
.20787 .13728 Mdot
.20394 .12944 Mdot
.20394 .1216 Mdot
.19218 .1216 Mdot
.21179 .14513 Mdot
.21963 .15689 Mdot
.23139 .16473 Mdot
.22747 .15689 Mdot
.22355 .14905 Mdot
.21571 .13336 Mdot
.21179 .1216 Mdot
.21571 .12552 Mdot
.21963 .13336 Mdot
.23139 .14905 Mdot
.22747 .15297 Mdot
.21571 .1412 Mdot
.21179 .13728 Mdot
.21571 .1412 Mdot
.1961 .12944 Mdot
.18434 .12944 Mdot
.18042 .1216 Mdot
.1961 .12944 Mdot
.19218 .12552 Mdot
.18826 .12944 Mdot
.19218 .12944 Mdot
.19218 .12944 Mdot
.20002 .13336 Mdot
.20002 .12944 Mdot
.20002 .13336 Mdot
.18826 .13336 Mdot
.18434 .1216 Mdot
.19218 .12944 Mdot
.19218 .13728 Mdot
.18434 .13336 Mdot
.1961 .13336 Mdot
.18826 .12552 Mdot
.16473 .10199 Mdot
.16473 .09807 Mdot
.15297 .08631 Mdot
.15297 .08631 Mdot
.15297 .09023 Mdot
.16081 .09807 Mdot
.1412 .09023 Mdot
.14513 .09023 Mdot
.13728 .08631 Mdot
.12944 .08239 Mdot
.13336 .08239 Mdot
.1412 .07846 Mdot
.12944 .06278 Mdot
.11376 .05886 Mdot
.11768 .06278 Mdot
.11768 .07062 Mdot
.11768 .0667 Mdot
.10983 .05102 Mdot
.11376 .05102 Mdot
.1216 .05886 Mdot
.11768 .0667 Mdot
.10983 .05886 Mdot
.10591 .05886 Mdot
.10591 .05886 Mdot
.11768 .0667 Mdot
.08239 .03533 Mdot
.08239 .03533 Mdot
.07846 .03141 Mdot
.08631 .03533 Mdot
.03925 .01572 Mdot
.05494 .01965 Mdot
.05886 .01965 Mdot
.08239 .04317 Mdot
.10199 .07454 Mdot
.10983 .08631 Mdot
.11376 .08239 Mdot
.11376 .07846 Mdot
.12944 .10199 Mdot
.13728 .10199 Mdot
.12944 .08239 Mdot
.13728 .08631 Mdot
.12944 .07846 Mdot
.1216 .07062 Mdot
.11376 .06278 Mdot
.12552 .07062 Mdot
.13728 .0667 Mdot
.14905 .07062 Mdot
.15297 .07062 Mdot
.16081 .08631 Mdot
.15297 .08239 Mdot
.15689 .09023 Mdot
.16473 .10591 Mdot
.15689 .09807 Mdot
.16473 .10591 Mdot
.16081 .10591 Mdot
.17257 .11376 Mdot
.1765 .12552 Mdot
.1765 .13336 Mdot
.17257 .12944 Mdot
.1765 .12944 Mdot
.18434 .12944 Mdot
.18042 .13728 Mdot
.16865 .12552 Mdot
.1765 .12944 Mdot
.1765 .1216 Mdot
.18434 .1216 Mdot
.17257 .10983 Mdot
.16081 .10591 Mdot
.16865 .10591 Mdot
.16865 .10591 Mdot
.16473 .10983 Mdot
.18042 .11768 Mdot
.18042 .11768 Mdot
.18826 .12552 Mdot
.18826 .1216 Mdot
.20394 .12944 Mdot
.21179 .13728 Mdot
.20787 .13336 Mdot
.18826 .12552 Mdot
.18826 .1216 Mdot
.18826 .12944 Mdot
.18826 .12552 Mdot
.19218 .12552 Mdot
.1961 .13728 Mdot
.1961 .13336 Mdot
.19218 .1216 Mdot
.19218 .1216 Mdot
.18434 .11376 Mdot
.1961 .1216 Mdot
.19218 .11768 Mdot
.19218 .12552 Mdot
.1961 .12944 Mdot
.18826 .12944 Mdot
.19218 .13728 Mdot
.20787 .14513 Mdot
.22355 .15689 Mdot
.22355 .15689 Mdot
.22355 .16473 Mdot
.21963 .16473 Mdot
.21179 .16473 Mdot
.21963 .17257 Mdot
.20002 .14905 Mdot
.1961 .13728 Mdot
.1961 .1216 Mdot
.20394 .1216 Mdot
.20394 .10983 Mdot
.20394 .10591 Mdot
.20394 .10199 Mdot
.21963 .1216 Mdot
.21179 .12552 Mdot
.21179 .13336 Mdot
.20002 .12944 Mdot
.18434 .1216 Mdot
.18434 .12552 Mdot
.18826 .12552 Mdot
.19218 .1216 Mdot
.1961 .11376 Mdot
.20002 .10199 Mdot
.20002 .09807 Mdot
.20002 .10591 Mdot
.20394 .11768 Mdot
.20002 .12944 Mdot
.20787 .13728 Mdot
.21179 .1412 Mdot
.22355 .14905 Mdot
.21963 .14513 Mdot
.21179 .13336 Mdot
.21179 .12552 Mdot
.20787 .11768 Mdot
.20787 .12552 Mdot
.22355 .1412 Mdot
.21179 .13336 Mdot
.20394 .13728 Mdot
.21571 .1412 Mdot
.21179 .12944 Mdot
.21963 .12944 Mdot
.21179 .1216 Mdot
.21963 .13336 Mdot
.21179 .12944 Mdot
.21179 .13728 Mdot
.21571 .1412 Mdot
.21571 .1412 Mdot
.20787 .13728 Mdot
.19218 .13728 Mdot
.18434 .12944 Mdot
.1765 .11768 Mdot
.18042 .1216 Mdot
.17257 .11376 Mdot
.18042 .11768 Mdot
.18434 .1216 Mdot
.18042 .12552 Mdot
.19218 .13336 Mdot
.1961 .12944 Mdot
.18434 .12552 Mdot
.18042 .12552 Mdot
.17257 .13336 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.18042 .12944 Mdot
.18826 .1216 Mdot
.14905 .08631 Mdot
.15689 .08631 Mdot
.15297 .07454 Mdot
.14905 .0667 Mdot
.15297 .07062 Mdot
.15689 .08631 Mdot
.16473 .09807 Mdot
.15297 .08631 Mdot
.13336 .07846 Mdot
.1216 .07454 Mdot
.12552 .07846 Mdot
.1412 .08631 Mdot
.12552 .07454 Mdot
.1216 .07454 Mdot
.12944 .08239 Mdot
.1216 .08239 Mdot
.1216 .08239 Mdot
.12552 .07846 Mdot
.12552 .07062 Mdot
.1216 .05886 Mdot
.11376 .05494 Mdot
.1216 .05886 Mdot
.10983 .05494 Mdot
.11376 .05494 Mdot
.11768 .05886 Mdot
.10983 .05494 Mdot
.10199 .04709 Mdot
.09807 .05494 Mdot
.09023 .05102 Mdot
.03925 .0118 Mdot
.05102 .01572 Mdot
.08631 .03533 Mdot
.10983 .05886 Mdot
.13728 .08239 Mdot
.1216 .07846 Mdot
.08631 .05886 Mdot
.08239 .0667 Mdot
.10591 .07846 Mdot
.09415 .0667 Mdot
.10199 .07062 Mdot
.11768 .07454 Mdot
.12552 .07846 Mdot
.13728 .08239 Mdot
.13728 .07454 Mdot
.1412 .0667 Mdot
.13728 .05886 Mdot
.15297 .0667 Mdot
.15689 .0667 Mdot
.15689 .07454 Mdot
.15297 .08239 Mdot
.15297 .09415 Mdot
.16473 .10199 Mdot
.16473 .10199 Mdot
.16081 .10199 Mdot
.17257 .10983 Mdot
.18434 .1216 Mdot
.18042 .12552 Mdot
.18434 .13728 Mdot
.17257 .13336 Mdot
.18042 .13728 Mdot
.18434 .1412 Mdot
.18826 .14905 Mdot
.18826 .14513 Mdot
.18434 .13336 Mdot
.17257 .11376 Mdot
.18434 .11768 Mdot
.1765 .10983 Mdot
.1765 .10591 Mdot
.18434 .10591 Mdot
.18434 .10591 Mdot
.17257 .09807 Mdot
.18042 .10591 Mdot
.19218 .1216 Mdot
.20394 .12552 Mdot
.1961 .11768 Mdot
.19218 .11376 Mdot
.20002 .12552 Mdot
.19218 .12552 Mdot
.19218 .12944 Mdot
.18826 .13336 Mdot
.19218 .1412 Mdot
.1961 .14513 Mdot
.19218 .1412 Mdot
.18434 .13728 Mdot
.19218 .13336 Mdot
.20002 .13336 Mdot
.21179 .13728 Mdot
.20394 .12944 Mdot
.20002 .12944 Mdot
.18826 .11768 Mdot
.1961 .1216 Mdot
.20394 .12552 Mdot
.20002 .1216 Mdot
.20002 .12552 Mdot
.20394 .12552 Mdot
.21963 .1412 Mdot
.21963 .14905 Mdot
.22747 .15689 Mdot
.22355 .15297 Mdot
.23139 .16865 Mdot
.22747 .17257 Mdot
.22747 .16865 Mdot
.21963 .15297 Mdot
.21571 .1412 Mdot
.21179 .12944 Mdot
.20787 .11376 Mdot
.20787 .10199 Mdot
.21571 .10591 Mdot
.21179 .11376 Mdot
.20787 .1216 Mdot
.21179 .12944 Mdot
.20787 .12944 Mdot
.20002 .12944 Mdot
.19218 .12552 Mdot
.1961 .12944 Mdot
.20394 .13336 Mdot
.20002 .12552 Mdot
.20394 .1216 Mdot
.20394 .11768 Mdot
.1961 .11768 Mdot
.1961 .1216 Mdot
.21179 .13336 Mdot
.21179 .13728 Mdot
.21571 .14513 Mdot
.21179 .13728 Mdot
.21963 .13336 Mdot
.21571 .1216 Mdot
.21179 .11768 Mdot
.21963 .12552 Mdot
.21179 .12944 Mdot
.21963 .13336 Mdot
.22355 .13728 Mdot
.21963 .1412 Mdot
.22355 .14905 Mdot
.21571 .1412 Mdot
.20787 .13336 Mdot
.20787 .13336 Mdot
.21571 .13336 Mdot
.21179 .1412 Mdot
.21963 .14905 Mdot
.22355 .14905 Mdot
.22355 .14513 Mdot
.21179 .13728 Mdot
.20394 .13728 Mdot
.18826 .12944 Mdot
.17257 .11768 Mdot
.1765 .12944 Mdot
.1765 .12944 Mdot
.18434 .13336 Mdot
.18042 .12552 Mdot
.18826 .12552 Mdot
.1961 .12944 Mdot
.1961 .12944 Mdot
.18434 .1216 Mdot
.18826 .13336 Mdot
.18826 .13728 Mdot
.1765 .12552 Mdot
.18826 .12552 Mdot
.18826 .1216 Mdot
.18434 .11768 Mdot
.1765 .10199 Mdot
.18434 .10199 Mdot
.16865 .08631 Mdot
.16081 .07846 Mdot
.15297 .07454 Mdot
.16473 .09415 Mdot
.16473 .10199 Mdot
.15689 .09023 Mdot
.15689 .09415 Mdot
.14905 .08631 Mdot
.1412 .07846 Mdot
.1412 .07846 Mdot
.12552 .07062 Mdot
.1216 .07062 Mdot
.11376 .07454 Mdot
.10983 .07846 Mdot
.10199 .07062 Mdot
.11376 .07454 Mdot
.1412 .08631 Mdot
.1216 .07454 Mdot
.10199 .06278 Mdot
.09807 .05102 Mdot
.10983 .05102 Mdot
.10983 .04709 Mdot
.10983 .04317 Mdot
.11768 .05494 Mdot
.09807 .04317 Mdot
.09807 .04317 Mdot
.08631 .03533 Mdot
.04317 .01572 Mdot
.06278 .02357 Mdot
.0667 .02357 Mdot
.07062 .03141 Mdot
.09023 .03925 Mdot
.09807 .04317 Mdot
.09415 .03925 Mdot
.07846 .04317 Mdot
.0667 .04317 Mdot
.04317 .02749 Mdot
.0667 .03533 Mdot
.09023 .05102 Mdot
.11768 .06278 Mdot
.11376 .06278 Mdot
.12552 .0667 Mdot
.1412 .07062 Mdot
.14513 .07062 Mdot
.14513 .07062 Mdot
.15297 .07846 Mdot
.14905 .08631 Mdot
.15689 .09807 Mdot
.15689 .09807 Mdot
.16473 .10591 Mdot
.16865 .10591 Mdot
.16473 .09807 Mdot
.18826 .10983 Mdot
.20002 .11376 Mdot
.1961 .11768 Mdot
.19218 .1216 Mdot
.18826 .12552 Mdot
.17257 .12552 Mdot
.18434 .13336 Mdot
.18042 .13336 Mdot
.1765 .12944 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.1961 .13728 Mdot
.19218 .12552 Mdot
.20394 .13336 Mdot
.18826 .1216 Mdot
.18434 .11768 Mdot
.18042 .11376 Mdot
.18042 .11376 Mdot
.18826 .11376 Mdot
.20002 .11768 Mdot
.1961 .11376 Mdot
.20787 .1216 Mdot
.20394 .11768 Mdot
.1961 .10983 Mdot
.20002 .11376 Mdot
.18434 .11768 Mdot
.17257 .11768 Mdot
.18434 .12552 Mdot
.1961 .13728 Mdot
.1961 .14513 Mdot
.1961 .14905 Mdot
.18826 .1412 Mdot
.20002 .14513 Mdot
.20787 .14905 Mdot
.20394 .1412 Mdot
.19218 .1216 Mdot
.18434 .10983 Mdot
.19218 .11376 Mdot
.20002 .11376 Mdot
.21571 .11768 Mdot
.21179 .11768 Mdot
.22355 .13336 Mdot
.22747 .14513 Mdot
.22747 .14513 Mdot
.21963 .13728 Mdot
.23139 .14905 Mdot
.23531 .15297 Mdot
.23531 .15689 Mdot
.23139 .14905 Mdot
.23531 .15297 Mdot
.23924 .14905 Mdot
.22355 .12944 Mdot
.22747 .12944 Mdot
.23531 .12944 Mdot
.22355 .12552 Mdot
.22747 .12944 Mdot
.21179 .11768 Mdot
.21571 .1216 Mdot
.20787 .13336 Mdot
.20787 .14513 Mdot
.20787 .14905 Mdot
.20394 .14905 Mdot
.20394 .1412 Mdot
.21571 .1412 Mdot
.20787 .1216 Mdot
.20394 .11376 Mdot
.20787 .11376 Mdot
.20002 .10983 Mdot
.20002 .11768 Mdot
.21571 .13336 Mdot
.22355 .13336 Mdot
.21571 .1216 Mdot
.21963 .11768 Mdot
.20394 .10199 Mdot
.21963 .1216 Mdot
.22355 .13336 Mdot
.21963 .13336 Mdot
.21963 .13336 Mdot
.21571 .13336 Mdot
.22355 .1412 Mdot
.21963 .13336 Mdot
.21571 .13336 Mdot
.20394 .12552 Mdot
.21963 .13336 Mdot
.21963 .14513 Mdot
.22355 .15297 Mdot
.22355 .14905 Mdot
.22355 .14905 Mdot
.21571 .14513 Mdot
.21179 .1412 Mdot
.20002 .13728 Mdot
.18042 .13336 Mdot
.1765 .13728 Mdot
.16865 .13336 Mdot
.18042 .13336 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.18826 .12944 Mdot
.18434 .12552 Mdot
.19218 .13336 Mdot
.19218 .13728 Mdot
.1961 .1412 Mdot
.18434 .12944 Mdot
.1765 .11376 Mdot
.18434 .11376 Mdot
.1765 .09807 Mdot
.18042 .09807 Mdot
.18042 .09415 Mdot
.18042 .09415 Mdot
.16865 .08631 Mdot
.15297 .07454 Mdot
.15689 .08631 Mdot
.15689 .08631 Mdot
.15297 .09415 Mdot
.16081 .10591 Mdot
.16473 .10983 Mdot
.15689 .10199 Mdot
.14905 .09415 Mdot
.13336 .08239 Mdot
.12552 .07454 Mdot
.11376 .06278 Mdot
.1216 .07454 Mdot
.11768 .07062 Mdot
.12944 .08631 Mdot
.13336 .09023 Mdot
.12552 .08631 Mdot
.10983 .0667 Mdot
.10591 .06278 Mdot
.10983 .05886 Mdot
.11376 .04709 Mdot
.10983 .03925 Mdot
.10983 .03925 Mdot
.10591 .03533 Mdot
.09807 .03533 Mdot
.08239 .03141 Mdot
.03141 .01572 Mdot
.03533 .01572 Mdot
.03533 .00788 Mdot
.05102 .0118 Mdot
.05886 .01572 Mdot
.07454 .01965 Mdot
.10591 .03925 Mdot
.09415 .03533 Mdot
.07454 .02749 Mdot
.04709 .01572 Mdot
.05886 .02357 Mdot
.07846 .03533 Mdot
.06278 .02749 Mdot
.06278 .02357 Mdot
.09415 .04709 Mdot
.1216 .07062 Mdot
.1412 .08239 Mdot
.1412 .08239 Mdot
.16473 .09807 Mdot
.16081 .10591 Mdot
.16081 .10983 Mdot
.16865 .11376 Mdot
.16865 .10591 Mdot
.16865 .10591 Mdot
.16473 .09415 Mdot
.1765 .09415 Mdot
.18826 .09807 Mdot
.18434 .09807 Mdot
.19218 .10591 Mdot
.1961 .11768 Mdot
.18826 .1216 Mdot
.1765 .11768 Mdot
.18434 .12552 Mdot
.18042 .12552 Mdot
.20394 .1412 Mdot
.19218 .12944 Mdot
.20002 .13336 Mdot
.20002 .13336 Mdot
.1961 .12552 Mdot
.1961 .12944 Mdot
.20002 .13336 Mdot
.20787 .13728 Mdot
.20002 .12944 Mdot
.1961 .12944 Mdot
.20787 .12944 Mdot
.21179 .13336 Mdot
.21571 .13728 Mdot
.21179 .12944 Mdot
.20787 .12552 Mdot
.20787 .12944 Mdot
.19218 .12552 Mdot
.18042 .11768 Mdot
.1765 .11768 Mdot
.18434 .12944 Mdot
.18434 .12944 Mdot
.1961 .1412 Mdot
.20002 .14513 Mdot
.20002 .14905 Mdot
.20394 .14905 Mdot
.20787 .1412 Mdot
.21179 .1412 Mdot
.21571 .1412 Mdot
.20787 .12944 Mdot
.20394 .11768 Mdot
.19218 .10199 Mdot
.20394 .11376 Mdot
.20787 .12552 Mdot
.21571 .13336 Mdot
.21963 .13728 Mdot
.22747 .13728 Mdot
.23531 .14513 Mdot
.23531 .14513 Mdot
.23531 .14513 Mdot
.23924 .15297 Mdot
.24316 .15297 Mdot
.23531 .14513 Mdot
.23924 .1412 Mdot
.22747 .12944 Mdot
.23139 .13728 Mdot
.22747 .13336 Mdot
.21571 .13728 Mdot
.21963 .13336 Mdot
.22747 .13336 Mdot
.21571 .12944 Mdot
.21179 .13336 Mdot
.21179 .1412 Mdot
.20787 .14513 Mdot
.20394 .13728 Mdot
.21179 .13728 Mdot
.21179 .13728 Mdot
.20787 .1216 Mdot
.20002 .11376 Mdot
.20002 .10983 Mdot
.20394 .11376 Mdot
.21963 .12552 Mdot
.21571 .1216 Mdot
.21571 .1216 Mdot
.21571 .11768 Mdot
.21963 .11768 Mdot
.23139 .13336 Mdot
.24316 .15297 Mdot
.23139 .15297 Mdot
.20787 .13728 Mdot
.20787 .12552 Mdot
.21571 .12944 Mdot
.21571 .12944 Mdot
.21963 .13336 Mdot
.22355 .13728 Mdot
.22355 .13728 Mdot
.23139 .1412 Mdot
.21963 .13728 Mdot
.21179 .12944 Mdot
.20002 .1216 Mdot
.20787 .13336 Mdot
.20394 .12944 Mdot
.21179 .13728 Mdot
.1961 .13336 Mdot
.18042 .13336 Mdot
.18434 .1412 Mdot
.19218 .14513 Mdot
.19218 .1412 Mdot
.1961 .1412 Mdot
.19218 .13728 Mdot
.18826 .13336 Mdot
.18826 .12944 Mdot
.18826 .12944 Mdot
.19218 .13336 Mdot
.19218 .12552 Mdot
.19218 .1216 Mdot
.19218 .11768 Mdot
.17257 .08631 Mdot
.1765 .08631 Mdot
.1765 .08631 Mdot
.18042 .10199 Mdot
.18042 .10591 Mdot
.14905 .08239 Mdot
.15297 .09415 Mdot
.15297 .09415 Mdot
.15297 .09807 Mdot
.15297 .09807 Mdot
.15689 .10199 Mdot
.16473 .10591 Mdot
.14905 .09807 Mdot
.14513 .09023 Mdot
.13336 .08239 Mdot
.13728 .08631 Mdot
.14905 .09023 Mdot
.12552 .07062 Mdot
.13336 .07062 Mdot
.14513 .08239 Mdot
.12944 .07846 Mdot
.12944 .07454 Mdot
.12944 .07454 Mdot
.11376 .06278 Mdot
.11376 .05886 Mdot
.11376 .06278 Mdot
.11768 .06278 Mdot
.11768 .06278 Mdot
.09807 .05494 Mdot
.08631 .04317 Mdot
.02357 .02357 Mdot
.03141 .01965 Mdot
.02749 .00788 Mdot
.03533 .00396 Mdot
.03533 .00396 Mdot
.06278 .0118 Mdot
.07454 .0118 Mdot
.07846 .01572 Mdot
.08239 .0118 Mdot
.0667 .0118 Mdot
.0667 .01965 Mdot
.07062 .02749 Mdot
.07062 .03533 Mdot
.05494 .02357 Mdot
.05494 .02749 Mdot
.05886 .02749 Mdot
.09415 .05102 Mdot
.11768 .06278 Mdot
.13728 .06278 Mdot
.15297 .08631 Mdot
.16473 .09807 Mdot
.1765 .10199 Mdot
.18042 .10199 Mdot
.17257 .09415 Mdot
.16865 .09807 Mdot
.17257 .09807 Mdot
.17257 .09023 Mdot
.18434 .09807 Mdot
.18826 .10591 Mdot
.19218 .11768 Mdot
.18826 .1216 Mdot
.19218 .11768 Mdot
.20002 .1216 Mdot
.1961 .1216 Mdot
.20002 .13336 Mdot
.20002 .13336 Mdot
.20002 .13728 Mdot
.20394 .1412 Mdot
.20787 .14513 Mdot
.21571 .14513 Mdot
.21179 .1412 Mdot
.21179 .1412 Mdot
.21179 .1412 Mdot
.20394 .13728 Mdot
.20787 .13336 Mdot
.21571 .1412 Mdot
.21571 .13728 Mdot
.20787 .13336 Mdot
.21179 .13728 Mdot
.21571 .1412 Mdot
.20394 .13728 Mdot
.1961 .12552 Mdot
.18042 .10983 Mdot
.18826 .1216 Mdot
.1765 .1216 Mdot
.18826 .12552 Mdot
.19218 .12552 Mdot
.20394 .1412 Mdot
.21179 .14905 Mdot
.21571 .15297 Mdot
.20787 .14513 Mdot
.20787 .13728 Mdot
.20787 .13728 Mdot
.21179 .1412 Mdot
.20002 .12552 Mdot
.21571 .12944 Mdot
.21179 .12552 Mdot
.21571 .12552 Mdot
.21963 .12552 Mdot
.22747 .1412 Mdot
.23531 .13728 Mdot
.23531 .13336 Mdot
.24316 .13728 Mdot
.24316 .1412 Mdot
.24316 .14905 Mdot
.23139 .1412 Mdot
.22747 .13728 Mdot
.23139 .1412 Mdot
.22747 .1412 Mdot
.22747 .15297 Mdot
.23531 .15689 Mdot
.23139 .15689 Mdot
.23531 .15689 Mdot
.21963 .1412 Mdot
.21571 .13336 Mdot
.21179 .13336 Mdot
.20787 .13728 Mdot
.20787 .13336 Mdot
.20787 .13728 Mdot
.20787 .13336 Mdot
.1961 .12552 Mdot
.20002 .11768 Mdot
.20002 .11376 Mdot
.20002 .11376 Mdot
.21963 .1216 Mdot
.21571 .1216 Mdot
.22355 .13728 Mdot
.22355 .13728 Mdot
.23139 .13336 Mdot
.23531 .13336 Mdot
.24316 .14905 Mdot
.23924 .15297 Mdot
.24316 .15297 Mdot
.22355 .13728 Mdot
.20787 .12552 Mdot
.21571 .13336 Mdot
.23531 .14513 Mdot
.23924 .14513 Mdot
.23139 .13728 Mdot
.23139 .13728 Mdot
.21179 .12552 Mdot
.21571 .12552 Mdot
.21179 .11768 Mdot
.20002 .10983 Mdot
.20787 .1216 Mdot
.21571 .12944 Mdot
.20002 .12552 Mdot
.20002 .12944 Mdot
.19218 .13728 Mdot
.1961 .14513 Mdot
.1961 .14513 Mdot
.20002 .13728 Mdot
.1961 .13336 Mdot
.18826 .13728 Mdot
.18434 .1412 Mdot
.19218 .1412 Mdot
.1961 .13336 Mdot
.1961 .12552 Mdot
.18826 .11376 Mdot
.1765 .09415 Mdot
.16865 .07846 Mdot
.1765 .07846 Mdot
.16081 .07454 Mdot
.16473 .09023 Mdot
.18042 .11376 Mdot
.17257 .11376 Mdot
.15689 .10591 Mdot
.15689 .10983 Mdot
.15297 .10199 Mdot
.14513 .09415 Mdot
.14905 .09807 Mdot
.15689 .10199 Mdot
.15297 .09807 Mdot
.13336 .08239 Mdot
.13336 .08239 Mdot
.13336 .07846 Mdot
.14513 .08631 Mdot
.13336 .07454 Mdot
.12552 .05494 Mdot
.13728 .06278 Mdot
.13728 .07062 Mdot
.13728 .07062 Mdot
.12552 .0667 Mdot
.10591 .05886 Mdot
.09807 .05494 Mdot
.11768 .07454 Mdot
.10983 .07062 Mdot
.11376 .07454 Mdot
.09415 .06278 Mdot
.09023 .05494 Mdot
.03533 .02749 Mdot
.04317 .01965 Mdot
.03925 .00788 Mdot
.03925 .00788 Mdot
.02749 .00396 Mdot
.03141 .00396 Mdot
.03533 .00396 Mdot
.03141 .00396 Mdot
.03533 .00396 Mdot
.0667 .0118 Mdot
.08239 .03925 Mdot
.10591 .05494 Mdot
.09023 .04709 Mdot
.07062 .03533 Mdot
.05886 .02357 Mdot
.04709 .01965 Mdot
.04709 .01572 Mdot
.07454 .02357 Mdot
.09415 .02749 Mdot
.12944 .05102 Mdot
.14905 .0667 Mdot
.17257 .08631 Mdot
.19218 .10983 Mdot
.18826 .10199 Mdot
.19218 .11768 Mdot
.18434 .11768 Mdot
.19218 .11768 Mdot
.1961 .11768 Mdot
.18434 .11376 Mdot
.18042 .10199 Mdot
.19218 .10199 Mdot
.20002 .10591 Mdot
.19218 .09807 Mdot
.1961 .10591 Mdot
.21179 .12552 Mdot
.19218 .1216 Mdot
.20002 .13336 Mdot
.20002 .13728 Mdot
.20787 .15297 Mdot
.22355 .16473 Mdot
.21963 .15689 Mdot
.22355 .15689 Mdot
.21571 .15297 Mdot
.20787 .1412 Mdot
.21179 .14513 Mdot
.21963 .1412 Mdot
.21963 .1412 Mdot
.22747 .14513 Mdot
.22747 .1412 Mdot
.21963 .14513 Mdot
.21963 .14513 Mdot
.20002 .12552 Mdot
.18042 .10983 Mdot
.18434 .11376 Mdot
.1961 .12944 Mdot
.1961 .13336 Mdot
.20787 .13728 Mdot
.21179 .1412 Mdot
.21963 .14513 Mdot
.22355 .14905 Mdot
.21963 .14513 Mdot
.21179 .1412 Mdot
.21963 .1412 Mdot
.22355 .14513 Mdot
.22747 .1412 Mdot
.21963 .12552 Mdot
.23139 .12944 Mdot
.21179 .1216 Mdot
.20787 .11376 Mdot
.20787 .12552 Mdot
.21179 .12944 Mdot
.21963 .13336 Mdot
.23531 .1412 Mdot
.23924 .1412 Mdot
.23139 .1412 Mdot
.22355 .13336 Mdot
.21963 .12944 Mdot
.22747 .13728 Mdot
.21963 .12944 Mdot
.23139 .14513 Mdot
.23531 .15689 Mdot
.23924 .16473 Mdot
.23531 .16081 Mdot
.22747 .14905 Mdot
.22747 .1412 Mdot
.22747 .1412 Mdot
.21571 .14513 Mdot
.20787 .1412 Mdot
.21571 .14905 Mdot
.20394 .13728 Mdot
.1961 .12552 Mdot
.20002 .11376 Mdot
.20002 .11376 Mdot
.20787 .11768 Mdot
.21179 .1216 Mdot
.23139 .12944 Mdot
.22747 .12552 Mdot
.21571 .1216 Mdot
.22747 .12944 Mdot
.23139 .13336 Mdot
.22355 .13728 Mdot
.23531 .14513 Mdot
.23924 .15689 Mdot
.22355 .14513 Mdot
.21179 .1412 Mdot
.1961 .12552 Mdot
.20394 .12944 Mdot
.22355 .14905 Mdot
.24316 .16081 Mdot
.22747 .14905 Mdot
.23531 .15297 Mdot
.23531 .14513 Mdot
.22747 .13336 Mdot
.22355 .12944 Mdot
.22747 .12552 Mdot
.23139 .12944 Mdot
.20787 .11376 Mdot
.20394 .11768 Mdot
.20787 .12944 Mdot
.20394 .13728 Mdot
.21179 .14905 Mdot
.21179 .15297 Mdot
.20394 .15297 Mdot
.20002 .15297 Mdot
.19218 .15297 Mdot
.18826 .14905 Mdot
.18434 .13728 Mdot
.18826 .13336 Mdot
.18434 .11376 Mdot
.18826 .09807 Mdot
.18434 .09023 Mdot
.17257 .07846 Mdot
.16865 .08631 Mdot
.16865 .09415 Mdot
.18042 .11376 Mdot
.1765 .11768 Mdot
.18042 .12552 Mdot
.16865 .1216 Mdot
.15689 .10983 Mdot
.16081 .11768 Mdot
.13728 .10199 Mdot
.12944 .09807 Mdot
.12944 .09415 Mdot
.14513 .09023 Mdot
.14905 .08631 Mdot
.14513 .09023 Mdot
.14905 .09023 Mdot
.1412 .09023 Mdot
.13336 .08239 Mdot
.1216 .0667 Mdot
.12552 .06278 Mdot
.13336 .07454 Mdot
.12944 .07062 Mdot
.12944 .07062 Mdot
.1216 .06278 Mdot
.11768 .0667 Mdot
.11376 .07454 Mdot
.11768 .07454 Mdot
.10199 .05886 Mdot
.08631 .04317 Mdot
.03925 .02357 Mdot
.03533 .0118 Mdot
.04317 .00788 Mdot
.04709 .00788 Mdot
.04317 .00396 Mdot
.02749 .00396 Mdot
.01965 .00396 Mdot
.02749 .00396 Mdot
.03533 .00396 Mdot
.02749 .00396 Mdot
.07846 .02357 Mdot
.10199 .04317 Mdot
.09807 .04317 Mdot
.08239 .03533 Mdot
.05494 .01572 Mdot
.05102 .00788 Mdot
.04709 .00788 Mdot
.03533 .00396 Mdot
.04709 .00788 Mdot
.08239 .02357 Mdot
.12552 .05886 Mdot
.15297 .09023 Mdot
.17257 .11376 Mdot
.18826 .12944 Mdot
.20787 .15297 Mdot
.20787 .15689 Mdot
.21571 .15297 Mdot
.20002 .13336 Mdot
.20002 .1216 Mdot
.19218 .10199 Mdot
.18434 .08631 Mdot
.19218 .08239 Mdot
.20394 .09415 Mdot
.20394 .10199 Mdot
.20394 .11376 Mdot
.20787 .12944 Mdot
.20787 .1412 Mdot
.21179 .15689 Mdot
.20394 .16473 Mdot
.20787 .1765 Mdot
.20787 .17257 Mdot
.21571 .1765 Mdot
.21571 .16865 Mdot
.21571 .16473 Mdot
.22355 .15297 Mdot
.23139 .14905 Mdot
.23531 .15297 Mdot
.22747 .14513 Mdot
.23531 .14513 Mdot
.22355 .13336 Mdot
.21963 .13336 Mdot
.21179 .12552 Mdot
.21179 .12944 Mdot
.22355 .14513 Mdot
.21963 .14905 Mdot
.21179 .15689 Mdot
.21179 .16473 Mdot
.22355 .16865 Mdot
.21179 .15297 Mdot
.22355 .14905 Mdot
.22747 .14905 Mdot
.21179 .1412 Mdot
.21179 .13336 Mdot
.21571 .13728 Mdot
.22747 .13728 Mdot
.23531 .13336 Mdot
.22747 .12552 Mdot
.22355 .12552 Mdot
.22355 .12944 Mdot
.21571 .13336 Mdot
.21571 .13336 Mdot
.21571 .13336 Mdot
.21963 .14513 Mdot
.22355 .14513 Mdot
.21963 .1412 Mdot
.23531 .15297 Mdot
.24316 .15689 Mdot
.23139 .1412 Mdot
.24708 .14513 Mdot
.23924 .1412 Mdot
.25492 .16473 Mdot
.24316 .15689 Mdot
.26276 .16473 Mdot
.24708 .14905 Mdot
.22747 .1412 Mdot
.22355 .14513 Mdot
.21963 .14905 Mdot
.21571 .14513 Mdot
.20787 .14513 Mdot
.21179 .14905 Mdot
.20002 .13728 Mdot
.20394 .12552 Mdot
.20002 .1216 Mdot
.20787 .12944 Mdot
.20787 .11768 Mdot
.23531 .12944 Mdot
.23531 .11768 Mdot
.23139 .11376 Mdot
.21571 .10591 Mdot
.22747 .11768 Mdot
.22747 .12552 Mdot
.23531 .1412 Mdot
.24708 .14905 Mdot
.23531 .15297 Mdot
.21963 .14905 Mdot
.22747 .16865 Mdot
.21179 .16081 Mdot
.21179 .16081 Mdot
.22747 .16473 Mdot
.23924 .17257 Mdot
.24316 .16081 Mdot
.24316 .16081 Mdot
.24316 .15689 Mdot
.23924 .1412 Mdot
.23139 .12944 Mdot
.22355 .12552 Mdot
.21963 .1216 Mdot
.21179 .12552 Mdot
.21571 .13728 Mdot
.21179 .1412 Mdot
.20787 .14513 Mdot
.20787 .15689 Mdot
.21179 .16473 Mdot
.20787 .16081 Mdot
.20002 .16081 Mdot
.18826 .15297 Mdot
.1961 .15297 Mdot
.1765 .12944 Mdot
.18826 .1216 Mdot
.19218 .11376 Mdot
.19218 .10591 Mdot
.18826 .10199 Mdot
.18434 .09807 Mdot
.18826 .10983 Mdot
.19218 .11376 Mdot
.18826 .11376 Mdot
.1765 .11768 Mdot
.17257 .11376 Mdot
.18042 .12552 Mdot
.16473 .11768 Mdot
.1412 .09807 Mdot
.13336 .09415 Mdot
.13336 .09023 Mdot
.13728 .09415 Mdot
.14513 .10199 Mdot
.14905 .10591 Mdot
.15297 .10983 Mdot
.15689 .1216 Mdot
.15689 .11768 Mdot
.15297 .10199 Mdot
.1412 .08631 Mdot
.14513 .08631 Mdot
.13336 .07062 Mdot
.13336 .06278 Mdot
.13336 .06278 Mdot
.1216 .05494 Mdot
.12552 .06278 Mdot
.10983 .05102 Mdot
.09807 .03925 Mdot
.08631 .02749 Mdot
.04709 .0118 Mdot
.04709 .01965 Mdot
.05494 .01965 Mdot
.06278 .01572 Mdot
.05102 .0118 Mdot
.04709 .00396 Mdot
.03925 .00396 Mdot
.05102 .00788 Mdot
.04317 .00396 Mdot
.03533 .00396 Mdot
.05102 .00396 Mdot
.05102 .00788 Mdot
.06278 .01572 Mdot
.05886 .00788 Mdot
.06278 .00788 Mdot
.05494 .00788 Mdot
.04317 .00788 Mdot
.03141 .00788 Mdot
.01965 .00396 Mdot
.02749 .00788 Mdot
.05494 .03533 Mdot
.11376 .09023 Mdot
.16081 .13728 Mdot
.18826 .16081 Mdot
.20394 .1765 Mdot
.20787 .1765 Mdot
.21963 .17257 Mdot
.21963 .14905 Mdot
.21571 .13336 Mdot
.20394 .11376 Mdot
.21179 .10199 Mdot
.20787 .08631 Mdot
.21571 .08631 Mdot
.20787 .09023 Mdot
.19218 .09415 Mdot
.1961 .11376 Mdot
.21179 .14513 Mdot
.20787 .15297 Mdot
.21179 .16473 Mdot
.20394 .17257 Mdot
.20787 .18434 Mdot
.20787 .18434 Mdot
.21571 .18042 Mdot
.21571 .17257 Mdot
.23139 .16473 Mdot
.23924 .15689 Mdot
.23924 .15297 Mdot
.23139 .13728 Mdot
.23139 .13336 Mdot
.22747 .12944 Mdot
.24316 .14513 Mdot
.23531 .14905 Mdot
.23531 .15297 Mdot
.23531 .16473 Mdot
.22747 .18042 Mdot
.21179 .18042 Mdot
.21179 .18042 Mdot
.22355 .18434 Mdot
.23139 .17257 Mdot
.23924 .16081 Mdot
.23924 .14905 Mdot
.23139 .1412 Mdot
.21571 .12944 Mdot
.22747 .12944 Mdot
.23531 .13336 Mdot
.24316 .13728 Mdot
.23924 .13728 Mdot
.24708 .15297 Mdot
.24316 .16081 Mdot
.23139 .16081 Mdot
.23139 .16473 Mdot
.22355 .17257 Mdot
.21963 .16865 Mdot
.24708 .18042 Mdot
.24316 .16865 Mdot
.24708 .16473 Mdot
.25492 .16865 Mdot
.25492 .15689 Mdot
.24708 .14513 Mdot
.23531 .13336 Mdot
.24316 .1412 Mdot
.251 .14513 Mdot
.25492 .14905 Mdot
.25492 .16081 Mdot
.23531 .16473 Mdot
.23531 .17257 Mdot
.21571 .16081 Mdot
.20787 .16081 Mdot
.20787 .16081 Mdot
.21571 .15689 Mdot
.20394 .14513 Mdot
.21179 .14513 Mdot
.21179 .1412 Mdot
.20787 .12944 Mdot
.21179 .11376 Mdot
.22355 .10983 Mdot
.23531 .10199 Mdot
.24316 .09807 Mdot
.23924 .08631 Mdot
.23531 .09807 Mdot
.24708 .13336 Mdot
.23531 .13728 Mdot
.24708 .15297 Mdot
.25492 .1765 Mdot
.24708 .18434 Mdot
.24316 .18826 Mdot
.23531 .18434 Mdot
.22355 .18042 Mdot
.20787 .15689 Mdot
.21963 .14905 Mdot
.23139 .14905 Mdot
.24316 .14513 Mdot
.251 .14513 Mdot
.24316 .13336 Mdot
.23531 .12552 Mdot
.22355 .1216 Mdot
.23139 .13336 Mdot
.22355 .13728 Mdot
.22747 .14513 Mdot
.21179 .14905 Mdot
.21963 .16865 Mdot
.21571 .1765 Mdot
.20787 .1765 Mdot
.21571 .18042 Mdot
.20787 .17257 Mdot
.1961 .15689 Mdot
.1961 .15297 Mdot
.1961 .1412 Mdot
.20002 .13336 Mdot
.20002 .12944 Mdot
.1961 .11376 Mdot
.20394 .11376 Mdot
.1961 .10591 Mdot
.18434 .10983 Mdot
.18434 .10983 Mdot
.18826 .11376 Mdot
.17257 .10983 Mdot
.18042 .12552 Mdot
.18042 .13336 Mdot
.16865 .12944 Mdot
.15689 .12552 Mdot
.14513 .11768 Mdot
.1412 .11376 Mdot
.1412 .11376 Mdot
.15297 .11768 Mdot
.14905 .11768 Mdot
.15689 .1216 Mdot
.16081 .1216 Mdot
.16081 .1216 Mdot
.15297 .10591 Mdot
.15297 .09415 Mdot
.14905 .08239 Mdot
.15297 .07454 Mdot
.1412 .05886 Mdot
.14905 .05886 Mdot
.15297 .06278 Mdot
.14905 .05886 Mdot
.14513 .05494 Mdot
.13336 .04709 Mdot
.09415 .03141 Mdot
.04709 .01965 Mdot
.05494 .02357 Mdot
.07062 .03141 Mdot
.0667 .02357 Mdot
.05494 .01965 Mdot
.03925 .0118 Mdot
.03533 .00396 Mdot
.04709 .00788 Mdot
.04317 .00396 Mdot
.05102 .00788 Mdot
.04709 .00396 Mdot
.03141 .00396 Mdot
.03925 .00396 Mdot
.05494 .00788 Mdot
.05494 .01572 Mdot
.05102 .01572 Mdot
.05494 .02357 Mdot
.03925 .02357 Mdot
.02357 .02357 Mdot
.01965 .03141 Mdot
.01572 .03533 Mdot
.07454 .08239 Mdot
.10983 .11376 Mdot
.15689 .15297 Mdot
.18826 .16865 Mdot
.20787 .17257 Mdot
.21179 .15689 Mdot
.22355 .14513 Mdot
.22355 .12552 Mdot
.21571 .10983 Mdot
.21179 .10199 Mdot
.21963 .09415 Mdot
.22747 .09807 Mdot
.21963 .10983 Mdot
.21179 .11768 Mdot
.21571 .13336 Mdot
.21963 .15297 Mdot
.21963 .16865 Mdot
.21963 .16865 Mdot
.21571 .17257 Mdot
.21963 .18434 Mdot
.23139 .18826 Mdot
.23531 .18042 Mdot
.23139 .16865 Mdot
.24708 .16473 Mdot
.23531 .15297 Mdot
.24316 .15297 Mdot
.26276 .16473 Mdot
.25492 .15689 Mdot
.24708 .14905 Mdot
.24316 .15689 Mdot
.24316 .17257 Mdot
.24316 .18434 Mdot
.22747 .18434 Mdot
.23531 .1961 Mdot
.23531 .20002 Mdot
.23924 .20394 Mdot
.24316 .1961 Mdot
.24316 .18434 Mdot
.23924 .17257 Mdot
.24708 .16865 Mdot
.24708 .15689 Mdot
.23531 .1412 Mdot
.24316 .1412 Mdot
.24708 .1412 Mdot
.251 .14905 Mdot
.24316 .15689 Mdot
.24708 .17257 Mdot
.24316 .18434 Mdot
.22747 .18434 Mdot
.22747 .1961 Mdot
.23531 .20002 Mdot
.23924 .1961 Mdot
.23139 .18434 Mdot
.24708 .18434 Mdot
.24708 .17257 Mdot
.26668 .17257 Mdot
.26668 .15689 Mdot
.25884 .15689 Mdot
.251 .14905 Mdot
.24708 .14905 Mdot
.23924 .14513 Mdot
.25492 .16473 Mdot
.24708 .17257 Mdot
.24708 .19218 Mdot
.24708 .20002 Mdot
.23924 .19218 Mdot
.22747 .18042 Mdot
.23924 .1765 Mdot
.23139 .16473 Mdot
.21963 .14905 Mdot
.22747 .14905 Mdot
.21571 .13336 Mdot
.21963 .1216 Mdot
.20787 .10199 Mdot
.20002 .08239 Mdot
.20787 .08239 Mdot
.21571 .08239 Mdot
.22747 .08631 Mdot
.23924 .10199 Mdot
.22747 .12552 Mdot
.23139 .13728 Mdot
.24316 .16081 Mdot
.251 .16865 Mdot
.25492 .18042 Mdot
.25492 .18826 Mdot
.25492 .18434 Mdot
.24708 .17257 Mdot
.23531 .15297 Mdot
.22747 .12944 Mdot
.21963 .10199 Mdot
.22747 .09807 Mdot
.23139 .10199 Mdot
.23139 .10591 Mdot
.23139 .11768 Mdot
.22747 .12944 Mdot
.22747 .14905 Mdot
.21571 .14905 Mdot
.20394 .15689 Mdot
.20002 .16081 Mdot
.1961 .15689 Mdot
.20787 .17257 Mdot
.22355 .19218 Mdot
.20394 .17257 Mdot
.20787 .16473 Mdot
.19218 .14905 Mdot
.20002 .1412 Mdot
.19218 .12944 Mdot
.20394 .13336 Mdot
.21571 .1412 Mdot
.20394 .12944 Mdot
.20394 .1216 Mdot
.20002 .11768 Mdot
.18826 .1216 Mdot
.19218 .12552 Mdot
.19218 .13336 Mdot
.19218 .14513 Mdot
.18434 .14905 Mdot
.16473 .13728 Mdot
.17257 .14513 Mdot
.16865 .14513 Mdot
.16865 .14513 Mdot
.15297 .12944 Mdot
.13728 .11376 Mdot
.14905 .11768 Mdot
.14905 .10983 Mdot
.16081 .11376 Mdot
.16473 .10983 Mdot
.16865 .10983 Mdot
.16473 .09807 Mdot
.15689 .07846 Mdot
.16081 .07454 Mdot
.16081 .07062 Mdot
.15689 .05886 Mdot
.14513 .04317 Mdot
.14905 .04709 Mdot
.1412 .04317 Mdot
.1412 .05102 Mdot
.12944 .05494 Mdot
.10983 .05102 Mdot
.07062 .03925 Mdot
.06278 .03533 Mdot
.0667 .03533 Mdot
.05494 .02357 Mdot
.03533 .0118 Mdot
.02749 .0118 Mdot
.03141 .00788 Mdot
.05494 .01965 Mdot
.0667 .02357 Mdot
.05886 .00788 Mdot
.05886 .00788 Mdot
.04317 .00396 Mdot
.04709 .00396 Mdot
.05494 .0118 Mdot
.0667 .02357 Mdot
.05494 .01965 Mdot
.03925 .01572 Mdot
.02357 .00788 Mdot
.01572 .00788 Mdot
.02749 .03141 Mdot
.03533 .04317 Mdot
.03141 .04709 Mdot
.05886 .07846 Mdot
.10591 .11768 Mdot
.16081 .14905 Mdot
.18434 .15689 Mdot
.20002 .16081 Mdot
.20787 .14513 Mdot
.20787 .13336 Mdot
.21963 .12552 Mdot
.22355 .1216 Mdot
.21963 .11768 Mdot
.21963 .11768 Mdot
.21179 .10983 Mdot
.21571 .12552 Mdot
.20394 .13728 Mdot
.21963 .15689 Mdot
.22747 .1765 Mdot
.21571 .1765 Mdot
.22355 .18434 Mdot
.23531 .20002 Mdot
.23139 .19218 Mdot
.23531 .18042 Mdot
.23139 .16473 Mdot
.23924 .15689 Mdot
.23531 .1412 Mdot
.251 .14513 Mdot
.251 .14905 Mdot
.251 .15297 Mdot
.24708 .15297 Mdot
.23924 .15689 Mdot
.23139 .15689 Mdot
.24708 .1765 Mdot
.23531 .18434 Mdot
.24316 .18826 Mdot
.23924 .18826 Mdot
.23924 .1961 Mdot
.23531 .18826 Mdot
.23139 .18042 Mdot
.24316 .18434 Mdot
.251 .18042 Mdot
.251 .17257 Mdot
.24316 .15689 Mdot
.23924 .14905 Mdot
.23531 .1412 Mdot
.23924 .14513 Mdot
.23924 .15689 Mdot
.23924 .16865 Mdot
.22355 .18042 Mdot
.22355 .18826 Mdot
.23924 .20787 Mdot
.22355 .20787 Mdot
.22355 .20002 Mdot
.24708 .20787 Mdot
.251 .1961 Mdot
.25884 .18042 Mdot
.26668 .16865 Mdot
.27061 .16473 Mdot
.25884 .15297 Mdot
.24708 .14513 Mdot
.24316 .15297 Mdot
.23531 .16081 Mdot
.251 .17257 Mdot
.24708 .18042 Mdot
.25492 .1961 Mdot
.25884 .20002 Mdot
.25492 .20394 Mdot
.24316 .19218 Mdot
.24316 .18434 Mdot
.23924 .16865 Mdot
.24316 .16081 Mdot
.23139 .13728 Mdot
.21963 .12552 Mdot
.21963 .10983 Mdot
.20787 .09415 Mdot
.1961 .09023 Mdot
.1961 .08631 Mdot
.1961 .08631 Mdot
.20394 .08631 Mdot
.21571 .09023 Mdot
.21179 .10983 Mdot
.21179 .11768 Mdot
.22747 .1412 Mdot
.22747 .14905 Mdot
.22355 .16081 Mdot
.23139 .1765 Mdot
.24316 .17257 Mdot
.23531 .15689 Mdot
.23139 .14513 Mdot
.22747 .12552 Mdot
.21571 .10983 Mdot
.21963 .10199 Mdot
.22747 .10591 Mdot
.21963 .10591 Mdot
.22747 .11768 Mdot
.22747 .12944 Mdot
.22355 .1412 Mdot
.22355 .15297 Mdot
.21571 .16865 Mdot
.1961 .15689 Mdot
.19218 .15297 Mdot
.19218 .15689 Mdot
.18434 .15297 Mdot
.1961 .16865 Mdot
.20002 .15689 Mdot
.20394 .14905 Mdot
.21179 .14905 Mdot
.20787 .13728 Mdot
.19218 .1216 Mdot
.20394 .13336 Mdot
.20394 .13728 Mdot
.20002 .12552 Mdot
.20002 .1216 Mdot
.19218 .11768 Mdot
.19218 .12552 Mdot
.18434 .12552 Mdot
.1765 .12944 Mdot
.1961 .15297 Mdot
.18042 .14905 Mdot
.18826 .15689 Mdot
.18042 .16081 Mdot
.16865 .14905 Mdot
.15689 .12944 Mdot
.14905 .11768 Mdot
.15297 .11376 Mdot
.14513 .10591 Mdot
.15689 .10591 Mdot
.16081 .09807 Mdot
.15689 .09023 Mdot
.16473 .09023 Mdot
.16081 .09023 Mdot
.15297 .07846 Mdot
.15297 .07062 Mdot
.14513 .05886 Mdot
.12552 .04317 Mdot
.1412 .04709 Mdot
.1412 .05886 Mdot
.13336 .05886 Mdot
.12944 .05494 Mdot
.1216 .05494 Mdot
.08239 .05494 Mdot
.06278 .05102 Mdot
.05102 .03925 Mdot
.04709 .03141 Mdot
.05102 .03925 Mdot
.03925 .02357 Mdot
.03141 .0118 Mdot
.03533 .00788 Mdot
.05102 .01572 Mdot
.03533 .00788 Mdot
.03533 .00788 Mdot
.03925 .00396 Mdot
.04317 .00396 Mdot
.05102 .00788 Mdot
.03925 .00788 Mdot
.03533 .00788 Mdot
.03141 .00788 Mdot
.01965 .00396 Mdot
.00788 .00396 Mdot
.05494 .03141 Mdot
.08631 .07062 Mdot
.09023 .08631 Mdot
.08631 .10199 Mdot
.09807 .11768 Mdot
.11768 .14513 Mdot
.14905 .16473 Mdot
.18042 .1765 Mdot
.1961 .1765 Mdot
.20002 .16473 Mdot
.20787 .15689 Mdot
.20787 .14513 Mdot
.21963 .13728 Mdot
.21963 .12944 Mdot
.21571 .12552 Mdot
.21963 .12944 Mdot
.21963 .13728 Mdot
.22355 .14905 Mdot
.23139 .17257 Mdot
.23139 .18042 Mdot
.22355 .18042 Mdot
.22747 .18826 Mdot
.22355 .18826 Mdot
.23139 .18434 Mdot
.24316 .18826 Mdot
.23924 .16865 Mdot
.24316 .16473 Mdot
.25492 .16473 Mdot
.25492 .15297 Mdot
.26276 .15689 Mdot
.25884 .15297 Mdot
.25492 .14905 Mdot
.24708 .14513 Mdot
.251 .15689 Mdot
.24708 .16473 Mdot
.251 .1765 Mdot
.25492 .19218 Mdot
.24316 .1961 Mdot
.24708 .20002 Mdot
.24316 .20002 Mdot
.24316 .1961 Mdot
.23924 .19218 Mdot
.25492 .1961 Mdot
.25492 .18434 Mdot
.24316 .15689 Mdot
.23531 .13728 Mdot
.24316 .1412 Mdot
.24316 .1412 Mdot
.23531 .14513 Mdot
.23924 .15689 Mdot
.23531 .16865 Mdot
.23531 .18434 Mdot
.23531 .1961 Mdot
.22355 .19218 Mdot
.22747 .19218 Mdot
.23924 .19218 Mdot
.26276 .18826 Mdot
.26668 .18434 Mdot
.27845 .18042 Mdot
.28629 .17257 Mdot
.28237 .16473 Mdot
.27453 .16865 Mdot
.26276 .16865 Mdot
.25884 .17257 Mdot
.26668 .18434 Mdot
.25884 .18042 Mdot
.25884 .19218 Mdot
.26276 .20002 Mdot
.251 .20002 Mdot
.26276 .20002 Mdot
.25492 .18826 Mdot
.251 .18042 Mdot
.23924 .16473 Mdot
.21963 .1412 Mdot
.20787 .12552 Mdot
.1961 .10983 Mdot
.18434 .09807 Mdot
.1961 .10591 Mdot
.20002 .10591 Mdot
.19218 .09807 Mdot
.20394 .10199 Mdot
.20002 .10199 Mdot
.20787 .1216 Mdot
.21179 .13336 Mdot
.22747 .14513 Mdot
.23531 .15689 Mdot
.23139 .16081 Mdot
.23924 .16865 Mdot
.22747 .15297 Mdot
.22747 .14905 Mdot
.22355 .14513 Mdot
.23531 .14513 Mdot
.23531 .13336 Mdot
.22355 .11768 Mdot
.22355 .11376 Mdot
.22747 .11768 Mdot
.23139 .1216 Mdot
.23139 .12944 Mdot
.23531 .14513 Mdot
.23531 .15689 Mdot
.21179 .14905 Mdot
.20002 .14513 Mdot
.20002 .15689 Mdot
.18826 .15689 Mdot
.18434 .15297 Mdot
.19218 .15297 Mdot
.20394 .15297 Mdot
.20787 .14513 Mdot
.20787 .14513 Mdot
.20394 .13728 Mdot
.21179 .14513 Mdot
.20787 .13728 Mdot
.21179 .13728 Mdot
.20002 .12552 Mdot
.1961 .1216 Mdot
.1961 .1216 Mdot
.20002 .12944 Mdot
.18042 .12552 Mdot
.1765 .13336 Mdot
.18434 .13728 Mdot
.1765 .13728 Mdot
.18042 .13728 Mdot
.18434 .1412 Mdot
.17257 .12944 Mdot
.15689 .11768 Mdot
.16081 .11376 Mdot
.14513 .10591 Mdot
.14513 .10199 Mdot
.15297 .10199 Mdot
.14513 .09807 Mdot
.14905 .09415 Mdot
.16081 .09807 Mdot
.15297 .09807 Mdot
.15297 .09415 Mdot
.14905 .08631 Mdot
.1412 .07454 Mdot
.13728 .0667 Mdot
.13728 .0667 Mdot
.13336 .0667 Mdot
.12944 .07062 Mdot
.1216 .07062 Mdot
.0667 .04317 Mdot
.05886 .04709 Mdot
.04709 .03141 Mdot
.05102 .03141 Mdot
.05494 .03141 Mdot
.03925 .02357 Mdot
.03533 .01572 Mdot
.03925 .01965 Mdot
.02749 .0118 Mdot
.03533 .01572 Mdot
.04317 .01572 Mdot
.03925 .0118 Mdot
.03925 .00788 Mdot
.04317 .00788 Mdot
.03533 .00396 Mdot
.03141 .00396 Mdot
.02749 .00396 Mdot
.01965 .00396 Mdot
.0118 .00396 Mdot
.01965 .00396 Mdot
.07454 .04709 Mdot
.13336 .10199 Mdot
.1961 .16865 Mdot
.21571 .1961 Mdot
.20002 .20002 Mdot
.18826 .18826 Mdot
.19218 .19218 Mdot
.20394 .1961 Mdot
.21963 .20002 Mdot
.20002 .18042 Mdot
.1961 .15689 Mdot
.19218 .13728 Mdot
.19218 .12552 Mdot
.18826 .1216 Mdot
.19218 .11768 Mdot
.19218 .11376 Mdot
.20394 .12552 Mdot
.21571 .13728 Mdot
.21963 .15689 Mdot
.21571 .16865 Mdot
.21963 .1765 Mdot
.22747 .18042 Mdot
.21963 .1765 Mdot
.23924 .18826 Mdot
.21963 .16473 Mdot
.22747 .16473 Mdot
.23139 .14905 Mdot
.24708 .15689 Mdot
.23531 .14905 Mdot
.24316 .14513 Mdot
.23924 .1412 Mdot
.23531 .13336 Mdot
.24316 .14513 Mdot
.24316 .14905 Mdot
.251 .16865 Mdot
.25884 .1765 Mdot
.24316 .16865 Mdot
.23531 .16865 Mdot
.24708 .18434 Mdot
.23924 .18826 Mdot
.25492 .1961 Mdot
.251 .1961 Mdot
.25492 .19218 Mdot
.251 .18042 Mdot
.251 .16865 Mdot
.24708 .15297 Mdot
.24708 .14905 Mdot
.23531 .13728 Mdot
.23924 .1412 Mdot
.23531 .13728 Mdot
.24316 .15297 Mdot
.24708 .16473 Mdot
.24316 .17257 Mdot
.23924 .17257 Mdot
.23924 .16865 Mdot
.24708 .17257 Mdot
.27453 .18826 Mdot
.28237 .18042 Mdot
.27845 .17257 Mdot
.27061 .16473 Mdot
.27453 .17257 Mdot
.26276 .16865 Mdot
.26276 .1765 Mdot
.24316 .16081 Mdot
.251 .16865 Mdot
.25492 .17257 Mdot
.25884 .18042 Mdot
.26276 .19218 Mdot
.26276 .20002 Mdot
.25884 .1961 Mdot
.25884 .19218 Mdot
.24316 .17257 Mdot
.21179 .1412 Mdot
.20394 .12944 Mdot
.19218 .1216 Mdot
.19218 .11768 Mdot
.19218 .11768 Mdot
.19218 .11376 Mdot
.19218 .11376 Mdot
.20394 .11768 Mdot
.18826 .11376 Mdot
.18434 .10591 Mdot
.1961 .10983 Mdot
.20002 .11768 Mdot
.20394 .12944 Mdot
.21571 .13336 Mdot
.21571 .13336 Mdot
.22355 .1412 Mdot
.22747 .14513 Mdot
.23531 .14905 Mdot
.24316 .15689 Mdot
.25884 .16081 Mdot
.251 .15297 Mdot
.24316 .13336 Mdot
.23531 .12552 Mdot
.22747 .1216 Mdot
.20787 .10983 Mdot
.21963 .11768 Mdot
.24316 .1412 Mdot
.23531 .14905 Mdot
.21963 .14513 Mdot
.21179 .15297 Mdot
.20002 .15689 Mdot
.18434 .14513 Mdot
.18826 .14513 Mdot
.1961 .14905 Mdot
.20787 .16081 Mdot
.20787 .15689 Mdot
.20002 .14905 Mdot
.20002 .14905 Mdot
.20002 .1412 Mdot
.20002 .12944 Mdot
.19218 .1216 Mdot
.1961 .1216 Mdot
.20394 .11768 Mdot
.20002 .11768 Mdot
.18434 .11376 Mdot
.16865 .10983 Mdot
.1765 .11768 Mdot
.18042 .11376 Mdot
.18434 .10983 Mdot
.15689 .09415 Mdot
.1765 .10983 Mdot
.17257 .11768 Mdot
.16081 .11768 Mdot
.15297 .1216 Mdot
.14513 .11376 Mdot
.14905 .11376 Mdot
.14513 .1216 Mdot
.1412 .11376 Mdot
.1412 .11376 Mdot
.14513 .10591 Mdot
.14513 .09415 Mdot
.13336 .08631 Mdot
.13336 .08239 Mdot
.1412 .08631 Mdot
.14905 .08631 Mdot
.1412 .07846 Mdot
.12944 .07846 Mdot
.11768 .07454 Mdot
.04709 .01572 Mdot
.04709 .01965 Mdot
.05102 .02357 Mdot
.03925 .01572 Mdot
.03533 .0118 Mdot
.03533 .01572 Mdot
.05102 .02357 Mdot
.0667 .04317 Mdot
.0667 .04317 Mdot
.05494 .03533 Mdot
.0667 .03925 Mdot
.05886 .02357 Mdot
.05494 .0118 Mdot
.04709 .00788 Mdot
.03925 .00396 Mdot
.02749 .00396 Mdot
.02749 .00396 Mdot
.01965 .00396 Mdot
.01965 .00396 Mdot
.01965 .00396 Mdot
.0118 .00396 Mdot
.08631 .05494 Mdot
.27061 .1961 Mdot
.25884 .20002 Mdot
.22747 .19218 Mdot
.23139 .20002 Mdot
.22747 .20002 Mdot
.22355 .1961 Mdot
.25492 .21179 Mdot
.23924 .20002 Mdot
.18434 .15689 Mdot
.15689 .1216 Mdot
.15297 .10591 Mdot
.14513 .08631 Mdot
.14513 .07846 Mdot
.15689 .08239 Mdot
.16473 .08631 Mdot
.16473 .08631 Mdot
.18434 .10199 Mdot
.20394 .13336 Mdot
.21179 .15297 Mdot
.22355 .16473 Mdot
.23924 .17257 Mdot
.25884 .18826 Mdot
.25884 .18434 Mdot
.24708 .16865 Mdot
.251 .16473 Mdot
.251 .16081 Mdot
.23924 .15297 Mdot
.251 .16473 Mdot
.24316 .15689 Mdot
.251 .16473 Mdot
.24708 .16081 Mdot
.24708 .16473 Mdot
.24708 .16081 Mdot
.25492 .16473 Mdot
.25492 .16865 Mdot
.24708 .16473 Mdot
.251 .16865 Mdot
.24708 .16473 Mdot
.24708 .17257 Mdot
.25884 .18826 Mdot
.24708 .19218 Mdot
.251 .18826 Mdot
.25492 .18826 Mdot
.25492 .18042 Mdot
.25492 .17257 Mdot
.23924 .14513 Mdot
.24316 .14513 Mdot
.24708 .1412 Mdot
.251 .1412 Mdot
.25492 .1412 Mdot
.24708 .14513 Mdot
.251 .15689 Mdot
.24708 .16081 Mdot
.24708 .15297 Mdot
.26276 .16081 Mdot
.26276 .15297 Mdot
.26276 .16473 Mdot
.26276 .1765 Mdot
.25884 .18434 Mdot
.26276 .1961 Mdot
.24708 .18434 Mdot
.24316 .17257 Mdot
.24316 .16865 Mdot
.24708 .16865 Mdot
.25492 .16865 Mdot
.25884 .17257 Mdot
.25492 .17257 Mdot
.26276 .1765 Mdot
.27061 .18434 Mdot
.24316 .16081 Mdot
.22355 .14513 Mdot
.20787 .12944 Mdot
.20002 .12552 Mdot
.1961 .12552 Mdot
.19218 .11376 Mdot
.20394 .1216 Mdot
.20002 .1216 Mdot
.1961 .11376 Mdot
.18434 .10591 Mdot
.18042 .10983 Mdot
.18826 .11376 Mdot
.19218 .11376 Mdot
.1961 .11376 Mdot
.20002 .11376 Mdot
.20394 .11376 Mdot
.22355 .12552 Mdot
.23531 .13336 Mdot
.24316 .14513 Mdot
.23924 .15297 Mdot
.251 .16865 Mdot
.25492 .16865 Mdot
.251 .16473 Mdot
.24316 .14905 Mdot
.22355 .13336 Mdot
.20787 .11768 Mdot
.22355 .12552 Mdot
.23139 .13336 Mdot
.21963 .1216 Mdot
.21963 .12944 Mdot
.22355 .13728 Mdot
.20394 .13336 Mdot
.20002 .13336 Mdot
.1961 .12944 Mdot
.18826 .12552 Mdot
.1765 .11768 Mdot
.18826 .12552 Mdot
.20394 .14513 Mdot
.20394 .14905 Mdot
.1961 .14513 Mdot
.20002 .14513 Mdot
.1961 .1412 Mdot
.19218 .12944 Mdot
.20394 .12552 Mdot
.20787 .12944 Mdot
.18826 .11768 Mdot
.18434 .11768 Mdot
.16473 .10591 Mdot
.16081 .09807 Mdot
.1765 .09807 Mdot
.16081 .08239 Mdot
.15689 .07846 Mdot
.15297 .08631 Mdot
.16081 .10199 Mdot
.15297 .10591 Mdot
.13728 .10199 Mdot
.14513 .11376 Mdot
.13728 .11768 Mdot
.14905 .1216 Mdot
.15297 .1216 Mdot
.15297 .11768 Mdot
.13728 .10199 Mdot
.13336 .10199 Mdot
.14513 .10591 Mdot
.13336 .09415 Mdot
.13728 .09807 Mdot
.1412 .10591 Mdot
.13336 .10591 Mdot
.11768 .09023 Mdot
.04317 .0118 Mdot
.03925 .00396 Mdot
.05494 .0118 Mdot
.05494 .01572 Mdot
.03925 .0118 Mdot
.04709 .01965 Mdot
.07454 .03925 Mdot
.09415 .05886 Mdot
.10199 .0667 Mdot
.09023 .0667 Mdot
.10199 .07454 Mdot
.09415 .05494 Mdot
.08631 .03533 Mdot
.05886 .01965 Mdot
.04317 .0118 Mdot
.02749 .00788 Mdot
.03141 .00788 Mdot
.03141 .0118 Mdot
.02357 .00396 Mdot
.01572 .00396 Mdot
.03141 .0118 Mdot
.02749 .00788 Mdot
.10983 .06278 Mdot
.13728 .08239 Mdot
.20394 .1412 Mdot
.32158 .23139 Mdot
.22355 .15689 Mdot
.21571 .15689 Mdot
.25884 .18826 Mdot
.23924 .18042 Mdot
.11768 .09023 Mdot
.10199 .07846 Mdot
.08239 .05494 Mdot
.08631 .04709 Mdot
.09807 .04317 Mdot
.11768 .05102 Mdot
.12944 .05886 Mdot
.12552 .06278 Mdot
.15297 .08239 Mdot
.18826 .11768 Mdot
.21963 .14905 Mdot
.23531 .16865 Mdot
.251 .18042 Mdot
.26276 .18434 Mdot
.25492 .17257 Mdot
.26276 .17257 Mdot
.26276 .16473 Mdot
.27453 .16473 Mdot
.27061 .16081 Mdot
.27453 .17257 Mdot
.27453 .18042 Mdot
.26668 .18042 Mdot
.26276 .18042 Mdot
.25884 .1765 Mdot
.25492 .1765 Mdot
.26276 .1765 Mdot
.26276 .18042 Mdot
.26276 .18826 Mdot
.27453 .18826 Mdot
.25492 .17257 Mdot
.26276 .1765 Mdot
.25884 .18042 Mdot
.25884 .19218 Mdot
.25884 .19218 Mdot
.25884 .1961 Mdot
.26668 .19218 Mdot
.26668 .1765 Mdot
.251 .16473 Mdot
.251 .15689 Mdot
.25884 .15689 Mdot
.27845 .16473 Mdot
.27061 .16081 Mdot
.27453 .16081 Mdot
.26276 .15689 Mdot
.26668 .16081 Mdot
.27061 .16081 Mdot
.27061 .15689 Mdot
.27061 .15689 Mdot
.28237 .16865 Mdot
.28237 .18826 Mdot
.28629 .20002 Mdot
.27845 .21179 Mdot
.26668 .20002 Mdot
.25492 .1961 Mdot
.24316 .18042 Mdot
.23924 .16865 Mdot
.251 .17257 Mdot
.26276 .17257 Mdot
.251 .16081 Mdot
.26668 .17257 Mdot
.26276 .1765 Mdot
.26276 .18042 Mdot
.251 .17257 Mdot
.23531 .15689 Mdot
.20787 .13336 Mdot
.20002 .13336 Mdot
.20394 .12944 Mdot
.20002 .1216 Mdot
.20787 .12552 Mdot
.21963 .13336 Mdot
.20787 .12552 Mdot
.1961 .12552 Mdot
.1961 .12944 Mdot
.20002 .1216 Mdot
.20002 .11376 Mdot
.20002 .1216 Mdot
.1961 .11376 Mdot
.21179 .1216 Mdot
.21179 .12552 Mdot
.21963 .12944 Mdot
.23139 .13728 Mdot
.23924 .14513 Mdot
.23531 .15297 Mdot
.25492 .16865 Mdot
.26276 .16865 Mdot
.25492 .16081 Mdot
.23139 .1412 Mdot
.23531 .1412 Mdot
.21963 .13728 Mdot
.21963 .14513 Mdot
.21571 .1412 Mdot
.23139 .14905 Mdot
.22747 .14905 Mdot
.22747 .14905 Mdot
.20787 .13728 Mdot
.21179 .13336 Mdot
.21571 .12944 Mdot
.20394 .1216 Mdot
.20787 .13728 Mdot
.22355 .15689 Mdot
.22747 .16081 Mdot
.21179 .14905 Mdot
.20787 .1412 Mdot
.18434 .13336 Mdot
.20787 .1412 Mdot
.20394 .13336 Mdot
.20787 .13336 Mdot
.20787 .12944 Mdot
.1961 .12552 Mdot
.18434 .11768 Mdot
.19218 .11376 Mdot
.18042 .10199 Mdot
.1765 .09023 Mdot
.16865 .09415 Mdot
.17257 .10591 Mdot
.16865 .10591 Mdot
.16473 .10591 Mdot
.15297 .10591 Mdot
.16081 .1216 Mdot
.16473 .1216 Mdot
.16081 .11768 Mdot
.14905 .10591 Mdot
.15297 .10591 Mdot
.14513 .10199 Mdot
.1412 .09415 Mdot
.14513 .09415 Mdot
.14905 .09807 Mdot
.1412 .10199 Mdot
.1412 .10199 Mdot
.12552 .09415 Mdot
.03925 .02357 Mdot
.05494 .02749 Mdot
.04709 .01572 Mdot
.03925 .0118 Mdot
.04317 .0118 Mdot
.03925 .0118 Mdot
.05886 .03533 Mdot
.0667 .04709 Mdot
.09807 .06278 Mdot
.11376 .07454 Mdot
.11376 .08239 Mdot
.12552 .08239 Mdot
.10983 .0667 Mdot
.07454 .03533 Mdot
.05494 .01572 Mdot
.03925 .00788 Mdot
.03925 .00788 Mdot
.02357 .00788 Mdot
.03141 .0118 Mdot
.01965 .00788 Mdot
.02357 .00788 Mdot
.04317 .0118 Mdot
.06278 .01965 Mdot
.06278 .0118 Mdot
.07454 .01965 Mdot
.17257 .09807 Mdot
.1765 .10983 Mdot
.18042 .11768 Mdot
.27845 .1961 Mdot
.27845 .20394 Mdot
.18042 .13336 Mdot
.13336 .10591 Mdot
.07846 .0667 Mdot
.06278 .04709 Mdot
.06278 .03925 Mdot
.07062 .03925 Mdot
.08631 .05102 Mdot
.09807 .05886 Mdot
.15297 .09807 Mdot
.18826 .1216 Mdot
.23139 .15297 Mdot
.23924 .16081 Mdot
.26276 .18826 Mdot
.26668 .18434 Mdot
.26668 .1765 Mdot
.25884 .16865 Mdot
.26668 .1765 Mdot
.27061 .16865 Mdot
.27453 .17257 Mdot
.27453 .18042 Mdot
.28237 .19218 Mdot
.27845 .19218 Mdot
.26276 .1765 Mdot
.26668 .18434 Mdot
.25884 .18042 Mdot
.26276 .18434 Mdot
.27845 .1961 Mdot
.27845 .20002 Mdot
.27845 .1961 Mdot
.27453 .18826 Mdot
.27061 .1961 Mdot
.27061 .20002 Mdot
.27061 .19218 Mdot
.27453 .19218 Mdot
.26668 .1961 Mdot
.27061 .19218 Mdot
.25884 .1765 Mdot
.26276 .18042 Mdot
.25492 .1765 Mdot
.27453 .18042 Mdot
.27453 .18042 Mdot
.28237 .18434 Mdot
.27453 .18434 Mdot
.27845 .18042 Mdot
.27845 .16865 Mdot
.27453 .16473 Mdot
.28629 .17257 Mdot
.27845 .16865 Mdot
.29806 .19218 Mdot
.28629 .20002 Mdot
.28237 .20787 Mdot
.29021 .21963 Mdot
.29021 .21963 Mdot
.29021 .21963 Mdot
.26668 .1961 Mdot
.251 .1765 Mdot
.251 .16865 Mdot
.24708 .16081 Mdot
.24708 .15689 Mdot
.25884 .16473 Mdot
.25884 .1765 Mdot
.26668 .1961 Mdot
.27845 .20787 Mdot
.25884 .19218 Mdot
.23139 .17257 Mdot
.22355 .16865 Mdot
.21571 .16081 Mdot
.21571 .14513 Mdot
.22355 .14513 Mdot
.22355 .14513 Mdot
.22355 .13336 Mdot
.21571 .1216 Mdot
.20394 .11376 Mdot
.20394 .10983 Mdot
.20787 .10983 Mdot
.20002 .10591 Mdot
.19218 .10591 Mdot
.19218 .10983 Mdot
.1961 .1216 Mdot
.18826 .1216 Mdot
.20394 .12944 Mdot
.21571 .13728 Mdot
.23139 .14905 Mdot
.23531 .14905 Mdot
.251 .15689 Mdot
.25884 .16473 Mdot
.24316 .14905 Mdot
.24316 .14905 Mdot
.24316 .14905 Mdot
.23924 .15297 Mdot
.22355 .13728 Mdot
.21571 .12944 Mdot
.21571 .13728 Mdot
.23139 .14513 Mdot
.22355 .14513 Mdot
.21571 .13728 Mdot
.21179 .13728 Mdot
.20002 .12944 Mdot
.20002 .13336 Mdot
.21179 .1412 Mdot
.21571 .14513 Mdot
.1961 .12944 Mdot
.1961 .13728 Mdot
.20787 .14513 Mdot
.19218 .13336 Mdot
.18826 .1216 Mdot
.18826 .11768 Mdot
.1961 .1216 Mdot
.20787 .13336 Mdot
.20394 .1216 Mdot
.1961 .10983 Mdot
.18434 .09807 Mdot
.18434 .09415 Mdot
.1765 .09415 Mdot
.1765 .09807 Mdot
.17257 .10983 Mdot
.17257 .11768 Mdot
.15297 .11768 Mdot
.16081 .1216 Mdot
.15689 .11768 Mdot
.16473 .11768 Mdot
.16081 .10983 Mdot
.15689 .09807 Mdot
.14905 .09023 Mdot
.15297 .08631 Mdot
.15297 .09023 Mdot
.16081 .10199 Mdot
.16473 .09807 Mdot
.16081 .10591 Mdot
.1412 .09023 Mdot
.04709 .04317 Mdot
.04317 .03533 Mdot
.05886 .03533 Mdot
.04317 .01965 Mdot
.02749 .00788 Mdot
.01965 .00788 Mdot
.02749 .00788 Mdot
.04709 .03141 Mdot
.05494 .04317 Mdot
.07454 .05886 Mdot
.09415 .07062 Mdot
.10199 .07454 Mdot
.09807 .0667 Mdot
.07454 .04317 Mdot
.05494 .01572 Mdot
.04317 .00396 Mdot
.03141 .00788 Mdot
.02357 .00788 Mdot
.01965 .00788 Mdot
.02357 .0118 Mdot
.02357 .01572 Mdot
.04709 .02749 Mdot
.04709 .01965 Mdot
.04709 .0118 Mdot
.03925 .00788 Mdot
.04317 .0118 Mdot
.06278 .02749 Mdot
.07454 .03925 Mdot
.16865 .10591 Mdot
.22747 .15689 Mdot
.18434 .1216 Mdot
.16081 .10983 Mdot
.13728 .09023 Mdot
.1216 .08239 Mdot
.10199 .07454 Mdot
.08239 .0667 Mdot
.08631 .07062 Mdot
.08631 .0667 Mdot
.13728 .10199 Mdot
.16865 .12944 Mdot
.20787 .15689 Mdot
.22355 .16473 Mdot
.25492 .18826 Mdot
.26276 .19218 Mdot
.25884 .18434 Mdot
.25492 .1765 Mdot
.251 .16865 Mdot
.25884 .17257 Mdot
.26276 .1765 Mdot
.27453 .18434 Mdot
.27061 .18434 Mdot
.28629 .1961 Mdot
.27453 .18434 Mdot
.26276 .18434 Mdot
.27453 .1961 Mdot
.28237 .20394 Mdot
.28629 .20394 Mdot
.29413 .21179 Mdot
.28237 .20002 Mdot
.29021 .20394 Mdot
.29806 .20787 Mdot
.29021 .20787 Mdot
.29021 .20002 Mdot
.27845 .18826 Mdot
.27453 .18826 Mdot
.28237 .19218 Mdot
.26276 .18826 Mdot
.27061 .20002 Mdot
.26668 .20394 Mdot
.27061 .20002 Mdot
.27061 .19218 Mdot
.28629 .1961 Mdot
.29413 .20002 Mdot
.29021 .19218 Mdot
.28237 .17257 Mdot
.29413 .17257 Mdot
.29413 .17257 Mdot
.28237 .17257 Mdot
.27845 .18042 Mdot
.28237 .19218 Mdot
.29021 .21179 Mdot
.28237 .22355 Mdot
.29806 .23924 Mdot
.28629 .22747 Mdot
.29413 .22355 Mdot
.28237 .20787 Mdot
.28629 .21963 Mdot
.26276 .20002 Mdot
.251 .18826 Mdot
.251 .18042 Mdot
.251 .1765 Mdot
.26276 .18434 Mdot
.27845 .1961 Mdot
.27845 .19218 Mdot
.26276 .18434 Mdot
.24316 .1765 Mdot
.24316 .18434 Mdot
.24316 .1765 Mdot
.24316 .17257 Mdot
.23139 .16081 Mdot
.23139 .14905 Mdot
.22747 .13728 Mdot
.21963 .12552 Mdot
.21571 .11768 Mdot
.21571 .11768 Mdot
.20394 .10591 Mdot
.20394 .10983 Mdot
.20787 .11376 Mdot
.20787 .12552 Mdot
.19218 .1216 Mdot
.20002 .1216 Mdot
.20394 .1216 Mdot
.21571 .1412 Mdot
.24316 .15689 Mdot
.23924 .15297 Mdot
.24708 .16473 Mdot
.25884 .16865 Mdot
.251 .16081 Mdot
.24708 .15297 Mdot
.23531 .1412 Mdot
.21963 .12944 Mdot
.21571 .12944 Mdot
.21571 .12944 Mdot
.22747 .13728 Mdot
.23139 .14513 Mdot
.22355 .14513 Mdot
.21963 .14513 Mdot
.20002 .12944 Mdot
.20002 .12944 Mdot
.20002 .12944 Mdot
.1961 .12552 Mdot
.20394 .13336 Mdot
.20394 .13728 Mdot
.20002 .13728 Mdot
.20787 .14513 Mdot
.19218 .1412 Mdot
.1961 .14513 Mdot
.1961 .1412 Mdot
.19218 .13728 Mdot
.20002 .12944 Mdot
.20394 .12944 Mdot
.20002 .1216 Mdot
.1961 .10591 Mdot
.18434 .09807 Mdot
.18826 .10199 Mdot
.18042 .09807 Mdot
.17257 .10983 Mdot
.16473 .10983 Mdot
.17257 .12552 Mdot
.16081 .11768 Mdot
.16081 .11376 Mdot
.16865 .11376 Mdot
.17257 .1216 Mdot
.15689 .10591 Mdot
.14905 .09415 Mdot
.14513 .09023 Mdot
.14905 .09023 Mdot
.14905 .09023 Mdot
.15297 .09807 Mdot
.13728 .09415 Mdot
.09807 .10591 Mdot
.07454 .08239 Mdot
.05494 .05886 Mdot
.03925 .03141 Mdot
.03141 .01572 Mdot
.02749 .00788 Mdot
.01965 .00396 Mdot
.04317 .01572 Mdot
.07846 .03533 Mdot
.08631 .03925 Mdot
.07846 .03141 Mdot
.07846 .03925 Mdot
.07846 .04317 Mdot
.0667 .03141 Mdot
.05494 .02357 Mdot
.05494 .01572 Mdot
.03533 .0118 Mdot
.03533 .0118 Mdot
.02357 .00788 Mdot
.02357 .0118 Mdot
.03533 .02357 Mdot
.04317 .01965 Mdot
.03925 .0118 Mdot
.01965 .00788 Mdot
.02357 .00788 Mdot
.03141 .0118 Mdot
.03141 .01572 Mdot
.04317 .01965 Mdot
.05886 .02749 Mdot
.09023 .04709 Mdot
.09415 .05102 Mdot
.09415 .05886 Mdot
.10199 .05886 Mdot
.10591 .05494 Mdot
.11768 .0667 Mdot
.14905 .09807 Mdot
.14905 .10199 Mdot
.13728 .09023 Mdot
.1412 .10199 Mdot
.16081 .1216 Mdot
.18826 .14905 Mdot
.21571 .16473 Mdot
.23924 .1765 Mdot
.25492 .18434 Mdot
.25884 .1765 Mdot
.251 .16865 Mdot
.26276 .1765 Mdot
.25884 .17257 Mdot
.24708 .17257 Mdot
.251 .18042 Mdot
.27453 .19218 Mdot
.29021 .1961 Mdot
.29413 .20002 Mdot
.28629 .1961 Mdot
.30198 .20394 Mdot
.29021 .1961 Mdot
.28629 .19218 Mdot
.29413 .20394 Mdot
.29806 .20787 Mdot
.3059 .21179 Mdot
.29806 .20787 Mdot
.28629 .20394 Mdot
.28629 .20394 Mdot
.28629 .19218 Mdot
.29021 .1961 Mdot
.29021 .1961 Mdot
.27061 .18434 Mdot
.27453 .18826 Mdot
.27453 .1961 Mdot
.27845 .1961 Mdot
.28629 .1961 Mdot
.29021 .1961 Mdot
.29413 .20002 Mdot
.30198 .21179 Mdot
.29806 .20002 Mdot
.29413 .18826 Mdot
.29806 .18826 Mdot
.30198 .20002 Mdot
.29806 .20394 Mdot
.29413 .20394 Mdot
.29413 .20787 Mdot
.29413 .21179 Mdot
.29413 .21179 Mdot
.29413 .21179 Mdot
.29413 .20787 Mdot
.29021 .20002 Mdot
.27453 .20394 Mdot
.28629 .21963 Mdot
.26668 .20394 Mdot
.26668 .1961 Mdot
.25884 .18042 Mdot
.251 .16865 Mdot
.26668 .17257 Mdot
.26276 .16865 Mdot
.27061 .18042 Mdot
.27453 .19218 Mdot
.27845 .20787 Mdot
.26276 .19218 Mdot
.24316 .1765 Mdot
.23139 .16865 Mdot
.22355 .16081 Mdot
.24316 .16865 Mdot
.23924 .15689 Mdot
.22747 .13336 Mdot
.21963 .12944 Mdot
.21571 .12552 Mdot
.22355 .12944 Mdot
.21571 .12944 Mdot
.20787 .13728 Mdot
.20394 .13728 Mdot
.21179 .13728 Mdot
.1961 .12944 Mdot
.21179 .14513 Mdot
.20787 .1412 Mdot
.21571 .1412 Mdot
.21963 .14513 Mdot
.22747 .14513 Mdot
.23139 .1412 Mdot
.23139 .13728 Mdot
.24708 .14905 Mdot
.23924 .1412 Mdot
.23531 .1412 Mdot
.22355 .13728 Mdot
.21571 .13728 Mdot
.21571 .1412 Mdot
.23139 .15297 Mdot
.21571 .1412 Mdot
.20002 .12944 Mdot
.18434 .11768 Mdot
.20394 .13336 Mdot
.1961 .12552 Mdot
.1961 .13336 Mdot
.19218 .12944 Mdot
.18826 .12552 Mdot
.19218 .13336 Mdot
.20002 .13728 Mdot
.1961 .13728 Mdot
.19218 .14905 Mdot
.18042 .13728 Mdot
.1961 .1412 Mdot
.1961 .13336 Mdot
.1961 .12552 Mdot
.19218 .11768 Mdot
.18826 .10591 Mdot
.18434 .10591 Mdot
.18826 .11376 Mdot
.18042 .11768 Mdot
.16865 .11768 Mdot
.16473 .11376 Mdot
.16081 .11376 Mdot
.15689 .11376 Mdot
.14905 .10591 Mdot
.15689 .10983 Mdot
.15297 .10199 Mdot
.1412 .09023 Mdot
.14905 .09023 Mdot
.14513 .09023 Mdot
.14513 .08631 Mdot
.1412 .09023 Mdot
.13336 .07846 Mdot
.11376 .1412 Mdot
.11376 .13728 Mdot
.10591 .12944 Mdot
.07846 .10591 Mdot
.05886 .07454 Mdot
.05886 .06278 Mdot
.04317 .04709 Mdot
.07062 .05494 Mdot
.08239 .05886 Mdot
.0667 .03141 Mdot
.05494 .01572 Mdot
.06278 .01965 Mdot
.07846 .03533 Mdot
.07846 .04317 Mdot
.07062 .03533 Mdot
.06278 .02749 Mdot
.05102 .01965 Mdot
.03925 .0118 Mdot
.04317 .02357 Mdot
.03533 .01965 Mdot
.03533 .02749 Mdot
.03141 .02749 Mdot
.01965 .01572 Mdot
.01572 .00788 Mdot
.00788 .00788 Mdot
.01572 .0118 Mdot
.03533 .01965 Mdot
.05886 .03141 Mdot
.0667 .03533 Mdot
.05886 .02749 Mdot
.05494 .03141 Mdot
.06278 .03533 Mdot
.06278 .02749 Mdot
.05102 .0118 Mdot
.07062 .02749 Mdot
.11376 .06278 Mdot
.1765 .10591 Mdot
.1961 .11768 Mdot
.21179 .13336 Mdot
.21179 .1412 Mdot
.22355 .16081 Mdot
.23139 .17257 Mdot
.23531 .16865 Mdot
.23139 .15689 Mdot
.24316 .16473 Mdot
.24316 .16473 Mdot
.23531 .15297 Mdot
.23924 .15297 Mdot
.24316 .16473 Mdot
.25492 .16865 Mdot
.26276 .1765 Mdot
.27453 .18042 Mdot
.27453 .1765 Mdot
.28629 .18826 Mdot
.29806 .1961 Mdot
.29413 .20002 Mdot
.30198 .20394 Mdot
.30198 .21571 Mdot
.30198 .22355 Mdot
.30198 .22747 Mdot
.29806 .21571 Mdot
.30198 .21571 Mdot
.3059 .21571 Mdot
.30982 .21571 Mdot
.30982 .21179 Mdot
.3059 .20787 Mdot
.30198 .21179 Mdot
.29806 .21571 Mdot
.28629 .20394 Mdot
.28237 .1961 Mdot
.28237 .19218 Mdot
.30198 .1961 Mdot
.30198 .20394 Mdot
.31374 .21179 Mdot
.3059 .20394 Mdot
.29413 .20394 Mdot
.29806 .20394 Mdot
.29413 .1961 Mdot
.29413 .19218 Mdot
.3059 .20002 Mdot
.30198 .19218 Mdot
.29806 .18434 Mdot
.29021 .18826 Mdot
.29021 .1961 Mdot
.27845 .18826 Mdot
.29021 .1961 Mdot
.28629 .1961 Mdot
.27453 .20002 Mdot
.28237 .20394 Mdot
.28237 .20002 Mdot
.27453 .18434 Mdot
.27453 .17257 Mdot
.27061 .16473 Mdot
.26276 .15689 Mdot
.26668 .15689 Mdot
.28629 .18434 Mdot
.29021 .1961 Mdot
.28237 .20002 Mdot
.27061 .20002 Mdot
.26668 .1961 Mdot
.25884 .18434 Mdot
.25492 .17257 Mdot
.251 .15297 Mdot
.23531 .14513 Mdot
.23531 .1412 Mdot
.22355 .13336 Mdot
.21179 .12944 Mdot
.21963 .1412 Mdot
.21179 .12944 Mdot
.20787 .12552 Mdot
.20787 .1216 Mdot
.20002 .12944 Mdot
.1961 .13336 Mdot
.20002 .14905 Mdot
.21571 .15297 Mdot
.21963 .14513 Mdot
.21963 .14513 Mdot
.22747 .14905 Mdot
.22747 .13336 Mdot
.24316 .13728 Mdot
.25492 .1412 Mdot
.251 .13728 Mdot
.251 .14513 Mdot
.23531 .13728 Mdot
.21963 .13336 Mdot
.21571 .1412 Mdot
.21963 .14905 Mdot
.21571 .14513 Mdot
.20394 .13336 Mdot
.1961 .12552 Mdot
.19218 .1216 Mdot
.20002 .12552 Mdot
.1961 .12944 Mdot
.19218 .12552 Mdot
.18042 .11768 Mdot
.19218 .12944 Mdot
.20002 .13728 Mdot
.19218 .14513 Mdot
.18826 .1412 Mdot
.21179 .15297 Mdot
.1961 .13728 Mdot
.18434 .12552 Mdot
.1961 .1216 Mdot
.18434 .11376 Mdot
.18042 .11768 Mdot
.18434 .1216 Mdot
.16865 .10983 Mdot
.16865 .10983 Mdot
.16473 .10591 Mdot
.16081 .10983 Mdot
.15297 .10983 Mdot
.14513 .10199 Mdot
.1412 .09807 Mdot
.14905 .10983 Mdot
.14513 .10591 Mdot
.1412 .10199 Mdot
.14513 .09807 Mdot
.12552 .07846 Mdot
.13728 .08239 Mdot
.12552 .07454 Mdot
.17257 .19218 Mdot
.16473 .18434 Mdot
.15297 .16865 Mdot
.1412 .16081 Mdot
.12944 .14513 Mdot
.10199 .11768 Mdot
.07846 .09023 Mdot
.08631 .09023 Mdot
.07454 .07062 Mdot
.04317 .04317 Mdot
.05102 .03533 Mdot
.0667 .03533 Mdot
.07846 .03925 Mdot
.07846 .03533 Mdot
.07454 .03925 Mdot
.06278 .02749 Mdot
.05494 .01965 Mdot
.05102 .01965 Mdot
.04709 .02357 Mdot
.05102 .03141 Mdot
.05886 .05102 Mdot
.05886 .06278 Mdot
.04317 .04709 Mdot
.01965 .02357 Mdot
.01572 .01572 Mdot
.02749 .01965 Mdot
.0667 .05494 Mdot
.08631 .06278 Mdot
.07846 .05102 Mdot
.07062 .04317 Mdot
.0667 .03533 Mdot
.05886 .03141 Mdot
.05886 .03925 Mdot
.04317 .02357 Mdot
.04317 .01572 Mdot
.05102 .01965 Mdot
.07846 .03533 Mdot
.12944 .07454 Mdot
.21179 .13728 Mdot
.24708 .16473 Mdot
.27061 .18042 Mdot
.27061 .18826 Mdot
.24708 .18042 Mdot
.24316 .16865 Mdot
.23924 .16473 Mdot
.23139 .16473 Mdot
.22747 .16081 Mdot
.21571 .14905 Mdot
.21571 .16473 Mdot
.21179 .15689 Mdot
.22747 .16473 Mdot
.24316 .16865 Mdot
.25884 .1765 Mdot
.27453 .18434 Mdot
.28237 .19218 Mdot
.28629 .19218 Mdot
.29806 .21179 Mdot
.29806 .22355 Mdot
.29806 .22355 Mdot
.30198 .23531 Mdot
.30982 .23531 Mdot
.32158 .23531 Mdot
.31766 .22747 Mdot
.32943 .23139 Mdot
.31374 .21571 Mdot
.30982 .21571 Mdot
.30982 .21571 Mdot
.30982 .21963 Mdot
.29806 .21179 Mdot
.30198 .20787 Mdot
.29021 .19218 Mdot
.30198 .19218 Mdot
.29806 .20002 Mdot
.30982 .21179 Mdot
.29806 .20787 Mdot
.29021 .20787 Mdot
.29806 .20002 Mdot
.29021 .18042 Mdot
.30198 .18042 Mdot
.30198 .18826 Mdot
.3059 .18826 Mdot
.29806 .18434 Mdot
.29021 .18434 Mdot
.29413 .19218 Mdot
.28237 .19218 Mdot
.29021 .20394 Mdot
.27845 .20787 Mdot
.27845 .20787 Mdot
.27845 .20787 Mdot
.27845 .20394 Mdot
.27845 .18826 Mdot
.27845 .18434 Mdot
.27845 .16865 Mdot
.26276 .14905 Mdot
.27845 .16473 Mdot
.28237 .16865 Mdot
.27453 .1765 Mdot
.28237 .19218 Mdot
.27845 .20002 Mdot
.26668 .20002 Mdot
.27845 .20787 Mdot
.28629 .20002 Mdot
.27061 .18434 Mdot
.25884 .16473 Mdot
.24708 .15297 Mdot
.23531 .14905 Mdot
.22355 .14905 Mdot
.21179 .13728 Mdot
.20002 .12944 Mdot
.21179 .13728 Mdot
.20787 .13336 Mdot
.1961 .11768 Mdot
.20002 .12552 Mdot
.20002 .12944 Mdot
.21963 .14905 Mdot
.21963 .15297 Mdot
.22747 .14905 Mdot
.23531 .16081 Mdot
.22747 .15297 Mdot
.23139 .14513 Mdot
.23924 .13728 Mdot
.251 .1412 Mdot
.251 .14513 Mdot
.23924 .1412 Mdot
.21963 .1412 Mdot
.20394 .13336 Mdot
.20394 .13728 Mdot
.21571 .15297 Mdot
.20787 .1412 Mdot
.20394 .13336 Mdot
.20787 .12552 Mdot
.20002 .1216 Mdot
.1961 .1216 Mdot
.20002 .13336 Mdot
.18042 .12552 Mdot
.18434 .13336 Mdot
.18042 .13336 Mdot
.19218 .14513 Mdot
.1961 .13336 Mdot
.20002 .12944 Mdot
.1961 .13336 Mdot
.18434 .1216 Mdot
.18826 .11768 Mdot
.1961 .11376 Mdot
.18434 .11376 Mdot
.18042 .11376 Mdot
.1765 .11768 Mdot
.17257 .1216 Mdot
.15297 .10199 Mdot
.14513 .09807 Mdot
.15297 .10983 Mdot
.14905 .10983 Mdot
.15689 .11768 Mdot
.14513 .10983 Mdot
.14905 .10591 Mdot
.13728 .09023 Mdot
.13336 .08239 Mdot
.13728 .07846 Mdot
.13728 .07454 Mdot
.1216 .06278 Mdot
.15689 .18434 Mdot
.1765 .18826 Mdot
.16865 .16865 Mdot
.16473 .16081 Mdot
.16473 .16081 Mdot
.16081 .15297 Mdot
.14905 .14513 Mdot
.14513 .14513 Mdot
.09415 .09807 Mdot
.07062 .07454 Mdot
.06278 .06278 Mdot
.07062 .05494 Mdot
.08631 .05494 Mdot
.08631 .04709 Mdot
.08239 .03925 Mdot
.07062 .02357 Mdot
.05494 .01572 Mdot
.04709 .01572 Mdot
.0667 .03141 Mdot
.0667 .03141 Mdot
.07454 .05102 Mdot
.0667 .05494 Mdot
.0667 .06278 Mdot
.05886 .05494 Mdot
.02749 .03141 Mdot
.03141 .03141 Mdot
.07846 .06278 Mdot
.09807 .07846 Mdot
.08631 .0667 Mdot
.05494 .03925 Mdot
.03925 .01965 Mdot
.03925 .01572 Mdot
.03925 .01572 Mdot
.04317 .01572 Mdot
.04709 .01572 Mdot
.04317 .0118 Mdot
.03925 .0118 Mdot
.07846 .03533 Mdot
.11768 .06278 Mdot
.15297 .09023 Mdot
.17257 .10983 Mdot
.21571 .14905 Mdot
.25492 .19218 Mdot
.26668 .20002 Mdot
.26276 .1961 Mdot
.25492 .1961 Mdot
.24316 .19218 Mdot
.21963 .1765 Mdot
.20002 .16473 Mdot
.18434 .14905 Mdot
.16865 .13336 Mdot
.16865 .1216 Mdot
.21571 .15297 Mdot
.24708 .16865 Mdot
.27061 .18042 Mdot
.28629 .18826 Mdot
.30198 .20394 Mdot
.30198 .21571 Mdot
.29806 .21963 Mdot
.29806 .22747 Mdot
.29413 .22355 Mdot
.29021 .21571 Mdot
.30198 .21963 Mdot
.31374 .22355 Mdot
.31766 .22355 Mdot
.31374 .22355 Mdot
.33335 .23531 Mdot
.32943 .22747 Mdot
.31374 .21571 Mdot
.30198 .20394 Mdot
.30198 .20394 Mdot
.29413 .1961 Mdot
.29413 .1961 Mdot
.31374 .21179 Mdot
.30198 .21179 Mdot
.30982 .22355 Mdot
.30982 .21963 Mdot
.3059 .20394 Mdot
.30198 .18826 Mdot
.3059 .18826 Mdot
.30982 .18826 Mdot
.30982 .19218 Mdot
.29021 .18434 Mdot
.29021 .1961 Mdot
.27845 .20002 Mdot
.28237 .21963 Mdot
.28237 .22355 Mdot
.27845 .21963 Mdot
.28237 .21571 Mdot
.28237 .20787 Mdot
.28629 .1961 Mdot
.3059 .20002 Mdot
.30982 .1961 Mdot
.29806 .18434 Mdot
.29806 .18042 Mdot
.29413 .1765 Mdot
.29021 .1765 Mdot
.26668 .17257 Mdot
.26276 .18434 Mdot
.26276 .20394 Mdot
.28237 .21179 Mdot
.27453 .18826 Mdot
.27453 .18042 Mdot
.27845 .1765 Mdot
.27453 .17257 Mdot
.24708 .15689 Mdot
.23139 .14513 Mdot
.20787 .12552 Mdot
.20787 .13728 Mdot
.1961 .12944 Mdot
.20002 .12552 Mdot
.20002 .12552 Mdot
.20002 .12944 Mdot
.20002 .13336 Mdot
.21571 .15297 Mdot
.22747 .16081 Mdot
.21571 .14905 Mdot
.22747 .15689 Mdot
.23139 .16081 Mdot
.23139 .15297 Mdot
.22355 .1412 Mdot
.22747 .13728 Mdot
.24708 .14513 Mdot
.24708 .14513 Mdot
.23924 .14513 Mdot
.22355 .14513 Mdot
.21571 .14905 Mdot
.21571 .14905 Mdot
.21571 .14513 Mdot
.22355 .15297 Mdot
.21963 .14905 Mdot
.21179 .1412 Mdot
.19218 .12552 Mdot
.18434 .12944 Mdot
.18042 .13728 Mdot
.17257 .12944 Mdot
.18434 .13336 Mdot
.1961 .13728 Mdot
.20002 .13728 Mdot
.20002 .12552 Mdot
.18826 .1216 Mdot
.18826 .11376 Mdot
.20002 .10983 Mdot
.20394 .10591 Mdot
.20394 .10591 Mdot
.16865 .09415 Mdot
.16473 .10591 Mdot
.16081 .11768 Mdot
.14905 .10591 Mdot
.15689 .10983 Mdot
.14905 .10983 Mdot
.1412 .10591 Mdot
.16081 .11768 Mdot
.15297 .10983 Mdot
.14905 .10983 Mdot
.14513 .09807 Mdot
.1412 .07846 Mdot
.13728 .07062 Mdot
.12944 .0667 Mdot
.1216 .05102 Mdot
.18434 .1961 Mdot
.18826 .20787 Mdot
.17257 .18042 Mdot
.16473 .16865 Mdot
.16473 .16081 Mdot
.18042 .16865 Mdot
.18042 .1765 Mdot
.16473 .1765 Mdot
.15689 .16473 Mdot
.13336 .14513 Mdot
.10983 .11376 Mdot
.09807 .09023 Mdot
.10199 .07454 Mdot
.09023 .04709 Mdot
.07062 .01965 Mdot
.06278 .00788 Mdot
.05886 .0118 Mdot
.06278 .01965 Mdot
.07846 .02749 Mdot
.08239 .03141 Mdot
.07062 .03533 Mdot
.06278 .04317 Mdot
.05494 .04709 Mdot
.06278 .05494 Mdot
.05494 .04709 Mdot
.0667 .04709 Mdot
.09415 .07062 Mdot
.10199 .0667 Mdot
.08631 .05102 Mdot
.07846 .04317 Mdot
.05886 .01572 Mdot
.03533 .00396 Mdot
.03925 .00396 Mdot
.03925 .00788 Mdot
.03925 .01572 Mdot
.04709 .01572 Mdot
.04317 .01965 Mdot
.04709 .03533 Mdot
.07846 .05886 Mdot
.09023 .07454 Mdot
.10983 .09023 Mdot
.10591 .09023 Mdot
.21179 .16473 Mdot
.28629 .21963 Mdot
.3059 .22747 Mdot
.30198 .22355 Mdot
.29021 .22355 Mdot
.24316 .18826 Mdot
.20787 .15689 Mdot
.16865 .12552 Mdot
.12944 .09807 Mdot
.10199 .08631 Mdot
.1216 .09415 Mdot
.1765 .12944 Mdot
.21179 .15689 Mdot
.25492 .18042 Mdot
.29021 .20002 Mdot
.3059 .21179 Mdot
.29806 .20394 Mdot
.28629 .20394 Mdot
.28629 .21179 Mdot
.28629 .20787 Mdot
.29021 .21179 Mdot
.29021 .21963 Mdot
.30198 .23139 Mdot
.31374 .23924 Mdot
.32158 .23924 Mdot
.32158 .22355 Mdot
.31766 .21571 Mdot
.30982 .20787 Mdot
.31766 .21571 Mdot
.31374 .20394 Mdot
.31374 .20002 Mdot
.3059 .20394 Mdot
.31374 .21179 Mdot
.30982 .21963 Mdot
.30198 .21179 Mdot
.3059 .21571 Mdot
.3059 .21179 Mdot
.3059 .20394 Mdot
.29806 .1961 Mdot
.29806 .1961 Mdot
.29413 .20394 Mdot
.30198 .20787 Mdot
.29806 .21571 Mdot
.29413 .22355 Mdot
.29021 .22355 Mdot
.29413 .22747 Mdot
.30198 .23924 Mdot
.3059 .23139 Mdot
.30982 .22747 Mdot
.3059 .21571 Mdot
.3059 .21571 Mdot
.30982 .21179 Mdot
.30982 .20002 Mdot
.30198 .18826 Mdot
.29806 .19218 Mdot
.27453 .1765 Mdot
.25884 .1765 Mdot
.26276 .18826 Mdot
.25884 .19218 Mdot
.26668 .20394 Mdot
.26668 .19218 Mdot
.28237 .1961 Mdot
.26668 .18434 Mdot
.25492 .1765 Mdot
.26668 .18434 Mdot
.251 .17257 Mdot
.22747 .16081 Mdot
.20394 .1412 Mdot
.20394 .13336 Mdot
.21963 .1412 Mdot
.21571 .13336 Mdot
.21179 .13728 Mdot
.21179 .1412 Mdot
.23139 .15689 Mdot
.21963 .14905 Mdot
.22747 .15297 Mdot
.23924 .15297 Mdot
.24316 .15297 Mdot
.23924 .14513 Mdot
.21963 .12944 Mdot
.22747 .13336 Mdot
.23531 .1412 Mdot
.23531 .14905 Mdot
.23531 .15689 Mdot
.23139 .16081 Mdot
.20787 .1412 Mdot
.20002 .13728 Mdot
.20394 .13728 Mdot
.21963 .14905 Mdot
.21963 .14905 Mdot
.22355 .14905 Mdot
.20394 .13728 Mdot
.20394 .13728 Mdot
.1961 .13336 Mdot
.18826 .12944 Mdot
.20002 .14513 Mdot
.20394 .1412 Mdot
.20787 .13336 Mdot
.19218 .1216 Mdot
.18434 .11376 Mdot
.20394 .12944 Mdot
.1961 .11768 Mdot
.18434 .10983 Mdot
.18434 .10983 Mdot
.18434 .1216 Mdot
.17257 .1216 Mdot
.16473 .12552 Mdot
.15689 .1216 Mdot
.14905 .11376 Mdot
.14513 .10591 Mdot
.15297 .11376 Mdot
.1412 .10199 Mdot
.1412 .09023 Mdot
.13728 .08239 Mdot
.1412 .08239 Mdot
.1412 .07846 Mdot
.1412 .07454 Mdot
.12944 .0667 Mdot
.18042 .17257 Mdot
.18434 .18826 Mdot
.17257 .18434 Mdot
.16865 .16865 Mdot
.16081 .15689 Mdot
.16865 .15689 Mdot
.17257 .16865 Mdot
.18042 .18826 Mdot
.17257 .19218 Mdot
.1765 .18826 Mdot
.17257 .1765 Mdot
.16081 .15297 Mdot
.1412 .1216 Mdot
.10199 .07062 Mdot
.07454 .04317 Mdot
.06278 .03141 Mdot
.07454 .03925 Mdot
.05886 .03533 Mdot
.05102 .03925 Mdot
.05886 .05102 Mdot
.06278 .04709 Mdot
.01965 .01965 Mdot
.02357 .02357 Mdot
.02749 .02749 Mdot
.03141 .02357 Mdot
.0667 .03925 Mdot
.09415 .05102 Mdot
.1216 .06278 Mdot
.11376 .05494 Mdot
.09023 .03925 Mdot
.0667 .01572 Mdot
.05102 .00396 Mdot
.05102 .0118 Mdot
.03925 .0118 Mdot
.05886 .02749 Mdot
.06278 .03925 Mdot
.05494 .03533 Mdot
.04317 .03533 Mdot
.03925 .04317 Mdot
.05494 .06278 Mdot
.07062 .07454 Mdot
.07846 .07846 Mdot
.09807 .08631 Mdot
.15689 .12552 Mdot
.22355 .17257 Mdot
.26668 .20394 Mdot
.30982 .23531 Mdot
.23139 .1765 Mdot
.18434 .13728 Mdot
.15297 .10199 Mdot
.1216 .07846 Mdot
.10591 .07454 Mdot
.09807 .07062 Mdot
.11376 .08239 Mdot
.16081 .1216 Mdot
.21179 .15689 Mdot
.24708 .17257 Mdot
.27453 .18826 Mdot
.28237 .18826 Mdot
.28629 .18826 Mdot
.29021 .1961 Mdot
.28629 .20002 Mdot
.28237 .20394 Mdot
.28629 .21571 Mdot
.28237 .21571 Mdot
.29413 .22355 Mdot
.30198 .22355 Mdot
.30198 .21571 Mdot
.30982 .21571 Mdot
.31374 .21179 Mdot
.30982 .20787 Mdot
.31374 .1961 Mdot
.3059 .18434 Mdot
.30982 .18826 Mdot
.31374 .19218 Mdot
.3059 .1961 Mdot
.3059 .20394 Mdot
.29021 .20002 Mdot
.29021 .20002 Mdot
.29413 .20002 Mdot
.29806 .20002 Mdot
.29413 .1961 Mdot
.29806 .20394 Mdot
.30198 .21571 Mdot
.29806 .21963 Mdot
.29413 .21571 Mdot
.28629 .21571 Mdot
.29413 .23139 Mdot
.29021 .23139 Mdot
.29413 .23924 Mdot
.29806 .22747 Mdot
.28629 .20394 Mdot
.29806 .20787 Mdot
.29806 .1961 Mdot
.3059 .1961 Mdot
.29413 .18434 Mdot
.28629 .1765 Mdot
.28629 .1765 Mdot
.25884 .17257 Mdot
.24708 .16865 Mdot
.24316 .18042 Mdot
.24316 .18826 Mdot
.25884 .1961 Mdot
.26276 .1961 Mdot
.25884 .20002 Mdot
.25884 .19218 Mdot
.25492 .18434 Mdot
.25492 .16865 Mdot
.24708 .16081 Mdot
.22355 .13728 Mdot
.22355 .13336 Mdot
.22747 .13336 Mdot
.21179 .12552 Mdot
.20787 .12944 Mdot
.20787 .13728 Mdot
.21963 .14905 Mdot
.21963 .14513 Mdot
.23139 .14905 Mdot
.23531 .13336 Mdot
.23139 .12944 Mdot
.23531 .12552 Mdot
.23531 .12552 Mdot
.22355 .1216 Mdot
.22747 .12944 Mdot
.23531 .13336 Mdot
.23924 .1412 Mdot
.21571 .1412 Mdot
.21571 .14513 Mdot
.21179 .13728 Mdot
.21179 .12944 Mdot
.21179 .1216 Mdot
.22355 .13728 Mdot
.23531 .14905 Mdot
.22747 .13728 Mdot
.21571 .1412 Mdot
.20787 .13336 Mdot
.1961 .12552 Mdot
.18826 .11768 Mdot
.18042 .10983 Mdot
.19218 .11376 Mdot
.18826 .10591 Mdot
.19218 .10983 Mdot
.1765 .11376 Mdot
.18434 .12944 Mdot
.18434 .12944 Mdot
.18434 .12552 Mdot
.18042 .12944 Mdot
.16473 .12552 Mdot
.15297 .1216 Mdot
.14905 .11768 Mdot
.14513 .10983 Mdot
.13728 .10199 Mdot
.13336 .09023 Mdot
.13336 .08631 Mdot
.13728 .08631 Mdot
.12552 .07454 Mdot
.13728 .07846 Mdot
.14513 .08631 Mdot
.13728 .08631 Mdot
.12944 .07846 Mdot
.17257 .15297 Mdot
.19218 .16081 Mdot
.1961 .16865 Mdot
.1961 .16865 Mdot
.18826 .17257 Mdot
.18042 .16865 Mdot
.19218 .18434 Mdot
.18042 .18826 Mdot
.16865 .1961 Mdot
.18826 .21571 Mdot
.1961 .21571 Mdot
.20394 .21179 Mdot
.17257 .16865 Mdot
.11376 .10983 Mdot
.09415 .08631 Mdot
.07062 .07062 Mdot
.0667 .0667 Mdot
.05886 .07062 Mdot
.04709 .07062 Mdot
.04317 .0667 Mdot
.03533 .05886 Mdot
.02357 .04317 Mdot
.01965 .03141 Mdot
.02749 .02749 Mdot
.01965 .0118 Mdot
.04709 .01572 Mdot
.11376 .05102 Mdot
.13336 .06278 Mdot
.10983 .04709 Mdot
.07846 .03141 Mdot
.05886 .01965 Mdot
.04709 .0118 Mdot
.05102 .02357 Mdot
.05102 .02749 Mdot
.07062 .04317 Mdot
.08239 .04317 Mdot
.06278 .03925 Mdot
.05886 .04709 Mdot
.04709 .03925 Mdot
.05102 .05102 Mdot
.08239 .07454 Mdot
.09415 .08239 Mdot
.08239 .07454 Mdot
.09415 .08239 Mdot
.10591 .09023 Mdot
.13728 .10983 Mdot
.18042 .1412 Mdot
.17257 .13728 Mdot
.13728 .10591 Mdot
.10983 .07454 Mdot
.06278 .03533 Mdot
.11376 .07846 Mdot
.14513 .10199 Mdot
.16473 .11376 Mdot
.1765 .1216 Mdot
.18434 .12552 Mdot
.20394 .12944 Mdot
.22355 .1412 Mdot
.24316 .15689 Mdot
.26276 .16865 Mdot
.28237 .18826 Mdot
.29806 .20394 Mdot
.3059 .21571 Mdot
.29413 .21963 Mdot
.29806 .21963 Mdot
.30982 .22747 Mdot
.31374 .22355 Mdot
.31766 .21963 Mdot
.32943 .21963 Mdot
.33727 .22355 Mdot
.32943 .21963 Mdot
.3255 .21179 Mdot
.3255 .21179 Mdot
.3255 .20394 Mdot
.31766 .20394 Mdot
.3059 .20002 Mdot
.3059 .19218 Mdot
.31374 .21179 Mdot
.31374 .21571 Mdot
.31374 .21179 Mdot
.3059 .20787 Mdot
.3059 .20394 Mdot
.29413 .20002 Mdot
.30198 .20787 Mdot
.30982 .22355 Mdot
.30982 .22355 Mdot
.3059 .22747 Mdot
.3059 .22747 Mdot
.3059 .23531 Mdot
.31374 .24316 Mdot
.32158 .24316 Mdot
.31374 .23531 Mdot
.3059 .21963 Mdot
.30982 .21571 Mdot
.30198 .1961 Mdot
.29806 .19218 Mdot
.3059 .20002 Mdot
.3059 .20787 Mdot
.28629 .1961 Mdot
.27845 .20002 Mdot
.26668 .1961 Mdot
.26276 .1961 Mdot
.27453 .20394 Mdot
.28629 .20787 Mdot
.28629 .20787 Mdot
.27845 .1961 Mdot
.27453 .18826 Mdot
.26668 .18042 Mdot
.29021 .18434 Mdot
.25884 .15689 Mdot
.25884 .15297 Mdot
.24708 .1412 Mdot
.22747 .12552 Mdot
.22747 .13336 Mdot
.21963 .13728 Mdot
.21963 .14513 Mdot
.23139 .15297 Mdot
.23139 .14905 Mdot
.24316 .14905 Mdot
.23924 .13728 Mdot
.23531 .13336 Mdot
.23924 .1412 Mdot
.23531 .1412 Mdot
.24708 .14905 Mdot
.251 .14905 Mdot
.251 .16081 Mdot
.23924 .16081 Mdot
.23139 .15689 Mdot
.21179 .1412 Mdot
.21571 .13728 Mdot
.21963 .12944 Mdot
.22747 .13336 Mdot
.24316 .14905 Mdot
.24708 .14905 Mdot
.24316 .15689 Mdot
.22747 .1412 Mdot
.21179 .12552 Mdot
.20002 .1216 Mdot
.20002 .11768 Mdot
.20002 .11768 Mdot
.1961 .11768 Mdot
.20002 .1216 Mdot
.18826 .11768 Mdot
.18826 .1216 Mdot
.19218 .12552 Mdot
.1961 .13336 Mdot
.20002 .13728 Mdot
.1765 .11768 Mdot
.16081 .10591 Mdot
.17257 .11768 Mdot
.16865 .12944 Mdot
.15689 .11376 Mdot
.15689 .10983 Mdot
.16081 .10983 Mdot
.15297 .10199 Mdot
.15297 .09415 Mdot
.15689 .09023 Mdot
.15297 .09023 Mdot
.14905 .09415 Mdot
.14905 .09415 Mdot
.12552 .1216 Mdot
.14513 .11376 Mdot
.16473 .1216 Mdot
.16865 .13728 Mdot
.1765 .14905 Mdot
.18434 .16081 Mdot
.1961 .18042 Mdot
.19218 .18826 Mdot
.1961 .20394 Mdot
.1961 .21571 Mdot
.21963 .23139 Mdot
.251 .24708 Mdot
.21963 .21179 Mdot
.15297 .15297 Mdot
.13336 .13728 Mdot
.11768 .13336 Mdot
.08239 .11376 Mdot
.0667 .10199 Mdot
.05886 .09807 Mdot
.05494 .09415 Mdot
.02357 .0667 Mdot
.01572 .05886 Mdot
.01572 .03925 Mdot
.01572 .01965 Mdot
.01965 .0118 Mdot
.03141 .00788 Mdot
.09023 .03533 Mdot
.12552 .0667 Mdot
.11376 .06278 Mdot
.08631 .05102 Mdot
.0667 .03925 Mdot
.05102 .02749 Mdot
.05102 .03533 Mdot
.07062 .05494 Mdot
.09023 .07846 Mdot
.10199 .08239 Mdot
.09415 .08239 Mdot
.07062 .0667 Mdot
.05102 .05494 Mdot
.07062 .07454 Mdot
.07454 .07846 Mdot
.09023 .09023 Mdot
.0667 .07454 Mdot
.07062 .07062 Mdot
.07846 .07454 Mdot
.07846 .07454 Mdot
.10199 .08239 Mdot
.1216 .09023 Mdot
.09807 .0667 Mdot
.08239 .04709 Mdot
.06278 .03141 Mdot
.04709 .01965 Mdot
.1216 .0667 Mdot
.16865 .10983 Mdot
.16865 .1216 Mdot
.13728 .10199 Mdot
.13728 .09415 Mdot
.12944 .08631 Mdot
.14905 .09415 Mdot
.18042 .11376 Mdot
.22355 .1412 Mdot
.25884 .16865 Mdot
.28237 .18826 Mdot
.29413 .20002 Mdot
.3059 .20394 Mdot
.3059 .20002 Mdot
.32158 .20394 Mdot
.33335 .21179 Mdot
.32158 .20787 Mdot
.32943 .22355 Mdot
.32158 .21963 Mdot
.31374 .21963 Mdot
.3255 .22355 Mdot
.3255 .22355 Mdot
.3255 .21963 Mdot
.32158 .21571 Mdot
.31374 .21179 Mdot
.30982 .21179 Mdot
.30982 .21179 Mdot
.31766 .21963 Mdot
.3059 .21179 Mdot
.30982 .21179 Mdot
.29413 .20394 Mdot
.29806 .21179 Mdot
.30198 .21571 Mdot
.30198 .22355 Mdot
.3059 .22355 Mdot
.3059 .22747 Mdot
.30982 .22747 Mdot
.30982 .22355 Mdot
.31766 .23139 Mdot
.34511 .25884 Mdot
.33727 .25884 Mdot
.32158 .23924 Mdot
.31374 .22747 Mdot
.30982 .22355 Mdot
.30198 .21963 Mdot
.29806 .21963 Mdot
.29806 .21571 Mdot
.29806 .20787 Mdot
.30198 .20787 Mdot
.28629 .1961 Mdot
.29021 .1961 Mdot
.29806 .20002 Mdot
.29413 .20002 Mdot
.28629 .20002 Mdot
.28237 .19218 Mdot
.27845 .18826 Mdot
.28629 .1961 Mdot
.27845 .18434 Mdot
.27453 .17257 Mdot
.26276 .15297 Mdot
.25492 .13336 Mdot
.24316 .13336 Mdot
.22747 .1216 Mdot
.22747 .12944 Mdot
.24316 .14513 Mdot
.24316 .14513 Mdot
.24708 .15297 Mdot
.24316 .16081 Mdot
.24708 .16081 Mdot
.23924 .15689 Mdot
.23139 .14905 Mdot
.23531 .15689 Mdot
.23139 .15297 Mdot
.24708 .16473 Mdot
.24708 .16473 Mdot
.251 .16865 Mdot
.24316 .16865 Mdot
.23924 .15297 Mdot
.23531 .13336 Mdot
.21179 .11376 Mdot
.20787 .11768 Mdot
.22355 .12552 Mdot
.22747 .12944 Mdot
.23531 .13336 Mdot
.22747 .12552 Mdot
.21179 .11376 Mdot
.20002 .10591 Mdot
.1961 .10199 Mdot
.1765 .09807 Mdot
.18042 .10199 Mdot
.1765 .10983 Mdot
.18434 .1216 Mdot
.1961 .12944 Mdot
.1961 .13336 Mdot
.18434 .12944 Mdot
.19218 .12944 Mdot
.17257 .11376 Mdot
.15689 .10591 Mdot
.16473 .11376 Mdot
.15689 .10591 Mdot
.16081 .10983 Mdot
.15297 .10983 Mdot
.16081 .11376 Mdot
.16081 .11376 Mdot
.16865 .10983 Mdot
.17257 .11376 Mdot
.15689 .10199 Mdot
.15689 .09807 Mdot
.12552 .13336 Mdot
.12552 .11376 Mdot
.11376 .09023 Mdot
.11768 .09023 Mdot
.13336 .11376 Mdot
.15689 .13336 Mdot
.1961 .16865 Mdot
.20002 .18434 Mdot
.21571 .20394 Mdot
.21571 .21179 Mdot
.20787 .21571 Mdot
.21571 .22355 Mdot
.22355 .22355 Mdot
.21179 .20787 Mdot
.18042 .18042 Mdot
.17257 .18434 Mdot
.14905 .18042 Mdot
.1412 .18042 Mdot
.13336 .18042 Mdot
.11768 .16081 Mdot
.09023 .12944 Mdot
.05886 .09807 Mdot
.03925 .07454 Mdot
.02749 .05102 Mdot
.02749 .03533 Mdot
.02357 .01965 Mdot
.08631 .05494 Mdot
.11376 .0667 Mdot
.10983 .06278 Mdot
.08631 .05494 Mdot
.07454 .05102 Mdot
.07454 .05886 Mdot
.07454 .0667 Mdot
.07846 .07454 Mdot
.10591 .09415 Mdot
.13336 .11768 Mdot
.14905 .13728 Mdot
.14513 .12944 Mdot
.10983 .10591 Mdot
.10591 .10983 Mdot
.11376 .10983 Mdot
.09023 .10199 Mdot
.0667 .08239 Mdot
.05886 .0667 Mdot
.06278 .06278 Mdot
.06278 .05494 Mdot
.0667 .04709 Mdot
.09023 .05886 Mdot
.07846 .04317 Mdot
.07454 .03141 Mdot
.06278 .01965 Mdot
.04709 .0118 Mdot
.17257 .09807 Mdot
.21571 .13336 Mdot
.21179 .13728 Mdot
.13336 .08631 Mdot
.1216 .07846 Mdot
.09023 .05494 Mdot
.09415 .05494 Mdot
.09807 .05494 Mdot
.11768 .07062 Mdot
.14513 .08631 Mdot
.18042 .10983 Mdot
.21571 .13336 Mdot
.24708 .14905 Mdot
.27453 .16865 Mdot
.3059 .18826 Mdot
.30982 .20002 Mdot
.3255 .20787 Mdot
.32158 .21963 Mdot
.32158 .22355 Mdot
.32943 .22747 Mdot
.33335 .22747 Mdot
.3255 .20787 Mdot
.32943 .20787 Mdot
.32943 .22355 Mdot
.33335 .22355 Mdot
.32158 .21963 Mdot
.32158 .22355 Mdot
.30982 .21571 Mdot
.31374 .21963 Mdot
.31374 .21963 Mdot
.30982 .22355 Mdot
.31374 .21963 Mdot
.30982 .22355 Mdot
.3059 .23139 Mdot
.30982 .23139 Mdot
.29806 .22355 Mdot
.3059 .23139 Mdot
.30982 .23139 Mdot
.31766 .23924 Mdot
.3255 .23924 Mdot
.32943 .23531 Mdot
.32158 .23139 Mdot
.31766 .23531 Mdot
.31766 .23531 Mdot
.30982 .22747 Mdot
.3059 .22747 Mdot
.31374 .22355 Mdot
.29806 .20394 Mdot
.30198 .20002 Mdot
.28237 .18042 Mdot
.27845 .18826 Mdot
.28629 .19218 Mdot
.28237 .20002 Mdot
.28629 .21179 Mdot
.28629 .21179 Mdot
.28237 .20394 Mdot
.28237 .20394 Mdot
.27061 .19218 Mdot
.25884 .1765 Mdot
.25884 .15689 Mdot
.251 .13336 Mdot
.23924 .1216 Mdot
.23531 .12552 Mdot
.22747 .12552 Mdot
.23139 .13336 Mdot
.251 .14513 Mdot
.26276 .15297 Mdot
.24316 .14513 Mdot
.24708 .15297 Mdot
.23531 .14513 Mdot
.24316 .16081 Mdot
.23531 .16473 Mdot
.23924 .17257 Mdot
.24316 .18042 Mdot
.251 .18042 Mdot
.23531 .16473 Mdot
.24708 .16473 Mdot
.251 .16473 Mdot
.24316 .15297 Mdot
.21963 .13728 Mdot
.20787 .11768 Mdot
.20787 .10983 Mdot
.21179 .10983 Mdot
.20787 .10983 Mdot
.22355 .1216 Mdot
.21179 .10983 Mdot
.1961 .09807 Mdot
.18434 .09023 Mdot
.19218 .10591 Mdot
.20002 .1216 Mdot
.18042 .11768 Mdot
.18826 .12944 Mdot
.18826 .13336 Mdot
.18434 .12552 Mdot
.18826 .12552 Mdot
.19218 .12552 Mdot
.19218 .12552 Mdot
.18042 .10983 Mdot
.16865 .09807 Mdot
.15689 .08631 Mdot
.15297 .08631 Mdot
.16081 .09807 Mdot
.16473 .10199 Mdot
.15689 .09807 Mdot
.14513 .09415 Mdot
.15689 .10983 Mdot
.14513 .09807 Mdot
.14513 .09023 Mdot
.1412 .1412 Mdot
.1216 .12552 Mdot
.11376 .10591 Mdot
.10591 .08631 Mdot
.10983 .08239 Mdot
.12552 .09415 Mdot
.13728 .09807 Mdot
.15297 .1216 Mdot
.1765 .15297 Mdot
.19218 .18434 Mdot
.20787 .20002 Mdot
.21963 .21571 Mdot
.24708 .23139 Mdot
.21571 .20394 Mdot
.20002 .19218 Mdot
.20394 .20002 Mdot
.20394 .21179 Mdot
.20787 .21571 Mdot
.20394 .22355 Mdot
.20002 .23139 Mdot
.18042 .21571 Mdot
.15689 .1961 Mdot
.12944 .16473 Mdot
.07454 .11376 Mdot
.05494 .08239 Mdot
.03533 .05494 Mdot
.06278 .05886 Mdot
.09023 .0667 Mdot
.10591 .07062 Mdot
.09415 .0667 Mdot
.07846 .05102 Mdot
.07454 .05494 Mdot
.07846 .05494 Mdot
.09807 .07062 Mdot
.12944 .10199 Mdot
.12552 .10983 Mdot
.15297 .1412 Mdot
.16473 .15297 Mdot
.17257 .15689 Mdot
.16865 .15297 Mdot
.1765 .15689 Mdot
.11768 .11376 Mdot
.08239 .09023 Mdot
.05886 .07062 Mdot
.05494 .06278 Mdot
.05886 .05886 Mdot
.0667 .06278 Mdot
.07846 .0667 Mdot
.08239 .06278 Mdot
.07062 .05102 Mdot
.0667 .04317 Mdot
.05886 .02749 Mdot
.1216 .0667 Mdot
.14513 .07846 Mdot
.15689 .08239 Mdot
.14905 .08239 Mdot
.13728 .07454 Mdot
.10983 .06278 Mdot
.08631 .04709 Mdot
.08239 .05102 Mdot
.09023 .05494 Mdot
.09023 .05102 Mdot
.09023 .05102 Mdot
.11768 .0667 Mdot
.16081 .08631 Mdot
.20394 .11376 Mdot
.251 .14513 Mdot
.29021 .1765 Mdot
.30198 .19218 Mdot
.31766 .20394 Mdot
.31766 .21179 Mdot
.32158 .21179 Mdot
.32943 .20394 Mdot
.33335 .21963 Mdot
.32943 .21963 Mdot
.33335 .22747 Mdot
.34119 .23531 Mdot
.32943 .23139 Mdot
.32943 .23531 Mdot
.32943 .23139 Mdot
.32158 .22355 Mdot
.3059 .21571 Mdot
.3059 .21179 Mdot
.32158 .22747 Mdot
.32158 .23139 Mdot
.32158 .23924 Mdot
.3059 .23139 Mdot
.3059 .22747 Mdot
.30982 .22355 Mdot
.31374 .23139 Mdot
.30982 .22747 Mdot
.32943 .23531 Mdot
.31766 .22355 Mdot
.32158 .22747 Mdot
.32943 .23924 Mdot
.33335 .23531 Mdot
.3255 .23139 Mdot
.31766 .21963 Mdot
.31766 .21963 Mdot
.30982 .20787 Mdot
.32158 .21179 Mdot
.3255 .21963 Mdot
.30982 .21179 Mdot
.29806 .20394 Mdot
.29806 .20787 Mdot
.29413 .21571 Mdot
.28629 .21179 Mdot
.27845 .20787 Mdot
.28629 .20787 Mdot
.26668 .19218 Mdot
.26276 .18042 Mdot
.27061 .16865 Mdot
.25884 .14905 Mdot
.23924 .12552 Mdot
.23924 .12552 Mdot
.24708 .12944 Mdot
.23924 .13336 Mdot
.24316 .13728 Mdot
.251 .1412 Mdot
.24708 .1412 Mdot
.24316 .14513 Mdot
.24316 .14905 Mdot
.23531 .15297 Mdot
.23139 .15297 Mdot
.24316 .16865 Mdot
.23924 .16473 Mdot
.24708 .16865 Mdot
.23924 .16081 Mdot
.23924 .16081 Mdot
.24316 .16081 Mdot
.23531 .15689 Mdot
.23139 .14905 Mdot
.23531 .1412 Mdot
.22747 .12944 Mdot
.22355 .12552 Mdot
.21179 .11768 Mdot
.21179 .11768 Mdot
.21963 .12552 Mdot
.20002 .1216 Mdot
.19218 .11376 Mdot
.18042 .11768 Mdot
.1961 .13336 Mdot
.19218 .13336 Mdot
.18826 .12944 Mdot
.19218 .12944 Mdot
.19218 .12944 Mdot
.18434 .1216 Mdot
.19218 .11768 Mdot
.19218 .10983 Mdot
.17257 .09023 Mdot
.18042 .09415 Mdot
.18042 .09415 Mdot
.17257 .09023 Mdot
.17257 .09415 Mdot
.17257 .09415 Mdot
.16081 .09023 Mdot
.15689 .09415 Mdot
.16865 .10199 Mdot
.16081 .10199 Mdot
.14513 .09023 Mdot
.13728 .12944 Mdot
.13336 .12944 Mdot
.11376 .11768 Mdot
.10199 .09807 Mdot
.10983 .09023 Mdot
.10983 .08631 Mdot
.10591 .08239 Mdot
.11376 .09415 Mdot
.10983 .09807 Mdot
.1216 .11376 Mdot
.14513 .13336 Mdot
.1765 .16473 Mdot
.21571 .1961 Mdot
.22747 .20002 Mdot
.22355 .19218 Mdot
.21963 .20002 Mdot
.20394 .1961 Mdot
.20002 .20394 Mdot
.20787 .22355 Mdot
.20787 .23531 Mdot
.21571 .251 Mdot
.21571 .251 Mdot
.20394 .23531 Mdot
.1765 .20787 Mdot
.13728 .16473 Mdot
.11376 .12944 Mdot
.09807 .10591 Mdot
.10591 .09023 Mdot
.11768 .09023 Mdot
.10591 .07454 Mdot
.09415 .06278 Mdot
.09415 .05886 Mdot
.09807 .06278 Mdot
.11376 .07846 Mdot
.09807 .07062 Mdot
.09023 .07062 Mdot
.10591 .08631 Mdot
.13728 .11768 Mdot
.18042 .15297 Mdot
.1961 .16473 Mdot
.21179 .1765 Mdot
.20394 .17257 Mdot
.12552 .11376 Mdot
.10199 .09415 Mdot
.07454 .08239 Mdot
.05886 .0667 Mdot
.05102 .0667 Mdot
.06278 .07454 Mdot
.07062 .07454 Mdot
.08631 .08239 Mdot
.07846 .07062 Mdot
.09023 .06278 Mdot
.09807 .05886 Mdot
.1216 .05886 Mdot
.12552 .05102 Mdot
.1216 .04709 Mdot
.1216 .04709 Mdot
.10591 .04317 Mdot
.09415 .03533 Mdot
.09415 .03533 Mdot
.08631 .03533 Mdot
.08239 .03141 Mdot
.08239 .03141 Mdot
.08631 .03533 Mdot
.11768 .05494 Mdot
.10591 .03925 Mdot
.15297 .07454 Mdot
.23139 .12944 Mdot
.27061 .16081 Mdot
.3059 .18826 Mdot
.32158 .20002 Mdot
.32943 .21179 Mdot
.33335 .21571 Mdot
.32943 .22355 Mdot
.3255 .21963 Mdot
.3255 .22355 Mdot
.33727 .23139 Mdot
.33727 .23531 Mdot
.33727 .24316 Mdot
.33335 .24316 Mdot
.33335 .23924 Mdot
.31766 .22747 Mdot
.31374 .22747 Mdot
.31374 .23139 Mdot
.3255 .24708 Mdot
.32943 .24316 Mdot
.31766 .22747 Mdot
.30982 .21963 Mdot
.31374 .21963 Mdot
.30982 .21963 Mdot
.31766 .22355 Mdot
.30982 .21963 Mdot
.31766 .22747 Mdot
.31766 .22747 Mdot
.31766 .23924 Mdot
.32158 .24316 Mdot
.3255 .24316 Mdot
.31766 .23139 Mdot
.30982 .21571 Mdot
.30982 .21179 Mdot
.30982 .21179 Mdot
.30982 .21571 Mdot
.30982 .21179 Mdot
.3059 .21179 Mdot
.31374 .21963 Mdot
.31374 .21963 Mdot
.29413 .21571 Mdot
.29413 .21571 Mdot
.29413 .21179 Mdot
.27453 .20002 Mdot
.26668 .19218 Mdot
.26276 .18042 Mdot
.26668 .16865 Mdot
.24708 .15297 Mdot
.26276 .14905 Mdot
.26668 .1412 Mdot
.25884 .13728 Mdot
.24708 .1412 Mdot
.25492 .14513 Mdot
.25884 .15297 Mdot
.25884 .15689 Mdot
.251 .16081 Mdot
.24316 .16081 Mdot
.22747 .15297 Mdot
.22355 .14905 Mdot
.21179 .1412 Mdot
.22355 .15297 Mdot
.23924 .16081 Mdot
.23924 .15689 Mdot
.23924 .15689 Mdot
.22747 .14513 Mdot
.23924 .15297 Mdot
.23531 .14513 Mdot
.23924 .14513 Mdot
.23924 .1412 Mdot
.23924 .1412 Mdot
.21571 .1216 Mdot
.21179 .11768 Mdot
.20787 .12944 Mdot
.20787 .13728 Mdot
.20002 .13336 Mdot
.20002 .1412 Mdot
.20002 .14905 Mdot
.20002 .14513 Mdot
.1961 .13336 Mdot
.19218 .1216 Mdot
.17257 .10199 Mdot
.1765 .09415 Mdot
.19218 .10591 Mdot
.18434 .09807 Mdot
.18826 .10199 Mdot
.18434 .10199 Mdot
.1765 .09807 Mdot
.18042 .10199 Mdot
.16865 .09023 Mdot
.16473 .09023 Mdot
.16081 .08239 Mdot
.15689 .07454 Mdot
.16081 .09415 Mdot
.14905 .09415 Mdot
.08631 .09023 Mdot
.16865 .15297 Mdot
.12552 .13728 Mdot
.10591 .1216 Mdot
.09023 .10983 Mdot
.09023 .10199 Mdot
.09023 .09415 Mdot
.09415 .09415 Mdot
.08239 .08239 Mdot
.07846 .07062 Mdot
.08631 .07454 Mdot
.10983 .08631 Mdot
.15297 .1216 Mdot
.18042 .13728 Mdot
.20787 .15297 Mdot
.23531 .18826 Mdot
.21963 .18826 Mdot
.21179 .18826 Mdot
.1961 .19218 Mdot
.20002 .21179 Mdot
.20394 .23531 Mdot
.21963 .251 Mdot
.22747 .251 Mdot
.22747 .24316 Mdot
.21571 .23139 Mdot
.19218 .20394 Mdot
.16865 .16865 Mdot
.15297 .1412 Mdot
.13728 .11768 Mdot
.10199 .09023 Mdot
.10591 .09023 Mdot
.10591 .08239 Mdot
.10591 .07846 Mdot
.11376 .08239 Mdot
.09415 .0667 Mdot
.07062 .04709 Mdot
.0667 .05102 Mdot
.08631 .06278 Mdot
.1412 .10591 Mdot
.16865 .12552 Mdot
.1961 .14905 Mdot
.20787 .16473 Mdot
.20787 .16865 Mdot
.18826 .16473 Mdot
.16473 .15297 Mdot
.12552 .13336 Mdot
.09807 .1216 Mdot
.08631 .11376 Mdot
.07846 .09807 Mdot
.07846 .09023 Mdot
.10983 .10199 Mdot
.13336 .10591 Mdot
.12944 .09415 Mdot
.13336 .07846 Mdot
.12552 .05494 Mdot
.12944 .05494 Mdot
.11768 .04709 Mdot
.10199 .03533 Mdot
.09807 .03533 Mdot
.08239 .02357 Mdot
.08239 .01965 Mdot
.07846 .01965 Mdot
.08631 .02357 Mdot
.09023 .02749 Mdot
.09807 .03925 Mdot
.07846 .02357 Mdot
.08631 .03141 Mdot
.11768 .04317 Mdot
.18434 .09807 Mdot
.23531 .14905 Mdot
.29021 .20002 Mdot
.32158 .22355 Mdot
.32943 .22747 Mdot
.34119 .23924 Mdot
.34119 .23139 Mdot
.34511 .22355 Mdot
.34511 .22355 Mdot
.33727 .22355 Mdot
.32943 .23139 Mdot
.33727 .23531 Mdot
.33335 .23924 Mdot
.31766 .23139 Mdot
.31374 .23924 Mdot
.31374 .23924 Mdot
.3255 .24708 Mdot
.32943 .24316 Mdot
.33335 .23531 Mdot
.31374 .20787 Mdot
.31374 .1961 Mdot
.30982 .20002 Mdot
.30198 .20394 Mdot
.30198 .20787 Mdot
.29806 .20787 Mdot
.29413 .21179 Mdot
.30982 .23531 Mdot
.30982 .24316 Mdot
.30982 .23531 Mdot
.31374 .22747 Mdot
.31374 .21571 Mdot
.31374 .21179 Mdot
.3059 .20787 Mdot
.30198 .20787 Mdot
.30198 .20787 Mdot
.29806 .20394 Mdot
.29806 .20787 Mdot
.3059 .21571 Mdot
.28629 .20002 Mdot
.28629 .21179 Mdot
.30198 .22355 Mdot
.29413 .21963 Mdot
.27061 .21179 Mdot
.26276 .20787 Mdot
.25884 .19218 Mdot
.24708 .1765 Mdot
.25492 .17257 Mdot
.25884 .15689 Mdot
.251 .1412 Mdot
.251 .1412 Mdot
.25492 .1412 Mdot
.26276 .15297 Mdot
.23924 .13728 Mdot
.23531 .1412 Mdot
.23531 .14905 Mdot
.22355 .14905 Mdot
.22355 .15297 Mdot
.20787 .15297 Mdot
.20394 .14905 Mdot
.21963 .15297 Mdot
.22747 .14905 Mdot
.22355 .14513 Mdot
.22355 .1412 Mdot
.22747 .13728 Mdot
.21963 .12944 Mdot
.22355 .12944 Mdot
.21963 .12552 Mdot
.21963 .1216 Mdot
.20787 .10983 Mdot
.1961 .10983 Mdot
.20002 .1216 Mdot
.1961 .12944 Mdot
.1961 .13728 Mdot
.18826 .14513 Mdot
.20002 .14513 Mdot
.20002 .13336 Mdot
.20394 .13728 Mdot
.20002 .13336 Mdot
.18042 .11768 Mdot
.17257 .10591 Mdot
.1765 .10983 Mdot
.17257 .09807 Mdot
.17257 .10199 Mdot
.17257 .10199 Mdot
.17257 .10591 Mdot
.18434 .10983 Mdot
.18434 .11768 Mdot
.16865 .10983 Mdot
.15297 .09023 Mdot
.14513 .07846 Mdot
.14513 .07454 Mdot
.13728 .07846 Mdot
.47059 .44314 Mdot
.25492 .21963 Mdot
.20394 .18434 Mdot
.16865 .16865 Mdot
.15689 .16473 Mdot
.13728 .14905 Mdot
.10983 .12552 Mdot
.10199 .11376 Mdot
.09415 .09415 Mdot
.09415 .07846 Mdot
.08631 .0667 Mdot
.09023 .0667 Mdot
.09415 .06278 Mdot
.10199 .06278 Mdot
.15297 .09807 Mdot
.1765 .11768 Mdot
.20002 .16081 Mdot
.21963 .18826 Mdot
.21571 .18826 Mdot
.21179 .20002 Mdot
.21571 .23139 Mdot
.23531 .25492 Mdot
.23531 .26276 Mdot
.23531 .26276 Mdot
.22355 .24708 Mdot
.22747 .23924 Mdot
.20787 .21571 Mdot
.18042 .18434 Mdot
.14905 .15689 Mdot
.13728 .14513 Mdot
.12552 .13336 Mdot
.1216 .11768 Mdot
.11768 .10983 Mdot
.09807 .09807 Mdot
.08239 .08239 Mdot
.06278 .0667 Mdot
.05102 .05102 Mdot
.09807 .08631 Mdot
.13728 .10591 Mdot
.13336 .09807 Mdot
.1216 .08239 Mdot
.12944 .09023 Mdot
.17257 .13728 Mdot
.19218 .16473 Mdot
.20002 .18042 Mdot
.20002 .19218 Mdot
.18434 .18434 Mdot
.13728 .1412 Mdot
.11768 .1216 Mdot
.10983 .11376 Mdot
.12944 .10983 Mdot
.13728 .10983 Mdot
.14513 .10591 Mdot
.12944 .08631 Mdot
.1216 .0667 Mdot
.12944 .06278 Mdot
.1216 .0667 Mdot
.09415 .04317 Mdot
.08239 .04317 Mdot
.07454 .03533 Mdot
.07062 .03925 Mdot
.07062 .03141 Mdot
.07846 .03533 Mdot
.09415 .04709 Mdot
.09415 .05494 Mdot
.08239 .04317 Mdot
.08239 .03533 Mdot
.08239 .01965 Mdot
.10591 .03925 Mdot
.11376 .05102 Mdot
.23139 .14513 Mdot
.27845 .18826 Mdot
.31374 .21179 Mdot
.3255 .21963 Mdot
.34119 .23139 Mdot
.34511 .22355 Mdot
.34511 .22747 Mdot
.34119 .22747 Mdot
.33335 .22747 Mdot
.33727 .23139 Mdot
.33727 .23139 Mdot
.34511 .24316 Mdot
.33335 .23924 Mdot
.32158 .23531 Mdot
.31766 .22355 Mdot
.3255 .22747 Mdot
.3255 .22355 Mdot
.30982 .20787 Mdot
.31766 .20787 Mdot
.31374 .20787 Mdot
.30982 .20787 Mdot
.3059 .21179 Mdot
.29806 .20394 Mdot
.30198 .20787 Mdot
.3059 .21963 Mdot
.31374 .21963 Mdot
.29806 .21963 Mdot
.29806 .21571 Mdot
.3059 .21179 Mdot
.30198 .21179 Mdot
.29806 .20787 Mdot
.30198 .20394 Mdot
.29806 .20394 Mdot
.29413 .20394 Mdot
.29806 .21179 Mdot
.3059 .21179 Mdot
.30982 .21179 Mdot
.30198 .21179 Mdot
.29413 .21963 Mdot
.29021 .22355 Mdot
.28629 .22747 Mdot
.27453 .22747 Mdot
.26276 .21179 Mdot
.25884 .20002 Mdot
.24316 .18042 Mdot
.23924 .16473 Mdot
.24708 .15689 Mdot
.24316 .1412 Mdot
.24708 .1412 Mdot
.24708 .1412 Mdot
.24316 .14513 Mdot
.23531 .15297 Mdot
.23531 .15297 Mdot
.22355 .14905 Mdot
.20787 .13728 Mdot
.20787 .1412 Mdot
.21179 .1412 Mdot
.19218 .12944 Mdot
.21179 .13336 Mdot
.22355 .14513 Mdot
.23139 .14905 Mdot
.22355 .14513 Mdot
.22747 .14513 Mdot
.22355 .1412 Mdot
.21963 .13336 Mdot
.21571 .12552 Mdot
.20394 .11768 Mdot
.20394 .11768 Mdot
.20394 .1216 Mdot
.19218 .1216 Mdot
.18434 .1216 Mdot
.18434 .12552 Mdot
.1961 .13728 Mdot
.19218 .12944 Mdot
.18826 .12552 Mdot
.19218 .12552 Mdot
.1961 .13336 Mdot
.18434 .12552 Mdot
.1765 .11376 Mdot
.16865 .09807 Mdot
.16081 .09023 Mdot
.16473 .09807 Mdot
.18042 .10983 Mdot
.17257 .10983 Mdot
.1765 .11376 Mdot
.16865 .10591 Mdot
.16081 .10199 Mdot
.16473 .10199 Mdot
.15689 .08631 Mdot
.13728 .06278 Mdot
.65489 .64705 Mdot
.35295 .3255 Mdot
.30982 .29413 Mdot
.26668 .25884 Mdot
.22355 .22355 Mdot
.18826 .18042 Mdot
.15297 .12944 Mdot
.13336 .09415 Mdot
.12944 .09023 Mdot
.12552 .09023 Mdot
.12944 .09415 Mdot
.13728 .09415 Mdot
.12552 .08239 Mdot
.11768 .09023 Mdot
.14513 .1412 Mdot
.1765 .17257 Mdot
.18042 .1765 Mdot
.18434 .19218 Mdot
.22355 .22747 Mdot
.23924 .251 Mdot
.24708 .27061 Mdot
.26668 .28237 Mdot
.25492 .27453 Mdot
.24316 .25884 Mdot
.21963 .23139 Mdot
.21963 .22355 Mdot
.19218 .20002 Mdot
.20394 .1961 Mdot
.21963 .20787 Mdot
.17257 .17257 Mdot
.15297 .17257 Mdot
.11768 .14905 Mdot
.07454 .11376 Mdot
.05102 .09023 Mdot
.04709 .08239 Mdot
.09023 .10983 Mdot
.12552 .12944 Mdot
.10591 .10591 Mdot
.07846 .07062 Mdot
.06278 .05102 Mdot
.09023 .07062 Mdot
.10983 .09415 Mdot
.15689 .13728 Mdot
.18434 .16473 Mdot
.20002 .17257 Mdot
.16081 .13728 Mdot
.14905 .1216 Mdot
.17257 .13728 Mdot
.16865 .12944 Mdot
.15689 .11768 Mdot
.14513 .10199 Mdot
.11768 .07846 Mdot
.11376 .06278 Mdot
.12944 .07062 Mdot
.1216 .06278 Mdot
.10199 .04709 Mdot
.08239 .03925 Mdot
.08239 .04317 Mdot
.07454 .04709 Mdot
.06278 .03533 Mdot
.06278 .03925 Mdot
.07062 .04317 Mdot
.07454 .04709 Mdot
.09023 .05886 Mdot
.09415 .05494 Mdot
.12944 .0667 Mdot
.1412 .07062 Mdot
.15297 .08239 Mdot
.18434 .10199 Mdot
.23139 .13336 Mdot
.27061 .16081 Mdot
.29806 .19218 Mdot
.32158 .21963 Mdot
.33727 .23139 Mdot
.34511 .24708 Mdot
.34903 .25492 Mdot
.33727 .25492 Mdot
.34119 .25884 Mdot
.33727 .24316 Mdot
.33335 .23139 Mdot
.32943 .22355 Mdot
.34119 .22747 Mdot
.33335 .22747 Mdot
.31766 .21963 Mdot
.32158 .22355 Mdot
.3059 .21571 Mdot
.3059 .22355 Mdot
.31374 .22747 Mdot
.30982 .21963 Mdot
.31766 .21963 Mdot
.31374 .20787 Mdot
.31766 .21179 Mdot
.30198 .20002 Mdot
.29413 .19218 Mdot
.29021 .1961 Mdot
.29806 .20002 Mdot
.30982 .21571 Mdot
.30982 .22355 Mdot
.30982 .22747 Mdot
.3059 .22355 Mdot
.29413 .22355 Mdot
.29413 .22355 Mdot
.29413 .22355 Mdot
.29413 .21179 Mdot
.30982 .20787 Mdot
.30198 .20002 Mdot
.30982 .20394 Mdot
.29021 .20394 Mdot
.28629 .21179 Mdot
.27845 .21571 Mdot
.26276 .20787 Mdot
.26668 .20787 Mdot
.24316 .18434 Mdot
.23531 .17257 Mdot
.23139 .16081 Mdot
.24708 .15689 Mdot
.24708 .1412 Mdot
.24316 .13728 Mdot
.23924 .13336 Mdot
.23531 .13336 Mdot
.24708 .1412 Mdot
.23139 .13336 Mdot
.22355 .12552 Mdot
.21963 .12552 Mdot
.23924 .14513 Mdot
.22355 .13728 Mdot
.21179 .12944 Mdot
.21179 .13728 Mdot
.21963 .1412 Mdot
.21963 .14513 Mdot
.22355 .15689 Mdot
.22355 .15689 Mdot
.22747 .15297 Mdot
.21963 .14513 Mdot
.21571 .1412 Mdot
.21963 .13728 Mdot
.21571 .13336 Mdot
.21179 .12552 Mdot
.1961 .11768 Mdot
.19218 .12552 Mdot
.18042 .1216 Mdot
.19218 .12944 Mdot
.19218 .12944 Mdot
.1961 .14513 Mdot
.1961 .14905 Mdot
.1961 .14905 Mdot
.18042 .13336 Mdot
.16865 .1216 Mdot
.17257 .11768 Mdot
.16865 .10983 Mdot
.1765 .11376 Mdot
.17257 .11768 Mdot
.16473 .10983 Mdot
.16081 .10983 Mdot
.16081 .10591 Mdot
.16473 .10199 Mdot
.16081 .08631 Mdot
.14905 .0667 Mdot
.87448 .87448 Mdot
.72155 .72155 Mdot
.50196 .48628 Mdot
.43138 .42354 Mdot
.30982 .30982 Mdot
.29021 .28237 Mdot
.31766 .29413 Mdot
.33335 .29021 Mdot
.31766 .27061 Mdot
.22355 .20394 Mdot
.1765 .17257 Mdot
.17257 .18826 Mdot
.17257 .1961 Mdot
.16473 .18826 Mdot
.13336 .15297 Mdot
.12552 .1412 Mdot
.16473 .16865 Mdot
.18826 .1961 Mdot
.22355 .23531 Mdot
.23924 .25492 Mdot
.25492 .25884 Mdot
.24708 .25492 Mdot
.21571 .23139 Mdot
.20394 .21963 Mdot
.21571 .21963 Mdot
.22747 .22355 Mdot
.24708 .23924 Mdot
.24316 .23924 Mdot
.24708 .251 Mdot
.21571 .23531 Mdot
.16081 .20394 Mdot
.11768 .17257 Mdot
.10199 .15297 Mdot
.1216 .15689 Mdot
.12944 .14905 Mdot
.08239 .10199 Mdot
.07062 .07454 Mdot
.05886 .05494 Mdot
.05494 .05102 Mdot
.07062 .06278 Mdot
.08239 .07062 Mdot
.10199 .09023 Mdot
.13336 .11768 Mdot
.15297 .13336 Mdot
.19218 .16081 Mdot
.20394 .16473 Mdot
.20394 .16473 Mdot
.19218 .15297 Mdot
.15689 .11376 Mdot
.1412 .08631 Mdot
.13336 .07062 Mdot
.12944 .07062 Mdot
.12944 .07062 Mdot
.10983 .05494 Mdot
.09023 .04317 Mdot
.09415 .05102 Mdot
.09023 .05102 Mdot
.07454 .03925 Mdot
.07062 .04317 Mdot
.07062 .04317 Mdot
.07846 .05102 Mdot
.05886 .04709 Mdot
.07062 .06278 Mdot
.27453 .20787 Mdot
.32158 .23924 Mdot
.34903 .251 Mdot
.32158 .21963 Mdot
.30198 .20002 Mdot
.28237 .17257 Mdot
.27453 .16865 Mdot
.28629 .18434 Mdot
.29806 .20394 Mdot
.31766 .23139 Mdot
.3255 .24708 Mdot
.33335 .25492 Mdot
.34119 .251 Mdot
.34119 .24316 Mdot
.33335 .23139 Mdot
.32158 .22355 Mdot
.33335 .23139 Mdot
.33727 .23531 Mdot
.35295 .24708 Mdot
.33727 .23924 Mdot
.32943 .23531 Mdot
.31374 .23139 Mdot
.31374 .23531 Mdot
.32158 .23139 Mdot
.32158 .22355 Mdot
.32158 .21179 Mdot
.31766 .20787 Mdot
.3059 .20002 Mdot
.30198 .20002 Mdot
.30198 .20787 Mdot
.3059 .20787 Mdot
.30982 .21571 Mdot
.30198 .22355 Mdot
.31766 .23924 Mdot
.31374 .24316 Mdot
.29806 .22355 Mdot
.29021 .21571 Mdot
.3059 .22355 Mdot
.3059 .21571 Mdot
.3059 .20787 Mdot
.30198 .20394 Mdot
.30982 .20787 Mdot
.30198 .20787 Mdot
.30198 .20787 Mdot
.29413 .20787 Mdot
.29021 .21571 Mdot
.29021 .21179 Mdot
.27453 .20002 Mdot
.251 .19218 Mdot
.24708 .18434 Mdot
.251 .16865 Mdot
.24316 .15297 Mdot
.24316 .1412 Mdot
.24316 .13728 Mdot
.24316 .14513 Mdot
.24316 .14513 Mdot
.24316 .14513 Mdot
.24316 .14513 Mdot
.23924 .14513 Mdot
.23531 .14905 Mdot
.22747 .14905 Mdot
.23531 .15297 Mdot
.21963 .14513 Mdot
.21179 .13336 Mdot
.21179 .13728 Mdot
.21571 .1412 Mdot
.21571 .14905 Mdot
.22355 .14905 Mdot
.22355 .14905 Mdot
.22355 .15297 Mdot
.21963 .14905 Mdot
.22747 .15297 Mdot
.21963 .14905 Mdot
.21179 .14905 Mdot
.19218 .13728 Mdot
.18434 .12944 Mdot
.19218 .13728 Mdot
.1961 .14513 Mdot
.18826 .14513 Mdot
.18434 .14513 Mdot
.18042 .14513 Mdot
.18042 .14513 Mdot
.17257 .13336 Mdot
.1765 .13336 Mdot
.16865 .11768 Mdot
.1765 .11768 Mdot
.16865 .10983 Mdot
.15689 .10591 Mdot
.15297 .10199 Mdot
.15689 .09807 Mdot
.16081 .09415 Mdot
.15297 .09023 Mdot
.14905 .08631 Mdot
.89801 .89801 Mdot
.67057 .68234 Mdot
.54509 .56078 Mdot
.5647 .55686 Mdot
.58431 .56078 Mdot
.57646 .53725 Mdot
.47451 .45098 Mdot
.41569 .40001 Mdot
.44706 .42746 Mdot
.30982 .3255 Mdot
.15297 .1961 Mdot
.11768 .15297 Mdot
.09415 .11768 Mdot
.08631 .10591 Mdot
.10983 .1216 Mdot
.15297 .15297 Mdot
.19218 .18042 Mdot
.22747 .21571 Mdot
.24316 .23924 Mdot
.24708 .251 Mdot
.22355 .23924 Mdot
.26276 .26668 Mdot
.27845 .27845 Mdot
.28237 .28237 Mdot
.27453 .28629 Mdot
.27061 .29021 Mdot
.251 .27845 Mdot
.24316 .27453 Mdot
.22747 .26668 Mdot
.20787 .24708 Mdot
.19218 .22747 Mdot
.12944 .17257 Mdot
.09023 .12944 Mdot
.07454 .10199 Mdot
.06278 .07454 Mdot
.07454 .07062 Mdot
.07454 .0667 Mdot
.05886 .05494 Mdot
.06278 .04709 Mdot
.07062 .05886 Mdot
.09023 .07454 Mdot
.19218 .15689 Mdot
.19218 .16081 Mdot
.21571 .17257 Mdot
.19218 .14905 Mdot
.17257 .13728 Mdot
.15689 .11768 Mdot
.14905 .10591 Mdot
.13728 .09807 Mdot
.12944 .09023 Mdot
.11768 .08239 Mdot
.10591 .07062 Mdot
.10591 .0667 Mdot
.09415 .05102 Mdot
.09023 .04709 Mdot
.08631 .04317 Mdot
.09807 .0667 Mdot
.07846 .05886 Mdot
.09415 .07062 Mdot
.11768 .09415 Mdot
.22355 .18042 Mdot
.37256 .29413 Mdot
.40393 .31374 Mdot
.41177 .30982 Mdot
.40001 .28629 Mdot
.35687 .24708 Mdot
.3255 .22355 Mdot
.30982 .20787 Mdot
.29806 .20002 Mdot
.30982 .20787 Mdot
.31374 .21963 Mdot
.3255 .23139 Mdot
.34119 .24708 Mdot
.33335 .23924 Mdot
.33727 .23924 Mdot
.34903 .24316 Mdot
.34511 .24316 Mdot
.33727 .24316 Mdot
.34511 .251 Mdot
.34119 .23924 Mdot
.34511 .23531 Mdot
.33727 .22747 Mdot
.33335 .22355 Mdot
.32943 .22747 Mdot
.32943 .23139 Mdot
.3255 .23139 Mdot
.32158 .23139 Mdot
.3255 .23531 Mdot
.31766 .23531 Mdot
.30982 .22747 Mdot
.3059 .21179 Mdot
.3059 .20787 Mdot
.3059 .21179 Mdot
.3059 .21571 Mdot
.30982 .22355 Mdot
.3059 .21179 Mdot
.30198 .20787 Mdot
.31374 .21571 Mdot
.30982 .21963 Mdot
.30982 .21963 Mdot
.31374 .21571 Mdot
.32158 .21963 Mdot
.31374 .21571 Mdot
.30198 .21179 Mdot
.30198 .21179 Mdot
.29806 .20787 Mdot
.29413 .20394 Mdot
.27845 .19218 Mdot
.28237 .20002 Mdot
.27061 .18826 Mdot
.25884 .18042 Mdot
.25492 .17257 Mdot
.23139 .15297 Mdot
.23139 .15297 Mdot
.23139 .15297 Mdot
.251 .16473 Mdot
.24708 .16473 Mdot
.24708 .16473 Mdot
.23924 .15689 Mdot
.24316 .15689 Mdot
.23139 .15689 Mdot
.23531 .16473 Mdot
.23924 .15689 Mdot
.23531 .15689 Mdot
.23139 .15297 Mdot
.22355 .14905 Mdot
.23139 .14905 Mdot
.22747 .14513 Mdot
.21963 .14513 Mdot
.21963 .15297 Mdot
.23924 .1765 Mdot
.23531 .18434 Mdot
.22355 .18042 Mdot
.23139 .18434 Mdot
.20787 .16081 Mdot
.1961 .14905 Mdot
.19218 .14513 Mdot
.19218 .14513 Mdot
.18826 .1412 Mdot
.19218 .1412 Mdot
.18826 .13728 Mdot
.18042 .13336 Mdot
.18826 .13728 Mdot
.18434 .13728 Mdot
.17257 .13336 Mdot
.17257 .12552 Mdot
.16081 .10591 Mdot
.14513 .09807 Mdot
.14905 .10199 Mdot
.14905 .10199 Mdot
.16081 .10591 Mdot
.16081 .10591 Mdot
.1412 .10199 Mdot
.81174 .81174 Mdot
.72547 .70979 Mdot
.63528 .59607 Mdot
.63528 .58039 Mdot
.6196 .56862 Mdot
.62744 .57254 Mdot
.48628 .46275 Mdot
.1216 .17257 Mdot
.11768 .15297 Mdot
.09807 .1216 Mdot
.08239 .10199 Mdot
.07062 .08239 Mdot
.07846 .08631 Mdot
.12552 .1216 Mdot
.15297 .1412 Mdot
.18434 .16865 Mdot
.23924 .21963 Mdot
.24708 .23139 Mdot
.30982 .28237 Mdot
.32158 .29413 Mdot
.29413 .27845 Mdot
.29021 .29021 Mdot
.26668 .28237 Mdot
.26668 .29021 Mdot
.25492 .28629 Mdot
.25492 .28629 Mdot
.26276 .3059 Mdot
.25884 .29413 Mdot
.24316 .27453 Mdot
.16865 .21179 Mdot
.11768 .16081 Mdot
.09807 .12552 Mdot
.07454 .09807 Mdot
.07062 .08631 Mdot
.05102 .06278 Mdot
.05886 .05886 Mdot
.06278 .05886 Mdot
.10983 .08631 Mdot
.1961 .15689 Mdot
.17257 .1412 Mdot
.17257 .1412 Mdot
.18434 .14513 Mdot
.18434 .1412 Mdot
.16865 .12944 Mdot
.16081 .12552 Mdot
.13728 .11376 Mdot
.13728 .1216 Mdot
.1412 .1216 Mdot
.14905 .11768 Mdot
.12944 .09807 Mdot
.11768 .08239 Mdot
.11768 .07846 Mdot
.11376 .07062 Mdot
.1216 .07846 Mdot
.09807 .0667 Mdot
.11376 .08631 Mdot
.16473 .12552 Mdot
.1412 .10983 Mdot
.3059 .24316 Mdot
.3804 .29413 Mdot
.3608 .27453 Mdot
.34119 .26276 Mdot
.36864 .27845 Mdot
.38432 .27453 Mdot
.37256 .251 Mdot
.34511 .21963 Mdot
.32943 .20002 Mdot
.32158 .20394 Mdot
.31766 .20002 Mdot
.32158 .21963 Mdot
.32158 .22747 Mdot
.31766 .22355 Mdot
.32943 .23139 Mdot
.35295 .24316 Mdot
.33727 .23531 Mdot
.35295 .24316 Mdot
.3608 .24708 Mdot
.34119 .23139 Mdot
.33727 .23531 Mdot
.33335 .23139 Mdot
.33335 .23139 Mdot
.32158 .23531 Mdot
.3255 .24316 Mdot
.3255 .251 Mdot
.31766 .251 Mdot
.30982 .24708 Mdot
.31374 .251 Mdot
.31766 .24316 Mdot
.31766 .22355 Mdot
.31374 .21963 Mdot
.30982 .21571 Mdot
.31374 .21571 Mdot
.30982 .20394 Mdot
.30982 .20787 Mdot
.29806 .20787 Mdot
.29806 .21963 Mdot
.29806 .22747 Mdot
.29806 .22355 Mdot
.31374 .23531 Mdot
.29806 .22747 Mdot
.30198 .22747 Mdot
.29806 .21963 Mdot
.29021 .20002 Mdot
.28629 .19218 Mdot
.29021 .19218 Mdot
.29021 .19218 Mdot
.29021 .19218 Mdot
.27845 .19218 Mdot
.27061 .18826 Mdot
.25884 .18826 Mdot
.24316 .18434 Mdot
.22747 .16473 Mdot
.23531 .16865 Mdot
.22747 .17257 Mdot
.22747 .17257 Mdot
.23531 .16473 Mdot
.23531 .14905 Mdot
.24316 .14905 Mdot
.24708 .14905 Mdot
.251 .14905 Mdot
.23924 .14513 Mdot
.23139 .14905 Mdot
.23139 .14905 Mdot
.22355 .14513 Mdot
.22355 .14905 Mdot
.21179 .1412 Mdot
.21571 .14513 Mdot
.20787 .14513 Mdot
.21571 .16081 Mdot
.22747 .1765 Mdot
.22747 .16865 Mdot
.21963 .15689 Mdot
.21179 .14513 Mdot
.1961 .13336 Mdot
.19218 .12944 Mdot
.19218 .12944 Mdot
.20002 .12944 Mdot
.20787 .13336 Mdot
.20002 .12944 Mdot
.18042 .1216 Mdot
.19218 .13728 Mdot
.18434 .13728 Mdot
.1765 .1216 Mdot
.16081 .10591 Mdot
.14513 .09415 Mdot
.14513 .10199 Mdot
.13728 .10983 Mdot
.15689 .1216 Mdot
.14513 .11768 Mdot
.13728 .11376 Mdot
.8235 .79606 Mdot
.65489 .59215 Mdot
.65881 .58823 Mdot
.6196 .55294 Mdot
.3608 .34511 Mdot
.12944 .16081 Mdot
.13336 .14905 Mdot
.10983 .11376 Mdot
.08239 .08631 Mdot
.07846 .08239 Mdot
.07454 .07454 Mdot
.08631 .07846 Mdot
.11376 .09807 Mdot
.14513 .12944 Mdot
.17257 .15689 Mdot
.22747 .20002 Mdot
.25884 .23139 Mdot
.26276 .23924 Mdot
.27061 .25492 Mdot
.27061 .27845 Mdot
.27061 .28629 Mdot
.27061 .29021 Mdot
.27845 .29413 Mdot
.27845 .3059 Mdot
.27453 .29806 Mdot
.27453 .3059 Mdot
.28237 .30982 Mdot
.25884 .28237 Mdot
.21963 .23924 Mdot
.14513 .16473 Mdot
.11376 .13336 Mdot
.09807 .1216 Mdot
.07846 .10591 Mdot
.05494 .08239 Mdot
.14513 .14513 Mdot
.15297 .14513 Mdot
.13336 .1216 Mdot
.12552 .10591 Mdot
.16081 .1216 Mdot
.18434 .13336 Mdot
.16865 .11768 Mdot
.14905 .10591 Mdot
.16081 .1216 Mdot
.15689 .12552 Mdot
.16865 .13336 Mdot
.15689 .11768 Mdot
.16473 .1216 Mdot
.15297 .11376 Mdot
.15297 .10591 Mdot
.14513 .09807 Mdot
.11768 .08239 Mdot
.10199 .07846 Mdot
.08631 .07454 Mdot
.10591 .09023 Mdot
.10983 .09023 Mdot
.41961 .32158 Mdot
.4353 .33727 Mdot
.31766 .24708 Mdot
.21963 .17257 Mdot
.22747 .1765 Mdot
.251 .1765 Mdot
.38432 .25884 Mdot
.38432 .24708 Mdot
.38432 .24316 Mdot
.37256 .23139 Mdot
.33335 .21179 Mdot
.31766 .21571 Mdot
.32158 .22747 Mdot
.32158 .23924 Mdot
.32158 .23531 Mdot
.31766 .22747 Mdot
.32943 .23139 Mdot
.34119 .23924 Mdot
.35687 .251 Mdot
.34119 .23924 Mdot
.34119 .24708 Mdot
.33727 .24316 Mdot
.32943 .23531 Mdot
.32158 .23924 Mdot
.30982 .23139 Mdot
.31766 .24316 Mdot
.32158 .251 Mdot
.32158 .25492 Mdot
.31766 .251 Mdot
.31374 .24708 Mdot
.31374 .24316 Mdot
.31374 .23531 Mdot
.31766 .22747 Mdot
.3255 .22355 Mdot
.31374 .20787 Mdot
.3059 .20394 Mdot
.30982 .21179 Mdot
.30198 .21571 Mdot
.3059 .21571 Mdot
.30982 .22747 Mdot
.30198 .23531 Mdot
.30198 .22747 Mdot
.30982 .23139 Mdot
.29806 .21963 Mdot
.29413 .20787 Mdot
.29021 .1961 Mdot
.29413 .1961 Mdot
.3059 .20002 Mdot
.29413 .1961 Mdot
.28237 .19218 Mdot
.28237 .20002 Mdot
.28629 .20002 Mdot
.27061 .20002 Mdot
.24708 .18042 Mdot
.23924 .17257 Mdot
.21963 .15689 Mdot
.23139 .16865 Mdot
.22747 .15689 Mdot
.23924 .14905 Mdot
.24316 .13728 Mdot
.23139 .12552 Mdot
.23139 .12944 Mdot
.23139 .1412 Mdot
.22747 .14513 Mdot
.22747 .14513 Mdot
.21571 .13336 Mdot
.22355 .13728 Mdot
.22355 .1412 Mdot
.21963 .14513 Mdot
.20394 .13336 Mdot
.21571 .13728 Mdot
.22355 .14905 Mdot
.22355 .14905 Mdot
.21963 .16081 Mdot
.21963 .14513 Mdot
.1961 .12552 Mdot
.20002 .12944 Mdot
.18042 .11376 Mdot
.18434 .11768 Mdot
.18826 .11768 Mdot
.18826 .11376 Mdot
.19218 .11376 Mdot
.19218 .12552 Mdot
.19218 .13336 Mdot
.18042 .12552 Mdot
.16081 .11768 Mdot
.14513 .10199 Mdot
.12944 .09023 Mdot
.14513 .10199 Mdot
.15689 .11768 Mdot
.1412 .11768 Mdot
.13728 .11768 Mdot
.91761 .89801 Mdot
.83919 .79998 Mdot
.56078 .49804 Mdot
.29021 .27845 Mdot
.1961 .18826 Mdot
.16081 .15689 Mdot
.10983 .1216 Mdot
.09415 .10591 Mdot
.08631 .08631 Mdot
.08239 .07846 Mdot
.09415 .08239 Mdot
.10199 .08239 Mdot
.10199 .07846 Mdot
.12552 .10199 Mdot
.14905 .12552 Mdot
.20394 .17257 Mdot
.251 .22355 Mdot
.27061 .251 Mdot
.28237 .26668 Mdot
.30198 .29021 Mdot
.30198 .30198 Mdot
.30982 .31766 Mdot
.3059 .32158 Mdot
.29806 .31374 Mdot
.30198 .3059 Mdot
.29021 .29413 Mdot
.28237 .28629 Mdot
.26276 .26668 Mdot
.23531 .24708 Mdot
.21571 .23531 Mdot
.15297 .19218 Mdot
.11768 .16473 Mdot
.17257 .18434 Mdot
.13336 .14905 Mdot
.08239 .10199 Mdot
.08239 .09023 Mdot
.10591 .09023 Mdot
.11376 .08631 Mdot
.12944 .09807 Mdot
.1412 .10591 Mdot
.14513 .10983 Mdot
.15689 .10983 Mdot
.15297 .10199 Mdot
.14905 .09807 Mdot
.16081 .10199 Mdot
.16473 .10199 Mdot
.16473 .10591 Mdot
.14513 .09807 Mdot
.12944 .09023 Mdot
.11376 .09415 Mdot
.10199 .09807 Mdot
.12552 .1216 Mdot
.11768 .11376 Mdot
.251 .20787 Mdot
.27845 .22355 Mdot
.1765 .14513 Mdot
.1961 .15689 Mdot
.16081 .12552 Mdot
.12552 .08631 Mdot
.1765 .10983 Mdot
.29413 .19218 Mdot
.40785 .27845 Mdot
.42746 .29806 Mdot
.40785 .29413 Mdot
.37256 .27061 Mdot
.33727 .24708 Mdot
.32943 .24708 Mdot
.31374 .24316 Mdot
.29413 .22747 Mdot
.29806 .22747 Mdot
.30982 .23531 Mdot
.32943 .24708 Mdot
.34511 .25884 Mdot
.34511 .26276 Mdot
.34119 .25884 Mdot
.33727 .251 Mdot
.33335 .23139 Mdot
.33335 .23139 Mdot
.33727 .23139 Mdot
.33335 .22355 Mdot
.32158 .22747 Mdot
.3255 .23531 Mdot
.31374 .23924 Mdot
.30982 .24708 Mdot
.32158 .24708 Mdot
.32943 .23531 Mdot
.32943 .23139 Mdot
.31374 .20787 Mdot
.31766 .20787 Mdot
.31374 .20787 Mdot
.31374 .21179 Mdot
.30198 .21179 Mdot
.30982 .21179 Mdot
.31374 .22355 Mdot
.30198 .21963 Mdot
.30198 .23139 Mdot
.30198 .22747 Mdot
.3059 .21963 Mdot
.3059 .21963 Mdot
.29021 .20394 Mdot
.29806 .20394 Mdot
.30198 .20002 Mdot
.29806 .19218 Mdot
.28237 .18042 Mdot
.29021 .19218 Mdot
.28237 .19218 Mdot
.27453 .19218 Mdot
.26276 .18826 Mdot
.251 .18826 Mdot
.23139 .1765 Mdot
.22747 .16473 Mdot
.22747 .15297 Mdot
.22747 .14905 Mdot
.23531 .14513 Mdot
.23531 .1412 Mdot
.22747 .1412 Mdot
.21179 .12944 Mdot
.20787 .13336 Mdot
.21571 .13336 Mdot
.21571 .13336 Mdot
.22747 .14513 Mdot
.21179 .13728 Mdot
.21963 .14513 Mdot
.20787 .13728 Mdot
.20787 .13728 Mdot
.21179 .1412 Mdot
.21179 .14513 Mdot
.21963 .14905 Mdot
.22355 .1412 Mdot
.21571 .13336 Mdot
.20394 .12552 Mdot
.1961 .12552 Mdot
.18826 .1216 Mdot
.19218 .13336 Mdot
.1961 .13336 Mdot
.19218 .12944 Mdot
.1961 .12944 Mdot
.18826 .1216 Mdot
.17257 .11376 Mdot
.15689 .10983 Mdot
.15689 .10591 Mdot
.16473 .10199 Mdot
.15297 .09807 Mdot
.14905 .10199 Mdot
.1412 .10591 Mdot
.76861 .749 Mdot
.56078 .54509 Mdot
.27061 .27453 Mdot
.1961 .21179 Mdot
.14513 .17257 Mdot
.12552 .14905 Mdot
.1216 .12552 Mdot
.10591 .09807 Mdot
.10591 .08631 Mdot
.09415 .07846 Mdot
.09415 .07846 Mdot
.09415 .08239 Mdot
.08239 .07062 Mdot
.15689 .12552 Mdot
.18434 .16081 Mdot
.23531 .20787 Mdot
.27061 .24708 Mdot
.28629 .27061 Mdot
.3059 .29806 Mdot
.32158 .31766 Mdot
.29413 .29806 Mdot
.28237 .29021 Mdot
.29806 .29413 Mdot
.29021 .30198 Mdot
.29021 .30198 Mdot
.29806 .3059 Mdot
.28237 .30198 Mdot
.26668 .28629 Mdot
.24316 .27845 Mdot
.22747 .25884 Mdot
.1412 .18434 Mdot
.08631 .13336 Mdot
.0667 .10591 Mdot
.07062 .09023 Mdot
.06278 .07846 Mdot
.0667 .07454 Mdot
.08239 .07454 Mdot
.1216 .09807 Mdot
.13728 .10199 Mdot
.14513 .10591 Mdot
.13728 .09415 Mdot
.15297 .09807 Mdot
.16473 .10199 Mdot
.17257 .11376 Mdot
.15297 .10591 Mdot
.15297 .1216 Mdot
.15689 .13336 Mdot
.16081 .15689 Mdot
.15689 .16473 Mdot
.14513 .15297 Mdot
.10983 .1216 Mdot
.11376 .11768 Mdot
.11376 .11376 Mdot
.13728 .1216 Mdot
.12552 .10983 Mdot
.11768 .10199 Mdot
.10983 .09415 Mdot
.11376 .09415 Mdot
.23139 .17257 Mdot
.30982 .23139 Mdot
.37648 .28237 Mdot
.41961 .30982 Mdot
.42354 .31374 Mdot
.34511 .26276 Mdot
.251 .19218 Mdot
.21963 .16865 Mdot
.21963 .16473 Mdot
.23531 .18042 Mdot
.25492 .1961 Mdot
.30198 .22747 Mdot
.31766 .23531 Mdot
.34119 .251 Mdot
.33727 .24316 Mdot
.34119 .24708 Mdot
.34511 .23531 Mdot
.3608 .23139 Mdot
.33727 .21179 Mdot
.33727 .21179 Mdot
.32943 .21571 Mdot
.31766 .22355 Mdot
.32158 .23531 Mdot
.31374 .22747 Mdot
.31766 .21963 Mdot
.32943 .22747 Mdot
.32158 .21571 Mdot
.31766 .21179 Mdot
.31766 .21179 Mdot
.31766 .20394 Mdot
.31766 .20787 Mdot
.30982 .20787 Mdot
.30198 .20002 Mdot
.29021 .20002 Mdot
.29413 .20394 Mdot
.30982 .22355 Mdot
.3059 .21963 Mdot
.31374 .21963 Mdot
.31374 .21571 Mdot
.30198 .20787 Mdot
.30198 .20394 Mdot
.30198 .20002 Mdot
.28237 .18434 Mdot
.28237 .19218 Mdot
.27845 .19218 Mdot
.29021 .20394 Mdot
.29021 .20394 Mdot
.27061 .18826 Mdot
.25492 .18434 Mdot
.23924 .1765 Mdot
.22747 .16081 Mdot
.22355 .16473 Mdot
.22747 .16473 Mdot
.23924 .16865 Mdot
.24316 .16473 Mdot
.24316 .16473 Mdot
.21571 .14905 Mdot
.20002 .13336 Mdot
.20394 .12944 Mdot
.20002 .12552 Mdot
.20002 .12552 Mdot
.20787 .12944 Mdot
.20394 .12552 Mdot
.20394 .12552 Mdot
.21963 .13728 Mdot
.22355 .13728 Mdot
.21963 .13336 Mdot
.21963 .13336 Mdot
.21571 .12944 Mdot
.21571 .13728 Mdot
.20394 .13728 Mdot
.19218 .12944 Mdot
.18434 .13336 Mdot
.18434 .12552 Mdot
.20002 .12944 Mdot
.18434 .11768 Mdot
.17257 .10983 Mdot
.18434 .11768 Mdot
.16081 .10199 Mdot
.13728 .08631 Mdot
.14905 .08631 Mdot
.14905 .08239 Mdot
.15297 .08631 Mdot
.13728 .08631 Mdot
.65881 .66273 Mdot
.41961 .43138 Mdot
.20002 .21179 Mdot
.18042 .17257 Mdot
.14513 .12944 Mdot
.1216 .10591 Mdot
.10591 .09807 Mdot
.09807 .09023 Mdot
.08239 .07454 Mdot
.07062 .0667 Mdot
.07062 .0667 Mdot
.07846 .07062 Mdot
.1216 .10591 Mdot
.1961 .17257 Mdot
.26276 .23531 Mdot
.27453 .25492 Mdot
.30198 .28629 Mdot
.3059 .29413 Mdot
.3059 .30198 Mdot
.29806 .29806 Mdot
.30198 .3059 Mdot
.30198 .30198 Mdot
.29021 .29806 Mdot
.28629 .29413 Mdot
.29806 .31374 Mdot
.29413 .3255 Mdot
.28237 .3255 Mdot
.24316 .29021 Mdot
.20394 .251 Mdot
.13336 .1765 Mdot
.07454 .12552 Mdot
.07454 .10983 Mdot
.0667 .09023 Mdot
.07062 .08239 Mdot
.08239 .08631 Mdot
.11768 .10591 Mdot
.13728 .11768 Mdot
.1412 .1216 Mdot
.14905 .10983 Mdot
.16473 .1216 Mdot
.16865 .1216 Mdot
.16081 .1216 Mdot
.15297 .1216 Mdot
.21571 .18826 Mdot
.21571 .20787 Mdot
.20394 .21571 Mdot
.1412 .16473 Mdot
.11768 .1412 Mdot
.09023 .11376 Mdot
.09023 .10983 Mdot
.11376 .11376 Mdot
.12552 .10983 Mdot
.11376 .09807 Mdot
.12944 .10591 Mdot
.12944 .10591 Mdot
.1216 .09415 Mdot
.15297 .10199 Mdot
.1765 .11376 Mdot
.23924 .16081 Mdot
.40393 .29021 Mdot
.38432 .27845 Mdot
.20787 .14513 Mdot
.16865 .11768 Mdot
.13336 .09023 Mdot
.12944 .08239 Mdot
.12552 .07846 Mdot
.22355 .14513 Mdot
.26276 .1765 Mdot
.3059 .21179 Mdot
.32943 .23531 Mdot
.33727 .251 Mdot
.33335 .24708 Mdot
.34511 .24316 Mdot
.34119 .23139 Mdot
.34119 .22747 Mdot
.33335 .21963 Mdot
.3255 .21571 Mdot
.33335 .21963 Mdot
.32158 .21571 Mdot
.30982 .21179 Mdot
.3059 .21571 Mdot
.32158 .22355 Mdot
.30982 .21571 Mdot
.3059 .21179 Mdot
.3059 .21179 Mdot
.31374 .21963 Mdot
.30198 .20394 Mdot
.29806 .18826 Mdot
.28629 .18434 Mdot
.29413 .1961 Mdot
.29806 .20002 Mdot
.29413 .1961 Mdot
.30198 .20787 Mdot
.30198 .20787 Mdot
.30198 .21963 Mdot
.29806 .22747 Mdot
.28629 .21963 Mdot
.28237 .21179 Mdot
.27453 .20394 Mdot
.27061 .1961 Mdot
.27453 .19218 Mdot
.28237 .19218 Mdot
.28237 .18826 Mdot
.27845 .18826 Mdot
.27453 .18826 Mdot
.25884 .1765 Mdot
.24316 .16865 Mdot
.22355 .16865 Mdot
.22355 .16865 Mdot
.22355 .17257 Mdot
.22355 .16865 Mdot
.21179 .15297 Mdot
.20787 .1412 Mdot
.20394 .13336 Mdot
.20394 .11768 Mdot
.20394 .11376 Mdot
.20787 .11376 Mdot
.20394 .10591 Mdot
.19218 .09807 Mdot
.20394 .10591 Mdot
.21571 .11768 Mdot
.21179 .11768 Mdot
.21571 .13336 Mdot
.20394 .13336 Mdot
.20394 .14905 Mdot
.20002 .16081 Mdot
.16865 .13728 Mdot
.16473 .13336 Mdot
.16865 .12552 Mdot
.1765 .12944 Mdot
.18042 .12944 Mdot
.18434 .1216 Mdot
.18042 .11376 Mdot
.16865 .09807 Mdot
.15689 .08631 Mdot
.16081 .08631 Mdot
.14905 .07454 Mdot
.1412 .07062 Mdot
.13728 .0667 Mdot
.81174 .81174 Mdot
.63528 .6196 Mdot
.251 .21571 Mdot
.17257 .1412 Mdot
.15297 .1216 Mdot
.11376 .09807 Mdot
.09807 .09023 Mdot
.07846 .07454 Mdot
.07846 .07454 Mdot
.07062 .0667 Mdot
.07846 .07846 Mdot
.09807 .09023 Mdot
.13728 .12552 Mdot
.18826 .1765 Mdot
.23139 .21963 Mdot
.27061 .251 Mdot
.28629 .27061 Mdot
.3059 .29021 Mdot
.31766 .30198 Mdot
.31766 .30198 Mdot
.30982 .29413 Mdot
.29806 .29021 Mdot
.28629 .29413 Mdot
.27453 .30198 Mdot
.27453 .31374 Mdot
.28237 .32158 Mdot
.29021 .32943 Mdot
.27061 .3059 Mdot
.21571 .24316 Mdot
.1216 .16081 Mdot
.11376 .14513 Mdot
.09807 .11768 Mdot
.07062 .09807 Mdot
.09415 .11768 Mdot
.13336 .1412 Mdot
.14905 .14513 Mdot
.15689 .1412 Mdot
.16473 .14513 Mdot
.16865 .14513 Mdot
.16081 .13728 Mdot
.14513 .12552 Mdot
.21571 .18826 Mdot
.27061 .23924 Mdot
.28237 .26276 Mdot
.23139 .21963 Mdot
.18042 .18434 Mdot
.13728 .14905 Mdot
.10199 .1216 Mdot
.11376 .12552 Mdot
.11376 .1216 Mdot
.11376 .10983 Mdot
.11768 .10591 Mdot
.10591 .09023 Mdot
.09023 .07454 Mdot
.11768 .07454 Mdot
.1412 .08239 Mdot
.1216 .05886 Mdot
.18042 .11376 Mdot
.20394 .13336 Mdot
.16081 .10199 Mdot
.13336 .07846 Mdot
.12944 .07846 Mdot
.12944 .07846 Mdot
.11376 .0667 Mdot
.16473 .10591 Mdot
.1961 .12552 Mdot
.27453 .18434 Mdot
.29021 .1961 Mdot
.3059 .21571 Mdot
.3059 .22355 Mdot
.34119 .24316 Mdot
.34903 .23924 Mdot
.34903 .23531 Mdot
.34511 .22355 Mdot
.32943 .21571 Mdot
.34119 .22355 Mdot
.31766 .20787 Mdot
.30982 .21179 Mdot
.31766 .21963 Mdot
.30982 .21963 Mdot
.30982 .22355 Mdot
.3059 .22355 Mdot
.30982 .22747 Mdot
.31374 .23139 Mdot
.31374 .23139 Mdot
.30198 .20787 Mdot
.29021 .19218 Mdot
.26668 .1765 Mdot
.26276 .16865 Mdot
.26276 .16473 Mdot
.27453 .18042 Mdot
.29413 .20002 Mdot
.29021 .20787 Mdot
.29806 .21963 Mdot
.30198 .22747 Mdot
.29021 .22355 Mdot
.27845 .22355 Mdot
.27453 .21963 Mdot
.27453 .20394 Mdot
.27061 .18826 Mdot
.26668 .18434 Mdot
.26668 .18826 Mdot
.26276 .18042 Mdot
.27061 .18434 Mdot
.251 .17257 Mdot
.23924 .18042 Mdot
.24708 .18826 Mdot
.23139 .18434 Mdot
.21963 .18042 Mdot
.21571 .17257 Mdot
.21571 .16865 Mdot
.20787 .1412 Mdot
.20394 .12944 Mdot
.21571 .13336 Mdot
.22355 .12944 Mdot
.21963 .11768 Mdot
.20787 .11768 Mdot
.1961 .11376 Mdot
.20394 .1216 Mdot
.1961 .11376 Mdot
.20787 .12944 Mdot
.20394 .13728 Mdot
.20787 .15297 Mdot
.21179 .16473 Mdot
.19218 .15297 Mdot
.1765 .13728 Mdot
.18434 .1412 Mdot
.16473 .1216 Mdot
.1765 .11768 Mdot
.18434 .1216 Mdot
.18434 .11376 Mdot
.1765 .09415 Mdot
.18042 .09023 Mdot
.18042 .08631 Mdot
.1765 .07454 Mdot
.14905 .05886 Mdot
.1412 .05886 Mdot
.81566 .80782 Mdot
.60391 .59607 Mdot
.16473 .16473 Mdot
.13728 .14905 Mdot
.11376 .12552 Mdot
.09807 .09807 Mdot
.10199 .09807 Mdot
.10591 .10199 Mdot
.10591 .10199 Mdot
.11768 .10591 Mdot
.11376 .10591 Mdot
.12944 .12552 Mdot
.15689 .14513 Mdot
.20002 .18826 Mdot
.27061 .24708 Mdot
.30982 .27845 Mdot
.32943 .30198 Mdot
.33335 .31766 Mdot
.32158 .32158 Mdot
.29806 .31766 Mdot
.28629 .31766 Mdot
.28237 .31766 Mdot
.27453 .31766 Mdot
.33727 .35687 Mdot
.29806 .32158 Mdot
.3255 .3255 Mdot
.27453 .27061 Mdot
.25492 .251 Mdot
.20394 .22355 Mdot
.12552 .16865 Mdot
.10591 .15297 Mdot
.1765 .20787 Mdot
.1765 .20002 Mdot
.15689 .16865 Mdot
.15297 .14905 Mdot
.16081 .14513 Mdot
.15297 .13336 Mdot
.14905 .12552 Mdot
.12944 .11768 Mdot
.18826 .16865 Mdot
.24316 .22355 Mdot
.27061 .24316 Mdot
.26276 .23924 Mdot
.25492 .23139 Mdot
.20787 .1961 Mdot
.16865 .16865 Mdot
.14513 .14905 Mdot
.1216 .12944 Mdot
.10591 .10199 Mdot
.08239 .07454 Mdot
.0667 .05886 Mdot
.10983 .07846 Mdot
.12552 .08239 Mdot
.1216 .07454 Mdot
.13336 .08631 Mdot
.16473 .10983 Mdot
.1765 .12552 Mdot
.1412 .09415 Mdot
.13336 .08239 Mdot
.13728 .09023 Mdot
.14513 .09807 Mdot
.20002 .1412 Mdot
.24316 .16473 Mdot
.27061 .18042 Mdot
.28629 .19218 Mdot
.29806 .18826 Mdot
.29806 .18826 Mdot
.32158 .20787 Mdot
.31766 .20002 Mdot
.3255 .20787 Mdot
.33335 .22355 Mdot
.32943 .22355 Mdot
.34119 .23139 Mdot
.3255 .22355 Mdot
.3255 .22355 Mdot
.32943 .22355 Mdot
.3255 .21571 Mdot
.33335 .22355 Mdot
.32943 .22747 Mdot
.3255 .22747 Mdot
.32943 .23139 Mdot
.32943 .24316 Mdot
.32158 .23924 Mdot
.30982 .22747 Mdot
.29021 .21963 Mdot
.28237 .20787 Mdot
.27453 .19218 Mdot
.27845 .18826 Mdot
.27845 .18826 Mdot
.27845 .18826 Mdot
.27845 .19218 Mdot
.29806 .20394 Mdot
.29413 .20394 Mdot
.28629 .20787 Mdot
.28629 .21571 Mdot
.27845 .21179 Mdot
.26668 .20002 Mdot
.27845 .21179 Mdot
.27845 .21179 Mdot
.27061 .1961 Mdot
.27453 .19218 Mdot
.26668 .18826 Mdot
.25884 .19218 Mdot
.25884 .1961 Mdot
.251 .19218 Mdot
.251 .19218 Mdot
.25492 .18434 Mdot
.25884 .18042 Mdot
.24708 .16473 Mdot
.23531 .15297 Mdot
.23924 .16081 Mdot
.23531 .16081 Mdot
.22747 .14905 Mdot
.22747 .15297 Mdot
.21963 .15689 Mdot
.20787 .15297 Mdot
.1961 .14513 Mdot
.1961 .1412 Mdot
.20002 .1412 Mdot
.20394 .1412 Mdot
.20787 .14513 Mdot
.21963 .15689 Mdot
.20394 .14513 Mdot
.20002 .13728 Mdot
.20394 .13336 Mdot
.18434 .11768 Mdot
.18826 .1216 Mdot
.18826 .11768 Mdot
.1961 .11376 Mdot
.19218 .10199 Mdot
.18826 .09415 Mdot
.18042 .08631 Mdot
.17257 .09023 Mdot
.16081 .08239 Mdot
.63528 .63136 Mdot
.38432 .40393 Mdot
.16865 .19218 Mdot
.18434 .20002 Mdot
.20787 .21571 Mdot
.17257 .1765 Mdot
.15689 .15689 Mdot
.14905 .14513 Mdot
.1412 .12944 Mdot
.14905 .13336 Mdot
.15689 .13728 Mdot
.20394 .1765 Mdot
.21963 .1961 Mdot
.27453 .23924 Mdot
.30198 .27453 Mdot
.31766 .30982 Mdot
.32158 .3255 Mdot
.3255 .34511 Mdot
.31766 .34119 Mdot
.29413 .32158 Mdot
.29806 .30982 Mdot
.3059 .3059 Mdot
.32158 .3059 Mdot
.34119 .3255 Mdot
.32158 .32158 Mdot
.31374 .3255 Mdot
.28237 .30982 Mdot
.23531 .27453 Mdot
.23531 .26668 Mdot
.14513 .19218 Mdot
.12552 .15689 Mdot
.11376 .12552 Mdot
.10591 .10983 Mdot
.10591 .09415 Mdot
.10591 .09023 Mdot
.07846 .07846 Mdot
.08239 .09415 Mdot
.12552 .13336 Mdot
.21571 .20002 Mdot
.25884 .23531 Mdot
.27845 .24708 Mdot
.28629 .251 Mdot
.28237 .251 Mdot
.21179 .20002 Mdot
.17257 .1765 Mdot
.13728 .14905 Mdot
.10983 .10983 Mdot
.07846 .07062 Mdot
.07846 .0667 Mdot
.08631 .07062 Mdot
.09807 .07062 Mdot
.15689 .11376 Mdot
.1765 .1216 Mdot
.1961 .13728 Mdot
.1765 .11768 Mdot
.17257 .10983 Mdot
.16473 .10199 Mdot
.1412 .08631 Mdot
.1765 .1216 Mdot
.19218 .12944 Mdot
.22355 .14513 Mdot
.23531 .15297 Mdot
.26276 .16081 Mdot
.26668 .16081 Mdot
.29021 .18826 Mdot
.30198 .20002 Mdot
.30198 .20002 Mdot
.30982 .20002 Mdot
.31766 .21179 Mdot
.32158 .22355 Mdot
.32943 .22747 Mdot
.3255 .22747 Mdot
.3255 .22355 Mdot
.32943 .21963 Mdot
.33727 .22355 Mdot
.3255 .21963 Mdot
.31766 .21963 Mdot
.31374 .23139 Mdot
.31766 .24708 Mdot
.3255 .25492 Mdot
.31766 .24708 Mdot
.30982 .23924 Mdot
.29413 .22747 Mdot
.29021 .21179 Mdot
.29021 .20394 Mdot
.30198 .20787 Mdot
.28629 .20002 Mdot
.29021 .20394 Mdot
.28237 .19218 Mdot
.27453 .18434 Mdot
.28237 .18826 Mdot
.27845 .19218 Mdot
.27453 .19218 Mdot
.25884 .18826 Mdot
.27061 .1961 Mdot
.27061 .1961 Mdot
.25884 .18434 Mdot
.25492 .18042 Mdot
.251 .1765 Mdot
.25884 .18434 Mdot
.251 .1765 Mdot
.25492 .18042 Mdot
.251 .1765 Mdot
.25884 .18042 Mdot
.25492 .1765 Mdot
.25492 .16865 Mdot
.24708 .16865 Mdot
.251 .1765 Mdot
.25492 .18042 Mdot
.24708 .1765 Mdot
.23531 .1765 Mdot
.23139 .18042 Mdot
.22355 .18042 Mdot
.22355 .1765 Mdot
.20787 .16473 Mdot
.20002 .15297 Mdot
.19218 .13728 Mdot
.18826 .12552 Mdot
.1961 .12552 Mdot
.20002 .12552 Mdot
.20394 .1216 Mdot
.21179 .12552 Mdot
.20002 .10983 Mdot
.18434 .09807 Mdot
.18434 .10199 Mdot
.16473 .10199 Mdot
.17257 .10591 Mdot
.17257 .09807 Mdot
.16473 .09023 Mdot
.16473 .10591 Mdot
.16081 .10591 Mdot
.69802 .6941 Mdot
.56078 .55294 Mdot
.32943 .34119 Mdot
.32943 .32158 Mdot
.29413 .26668 Mdot
.23924 .21179 Mdot
.21571 .18042 Mdot
.19218 .16473 Mdot
.18434 .16081 Mdot
.18042 .17257 Mdot
.20002 .19218 Mdot
.21179 .20394 Mdot
.26276 .251 Mdot
.28629 .28237 Mdot
.32158 .31766 Mdot
.34119 .33727 Mdot
.34511 .33335 Mdot
.33727 .31374 Mdot
.32158 .29806 Mdot
.32158 .30198 Mdot
.34511 .33335 Mdot
.33335 .34119 Mdot
.3255 .35687 Mdot
.33335 .36864 Mdot
.33335 .36472 Mdot
.3255 .34511 Mdot
.24316 .27845 Mdot
.20787 .23924 Mdot
.13728 .16081 Mdot
.13728 .1412 Mdot
.10199 .10591 Mdot
.07454 .09023 Mdot
.05494 .07846 Mdot
.08239 .09415 Mdot
.07846 .07846 Mdot
.23531 .1961 Mdot
.22747 .20394 Mdot
.21963 .20787 Mdot
.22355 .21179 Mdot
.24316 .23139 Mdot
.27061 .25492 Mdot
.27845 .26276 Mdot
.26668 .24708 Mdot
.18826 .1765 Mdot
.09415 .08631 Mdot
.09023 .07454 Mdot
.07846 .06278 Mdot
.08239 .05886 Mdot
.18042 .12552 Mdot
.1765 .1216 Mdot
.18434 .1216 Mdot
.18826 .11376 Mdot
.18826 .11376 Mdot
.1961 .11768 Mdot
.19218 .11768 Mdot
.17257 .10199 Mdot
.14905 .09023 Mdot
.13728 .08239 Mdot
.12552 .07062 Mdot
.16081 .09415 Mdot
.19218 .1216 Mdot
.26276 .17257 Mdot
.3059 .20002 Mdot
.31374 .21179 Mdot
.3255 .21571 Mdot
.32158 .20787 Mdot
.31766 .21571 Mdot
.3059 .21571 Mdot
.30198 .21179 Mdot
.3059 .21571 Mdot
.31766 .22747 Mdot
.32158 .22355 Mdot
.31766 .21963 Mdot
.32158 .22355 Mdot
.3255 .24316 Mdot
.3255 .24708 Mdot
.34119 .25884 Mdot
.32158 .24316 Mdot
.31374 .22747 Mdot
.30982 .21963 Mdot
.3059 .21179 Mdot
.3059 .21179 Mdot
.3059 .20787 Mdot
.30982 .21571 Mdot
.29806 .20787 Mdot
.29413 .20002 Mdot
.28629 .19218 Mdot
.29021 .18826 Mdot
.28237 .18042 Mdot
.27453 .18434 Mdot
.27453 .18434 Mdot
.27061 .18042 Mdot
.26276 .18826 Mdot
.26668 .19218 Mdot
.26276 .18826 Mdot
.25492 .18042 Mdot
.26668 .18826 Mdot
.27061 .19218 Mdot
.25884 .18042 Mdot
.251 .16865 Mdot
.251 .16865 Mdot
.251 .16473 Mdot
.24708 .16865 Mdot
.24708 .16865 Mdot
.25884 .1765 Mdot
.25492 .16865 Mdot
.25492 .17257 Mdot
.24708 .1765 Mdot
.23139 .17257 Mdot
.23531 .1765 Mdot
.23531 .1765 Mdot
.22747 .1765 Mdot
.21963 .16865 Mdot
.21179 .15297 Mdot
.19218 .12944 Mdot
.20002 .12944 Mdot
.20787 .12944 Mdot
.21179 .12944 Mdot
.20394 .12552 Mdot
.20002 .11768 Mdot
.19218 .10983 Mdot
.20002 .11768 Mdot
.18434 .10591 Mdot
.18434 .09807 Mdot
.18042 .09415 Mdot
.16865 .09023 Mdot
.17257 .10591 Mdot
.1765 .10983 Mdot
.90585 .89409 Mdot
.8039 .77645 Mdot
.61568 .54902 Mdot
.37256 .34903 Mdot
.3255 .29806 Mdot
.30198 .27453 Mdot
.26668 .251 Mdot
.25884 .24316 Mdot
.24708 .22747 Mdot
.20787 .1961 Mdot
.20002 .1961 Mdot
.21179 .21571 Mdot
.25492 .25884 Mdot
.30198 .30198 Mdot
.32158 .30982 Mdot
.34511 .31374 Mdot
.35295 .3059 Mdot
.37256 .32158 Mdot
.36472 .33335 Mdot
.34119 .33727 Mdot
.32158 .34511 Mdot
.3255 .36472 Mdot
.34511 .3804 Mdot
.35295 .38824 Mdot
.34511 .3804 Mdot
.33335 .3608 Mdot
.28237 .30198 Mdot
.251 .25492 Mdot
.16473 .18042 Mdot
.13728 .15297 Mdot
.09023 .11376 Mdot
.08631 .10199 Mdot
.13336 .12944 Mdot
.27061 .23924 Mdot
.15297 .15689 Mdot
.14513 .15297 Mdot
.1216 .13728 Mdot
.12552 .13728 Mdot
.1961 .18826 Mdot
.24708 .22747 Mdot
.27845 .24708 Mdot
.29806 .24708 Mdot
.18042 .14513 Mdot
.11376 .08239 Mdot
.09023 .05102 Mdot
.06278 .02749 Mdot
.09415 .05494 Mdot
.10591 .05886 Mdot
.11376 .05102 Mdot
.14513 .07454 Mdot
.16081 .09415 Mdot
.18434 .11768 Mdot
.1765 .10983 Mdot
.16081 .10591 Mdot
.14513 .09807 Mdot
.1765 .12552 Mdot
.14513 .10199 Mdot
.12944 .09415 Mdot
.1216 .08631 Mdot
.27061 .19218 Mdot
.41569 .29806 Mdot
.39609 .28237 Mdot
.39609 .27845 Mdot
.3608 .26276 Mdot
.33335 .24708 Mdot
.31374 .23924 Mdot
.30198 .22747 Mdot
.29806 .21963 Mdot
.29806 .21963 Mdot
.29413 .21179 Mdot
.29413 .21571 Mdot
.30198 .21963 Mdot
.30982 .23531 Mdot
.32158 .23924 Mdot
.32158 .23139 Mdot
.33335 .23531 Mdot
.32158 .23139 Mdot
.30982 .21571 Mdot
.30198 .20787 Mdot
.29806 .20394 Mdot
.3059 .20787 Mdot
.31766 .21179 Mdot
.30982 .20394 Mdot
.31374 .20394 Mdot
.30198 .19218 Mdot
.29021 .18826 Mdot
.28237 .18042 Mdot
.28237 .19218 Mdot
.28237 .19218 Mdot
.26668 .19218 Mdot
.26276 .20394 Mdot
.26276 .20394 Mdot
.25884 .1961 Mdot
.26276 .1961 Mdot
.27845 .20002 Mdot
.25884 .18042 Mdot
.26668 .18042 Mdot
.26668 .17257 Mdot
.26276 .16473 Mdot
.25884 .15689 Mdot
.25492 .15689 Mdot
.24316 .15297 Mdot
.23924 .15297 Mdot
.23531 .15689 Mdot
.24316 .16473 Mdot
.23924 .16865 Mdot
.23924 .1765 Mdot
.23924 .16865 Mdot
.23531 .16473 Mdot
.21571 .15297 Mdot
.21571 .15689 Mdot
.21179 .15297 Mdot
.20394 .1412 Mdot
.20394 .13336 Mdot
.20002 .12944 Mdot
.20002 .12552 Mdot
.1961 .1216 Mdot
.18826 .11768 Mdot
.18434 .11376 Mdot
.18434 .11376 Mdot
.18042 .10199 Mdot
.16473 .08631 Mdot
.15297 .08631 Mdot
.16865 .10199 Mdot
.16473 .09807 Mdot
.17257 .10199 Mdot
.88232 .8784 Mdot
.76469 .75292 Mdot
.47843 .47451 Mdot
.53333 .49412 Mdot
.57646 .49804 Mdot
.28237 .25884 Mdot
.27845 .251 Mdot
.25492 .23139 Mdot
.22747 .21963 Mdot
.22747 .22747 Mdot
.22355 .22747 Mdot
.23924 .24708 Mdot
.26668 .25884 Mdot
.31766 .28629 Mdot
.34903 .3059 Mdot
.36864 .32158 Mdot
.36472 .33727 Mdot
.34119 .33335 Mdot
.32943 .34511 Mdot
.34119 .36472 Mdot
.34119 .36864 Mdot
.3255 .36864 Mdot
.33727 .37648 Mdot
.34511 .37256 Mdot
.35687 .36472 Mdot
.32943 .32943 Mdot
.29021 .29021 Mdot
.20787 .21179 Mdot
.1412 .15689 Mdot
.21571 .20787 Mdot
.24708 .22355 Mdot
.12552 .13728 Mdot
.12552 .1412 Mdot
.09023 .11768 Mdot
.07062 .09807 Mdot
.08239 .09415 Mdot
.11376 .11376 Mdot
.15689 .13728 Mdot
.19218 .15689 Mdot
.19218 .14513 Mdot
.13728 .09807 Mdot
.11376 .07062 Mdot
.11768 .0667 Mdot
.09415 .04709 Mdot
.09807 .05102 Mdot
.09415 .05102 Mdot
.09023 .04709 Mdot
.10983 .06278 Mdot
.1216 .07454 Mdot
.12552 .07846 Mdot
.10983 .07454 Mdot
.08631 .0667 Mdot
.15689 .11768 Mdot
.17257 .12552 Mdot
.1765 .13336 Mdot
.17257 .12944 Mdot
.21179 .15297 Mdot
.34511 .251 Mdot
.41961 .32158 Mdot
.43922 .33727 Mdot
.44314 .34903 Mdot
.41177 .3255 Mdot
.35295 .28237 Mdot
.30982 .24708 Mdot
.27453 .20787 Mdot
.25492 .19218 Mdot
.24708 .18826 Mdot
.25492 .18826 Mdot
.25884 .20002 Mdot
.27845 .21179 Mdot
.29806 .21963 Mdot
.31766 .23139 Mdot
.31766 .24316 Mdot
.30982 .24316 Mdot
.30982 .23924 Mdot
.29413 .21963 Mdot
.3059 .21571 Mdot
.30982 .20394 Mdot
.31374 .1961 Mdot
.30982 .1961 Mdot
.30198 .18826 Mdot
.30198 .1961 Mdot
.29806 .19218 Mdot
.29806 .1961 Mdot
.27845 .1961 Mdot
.28237 .20787 Mdot
.26668 .20787 Mdot
.27061 .21571 Mdot
.27453 .22355 Mdot
.26276 .20787 Mdot
.25884 .18826 Mdot
.27453 .18826 Mdot
.26668 .1765 Mdot
.26668 .17257 Mdot
.26276 .16473 Mdot
.27061 .17257 Mdot
.25884 .16473 Mdot
.24316 .16473 Mdot
.24316 .16865 Mdot
.22355 .15689 Mdot
.21963 .15297 Mdot
.22355 .15297 Mdot
.23139 .15689 Mdot
.23531 .16081 Mdot
.23531 .15689 Mdot
.23531 .15297 Mdot
.23139 .14513 Mdot
.22355 .13728 Mdot
.21571 .12944 Mdot
.20787 .1216 Mdot
.20394 .11376 Mdot
.18826 .10983 Mdot
.18826 .11768 Mdot
.18826 .1216 Mdot
.1765 .11376 Mdot
.18434 .11768 Mdot
.18434 .1216 Mdot
.17257 .11376 Mdot
.16473 .10591 Mdot
.16473 .10591 Mdot
.16865 .11376 Mdot
.17257 .11768 Mdot
.16081 .11768 Mdot
.83527 .81958 Mdot
.76861 .71763 Mdot
.56078 .4902 Mdot
.50588 .42746 Mdot
.34511 .30198 Mdot
.34903 .3059 Mdot
.32158 .28629 Mdot
.29413 .27061 Mdot
.26668 .25492 Mdot
.251 .23139 Mdot
.24708 .22355 Mdot
.26276 .23139 Mdot
.30198 .26276 Mdot
.3255 .29021 Mdot
.34903 .3255 Mdot
.3608 .34511 Mdot
.36472 .36864 Mdot
.35687 .36864 Mdot
.34119 .36472 Mdot
.34119 .36472 Mdot
.33727 .35687 Mdot
.34511 .35295 Mdot
.3608 .3608 Mdot
.37256 .35687 Mdot
.3608 .34119 Mdot
.31374 .30982 Mdot
.29021 .29413 Mdot
.22747 .23924 Mdot
.11768 .16081 Mdot
.11376 .15689 Mdot
.09807 .1412 Mdot
.07062 .10983 Mdot
.07846 .10199 Mdot
.07846 .09023 Mdot
.08239 .07454 Mdot
.09415 .07454 Mdot
.10591 .07454 Mdot
.10983 .07454 Mdot
.10983 .0667 Mdot
.12944 .07062 Mdot
.13728 .07454 Mdot
.1216 .07062 Mdot
.10983 .05886 Mdot
.10591 .05886 Mdot
.09415 .05494 Mdot
.10983 .0667 Mdot
.08239 .04709 Mdot
.07062 .03533 Mdot
.06278 .03925 Mdot
.0667 .05102 Mdot
.09023 .07062 Mdot
.10199 .07062 Mdot
.10983 .08239 Mdot
.18042 .13728 Mdot
.21179 .17257 Mdot
.31766 .25492 Mdot
.36864 .29413 Mdot
.42746 .34119 Mdot
.45491 .36864 Mdot
.47059 .37648 Mdot
.39609 .31766 Mdot
.26668 .20787 Mdot
.18434 .13336 Mdot
.14905 .10591 Mdot
.14513 .10199 Mdot
.18042 .12944 Mdot
.20787 .15689 Mdot
.22355 .16865 Mdot
.26668 .1961 Mdot
.29021 .21571 Mdot
.30198 .23139 Mdot
.30982 .23924 Mdot
.29806 .21963 Mdot
.30198 .20394 Mdot
.31374 .18826 Mdot
.31374 .1765 Mdot
.30982 .1765 Mdot
.30982 .17257 Mdot
.29021 .16081 Mdot
.27845 .16473 Mdot
.28237 .18434 Mdot
.28237 .20002 Mdot
.27061 .20787 Mdot
.27453 .21571 Mdot
.25884 .20787 Mdot
.26668 .21571 Mdot
.26276 .20787 Mdot
.251 .18826 Mdot
.25492 .17257 Mdot
.25884 .16081 Mdot
.25492 .15297 Mdot
.26668 .15689 Mdot
.251 .15689 Mdot
.25492 .16081 Mdot
.23531 .15689 Mdot
.24316 .16865 Mdot
.23531 .1765 Mdot
.23531 .18042 Mdot
.22747 .17257 Mdot
.23139 .18042 Mdot
.21179 .16473 Mdot
.20787 .15689 Mdot
.21571 .1412 Mdot
.22747 .13728 Mdot
.22747 .12944 Mdot
.22747 .1216 Mdot
.22355 .11376 Mdot
.21179 .10983 Mdot
.21179 .10983 Mdot
.20002 .10983 Mdot
.20002 .11376 Mdot
.18826 .1216 Mdot
.1961 .12944 Mdot
.18434 .1216 Mdot
.1765 .12552 Mdot
.17257 .12944 Mdot
.1765 .1412 Mdot
.18042 .14513 Mdot
.16081 .12552 Mdot
.14513 .11768 Mdot
.83919 .79213 Mdot
.6941 .64313 Mdot
.60391 .53725 Mdot
.55294 .49412 Mdot
.5098 .45098 Mdot
.42746 .36864 Mdot
.3255 .26276 Mdot
.28629 .22747 Mdot
.25884 .20787 Mdot
.22747 .19218 Mdot
.24316 .21179 Mdot
.251 .23139 Mdot
.28629 .27453 Mdot
.32158 .32158 Mdot
.35687 .35687 Mdot
.36472 .36864 Mdot
.36472 .3608 Mdot
.35295 .34903 Mdot
.34511 .34119 Mdot
.34119 .33727 Mdot
.36472 .35687 Mdot
.38432 .36472 Mdot
.38432 .37256 Mdot
.36472 .37256 Mdot
.35295 .37648 Mdot
.22355 .27845 Mdot
.18826 .24708 Mdot
.14513 .1961 Mdot
.10591 .15297 Mdot
.09415 .13728 Mdot
.09023 .10983 Mdot
.08631 .09023 Mdot
.07454 .06278 Mdot
.06278 .04317 Mdot
.09807 .05886 Mdot
.13336 .07454 Mdot
.15689 .07846 Mdot
.17257 .09023 Mdot
.16865 .09023 Mdot
.14905 .07846 Mdot
.13728 .07454 Mdot
.13336 .07454 Mdot
.10983 .05494 Mdot
.09415 .03533 Mdot
.05886 .01965 Mdot
.05494 .02749 Mdot
.0667 .05102 Mdot
.07846 .06278 Mdot
.09023 .08239 Mdot
.07454 .07454 Mdot
.07454 .08631 Mdot
.08631 .10199 Mdot
.15689 .14905 Mdot
.21179 .1961 Mdot
.29806 .25884 Mdot
.37256 .30198 Mdot
.42354 .3255 Mdot
.3804 .28237 Mdot
.41961 .29413 Mdot
.28237 .1961 Mdot
.21963 .15689 Mdot
.16865 .13728 Mdot
.15689 .14905 Mdot
.12944 .13336 Mdot
.15689 .14513 Mdot
.20002 .16473 Mdot
.24316 .1961 Mdot
.27061 .21179 Mdot
.28629 .20394 Mdot
.27845 .18826 Mdot
.28237 .17257 Mdot
.28237 .15689 Mdot
.29413 .16473 Mdot
.28237 .16473 Mdot
.27061 .16081 Mdot
.25884 .15297 Mdot
.25884 .15689 Mdot
.26276 .1765 Mdot
.25884 .18434 Mdot
.251 .18826 Mdot
.25492 .20002 Mdot
.251 .20002 Mdot
.24316 .18826 Mdot
.24708 .18434 Mdot
.251 .1765 Mdot
.25492 .16473 Mdot
.25492 .15297 Mdot
.25884 .15297 Mdot
.27061 .16473 Mdot
.26668 .16865 Mdot
.26276 .17257 Mdot
.25884 .1765 Mdot
.23924 .16865 Mdot
.23531 .17257 Mdot
.24316 .18434 Mdot
.23531 .18826 Mdot
.22747 .1765 Mdot
.20787 .15689 Mdot
.20787 .15689 Mdot
.20394 .14905 Mdot
.20787 .13728 Mdot
.21571 .13728 Mdot
.21963 .12944 Mdot
.22747 .13336 Mdot
.22747 .12944 Mdot
.21571 .1216 Mdot
.20787 .1216 Mdot
.21179 .12552 Mdot
.19218 .1216 Mdot
.18042 .11768 Mdot
.1765 .1216 Mdot
.18042 .12944 Mdot
.1765 .13728 Mdot
.17257 .13728 Mdot
.17257 .13728 Mdot
.16081 .1216 Mdot
.14905 .10983 Mdot
.9333 .91761 Mdot
.85095 .81958 Mdot
.6941 .63528 Mdot
.60783 .54902 Mdot
.57646 .49412 Mdot
.33727 .28629 Mdot
.25492 .21571 Mdot
.22747 .1961 Mdot
.19218 .16865 Mdot
.1765 .15689 Mdot
.16865 .16081 Mdot
.21179 .20002 Mdot
.30982 .28629 Mdot
.33335 .31374 Mdot
.3608 .34903 Mdot
.37648 .3608 Mdot
.37256 .3608 Mdot
.35687 .35687 Mdot
.35687 .35687 Mdot
.36472 .3608 Mdot
.3804 .36864 Mdot
.3804 .36472 Mdot
.38824 .38432 Mdot
.38432 .38824 Mdot
.3608 .37648 Mdot
.26668 .29413 Mdot
.22747 .251 Mdot
.16865 .20002 Mdot
.11768 .1412 Mdot
.08631 .10199 Mdot
.07062 .07062 Mdot
.06278 .04317 Mdot
.10199 .05494 Mdot
.13728 .0667 Mdot
.18434 .09415 Mdot
.21571 .12944 Mdot
.22747 .13336 Mdot
.20394 .10983 Mdot
.16081 .07846 Mdot
.13336 .05886 Mdot
.10591 .03925 Mdot
.08631 .02357 Mdot
.07846 .01965 Mdot
.0667 .02749 Mdot
.07454 .04317 Mdot
.09415 .05886 Mdot
.10983 .07062 Mdot
.11376 .09415 Mdot
.1216 .10983 Mdot
.11768 .10983 Mdot
.10983 .10591 Mdot
.13336 .13336 Mdot
.21179 .19218 Mdot
.28237 .23924 Mdot
.36864 .28629 Mdot
.15689 .11768 Mdot
.18434 .12552 Mdot
.20002 .13728 Mdot
.31766 .22355 Mdot
.40001 .29413 Mdot
.36864 .28237 Mdot
.33727 .27061 Mdot
.29413 .23531 Mdot
.251 .20394 Mdot
.24316 .20002 Mdot
.25884 .20787 Mdot
.27061 .21179 Mdot
.27061 .20394 Mdot
.26276 .18434 Mdot
.26668 .16865 Mdot
.26276 .15689 Mdot
.27061 .16081 Mdot
.251 .15689 Mdot
.24708 .15297 Mdot
.24708 .16081 Mdot
.23924 .16081 Mdot
.23531 .15689 Mdot
.23924 .16081 Mdot
.24708 .18042 Mdot
.24708 .18826 Mdot
.23531 .18042 Mdot
.22747 .16865 Mdot
.22747 .16081 Mdot
.24316 .16865 Mdot
.25492 .18434 Mdot
.251 .1765 Mdot
.24708 .17257 Mdot
.25492 .1765 Mdot
.24708 .1765 Mdot
.251 .18042 Mdot
.251 .16865 Mdot
.23924 .15689 Mdot
.24316 .16081 Mdot
.23924 .16473 Mdot
.22355 .15297 Mdot
.20787 .14905 Mdot
.20394 .14905 Mdot
.20002 .14513 Mdot
.20002 .14513 Mdot
.20002 .14905 Mdot
.20394 .15297 Mdot
.20394 .15297 Mdot
.20787 .14905 Mdot
.21179 .1412 Mdot
.20787 .13728 Mdot
.20394 .12944 Mdot
.19218 .11768 Mdot
.18826 .1216 Mdot
.18434 .11376 Mdot
.18826 .10983 Mdot
.17257 .10199 Mdot
.18434 .11376 Mdot
.18434 .1216 Mdot
.18042 .10983 Mdot
.17257 .10591 Mdot
.92938 .91761 Mdot
.84703 .81566 Mdot
.52941 .48628 Mdot
.3059 .30198 Mdot
.26668 .24708 Mdot
.23531 .20394 Mdot
.20002 .16473 Mdot
.1765 .13728 Mdot
.15689 .12552 Mdot
.15689 .13728 Mdot
.23139 .20394 Mdot
.27061 .251 Mdot
.30982 .29413 Mdot
.34511 .3255 Mdot
.36864 .35295 Mdot
.39217 .36472 Mdot
.41177 .3804 Mdot
.38824 .3608 Mdot
.36864 .34119 Mdot
.3804 .35295 Mdot
.37256 .35295 Mdot
.38432 .36864 Mdot
.3804 .37256 Mdot
.37256 .3608 Mdot
.34119 .33335 Mdot
.25884 .25884 Mdot
.1412 .15297 Mdot
.09415 .09415 Mdot
.07454 .05886 Mdot
.11376 .0667 Mdot
.14905 .08631 Mdot
.16865 .09415 Mdot
.1961 .10591 Mdot
.21963 .12944 Mdot
.20394 .11376 Mdot
.16865 .08239 Mdot
.12552 .05886 Mdot
.08631 .03925 Mdot
.06278 .02357 Mdot
.05494 .02749 Mdot
.07062 .03925 Mdot
.07454 .05494 Mdot
.16865 .12552 Mdot
.13336 .09415 Mdot
.10983 .07062 Mdot
.34903 .23924 Mdot
.30198 .20394 Mdot
.15297 .12552 Mdot
.29413 .251 Mdot
.25884 .22355 Mdot
.23139 .20394 Mdot
.20394 .1765 Mdot
.16081 .12944 Mdot
.09807 .07454 Mdot
.07454 .05102 Mdot
.05886 .03533 Mdot
.26276 .18826 Mdot
.58039 .43922 Mdot
.58039 .45098 Mdot
.5647 .44706 Mdot
.37256 .31766 Mdot
.35295 .3059 Mdot
.32943 .29021 Mdot
.30982 .26276 Mdot
.29413 .24316 Mdot
.27845 .21963 Mdot
.27845 .1961 Mdot
.27453 .1765 Mdot
.28629 .17257 Mdot
.27845 .16865 Mdot
.26668 .16473 Mdot
.26276 .16081 Mdot
.24708 .14513 Mdot
.24708 .14905 Mdot
.23531 .15297 Mdot
.23139 .15689 Mdot
.24316 .16865 Mdot
.23531 .17257 Mdot
.21571 .16081 Mdot
.21963 .16081 Mdot
.22355 .16865 Mdot
.21963 .17257 Mdot
.22747 .18042 Mdot
.23139 .18042 Mdot
.23924 .18826 Mdot
.23531 .18042 Mdot
.23531 .16865 Mdot
.23924 .15689 Mdot
.24708 .14905 Mdot
.24316 .1412 Mdot
.23531 .13336 Mdot
.21963 .1216 Mdot
.21179 .12944 Mdot
.20787 .13336 Mdot
.20002 .12944 Mdot
.20002 .13336 Mdot
.1961 .1412 Mdot
.19218 .14905 Mdot
.19218 .15297 Mdot
.20394 .15689 Mdot
.20787 .14513 Mdot
.20787 .1412 Mdot
.21179 .12944 Mdot
.21179 .1216 Mdot
.20002 .11768 Mdot
.1961 .10983 Mdot
.19218 .09415 Mdot
.18826 .09023 Mdot
.18042 .09415 Mdot
.1765 .09807 Mdot
.17257 .09807 Mdot
.16865 .09807 Mdot
.76076 .74116 Mdot
.57254 .54117 Mdot
.3059 .27845 Mdot
.23924 .20394 Mdot
.23139 .17257 Mdot
.20002 .14905 Mdot
.20787 .16473 Mdot
.19218 .16865 Mdot
.18826 .18434 Mdot
.18826 .18826 Mdot
.20002 .20002 Mdot
.28237 .25884 Mdot
.34119 .3059 Mdot
.3804 .33335 Mdot
.38824 .34119 Mdot
.39609 .34119 Mdot
.38432 .33335 Mdot
.36472 .3255 Mdot
.37256 .33335 Mdot
.39609 .34903 Mdot
.38824 .35687 Mdot
.3804 .35687 Mdot
.39609 .3608 Mdot
.27061 .251 Mdot
.1216 .1216 Mdot
.1216 .10199 Mdot
.11376 .08239 Mdot
.11768 .07846 Mdot
.12552 .07062 Mdot
.13336 .07062 Mdot
.1412 .07454 Mdot
.14513 .08631 Mdot
.16081 .09415 Mdot
.13336 .07454 Mdot
.08239 .05102 Mdot
.0667 .05494 Mdot
.06278 .05886 Mdot
.05494 .05494 Mdot
.06278 .06278 Mdot
.1412 .1216 Mdot
.07454 .07454 Mdot
.20002 .18042 Mdot
.78429 .6196 Mdot
.77253 .62744 Mdot
.48628 .41569 Mdot
.32158 .28629 Mdot
.31374 .27061 Mdot
.13728 .12552 Mdot
.1216 .10591 Mdot
.08631 .07454 Mdot
.09415 .07454 Mdot
.07062 .05886 Mdot
.06278 .05494 Mdot
.07062 .0667 Mdot
.54902 .42746 Mdot
.67842 .54117 Mdot
.62744 .5098 Mdot
.59607 .49804 Mdot
.47843 .42354 Mdot
.46275 .40785 Mdot
.44706 .3804 Mdot
.43922 .3608 Mdot
.40393 .33727 Mdot
.3804 .30198 Mdot
.36864 .27453 Mdot
.34511 .251 Mdot
.32158 .22747 Mdot
.30982 .21963 Mdot
.29413 .21179 Mdot
.27845 .1961 Mdot
.26276 .18434 Mdot
.24708 .16865 Mdot
.23531 .16865 Mdot
.23139 .17257 Mdot
.22747 .16473 Mdot
.21571 .16865 Mdot
.21179 .16473 Mdot
.20787 .16081 Mdot
.21571 .16473 Mdot
.20787 .15689 Mdot
.20394 .16081 Mdot
.21179 .16081 Mdot
.20787 .15297 Mdot
.20002 .1412 Mdot
.21571 .14905 Mdot
.20787 .1412 Mdot
.20787 .1412 Mdot
.21963 .1412 Mdot
.21963 .12944 Mdot
.21571 .1216 Mdot
.20394 .11768 Mdot
.20002 .1216 Mdot
.1961 .12552 Mdot
.1961 .12944 Mdot
.19218 .12944 Mdot
.20394 .14513 Mdot
.20394 .14513 Mdot
.20787 .1412 Mdot
.1961 .12552 Mdot
.20394 .12552 Mdot
.1961 .10983 Mdot
.1961 .11376 Mdot
.1961 .10591 Mdot
.1961 .10199 Mdot
.18042 .09415 Mdot
.16865 .09023 Mdot
.17257 .10199 Mdot
.17257 .11376 Mdot
.16473 .10591 Mdot
.6392 .63136 Mdot
.53333 .49804 Mdot
.38824 .34119 Mdot
.3059 .27453 Mdot
.251 .23924 Mdot
.23139 .22355 Mdot
.20002 .19218 Mdot
.16865 .15689 Mdot
.14905 .13728 Mdot
.16473 .14513 Mdot
.26668 .21571 Mdot
.3059 .25492 Mdot
.37648 .3059 Mdot
.38824 .31766 Mdot
.39609 .3255 Mdot
.33727 .28629 Mdot
.38432 .31374 Mdot
.34903 .28237 Mdot
.34119 .28237 Mdot
.34119 .28237 Mdot
.36472 .29806 Mdot
.26668 .21571 Mdot
.17257 .12944 Mdot
.14905 .09415 Mdot
.12944 .07846 Mdot
.10983 .05494 Mdot
.10591 .05494 Mdot
.10199 .05102 Mdot
.11376 .07062 Mdot
.12944 .09415 Mdot
.12552 .09023 Mdot
.09807 .07062 Mdot
.07454 .05102 Mdot
.07454 .05102 Mdot
.07454 .06278 Mdot
.06278 .05886 Mdot
.08239 .07846 Mdot
.10983 .10591 Mdot
.11376 .1216 Mdot
.44314 .37648 Mdot
.56078 .47059 Mdot
.82743 .66665 Mdot
.4902 .39609 Mdot
.22355 .17257 Mdot
.16473 .11376 Mdot
.1216 .08239 Mdot
.08239 .05102 Mdot
.05494 .04317 Mdot
.06278 .05494 Mdot
.06278 .06278 Mdot
.05494 .05494 Mdot
.23924 .20002 Mdot
.6941 .55686 Mdot
.62352 .5098 Mdot
.61176 .50588 Mdot
.55294 .45883 Mdot
.37256 .3255 Mdot
.40001 .33335 Mdot
.42746 .35687 Mdot
.48235 .40785 Mdot
.56078 .47451 Mdot
.58039 .48235 Mdot
.56078 .46275 Mdot
.52941 .42746 Mdot
.45491 .3608 Mdot
.40393 .3255 Mdot
.37648 .31766 Mdot
.35687 .31766 Mdot
.32943 .29021 Mdot
.3059 .26276 Mdot
.26668 .21963 Mdot
.251 .20787 Mdot
.23531 .20394 Mdot
.22355 .19218 Mdot
.22355 .18826 Mdot
.23139 .18042 Mdot
.21963 .16865 Mdot
.21963 .16081 Mdot
.21963 .15689 Mdot
.21571 .16081 Mdot
.20787 .16081 Mdot
.20002 .15689 Mdot
.20787 .16081 Mdot
.20002 .15297 Mdot
.20002 .14513 Mdot
.21179 .13728 Mdot
.21179 .1216 Mdot
.19218 .10199 Mdot
.20394 .11376 Mdot
.19218 .10983 Mdot
.18826 .11768 Mdot
.18826 .1216 Mdot
.18826 .1216 Mdot
.19218 .13336 Mdot
.18042 .1216 Mdot
.18826 .1216 Mdot
.17257 .10591 Mdot
.18042 .10591 Mdot
.16865 .09807 Mdot
.17257 .10199 Mdot
.16473 .10591 Mdot
.16081 .09807 Mdot
.15297 .09415 Mdot
.17257 .11768 Mdot
.16865 .12552 Mdot
.16081 .11768 Mdot
.92154 .90193 Mdot
.749 .72939 Mdot
.41177 .38432 Mdot
.35295 .32943 Mdot
.18826 .1961 Mdot
.18434 .18042 Mdot
.16081 .15689 Mdot
.1412 .13336 Mdot
.15689 .13336 Mdot
.18826 .15297 Mdot
.23531 .18042 Mdot
.29806 .22747 Mdot
.30198 .22747 Mdot
.22747 .18042 Mdot
.24708 .18826 Mdot
.22747 .16473 Mdot
.20787 .14513 Mdot
.22355 .15689 Mdot
.27453 .19218 Mdot
.30198 .20394 Mdot
.19218 .12552 Mdot
.19218 .12944 Mdot
.15689 .09807 Mdot
.12944 .08239 Mdot
.10199 .06278 Mdot
.09415 .05886 Mdot
.11376 .08239 Mdot
.13728 .10983 Mdot
.13336 .10983 Mdot
.08631 .07454 Mdot
.08239 .06278 Mdot
.08631 .06278 Mdot
.08631 .06278 Mdot
.07846 .06278 Mdot
.1216 .10591 Mdot
.13336 .12944 Mdot
.14905 .13728 Mdot
.14905 .1412 Mdot
.21963 .20002 Mdot
.47059 .39217 Mdot
.46275 .3804 Mdot
.27845 .22355 Mdot
.1216 .09023 Mdot
.14513 .10199 Mdot
.05494 .04317 Mdot
.04709 .03925 Mdot
.03141 .04317 Mdot
.02357 .04709 Mdot
.04317 .0667 Mdot
.31374 .28237 Mdot
.59607 .50588 Mdot
.62744 .53725 Mdot
.58823 .49804 Mdot
.61176 .50196 Mdot
.54509 .44706 Mdot
.46667 .38824 Mdot
.38432 .33335 Mdot
.40001 .34511 Mdot
.61176 .5098 Mdot
.59607 .49412 Mdot
.61176 .50196 Mdot
.6392 .52157 Mdot
.58431 .47059 Mdot
.39609 .33335 Mdot
.41569 .36864 Mdot
.45491 .41177 Mdot
.46667 .42354 Mdot
.45098 .40785 Mdot
.42746 .37256 Mdot
.39609 .34511 Mdot
.36472 .32158 Mdot
.32158 .29021 Mdot
.29806 .27845 Mdot
.27845 .24708 Mdot
.27453 .23139 Mdot
.26668 .21963 Mdot
.26276 .20787 Mdot
.251 .20394 Mdot
.22747 .19218 Mdot
.20002 .17257 Mdot
.20002 .16473 Mdot
.1961 .15297 Mdot
.18826 .13728 Mdot
.18826 .11768 Mdot
.1961 .11376 Mdot
.18826 .10591 Mdot
.1961 .10983 Mdot
.20394 .11376 Mdot
.20002 .1216 Mdot
.17257 .10591 Mdot
.15297 .08631 Mdot
.12552 .07454 Mdot
.11376 .06278 Mdot
.1216 .07062 Mdot
.12944 .07846 Mdot
.13728 .08239 Mdot
.16081 .09807 Mdot
.17257 .10983 Mdot
.16473 .11376 Mdot
.15297 .10591 Mdot
.15689 .11376 Mdot
.15689 .11376 Mdot
.15297 .11768 Mdot
.16081 .1216 Mdot
.85095 .84703 Mdot
.60391 .61176 Mdot
.20394 .20394 Mdot
.21571 .20002 Mdot
.20394 .18042 Mdot
.1961 .16473 Mdot
.20394 .15689 Mdot
.20787 .14905 Mdot
.18826 .12944 Mdot
.18042 .11768 Mdot
.16081 .10983 Mdot
.14513 .09807 Mdot
.13336 .08239 Mdot
.14905 .08631 Mdot
.16081 .09415 Mdot
.20787 .12552 Mdot
.23531 .14905 Mdot
.20787 .13728 Mdot
.18434 .12552 Mdot
.14905 .10983 Mdot
.1216 .09807 Mdot
.10983 .09415 Mdot
.10983 .09023 Mdot
.12552 .11376 Mdot
.14513 .13336 Mdot
.12944 .11376 Mdot
.11768 .09807 Mdot
.09807 .08239 Mdot
.10591 .07846 Mdot
.10591 .07062 Mdot
.09023 .06278 Mdot
.08239 .0667 Mdot
.1412 .11376 Mdot
.19218 .14905 Mdot
.22747 .1765 Mdot
.24708 .1961 Mdot
.29806 .23531 Mdot
.32158 .251 Mdot
.29413 .22747 Mdot
.11768 .09023 Mdot
.13728 .10983 Mdot
.09807 .09023 Mdot
.07062 .07846 Mdot
.05494 .07846 Mdot
.04317 .07454 Mdot
.04317 .07454 Mdot
.22355 .22747 Mdot
.48235 .43138 Mdot
.51765 .45491 Mdot
.57254 .48235 Mdot
.59215 .48628 Mdot
.61176 .49804 Mdot
.61176 .49804 Mdot
.56862 .47059 Mdot
.54509 .45098 Mdot
.56078 .45883 Mdot
.58431 .47451 Mdot
.58823 .48235 Mdot
.58039 .47843 Mdot
.64705 .54117 Mdot
.57646 .49804 Mdot
.3608 .34119 Mdot
.37256 .34511 Mdot
.33727 .31766 Mdot
.50196 .43138 Mdot
.58431 .4902 Mdot
.40393 .36472 Mdot
.38432 .35687 Mdot
.39609 .36864 Mdot
.42746 .39217 Mdot
.43922 .40001 Mdot
.44314 .40001 Mdot
.4353 .3804 Mdot
.41177 .34903 Mdot
.38432 .32158 Mdot
.33727 .28237 Mdot
.29021 .24708 Mdot
.22747 .1961 Mdot
.20787 .17257 Mdot
.21179 .16081 Mdot
.20394 .13728 Mdot
.18434 .11768 Mdot
.19218 .11768 Mdot
.1961 .1216 Mdot
.18826 .1216 Mdot
.18434 .12552 Mdot
.14513 .09415 Mdot
.10983 .06278 Mdot
.07454 .03141 Mdot
.04709 .01572 Mdot
.03141 .00788 Mdot
.04317 .01965 Mdot
.04709 .01965 Mdot
.10983 .05886 Mdot
.13728 .07846 Mdot
.15297 .09415 Mdot
.15297 .09807 Mdot
.14905 .10983 Mdot
.15297 .11376 Mdot
.1412 .10591 Mdot
.13728 .09807 Mdot
.65097 .63528 Mdot
.56862 .50588 Mdot
.31374 .251 Mdot
.30198 .23139 Mdot
.27845 .20787 Mdot
.24708 .18434 Mdot
.18826 .13728 Mdot
.1765 .13336 Mdot
.16081 .11768 Mdot
.15297 .10591 Mdot
.15689 .09415 Mdot
.16473 .09807 Mdot
.19218 .12552 Mdot
.23924 .17257 Mdot
.23139 .1765 Mdot
.19218 .15689 Mdot
.15689 .13336 Mdot
.13728 .11768 Mdot
.11768 .10199 Mdot
.12552 .10983 Mdot
.15297 .1412 Mdot
.16865 .15297 Mdot
.15297 .13336 Mdot
.14905 .12552 Mdot
.12944 .10983 Mdot
.11376 .10199 Mdot
.11768 .09023 Mdot
.07846 .05494 Mdot
.0667 .05102 Mdot
.07454 .05494 Mdot
.10591 .07062 Mdot
.1765 .1216 Mdot
.23139 .16081 Mdot
.32158 .22747 Mdot
.30982 .21571 Mdot
.24316 .16473 Mdot
.1961 .13336 Mdot
.15689 .11376 Mdot
.12944 .10591 Mdot
.11376 .09807 Mdot
.10591 .10591 Mdot
.09415 .09415 Mdot
.10199 .10199 Mdot
.09807 .09807 Mdot
.1765 .16081 Mdot
.28237 .23924 Mdot
.33335 .28237 Mdot
.40001 .32943 Mdot
.67842 .55294 Mdot
.64313 .53725 Mdot
.64705 .53725 Mdot
.64313 .52941 Mdot
.62744 .51372 Mdot
.62352 .5098 Mdot
.6196 .51372 Mdot
.59999 .5098 Mdot
.59999 .51765 Mdot
.60783 .52549 Mdot
.53725 .47451 Mdot
.47843 .42746 Mdot
.43138 .38432 Mdot
.42746 .37256 Mdot
.71371 .59215 Mdot
.6392 .53725 Mdot
.40001 .3608 Mdot
.40393 .36472 Mdot
.36864 .33727 Mdot
.3608 .32943 Mdot
.49412 .42746 Mdot
.54117 .46275 Mdot
.56078 .47059 Mdot
.5647 .47059 Mdot
.54509 .45098 Mdot
.47843 .40001 Mdot
.43138 .3608 Mdot
.40393 .33727 Mdot
.3608 .29413 Mdot
.32158 .25492 Mdot
.30198 .23139 Mdot
.27845 .20394 Mdot
.24708 .17257 Mdot
.21963 .16473 Mdot
.20787 .16473 Mdot
.17257 .13728 Mdot
.10591 .07062 Mdot
.0667 .03533 Mdot
.04709 .01965 Mdot
.02749 .00396 Mdot
.02749 .00788 Mdot
.01965 .00396 Mdot
.01572 .00396 Mdot
.04317 .01965 Mdot
.0667 .02357 Mdot
.09807 .04317 Mdot
.12944 .07454 Mdot
.15297 .09023 Mdot
.16081 .09807 Mdot
.1765 .11376 Mdot
.76861 .72939 Mdot
.6196 .56078 Mdot
.3608 .29806 Mdot
.26276 .20394 Mdot
.26668 .1961 Mdot
.24316 .16865 Mdot
.24708 .16473 Mdot
.22747 .13728 Mdot
.22355 .13336 Mdot
.21571 .14905 Mdot
.23139 .1765 Mdot
.23531 .18826 Mdot
.21571 .1765 Mdot
.1765 .14513 Mdot
.14905 .1216 Mdot
.1216 .09807 Mdot
.1216 .09807 Mdot
.1412 .11768 Mdot
.16081 .13336 Mdot
.18042 .15689 Mdot
.19218 .16473 Mdot
.18434 .16473 Mdot
.13728 .13728 Mdot
.11376 .10591 Mdot
.07062 .06278 Mdot
.07062 .05494 Mdot
.0667 .05102 Mdot
.08239 .05886 Mdot
.10199 .07454 Mdot
.16473 .11376 Mdot
.18434 .1216 Mdot
.18826 .1216 Mdot
.1961 .12552 Mdot
.16473 .09807 Mdot
.13336 .08239 Mdot
.11768 .09415 Mdot
.09807 .09807 Mdot
.1216 .12552 Mdot
.10591 .11768 Mdot
.26276 .23924 Mdot
.24316 .22747 Mdot
.28237 .251 Mdot
.30982 .27061 Mdot
.32158 .27453 Mdot
.26276 .23531 Mdot
.40785 .3608 Mdot
.67057 .57254 Mdot
.59215 .51372 Mdot
.6392 .54509 Mdot
.59999 .5098 Mdot
.63136 .53725 Mdot
.63136 .53725 Mdot
.62352 .53725 Mdot
.63136 .54509 Mdot
.62744 .54117 Mdot
.60783 .52157 Mdot
.59607 .50196 Mdot
.57646 .47451 Mdot
.56078 .46275 Mdot
.55294 .45098 Mdot
.57646 .47059 Mdot
.55686 .46667 Mdot
.55294 .45883 Mdot
.5098 .42354 Mdot
.4902 .41569 Mdot
.48628 .41961 Mdot
.52157 .44706 Mdot
.53333 .46275 Mdot
.54902 .47059 Mdot
.55686 .47059 Mdot
.55294 .46667 Mdot
.55294 .46275 Mdot
.56078 .46275 Mdot
.54902 .45491 Mdot
.51372 .44314 Mdot
.4902 .42746 Mdot
.47843 .41569 Mdot
.44706 .38824 Mdot
.40393 .35687 Mdot
.33727 .29413 Mdot
.1765 .16081 Mdot
.13728 .11376 Mdot
.10199 .07846 Mdot
.04709 .02749 Mdot
.03141 .0118 Mdot
.01965 .00788 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.01572 .00396 Mdot
.09415 .03533 Mdot
.14513 .07062 Mdot
.16081 .08239 Mdot
.16473 .09807 Mdot
.89017 .87056 Mdot
.62352 .6196 Mdot
.3804 .33727 Mdot
.46667 .3804 Mdot
.47451 .37648 Mdot
.3804 .29806 Mdot
.33727 .26276 Mdot
.29413 .23531 Mdot
.27845 .22747 Mdot
.26276 .21571 Mdot
.20394 .17257 Mdot
.18434 .15297 Mdot
.16473 .12944 Mdot
.14513 .11768 Mdot
.12552 .09807 Mdot
.12552 .09807 Mdot
.14513 .10983 Mdot
.15297 .12552 Mdot
.1765 .14513 Mdot
.18434 .15689 Mdot
.14513 .13336 Mdot
.11768 .11376 Mdot
.09023 .09023 Mdot
.07846 .07846 Mdot
.08239 .07454 Mdot
.08631 .07454 Mdot
.10983 .09023 Mdot
.13336 .10199 Mdot
.16865 .1216 Mdot
.18434 .12552 Mdot
.19218 .1216 Mdot
.14905 .08631 Mdot
.12552 .07846 Mdot
.10199 .08631 Mdot
.09415 .09023 Mdot
.08631 .09807 Mdot
.12552 .14513 Mdot
.26668 .26668 Mdot
.46667 .41961 Mdot
.46667 .41177 Mdot
.47059 .40785 Mdot
.47843 .39609 Mdot
.41177 .34511 Mdot
.27845 .25884 Mdot
.85095 .70587 Mdot
.52549 .46275 Mdot
.53333 .47059 Mdot
.40393 .36472 Mdot
.41569 .36864 Mdot
.56078 .47451 Mdot
.59215 .50196 Mdot
.61176 .51765 Mdot
.63136 .54117 Mdot
.61568 .52941 Mdot
.6392 .53725 Mdot
.38824 .34119 Mdot
.46275 .38432 Mdot
.58431 .47059 Mdot
.54509 .43922 Mdot
.54117 .45491 Mdot
.56862 .48235 Mdot
.58823 .50196 Mdot
.59215 .50196 Mdot
.58823 .4902 Mdot
.54509 .45491 Mdot
.53333 .45883 Mdot
.51765 .45883 Mdot
.51372 .46275 Mdot
.5098 .46275 Mdot
.51765 .45883 Mdot
.52549 .45098 Mdot
.52549 .45098 Mdot
.51765 .45098 Mdot
.52157 .44706 Mdot
.52157 .45098 Mdot
.52157 .45491 Mdot
.52549 .45098 Mdot
.55686 .46667 Mdot
.25492 .23924 Mdot
.08239 .09415 Mdot
.05494 .05102 Mdot
.00788 .00788 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.0118 .00396 Mdot
.02357 .00396 Mdot
.05102 .0118 Mdot
.07454 .01965 Mdot
.10983 .04317 Mdot
.16081 .08239 Mdot
.16865 .09415 Mdot
.91369 .89409 Mdot
.78037 .70194 Mdot
.65097 .56078 Mdot
.56862 .48628 Mdot
.48628 .41177 Mdot
.34119 .29806 Mdot
.31374 .27061 Mdot
.25884 .21571 Mdot
.21179 .17257 Mdot
.20002 .16081 Mdot
.16865 .13336 Mdot
.15297 .1216 Mdot
.15689 .11768 Mdot
.17257 .12944 Mdot
.17257 .13728 Mdot
.16473 .12944 Mdot
.13728 .11768 Mdot
.1216 .10591 Mdot
.09807 .09807 Mdot
.09807 .10199 Mdot
.08239 .09023 Mdot
.10199 .09807 Mdot
.13336 .10983 Mdot
.16473 .12552 Mdot
.17257 .12944 Mdot
.19218 .14513 Mdot
.1961 .14905 Mdot
.21179 .15689 Mdot
.19218 .12552 Mdot
.16081 .10591 Mdot
.14513 .11768 Mdot
.12944 .10983 Mdot
.11376 .10983 Mdot
.09807 .11376 Mdot
.36864 .32943 Mdot
.78037 .63528 Mdot
.55294 .45098 Mdot
.40001 .3255 Mdot
.38824 .3059 Mdot
.27845 .23139 Mdot
.29806 .25884 Mdot
.60783 .50588 Mdot
.51372 .43922 Mdot
.54509 .45883 Mdot
.44314 .37648 Mdot
.41569 .34511 Mdot
.51765 .42354 Mdot
.57646 .47843 Mdot
.59607 .49804 Mdot
.60783 .51765 Mdot
.61176 .52549 Mdot
.64313 .54117 Mdot
.27845 .26276 Mdot
.32943 .29806 Mdot
.74116 .59999 Mdot
.251 .23531 Mdot
.40393 .36864 Mdot
.68626 .58823 Mdot
.5098 .45098 Mdot
.50196 .44314 Mdot
.53725 .46667 Mdot
.54902 .47843 Mdot
.52157 .46275 Mdot
.50196 .45491 Mdot
.50588 .47059 Mdot
.49412 .47451 Mdot
.5098 .47843 Mdot
.51372 .46667 Mdot
.51765 .45491 Mdot
.5098 .44314 Mdot
.5098 .4353 Mdot
.48628 .40785 Mdot
.48235 .40393 Mdot
.48235 .39609 Mdot
.47843 .39217 Mdot
.21179 .1961 Mdot
.04709 .0667 Mdot
.0118 .02357 Mdot
.0118 .01572 Mdot
.00788 .00788 Mdot
.00788 .0118 Mdot
.00396 .00788 Mdot
.00788 .00396 Mdot
.01572 .00396 Mdot
.04317 .0118 Mdot
.10983 .05886 Mdot
.12944 .07062 Mdot
.15297 .09023 Mdot
.16473 .09023 Mdot
.16473 .09023 Mdot
.8784 .81174 Mdot
.77253 .67842 Mdot
.58431 .48235 Mdot
.53333 .44706 Mdot
.32943 .28237 Mdot
.27845 .21179 Mdot
.25884 .18434 Mdot
.23924 .16865 Mdot
.20394 .14905 Mdot
.19218 .1412 Mdot
.18042 .12944 Mdot
.1765 .12552 Mdot
.16081 .11768 Mdot
.13336 .10591 Mdot
.12552 .10199 Mdot
.11768 .09415 Mdot
.10591 .09415 Mdot
.10591 .09415 Mdot
.1216 .10983 Mdot
.14905 .12944 Mdot
.1961 .15297 Mdot
.20002 .15297 Mdot
.21179 .16081 Mdot
.20394 .16473 Mdot
.20394 .15689 Mdot
.20787 .15689 Mdot
.1961 .14905 Mdot
.19218 .14905 Mdot
.16081 .12552 Mdot
.10983 .08239 Mdot
.10199 .07454 Mdot
.09415 .0667 Mdot
.28629 .21179 Mdot
.39609 .29021 Mdot
.24708 .18434 Mdot
.24708 .18434 Mdot
.20002 .15689 Mdot
.19218 .15297 Mdot
.18826 .15689 Mdot
.16473 .13728 Mdot
.53725 .41569 Mdot
.46667 .3608 Mdot
.45883 .3608 Mdot
.49804 .40393 Mdot
.52549 .4353 Mdot
.54117 .45098 Mdot
.55294 .47059 Mdot
.5647 .4902 Mdot
.58823 .50588 Mdot
.48235 .42354 Mdot
.5098 .43138 Mdot
.67057 .54902 Mdot
.251 .24708 Mdot
.31766 .30982 Mdot
.72939 .62352 Mdot
.62744 .54117 Mdot
.46667 .41569 Mdot
.59607 .5098 Mdot
.52549 .46275 Mdot
.27453 .27453 Mdot
.36472 .35295 Mdot
.51765 .4902 Mdot
.48628 .47059 Mdot
.47451 .45098 Mdot
.49412 .45098 Mdot
.50588 .44314 Mdot
.50196 .4353 Mdot
.52157 .43138 Mdot
.50196 .40785 Mdot
.48628 .39609 Mdot
.43922 .35687 Mdot
.34511 .28237 Mdot
.20394 .1765 Mdot
.07062 .07454 Mdot
.04709 .05102 Mdot
.03141 .03925 Mdot
.01572 .02357 Mdot
.01965 .01965 Mdot
.00788 .00788 Mdot
.01572 .00788 Mdot
.04317 .02749 Mdot
.07454 .05102 Mdot
.14905 .09807 Mdot
.18042 .11376 Mdot
.18826 .12552 Mdot
.1961 .12944 Mdot
.20002 .12944 Mdot
.8588 .78429 Mdot
.6196 .48235 Mdot
.31374 .22747 Mdot
.34903 .251 Mdot
.31766 .23531 Mdot
.29413 .22747 Mdot
.27453 .21571 Mdot
.24708 .1961 Mdot
.21571 .1765 Mdot
.18042 .14513 Mdot
.15297 .11768 Mdot
.14513 .10983 Mdot
.13728 .10199 Mdot
.12944 .09807 Mdot
.12552 .09415 Mdot
.13728 .10591 Mdot
.17257 .12944 Mdot
.20787 .15689 Mdot
.22355 .16865 Mdot
.23139 .18042 Mdot
.21963 .17257 Mdot
.21963 .1765 Mdot
.20394 .16473 Mdot
.18826 .14905 Mdot
.1765 .1412 Mdot
.1961 .16081 Mdot
.16081 .12944 Mdot
.12552 .09807 Mdot
.11376 .09023 Mdot
.09415 .07846 Mdot
.09807 .07454 Mdot
.11768 .09023 Mdot
.10983 .08631 Mdot
.10983 .09023 Mdot
.13728 .11376 Mdot
.14905 .1216 Mdot
.11768 .09807 Mdot
.27453 .21179 Mdot
.42354 .31374 Mdot
.45883 .34903 Mdot
.61568 .47059 Mdot
.4902 .38432 Mdot
.38432 .3059 Mdot
.31374 .27061 Mdot
.38824 .35687 Mdot
.45883 .41961 Mdot
.52941 .46667 Mdot
.52941 .45883 Mdot
.55686 .47451 Mdot
.4902 .43922 Mdot
.48628 .43922 Mdot
.56862 .4902 Mdot
.68234 .57254 Mdot
.62744 .52157 Mdot
.61176 .51765 Mdot
.4353 .38824 Mdot
.13728 .18042 Mdot
.1765 .21963 Mdot
.65097 .57254 Mdot
.3608 .3608 Mdot
.27061 .29021 Mdot
.44314 .40393 Mdot
.53725 .45491 Mdot
.38824 .33727 Mdot
.34903 .29806 Mdot
.4353 .34903 Mdot
.46667 .37648 Mdot
.45491 .36472 Mdot
.35295 .28237 Mdot
.1765 .15297 Mdot
.10983 .10199 Mdot
.06278 .06278 Mdot
.03141 .03925 Mdot
.02357 .03141 Mdot
.01965 .01965 Mdot
.01572 .0118 Mdot
.00788 .00788 Mdot
.13728 .09023 Mdot
.18826 .12944 Mdot
.1961 .12944 Mdot
.20002 .12944 Mdot
.19218 .13728 Mdot
.17257 .12944 Mdot
.17257 .12552 Mdot
.8784 .85095 Mdot
.72547 .68234 Mdot
.57646 .47059 Mdot
.61176 .48235 Mdot
.51765 .40785 Mdot
.3608 .29413 Mdot
.251 .21963 Mdot
.23139 .1961 Mdot
.18434 .14513 Mdot
.18042 .12944 Mdot
.17257 .1216 Mdot
.16473 .1216 Mdot
.16081 .11376 Mdot
.15689 .11768 Mdot
.17257 .1412 Mdot
.21571 .17257 Mdot
.25492 .1961 Mdot
.26668 .21179 Mdot
.251 .20787 Mdot
.22747 .1961 Mdot
.20002 .16865 Mdot
.18042 .15689 Mdot
.16473 .14513 Mdot
.14905 .13336 Mdot
.16473 .13336 Mdot
.14905 .11376 Mdot
.13728 .09807 Mdot
.11376 .07846 Mdot
.12552 .09415 Mdot
.10591 .07846 Mdot
.08631 .06278 Mdot
.10983 .07846 Mdot
.12944 .09415 Mdot
.14513 .11376 Mdot
.13336 .11376 Mdot
.10983 .09023 Mdot
.16473 .12944 Mdot
.20002 .15689 Mdot
.31766 .23531 Mdot
.32158 .23139 Mdot
.31766 .23139 Mdot
.20787 .15689 Mdot
.20002 .14905 Mdot
.1961 .16473 Mdot
.32943 .27453 Mdot
.40785 .32943 Mdot
.46667 .37648 Mdot
.38824 .31766 Mdot
.34511 .29806 Mdot
.52941 .43922 Mdot
.53725 .45098 Mdot
.55686 .46667 Mdot
.56862 .48628 Mdot
.5098 .45098 Mdot
.1765 .21179 Mdot
.22355 .24316 Mdot
.54509 .47451 Mdot
.57646 .49412 Mdot
.29806 .27845 Mdot
.47843 .40785 Mdot
.51765 .43138 Mdot
.27453 .23924 Mdot
.07454 .08631 Mdot
.20394 .18042 Mdot
.49804 .40393 Mdot
.35295 .29021 Mdot
.24316 .21179 Mdot
.22355 .18826 Mdot
.12552 .10983 Mdot
.10983 .09415 Mdot
.05886 .05102 Mdot
.03533 .02749 Mdot
.03533 .01965 Mdot
.03141 .00788 Mdot
.03141 .0118 Mdot
.20787 .12944 Mdot
.31374 .20787 Mdot
.29806 .20394 Mdot
.23531 .16081 Mdot
.20787 .1412 Mdot
.18042 .12552 Mdot
.16081 .1216 Mdot
.94898 .91369 Mdot
.81958 .72155 Mdot
.63528 .52549 Mdot
.24708 .23139 Mdot
.30982 .27061 Mdot
.26668 .22747 Mdot
.251 .20002 Mdot
.24708 .18434 Mdot
.251 .18434 Mdot
.24316 .18826 Mdot
.24316 .18826 Mdot
.22747 .18434 Mdot
.251 .20002 Mdot
.30982 .24316 Mdot
.32943 .25884 Mdot
.25884 .21963 Mdot
.24316 .21571 Mdot
.23531 .20787 Mdot
.1961 .1765 Mdot
.1765 .16865 Mdot
.16865 .15689 Mdot
.18042 .15689 Mdot
.1765 .14513 Mdot
.16081 .12944 Mdot
.15297 .11376 Mdot
.15297 .11768 Mdot
.12944 .10199 Mdot
.09415 .07062 Mdot
.1412 .09415 Mdot
.15689 .10983 Mdot
.16473 .12552 Mdot
.1412 .10983 Mdot
.12944 .10591 Mdot
.11376 .09415 Mdot
.10591 .08631 Mdot
.15297 .11376 Mdot
.16865 .12552 Mdot
.16473 .12552 Mdot
.16081 .1216 Mdot
.15297 .10983 Mdot
.14905 .10199 Mdot
.16081 .11376 Mdot
.18826 .13728 Mdot
.49804 .36864 Mdot
.35295 .25884 Mdot
.23139 .17257 Mdot
.18042 .14905 Mdot
.35687 .29021 Mdot
.36864 .31766 Mdot
.41177 .37256 Mdot
.52941 .47059 Mdot
.56078 .49412 Mdot
.41177 .3804 Mdot
.44314 .38432 Mdot
.48628 .41177 Mdot
.50588 .41569 Mdot
.5098 .42354 Mdot
.49804 .42746 Mdot
.35295 .32943 Mdot
.1765 .1961 Mdot
.33727 .3059 Mdot
.37648 .33335 Mdot
.38824 .34119 Mdot
.28629 .25492 Mdot
.1216 .1216 Mdot
.12944 .11376 Mdot
.10199 .07454 Mdot
.0667 .04709 Mdot
.04709 .03141 Mdot
.03533 .01965 Mdot
.04709 .02749 Mdot
.07062 .03925 Mdot
.09807 .05102 Mdot
.31374 .20787 Mdot
.35687 .251 Mdot
.28237 .21179 Mdot
.251 .20002 Mdot
.20002 .15689 Mdot
.16081 .12552 Mdot
.81566 .76076 Mdot
.60391 .55294 Mdot
.57646 .48628 Mdot
.4902 .40785 Mdot
.4353 .35295 Mdot
.41177 .33335 Mdot
.38432 .31374 Mdot
.36472 .30198 Mdot
.31766 .26668 Mdot
.30198 .24708 Mdot
.28237 .23531 Mdot
.27845 .22747 Mdot
.26276 .21963 Mdot
.23924 .21179 Mdot
.22355 .21179 Mdot
.21963 .20787 Mdot
.21963 .20394 Mdot
.21963 .21179 Mdot
.20394 .1961 Mdot
.1961 .1765 Mdot
.20002 .1765 Mdot
.1961 .16865 Mdot
.18826 .16081 Mdot
.14513 .11768 Mdot
.10591 .09023 Mdot
.10983 .09415 Mdot
.13336 .10199 Mdot
.14905 .10591 Mdot
.13336 .10591 Mdot
.11768 .09415 Mdot
.09415 .07454 Mdot
.13728 .10983 Mdot
.20787 .16473 Mdot
.1961 .15297 Mdot
.1765 .13728 Mdot
.12552 .10199 Mdot
.11768 .09023 Mdot
.11768 .08239 Mdot
.1412 .09415 Mdot
.12944 .08239 Mdot
.18434 .11768 Mdot
.23139 .15297 Mdot
.23924 .15689 Mdot
.21179 .13728 Mdot
.1765 .11768 Mdot
.14513 .10983 Mdot
.1412 .12552 Mdot
.20394 .18434 Mdot
.44706 .37256 Mdot
.31766 .28237 Mdot
.28237 .25492 Mdot
.32158 .28237 Mdot
.42354 .35295 Mdot
.47059 .40001 Mdot
.48628 .42746 Mdot
.48628 .42746 Mdot
.44314 .39609 Mdot
.47059 .41569 Mdot
.3608 .33727 Mdot
.30198 .29021 Mdot
.3608 .30982 Mdot
.12552 .11768 Mdot
.11376 .10199 Mdot
.07062 .05102 Mdot
.05494 .02749 Mdot
.04317 .01572 Mdot
.03925 .02357 Mdot
.07454 .05886 Mdot
.07062 .05886 Mdot
.05886 .05886 Mdot
.09023 .08631 Mdot
.11376 .09807 Mdot
.14513 .11768 Mdot
.25884 .20394 Mdot
.23924 .19218 Mdot
.18434 .15297 Mdot
.83919 .78821 Mdot
.69018 .57254 Mdot
.55686 .45883 Mdot
.5098 .41569 Mdot
.40785 .33335 Mdot
.35687 .29806 Mdot
.33335 .27845 Mdot
.29413 .25492 Mdot
.28237 .23924 Mdot
.25884 .21963 Mdot
.251 .21963 Mdot
.23531 .20787 Mdot
.31766 .26668 Mdot
.3255 .28237 Mdot
.3059 .26668 Mdot
.27061 .23531 Mdot
.22747 .1961 Mdot
.21179 .18042 Mdot
.19218 .16081 Mdot
.18826 .16081 Mdot
.16473 .14513 Mdot
.13728 .10983 Mdot
.11376 .08631 Mdot
.1412 .10199 Mdot
.15689 .10983 Mdot
.14905 .10591 Mdot
.12944 .09023 Mdot
.10591 .07846 Mdot
.15689 .12944 Mdot
.18042 .14905 Mdot
.18434 .14513 Mdot
.17257 .13728 Mdot
.15689 .12944 Mdot
.13336 .10983 Mdot
.13336 .10199 Mdot
.11768 .08239 Mdot
.11376 .07454 Mdot
.07846 .04317 Mdot
.09415 .05494 Mdot
.11768 .07062 Mdot
.14513 .09023 Mdot
.13336 .08239 Mdot
.10199 .06278 Mdot
.09415 .0667 Mdot
.08239 .0667 Mdot
.25492 .20002 Mdot
.3804 .3059 Mdot
.1412 .13336 Mdot
.17257 .15689 Mdot
.16865 .16865 Mdot
.22355 .20394 Mdot
.38432 .32943 Mdot
.45098 .37648 Mdot
.45883 .38432 Mdot
.44706 .38824 Mdot
.43922 .38432 Mdot
.24316 .22747 Mdot
.27453 .23139 Mdot
.26668 .20787 Mdot
.12552 .09807 Mdot
.08239 .06278 Mdot
.08631 .05886 Mdot
.07454 .04709 Mdot
.06278 .04709 Mdot
.06278 .05494 Mdot
.05494 .05494 Mdot
.03925 .04709 Mdot
.03533 .04317 Mdot
.03533 .04317 Mdot
.03533 .04709 Mdot
.09023 .09023 Mdot
.11768 .10983 Mdot
.16473 .1412 Mdot
.92938 .89409 Mdot
.83135 .77253 Mdot
.62744 .51372 Mdot
.46667 .3804 Mdot
.45098 .36472 Mdot
.38824 .33727 Mdot
.33335 .3059 Mdot
.30198 .27845 Mdot
.29021 .26668 Mdot
.25884 .23139 Mdot
.39217 .31766 Mdot
.47059 .37256 Mdot
.47843 .36864 Mdot
.44706 .33727 Mdot
.20787 .15689 Mdot
.17257 .13728 Mdot
.14905 .1216 Mdot
.13336 .11376 Mdot
.13728 .12944 Mdot
.13728 .12944 Mdot
.13728 .12944 Mdot
.15689 .13728 Mdot
.16081 .13336 Mdot
.15297 .13336 Mdot
.13336 .1216 Mdot
.13728 .12944 Mdot
.24708 .21179 Mdot
.24708 .20787 Mdot
.20002 .16473 Mdot
.18042 .14513 Mdot
.16081 .12552 Mdot
.15689 .1216 Mdot
.1765 .13728 Mdot
.15297 .11768 Mdot
.10983 .07846 Mdot
.08239 .04317 Mdot
.06278 .02357 Mdot
.10591 .05102 Mdot
.12552 .06278 Mdot
.09807 .04709 Mdot
.06278 .03141 Mdot
.05102 .03141 Mdot
.04709 .03141 Mdot
.10983 .08239 Mdot
.39217 .29806 Mdot
.18826 .15297 Mdot
.18826 .16473 Mdot
.14513 .13728 Mdot
.12552 .11768 Mdot
.10591 .10199 Mdot
.21571 .16473 Mdot
.25492 .18042 Mdot
.20002 .1412 Mdot
.24316 .18042 Mdot
.29806 .22747 Mdot
.37648 .29413 Mdot
.32943 .24708 Mdot
.05494 .03533 Mdot
.09415 .07062 Mdot
.11768 .09023 Mdot
.10591 .08239 Mdot
.10983 .09023 Mdot
.08631 .07846 Mdot
.05494 .0667 Mdot
.02357 .05102 Mdot
.02749 .05494 Mdot
.01965 .04317 Mdot
.02357 .05102 Mdot
.03141 .0667 Mdot
.03925 .07062 Mdot
.10983 .11376 Mdot
.92546 .89801 Mdot
.73332 .65881 Mdot
.65489 .55686 Mdot
.41961 .3804 Mdot
.37256 .34511 Mdot
.34511 .31374 Mdot
.32943 .29021 Mdot
.27453 .23924 Mdot
.29413 .23924 Mdot
.3608 .27453 Mdot
.3059 .23924 Mdot
.22355 .1765 Mdot
.20394 .15689 Mdot
.18042 .14513 Mdot
.1412 .1216 Mdot
.13336 .12552 Mdot
.13728 .13728 Mdot
.1765 .16473 Mdot
.18826 .17257 Mdot
.18826 .1765 Mdot
.18826 .1765 Mdot
.15297 .15297 Mdot
.16081 .16473 Mdot
.34119 .29806 Mdot
.3059 .26668 Mdot
.251 .21571 Mdot
.22747 .18826 Mdot
.21571 .17257 Mdot
.20394 .16473 Mdot
.20394 .16473 Mdot
.14905 .12552 Mdot
.10199 .09023 Mdot
.05886 .05102 Mdot
.07062 .03533 Mdot
.10199 .05494 Mdot
.1216 .0667 Mdot
.1216 .07062 Mdot
.09023 .05102 Mdot
.06278 .04317 Mdot
.04317 .03533 Mdot
.03925 .03533 Mdot
.09415 .07454 Mdot
.10983 .09415 Mdot
.10591 .09415 Mdot
.09415 .09023 Mdot
.09415 .08631 Mdot
.10199 .09023 Mdot
.13728 .10983 Mdot
.13728 .09023 Mdot
.12944 .07062 Mdot
.11768 .05886 Mdot
.10199 .05494 Mdot
.16081 .10199 Mdot
.1765 .11768 Mdot
.12552 .08631 Mdot
.15689 .10983 Mdot
.14905 .11376 Mdot
.1412 .10591 Mdot
.23531 .1765 Mdot
.18434 .1412 Mdot
.15689 .12944 Mdot
.1216 .11376 Mdot
.10983 .10983 Mdot
.09023 .09415 Mdot
.07062 .08239 Mdot
.04709 .07454 Mdot
.03925 .07846 Mdot
.05886 .09023 Mdot
.85487 .80782 Mdot
.64705 .60391 Mdot
.40393 .37256 Mdot
.41177 .36864 Mdot
.32158 .29021 Mdot
.3059 .27453 Mdot
.28629 .24708 Mdot
.25884 .21963 Mdot
.23924 .20002 Mdot
.1961 .1765 Mdot
.16865 .15297 Mdot
.16081 .14905 Mdot
.1412 .13728 Mdot
.16865 .15689 Mdot
.1961 .17257 Mdot
.21571 .18434 Mdot
.20394 .17257 Mdot
.1961 .16473 Mdot
.18042 .16473 Mdot
.1765 .17257 Mdot
.21571 .20394 Mdot
.22355 .20787 Mdot
.22355 .19218 Mdot
.22355 .18826 Mdot
.22355 .18042 Mdot
.23531 .18826 Mdot
.21571 .18042 Mdot
.16865 .14513 Mdot
.1412 .13336 Mdot
.10983 .10199 Mdot
.10199 .08631 Mdot
.1216 .09023 Mdot
.1412 .09415 Mdot
.1216 .07846 Mdot
.10983 .0667 Mdot
.07454 .04709 Mdot
.08239 .04317 Mdot
.0667 .03141 Mdot
.07846 .05102 Mdot
.10199 .07062 Mdot
.11376 .09415 Mdot
.09807 .08631 Mdot
.08239 .0667 Mdot
.08631 .06278 Mdot
.11376 .07846 Mdot
.10983 .06278 Mdot
.10199 .05494 Mdot
.09807 .05494 Mdot
.09807 .05494 Mdot
.08239 .04709 Mdot
.10591 .07454 Mdot
.11376 .08239 Mdot
.12944 .09807 Mdot
.11376 .09415 Mdot
.11376 .09415 Mdot
.16865 .1216 Mdot
.23139 .15689 Mdot
.23139 .14513 Mdot
.17257 .09807 Mdot
.20787 .12944 Mdot
.22747 .16081 Mdot
.16865 .12944 Mdot
.16081 .13336 Mdot
.14513 .13336 Mdot
.11376 .10983 Mdot
.81958 .77253 Mdot
.54117 .46667 Mdot
.42746 .37648 Mdot
.38824 .34119 Mdot
.31766 .27845 Mdot
.29021 .251 Mdot
.22355 .20394 Mdot
.20002 .18826 Mdot
.18042 .18042 Mdot
.16865 .16865 Mdot
.16081 .16473 Mdot
.1765 .16865 Mdot
.20002 .18434 Mdot
.20394 .18042 Mdot
.20002 .17257 Mdot
.20394 .16865 Mdot
.20394 .16865 Mdot
.16865 .14513 Mdot
.16081 .1412 Mdot
.15689 .13336 Mdot
.16473 .13728 Mdot
.19218 .15297 Mdot
.21963 .17257 Mdot
.19218 .15689 Mdot
.18826 .15689 Mdot
.18042 .15689 Mdot
.14905 .13336 Mdot
.17257 .1412 Mdot
.20394 .15689 Mdot
.16865 .12944 Mdot
.13336 .09807 Mdot
.09807 .07062 Mdot
.07846 .05494 Mdot
.06278 .04317 Mdot
.05886 .03925 Mdot
.09415 .07062 Mdot
.10591 .07846 Mdot
.1216 .09807 Mdot
.10591 .08239 Mdot
.08631 .0667 Mdot
.08631 .05886 Mdot
.10983 .07062 Mdot
.09807 .05886 Mdot
.08631 .04709 Mdot
.07454 .04317 Mdot
.07062 .03925 Mdot
.07062 .03925 Mdot
.06278 .03141 Mdot
.07454 .04317 Mdot
.08631 .06278 Mdot
.07846 .05886 Mdot
.12552 .09415 Mdot
.15297 .10591 Mdot
.18042 .11376 Mdot
.18826 .10199 Mdot
.11376 .03533 Mdot
.21571 .1216 Mdot
.10591 .07062 Mdot
.1961 .16865 Mdot
.14513 .1412 Mdot
.20002 .16865 Mdot
.22747 .18434 Mdot
.9333 .90585 Mdot
.749 .72547 Mdot
.52549 .47451 Mdot
.42746 .39217 Mdot
.27845 .27453 Mdot
.28237 .27061 Mdot
.21571 .21963 Mdot
.19218 .1961 Mdot
.18434 .18434 Mdot
.1765 .1765 Mdot
.16865 .1765 Mdot
.18042 .18042 Mdot
.16865 .16473 Mdot
.16865 .15297 Mdot
.18826 .16473 Mdot
.1765 .14905 Mdot
.15689 .13336 Mdot
.14905 .12552 Mdot
.14513 .1216 Mdot
.14905 .1216 Mdot
.14513 .11768 Mdot
.14905 .12552 Mdot
.16473 .13728 Mdot
.18434 .14905 Mdot
.17257 .1412 Mdot
.18826 .14905 Mdot
.27061 .19218 Mdot
.18042 .1216 Mdot
.13336 .09023 Mdot
.09023 .07062 Mdot
.07062 .05886 Mdot
.07062 .05102 Mdot
.07454 .05102 Mdot
.09023 .06278 Mdot
.11768 .08631 Mdot
.1216 .09415 Mdot
.12552 .08631 Mdot
.11768 .07062 Mdot
.12552 .07846 Mdot
.1412 .08631 Mdot
.1216 .07062 Mdot
.11376 .0667 Mdot
.08631 .05494 Mdot
.07454 .05494 Mdot
.08239 .05886 Mdot
.07062 .04317 Mdot
.04317 .01572 Mdot
.05102 .02357 Mdot
.04709 .02357 Mdot
.05102 .01965 Mdot
.05886 .02749 Mdot
.08239 .04317 Mdot
.11768 .07062 Mdot
.09415 .05886 Mdot
.3255 .23139 Mdot
.05102 .04317 Mdot
.44314 .36472 Mdot
.41569 .33335 Mdot
.07062 .06278 Mdot
.1412 .10983 Mdot
.91761 .89409 Mdot
.62744 .58823 Mdot
.50588 .4353 Mdot
.34511 .29021 Mdot
.32158 .26276 Mdot
.28629 .23139 Mdot
.24708 .20787 Mdot
.22355 .20002 Mdot
.22747 .20002 Mdot
.16081 .15689 Mdot
.16473 .15297 Mdot
.15689 .14513 Mdot
.15297 .1412 Mdot
.13728 .12552 Mdot
.14513 .12944 Mdot
.17257 .1412 Mdot
.16865 .13336 Mdot
.14905 .10983 Mdot
.14905 .10983 Mdot
.16473 .1216 Mdot
.16081 .1216 Mdot
.16865 .11768 Mdot
.18042 .11376 Mdot
.18434 .11376 Mdot
.18042 .11376 Mdot
.14513 .08631 Mdot
.1216 .07062 Mdot
.10983 .06278 Mdot
.09807 .05494 Mdot
.09415 .05494 Mdot
.10983 .0667 Mdot
.10983 .06278 Mdot
.1216 .07846 Mdot
.12944 .08631 Mdot
.1216 .07846 Mdot
.12944 .09415 Mdot
.1412 .09807 Mdot
.13728 .09415 Mdot
.13728 .09415 Mdot
.10591 .0667 Mdot
.07454 .05102 Mdot
.08239 .05886 Mdot
.07062 .04709 Mdot
.05494 .02357 Mdot
.04709 .01572 Mdot
.03925 .01965 Mdot
.03141 .01572 Mdot
.03141 .02749 Mdot
.02749 .01965 Mdot
.03925 .01965 Mdot
.04317 .0118 Mdot
.06278 .01572 Mdot
.10199 .04317 Mdot
.12552 .05886 Mdot
.16081 .08239 Mdot
.15297 .07846 Mdot
.10983 .05494 Mdot
.78429 .73724 Mdot
.60391 .55294 Mdot
.41961 .3608 Mdot
.33335 .28629 Mdot
.30982 .25884 Mdot
.28237 .23924 Mdot
.25884 .21571 Mdot
.22355 .18434 Mdot
.1961 .16473 Mdot
.15689 .13728 Mdot
.13336 .11768 Mdot
.13728 .1216 Mdot
.13728 .12552 Mdot
.15297 .12944 Mdot
.15689 .11768 Mdot
.1412 .09807 Mdot
.1216 .08239 Mdot
.1216 .07846 Mdot
.16081 .10591 Mdot
.12944 .07062 Mdot
.13336 .0667 Mdot
.15297 .07846 Mdot
.14513 .08239 Mdot
.1412 .08631 Mdot
.13728 .09023 Mdot
.13336 .09023 Mdot
.12552 .09023 Mdot
.11768 .08239 Mdot
.09807 .0667 Mdot
.10983 .07846 Mdot
.1216 .08239 Mdot
.13728 .09023 Mdot
.14905 .09807 Mdot
.14905 .09807 Mdot
.14905 .09415 Mdot
.14513 .09415 Mdot
.13336 .08239 Mdot
.1216 .06278 Mdot
.10199 .05102 Mdot
.08239 .03925 Mdot
.07454 .02749 Mdot
.06278 .01965 Mdot
.06278 .02749 Mdot
.05102 .01965 Mdot
.03925 .01965 Mdot
.03141 .01572 Mdot
.03533 .01572 Mdot
.03925 .0118 Mdot
.03925 .00396 Mdot
.05886 .00788 Mdot
.07846 .02357 Mdot
.10591 .03925 Mdot
.07454 .01965 Mdot
.05102 .0118 Mdot
.74508 .71371 Mdot
.42746 .37648 Mdot
.36472 .3059 Mdot
.32943 .26668 Mdot
.29413 .24316 Mdot
.24708 .21571 Mdot
.21571 .1961 Mdot
.20787 .18434 Mdot
.19218 .17257 Mdot
.17257 .16473 Mdot
.15689 .15297 Mdot
.14905 .14513 Mdot
.13728 .12944 Mdot
.12944 .11376 Mdot
.11768 .09415 Mdot
.13728 .10199 Mdot
.12552 .09023 Mdot
.12552 .07846 Mdot
.14905 .09807 Mdot
.16473 .11376 Mdot
.15689 .10983 Mdot
.15297 .11376 Mdot
.15297 .11376 Mdot
.16081 .1216 Mdot
.14905 .10591 Mdot
.13728 .09023 Mdot
.15297 .09023 Mdot
.16865 .09023 Mdot
.17257 .09415 Mdot
.18826 .10199 Mdot
.16865 .08239 Mdot
.17257 .08239 Mdot
.16081 .08239 Mdot
.15297 .09023 Mdot
.13728 .07846 Mdot
.13728 .07454 Mdot
.13336 .06278 Mdot
.10983 .05102 Mdot
.10983 .05102 Mdot
.08631 .04317 Mdot
.07454 .03533 Mdot
.08631 .04709 Mdot
.07062 .04709 Mdot
.05886 .03533 Mdot
.05886 .03141 Mdot
.0667 .02749 Mdot
.06278 .02357 Mdot
.06278 .02749 Mdot
.08239 .03925 Mdot
.0667 .03533 Mdot
.03925 .01965 Mdot
.87448 .86272 Mdot
.72939 .70587 Mdot
.40393 .38824 Mdot
.3059 .29806 Mdot
.28629 .27061 Mdot
.26668 .23531 Mdot
.23531 .20002 Mdot
.19218 .17257 Mdot
.16081 .16081 Mdot
.13728 .15297 Mdot
.12552 .13728 Mdot
.11376 .12552 Mdot
.12944 .12944 Mdot
.12944 .11376 Mdot
.10199 .09023 Mdot
.08239 .07062 Mdot
.08631 .07062 Mdot
.09415 .07454 Mdot
.10591 .08239 Mdot
.10591 .07454 Mdot
.10983 .07846 Mdot
.11768 .08239 Mdot
.1216 .07846 Mdot
.13336 .08631 Mdot
.12552 .06278 Mdot
.11768 .05102 Mdot
.12944 .05886 Mdot
.1412 .06278 Mdot
.13728 .05886 Mdot
.13336 .05886 Mdot
.1216 .05102 Mdot
.12552 .05494 Mdot
.12552 .05886 Mdot
.11768 .04709 Mdot
.11768 .04317 Mdot
.12944 .05494 Mdot
.1216 .05494 Mdot
.10591 .05886 Mdot
.08631 .05102 Mdot
.08631 .05102 Mdot
.07062 .04317 Mdot
.06278 .04317 Mdot
.05494 .04709 Mdot
.05886 .04709 Mdot
.0667 .04709 Mdot
.06278 .04317 Mdot
.05886 .04709 Mdot
.05494 .04709 Mdot
.03925 .03141 Mdot
.88232 .87056 Mdot
.61176 .56862 Mdot
.47451 .39217 Mdot
.23531 .20394 Mdot
.22355 .21179 Mdot
.17257 .18826 Mdot
.1216 .15689 Mdot
.10591 .14513 Mdot
.10591 .1412 Mdot
.12552 .14513 Mdot
.12552 .14513 Mdot
.11768 .13336 Mdot
.08239 .09807 Mdot
.0667 .08239 Mdot
.0667 .07454 Mdot
.05886 .05494 Mdot
.05102 .03141 Mdot
.07846 .04709 Mdot
.08239 .04317 Mdot
.07454 .03533 Mdot
.08239 .04317 Mdot
.07846 .02749 Mdot
.10199 .03533 Mdot
.10591 .03141 Mdot
.11768 .03533 Mdot
.10199 .01965 Mdot
.09807 .00788 Mdot
.11768 .01965 Mdot
.12552 .03141 Mdot
.10199 .02749 Mdot
.08631 .01965 Mdot
.07454 .0118 Mdot
.08239 .02749 Mdot
.07846 .03533 Mdot
.07846 .03925 Mdot
.07062 .05102 Mdot
.07846 .06278 Mdot
.05886 .05102 Mdot
.04709 .04317 Mdot
.03141 .02749 Mdot
.05102 .03925 Mdot
.0667 .05102 Mdot
.05494 .05102 Mdot
.05886 .05102 Mdot
.06278 .04709 Mdot
.04317 .03533 Mdot
.69018 .68234 Mdot
.42746 .45491 Mdot
.25884 .3059 Mdot
.15297 .21963 Mdot
.12552 .18826 Mdot
.10591 .16081 Mdot
.10199 .1412 Mdot
.09023 .12552 Mdot
.07846 .11376 Mdot
.07846 .10983 Mdot
.08239 .10199 Mdot
.07454 .08239 Mdot
.07454 .0667 Mdot
.08239 .06278 Mdot
.08631 .05886 Mdot
.08239 .05494 Mdot
.07454 .04709 Mdot
.06278 .03533 Mdot
.05102 .02357 Mdot
.10199 .05102 Mdot
.12944 .05102 Mdot
.11376 .03141 Mdot
.11376 .02357 Mdot
.11376 .0118 Mdot
.1216 .01965 Mdot
.1216 .02749 Mdot
.09415 .01965 Mdot
.09023 .02357 Mdot
.07454 .02357 Mdot
.08239 .02749 Mdot
.05886 .02749 Mdot
.06278 .03925 Mdot
.07454 .05102 Mdot
.07846 .05886 Mdot
.07062 .04709 Mdot
.05886 .03925 Mdot
.05494 .03141 Mdot
.05494 .03141 Mdot
.08239 .05886 Mdot
.05494 .05102 Mdot
.05494 .05102 Mdot
.06278 .05886 Mdot
.05886 .04709 Mdot
.55686 .60783 Mdot
.19218 .24316 Mdot
.19218 .21571 Mdot
.1412 .15689 Mdot
.10199 .1216 Mdot
.09023 .10591 Mdot
.09807 .10199 Mdot
.09023 .09415 Mdot
.09807 .10199 Mdot
.09807 .09807 Mdot
.09807 .09023 Mdot
.07846 .07454 Mdot
.09415 .08631 Mdot
.06278 .06278 Mdot
.05102 .05102 Mdot
.05102 .04709 Mdot
.0667 .04709 Mdot
.09807 .05102 Mdot
.10591 .04709 Mdot
.11768 .05102 Mdot
.10591 .03533 Mdot
.09807 .02357 Mdot
.10199 .02749 Mdot
.11768 .03925 Mdot
.10591 .03925 Mdot
.10983 .05494 Mdot
.10199 .05886 Mdot
.08631 .04317 Mdot
.07846 .04709 Mdot
.07454 .04317 Mdot
.07454 .04709 Mdot
.08239 .04709 Mdot
.07062 .03141 Mdot
.0667 .03141 Mdot
.06278 .02749 Mdot
.07062 .04317 Mdot
.07454 .05494 Mdot
.07454 .0667 Mdot
.07454 .0667 Mdot
.07062 .05886 Mdot
.8039 .8039 Mdot
.58823 .58823 Mdot
.15297 .15689 Mdot
.12552 .13336 Mdot
.10591 .11768 Mdot
.09023 .09807 Mdot
.08631 .09415 Mdot
.09415 .09415 Mdot
.09415 .09415 Mdot
.07846 .09023 Mdot
.06278 .07846 Mdot
.07062 .08239 Mdot
.06278 .07062 Mdot
.03925 .04709 Mdot
.07454 .0667 Mdot
.10983 .09023 Mdot
.11768 .08239 Mdot
.10983 .0667 Mdot
.11768 .0667 Mdot
.10983 .05494 Mdot
.11768 .05102 Mdot
.10983 .04317 Mdot
.10591 .05102 Mdot
.10591 .05494 Mdot
.10199 .05886 Mdot
.09807 .05102 Mdot
.08631 .05102 Mdot
.07846 .05102 Mdot
.07454 .05494 Mdot
.08631 .05494 Mdot
.09023 .04709 Mdot
.07454 .02357 Mdot
.05102 .0118 Mdot
.04709 .01572 Mdot
.05886 .03141 Mdot
.05102 .03141 Mdot
.05102 .03141 Mdot
.05494 .03141 Mdot
.57254 .57646 Mdot
.34511 .34511 Mdot
.10983 .10983 Mdot
.11376 .11768 Mdot
.10591 .10983 Mdot
.09415 .09415 Mdot
.07846 .08239 Mdot
.07062 .07846 Mdot
.07846 .09023 Mdot
.07846 .07846 Mdot
.05886 .05494 Mdot
.05886 .04317 Mdot
.08631 .05102 Mdot
.10983 .06278 Mdot
.12944 .07454 Mdot
.1412 .07846 Mdot
.14513 .07454 Mdot
.13728 .0667 Mdot
.11768 .05494 Mdot
.10591 .05886 Mdot
.10591 .05886 Mdot
.10591 .05886 Mdot
.09807 .05494 Mdot
.08239 .05102 Mdot
.0667 .03925 Mdot
.07846 .05494 Mdot
.08631 .06278 Mdot
.08631 .04317 Mdot
.07846 .03533 Mdot
.07454 .02749 Mdot
.0667 .02357 Mdot
.06278 .01572 Mdot
.05494 .0118 Mdot
.07846 .03141 Mdot
.07846 .03141 Mdot
.56862 .57646 Mdot
.33335 .3608 Mdot
.09807 .13336 Mdot
.11376 .14513 Mdot
.1216 .14905 Mdot
.09807 .12944 Mdot
.08239 .10199 Mdot
.07062 .0667 Mdot
.05494 .04709 Mdot
.0667 .05102 Mdot
.08631 .05886 Mdot
.11376 .07846 Mdot
.12944 .08631 Mdot
.1412 .09023 Mdot
.12944 .08239 Mdot
.10983 .07062 Mdot
.10983 .07454 Mdot
.10591 .07846 Mdot
.08239 .06278 Mdot
.07062 .05102 Mdot
.07846 .05494 Mdot
.08239 .05886 Mdot
.09415 .0667 Mdot
.08631 .05886 Mdot
.07454 .03925 Mdot
.07062 .03533 Mdot
.0667 .03533 Mdot
.07062 .03925 Mdot
.07454 .03533 Mdot
.07846 .03533 Mdot
.05886 .01965 Mdot
.03533 .00788 Mdot
.77253 .78429 Mdot
.63528 .63528 Mdot
.16473 .18826 Mdot
.12944 .16081 Mdot
.11376 .13728 Mdot
.09023 .09807 Mdot
.07062 .0667 Mdot
.07062 .05886 Mdot
.08239 .06278 Mdot
.09807 .07454 Mdot
.1216 .10199 Mdot
.13728 .11376 Mdot
.11768 .09415 Mdot
.09807 .07454 Mdot
.10199 .07454 Mdot
.11376 .09415 Mdot
.09023 .07846 Mdot
.09023 .07454 Mdot
.09023 .07062 Mdot
.10199 .0667 Mdot
.09807 .0667 Mdot
.10199 .07454 Mdot
.08239 .05886 Mdot
.0667 .04709 Mdot
.07062 .05102 Mdot
.07454 .05886 Mdot
.08631 .06278 Mdot
.0667 .04317 Mdot
.04317 .01965 Mdot
.02749 .00788 Mdot
.78429 .78821 Mdot
.5647 .57254 Mdot
.12944 .10983 Mdot
.15297 .10983 Mdot
.1216 .08239 Mdot
.10591 .07062 Mdot
.09415 .06278 Mdot
.10591 .08239 Mdot
.10983 .09415 Mdot
.10983 .09415 Mdot
.10591 .09415 Mdot
.12552 .11376 Mdot
.12552 .11376 Mdot
.11768 .10591 Mdot
.10983 .09415 Mdot
.10983 .09023 Mdot
.08631 .0667 Mdot
.10983 .07846 Mdot
.10591 .07846 Mdot
.09415 .07454 Mdot
.07454 .0667 Mdot
.05886 .05494 Mdot
.07846 .07454 Mdot
.09023 .07846 Mdot
.0667 .05494 Mdot
.03925 .02749 Mdot
.0118 .00788 Mdot
.60391 .56862 Mdot
.35687 .31374 Mdot
.13728 .08239 Mdot
.12944 .08239 Mdot
.10591 .08631 Mdot
.09415 .08631 Mdot
.10199 .09023 Mdot
.11768 .10591 Mdot
.12552 .10983 Mdot
.13336 .11768 Mdot
.12552 .11376 Mdot
.12552 .10983 Mdot
.1216 .10591 Mdot
.10591 .09023 Mdot
.11768 .09023 Mdot
.1216 .09023 Mdot
.09807 .07454 Mdot
.09415 .07062 Mdot
.07846 .06278 Mdot
.05886 .05102 Mdot
.05886 .04709 Mdot
.04709 .03533 Mdot
.02749 .01965 Mdot
.0118 .00396 Mdot
.57646 .56078 Mdot
.34511 .34119 Mdot
.08631 .10199 Mdot
.09807 .10591 Mdot
.12552 .11376 Mdot
.1412 .11768 Mdot
.15297 .11768 Mdot
.14513 .11768 Mdot
.1412 .11376 Mdot
.1216 .09807 Mdot
.11376 .09415 Mdot
.11768 .09415 Mdot
.1216 .09023 Mdot
.1216 .08631 Mdot
.09415 .07062 Mdot
.06278 .04709 Mdot
.03925 .03141 Mdot
.03925 .03141 Mdot
.02357 .01572 Mdot
.0118 .00788 Mdot
.0118 .00396 Mdot
.76861 .77645 Mdot
.53333 .54902 Mdot
.07454 .09023 Mdot
.07846 .07454 Mdot
.10199 .08239 Mdot
.10983 .08631 Mdot
.09023 .07846 Mdot
.09807 .08239 Mdot
.09023 .07846 Mdot
.09807 .07846 Mdot
.09023 .06278 Mdot
.08631 .04709 Mdot
.06278 .03141 Mdot
.02749 .01572 Mdot
.03925 .03141 Mdot
.05102 .03925 Mdot
.02749 .02357 Mdot
.01965 .01572 Mdot
.01965 .0118 Mdot
.76469 .76861 Mdot
.52941 .53333 Mdot
.07846 .07454 Mdot
.09023 .08631 Mdot
.08239 .07454 Mdot
.07846 .05886 Mdot
.08631 .05102 Mdot
.09023 .05102 Mdot
.07454 .04317 Mdot
.04709 .02749 Mdot
.03925 .01965 Mdot
.04317 .02357 Mdot
.05494 .03141 Mdot
.03925 .01965 Mdot
.02749 .0118 Mdot
.02749 .01572 Mdot
.58431 .57646 Mdot
.34511 .33727 Mdot
.11768 .10591 Mdot
.08631 .06278 Mdot
.07846 .05494 Mdot
.07846 .07454 Mdot
.07062 .07062 Mdot
.05494 .05886 Mdot
.05886 .05494 Mdot
.0667 .05102 Mdot
.0667 .03925 Mdot
.02749 .0118 Mdot
.02357 .00396 Mdot
.55686 .55686 Mdot
.33335 .33727 Mdot
.13728 .13728 Mdot
.10591 .11768 Mdot
.08631 .10983 Mdot
.06278 .08631 Mdot
.05102 .05886 Mdot
.04317 .03925 Mdot
.03533 .01572 Mdot
.02357 .00788 Mdot
.76076 .77253 Mdot
.54117 .55686 Mdot
.06278 .09415 Mdot
.03141 .0667 Mdot
.01572 .04317 Mdot
.0118 .01965 Mdot
.0118 .00788 Mdot
.01572 .0118 Mdot
.76469 .77645 Mdot
.51765 .53725 Mdot
.02749 .04317 Mdot
.01965 .02357 Mdot
.0118 .0118 Mdot
.51372 .51765 Mdot
.25492 .26668 Mdot
0 0 1 r
.8588 .84703 Mdot
.5098 .47451 Mdot
.48628 .44314 Mdot
.73724 .72155 Mdot
.56862 .53725 Mdot
.58823 .5647 Mdot
.59607 .5647 Mdot
.57254 .54902 Mdot
.68626 .67057 Mdot
.78429 .77645 Mdot
.58823 .54902 Mdot
.59607 .57646 Mdot
.61176 .60391 Mdot
.60783 .61568 Mdot
.59999 .61568 Mdot
.58823 .60391 Mdot
.59215 .59607 Mdot
.70194 .70194 Mdot
.89801 .90193 Mdot
.59215 .56078 Mdot
.61176 .59215 Mdot
.61568 .61568 Mdot
.61568 .62744 Mdot
.61568 .6392 Mdot
.61176 .64313 Mdot
.59999 .6196 Mdot
.60783 .6196 Mdot
.61176 .6196 Mdot
.6196 .6196 Mdot
.81566 .81566 Mdot
.91369 .90977 Mdot
.58039 .55294 Mdot
.6196 .60391 Mdot
.6196 .61568 Mdot
.62744 .63136 Mdot
.63528 .64705 Mdot
.62744 .64705 Mdot
.62744 .62744 Mdot
.62744 .6196 Mdot
.62352 .61568 Mdot
.63136 .62352 Mdot
.6392 .62352 Mdot
.64313 .61568 Mdot
.65097 .60783 Mdot
.83135 .79998 Mdot
.61176 .57254 Mdot
.63136 .60783 Mdot
.6392 .62352 Mdot
.6392 .63136 Mdot
.63528 .62744 Mdot
.63528 .62744 Mdot
.63528 .62352 Mdot
.63528 .61568 Mdot
.62744 .60783 Mdot
.63136 .61176 Mdot
.63528 .60391 Mdot
.64313 .60783 Mdot
.65489 .60783 Mdot
.65489 .60783 Mdot
.67057 .61568 Mdot
.749 .70194 Mdot
.83527 .8039 Mdot
.59215 .56078 Mdot
.63136 .59607 Mdot
.6392 .60391 Mdot
.63136 .60783 Mdot
.63136 .60783 Mdot
.63528 .60783 Mdot
.62352 .59607 Mdot
.61568 .58431 Mdot
.63136 .59607 Mdot
.64705 .61176 Mdot
.65097 .61568 Mdot
.65489 .62352 Mdot
.65489 .61568 Mdot
.65097 .61176 Mdot
.65489 .61568 Mdot
.65097 .61176 Mdot
.66273 .6196 Mdot
.63528 .59215 Mdot
.80782 .79213 Mdot
.89801 .88624 Mdot
.60783 .57646 Mdot
.62352 .59607 Mdot
.62744 .59999 Mdot
.62744 .60391 Mdot
.62352 .59215 Mdot
.63136 .59215 Mdot
.62744 .59215 Mdot
.63136 .59999 Mdot
.63136 .60391 Mdot
.63528 .61568 Mdot
.64313 .61568 Mdot
.64705 .61568 Mdot
.65489 .6196 Mdot
.65489 .6196 Mdot
.65097 .62352 Mdot
.66273 .63136 Mdot
.65881 .62352 Mdot
.65489 .6196 Mdot
.64705 .60783 Mdot
.65097 .60391 Mdot
.52157 .49804 Mdot
.749 .73724 Mdot
.82743 .83135 Mdot
.58039 .55294 Mdot
.6196 .58823 Mdot
.63528 .60783 Mdot
.63528 .61176 Mdot
.62352 .61176 Mdot
.61176 .59999 Mdot
.6196 .60783 Mdot
.62744 .6196 Mdot
.63136 .62352 Mdot
.63136 .62744 Mdot
.64313 .62744 Mdot
.6392 .61568 Mdot
.64705 .6196 Mdot
.65489 .62352 Mdot
.64313 .6196 Mdot
.66273 .63528 Mdot
.65097 .62744 Mdot
.66273 .63136 Mdot
.65881 .6196 Mdot
.65489 .6196 Mdot
.67057 .62744 Mdot
.63136 .58431 Mdot
.50588 .46667 Mdot
.54117 .52549 Mdot
.68626 .66665 Mdot
.58039 .53725 Mdot
.62744 .59607 Mdot
.64313 .61568 Mdot
.6196 .61568 Mdot
.62352 .6196 Mdot
.61568 .62744 Mdot
.61568 .62744 Mdot
.62352 .62744 Mdot
.63136 .62744 Mdot
.63528 .63136 Mdot
.6392 .6392 Mdot
.65097 .64313 Mdot
.65489 .64313 Mdot
.65881 .6392 Mdot
.66273 .63136 Mdot
.66665 .62744 Mdot
.65881 .62744 Mdot
.65881 .63136 Mdot
.6745 .64313 Mdot
.6745 .6392 Mdot
.6745 .63528 Mdot
.67057 .63136 Mdot
.66665 .6196 Mdot
.63136 .58431 Mdot
.5647 .51765 Mdot
.48235 .42354 Mdot
.50588 .47843 Mdot
.64705 .63528 Mdot
.60783 .56862 Mdot
.6392 .61568 Mdot
.64705 .6392 Mdot
.64313 .64313 Mdot
.63528 .65097 Mdot
.63136 .64705 Mdot
.62352 .63136 Mdot
.6196 .62744 Mdot
.62744 .62744 Mdot
.63528 .63528 Mdot
.65097 .64313 Mdot
.65097 .64313 Mdot
.65097 .6392 Mdot
.65489 .6392 Mdot
.66273 .63136 Mdot
.66665 .62744 Mdot
.67057 .63136 Mdot
.6745 .6392 Mdot
.66665 .65097 Mdot
.68234 .65489 Mdot
.67842 .65489 Mdot
.6745 .64313 Mdot
.67842 .64313 Mdot
.68234 .64705 Mdot
.67842 .6392 Mdot
.66665 .61568 Mdot
.62744 .5647 Mdot
.43922 .40785 Mdot
.40393 .37648 Mdot
.75292 .72939 Mdot
.81958 .8235 Mdot
.6196 .58823 Mdot
.64313 .6196 Mdot
.64705 .64313 Mdot
.64313 .65097 Mdot
.6392 .65489 Mdot
.63528 .65489 Mdot
.62744 .65097 Mdot
.62352 .6392 Mdot
.63136 .63528 Mdot
.6392 .6392 Mdot
.64705 .64313 Mdot
.65097 .6392 Mdot
.65881 .63528 Mdot
.66665 .63528 Mdot
.66665 .63528 Mdot
.65489 .62744 Mdot
.66665 .6392 Mdot
.6745 .65097 Mdot
.67842 .66665 Mdot
.68234 .67057 Mdot
.67842 .66665 Mdot
.68626 .6745 Mdot
.67842 .66665 Mdot
.67842 .66665 Mdot
.68626 .66665 Mdot
.68626 .65489 Mdot
.6941 .65097 Mdot
.6745 .62352 Mdot
.59215 .55686 Mdot
.52941 .50196 Mdot
.39609 .40785 Mdot
.34119 .36864 Mdot
.77645 .76076 Mdot
.89017 .8784 Mdot
.60391 .57646 Mdot
.63136 .60783 Mdot
.63528 .6196 Mdot
.63136 .62744 Mdot
.6196 .62744 Mdot
.62352 .6392 Mdot
.63136 .64705 Mdot
.62744 .6392 Mdot
.63136 .6392 Mdot
.6392 .63528 Mdot
.65097 .64705 Mdot
.66273 .65489 Mdot
.66665 .64705 Mdot
.6745 .64705 Mdot
.6745 .6392 Mdot
.66273 .64705 Mdot
.67057 .66273 Mdot
.66665 .66273 Mdot
.67057 .65881 Mdot
.6745 .67057 Mdot
.67842 .67057 Mdot
.68234 .67057 Mdot
.68234 .6745 Mdot
.69018 .67842 Mdot
.70194 .68234 Mdot
.70587 .67842 Mdot
.69018 .65489 Mdot
.70194 .65097 Mdot
.54509 .51372 Mdot
.41961 .41569 Mdot
.4353 .43138 Mdot
.48235 .47451 Mdot
.65881 .60783 Mdot
.6392 .59215 Mdot
.74116 .70587 Mdot
.84703 .81958 Mdot
.59607 .58431 Mdot
.62352 .62352 Mdot
.63528 .64705 Mdot
.62352 .64705 Mdot
.61568 .63528 Mdot
.61568 .63136 Mdot
.62744 .63528 Mdot
.63136 .63136 Mdot
.63136 .62744 Mdot
.64313 .64313 Mdot
.64313 .65489 Mdot
.64705 .66665 Mdot
.66273 .6745 Mdot
.65881 .66273 Mdot
.66273 .65097 Mdot
.67057 .65881 Mdot
.68234 .67842 Mdot
.6745 .67842 Mdot
.6745 .6745 Mdot
.67842 .6745 Mdot
.67842 .67057 Mdot
.67842 .66665 Mdot
.6941 .68626 Mdot
.69802 .69018 Mdot
.69802 .67842 Mdot
.6941 .67057 Mdot
.6941 .67057 Mdot
.70979 .6745 Mdot
.59999 .57254 Mdot
.42746 .4353 Mdot
.42746 .43138 Mdot
.61568 .58039 Mdot
.66665 .62744 Mdot
.6745 .6392 Mdot
.70194 .65489 Mdot
.70979 .66273 Mdot
.71371 .67057 Mdot
.76076 .73724 Mdot
.81958 .81566 Mdot
.59999 .59999 Mdot
.62352 .64705 Mdot
.63136 .66665 Mdot
.6196 .65881 Mdot
.6196 .65489 Mdot
.62744 .65881 Mdot
.63528 .65489 Mdot
.63136 .6392 Mdot
.6392 .64313 Mdot
.6392 .65097 Mdot
.6392 .65881 Mdot
.64705 .66273 Mdot
.65097 .66273 Mdot
.65881 .66273 Mdot
.65489 .65881 Mdot
.65881 .66273 Mdot
.6745 .68234 Mdot
.67057 .68626 Mdot
.6745 .67842 Mdot
.68626 .67842 Mdot
.69018 .6745 Mdot
.67842 .6745 Mdot
.68234 .68626 Mdot
.69018 .69018 Mdot
.70194 .69802 Mdot
.70587 .69802 Mdot
.70979 .68626 Mdot
.70979 .68626 Mdot
.6745 .65881 Mdot
.6392 .62744 Mdot
.60783 .59215 Mdot
.65097 .6196 Mdot
.69802 .65489 Mdot
.69802 .66665 Mdot
.70979 .68234 Mdot
.71371 .68626 Mdot
.70979 .69018 Mdot
.70979 .69018 Mdot
.69802 .67842 Mdot
.70194 .6745 Mdot
.85487 .83527 Mdot
.9333 .92154 Mdot
.58823 .59215 Mdot
.60783 .63528 Mdot
.62744 .66665 Mdot
.62352 .67057 Mdot
.61568 .66273 Mdot
.61176 .65097 Mdot
.61568 .65097 Mdot
.62352 .64313 Mdot
.63528 .65489 Mdot
.6392 .65881 Mdot
.63136 .65097 Mdot
.65097 .65881 Mdot
.65881 .66273 Mdot
.65489 .65881 Mdot
.65489 .66273 Mdot
.65881 .66273 Mdot
.68234 .68626 Mdot
.69018 .6941 Mdot
.68234 .67842 Mdot
.67842 .68234 Mdot
.68234 .67842 Mdot
.68234 .67842 Mdot
.68234 .6745 Mdot
.68626 .68234 Mdot
.6941 .68626 Mdot
.70194 .68626 Mdot
.69802 .6745 Mdot
.70979 .68234 Mdot
.70979 .67842 Mdot
.70194 .66665 Mdot
.68626 .65489 Mdot
.69802 .66273 Mdot
.70979 .67057 Mdot
.70587 .67842 Mdot
.70979 .69018 Mdot
.72155 .70587 Mdot
.71763 .70194 Mdot
.72939 .71371 Mdot
.72155 .70194 Mdot
.72547 .69802 Mdot
.70587 .6745 Mdot
.72547 .67057 Mdot
.72547 .64313 Mdot
.8588 .81958 Mdot
.92546 .90585 Mdot
.59607 .59999 Mdot
.6196 .62744 Mdot
.62744 .64705 Mdot
.62352 .65881 Mdot
.61568 .65881 Mdot
.61176 .64313 Mdot
.61568 .6392 Mdot
.61176 .6392 Mdot
.62352 .64705 Mdot
.63528 .65489 Mdot
.6392 .65489 Mdot
.64313 .64705 Mdot
.64705 .65097 Mdot
.65097 .66273 Mdot
.65489 .66665 Mdot
.65489 .66273 Mdot
.67057 .67057 Mdot
.6745 .6745 Mdot
.68626 .68234 Mdot
.67842 .68234 Mdot
.69018 .69018 Mdot
.67842 .68234 Mdot
.69018 .69018 Mdot
.6941 .70194 Mdot
.6941 .70979 Mdot
.69802 .70587 Mdot
.6941 .6941 Mdot
.70979 .69802 Mdot
.70979 .69018 Mdot
.70194 .68234 Mdot
.70587 .68234 Mdot
.70194 .67842 Mdot
.70194 .68234 Mdot
.70979 .68234 Mdot
.71763 .6941 Mdot
.72155 .70194 Mdot
.71763 .70587 Mdot
.72939 .71371 Mdot
.73332 .70979 Mdot
.73724 .70979 Mdot
.72939 .69018 Mdot
.72939 .6745 Mdot
.74508 .67057 Mdot
.74116 .66665 Mdot
.72547 .65881 Mdot
.79998 .749 Mdot
.87448 .83919 Mdot
.58823 .59215 Mdot
.62352 .63528 Mdot
.63528 .65881 Mdot
.63136 .66273 Mdot
.61568 .65097 Mdot
.61568 .64705 Mdot
.61568 .64705 Mdot
.62352 .65881 Mdot
.62352 .66273 Mdot
.62352 .65881 Mdot
.63528 .66273 Mdot
.64705 .67057 Mdot
.64313 .66665 Mdot
.65097 .67842 Mdot
.65489 .67842 Mdot
.65489 .6745 Mdot
.65097 .67057 Mdot
.65489 .6745 Mdot
.67057 .68626 Mdot
.67057 .6941 Mdot
.67842 .69802 Mdot
.67842 .70587 Mdot
.68626 .70979 Mdot
.70194 .72155 Mdot
.6941 .71763 Mdot
.69018 .70979 Mdot
.69018 .70979 Mdot
.6941 .70587 Mdot
.70587 .71371 Mdot
.69802 .70194 Mdot
.70979 .70979 Mdot
.71763 .71371 Mdot
.71371 .70587 Mdot
.70979 .69018 Mdot
.71371 .69018 Mdot
.72547 .70979 Mdot
.73332 .72155 Mdot
.73332 .72155 Mdot
.73332 .71371 Mdot
.73332 .70587 Mdot
.73724 .6941 Mdot
.73724 .67842 Mdot
.749 .67842 Mdot
.749 .67842 Mdot
.749 .68234 Mdot
.749 .68626 Mdot
.74116 .68626 Mdot
.74116 .6941 Mdot
.79213 .76076 Mdot
.87448 .84703 Mdot
.58823 .59999 Mdot
.6196 .6392 Mdot
.63528 .66273 Mdot
.62352 .66273 Mdot
.6196 .65489 Mdot
.6196 .65097 Mdot
.61176 .64313 Mdot
.62744 .65097 Mdot
.63136 .66273 Mdot
.6196 .65489 Mdot
.64313 .67057 Mdot
.6392 .67057 Mdot
.65097 .67842 Mdot
.64313 .6745 Mdot
.65097 .67842 Mdot
.64313 .6745 Mdot
.64313 .6745 Mdot
.6392 .6745 Mdot
.64313 .6745 Mdot
.65097 .67842 Mdot
.66273 .69018 Mdot
.66273 .69018 Mdot
.6745 .70194 Mdot
.6941 .71763 Mdot
.69802 .72155 Mdot
.6941 .71371 Mdot
.69018 .70979 Mdot
.69802 .71371 Mdot
.6941 .70979 Mdot
.70194 .70587 Mdot
.70194 .70194 Mdot
.70587 .70194 Mdot
.70979 .69802 Mdot
.72155 .70587 Mdot
.72155 .71371 Mdot
.72155 .71371 Mdot
.72547 .71763 Mdot
.72939 .72155 Mdot
.72939 .71763 Mdot
.74116 .70979 Mdot
.74116 .70194 Mdot
.74116 .68626 Mdot
.749 .69018 Mdot
.75292 .69018 Mdot
.749 .68234 Mdot
.749 .68234 Mdot
.74508 .68234 Mdot
.75292 .6941 Mdot
.749 .69018 Mdot
.749 .69018 Mdot
.73332 .67842 Mdot
.85095 .81958 Mdot
.91761 .89801 Mdot
.52549 .54902 Mdot
.62352 .63136 Mdot
.61568 .64313 Mdot
.59999 .64313 Mdot
.59215 .6392 Mdot
.60783 .64313 Mdot
.60783 .6392 Mdot
.62352 .65097 Mdot
.62744 .65881 Mdot
.62744 .66273 Mdot
.62352 .65489 Mdot
.63528 .66273 Mdot
.6392 .67057 Mdot
.64313 .67057 Mdot
.64705 .67057 Mdot
.64313 .66665 Mdot
.65097 .67842 Mdot
.65489 .68234 Mdot
.65881 .68626 Mdot
.65489 .68234 Mdot
.65489 .68234 Mdot
.65881 .68626 Mdot
.65881 .68626 Mdot
.66273 .68626 Mdot
.6745 .68626 Mdot
.68626 .68234 Mdot
.68626 .68234 Mdot
.70194 .70194 Mdot
.69802 .70979 Mdot
.6941 .70587 Mdot
.69802 .6941 Mdot
.70194 .68626 Mdot
.70194 .69018 Mdot
.71763 .70587 Mdot
.72155 .71763 Mdot
.70587 .70194 Mdot
.71371 .71371 Mdot
.72155 .71371 Mdot
.72547 .70587 Mdot
.72939 .69802 Mdot
.72547 .69018 Mdot
.749 .69802 Mdot
.749 .69018 Mdot
.74116 .67842 Mdot
.74116 .6745 Mdot
.749 .67842 Mdot
.75292 .67842 Mdot
.74508 .6745 Mdot
.749 .6745 Mdot
.75684 .68626 Mdot
.75292 .69018 Mdot
.74508 .67842 Mdot
.74116 .66665 Mdot
.64313 .56862 Mdot
.75292 .72939 Mdot
.86664 .85487 Mdot
.55686 .5647 Mdot
.59607 .59999 Mdot
.61176 .63136 Mdot
.60783 .64313 Mdot
.59215 .6392 Mdot
.59215 .64313 Mdot
.58823 .6392 Mdot
.60783 .65489 Mdot
.6196 .67057 Mdot
.62352 .6745 Mdot
.62352 .66273 Mdot
.62352 .65881 Mdot
.6392 .67057 Mdot
.63136 .65881 Mdot
.64313 .65881 Mdot
.64313 .65881 Mdot
.65097 .66665 Mdot
.65881 .67057 Mdot
.66273 .66665 Mdot
.66273 .66665 Mdot
.67057 .67057 Mdot
.66665 .6745 Mdot
.65881 .67057 Mdot
.66665 .68234 Mdot
.6745 .68234 Mdot
.69018 .6745 Mdot
.69802 .68234 Mdot
.6941 .67842 Mdot
.70587 .69018 Mdot
.70979 .6941 Mdot
.71371 .6941 Mdot
.71371 .6941 Mdot
.70979 .68626 Mdot
.70587 .68626 Mdot
.71763 .70194 Mdot
.70587 .70194 Mdot
.71371 .71371 Mdot
.71371 .70979 Mdot
.71763 .70194 Mdot
.72547 .70587 Mdot
.73332 .70979 Mdot
.73332 .6941 Mdot
.74508 .6941 Mdot
.749 .6941 Mdot
.74508 .68626 Mdot
.74508 .68234 Mdot
.749 .6745 Mdot
.75292 .6745 Mdot
.74508 .6745 Mdot
.75292 .68626 Mdot
.749 .69018 Mdot
.75292 .68626 Mdot
.75292 .68234 Mdot
.74116 .6745 Mdot
.70587 .6392 Mdot
.69018 .6196 Mdot
.76469 .71763 Mdot
.80782 .78429 Mdot
.58431 .56862 Mdot
.60783 .60391 Mdot
.6196 .63528 Mdot
.60783 .6392 Mdot
.58823 .63528 Mdot
.59215 .63528 Mdot
.60391 .6392 Mdot
.60783 .63528 Mdot
.61176 .6392 Mdot
.61568 .64705 Mdot
.6196 .65097 Mdot
.62352 .65097 Mdot
.63136 .65881 Mdot
.6392 .65881 Mdot
.63528 .64705 Mdot
.64313 .65097 Mdot
.64705 .66273 Mdot
.64705 .65489 Mdot
.64705 .65097 Mdot
.65489 .65489 Mdot
.65489 .65489 Mdot
.65881 .66273 Mdot
.65881 .67057 Mdot
.67057 .6745 Mdot
.66665 .67057 Mdot
.6745 .6745 Mdot
.68234 .68626 Mdot
.68626 .69018 Mdot
.68626 .68626 Mdot
.69802 .68626 Mdot
.69802 .68626 Mdot
.70979 .6941 Mdot
.71371 .6941 Mdot
.70979 .69018 Mdot
.70587 .6941 Mdot
.72155 .70587 Mdot
.70979 .70587 Mdot
.72155 .70587 Mdot
.71371 .69018 Mdot
.72547 .69802 Mdot
.72939 .69802 Mdot
.72547 .68626 Mdot
.73724 .6941 Mdot
.749 .69802 Mdot
.749 .69802 Mdot
.749 .6941 Mdot
.749 .69018 Mdot
.749 .67842 Mdot
.74508 .67842 Mdot
.75684 .68626 Mdot
.76469 .6941 Mdot
.76076 .69018 Mdot
.76076 .68234 Mdot
.75292 .67057 Mdot
.74508 .6745 Mdot
.74116 .6745 Mdot
.74508 .66665 Mdot
.74116 .65881 Mdot
.72155 .63528 Mdot
.78037 .71763 Mdot
.63136 .6392 Mdot
.53333 .52549 Mdot
.60783 .60391 Mdot
.61568 .63136 Mdot
.61176 .6392 Mdot
.60391 .64313 Mdot
.59999 .65097 Mdot
.61176 .65881 Mdot
.61568 .65097 Mdot
.6196 .65097 Mdot
.62352 .64705 Mdot
.62352 .64705 Mdot
.6196 .64705 Mdot
.62352 .65097 Mdot
.63528 .65097 Mdot
.6392 .64705 Mdot
.64705 .65489 Mdot
.64705 .65881 Mdot
.65881 .6745 Mdot
.65489 .65881 Mdot
.66665 .66273 Mdot
.65881 .65097 Mdot
.66273 .65881 Mdot
.67057 .66273 Mdot
.68234 .6745 Mdot
.67842 .68234 Mdot
.68234 .68234 Mdot
.69018 .69802 Mdot
.6941 .69802 Mdot
.68234 .69018 Mdot
.70194 .69802 Mdot
.70194 .69018 Mdot
.70979 .69802 Mdot
.70587 .69018 Mdot
.70979 .69802 Mdot
.70979 .69802 Mdot
.72155 .70979 Mdot
.72547 .70587 Mdot
.71763 .6941 Mdot
.72939 .69802 Mdot
.72547 .69802 Mdot
.72939 .69802 Mdot
.72547 .69018 Mdot
.73724 .69802 Mdot
.74116 .69802 Mdot
.749 .70194 Mdot
.74508 .70194 Mdot
.749 .69018 Mdot
.749 .68626 Mdot
.749 .67842 Mdot
.76076 .68234 Mdot
.75684 .68234 Mdot
.75684 .68234 Mdot
.75292 .68626 Mdot
.75292 .68234 Mdot
.76861 .6941 Mdot
.76076 .68234 Mdot
.76076 .67842 Mdot
.76469 .67842 Mdot
.76861 .6745 Mdot
.79213 .67842 Mdot
.49804 .45098 Mdot
.26276 .26276 Mdot
.65489 .6392 Mdot
.89801 .87056 Mdot
.53333 .52549 Mdot
.58431 .59215 Mdot
.60391 .63136 Mdot
.61568 .65489 Mdot
.60783 .65881 Mdot
.61176 .66665 Mdot
.60391 .66273 Mdot
.61568 .66665 Mdot
.6196 .66665 Mdot
.6196 .65489 Mdot
.63136 .65881 Mdot
.63528 .66273 Mdot
.63136 .66273 Mdot
.6392 .67057 Mdot
.64313 .66665 Mdot
.64313 .65881 Mdot
.65489 .66665 Mdot
.66273 .68234 Mdot
.65489 .67842 Mdot
.66273 .68234 Mdot
.6745 .68626 Mdot
.67057 .68234 Mdot
.67057 .68234 Mdot
.67057 .68234 Mdot
.67842 .68626 Mdot
.68234 .69018 Mdot
.6941 .69802 Mdot
.69802 .69802 Mdot
.69018 .6941 Mdot
.6941 .69802 Mdot
.71371 .70587 Mdot
.70979 .69802 Mdot
.71763 .70587 Mdot
.71371 .71763 Mdot
.71763 .72155 Mdot
.72155 .72547 Mdot
.73332 .72155 Mdot
.73332 .71763 Mdot
.74116 .71371 Mdot
.73724 .71763 Mdot
.73332 .71371 Mdot
.72939 .70979 Mdot
.74508 .71763 Mdot
.749 .71763 Mdot
.74508 .70979 Mdot
.749 .70194 Mdot
.75684 .70194 Mdot
.75684 .69018 Mdot
.75684 .68234 Mdot
.75684 .67842 Mdot
.77253 .6941 Mdot
.76076 .69802 Mdot
.76076 .70587 Mdot
.76469 .71371 Mdot
.76076 .70979 Mdot
.76469 .71371 Mdot
.77253 .70587 Mdot
.77645 .6941 Mdot
.77645 .67842 Mdot
.79213 .6745 Mdot
.76469 .64313 Mdot
.50588 .4353 Mdot
.35295 .33335 Mdot
.73724 .63136 Mdot
.6196 .54902 Mdot
.85095 .80782 Mdot
.92154 .89801 Mdot
.51765 .52157 Mdot
.58431 .60783 Mdot
.59999 .6392 Mdot
.60391 .65097 Mdot
.59215 .64705 Mdot
.59999 .64705 Mdot
.59607 .64705 Mdot
.60391 .64705 Mdot
.61568 .65097 Mdot
.62744 .65881 Mdot
.63136 .65489 Mdot
.62352 .65489 Mdot
.6196 .66273 Mdot
.63528 .67057 Mdot
.64705 .67057 Mdot
.62744 .65097 Mdot
.6392 .65097 Mdot
.65097 .66273 Mdot
.66273 .68234 Mdot
.66665 .6941 Mdot
.66273 .70194 Mdot
.66273 .69802 Mdot
.67057 .69802 Mdot
.67057 .69018 Mdot
.66665 .68626 Mdot
.67842 .6941 Mdot
.67842 .69018 Mdot
.67842 .6941 Mdot
.67842 .69802 Mdot
.69018 .70194 Mdot
.70194 .70587 Mdot
.70587 .70587 Mdot
.70979 .71763 Mdot
.70194 .71763 Mdot
.69802 .71371 Mdot
.70979 .72155 Mdot
.71371 .72939 Mdot
.70979 .72155 Mdot
.72155 .71763 Mdot
.70979 .70587 Mdot
.71371 .70979 Mdot
.72155 .70979 Mdot
.73724 .72547 Mdot
.73724 .72155 Mdot
.749 .72155 Mdot
.74116 .70979 Mdot
.74508 .70979 Mdot
.74508 .69802 Mdot
.749 .70194 Mdot
.749 .69802 Mdot
.75292 .6941 Mdot
.75292 .70587 Mdot
.76076 .72155 Mdot
.76076 .72547 Mdot
.75684 .71763 Mdot
.76076 .70587 Mdot
.76469 .70587 Mdot
.76861 .69802 Mdot
.76861 .6745 Mdot
.76469 .66273 Mdot
.76076 .66665 Mdot
.74508 .66273 Mdot
.70587 .6392 Mdot
.72939 .65489 Mdot
.74116 .67057 Mdot
.749 .66665 Mdot
.74116 .65097 Mdot
.79998 .72939 Mdot
.69018 .68234 Mdot
.53725 .54902 Mdot
.57646 .61568 Mdot
.57646 .63136 Mdot
.57646 .63528 Mdot
.58431 .63528 Mdot
.59607 .6392 Mdot
.59999 .63528 Mdot
.59607 .63136 Mdot
.60783 .64313 Mdot
.61568 .64705 Mdot
.62744 .65881 Mdot
.62352 .65881 Mdot
.62352 .66273 Mdot
.62352 .65489 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.62352 .65097 Mdot
.63528 .66273 Mdot
.65489 .68234 Mdot
.64705 .69018 Mdot
.65097 .69802 Mdot
.65097 .69802 Mdot
.64705 .68626 Mdot
.66273 .6941 Mdot
.67057 .69802 Mdot
.66665 .6941 Mdot
.66665 .69802 Mdot
.67057 .70194 Mdot
.68234 .70587 Mdot
.68234 .70194 Mdot
.68234 .70194 Mdot
.68626 .70587 Mdot
.70587 .72155 Mdot
.70194 .71763 Mdot
.69802 .71763 Mdot
.70194 .72547 Mdot
.70194 .73332 Mdot
.70587 .72547 Mdot
.71763 .72155 Mdot
.71371 .71371 Mdot
.71371 .70587 Mdot
.71371 .70194 Mdot
.72939 .71371 Mdot
.73332 .71763 Mdot
.73724 .71371 Mdot
.74116 .71371 Mdot
.749 .70587 Mdot
.74508 .69802 Mdot
.74116 .69018 Mdot
.74508 .69018 Mdot
.74508 .69018 Mdot
.749 .69802 Mdot
.76076 .71371 Mdot
.76076 .71371 Mdot
.76861 .71371 Mdot
.76076 .70979 Mdot
.76076 .69802 Mdot
.76469 .68626 Mdot
.76469 .68234 Mdot
.76861 .68234 Mdot
.76469 .67842 Mdot
.76469 .68234 Mdot
.75684 .67057 Mdot
.75684 .67842 Mdot
.75292 .6745 Mdot
.76469 .67842 Mdot
.76861 .67057 Mdot
.76469 .66273 Mdot
.6941 .61568 Mdot
.67842 .60391 Mdot
.77645 .70979 Mdot
.93722 .90977 Mdot
.54117 .5647 Mdot
.58039 .6196 Mdot
.59607 .64313 Mdot
.59607 .6392 Mdot
.58823 .63528 Mdot
.58823 .63136 Mdot
.59215 .63528 Mdot
.59999 .64313 Mdot
.59999 .65097 Mdot
.60391 .65097 Mdot
.61568 .67057 Mdot
.61176 .66273 Mdot
.6196 .65881 Mdot
.63136 .66273 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.63136 .66273 Mdot
.6392 .66665 Mdot
.64313 .6745 Mdot
.65489 .67842 Mdot
.64313 .68234 Mdot
.64313 .6941 Mdot
.65881 .70587 Mdot
.65489 .70979 Mdot
.66665 .71371 Mdot
.67057 .70587 Mdot
.6745 .70979 Mdot
.6745 .71763 Mdot
.69018 .72547 Mdot
.68626 .71763 Mdot
.69802 .71371 Mdot
.6941 .70587 Mdot
.69802 .70194 Mdot
.6941 .70194 Mdot
.6941 .70587 Mdot
.71371 .71763 Mdot
.71763 .72547 Mdot
.72547 .72547 Mdot
.72547 .72155 Mdot
.72547 .71763 Mdot
.72155 .70194 Mdot
.72547 .70194 Mdot
.74116 .70979 Mdot
.74116 .70587 Mdot
.74116 .70979 Mdot
.74116 .70194 Mdot
.74116 .69802 Mdot
.74116 .68626 Mdot
.749 .68626 Mdot
.749 .68626 Mdot
.74508 .68234 Mdot
.74508 .69018 Mdot
.749 .69018 Mdot
.74508 .69018 Mdot
.75684 .69802 Mdot
.76861 .70587 Mdot
.76469 .70194 Mdot
.77253 .70194 Mdot
.76861 .70194 Mdot
.76469 .69802 Mdot
.76469 .67842 Mdot
.76469 .6745 Mdot
.77645 .6745 Mdot
.77645 .67842 Mdot
.77645 .6745 Mdot
.77253 .6745 Mdot
.77253 .66273 Mdot
.77645 .66273 Mdot
.78037 .66273 Mdot
.76469 .65881 Mdot
.76076 .65097 Mdot
.76469 .64705 Mdot
.76469 .6392 Mdot
.89017 .8235 Mdot
.94114 .90585 Mdot
.52941 .54902 Mdot
.58039 .60391 Mdot
.59215 .6196 Mdot
.60391 .62744 Mdot
.59215 .62744 Mdot
.59999 .64313 Mdot
.59215 .6392 Mdot
.59215 .65097 Mdot
.59999 .65097 Mdot
.60783 .65489 Mdot
.59607 .64705 Mdot
.61176 .66665 Mdot
.61568 .66665 Mdot
.62352 .65881 Mdot
.63528 .66273 Mdot
.64313 .66665 Mdot
.63136 .66273 Mdot
.63136 .66665 Mdot
.63136 .68234 Mdot
.64313 .69018 Mdot
.65097 .69018 Mdot
.64313 .6941 Mdot
.64705 .70194 Mdot
.65489 .70979 Mdot
.66665 .71371 Mdot
.67057 .70587 Mdot
.66665 .70194 Mdot
.67842 .71371 Mdot
.68626 .71763 Mdot
.67842 .70587 Mdot
.68626 .69802 Mdot
.6941 .69802 Mdot
.6941 .6941 Mdot
.69802 .6941 Mdot
.70587 .70587 Mdot
.71371 .71371 Mdot
.70587 .71371 Mdot
.71763 .71763 Mdot
.71371 .71371 Mdot
.72547 .71371 Mdot
.72547 .70587 Mdot
.73332 .69802 Mdot
.73724 .6941 Mdot
.74508 .6941 Mdot
.74116 .70194 Mdot
.73724 .69802 Mdot
.74116 .70194 Mdot
.74508 .70194 Mdot
.73724 .6941 Mdot
.76076 .70587 Mdot
.76076 .70194 Mdot
.75684 .70194 Mdot
.76076 .70194 Mdot
.76469 .69018 Mdot
.76861 .6941 Mdot
.76861 .69802 Mdot
.77253 .70587 Mdot
.76469 .70587 Mdot
.77645 .71763 Mdot
.76861 .71371 Mdot
.77253 .70587 Mdot
.76076 .68234 Mdot
.76469 .67842 Mdot
.77253 .6745 Mdot
.78037 .67057 Mdot
.78429 .66665 Mdot
.78037 .65881 Mdot
.78429 .65489 Mdot
.77253 .65097 Mdot
.78037 .65881 Mdot
.78037 .65097 Mdot
.78429 .64705 Mdot
.78429 .6392 Mdot
.77645 .63136 Mdot
.77645 .6196 Mdot
.75684 .60391 Mdot
.89017 .80782 Mdot
.50588 .53333 Mdot
.57254 .59607 Mdot
.58823 .6196 Mdot
.59215 .62352 Mdot
.58823 .6196 Mdot
.59607 .62744 Mdot
.59215 .63136 Mdot
.59607 .63528 Mdot
.59607 .63528 Mdot
.59215 .62744 Mdot
.59999 .63528 Mdot
.61176 .64705 Mdot
.60783 .65489 Mdot
.61176 .66665 Mdot
.62352 .67057 Mdot
.62352 .65881 Mdot
.63136 .66665 Mdot
.63528 .6745 Mdot
.6392 .68234 Mdot
.6392 .68234 Mdot
.6392 .68234 Mdot
.65489 .6941 Mdot
.65489 .70194 Mdot
.65097 .69802 Mdot
.65489 .70194 Mdot
.66273 .70194 Mdot
.66665 .69802 Mdot
.66273 .69802 Mdot
.66273 .70194 Mdot
.6745 .70194 Mdot
.68626 .70587 Mdot
.69018 .70194 Mdot
.69018 .6941 Mdot
.69802 .69018 Mdot
.70194 .69802 Mdot
.71371 .71371 Mdot
.70979 .72155 Mdot
.70979 .71763 Mdot
.70979 .72155 Mdot
.71371 .71763 Mdot
.72155 .70979 Mdot
.73332 .70587 Mdot
.73332 .70194 Mdot
.73332 .69802 Mdot
.74116 .70194 Mdot
.74116 .70587 Mdot
.73724 .70979 Mdot
.74116 .70979 Mdot
.749 .70979 Mdot
.74508 .70587 Mdot
.75684 .70979 Mdot
.75292 .71371 Mdot
.749 .70979 Mdot
.76076 .70587 Mdot
.75292 .68626 Mdot
.76076 .68626 Mdot
.76469 .70194 Mdot
.76861 .70979 Mdot
.75684 .70587 Mdot
.77253 .71371 Mdot
.77645 .70194 Mdot
.77645 .69018 Mdot
.77645 .68234 Mdot
.78821 .67842 Mdot
.78821 .67057 Mdot
.78037 .65097 Mdot
.78429 .64313 Mdot
.78429 .64705 Mdot
.77253 .64705 Mdot
.78037 .65881 Mdot
.77645 .65097 Mdot
.77253 .64705 Mdot
.78037 .64705 Mdot
.78429 .6392 Mdot
.77645 .63528 Mdot
.77645 .63136 Mdot
.78037 .62744 Mdot
.78429 .62352 Mdot
.78037 .67842 Mdot
.8235 .76469 Mdot
.51765 .54902 Mdot
.57254 .60391 Mdot
.59215 .62744 Mdot
.59215 .63136 Mdot
.58823 .62744 Mdot
.58823 .6392 Mdot
.58823 .63528 Mdot
.60783 .64313 Mdot
.60783 .63528 Mdot
.60783 .63136 Mdot
.6196 .64705 Mdot
.62352 .65489 Mdot
.6196 .66273 Mdot
.61176 .65881 Mdot
.62352 .67842 Mdot
.6392 .68626 Mdot
.63528 .68234 Mdot
.64313 .68626 Mdot
.64313 .68626 Mdot
.64313 .68234 Mdot
.65097 .68234 Mdot
.65881 .68234 Mdot
.65881 .6941 Mdot
.66665 .70979 Mdot
.66273 .70979 Mdot
.66273 .70587 Mdot
.67057 .70979 Mdot
.68234 .71763 Mdot
.67842 .70587 Mdot
.67057 .6941 Mdot
.68626 .6941 Mdot
.69802 .69018 Mdot
.70194 .69018 Mdot
.71371 .69802 Mdot
.70194 .69018 Mdot
.70979 .70194 Mdot
.70194 .70587 Mdot
.71371 .72155 Mdot
.71763 .73332 Mdot
.72547 .73332 Mdot
.72939 .73332 Mdot
.73332 .72939 Mdot
.73332 .71763 Mdot
.74508 .72155 Mdot
.74508 .71371 Mdot
.73724 .70194 Mdot
.73724 .70194 Mdot
.749 .72155 Mdot
.76469 .73332 Mdot
.749 .71763 Mdot
.76469 .72547 Mdot
.749 .71763 Mdot
.749 .70587 Mdot
.75292 .70194 Mdot
.76469 .70194 Mdot
.76076 .6941 Mdot
.77645 .70587 Mdot
.77253 .70587 Mdot
.76469 .70587 Mdot
.78037 .70979 Mdot
.78429 .69802 Mdot
.78037 .68234 Mdot
.78429 .69018 Mdot
.78429 .68626 Mdot
.78429 .67057 Mdot
.78037 .65881 Mdot
.79213 .65489 Mdot
.79606 .65489 Mdot
.78037 .64705 Mdot
.78429 .65881 Mdot
.78037 .65489 Mdot
.77645 .65489 Mdot
.78821 .66273 Mdot
.78821 .65097 Mdot
.78037 .63528 Mdot
.79998 .64705 Mdot
.79606 .64705 Mdot
.78821 .64313 Mdot
.78037 .63528 Mdot
.78037 .63528 Mdot
.76469 .62744 Mdot
.83527 .73724 Mdot
.94898 .91369 Mdot
.56078 .55686 Mdot
.60783 .61176 Mdot
.6196 .6392 Mdot
.59999 .64313 Mdot
.58039 .6392 Mdot
.58823 .65489 Mdot
.58823 .65489 Mdot
.59607 .65489 Mdot
.60783 .65881 Mdot
.60783 .64313 Mdot
.60783 .64313 Mdot
.6196 .65881 Mdot
.6196 .67057 Mdot
.62744 .67057 Mdot
.63136 .67842 Mdot
.63528 .67842 Mdot
.63136 .67842 Mdot
.6392 .68626 Mdot
.64313 .67842 Mdot
.64313 .6745 Mdot
.65489 .68234 Mdot
.65489 .68626 Mdot
.65489 .69018 Mdot
.66273 .70194 Mdot
.67057 .70587 Mdot
.66665 .69802 Mdot
.67057 .70194 Mdot
.67842 .70194 Mdot
.68234 .70587 Mdot
.68626 .6941 Mdot
.69018 .6941 Mdot
.69802 .70587 Mdot
.70194 .69802 Mdot
.70194 .69018 Mdot
.6941 .68626 Mdot
.70587 .69018 Mdot
.71763 .70587 Mdot
.71763 .71371 Mdot
.71763 .71763 Mdot
.72155 .71763 Mdot
.72547 .71763 Mdot
.71763 .70979 Mdot
.73332 .71763 Mdot
.73332 .71763 Mdot
.73724 .71763 Mdot
.73332 .71371 Mdot
.73332 .71371 Mdot
.74116 .72155 Mdot
.75292 .73332 Mdot
.73724 .72155 Mdot
.749 .72939 Mdot
.75684 .73332 Mdot
.76076 .72155 Mdot
.76076 .71371 Mdot
.75684 .70587 Mdot
.76469 .70194 Mdot
.76861 .70194 Mdot
.77253 .70979 Mdot
.78037 .71763 Mdot
.76861 .69802 Mdot
.76861 .69018 Mdot
.78821 .69802 Mdot
.78037 .69018 Mdot
.78037 .68626 Mdot
.77253 .67057 Mdot
.77253 .66665 Mdot
.78429 .66665 Mdot
.78821 .66273 Mdot
.78037 .65881 Mdot
.77645 .65881 Mdot
.77253 .65489 Mdot
.78037 .65881 Mdot
.79213 .66273 Mdot
.79606 .65881 Mdot
.79606 .65097 Mdot
.79998 .65881 Mdot
.79606 .65097 Mdot
.79213 .65097 Mdot
.78037 .6392 Mdot
.78821 .64705 Mdot
.78429 .65489 Mdot
.78037 .65489 Mdot
.77645 .65097 Mdot
.77253 .64313 Mdot
.86272 .79998 Mdot
.90977 .88232 Mdot
.5647 .57254 Mdot
.58823 .6196 Mdot
.59999 .6392 Mdot
.58823 .64313 Mdot
.57646 .65489 Mdot
.58823 .6745 Mdot
.59999 .68234 Mdot
.60391 .6745 Mdot
.61568 .66273 Mdot
.61568 .64313 Mdot
.61176 .6392 Mdot
.6196 .64313 Mdot
.6196 .65489 Mdot
.62352 .65881 Mdot
.63136 .66273 Mdot
.63136 .66665 Mdot
.63528 .6745 Mdot
.63528 .68234 Mdot
.6392 .67842 Mdot
.64313 .6745 Mdot
.65881 .68626 Mdot
.65097 .68234 Mdot
.65489 .68626 Mdot
.65489 .6941 Mdot
.65097 .69018 Mdot
.66665 .69802 Mdot
.67057 .6941 Mdot
.6745 .69802 Mdot
.6745 .6941 Mdot
.66665 .68626 Mdot
.68626 .6941 Mdot
.69802 .70587 Mdot
.69802 .70587 Mdot
.69802 .70587 Mdot
.69018 .69802 Mdot
.69802 .69802 Mdot
.70587 .70979 Mdot
.70587 .71371 Mdot
.71371 .71371 Mdot
.72155 .71371 Mdot
.71371 .70979 Mdot
.70979 .70587 Mdot
.72155 .71371 Mdot
.73724 .72939 Mdot
.73332 .72547 Mdot
.73332 .72155 Mdot
.72939 .71763 Mdot
.74116 .72939 Mdot
.73724 .72547 Mdot
.74116 .72547 Mdot
.74508 .72547 Mdot
.75292 .72547 Mdot
.76076 .72547 Mdot
.749 .71371 Mdot
.74508 .72155 Mdot
.75292 .72155 Mdot
.75684 .72155 Mdot
.76076 .72155 Mdot
.75684 .71763 Mdot
.76076 .71371 Mdot
.76861 .70194 Mdot
.78037 .70194 Mdot
.77645 .6941 Mdot
.78429 .6941 Mdot
.78429 .68626 Mdot
.77645 .67842 Mdot
.78037 .68234 Mdot
.77645 .67842 Mdot
.78037 .68234 Mdot
.78037 .68626 Mdot
.78821 .69018 Mdot
.77645 .67842 Mdot
.76469 .67057 Mdot
.77645 .66665 Mdot
.78821 .66665 Mdot
.79998 .65881 Mdot
.79606 .65489 Mdot
.78821 .65881 Mdot
.78429 .65489 Mdot
.78429 .66273 Mdot
.78037 .66665 Mdot
.78429 .66665 Mdot
.78429 .66273 Mdot
.77253 .65881 Mdot
.76861 .65489 Mdot
.749 .64313 Mdot
.75684 .65097 Mdot
.88232 .82743 Mdot
.56862 .58431 Mdot
.58431 .62744 Mdot
.59607 .65881 Mdot
.59215 .66665 Mdot
.58823 .6745 Mdot
.58431 .6745 Mdot
.57254 .66273 Mdot
.58431 .66273 Mdot
.60783 .66273 Mdot
.61568 .65881 Mdot
.6196 .65489 Mdot
.62352 .66273 Mdot
.62744 .66665 Mdot
.63136 .67057 Mdot
.63528 .6745 Mdot
.6392 .67842 Mdot
.62744 .67057 Mdot
.63528 .68234 Mdot
.6392 .69018 Mdot
.65097 .69802 Mdot
.64705 .68234 Mdot
.65881 .68626 Mdot
.65489 .67842 Mdot
.65489 .67842 Mdot
.64705 .68234 Mdot
.64313 .67842 Mdot
.66273 .69018 Mdot
.67057 .6941 Mdot
.6745 .6941 Mdot
.68234 .70194 Mdot
.68234 .6941 Mdot
.6941 .70194 Mdot
.69018 .69018 Mdot
.69018 .69802 Mdot
.68626 .69802 Mdot
.68626 .69802 Mdot
.69802 .70587 Mdot
.70587 .70587 Mdot
.70194 .70194 Mdot
.72155 .71371 Mdot
.72939 .73332 Mdot
.72155 .72939 Mdot
.71763 .72155 Mdot
.71763 .71763 Mdot
.72547 .72547 Mdot
.72939 .73332 Mdot
.73724 .73724 Mdot
.73724 .73724 Mdot
.73724 .74116 Mdot
.73724 .74116 Mdot
.74116 .73724 Mdot
.749 .74116 Mdot
.749 .74116 Mdot
.75292 .73724 Mdot
.749 .72939 Mdot
.75684 .73332 Mdot
.75292 .72939 Mdot
.76861 .73724 Mdot
.76861 .72939 Mdot
.76861 .71763 Mdot
.76469 .69802 Mdot
.77253 .70194 Mdot
.77253 .69802 Mdot
.78037 .70194 Mdot
.78037 .70194 Mdot
.78429 .71371 Mdot
.78429 .70979 Mdot
.77645 .70587 Mdot
.77645 .70587 Mdot
.77253 .69802 Mdot
.78037 .69802 Mdot
.78429 .69802 Mdot
.78037 .69018 Mdot
.78037 .69018 Mdot
.78037 .6745 Mdot
.79213 .67842 Mdot
.78037 .66273 Mdot
.79213 .6745 Mdot
.79213 .68234 Mdot
.78821 .68626 Mdot
.78429 .67842 Mdot
.78429 .6745 Mdot
.77645 .66665 Mdot
.78821 .6745 Mdot
.78037 .6745 Mdot
.77253 .66665 Mdot
.76076 .65881 Mdot
.76861 .65881 Mdot
.76469 .65097 Mdot
.81566 .72547 Mdot
.86664 .81174 Mdot
.56078 .58431 Mdot
.58431 .63136 Mdot
.59607 .65489 Mdot
.58431 .66665 Mdot
.58431 .6745 Mdot
.58431 .67057 Mdot
.58823 .66665 Mdot
.59607 .66273 Mdot
.61176 .66665 Mdot
.61176 .65881 Mdot
.60783 .65881 Mdot
.61568 .66665 Mdot
.62352 .6745 Mdot
.6392 .68626 Mdot
.62744 .67842 Mdot
.62744 .67842 Mdot
.63136 .67842 Mdot
.64313 .6941 Mdot
.64313 .70194 Mdot
.64705 .70194 Mdot
.65097 .70194 Mdot
.65881 .69018 Mdot
.65881 .68626 Mdot
.65881 .68234 Mdot
.6745 .6941 Mdot
.65881 .69018 Mdot
.65881 .68626 Mdot
.66665 .69018 Mdot
.67842 .69802 Mdot
.68234 .69802 Mdot
.6745 .69802 Mdot
.67842 .70194 Mdot
.69018 .70979 Mdot
.69018 .70979 Mdot
.6941 .71371 Mdot
.69802 .70979 Mdot
.70194 .71763 Mdot
.70979 .71763 Mdot
.71371 .70979 Mdot
.72155 .71371 Mdot
.71763 .71763 Mdot
.72155 .72939 Mdot
.73332 .74508 Mdot
.72939 .73724 Mdot
.72939 .71763 Mdot
.73724 .72155 Mdot
.73724 .73332 Mdot
.74116 .73724 Mdot
.73332 .73332 Mdot
.74508 .74508 Mdot
.749 .75684 Mdot
.75684 .76469 Mdot
.75292 .76469 Mdot
.75292 .75684 Mdot
.75292 .75292 Mdot
.75292 .749 Mdot
.749 .73724 Mdot
.76076 .74116 Mdot
.76076 .73332 Mdot
.77645 .72939 Mdot
.78429 .72547 Mdot
.77253 .71371 Mdot
.77253 .70979 Mdot
.77645 .71763 Mdot
.77645 .71763 Mdot
.77253 .71371 Mdot
.77645 .71763 Mdot
.78429 .72155 Mdot
.78821 .72547 Mdot
.78429 .72155 Mdot
.78429 .71763 Mdot
.78429 .71371 Mdot
.78429 .70587 Mdot
.78821 .70587 Mdot
.78429 .6941 Mdot
.79213 .68626 Mdot
.78429 .67842 Mdot
.78821 .68626 Mdot
.78821 .6941 Mdot
.79606 .6941 Mdot
.79606 .69802 Mdot
.78429 .68626 Mdot
.78821 .67842 Mdot
.79213 .67842 Mdot
.78821 .68234 Mdot
.78821 .69018 Mdot
.78821 .68626 Mdot
.78037 .6745 Mdot
.78821 .67842 Mdot
.78037 .67057 Mdot
.78037 .66665 Mdot
.76469 .65097 Mdot
.81174 .72547 Mdot
.93722 .90977 Mdot
.55294 .58039 Mdot
.58431 .63136 Mdot
.60783 .66273 Mdot
.59607 .66273 Mdot
.58039 .67057 Mdot
.57646 .66665 Mdot
.58823 .66665 Mdot
.59607 .67057 Mdot
.59999 .6745 Mdot
.60783 .67842 Mdot
.61568 .68626 Mdot
.61568 .68626 Mdot
.62744 .69018 Mdot
.63528 .68626 Mdot
.63136 .68234 Mdot
.63136 .68626 Mdot
.62352 .68626 Mdot
.63528 .6941 Mdot
.63528 .6941 Mdot
.6392 .6941 Mdot
.65489 .69802 Mdot
.65097 .68626 Mdot
.65489 .68626 Mdot
.65881 .68626 Mdot
.6745 .6941 Mdot
.66665 .69018 Mdot
.67842 .69802 Mdot
.66665 .6941 Mdot
.67842 .70587 Mdot
.68626 .71371 Mdot
.6941 .71763 Mdot
.68626 .71763 Mdot
.68626 .73332 Mdot
.69018 .74116 Mdot
.6941 .72939 Mdot
.68626 .71763 Mdot
.69802 .72155 Mdot
.70194 .72155 Mdot
.71371 .72547 Mdot
.72155 .72939 Mdot
.71763 .72155 Mdot
.72547 .72939 Mdot
.71371 .72939 Mdot
.72547 .74508 Mdot
.72547 .73724 Mdot
.73332 .73724 Mdot
.73332 .74116 Mdot
.73332 .74508 Mdot
.72939 .74116 Mdot
.73724 .74508 Mdot
.74508 .75684 Mdot
.749 .76076 Mdot
.76076 .76076 Mdot
.75684 .75292 Mdot
.76076 .75292 Mdot
.75684 .74508 Mdot
.75684 .73724 Mdot
.76469 .73724 Mdot
.76076 .72547 Mdot
.77645 .72547 Mdot
.79213 .72939 Mdot
.77253 .70979 Mdot
.76861 .70194 Mdot
.77253 .70194 Mdot
.76861 .69802 Mdot
.77645 .70587 Mdot
.76861 .71371 Mdot
.78037 .72155 Mdot
.78429 .72547 Mdot
.78821 .72547 Mdot
.78821 .71371 Mdot
.77645 .70194 Mdot
.78037 .70194 Mdot
.78429 .69802 Mdot
.78821 .68626 Mdot
.78037 .6745 Mdot
.78429 .6745 Mdot
.78821 .69018 Mdot
.78429 .6941 Mdot
.78821 .70194 Mdot
.78821 .69802 Mdot
.78821 .69018 Mdot
.78821 .68234 Mdot
.78821 .67842 Mdot
.78821 .68234 Mdot
.78429 .68234 Mdot
.78821 .68626 Mdot
.77253 .68234 Mdot
.76861 .67842 Mdot
.78037 .68234 Mdot
.77645 .6745 Mdot
.77645 .66665 Mdot
.77253 .66665 Mdot
.76861 .65881 Mdot
.76469 .65097 Mdot
.88232 .8235 Mdot
.93722 .90977 Mdot
.55686 .56862 Mdot
.57646 .60783 Mdot
.59607 .6392 Mdot
.59215 .65489 Mdot
.58039 .65097 Mdot
.59607 .66665 Mdot
.59215 .66665 Mdot
.59999 .68234 Mdot
.58823 .68234 Mdot
.59215 .68234 Mdot
.59999 .69018 Mdot
.61176 .69802 Mdot
.6196 .68626 Mdot
.6392 .69018 Mdot
.6392 .68626 Mdot
.62744 .68234 Mdot
.63136 .69018 Mdot
.63528 .69802 Mdot
.6392 .6941 Mdot
.64313 .69802 Mdot
.64705 .70194 Mdot
.65881 .70979 Mdot
.66273 .71371 Mdot
.67057 .71763 Mdot
.65881 .70979 Mdot
.66665 .70587 Mdot
.6745 .69802 Mdot
.6745 .69802 Mdot
.67842 .70194 Mdot
.68234 .70587 Mdot
.68234 .71371 Mdot
.67842 .71763 Mdot
.6745 .72547 Mdot
.68234 .74116 Mdot
.68626 .74116 Mdot
.69018 .73724 Mdot
.6941 .73724 Mdot
.70979 .74116 Mdot
.70587 .73724 Mdot
.70587 .74116 Mdot
.70979 .74116 Mdot
.70979 .74116 Mdot
.71371 .74508 Mdot
.70979 .74508 Mdot
.72155 .75684 Mdot
.72155 .75292 Mdot
.72547 .74508 Mdot
.73724 .749 Mdot
.73724 .75292 Mdot
.749 .76076 Mdot
.74508 .76076 Mdot
.75292 .75684 Mdot
.73724 .74116 Mdot
.75292 .749 Mdot
.76469 .75684 Mdot
.76076 .749 Mdot
.75292 .74116 Mdot
.76861 .74508 Mdot
.749 .72547 Mdot
.749 .72155 Mdot
.76861 .72155 Mdot
.77253 .71763 Mdot
.78429 .72155 Mdot
.78429 .71371 Mdot
.77253 .70587 Mdot
.78037 .71371 Mdot
.76861 .71371 Mdot
.77645 .71763 Mdot
.78429 .72155 Mdot
.78429 .72939 Mdot
.78429 .72939 Mdot
.78821 .71371 Mdot
.78821 .69802 Mdot
.78821 .69018 Mdot
.79213 .68626 Mdot
.78821 .67842 Mdot
.79606 .68234 Mdot
.78037 .67842 Mdot
.78429 .6941 Mdot
.79213 .70979 Mdot
.78821 .70979 Mdot
.78821 .70587 Mdot
.78821 .6941 Mdot
.78429 .68626 Mdot
.78821 .68626 Mdot
.78821 .6941 Mdot
.79213 .70194 Mdot
.78429 .70194 Mdot
.78429 .70587 Mdot
.77645 .6941 Mdot
.78429 .69018 Mdot
.77645 .67842 Mdot
.76861 .66273 Mdot
.78037 .66273 Mdot
.78037 .65489 Mdot
.77645 .65097 Mdot
.76469 .65097 Mdot
.69802 .60391 Mdot
.86664 .81566 Mdot
.54902 .56078 Mdot
.57646 .60783 Mdot
.58431 .63136 Mdot
.58823 .65097 Mdot
.58823 .64705 Mdot
.58823 .65097 Mdot
.59999 .65489 Mdot
.59215 .65881 Mdot
.58823 .66665 Mdot
.59999 .67057 Mdot
.61176 .68234 Mdot
.61568 .68626 Mdot
.62352 .67842 Mdot
.62352 .67842 Mdot
.62744 .67842 Mdot
.63136 .68234 Mdot
.62744 .68234 Mdot
.62744 .69802 Mdot
.62744 .6941 Mdot
.63136 .6941 Mdot
.65097 .70587 Mdot
.65489 .70979 Mdot
.64705 .70979 Mdot
.64705 .71371 Mdot
.64705 .72155 Mdot
.66665 .72155 Mdot
.6745 .71371 Mdot
.6745 .70979 Mdot
.67842 .70587 Mdot
.67842 .71371 Mdot
.68234 .71371 Mdot
.68626 .70979 Mdot
.68626 .72155 Mdot
.6941 .74116 Mdot
.69018 .74116 Mdot
.6941 .74508 Mdot
.6941 .749 Mdot
.69802 .749 Mdot
.69802 .749 Mdot
.70194 .75292 Mdot
.70979 .749 Mdot
.71763 .75292 Mdot
.71763 .75292 Mdot
.72547 .76076 Mdot
.71763 .76076 Mdot
.72939 .76469 Mdot
.72547 .75292 Mdot
.74116 .75684 Mdot
.749 .76076 Mdot
.74508 .76076 Mdot
.749 .75684 Mdot
.749 .75292 Mdot
.75684 .749 Mdot
.74508 .73724 Mdot
.73724 .72939 Mdot
.74508 .73724 Mdot
.74508 .73332 Mdot
.75684 .74116 Mdot
.75684 .73332 Mdot
.76076 .72547 Mdot
.76861 .72547 Mdot
.76469 .72547 Mdot
.77645 .74116 Mdot
.77645 .74508 Mdot
.76469 .72939 Mdot
.76469 .72547 Mdot
.76861 .72939 Mdot
.76469 .72547 Mdot
.78037 .73332 Mdot
.77645 .72939 Mdot
.77253 .72939 Mdot
.78821 .72547 Mdot
.79606 .72547 Mdot
.79213 .70194 Mdot
.78429 .69018 Mdot
.79998 .68626 Mdot
.79213 .6745 Mdot
.79213 .68234 Mdot
.78821 .6941 Mdot
.78429 .69802 Mdot
.78429 .69802 Mdot
.77645 .69802 Mdot
.79213 .70587 Mdot
.78037 .69802 Mdot
.77645 .69802 Mdot
.77645 .6941 Mdot
.78037 .6941 Mdot
.77253 .69802 Mdot
.78821 .71371 Mdot
.77645 .70194 Mdot
.77645 .69018 Mdot
.77253 .68234 Mdot
.77645 .6745 Mdot
.77645 .66273 Mdot
.78429 .66273 Mdot
.77253 .66273 Mdot
.76861 .66665 Mdot
.76469 .66273 Mdot
.75292 .65489 Mdot
.749 .65881 Mdot
.80782 .74116 Mdot
.81958 .78429 Mdot
.54117 .57254 Mdot
.59215 .62744 Mdot
.59999 .65489 Mdot
.59215 .65489 Mdot
.59215 .65881 Mdot
.59215 .65097 Mdot
.58823 .65097 Mdot
.59607 .65881 Mdot
.58823 .66665 Mdot
.60391 .6745 Mdot
.61568 .67057 Mdot
.61568 .67057 Mdot
.6196 .6745 Mdot
.6196 .6745 Mdot
.61176 .66665 Mdot
.6196 .66665 Mdot
.6196 .6745 Mdot
.62744 .6941 Mdot
.62744 .70194 Mdot
.63528 .71371 Mdot
.6392 .71371 Mdot
.65097 .71371 Mdot
.65881 .71763 Mdot
.64705 .70979 Mdot
.65489 .71763 Mdot
.66273 .71763 Mdot
.67057 .71371 Mdot
.67057 .71371 Mdot
.67842 .71763 Mdot
.67842 .71763 Mdot
.68234 .72155 Mdot
.68234 .72155 Mdot
.69802 .72939 Mdot
.69802 .73332 Mdot
.6941 .73332 Mdot
.69018 .72939 Mdot
.6941 .74116 Mdot
.69802 .74116 Mdot
.70194 .74116 Mdot
.70194 .74508 Mdot
.69802 .74508 Mdot
.71371 .75292 Mdot
.71763 .749 Mdot
.71763 .74508 Mdot
.71371 .74508 Mdot
.72547 .75292 Mdot
.72155 .74508 Mdot
.72155 .749 Mdot
.72547 .75292 Mdot
.72939 .75292 Mdot
.73332 .75292 Mdot
.72939 .74508 Mdot
.73724 .749 Mdot
.74508 .749 Mdot
.74508 .749 Mdot
.74508 .74508 Mdot
.74116 .74116 Mdot
.75292 .73332 Mdot
.75684 .73332 Mdot
.75684 .72939 Mdot
.749 .72547 Mdot
.749 .72939 Mdot
.76469 .74116 Mdot
.76861 .74508 Mdot
.77645 .74508 Mdot
.78429 .74508 Mdot
.78037 .74508 Mdot
.76469 .74116 Mdot
.76469 .73332 Mdot
.77645 .73724 Mdot
.77253 .72547 Mdot
.77253 .71371 Mdot
.76076 .6941 Mdot
.77645 .69802 Mdot
.78037 .69802 Mdot
.78429 .69018 Mdot
.78821 .68626 Mdot
.78037 .68626 Mdot
.78037 .6941 Mdot
.77253 .6941 Mdot
.78037 .70194 Mdot
.78037 .70194 Mdot
.78821 .70587 Mdot
.78429 .70194 Mdot
.78037 .70194 Mdot
.77645 .69802 Mdot
.78821 .70587 Mdot
.77645 .70194 Mdot
.78821 .71371 Mdot
.77645 .70587 Mdot
.76861 .6941 Mdot
.77253 .6941 Mdot
.77253 .6941 Mdot
.77253 .67842 Mdot
.77253 .6745 Mdot
.76861 .66665 Mdot
.78037 .68234 Mdot
.78037 .67842 Mdot
.75684 .65881 Mdot
.75292 .66273 Mdot
.749 .66273 Mdot
.749 .65881 Mdot
.749 .65097 Mdot
.78037 .71763 Mdot
.92546 .90585 Mdot
.57646 .59999 Mdot
.58823 .62744 Mdot
.60391 .65097 Mdot
.59607 .65881 Mdot
.60391 .67057 Mdot
.60391 .67057 Mdot
.58431 .65881 Mdot
.59999 .67057 Mdot
.60391 .66665 Mdot
.60391 .66273 Mdot
.59999 .65489 Mdot
.60783 .65881 Mdot
.62352 .6745 Mdot
.62744 .67842 Mdot
.63528 .68626 Mdot
.63528 .68626 Mdot
.6392 .6941 Mdot
.63136 .69802 Mdot
.63136 .70979 Mdot
.63136 .71763 Mdot
.63528 .71371 Mdot
.6392 .70979 Mdot
.64705 .70979 Mdot
.65881 .72939 Mdot
.65489 .72155 Mdot
.66665 .71763 Mdot
.6745 .71371 Mdot
.67842 .71371 Mdot
.68626 .71763 Mdot
.68234 .71371 Mdot
.68626 .72547 Mdot
.68626 .72939 Mdot
.68626 .73332 Mdot
.70194 .73332 Mdot
.70587 .73332 Mdot
.70587 .73332 Mdot
.70587 .73332 Mdot
.70587 .73724 Mdot
.69802 .73724 Mdot
.70979 .749 Mdot
.70587 .74508 Mdot
.71371 .749 Mdot
.71371 .76469 Mdot
.71371 .76076 Mdot
.71763 .749 Mdot
.71763 .74508 Mdot
.72547 .75292 Mdot
.72547 .76076 Mdot
.72547 .75292 Mdot
.72155 .749 Mdot
.73332 .75292 Mdot
.73332 .75292 Mdot
.73724 .75684 Mdot
.74508 .76076 Mdot
.74508 .75684 Mdot
.74508 .75292 Mdot
.74116 .75292 Mdot
.76076 .76076 Mdot
.75292 .75292 Mdot
.749 .749 Mdot
.75684 .749 Mdot
.75684 .74116 Mdot
.76469 .74116 Mdot
.76469 .73724 Mdot
.76469 .73724 Mdot
.76861 .73724 Mdot
.75684 .73724 Mdot
.76861 .75292 Mdot
.76861 .74508 Mdot
.76469 .74116 Mdot
.76076 .73724 Mdot
.76861 .73724 Mdot
.77253 .72155 Mdot
.76861 .70979 Mdot
.76469 .70979 Mdot
.77645 .71371 Mdot
.77645 .6941 Mdot
.79213 .70194 Mdot
.78429 .6941 Mdot
.78037 .6941 Mdot
.78429 .70194 Mdot
.78037 .70194 Mdot
.78037 .70194 Mdot
.78821 .70587 Mdot
.79213 .71371 Mdot
.78821 .71371 Mdot
.77645 .70587 Mdot
.77645 .70587 Mdot
.78429 .70979 Mdot
.78037 .71371 Mdot
.77645 .70587 Mdot
.77645 .70587 Mdot
.77253 .69802 Mdot
.78037 .69018 Mdot
.77645 .69018 Mdot
.77645 .68626 Mdot
.77645 .68234 Mdot
.78037 .68234 Mdot
.77645 .67842 Mdot
.76076 .67057 Mdot
.76076 .67057 Mdot
.76076 .67057 Mdot
.76076 .6745 Mdot
.74116 .66273 Mdot
.74508 .66665 Mdot
.74116 .64313 Mdot
.85095 .80782 Mdot
.90585 .89017 Mdot
.54902 .59215 Mdot
.58823 .63136 Mdot
.59999 .65881 Mdot
.59607 .67842 Mdot
.59607 .67842 Mdot
.60391 .68234 Mdot
.60391 .67842 Mdot
.61568 .6745 Mdot
.60391 .65881 Mdot
.61568 .67057 Mdot
.61568 .67842 Mdot
.61568 .67057 Mdot
.62744 .6745 Mdot
.6392 .67842 Mdot
.64313 .69018 Mdot
.6392 .68626 Mdot
.6392 .6941 Mdot
.6392 .70587 Mdot
.64313 .71763 Mdot
.64313 .72155 Mdot
.64313 .71371 Mdot
.65489 .71371 Mdot
.65489 .70979 Mdot
.66273 .72155 Mdot
.67057 .72547 Mdot
.6745 .71763 Mdot
.68234 .72155 Mdot
.68234 .71763 Mdot
.69018 .72155 Mdot
.70194 .72939 Mdot
.69018 .73332 Mdot
.68234 .72939 Mdot
.6941 .73724 Mdot
.70587 .74116 Mdot
.70587 .73332 Mdot
.71371 .74116 Mdot
.71371 .75292 Mdot
.71763 .75292 Mdot
.71763 .749 Mdot
.72547 .75292 Mdot
.72547 .75292 Mdot
.73332 .76076 Mdot
.71371 .749 Mdot
.72547 .76861 Mdot
.72939 .76861 Mdot
.72939 .76076 Mdot
.72155 .75292 Mdot
.72939 .76469 Mdot
.72547 .75684 Mdot
.72547 .75292 Mdot
.73332 .76076 Mdot
.73724 .76076 Mdot
.75292 .77253 Mdot
.74116 .77253 Mdot
.74508 .77253 Mdot
.76076 .78037 Mdot
.75684 .76861 Mdot
.76861 .76861 Mdot
.76076 .75292 Mdot
.75292 .75292 Mdot
.75292 .74508 Mdot
.76076 .74116 Mdot
.76861 .74116 Mdot
.76861 .73724 Mdot
.76861 .72939 Mdot
.76469 .73724 Mdot
.76861 .74116 Mdot
.78037 .75292 Mdot
.77253 .76076 Mdot
.77645 .76076 Mdot
.77645 .76076 Mdot
.78429 .77253 Mdot
.76861 .749 Mdot
.78037 .74116 Mdot
.79213 .74508 Mdot
.78821 .74508 Mdot
.78429 .72547 Mdot
.79998 .72939 Mdot
.79606 .71371 Mdot
.79998 .70979 Mdot
.8039 .71371 Mdot
.79998 .70979 Mdot
.79213 .70979 Mdot
.79213 .71371 Mdot
.78429 .71763 Mdot
.78821 .72939 Mdot
.78429 .72547 Mdot
.78821 .72547 Mdot
.78429 .72155 Mdot
.78821 .72547 Mdot
.77253 .71763 Mdot
.77645 .71763 Mdot
.77645 .71371 Mdot
.78429 .70979 Mdot
.78821 .70979 Mdot
.78429 .70979 Mdot
.78429 .71371 Mdot
.77645 .70194 Mdot
.78429 .69802 Mdot
.78429 .6941 Mdot
.78037 .6941 Mdot
.77645 .68626 Mdot
.77645 .68626 Mdot
.76861 .68234 Mdot
.77253 .6941 Mdot
.76469 .69018 Mdot
.749 .67842 Mdot
.73724 .66665 Mdot
.70194 .62352 Mdot
.85095 .81174 Mdot
.54117 .58823 Mdot
.57254 .63528 Mdot
.58823 .66665 Mdot
.58823 .67842 Mdot
.58431 .68234 Mdot
.60391 .6941 Mdot
.59999 .6745 Mdot
.59607 .66273 Mdot
.59607 .65489 Mdot
.59999 .65881 Mdot
.6196 .6745 Mdot
.6196 .67057 Mdot
.62352 .66665 Mdot
.63528 .67057 Mdot
.64313 .69018 Mdot
.6392 .69018 Mdot
.62352 .69018 Mdot
.62352 .69802 Mdot
.62744 .70194 Mdot
.6392 .70587 Mdot
.64313 .70194 Mdot
.65097 .69802 Mdot
.65881 .70587 Mdot
.65489 .69802 Mdot
.67057 .71371 Mdot
.67057 .71371 Mdot
.6745 .70979 Mdot
.67842 .70979 Mdot
.68626 .71763 Mdot
.68626 .72939 Mdot
.69018 .73332 Mdot
.6745 .71763 Mdot
.69018 .72547 Mdot
.69802 .73332 Mdot
.70194 .73332 Mdot
.70979 .73724 Mdot
.70979 .74116 Mdot
.71371 .749 Mdot
.71371 .75292 Mdot
.72155 .75684 Mdot
.72547 .749 Mdot
.71763 .73724 Mdot
.71763 .74116 Mdot
.71763 .749 Mdot
.72547 .75684 Mdot
.72939 .76469 Mdot
.73332 .76861 Mdot
.72939 .76469 Mdot
.72939 .76469 Mdot
.73332 .76469 Mdot
.73724 .76469 Mdot
.72939 .76076 Mdot
.73332 .76861 Mdot
.72939 .76469 Mdot
.73724 .76861 Mdot
.75292 .76469 Mdot
.75292 .76469 Mdot
.75684 .76076 Mdot
.75292 .75292 Mdot
.75684 .75292 Mdot
.75684 .75684 Mdot
.76076 .75684 Mdot
.77253 .75684 Mdot
.77253 .75292 Mdot
.76076 .72939 Mdot
.77253 .73332 Mdot
.76076 .72547 Mdot
.77253 .74116 Mdot
.76861 .74116 Mdot
.76469 .74116 Mdot
.76469 .749 Mdot
.77253 .75684 Mdot
.76861 .749 Mdot
.78037 .74508 Mdot
.77645 .73724 Mdot
.77253 .72939 Mdot
.78429 .72939 Mdot
.78037 .71371 Mdot
.78429 .70979 Mdot
.78821 .70587 Mdot
.78821 .71371 Mdot
.79606 .72547 Mdot
.78429 .72155 Mdot
.78429 .72155 Mdot
.78037 .72939 Mdot
.78037 .73724 Mdot
.78821 .74116 Mdot
.78429 .73724 Mdot
.78429 .72939 Mdot
.79213 .72939 Mdot
.78037 .72155 Mdot
.78037 .71371 Mdot
.78037 .70194 Mdot
.78429 .70194 Mdot
.78821 .71371 Mdot
.78429 .71763 Mdot
.78037 .72155 Mdot
.78037 .71763 Mdot
.78429 .70979 Mdot
.77645 .69802 Mdot
.78037 .69802 Mdot
.77645 .69018 Mdot
.77645 .69018 Mdot
.76861 .6941 Mdot
.76861 .70194 Mdot
.76076 .6941 Mdot
.75684 .69018 Mdot
.74508 .68234 Mdot
.73724 .68234 Mdot
.74116 .67842 Mdot
.69018 .62744 Mdot
.74508 .69802 Mdot
.78821 .76861 Mdot
.54509 .58823 Mdot
.57254 .63528 Mdot
.58823 .65881 Mdot
.58823 .67842 Mdot
.56862 .66665 Mdot
.57254 .66665 Mdot
.58039 .65097 Mdot
.58823 .65097 Mdot
.59999 .64705 Mdot
.60783 .65097 Mdot
.59999 .65489 Mdot
.60391 .65881 Mdot
.60783 .66273 Mdot
.61568 .67057 Mdot
.6196 .6745 Mdot
.6196 .67842 Mdot
.62744 .69018 Mdot
.61568 .69018 Mdot
.62352 .69802 Mdot
.63136 .70194 Mdot
.64705 .70587 Mdot
.65489 .69802 Mdot
.64705 .69018 Mdot
.65489 .70587 Mdot
.65489 .71763 Mdot
.65489 .70979 Mdot
.67057 .71371 Mdot
.67842 .71763 Mdot
.67842 .72155 Mdot
.67057 .71763 Mdot
.67057 .72155 Mdot
.67057 .71763 Mdot
.68626 .72155 Mdot
.69018 .72547 Mdot
.69018 .72939 Mdot
.6941 .72939 Mdot
.6941 .73724 Mdot
.6941 .74508 Mdot
.6941 .74116 Mdot
.70979 .749 Mdot
.70979 .749 Mdot
.71371 .749 Mdot
.72155 .749 Mdot
.71763 .74116 Mdot
.71763 .74116 Mdot
.72155 .73724 Mdot
.72547 .75684 Mdot
.72939 .76076 Mdot
.72547 .75684 Mdot
.72939 .76076 Mdot
.73332 .76076 Mdot
.74116 .75292 Mdot
.74116 .76469 Mdot
.73332 .76076 Mdot
.73332 .75292 Mdot
.73332 .74508 Mdot
.74116 .749 Mdot
.75292 .749 Mdot
.75292 .74508 Mdot
.75292 .749 Mdot
.74508 .74116 Mdot
.74508 .74508 Mdot
.75684 .75684 Mdot
.74116 .74508 Mdot
.74508 .73724 Mdot
.749 .73332 Mdot
.75684 .73332 Mdot
.76076 .73332 Mdot
.76469 .74116 Mdot
.77253 .749 Mdot
.76469 .749 Mdot
.76469 .74508 Mdot
.77253 .749 Mdot
.77253 .74116 Mdot
.76469 .73332 Mdot
.77645 .74116 Mdot
.77645 .73332 Mdot
.78037 .72155 Mdot
.78037 .71371 Mdot
.77645 .70194 Mdot
.78429 .70979 Mdot
.78821 .71371 Mdot
.78037 .70587 Mdot
.78429 .72155 Mdot
.76861 .72155 Mdot
.76469 .72939 Mdot
.76469 .72547 Mdot
.78429 .72547 Mdot
.78037 .72547 Mdot
.77253 .71763 Mdot
.78037 .71763 Mdot
.77253 .70979 Mdot
.77253 .69802 Mdot
.78429 .69802 Mdot
.77645 .69018 Mdot
.76861 .6941 Mdot
.77645 .69802 Mdot
.77645 .6941 Mdot
.77253 .69018 Mdot
.77253 .69018 Mdot
.77253 .69802 Mdot
.76076 .69018 Mdot
.76076 .6941 Mdot
.74508 .68626 Mdot
.74116 .68234 Mdot
.75684 .6941 Mdot
.75292 .6941 Mdot
.75292 .69802 Mdot
.74508 .69802 Mdot
.74116 .69018 Mdot
.72939 .6745 Mdot
.72155 .66665 Mdot
.71763 .66665 Mdot
.65097 .59999 Mdot
.73332 .68626 Mdot
.91761 .89801 Mdot
.54117 .57254 Mdot
.57254 .61568 Mdot
.58039 .6392 Mdot
.57646 .65489 Mdot
.57646 .66665 Mdot
.5647 .66273 Mdot
.58039 .66665 Mdot
.58039 .65489 Mdot
.59215 .65097 Mdot
.59215 .65489 Mdot
.59999 .67057 Mdot
.59999 .6745 Mdot
.60391 .67057 Mdot
.61176 .67057 Mdot
.60783 .66665 Mdot
.61176 .66273 Mdot
.6196 .67842 Mdot
.61568 .68234 Mdot
.62744 .69802 Mdot
.6196 .6941 Mdot
.62744 .70587 Mdot
.6392 .70979 Mdot
.62744 .70194 Mdot
.64313 .70979 Mdot
.64313 .70979 Mdot
.64705 .70587 Mdot
.65881 .71371 Mdot
.67057 .72155 Mdot
.67057 .71763 Mdot
.66665 .72155 Mdot
.66665 .72547 Mdot
.67057 .72547 Mdot
.6745 .71763 Mdot
.6745 .70587 Mdot
.67842 .70979 Mdot
.68626 .72155 Mdot
.6941 .73332 Mdot
.70194 .74508 Mdot
.70587 .75292 Mdot
.70587 .75684 Mdot
.70587 .76861 Mdot
.69802 .75684 Mdot
.70587 .76076 Mdot
.70587 .76469 Mdot
.72155 .76469 Mdot
.71763 .749 Mdot
.72547 .75684 Mdot
.72547 .76076 Mdot
.72547 .76076 Mdot
.72939 .76469 Mdot
.72547 .75684 Mdot
.72939 .75684 Mdot
.74116 .77253 Mdot
.73724 .77645 Mdot
.73332 .76861 Mdot
.72155 .75292 Mdot
.72547 .75684 Mdot
.73332 .75684 Mdot
.73724 .75684 Mdot
.73724 .75292 Mdot
.74116 .75292 Mdot
.73724 .749 Mdot
.73332 .74508 Mdot
.74116 .75292 Mdot
.75292 .76076 Mdot
.73724 .74116 Mdot
.74116 .73724 Mdot
.749 .74508 Mdot
.75684 .74508 Mdot
.76076 .75684 Mdot
.749 .75684 Mdot
.749 .75292 Mdot
.749 .749 Mdot
.75684 .75292 Mdot
.749 .749 Mdot
.76076 .749 Mdot
.76076 .749 Mdot
.75684 .74116 Mdot
.77253 .74508 Mdot
.78037 .74116 Mdot
.78037 .73724 Mdot
.77645 .73724 Mdot
.76469 .72547 Mdot
.76861 .72547 Mdot
.76861 .72547 Mdot
.76469 .72155 Mdot
.76469 .71371 Mdot
.77253 .71371 Mdot
.77645 .72155 Mdot
.77253 .72155 Mdot
.77253 .71371 Mdot
.76469 .70587 Mdot
.77253 .70194 Mdot
.77253 .69802 Mdot
.78037 .70194 Mdot
.76861 .70194 Mdot
.76469 .70587 Mdot
.77253 .72155 Mdot
.76076 .70979 Mdot
.76469 .70979 Mdot
.75684 .70587 Mdot
.75292 .70587 Mdot
.76861 .70979 Mdot
.75292 .69802 Mdot
.74508 .6941 Mdot
.749 .6941 Mdot
.749 .70194 Mdot
.75684 .70979 Mdot
.73724 .69802 Mdot
.73724 .6941 Mdot
.73332 .68626 Mdot
.72939 .68234 Mdot
.73332 .69018 Mdot
.72547 .69018 Mdot
.71371 .67057 Mdot
.70587 .65881 Mdot
.70194 .63528 Mdot
.84311 .81566 Mdot
.83919 .84703 Mdot
.55686 .57646 Mdot
.57254 .60783 Mdot
.58823 .63136 Mdot
.58431 .64313 Mdot
.57254 .64705 Mdot
.57254 .65881 Mdot
.57646 .66273 Mdot
.58823 .67057 Mdot
.58823 .66665 Mdot
.59215 .66665 Mdot
.59999 .68234 Mdot
.61568 .69802 Mdot
.60783 .6941 Mdot
.62352 .6941 Mdot
.60783 .67842 Mdot
.60783 .68234 Mdot
.6196 .69018 Mdot
.6196 .69018 Mdot
.62744 .6941 Mdot
.63136 .70587 Mdot
.6392 .71371 Mdot
.64313 .71763 Mdot
.64705 .71371 Mdot
.6392 .70587 Mdot
.64313 .70587 Mdot
.6392 .70587 Mdot
.65489 .72155 Mdot
.66665 .72547 Mdot
.6745 .72939 Mdot
.67057 .72939 Mdot
.65881 .73332 Mdot
.66273 .73332 Mdot
.66665 .72547 Mdot
.67057 .72547 Mdot
.66665 .71371 Mdot
.69018 .73332 Mdot
.70587 .749 Mdot
.69802 .75684 Mdot
.69802 .75292 Mdot
.70194 .76076 Mdot
.70979 .76469 Mdot
.70587 .76076 Mdot
.70194 .77253 Mdot
.71371 .78037 Mdot
.70979 .77253 Mdot
.71371 .76861 Mdot
.72155 .76469 Mdot
.72155 .76469 Mdot
.71763 .76861 Mdot
.72155 .76861 Mdot
.72547 .76469 Mdot
.72939 .76469 Mdot
.72155 .75684 Mdot
.74116 .77645 Mdot
.73724 .77253 Mdot
.72939 .76469 Mdot
.73724 .77253 Mdot
.72155 .76076 Mdot
.73332 .76469 Mdot
.74508 .77645 Mdot
.75292 .78429 Mdot
.73724 .76861 Mdot
.74116 .76469 Mdot
.74116 .75684 Mdot
.749 .76076 Mdot
.75292 .76469 Mdot
.75292 .75684 Mdot
.75292 .749 Mdot
.749 .74116 Mdot
.75292 .749 Mdot
.75684 .76076 Mdot
.75292 .76076 Mdot
.75292 .76469 Mdot
.75292 .76076 Mdot
.75684 .76861 Mdot
.75292 .76469 Mdot
.75684 .76469 Mdot
.75684 .75684 Mdot
.75292 .75292 Mdot
.76469 .76076 Mdot
.76861 .76076 Mdot
.77253 .75292 Mdot
.76076 .74116 Mdot
.76469 .74116 Mdot
.76469 .72547 Mdot
.76469 .72547 Mdot
.76076 .71763 Mdot
.76469 .71763 Mdot
.76861 .71763 Mdot
.77645 .72155 Mdot
.77253 .71371 Mdot
.77253 .70979 Mdot
.77645 .71371 Mdot
.76861 .70979 Mdot
.77253 .71371 Mdot
.77253 .70979 Mdot
.76469 .71763 Mdot
.76076 .72939 Mdot
.75292 .73332 Mdot
.76076 .73332 Mdot
.76076 .73332 Mdot
.75684 .72155 Mdot
.75684 .71371 Mdot
.75292 .70194 Mdot
.75684 .70587 Mdot
.75292 .69802 Mdot
.75292 .69018 Mdot
.749 .68626 Mdot
.75292 .69802 Mdot
.74508 .6941 Mdot
.74116 .6941 Mdot
.72939 .68626 Mdot
.72939 .69018 Mdot
.72939 .6941 Mdot
.72547 .69018 Mdot
.71763 .67842 Mdot
.71763 .6745 Mdot
.71763 .68626 Mdot
.59215 .59215 Mdot
.59999 .58431 Mdot
.59999 .63528 Mdot
.52941 .58039 Mdot
.58039 .62744 Mdot
.58431 .6392 Mdot
.59215 .65489 Mdot
.57646 .6392 Mdot
.57254 .6392 Mdot
.56862 .64705 Mdot
.58431 .65881 Mdot
.58039 .66665 Mdot
.58039 .67057 Mdot
.58823 .68234 Mdot
.59215 .69018 Mdot
.59607 .68626 Mdot
.60391 .69018 Mdot
.61176 .6941 Mdot
.60783 .69018 Mdot
.60391 .69018 Mdot
.60391 .6941 Mdot
.61568 .70194 Mdot
.63136 .70587 Mdot
.6392 .71371 Mdot
.63136 .70979 Mdot
.6392 .71371 Mdot
.64313 .70979 Mdot
.65489 .70979 Mdot
.65097 .70979 Mdot
.65489 .71763 Mdot
.65489 .71371 Mdot
.64705 .71371 Mdot
.65881 .72547 Mdot
.64705 .72547 Mdot
.65489 .73332 Mdot
.66273 .74116 Mdot
.66273 .73724 Mdot
.66273 .74508 Mdot
.6745 .749 Mdot
.68234 .75292 Mdot
.69018 .76076 Mdot
.6941 .76469 Mdot
.71371 .76861 Mdot
.71371 .76469 Mdot
.70979 .76469 Mdot
.71371 .77645 Mdot
.71763 .78037 Mdot
.70587 .76861 Mdot
.70979 .76469 Mdot
.70979 .76076 Mdot
.71763 .76076 Mdot
.71763 .75292 Mdot
.71763 .75292 Mdot
.72155 .76076 Mdot
.71763 .75292 Mdot
.72547 .75292 Mdot
.72547 .75684 Mdot
.72939 .75684 Mdot
.72547 .75684 Mdot
.73332 .76076 Mdot
.73724 .76469 Mdot
.72547 .75684 Mdot
.73724 .76469 Mdot
.74508 .76861 Mdot
.74116 .76469 Mdot
.73332 .76076 Mdot
.73332 .76076 Mdot
.73724 .749 Mdot
.74508 .749 Mdot
.749 .74508 Mdot
.75684 .73724 Mdot
.75684 .73332 Mdot
.76076 .73332 Mdot
.76076 .72939 Mdot
.75292 .73332 Mdot
.74508 .73332 Mdot
.72547 .71763 Mdot
.75292 .73724 Mdot
.75292 .74508 Mdot
.749 .74116 Mdot
.74508 .74116 Mdot
.75292 .74508 Mdot
.75684 .75684 Mdot
.75292 .749 Mdot
.75292 .74508 Mdot
.75684 .73724 Mdot
.75684 .72939 Mdot
.76469 .72155 Mdot
.75292 .70587 Mdot
.76076 .71371 Mdot
.76076 .71371 Mdot
.76076 .71371 Mdot
.75684 .71371 Mdot
.76469 .71371 Mdot
.76861 .70979 Mdot
.76469 .70194 Mdot
.76076 .6941 Mdot
.75684 .69018 Mdot
.75292 .68234 Mdot
.749 .69018 Mdot
.75292 .70194 Mdot
.749 .70979 Mdot
.74508 .71763 Mdot
.75684 .72155 Mdot
.76076 .72155 Mdot
.76469 .71763 Mdot
.75684 .69802 Mdot
.749 .6941 Mdot
.749 .68626 Mdot
.749 .67842 Mdot
.75292 .6745 Mdot
.76076 .68234 Mdot
.75292 .6745 Mdot
.75292 .67842 Mdot
.74508 .68626 Mdot
.73724 .69018 Mdot
.73332 .68626 Mdot
.72939 .6745 Mdot
.72155 .67057 Mdot
.71763 .67842 Mdot
.71763 .67842 Mdot
.71371 .66665 Mdot
.70587 .65489 Mdot
.59999 .55294 Mdot
.3608 .34511 Mdot
.51372 .4902 Mdot
.55686 .5647 Mdot
.52549 .57254 Mdot
.55686 .6196 Mdot
.5647 .6392 Mdot
.5647 .65097 Mdot
.56078 .64705 Mdot
.55686 .6392 Mdot
.5647 .65489 Mdot
.57254 .65881 Mdot
.58039 .66665 Mdot
.58039 .67842 Mdot
.59215 .68626 Mdot
.59215 .69018 Mdot
.58823 .6941 Mdot
.61176 .70587 Mdot
.61176 .69802 Mdot
.61568 .70979 Mdot
.61568 .70979 Mdot
.6196 .70979 Mdot
.6196 .71371 Mdot
.62744 .71763 Mdot
.63528 .72155 Mdot
.63528 .72155 Mdot
.6392 .72939 Mdot
.63528 .72547 Mdot
.64313 .72547 Mdot
.65489 .72155 Mdot
.65489 .71763 Mdot
.64313 .70587 Mdot
.65489 .71763 Mdot
.65881 .72547 Mdot
.66273 .73724 Mdot
.66665 .74508 Mdot
.67057 .749 Mdot
.66665 .749 Mdot
.67842 .76076 Mdot
.66665 .75684 Mdot
.66665 .75684 Mdot
.6745 .75684 Mdot
.68234 .76076 Mdot
.69018 .76076 Mdot
.6941 .76076 Mdot
.70587 .76861 Mdot
.70979 .76861 Mdot
.70979 .77253 Mdot
.71763 .78037 Mdot
.71763 .76861 Mdot
.71763 .76076 Mdot
.72155 .76076 Mdot
.72939 .76469 Mdot
.72939 .76076 Mdot
.72547 .75684 Mdot
.72155 .75684 Mdot
.72155 .75292 Mdot
.73332 .75684 Mdot
.73332 .75292 Mdot
.72547 .75684 Mdot
.73724 .76861 Mdot
.73724 .76469 Mdot
.72547 .76469 Mdot
.72939 .76469 Mdot
.73332 .76861 Mdot
.72939 .76076 Mdot
.73724 .76469 Mdot
.72939 .75292 Mdot
.73724 .749 Mdot
.749 .75292 Mdot
.75684 .749 Mdot
.75684 .73332 Mdot
.749 .72547 Mdot
.75684 .72939 Mdot
.75684 .72547 Mdot
.76469 .72547 Mdot
.75292 .72939 Mdot
.75684 .73724 Mdot
.75684 .73724 Mdot
.76469 .749 Mdot
.75684 .73724 Mdot
.749 .73332 Mdot
.75684 .74116 Mdot
.76076 .75292 Mdot
.76469 .75684 Mdot
.76469 .75292 Mdot
.76469 .74508 Mdot
.749 .72547 Mdot
.75684 .72939 Mdot
.76861 .72939 Mdot
.76861 .72939 Mdot
.76076 .72939 Mdot
.75684 .73332 Mdot
.76861 .74116 Mdot
.749 .72547 Mdot
.76469 .72939 Mdot
.76076 .71763 Mdot
.77253 .71371 Mdot
.76861 .70979 Mdot
.76076 .70194 Mdot
.76076 .70587 Mdot
.75292 .71371 Mdot
.76076 .73332 Mdot
.76861 .74116 Mdot
.75292 .73332 Mdot
.75684 .72155 Mdot
.76076 .72155 Mdot
.749 .71371 Mdot
.74508 .71371 Mdot
.73332 .70587 Mdot
.72939 .6941 Mdot
.72939 .69018 Mdot
.74116 .68626 Mdot
.74508 .68626 Mdot
.73332 .68234 Mdot
.73724 .6941 Mdot
.74116 .70194 Mdot
.73332 .6941 Mdot
.72939 .68626 Mdot
.72547 .68626 Mdot
.72155 .6941 Mdot
.72155 .6941 Mdot
.71371 .68626 Mdot
.70587 .67057 Mdot
.71763 .65881 Mdot
.69802 .63528 Mdot
.59999 .53725 Mdot
.14513 .16865 Mdot
.19218 .1961 Mdot
.58431 .58431 Mdot
.78821 .79213 Mdot
.54509 .59607 Mdot
.57254 .6392 Mdot
.57646 .66273 Mdot
.57254 .66665 Mdot
.56078 .66273 Mdot
.55294 .65097 Mdot
.58039 .66273 Mdot
.57646 .65881 Mdot
.58039 .65881 Mdot
.57646 .66665 Mdot
.58431 .67842 Mdot
.58039 .67842 Mdot
.59607 .68626 Mdot
.60391 .69018 Mdot
.59215 .67842 Mdot
.60391 .6941 Mdot
.61176 .70194 Mdot
.62352 .70979 Mdot
.62352 .70979 Mdot
.62352 .70979 Mdot
.62744 .71371 Mdot
.63528 .72155 Mdot
.63136 .72547 Mdot
.63136 .72155 Mdot
.63528 .72155 Mdot
.63136 .72155 Mdot
.64313 .71763 Mdot
.64705 .71371 Mdot
.65489 .72155 Mdot
.65489 .72155 Mdot
.64705 .72547 Mdot
.65097 .72939 Mdot
.66665 .74116 Mdot
.66665 .73724 Mdot
.67057 .74116 Mdot
.6745 .75292 Mdot
.6745 .76076 Mdot
.6745 .75684 Mdot
.67057 .75292 Mdot
.68626 .76076 Mdot
.69018 .76076 Mdot
.6941 .76076 Mdot
.70194 .76861 Mdot
.70979 .77645 Mdot
.70194 .76861 Mdot
.70587 .76861 Mdot
.70587 .75684 Mdot
.72547 .77253 Mdot
.73332 .77645 Mdot
.73332 .76861 Mdot
.72547 .749 Mdot
.72939 .749 Mdot
.72939 .75292 Mdot
.73332 .75292 Mdot
.72939 .75292 Mdot
.72939 .75292 Mdot
.72547 .749 Mdot
.72939 .76469 Mdot
.72939 .76469 Mdot
.73332 .76861 Mdot
.73724 .76861 Mdot
.73332 .76469 Mdot
.73332 .76469 Mdot
.74116 .76861 Mdot
.73724 .76076 Mdot
.73332 .74508 Mdot
.75292 .75292 Mdot
.74508 .73724 Mdot
.74116 .73332 Mdot
.74116 .72939 Mdot
.74508 .73332 Mdot
.749 .73724 Mdot
.74508 .73724 Mdot
.74116 .73724 Mdot
.749 .74116 Mdot
.749 .74508 Mdot
.75684 .74508 Mdot
.749 .74116 Mdot
.75292 .74116 Mdot
.75292 .75292 Mdot
.76076 .76469 Mdot
.75684 .76076 Mdot
.76469 .749 Mdot
.75684 .73724 Mdot
.75292 .73332 Mdot
.75292 .72939 Mdot
.75292 .73332 Mdot
.74508 .73332 Mdot
.75292 .749 Mdot
.74508 .75292 Mdot
.749 .76076 Mdot
.749 .75292 Mdot
.749 .74116 Mdot
.749 .72939 Mdot
.74508 .72155 Mdot
.74508 .72155 Mdot
.749 .72155 Mdot
.749 .73724 Mdot
.75292 .73724 Mdot
.76076 .74508 Mdot
.76076 .749 Mdot
.76076 .74508 Mdot
.75684 .72939 Mdot
.74508 .72547 Mdot
.74116 .72155 Mdot
.74116 .72155 Mdot
.74508 .72155 Mdot
.74508 .71763 Mdot
.74508 .70587 Mdot
.74508 .70587 Mdot
.73724 .69802 Mdot
.73724 .69802 Mdot
.74508 .71371 Mdot
.73724 .70979 Mdot
.72547 .70194 Mdot
.72547 .69802 Mdot
.70979 .6941 Mdot
.70979 .69018 Mdot
.70587 .68626 Mdot
.70194 .6745 Mdot
.69802 .66665 Mdot
.6941 .65881 Mdot
.70587 .65489 Mdot
.44706 .4353 Mdot
.28629 .29413 Mdot
.18826 .20002 Mdot
.1765 .18042 Mdot
.15689 .17257 Mdot
.57646 .58823 Mdot
.78037 .78821 Mdot
.53333 .59999 Mdot
.55686 .6392 Mdot
.55686 .65881 Mdot
.5647 .6745 Mdot
.55686 .67057 Mdot
.54902 .67057 Mdot
.5647 .66273 Mdot
.57646 .67057 Mdot
.56862 .66273 Mdot
.57254 .66273 Mdot
.58823 .67842 Mdot
.60391 .6941 Mdot
.59607 .69018 Mdot
.60783 .6941 Mdot
.60783 .69018 Mdot
.60783 .68626 Mdot
.61176 .6941 Mdot
.6196 .70587 Mdot
.62352 .71371 Mdot
.63136 .71763 Mdot
.62744 .70979 Mdot
.6392 .71763 Mdot
.64705 .72547 Mdot
.6392 .72547 Mdot
.63528 .73332 Mdot
.62744 .72939 Mdot
.62744 .72155 Mdot
.63528 .71763 Mdot
.64705 .72547 Mdot
.66273 .73332 Mdot
.64705 .72939 Mdot
.64313 .72939 Mdot
.65489 .73332 Mdot
.66273 .73332 Mdot
.66273 .72939 Mdot
.66665 .74508 Mdot
.66665 .75684 Mdot
.6745 .76861 Mdot
.68234 .77645 Mdot
.67842 .76861 Mdot
.68234 .75684 Mdot
.68234 .75292 Mdot
.68626 .75292 Mdot
.69802 .76076 Mdot
.69802 .76076 Mdot
.70979 .76469 Mdot
.71371 .76861 Mdot
.72155 .76469 Mdot
.70587 .749 Mdot
.71763 .75684 Mdot
.72155 .75292 Mdot
.72547 .749 Mdot
.72155 .749 Mdot
.71371 .749 Mdot
.71763 .749 Mdot
.72547 .76076 Mdot
.72547 .76469 Mdot
.73332 .77253 Mdot
.72547 .76076 Mdot
.72547 .76469 Mdot
.72939 .77253 Mdot
.72547 .77253 Mdot
.72155 .76076 Mdot
.72939 .76076 Mdot
.73332 .77253 Mdot
.73724 .76861 Mdot
.73724 .76469 Mdot
.74508 .75684 Mdot
.74116 .75292 Mdot
.74508 .75684 Mdot
.75684 .76469 Mdot
.75292 .76861 Mdot
.749 .76076 Mdot
.74508 .749 Mdot
.74116 .74508 Mdot
.73724 .73724 Mdot
.749 .73724 Mdot
.749 .74508 Mdot
.74508 .74116 Mdot
.74116 .73724 Mdot
.74508 .749 Mdot
.75292 .75684 Mdot
.749 .75684 Mdot
.75684 .75292 Mdot
.75292 .74116 Mdot
.75292 .74116 Mdot
.75292 .74116 Mdot
.74508 .74508 Mdot
.74116 .749 Mdot
.74508 .749 Mdot
.75292 .75292 Mdot
.74116 .74508 Mdot
.74116 .749 Mdot
.74116 .74116 Mdot
.749 .74508 Mdot
.73724 .72547 Mdot
.74508 .72939 Mdot
.749 .73724 Mdot
.74116 .73724 Mdot
.74116 .74508 Mdot
.73724 .74116 Mdot
.74116 .73724 Mdot
.74508 .73724 Mdot
.74508 .72155 Mdot
.73724 .71371 Mdot
.74508 .70979 Mdot
.74116 .70194 Mdot
.73724 .6941 Mdot
.74508 .70194 Mdot
.749 .71371 Mdot
.74116 .70587 Mdot
.73724 .70194 Mdot
.73724 .69802 Mdot
.72939 .69802 Mdot
.72547 .70587 Mdot
.73724 .71763 Mdot
.72547 .70194 Mdot
.71763 .69018 Mdot
.70587 .67842 Mdot
.70194 .68626 Mdot
.70587 .68626 Mdot
.70194 .68626 Mdot
.70587 .68234 Mdot
.68626 .65881 Mdot
.58039 .56078 Mdot
.30982 .32158 Mdot
.26276 .26668 Mdot
.25492 .25492 Mdot
.21179 .23139 Mdot
.18434 .21571 Mdot
.34903 .38432 Mdot
.58431 .59999 Mdot
.51765 .60783 Mdot
.53725 .64705 Mdot
.55686 .67057 Mdot
.56078 .68234 Mdot
.55686 .67842 Mdot
.55686 .67842 Mdot
.56078 .66273 Mdot
.55686 .64705 Mdot
.56862 .64705 Mdot
.57254 .64705 Mdot
.57646 .65489 Mdot
.59999 .68234 Mdot
.59215 .68234 Mdot
.58823 .66665 Mdot
.60391 .67057 Mdot
.62352 .68626 Mdot
.6196 .69018 Mdot
.60783 .6941 Mdot
.61176 .70979 Mdot
.6196 .71763 Mdot
.62352 .71371 Mdot
.62352 .70587 Mdot
.62744 .70587 Mdot
.62744 .71371 Mdot
.63136 .72547 Mdot
.62744 .72155 Mdot
.63136 .71763 Mdot
.63528 .71371 Mdot
.65097 .71763 Mdot
.64313 .71763 Mdot
.65097 .72939 Mdot
.65881 .74116 Mdot
.66665 .74116 Mdot
.65881 .72939 Mdot
.66273 .73332 Mdot
.65881 .73332 Mdot
.67057 .749 Mdot
.67842 .76469 Mdot
.6745 .76469 Mdot
.67842 .76076 Mdot
.68626 .76469 Mdot
.68234 .749 Mdot
.69018 .75292 Mdot
.69018 .75292 Mdot
.70194 .76076 Mdot
.69802 .75292 Mdot
.70587 .749 Mdot
.71371 .75292 Mdot
.71371 .749 Mdot
.72155 .75684 Mdot
.71763 .75292 Mdot
.70979 .74508 Mdot
.70194 .73724 Mdot
.70979 .749 Mdot
.72155 .75684 Mdot
.72547 .76076 Mdot
.72547 .76469 Mdot
.72547 .76469 Mdot
.72939 .76861 Mdot
.72155 .76861 Mdot
.72547 .77253 Mdot
.72547 .77253 Mdot
.72547 .77253 Mdot
.71763 .75292 Mdot
.72155 .75684 Mdot
.72547 .76076 Mdot
.73724 .76469 Mdot
.72939 .76076 Mdot
.72939 .75292 Mdot
.74116 .75684 Mdot
.74116 .75684 Mdot
.73724 .75292 Mdot
.72547 .74116 Mdot
.73332 .72939 Mdot
.73724 .72547 Mdot
.73724 .72155 Mdot
.74116 .72547 Mdot
.74116 .73724 Mdot
.73724 .73332 Mdot
.73724 .73332 Mdot
.73332 .73332 Mdot
.74116 .74508 Mdot
.749 .75684 Mdot
.73724 .74116 Mdot
.73724 .72547 Mdot
.74508 .72939 Mdot
.73724 .73332 Mdot
.73724 .74508 Mdot
.74116 .749 Mdot
.75292 .749 Mdot
.74116 .74116 Mdot
.749 .749 Mdot
.73332 .73332 Mdot
.73332 .73332 Mdot
.74508 .73332 Mdot
.74116 .72155 Mdot
.74508 .72155 Mdot
.73724 .71763 Mdot
.73724 .72155 Mdot
.72939 .72547 Mdot
.73332 .72547 Mdot
.73724 .72939 Mdot
.72939 .72155 Mdot
.73332 .71371 Mdot
.72939 .70587 Mdot
.72939 .69802 Mdot
.73332 .69802 Mdot
.72547 .69018 Mdot
.72939 .6941 Mdot
.73724 .70587 Mdot
.73724 .70194 Mdot
.73724 .6941 Mdot
.73724 .69018 Mdot
.72939 .68234 Mdot
.72547 .68234 Mdot
.72155 .69018 Mdot
.72547 .69018 Mdot
.72155 .69018 Mdot
.71371 .68234 Mdot
.69802 .6745 Mdot
.6941 .68234 Mdot
.6941 .67842 Mdot
.6941 .67057 Mdot
.69802 .66273 Mdot
.70194 .66665 Mdot
.62744 .60783 Mdot
.48628 .5098 Mdot
.50196 .51372 Mdot
.47059 .47843 Mdot
.21963 .26276 Mdot
.1961 .21963 Mdot
.15689 .1765 Mdot
.14905 .16865 Mdot
.34903 .36472 Mdot
.56862 .56862 Mdot
.51765 .59999 Mdot
.54509 .64313 Mdot
.55294 .65881 Mdot
.54509 .66665 Mdot
.55294 .6745 Mdot
.56078 .6745 Mdot
.56078 .66273 Mdot
.56862 .65489 Mdot
.5647 .64313 Mdot
.56862 .6392 Mdot
.58431 .64313 Mdot
.58431 .64705 Mdot
.58823 .66273 Mdot
.59215 .65881 Mdot
.58823 .65489 Mdot
.59999 .6745 Mdot
.59999 .67842 Mdot
.59215 .69018 Mdot
.60391 .70194 Mdot
.61568 .70587 Mdot
.62352 .70194 Mdot
.63136 .70587 Mdot
.63136 .70587 Mdot
.62744 .70194 Mdot
.63136 .71763 Mdot
.6392 .72939 Mdot
.64705 .72547 Mdot
.64705 .71371 Mdot
.6392 .70979 Mdot
.63528 .71371 Mdot
.6392 .72547 Mdot
.66273 .74116 Mdot
.65881 .73332 Mdot
.66273 .73332 Mdot
.66273 .73332 Mdot
.67057 .73724 Mdot
.66665 .74508 Mdot
.66665 .749 Mdot
.66273 .75292 Mdot
.66665 .76076 Mdot
.66665 .75684 Mdot
.67842 .75684 Mdot
.68234 .75292 Mdot
.68626 .75292 Mdot
.69802 .75684 Mdot
.69018 .74116 Mdot
.70194 .74508 Mdot
.70979 .75292 Mdot
.71763 .75292 Mdot
.72155 .75292 Mdot
.71763 .75292 Mdot
.71763 .75292 Mdot
.71371 .75292 Mdot
.72155 .75684 Mdot
.71371 .75292 Mdot
.71763 .75292 Mdot
.71763 .75292 Mdot
.71763 .75684 Mdot
.72155 .76076 Mdot
.72155 .76861 Mdot
.72547 .77253 Mdot
.72155 .76861 Mdot
.72547 .77645 Mdot
.72155 .76861 Mdot
.72939 .76861 Mdot
.72155 .76076 Mdot
.73724 .76469 Mdot
.73332 .76469 Mdot
.73724 .76076 Mdot
.73332 .749 Mdot
.74116 .75292 Mdot
.74116 .75292 Mdot
.72939 .74508 Mdot
.72939 .73724 Mdot
.72939 .73724 Mdot
.74116 .74508 Mdot
.73724 .749 Mdot
.72547 .749 Mdot
.72547 .749 Mdot
.73724 .749 Mdot
.73332 .74116 Mdot
.73724 .74116 Mdot
.73724 .74116 Mdot
.73724 .73724 Mdot
.73332 .73332 Mdot
.72939 .73724 Mdot
.74116 .74508 Mdot
.73332 .74508 Mdot
.73724 .75292 Mdot
.73332 .75292 Mdot
.74116 .75292 Mdot
.74116 .74508 Mdot
.73724 .74116 Mdot
.73332 .73724 Mdot
.72939 .73332 Mdot
.72939 .72547 Mdot
.73724 .72939 Mdot
.73332 .72155 Mdot
.73332 .72155 Mdot
.72939 .72547 Mdot
.72547 .72547 Mdot
.73332 .72547 Mdot
.71763 .70979 Mdot
.72155 .70979 Mdot
.72155 .70979 Mdot
.73332 .72155 Mdot
.73332 .71371 Mdot
.72155 .70587 Mdot
.72939 .70587 Mdot
.72547 .69802 Mdot
.72547 .69802 Mdot
.73332 .6941 Mdot
.72547 .68626 Mdot
.72155 .67842 Mdot
.71371 .67842 Mdot
.72155 .70194 Mdot
.70979 .70979 Mdot
.70587 .70194 Mdot
.70587 .6941 Mdot
.70194 .69018 Mdot
.70194 .69018 Mdot
.69018 .68234 Mdot
.69018 .68626 Mdot
.68626 .6745 Mdot
.68234 .6745 Mdot
.67842 .67842 Mdot
.67842 .69018 Mdot
.67057 .68234 Mdot
.66665 .66273 Mdot
.57254 .56078 Mdot
.16081 .22355 Mdot
.18434 .21571 Mdot
.16081 .18434 Mdot
.1412 .16081 Mdot
.13728 .13728 Mdot
.13728 .10591 Mdot
.57646 .54902 Mdot
.78821 .77253 Mdot
.52549 .58823 Mdot
.55294 .6392 Mdot
.55294 .65881 Mdot
.54509 .66273 Mdot
.55686 .66665 Mdot
.55294 .65881 Mdot
.55686 .65881 Mdot
.55294 .65489 Mdot
.56862 .66665 Mdot
.57646 .66665 Mdot
.58823 .65881 Mdot
.59215 .65881 Mdot
.58823 .65489 Mdot
.58823 .66273 Mdot
.59215 .67057 Mdot
.59215 .67057 Mdot
.59215 .67057 Mdot
.59607 .68234 Mdot
.60391 .69018 Mdot
.61568 .6941 Mdot
.6196 .6941 Mdot
.6196 .69018 Mdot
.61568 .6941 Mdot
.62352 .70587 Mdot
.63528 .71763 Mdot
.64313 .72155 Mdot
.6392 .71763 Mdot
.63528 .72155 Mdot
.64705 .72939 Mdot
.65097 .73724 Mdot
.6392 .73724 Mdot
.65097 .73724 Mdot
.65097 .73332 Mdot
.65489 .72939 Mdot
.65881 .72939 Mdot
.67057 .73332 Mdot
.66665 .74116 Mdot
.65881 .749 Mdot
.66273 .749 Mdot
.67057 .76076 Mdot
.68234 .76469 Mdot
.6745 .76076 Mdot
.68234 .76469 Mdot
.69802 .77645 Mdot
.69802 .77253 Mdot
.70194 .76861 Mdot
.6941 .76076 Mdot
.69802 .75684 Mdot
.69802 .75684 Mdot
.70979 .76469 Mdot
.70979 .76076 Mdot
.71763 .75684 Mdot
.71763 .75292 Mdot
.71763 .75292 Mdot
.71763 .749 Mdot
.72155 .75292 Mdot
.71763 .749 Mdot
.71371 .74508 Mdot
.72547 .75684 Mdot
.72547 .75292 Mdot
.72155 .749 Mdot
.72155 .75292 Mdot
.71763 .749 Mdot
.72547 .749 Mdot
.71371 .74116 Mdot
.71763 .749 Mdot
.72547 .75292 Mdot
.72547 .749 Mdot
.72939 .75292 Mdot
.72939 .74508 Mdot
.72939 .73724 Mdot
.74116 .75292 Mdot
.74508 .75684 Mdot
.73724 .75292 Mdot
.72939 .74508 Mdot
.73332 .749 Mdot
.73332 .749 Mdot
.72155 .749 Mdot
.71763 .74508 Mdot
.72547 .749 Mdot
.73332 .74508 Mdot
.73724 .749 Mdot
.73724 .749 Mdot
.73724 .74508 Mdot
.73332 .74508 Mdot
.72547 .74116 Mdot
.72939 .749 Mdot
.73332 .75292 Mdot
.73724 .74508 Mdot
.73332 .74116 Mdot
.73332 .74508 Mdot
.73332 .74116 Mdot
.72939 .73332 Mdot
.72939 .73332 Mdot
.72547 .72547 Mdot
.73332 .72939 Mdot
.74508 .73724 Mdot
.75292 .74116 Mdot
.74116 .73724 Mdot
.74116 .74116 Mdot
.73332 .72939 Mdot
.72939 .72547 Mdot
.72155 .71763 Mdot
.71371 .71371 Mdot
.71371 .71763 Mdot
.72155 .72155 Mdot
.72939 .72939 Mdot
.72547 .72155 Mdot
.73332 .71763 Mdot
.73332 .71371 Mdot
.72547 .70587 Mdot
.71763 .70194 Mdot
.72155 .70587 Mdot
.71371 .70194 Mdot
.70587 .6941 Mdot
.71763 .71371 Mdot
.70194 .70979 Mdot
.71371 .71763 Mdot
.69802 .70587 Mdot
.69802 .70587 Mdot
.69802 .70587 Mdot
.6941 .70194 Mdot
.69018 .69802 Mdot
.68626 .68234 Mdot
.67842 .67842 Mdot
.66665 .6745 Mdot
.68234 .68234 Mdot
.6745 .6745 Mdot
.67057 .6745 Mdot
.68234 .67057 Mdot
.47059 .49412 Mdot
.34119 .38432 Mdot
.23924 .28629 Mdot
.20394 .251 Mdot
.16473 .20394 Mdot
.18042 .19218 Mdot
.22747 .20787 Mdot
.31766 .26276 Mdot
.16473 .14513 Mdot
.58431 .58823 Mdot
.78429 .78821 Mdot
.54117 .59607 Mdot
.5647 .6392 Mdot
.56862 .66273 Mdot
.56078 .66273 Mdot
.55294 .65881 Mdot
.55294 .65489 Mdot
.56078 .65881 Mdot
.56862 .66665 Mdot
.57254 .6745 Mdot
.57646 .67842 Mdot
.58823 .68234 Mdot
.58431 .66665 Mdot
.58431 .65881 Mdot
.58431 .66273 Mdot
.58823 .67842 Mdot
.59999 .68626 Mdot
.60391 .68626 Mdot
.60391 .68626 Mdot
.60391 .68626 Mdot
.61176 .69018 Mdot
.6196 .70194 Mdot
.61176 .70587 Mdot
.6196 .70979 Mdot
.62352 .71371 Mdot
.62352 .70979 Mdot
.63528 .71763 Mdot
.64313 .72547 Mdot
.63528 .72547 Mdot
.64313 .73724 Mdot
.64313 .73724 Mdot
.6392 .73724 Mdot
.64705 .73724 Mdot
.64705 .72939 Mdot
.65489 .72939 Mdot
.66273 .72547 Mdot
.66665 .72939 Mdot
.66665 .73332 Mdot
.65881 .72939 Mdot
.66665 .73724 Mdot
.67057 .75684 Mdot
.6745 .76861 Mdot
.6745 .77645 Mdot
.6745 .77253 Mdot
.68234 .77253 Mdot
.68626 .76861 Mdot
.6941 .76861 Mdot
.6941 .76861 Mdot
.70194 .77253 Mdot
.70979 .77253 Mdot
.70194 .76469 Mdot
.70979 .76861 Mdot
.71371 .76469 Mdot
.71371 .76861 Mdot
.71763 .76861 Mdot
.71763 .749 Mdot
.71763 .74116 Mdot
.72155 .74116 Mdot
.71763 .73724 Mdot
.72547 .749 Mdot
.72155 .75292 Mdot
.71763 .749 Mdot
.71763 .73724 Mdot
.70194 .73724 Mdot
.70979 .74508 Mdot
.71763 .75292 Mdot
.72155 .75684 Mdot
.72155 .75684 Mdot
.72547 .76076 Mdot
.72155 .75684 Mdot
.72547 .75684 Mdot
.73332 .75684 Mdot
.72547 .74508 Mdot
.72547 .74116 Mdot
.72939 .74508 Mdot
.72939 .749 Mdot
.72155 .74116 Mdot
.72547 .749 Mdot
.72939 .749 Mdot
.72939 .749 Mdot
.73332 .75684 Mdot
.73332 .76076 Mdot
.73332 .76469 Mdot
.72939 .75292 Mdot
.73332 .75292 Mdot
.72939 .74508 Mdot
.73332 .749 Mdot
.72547 .74508 Mdot
.72155 .73724 Mdot
.72547 .73724 Mdot
.73332 .74116 Mdot
.73332 .74508 Mdot
.73724 .749 Mdot
.72547 .72939 Mdot
.72155 .71763 Mdot
.73332 .72155 Mdot
.73332 .72939 Mdot
.73724 .74116 Mdot
.73332 .73724 Mdot
.73724 .74508 Mdot
.73724 .749 Mdot
.72939 .73724 Mdot
.73724 .73724 Mdot
.72155 .72939 Mdot
.72155 .72939 Mdot
.72155 .73724 Mdot
.70979 .72939 Mdot
.71763 .72939 Mdot
.72155 .73332 Mdot
.72155 .72547 Mdot
.71371 .71763 Mdot
.72155 .72155 Mdot
.72155 .72547 Mdot
.71371 .72155 Mdot
.71371 .72547 Mdot
.71371 .71763 Mdot
.70979 .70587 Mdot
.70194 .69802 Mdot
.69802 .6941 Mdot
.69802 .69802 Mdot
.69018 .69018 Mdot
.69018 .69802 Mdot
.6941 .69802 Mdot
.70194 .69802 Mdot
.70194 .69802 Mdot
.68626 .68626 Mdot
.67057 .6745 Mdot
.68234 .6745 Mdot
.67842 .6745 Mdot
.67842 .67842 Mdot
.67057 .66665 Mdot
.65881 .65489 Mdot
.65097 .6392 Mdot
.47843 .50196 Mdot
.40001 .44706 Mdot
.27845 .36472 Mdot
.29021 .36864 Mdot
.6392 .61568 Mdot
.5647 .54509 Mdot
.33727 .35687 Mdot
.35295 .34119 Mdot
.10199 .13728 Mdot
.30982 .34119 Mdot
.54117 .56078 Mdot
.51765 .59215 Mdot
.54902 .6392 Mdot
.56078 .65881 Mdot
.56078 .66665 Mdot
.55686 .66665 Mdot
.54509 .65881 Mdot
.55686 .66273 Mdot
.56078 .67057 Mdot
.5647 .67842 Mdot
.5647 .6745 Mdot
.56862 .67842 Mdot
.56078 .66665 Mdot
.5647 .66273 Mdot
.57646 .67842 Mdot
.57646 .6941 Mdot
.58431 .69802 Mdot
.59999 .70587 Mdot
.59999 .70587 Mdot
.60391 .69802 Mdot
.61568 .70194 Mdot
.61176 .70979 Mdot
.59999 .71371 Mdot
.61176 .72155 Mdot
.61176 .71763 Mdot
.6196 .71371 Mdot
.62352 .71371 Mdot
.62744 .71371 Mdot
.64313 .73332 Mdot
.6392 .74508 Mdot
.64313 .74508 Mdot
.64705 .74508 Mdot
.65097 .74508 Mdot
.64705 .73332 Mdot
.64313 .72547 Mdot
.64705 .73724 Mdot
.65881 .73724 Mdot
.66273 .73724 Mdot
.66273 .749 Mdot
.66273 .749 Mdot
.6745 .76076 Mdot
.66273 .76861 Mdot
.6745 .78037 Mdot
.6745 .77645 Mdot
.67842 .76861 Mdot
.6745 .76076 Mdot
.69018 .76861 Mdot
.68626 .77253 Mdot
.6941 .77645 Mdot
.69018 .77253 Mdot
.69018 .77253 Mdot
.70194 .78037 Mdot
.70587 .77645 Mdot
.71371 .77645 Mdot
.71763 .76861 Mdot
.72155 .75684 Mdot
.72547 .749 Mdot
.71371 .73332 Mdot
.71763 .749 Mdot
.71371 .749 Mdot
.71763 .75292 Mdot
.71371 .749 Mdot
.70979 .74508 Mdot
.70979 .74508 Mdot
.71371 .75292 Mdot
.71763 .76469 Mdot
.71763 .75684 Mdot
.71763 .75292 Mdot
.71763 .749 Mdot
.71371 .74508 Mdot
.71763 .749 Mdot
.72155 .75292 Mdot
.71763 .74508 Mdot
.72547 .74508 Mdot
.72547 .74116 Mdot
.72547 .749 Mdot
.72155 .74116 Mdot
.72547 .74116 Mdot
.72547 .73724 Mdot
.72939 .74508 Mdot
.74116 .75292 Mdot
.73332 .75292 Mdot
.73332 .76076 Mdot
.72547 .75292 Mdot
.72155 .75292 Mdot
.72547 .75292 Mdot
.71371 .74116 Mdot
.71763 .74508 Mdot
.72155 .74116 Mdot
.73724 .74116 Mdot
.73332 .73724 Mdot
.73332 .73724 Mdot
.72939 .73332 Mdot
.72547 .73724 Mdot
.73724 .74116 Mdot
.74116 .73332 Mdot
.73332 .72939 Mdot
.72939 .73724 Mdot
.73332 .749 Mdot
.72155 .74116 Mdot
.72939 .74508 Mdot
.72547 .73724 Mdot
.72939 .73332 Mdot
.71763 .73332 Mdot
.71763 .73724 Mdot
.72155 .74116 Mdot
.72155 .74116 Mdot
.70587 .73724 Mdot
.70194 .73332 Mdot
.70587 .72939 Mdot
.71763 .72547 Mdot
.72547 .71763 Mdot
.72939 .71763 Mdot
.72547 .71763 Mdot
.71763 .70587 Mdot
.71371 .70587 Mdot
.70587 .69802 Mdot
.69018 .68626 Mdot
.69802 .6941 Mdot
.70194 .70587 Mdot
.6941 .70979 Mdot
.6941 .70979 Mdot
.69802 .70979 Mdot
.70587 .70979 Mdot
.6941 .70194 Mdot
.68234 .69802 Mdot
.67057 .68626 Mdot
.67057 .68234 Mdot
.67842 .6941 Mdot
.68234 .6941 Mdot
.6745 .68626 Mdot
.65881 .6745 Mdot
.65489 .6745 Mdot
.64313 .67057 Mdot
.63528 .65881 Mdot
.59215 .6196 Mdot
.58039 .60391 Mdot
.59999 .61176 Mdot
.6196 .61176 Mdot
.60783 .59607 Mdot
.63528 .58823 Mdot
.3059 .31766 Mdot
.06278 .1216 Mdot
.08631 .13728 Mdot
.07846 .11376 Mdot
.30198 .3255 Mdot
.52157 .53333 Mdot
.47059 .56862 Mdot
.54117 .64705 Mdot
.54902 .66273 Mdot
.54902 .66665 Mdot
.54509 .67057 Mdot
.54902 .66273 Mdot
.55686 .66665 Mdot
.55686 .66273 Mdot
.55686 .66665 Mdot
.56078 .66665 Mdot
.55686 .66273 Mdot
.56078 .66665 Mdot
.57254 .67057 Mdot
.57254 .67057 Mdot
.57646 .67842 Mdot
.58039 .68234 Mdot
.59215 .69802 Mdot
.59999 .69802 Mdot
.59215 .68626 Mdot
.60391 .69018 Mdot
.61568 .70194 Mdot
.61568 .70194 Mdot
.60783 .70587 Mdot
.60391 .70194 Mdot
.60783 .70587 Mdot
.61176 .71371 Mdot
.61568 .72547 Mdot
.6196 .73332 Mdot
.62352 .74508 Mdot
.63136 .74508 Mdot
.64313 .749 Mdot
.65097 .749 Mdot
.65097 .74508 Mdot
.64705 .74116 Mdot
.65881 .73724 Mdot
.65097 .72547 Mdot
.66273 .74508 Mdot
.65881 .75292 Mdot
.66273 .75684 Mdot
.67842 .77253 Mdot
.67057 .76861 Mdot
.66665 .76861 Mdot
.6745 .77253 Mdot
.6745 .76861 Mdot
.68234 .76076 Mdot
.68234 .75684 Mdot
.67842 .75684 Mdot
.68626 .76861 Mdot
.68234 .76469 Mdot
.69018 .76076 Mdot
.70194 .76469 Mdot
.70194 .75684 Mdot
.70587 .75292 Mdot
.70194 .74508 Mdot
.70979 .749 Mdot
.70587 .74116 Mdot
.71371 .74508 Mdot
.71763 .749 Mdot
.70194 .74508 Mdot
.70194 .74508 Mdot
.70587 .749 Mdot
.70979 .749 Mdot
.71763 .75292 Mdot
.71763 .76469 Mdot
.70587 .76469 Mdot
.71763 .76469 Mdot
.71763 .76076 Mdot
.71371 .75292 Mdot
.71371 .749 Mdot
.71763 .74508 Mdot
.72547 .75292 Mdot
.70587 .73332 Mdot
.70979 .74116 Mdot
.72547 .75292 Mdot
.72155 .75292 Mdot
.72155 .74508 Mdot
.72155 .74116 Mdot
.71371 .73332 Mdot
.71763 .74116 Mdot
.72547 .74508 Mdot
.72939 .74508 Mdot
.72155 .73332 Mdot
.72547 .74508 Mdot
.71371 .74116 Mdot
.71371 .74116 Mdot
.71763 .74116 Mdot
.70979 .74116 Mdot
.71371 .74116 Mdot
.71371 .72939 Mdot
.72155 .72939 Mdot
.71763 .72547 Mdot
.71763 .73332 Mdot
.72547 .73724 Mdot
.73332 .74116 Mdot
.74116 .74116 Mdot
.74116 .74116 Mdot
.73332 .74116 Mdot
.72547 .73724 Mdot
.71371 .73724 Mdot
.70979 .74116 Mdot
.71371 .74116 Mdot
.71371 .73724 Mdot
.71763 .74116 Mdot
.71371 .73724 Mdot
.71371 .74116 Mdot
.70979 .73332 Mdot
.70979 .72939 Mdot
.72155 .72939 Mdot
.72155 .72547 Mdot
.71763 .71763 Mdot
.71763 .70194 Mdot
.71371 .69018 Mdot
.71371 .68626 Mdot
.70979 .68234 Mdot
.70587 .6941 Mdot
.70587 .69802 Mdot
.70587 .70587 Mdot
.69802 .69802 Mdot
.6941 .69802 Mdot
.69802 .70979 Mdot
.69018 .70979 Mdot
.69018 .71371 Mdot
.67842 .70587 Mdot
.68234 .70587 Mdot
.68234 .70194 Mdot
.67842 .69802 Mdot
.66665 .69018 Mdot
.6745 .70194 Mdot
.66665 .6941 Mdot
.65489 .68234 Mdot
.64705 .6745 Mdot
.65489 .68234 Mdot
.64705 .67842 Mdot
.65489 .68234 Mdot
.64313 .66665 Mdot
.6392 .65881 Mdot
.63136 .65097 Mdot
.63136 .64313 Mdot
.62352 .63528 Mdot
.60783 .61176 Mdot
.58039 .56078 Mdot
.31374 .33335 Mdot
.18434 .21571 Mdot
.14513 .16865 Mdot
.10591 .13336 Mdot
.07454 .10199 Mdot
.11376 .12552 Mdot
.60391 .59999 Mdot
.78429 .78821 Mdot
.49412 .57254 Mdot
.53725 .63136 Mdot
.55294 .66273 Mdot
.55294 .6745 Mdot
.54509 .67057 Mdot
.54117 .66273 Mdot
.55294 .65489 Mdot
.5647 .65097 Mdot
.57646 .65489 Mdot
.5647 .64705 Mdot
.56862 .65881 Mdot
.56078 .65881 Mdot
.56862 .67057 Mdot
.57646 .6745 Mdot
.57646 .6745 Mdot
.58823 .68234 Mdot
.59215 .69018 Mdot
.57646 .68234 Mdot
.58431 .68626 Mdot
.58431 .68234 Mdot
.58039 .6745 Mdot
.59607 .68234 Mdot
.59999 .67842 Mdot
.60391 .68234 Mdot
.59999 .69018 Mdot
.60783 .70194 Mdot
.6196 .71763 Mdot
.61568 .71371 Mdot
.62744 .72155 Mdot
.63528 .73724 Mdot
.63136 .73332 Mdot
.63528 .73332 Mdot
.64313 .72155 Mdot
.64313 .70979 Mdot
.65097 .70979 Mdot
.64705 .71763 Mdot
.65489 .72939 Mdot
.65097 .73724 Mdot
.64705 .74116 Mdot
.65881 .749 Mdot
.66273 .749 Mdot
.66665 .75292 Mdot
.6745 .76076 Mdot
.67842 .76076 Mdot
.6745 .75292 Mdot
.66665 .73724 Mdot
.68234 .74508 Mdot
.6745 .74116 Mdot
.69018 .749 Mdot
.68234 .749 Mdot
.68626 .74508 Mdot
.6941 .73724 Mdot
.6941 .72547 Mdot
.70194 .73332 Mdot
.6941 .73332 Mdot
.69802 .74116 Mdot
.6941 .73724 Mdot
.70194 .74508 Mdot
.6941 .73724 Mdot
.69802 .73724 Mdot
.70979 .74508 Mdot
.70587 .74508 Mdot
.71371 .75684 Mdot
.70194 .75684 Mdot
.69802 .75684 Mdot
.6941 .75292 Mdot
.70979 .75684 Mdot
.70587 .75292 Mdot
.69802 .74508 Mdot
.70587 .74116 Mdot
.70587 .73724 Mdot
.71371 .74116 Mdot
.71371 .74508 Mdot
.70194 .74116 Mdot
.70979 .74116 Mdot
.70979 .74116 Mdot
.71371 .74116 Mdot
.70587 .74116 Mdot
.71763 .74508 Mdot
.71763 .74116 Mdot
.71763 .73724 Mdot
.71371 .73724 Mdot
.71371 .73332 Mdot
.70979 .74116 Mdot
.70587 .73724 Mdot
.71371 .74508 Mdot
.70979 .74508 Mdot
.70979 .74116 Mdot
.71371 .73332 Mdot
.71763 .73724 Mdot
.71371 .73724 Mdot
.71763 .73332 Mdot
.71763 .73332 Mdot
.72155 .73332 Mdot
.71371 .72939 Mdot
.70979 .73332 Mdot
.71763 .74116 Mdot
.70587 .73724 Mdot
.70979 .73724 Mdot
.70979 .73332 Mdot
.70979 .73332 Mdot
.70587 .72939 Mdot
.70194 .72155 Mdot
.69802 .72155 Mdot
.70587 .72939 Mdot
.69802 .72939 Mdot
.70194 .72547 Mdot
.70587 .71763 Mdot
.70194 .70587 Mdot
.70194 .70587 Mdot
.71763 .70587 Mdot
.70979 .68626 Mdot
.71763 .68234 Mdot
.70194 .68626 Mdot
.70979 .69802 Mdot
.70587 .70194 Mdot
.70194 .70587 Mdot
.6941 .69802 Mdot
.69018 .6941 Mdot
.68234 .68626 Mdot
.68626 .70194 Mdot
.6745 .70587 Mdot
.65881 .70587 Mdot
.66273 .70587 Mdot
.67057 .69802 Mdot
.66665 .69802 Mdot
.67057 .70979 Mdot
.65881 .70587 Mdot
.65881 .70587 Mdot
.65881 .70194 Mdot
.65881 .69018 Mdot
.64705 .67842 Mdot
.6392 .6745 Mdot
.6392 .67057 Mdot
.63136 .66273 Mdot
.62744 .66273 Mdot
.62744 .65881 Mdot
.62352 .65881 Mdot
.62352 .65881 Mdot
.60783 .6392 Mdot
.61568 .62352 Mdot
.59607 .58823 Mdot
.58039 .54902 Mdot
.44314 .43138 Mdot
.20002 .24316 Mdot
.19218 .22747 Mdot
.14905 .18042 Mdot
.1961 .20787 Mdot
.21571 .21963 Mdot
.17257 .19218 Mdot
.57254 .58823 Mdot
.78429 .79213 Mdot
.5098 .5647 Mdot
.53333 .61176 Mdot
.54902 .64705 Mdot
.54902 .65881 Mdot
.55294 .66273 Mdot
.54117 .64705 Mdot
.54902 .6392 Mdot
.55686 .6392 Mdot
.54902 .63136 Mdot
.54902 .63528 Mdot
.54509 .63136 Mdot
.55294 .64705 Mdot
.55294 .65097 Mdot
.5647 .65881 Mdot
.57254 .66665 Mdot
.57646 .6745 Mdot
.58823 .68626 Mdot
.57646 .67842 Mdot
.58039 .67842 Mdot
.58823 .67842 Mdot
.58039 .67057 Mdot
.58431 .67057 Mdot
.59607 .68234 Mdot
.59999 .69018 Mdot
.59999 .6941 Mdot
.59215 .68626 Mdot
.58823 .68626 Mdot
.60391 .69802 Mdot
.61568 .70587 Mdot
.62352 .71371 Mdot
.6196 .70979 Mdot
.63136 .71763 Mdot
.6196 .70587 Mdot
.63528 .70587 Mdot
.65489 .71371 Mdot
.64705 .71371 Mdot
.6392 .71763 Mdot
.63528 .72155 Mdot
.64313 .72547 Mdot
.65881 .73724 Mdot
.65097 .72939 Mdot
.66273 .73724 Mdot
.66273 .749 Mdot
.65881 .74508 Mdot
.67842 .749 Mdot
.6745 .74116 Mdot
.67057 .72939 Mdot
.68626 .73724 Mdot
.6745 .73724 Mdot
.6745 .73332 Mdot
.6745 .72547 Mdot
.68234 .72939 Mdot
.69018 .72547 Mdot
.69802 .72939 Mdot
.69802 .72939 Mdot
.6941 .73332 Mdot
.68626 .73332 Mdot
.68626 .74116 Mdot
.68626 .73724 Mdot
.69018 .73724 Mdot
.6941 .73724 Mdot
.68626 .74116 Mdot
.68234 .74116 Mdot
.6941 .749 Mdot
.68234 .73332 Mdot
.68234 .74116 Mdot
.6941 .74508 Mdot
.69802 .74116 Mdot
.69802 .749 Mdot
.70194 .749 Mdot
.69802 .73724 Mdot
.69802 .73724 Mdot
.69802 .73724 Mdot
.69018 .72939 Mdot
.69802 .72939 Mdot
.70194 .72939 Mdot
.69802 .72155 Mdot
.69802 .72547 Mdot
.70194 .72547 Mdot
.71371 .73332 Mdot
.70587 .73724 Mdot
.70587 .73724 Mdot
.6941 .72939 Mdot
.69018 .72547 Mdot
.70587 .72939 Mdot
.70587 .72939 Mdot
.70979 .73332 Mdot
.69018 .72155 Mdot
.6941 .72155 Mdot
.6941 .72547 Mdot
.69802 .72939 Mdot
.70194 .72547 Mdot
.70194 .71763 Mdot
.71371 .72939 Mdot
.70979 .72939 Mdot
.70587 .73724 Mdot
.69802 .73332 Mdot
.70194 .74116 Mdot
.70587 .73724 Mdot
.70194 .72547 Mdot
.70194 .71763 Mdot
.6941 .71371 Mdot
.6941 .71371 Mdot
.69802 .71763 Mdot
.69802 .72155 Mdot
.69018 .72547 Mdot
.70194 .73332 Mdot
.69018 .71763 Mdot
.70194 .71763 Mdot
.70194 .71763 Mdot
.6941 .70587 Mdot
.69802 .70194 Mdot
.69802 .69802 Mdot
.6941 .69018 Mdot
.68626 .68234 Mdot
.67842 .6745 Mdot
.68626 .68626 Mdot
.69018 .68626 Mdot
.68234 .68234 Mdot
.67057 .68234 Mdot
.6745 .6941 Mdot
.66665 .6941 Mdot
.66273 .69802 Mdot
.65881 .6941 Mdot
.64313 .67842 Mdot
.65097 .68626 Mdot
.65097 .68626 Mdot
.65097 .69018 Mdot
.64313 .68626 Mdot
.64705 .6745 Mdot
.6392 .65881 Mdot
.62744 .65881 Mdot
.62352 .65881 Mdot
.6196 .65489 Mdot
.6196 .65489 Mdot
.61568 .65097 Mdot
.61568 .64313 Mdot
.60783 .62744 Mdot
.59607 .62352 Mdot
.59215 .62744 Mdot
.59999 .62352 Mdot
.58823 .60391 Mdot
.58431 .59607 Mdot
.58431 .58823 Mdot
.51765 .52941 Mdot
.49804 .50196 Mdot
.43922 .45491 Mdot
.40001 .41569 Mdot
.26276 .30198 Mdot
.20394 .26276 Mdot
.25884 .30198 Mdot
.35295 .35687 Mdot
.42746 .43922 Mdot
.53333 .55686 Mdot
.48628 .52549 Mdot
.54509 .60391 Mdot
.55294 .6392 Mdot
.55686 .65097 Mdot
.54117 .64705 Mdot
.55294 .64705 Mdot
.54509 .63528 Mdot
.54902 .63136 Mdot
.54509 .63136 Mdot
.55686 .65097 Mdot
.55686 .65489 Mdot
.55294 .65489 Mdot
.54902 .65489 Mdot
.56078 .65489 Mdot
.56862 .65881 Mdot
.57254 .66665 Mdot
.57646 .67842 Mdot
.57646 .68234 Mdot
.58431 .68234 Mdot
.58431 .6745 Mdot
.58823 .6745 Mdot
.59215 .67842 Mdot
.60391 .6941 Mdot
.59215 .69018 Mdot
.59999 .6941 Mdot
.59215 .6941 Mdot
.59999 .70194 Mdot
.59607 .69802 Mdot
.60783 .70194 Mdot
.62352 .70979 Mdot
.62352 .71371 Mdot
.62352 .71763 Mdot
.62744 .71371 Mdot
.6196 .70587 Mdot
.62744 .70587 Mdot
.63136 .70979 Mdot
.62744 .71371 Mdot
.63528 .71763 Mdot
.64705 .72939 Mdot
.65489 .72939 Mdot
.66273 .72939 Mdot
.66273 .73332 Mdot
.66273 .74116 Mdot
.65097 .74508 Mdot
.65881 .749 Mdot
.67057 .75292 Mdot
.67057 .74508 Mdot
.6745 .74116 Mdot
.67842 .74508 Mdot
.67842 .74508 Mdot
.67057 .73724 Mdot
.67842 .73724 Mdot
.6745 .72939 Mdot
.6745 .72547 Mdot
.68234 .73724 Mdot
.68626 .749 Mdot
.68626 .74508 Mdot
.68626 .74508 Mdot
.68234 .73724 Mdot
.69018 .74116 Mdot
.69018 .74116 Mdot
.68234 .73724 Mdot
.67842 .74116 Mdot
.68626 .749 Mdot
.69018 .749 Mdot
.6941 .75292 Mdot
.69802 .749 Mdot
.69802 .749 Mdot
.67842 .74508 Mdot
.68234 .74116 Mdot
.67842 .73724 Mdot
.68626 .74116 Mdot
.69018 .73332 Mdot
.68626 .72939 Mdot
.68626 .72939 Mdot
.6941 .73724 Mdot
.69802 .73724 Mdot
.70194 .73724 Mdot
.6941 .72939 Mdot
.70194 .72939 Mdot
.69802 .73332 Mdot
.70194 .73724 Mdot
.6941 .73332 Mdot
.70194 .72939 Mdot
.70194 .72939 Mdot
.69802 .72547 Mdot
.70194 .72939 Mdot
.6941 .73724 Mdot
.69018 .73724 Mdot
.6941 .73332 Mdot
.69802 .73724 Mdot
.6941 .72939 Mdot
.69018 .72155 Mdot
.6941 .72547 Mdot
.70587 .73724 Mdot
.70979 .749 Mdot
.70194 .74116 Mdot
.69802 .75292 Mdot
.70194 .74508 Mdot
.69018 .72939 Mdot
.6941 .71763 Mdot
.70587 .72155 Mdot
.70587 .72939 Mdot
.69802 .73332 Mdot
.6941 .73332 Mdot
.6941 .73332 Mdot
.69018 .72547 Mdot
.68626 .71371 Mdot
.68234 .70979 Mdot
.68626 .70979 Mdot
.6941 .72155 Mdot
.6941 .71763 Mdot
.67842 .70194 Mdot
.69018 .70587 Mdot
.68234 .70194 Mdot
.6745 .69802 Mdot
.6745 .69802 Mdot
.68626 .69802 Mdot
.67842 .68626 Mdot
.6745 .68626 Mdot
.66665 .69018 Mdot
.65881 .69018 Mdot
.66273 .69802 Mdot
.65881 .6941 Mdot
.65097 .69018 Mdot
.65489 .6941 Mdot
.65097 .6941 Mdot
.6392 .67842 Mdot
.6392 .6745 Mdot
.64313 .6745 Mdot
.64313 .6745 Mdot
.63528 .66665 Mdot
.63528 .66665 Mdot
.6392 .66665 Mdot
.6392 .66273 Mdot
.62352 .65489 Mdot
.61568 .64705 Mdot
.62352 .64705 Mdot
.61568 .63528 Mdot
.61568 .62744 Mdot
.60783 .6196 Mdot
.59999 .61176 Mdot
.59607 .61176 Mdot
.58431 .60783 Mdot
.58039 .60391 Mdot
.5647 .58823 Mdot
.56078 .58039 Mdot
.55294 .57254 Mdot
.52549 .54902 Mdot
.51765 .54902 Mdot
.52157 .55686 Mdot
.53333 .56078 Mdot
.45883 .47843 Mdot
.15689 .22747 Mdot
.23924 .25884 Mdot
.28629 .32943 Mdot
.52157 .54117 Mdot
.48628 .52549 Mdot
.52549 .58431 Mdot
.54902 .61568 Mdot
.55686 .6392 Mdot
.54117 .64705 Mdot
.54509 .65489 Mdot
.54902 .65489 Mdot
.54902 .65489 Mdot
.54902 .65097 Mdot
.54902 .64705 Mdot
.54902 .64705 Mdot
.54902 .65097 Mdot
.55294 .65881 Mdot
.55294 .65489 Mdot
.57254 .65881 Mdot
.56862 .65881 Mdot
.57646 .66665 Mdot
.58431 .6745 Mdot
.58431 .67842 Mdot
.58431 .6745 Mdot
.58823 .6745 Mdot
.58823 .6745 Mdot
.59215 .68234 Mdot
.58431 .68234 Mdot
.58431 .69018 Mdot
.58431 .6941 Mdot
.59215 .70194 Mdot
.58823 .70587 Mdot
.60391 .70587 Mdot
.61176 .70979 Mdot
.61176 .70979 Mdot
.60783 .72547 Mdot
.61568 .72547 Mdot
.61176 .71763 Mdot
.6196 .72547 Mdot
.62352 .71763 Mdot
.6196 .71371 Mdot
.62744 .72155 Mdot
.62744 .72939 Mdot
.63528 .74116 Mdot
.64313 .74116 Mdot
.64313 .73332 Mdot
.65489 .74116 Mdot
.65097 .74508 Mdot
.65097 .749 Mdot
.65489 .74508 Mdot
.67057 .749 Mdot
.66273 .72939 Mdot
.66665 .74116 Mdot
.6745 .749 Mdot
.6745 .749 Mdot
.67057 .74508 Mdot
.67057 .74116 Mdot
.6745 .74508 Mdot
.6745 .749 Mdot
.67057 .74508 Mdot
.67842 .749 Mdot
.68234 .74508 Mdot
.68234 .74508 Mdot
.67842 .74116 Mdot
.68626 .74508 Mdot
.68234 .75292 Mdot
.6745 .75684 Mdot
.68234 .76076 Mdot
.68626 .76076 Mdot
.68626 .75684 Mdot
.68626 .75684 Mdot
.68626 .749 Mdot
.69018 .749 Mdot
.69018 .749 Mdot
.68626 .74116 Mdot
.68234 .72939 Mdot
.68626 .72547 Mdot
.68626 .72939 Mdot
.69802 .74116 Mdot
.70194 .74116 Mdot
.69802 .74508 Mdot
.68626 .749 Mdot
.6941 .76076 Mdot
.69802 .76076 Mdot
.69802 .75684 Mdot
.69802 .75292 Mdot
.68626 .73332 Mdot
.68626 .72547 Mdot
.6941 .73332 Mdot
.6941 .72939 Mdot
.69018 .72547 Mdot
.69018 .73724 Mdot
.67842 .74116 Mdot
.6941 .749 Mdot
.69802 .75684 Mdot
.69802 .75292 Mdot
.6941 .749 Mdot
.68626 .73724 Mdot
.68234 .72939 Mdot
.6941 .73332 Mdot
.69018 .73332 Mdot
.6941 .73724 Mdot
.69802 .73724 Mdot
.6941 .73332 Mdot
.68626 .73332 Mdot
.69018 .73332 Mdot
.6941 .74116 Mdot
.6941 .74116 Mdot
.6941 .749 Mdot
.68234 .73332 Mdot
.68626 .72939 Mdot
.68626 .72155 Mdot
.67842 .70979 Mdot
.68234 .70979 Mdot
.67842 .71371 Mdot
.68234 .71763 Mdot
.69018 .71763 Mdot
.69018 .72155 Mdot
.67842 .72155 Mdot
.66665 .70979 Mdot
.66665 .70587 Mdot
.66273 .70194 Mdot
.66273 .69802 Mdot
.66665 .6941 Mdot
.65489 .69802 Mdot
.66273 .71371 Mdot
.65881 .71763 Mdot
.65881 .71371 Mdot
.66273 .71371 Mdot
.66273 .70979 Mdot
.64705 .70194 Mdot
.63528 .69018 Mdot
.64313 .68626 Mdot
.63136 .67842 Mdot
.63136 .6745 Mdot
.63136 .6745 Mdot
.63136 .66273 Mdot
.62744 .66273 Mdot
.61568 .65881 Mdot
.61176 .66665 Mdot
.60783 .65881 Mdot
.61176 .65097 Mdot
.61568 .64705 Mdot
.60783 .63528 Mdot
.59999 .6196 Mdot
.59999 .61176 Mdot
.60391 .6196 Mdot
.59607 .61568 Mdot
.58823 .60391 Mdot
.57254 .58431 Mdot
.5647 .57646 Mdot
.5647 .57646 Mdot
.56078 .57254 Mdot
.54509 .57254 Mdot
.54117 .58039 Mdot
.52941 .57254 Mdot
.53725 .56862 Mdot
.4902 .52157 Mdot
.50588 .50588 Mdot
.251 .28237 Mdot
.10199 .15297 Mdot
.07062 .09807 Mdot
.5098 .52157 Mdot
.75292 .75684 Mdot
.48628 .51372 Mdot
.54117 .58431 Mdot
.54509 .61176 Mdot
.54509 .62744 Mdot
.54117 .64705 Mdot
.53333 .65097 Mdot
.51372 .64313 Mdot
.52157 .65097 Mdot
.53333 .65489 Mdot
.54902 .65489 Mdot
.54509 .64313 Mdot
.54902 .64705 Mdot
.54509 .65489 Mdot
.55294 .65489 Mdot
.56078 .65097 Mdot
.5647 .64313 Mdot
.57646 .6392 Mdot
.58039 .64313 Mdot
.56862 .64705 Mdot
.57646 .67057 Mdot
.57646 .67057 Mdot
.58039 .6745 Mdot
.58823 .67842 Mdot
.58823 .68234 Mdot
.58431 .69018 Mdot
.58431 .70194 Mdot
.57646 .70194 Mdot
.58431 .70979 Mdot
.58823 .69802 Mdot
.59607 .69802 Mdot
.60391 .70587 Mdot
.59999 .71371 Mdot
.60783 .72547 Mdot
.60391 .72547 Mdot
.60783 .73332 Mdot
.61568 .72939 Mdot
.61568 .70979 Mdot
.6196 .71371 Mdot
.62744 .72547 Mdot
.62744 .72939 Mdot
.62744 .72547 Mdot
.63136 .72547 Mdot
.64313 .72939 Mdot
.65489 .74508 Mdot
.65097 .74116 Mdot
.65489 .74116 Mdot
.66273 .74116 Mdot
.66665 .74116 Mdot
.66273 .73724 Mdot
.66273 .73724 Mdot
.66665 .74508 Mdot
.66665 .75292 Mdot
.65881 .749 Mdot
.66273 .75292 Mdot
.67057 .75684 Mdot
.65881 .74508 Mdot
.66273 .75684 Mdot
.6745 .75684 Mdot
.6745 .75684 Mdot
.6745 .749 Mdot
.67842 .73724 Mdot
.6745 .74508 Mdot
.66665 .749 Mdot
.66665 .75292 Mdot
.6745 .749 Mdot
.6745 .74508 Mdot
.6745 .73724 Mdot
.67842 .749 Mdot
.67057 .74116 Mdot
.6745 .73724 Mdot
.67842 .73332 Mdot
.68234 .72547 Mdot
.69018 .72155 Mdot
.6941 .73332 Mdot
.6745 .72155 Mdot
.67842 .73724 Mdot
.68234 .75684 Mdot
.68626 .76861 Mdot
.68234 .76469 Mdot
.68234 .76469 Mdot
.6745 .75684 Mdot
.67057 .75292 Mdot
.66665 .74508 Mdot
.6745 .73332 Mdot
.68234 .73332 Mdot
.68626 .73724 Mdot
.67842 .72547 Mdot
.6745 .72547 Mdot
.67842 .72939 Mdot
.67057 .73332 Mdot
.6745 .74508 Mdot
.68234 .74116 Mdot
.67842 .73724 Mdot
.67842 .73332 Mdot
.6745 .72547 Mdot
.67842 .72939 Mdot
.68626 .73332 Mdot
.68234 .72547 Mdot
.68626 .72939 Mdot
.68234 .73332 Mdot
.67057 .71763 Mdot
.68234 .72547 Mdot
.68234 .72939 Mdot
.68234 .72939 Mdot
.6745 .72547 Mdot
.67057 .72155 Mdot
.68234 .72155 Mdot
.6745 .71371 Mdot
.67842 .71371 Mdot
.6745 .70979 Mdot
.67057 .70979 Mdot
.66273 .71371 Mdot
.66273 .71371 Mdot
.65881 .70194 Mdot
.67057 .70979 Mdot
.66665 .71371 Mdot
.65097 .70587 Mdot
.64313 .70194 Mdot
.64705 .68626 Mdot
.65097 .68234 Mdot
.65097 .68234 Mdot
.65097 .70194 Mdot
.65097 .71763 Mdot
.63136 .70979 Mdot
.64313 .71371 Mdot
.63136 .69802 Mdot
.62744 .68626 Mdot
.64313 .70587 Mdot
.63528 .69802 Mdot
.63528 .6941 Mdot
.63528 .68626 Mdot
.63136 .67057 Mdot
.62744 .65881 Mdot
.6196 .65489 Mdot
.61176 .66273 Mdot
.61568 .66273 Mdot
.60391 .65489 Mdot
.60783 .64313 Mdot
.61176 .62744 Mdot
.60391 .61176 Mdot
.59999 .60783 Mdot
.59607 .6196 Mdot
.59215 .62744 Mdot
.58823 .61568 Mdot
.58431 .60783 Mdot
.55686 .57646 Mdot
.56862 .58431 Mdot
.56862 .58431 Mdot
.5647 .59215 Mdot
.54902 .58823 Mdot
.55294 .58431 Mdot
.55294 .57646 Mdot
.54117 .55686 Mdot
.53333 .54509 Mdot
.5098 .52157 Mdot
.54902 .53333 Mdot
.25492 .27845 Mdot
.04709 .09415 Mdot
.03533 .0667 Mdot
.01965 .04709 Mdot
.48628 .53333 Mdot
.54117 .59607 Mdot
.55294 .62352 Mdot
.54509 .64705 Mdot
.54117 .66665 Mdot
.53333 .66273 Mdot
.52157 .65097 Mdot
.52941 .64705 Mdot
.53333 .64313 Mdot
.53725 .6392 Mdot
.54902 .64705 Mdot
.54902 .65097 Mdot
.54902 .66273 Mdot
.56078 .67057 Mdot
.58039 .6745 Mdot
.57254 .65097 Mdot
.58039 .65097 Mdot
.57646 .64705 Mdot
.56862 .65489 Mdot
.58431 .67842 Mdot
.58039 .69018 Mdot
.58039 .69018 Mdot
.58823 .68626 Mdot
.57646 .6745 Mdot
.58431 .69018 Mdot
.57254 .70194 Mdot
.58039 .71371 Mdot
.58823 .70979 Mdot
.59607 .69802 Mdot
.60391 .6941 Mdot
.61568 .70979 Mdot
.58823 .6941 Mdot
.60391 .71763 Mdot
.60783 .72547 Mdot
.60391 .72547 Mdot
.61176 .72155 Mdot
.61176 .70587 Mdot
.6196 .70587 Mdot
.62352 .70587 Mdot
.6196 .70194 Mdot
.63528 .70979 Mdot
.63528 .71371 Mdot
.6392 .71763 Mdot
.64705 .72547 Mdot
.65097 .73332 Mdot
.6392 .72547 Mdot
.65489 .73724 Mdot
.66665 .72939 Mdot
.66665 .72547 Mdot
.66273 .73332 Mdot
.65489 .73724 Mdot
.65489 .74508 Mdot
.66273 .75684 Mdot
.66665 .75292 Mdot
.65489 .74116 Mdot
.65881 .74116 Mdot
.65881 .73724 Mdot
.66665 .75292 Mdot
.66665 .76076 Mdot
.67057 .75684 Mdot
.67842 .749 Mdot
.6745 .74508 Mdot
.66665 .749 Mdot
.6745 .75292 Mdot
.6745 .74116 Mdot
.67057 .73332 Mdot
.68234 .73724 Mdot
.67842 .73724 Mdot
.6745 .73724 Mdot
.6745 .72939 Mdot
.67057 .71763 Mdot
.67842 .70979 Mdot
.68234 .71371 Mdot
.6745 .71763 Mdot
.67842 .72939 Mdot
.67842 .74508 Mdot
.67842 .75684 Mdot
.67057 .75292 Mdot
.67057 .75684 Mdot
.6745 .76469 Mdot
.66665 .75684 Mdot
.67057 .75684 Mdot
.6745 .75292 Mdot
.6745 .73724 Mdot
.68234 .73724 Mdot
.68234 .72939 Mdot
.67057 .72547 Mdot
.66273 .72155 Mdot
.67842 .72547 Mdot
.67842 .72547 Mdot
.6745 .73724 Mdot
.67057 .72939 Mdot
.6745 .72939 Mdot
.68234 .73332 Mdot
.6745 .72939 Mdot
.6745 .72939 Mdot
.67842 .72547 Mdot
.67842 .72547 Mdot
.67057 .72939 Mdot
.68234 .73332 Mdot
.68234 .72939 Mdot
.68234 .72547 Mdot
.67842 .71763 Mdot
.68234 .71763 Mdot
.6745 .72547 Mdot
.67842 .72547 Mdot
.67842 .72155 Mdot
.67842 .71763 Mdot
.68234 .71763 Mdot
.6745 .70979 Mdot
.67057 .71371 Mdot
.65881 .70587 Mdot
.66665 .70587 Mdot
.66665 .70587 Mdot
.65881 .70587 Mdot
.65489 .70979 Mdot
.65097 .70587 Mdot
.65097 .70587 Mdot
.65489 .70587 Mdot
.64313 .6941 Mdot
.6392 .69018 Mdot
.65097 .70194 Mdot
.63528 .70979 Mdot
.64313 .72547 Mdot
.6392 .71763 Mdot
.63528 .70194 Mdot
.63136 .6941 Mdot
.6392 .69802 Mdot
.6392 .70194 Mdot
.62352 .68234 Mdot
.62744 .68234 Mdot
.62744 .67842 Mdot
.61176 .66665 Mdot
.6196 .6745 Mdot
.6196 .67057 Mdot
.61568 .6745 Mdot
.60783 .66273 Mdot
.60783 .64705 Mdot
.60391 .63136 Mdot
.60391 .62352 Mdot
.59607 .61568 Mdot
.59607 .62352 Mdot
.58039 .6196 Mdot
.58039 .6196 Mdot
.58823 .61568 Mdot
.5647 .58431 Mdot
.56078 .57646 Mdot
.5647 .58431 Mdot
.55686 .59215 Mdot
.54509 .59215 Mdot
.54509 .58823 Mdot
.53725 .5647 Mdot
.52549 .54117 Mdot
.52941 .54117 Mdot
.5098 .52549 Mdot
.51765 .52941 Mdot
.51765 .51765 Mdot
.1961 .26668 Mdot
.14905 .21963 Mdot
.1216 .18434 Mdot
.47843 .54509 Mdot
.54509 .6196 Mdot
.56078 .64705 Mdot
.54509 .65097 Mdot
.54117 .66273 Mdot
.52941 .66273 Mdot
.53333 .65881 Mdot
.54509 .65489 Mdot
.56078 .65097 Mdot
.5647 .64705 Mdot
.55294 .65097 Mdot
.55294 .65881 Mdot
.55686 .66273 Mdot
.56862 .67057 Mdot
.57254 .66665 Mdot
.57646 .65881 Mdot
.58431 .65489 Mdot
.58431 .66665 Mdot
.57254 .67057 Mdot
.57646 .68234 Mdot
.58039 .6941 Mdot
.58039 .6941 Mdot
.58431 .68626 Mdot
.58823 .68234 Mdot
.58823 .68234 Mdot
.59215 .69802 Mdot
.59215 .69802 Mdot
.58431 .69018 Mdot
.59607 .69018 Mdot
.61176 .6941 Mdot
.60391 .68626 Mdot
.59607 .68626 Mdot
.60391 .70194 Mdot
.60391 .70979 Mdot
.60783 .71763 Mdot
.60391 .70587 Mdot
.61568 .70979 Mdot
.61568 .70979 Mdot
.6196 .70979 Mdot
.62352 .71371 Mdot
.6392 .71763 Mdot
.6392 .70194 Mdot
.64705 .70194 Mdot
.64705 .71371 Mdot
.65489 .73332 Mdot
.65489 .74508 Mdot
.65489 .74116 Mdot
.65489 .73332 Mdot
.66273 .73724 Mdot
.67842 .75292 Mdot
.65881 .74508 Mdot
.66273 .75292 Mdot
.66273 .749 Mdot
.66665 .749 Mdot
.6745 .75292 Mdot
.6745 .749 Mdot
.67842 .75292 Mdot
.67057 .75684 Mdot
.66273 .76076 Mdot
.66273 .75684 Mdot
.66665 .75292 Mdot
.66665 .74116 Mdot
.66665 .73332 Mdot
.67842 .73724 Mdot
.68626 .749 Mdot
.67842 .74116 Mdot
.6745 .73724 Mdot
.6745 .74116 Mdot
.67842 .74508 Mdot
.66273 .73332 Mdot
.67057 .72939 Mdot
.67057 .72155 Mdot
.68234 .72155 Mdot
.66665 .71763 Mdot
.67842 .72547 Mdot
.68234 .74508 Mdot
.68626 .75684 Mdot
.67057 .75292 Mdot
.67057 .75684 Mdot
.66273 .75292 Mdot
.6745 .75684 Mdot
.67842 .76861 Mdot
.6745 .76469 Mdot
.67842 .75292 Mdot
.67842 .74116 Mdot
.68626 .74508 Mdot
.68234 .749 Mdot
.68234 .75292 Mdot
.69018 .75292 Mdot
.68626 .749 Mdot
.67842 .74116 Mdot
.68234 .73332 Mdot
.68626 .72939 Mdot
.6745 .72939 Mdot
.67842 .73332 Mdot
.6745 .73332 Mdot
.67842 .72939 Mdot
.6745 .72939 Mdot
.68234 .74508 Mdot
.6745 .73332 Mdot
.67842 .72939 Mdot
.67842 .73332 Mdot
.6941 .749 Mdot
.69018 .74508 Mdot
.6941 .74508 Mdot
.68234 .74116 Mdot
.68234 .73724 Mdot
.68234 .72939 Mdot
.6745 .71371 Mdot
.67057 .70979 Mdot
.67842 .71763 Mdot
.67842 .71763 Mdot
.67057 .70979 Mdot
.67057 .71371 Mdot
.66273 .70587 Mdot
.64705 .69802 Mdot
.65097 .70194 Mdot
.65881 .70587 Mdot
.65881 .70587 Mdot
.65489 .70587 Mdot
.64705 .69802 Mdot
.65881 .70979 Mdot
.64313 .70979 Mdot
.64313 .72155 Mdot
.63136 .70979 Mdot
.6392 .70587 Mdot
.64705 .70587 Mdot
.6392 .6941 Mdot
.63528 .69802 Mdot
.63528 .70587 Mdot
.62744 .6941 Mdot
.62744 .68626 Mdot
.62352 .67842 Mdot
.61568 .67057 Mdot
.62352 .6745 Mdot
.6196 .67842 Mdot
.61176 .6745 Mdot
.61176 .65881 Mdot
.60391 .63528 Mdot
.60783 .62744 Mdot
.59999 .60783 Mdot
.61176 .61568 Mdot
.60391 .6196 Mdot
.60391 .61568 Mdot
.59999 .60391 Mdot
.58431 .58431 Mdot
.58039 .58039 Mdot
.56862 .58431 Mdot
.5647 .58823 Mdot
.57254 .60391 Mdot
.55686 .60391 Mdot
.54509 .59607 Mdot
.53333 .58431 Mdot
.53725 .57646 Mdot
.53333 .56078 Mdot
.52157 .54902 Mdot
.51372 .54117 Mdot
.50588 .52941 Mdot
.45098 .48235 Mdot
.44314 .45491 Mdot
.46667 .54509 Mdot
.53725 .6196 Mdot
.54902 .64313 Mdot
.54117 .64313 Mdot
.54902 .65881 Mdot
.54509 .65881 Mdot
.53725 .65097 Mdot
.54509 .64313 Mdot
.53725 .6392 Mdot
.54509 .64705 Mdot
.54902 .65097 Mdot
.55686 .65097 Mdot
.55686 .65881 Mdot
.56078 .66273 Mdot
.5647 .66273 Mdot
.55686 .65097 Mdot
.58039 .65881 Mdot
.58039 .67057 Mdot
.57254 .6745 Mdot
.56078 .6745 Mdot
.5647 .6745 Mdot
.56862 .67842 Mdot
.58823 .69802 Mdot
.58431 .70194 Mdot
.58823 .69802 Mdot
.59215 .70194 Mdot
.58431 .69802 Mdot
.59999 .69802 Mdot
.61176 .70194 Mdot
.60391 .6941 Mdot
.59999 .6941 Mdot
.59999 .70194 Mdot
.60391 .70194 Mdot
.60391 .70587 Mdot
.60391 .70979 Mdot
.61176 .70979 Mdot
.62352 .71763 Mdot
.6196 .71763 Mdot
.61176 .71371 Mdot
.6196 .70979 Mdot
.62744 .70587 Mdot
.63528 .70194 Mdot
.64705 .70587 Mdot
.64705 .70587 Mdot
.65097 .72547 Mdot
.64313 .73332 Mdot
.65097 .73724 Mdot
.65881 .74116 Mdot
.65097 .73332 Mdot
.64313 .73332 Mdot
.64313 .73724 Mdot
.65489 .74508 Mdot
.66273 .749 Mdot
.66273 .75292 Mdot
.65881 .75292 Mdot
.65881 .76076 Mdot
.65881 .76861 Mdot
.66665 .77253 Mdot
.66273 .77253 Mdot
.65881 .76469 Mdot
.66273 .76469 Mdot
.66665 .75292 Mdot
.67057 .749 Mdot
.68234 .75292 Mdot
.6745 .73724 Mdot
.67057 .73724 Mdot
.67057 .74116 Mdot
.67057 .749 Mdot
.6745 .75684 Mdot
.65881 .75292 Mdot
.66273 .749 Mdot
.66665 .74508 Mdot
.6745 .73724 Mdot
.68234 .73724 Mdot
.6745 .72547 Mdot
.67842 .73724 Mdot
.66665 .74116 Mdot
.66665 .749 Mdot
.66665 .749 Mdot
.67057 .749 Mdot
.67057 .749 Mdot
.67057 .76076 Mdot
.6745 .77253 Mdot
.6745 .76469 Mdot
.6745 .75292 Mdot
.67057 .75292 Mdot
.66665 .75292 Mdot
.67057 .75684 Mdot
.6745 .76076 Mdot
.67057 .76076 Mdot
.6745 .75684 Mdot
.67057 .74116 Mdot
.66665 .73724 Mdot
.65881 .74116 Mdot
.66665 .74116 Mdot
.66273 .73724 Mdot
.6745 .74116 Mdot
.66665 .73724 Mdot
.67842 .75292 Mdot
.67842 .75684 Mdot
.67842 .75292 Mdot
.6745 .74508 Mdot
.67057 .74116 Mdot
.66665 .749 Mdot
.67057 .749 Mdot
.67057 .749 Mdot
.67057 .74508 Mdot
.66273 .72939 Mdot
.67057 .72547 Mdot
.67842 .72939 Mdot
.67057 .73332 Mdot
.6745 .73332 Mdot
.66665 .72155 Mdot
.66273 .71371 Mdot
.65881 .71763 Mdot
.65881 .71763 Mdot
.65881 .71371 Mdot
.65881 .71763 Mdot
.65489 .70979 Mdot
.64705 .70194 Mdot
.65097 .70194 Mdot
.65097 .70587 Mdot
.64705 .69802 Mdot
.64313 .6941 Mdot
.6392 .70194 Mdot
.63136 .69802 Mdot
.63528 .70194 Mdot
.63136 .70194 Mdot
.6196 .69018 Mdot
.6392 .70587 Mdot
.6392 .70587 Mdot
.62744 .69802 Mdot
.6196 .68234 Mdot
.61568 .67842 Mdot
.60783 .65489 Mdot
.59999 .65097 Mdot
.60391 .65489 Mdot
.60391 .65489 Mdot
.61176 .65097 Mdot
.60391 .63528 Mdot
.59999 .61568 Mdot
.60783 .60783 Mdot
.59999 .61176 Mdot
.58823 .60391 Mdot
.58431 .59607 Mdot
.58039 .59215 Mdot
.57646 .58823 Mdot
.5647 .58431 Mdot
.55686 .58431 Mdot
.56078 .59607 Mdot
.55686 .59999 Mdot
.55686 .59999 Mdot
.54509 .59215 Mdot
.54509 .58431 Mdot
.54902 .59215 Mdot
.52941 .57254 Mdot
.52157 .54902 Mdot
.51765 .54117 Mdot
.5098 .52157 Mdot
.48628 .48235 Mdot
.44314 .53725 Mdot
.53725 .63136 Mdot
.54509 .65097 Mdot
.54117 .64705 Mdot
.54117 .65489 Mdot
.54117 .65097 Mdot
.53725 .65097 Mdot
.53333 .64705 Mdot
.52549 .64705 Mdot
.53725 .65097 Mdot
.54509 .65881 Mdot
.54509 .65097 Mdot
.54902 .65097 Mdot
.5647 .66273 Mdot
.56862 .66665 Mdot
.56862 .66273 Mdot
.57646 .66665 Mdot
.58823 .67842 Mdot
.57254 .66665 Mdot
.56862 .66665 Mdot
.57254 .66665 Mdot
.56862 .66665 Mdot
.56862 .68234 Mdot
.57646 .70194 Mdot
.58039 .70194 Mdot
.58039 .70587 Mdot
.58039 .70194 Mdot
.58431 .70587 Mdot
.59215 .70979 Mdot
.58431 .69802 Mdot
.59215 .69802 Mdot
.59607 .70587 Mdot
.58039 .69802 Mdot
.59607 .70979 Mdot
.60391 .71371 Mdot
.61176 .72155 Mdot
.61176 .71371 Mdot
.61176 .71371 Mdot
.60783 .71371 Mdot
.61568 .71371 Mdot
.6196 .71371 Mdot
.62744 .71371 Mdot
.6392 .70979 Mdot
.6392 .70587 Mdot
.64313 .72547 Mdot
.63528 .72939 Mdot
.64705 .73724 Mdot
.64705 .749 Mdot
.64705 .73724 Mdot
.64313 .73332 Mdot
.65489 .749 Mdot
.65489 .75684 Mdot
.65097 .75684 Mdot
.65097 .75292 Mdot
.65097 .75292 Mdot
.66273 .76076 Mdot
.65489 .76469 Mdot
.65489 .76469 Mdot
.65489 .76469 Mdot
.65489 .76469 Mdot
.65881 .76861 Mdot
.65489 .75292 Mdot
.66665 .75684 Mdot
.6745 .75292 Mdot
.67057 .74116 Mdot
.66665 .73724 Mdot
.67057 .74116 Mdot
.65881 .74116 Mdot
.66665 .76076 Mdot
.66273 .76861 Mdot
.65097 .76469 Mdot
.65489 .76076 Mdot
.66665 .75292 Mdot
.67057 .749 Mdot
.67057 .74508 Mdot
.66665 .749 Mdot
.66273 .74508 Mdot
.65881 .74508 Mdot
.65881 .749 Mdot
.67057 .75684 Mdot
.66665 .75292 Mdot
.67057 .75684 Mdot
.66273 .76469 Mdot
.65881 .76469 Mdot
.66665 .76861 Mdot
.65881 .76469 Mdot
.65489 .76469 Mdot
.66273 .77253 Mdot
.66665 .77645 Mdot
.65881 .77645 Mdot
.66665 .77645 Mdot
.65881 .76469 Mdot
.65881 .76469 Mdot
.66273 .76469 Mdot
.66665 .76469 Mdot
.65881 .75684 Mdot
.66665 .75292 Mdot
.6745 .75292 Mdot
.67057 .75292 Mdot
.67057 .75684 Mdot
.67842 .76076 Mdot
.67842 .76076 Mdot
.66273 .74508 Mdot
.66665 .74508 Mdot
.66665 .74116 Mdot
.66273 .74116 Mdot
.65881 .74116 Mdot
.65881 .74116 Mdot
.67057 .74116 Mdot
.66665 .73724 Mdot
.66273 .73332 Mdot
.66665 .73332 Mdot
.66273 .73724 Mdot
.65881 .72547 Mdot
.64705 .71763 Mdot
.65489 .72547 Mdot
.65489 .72547 Mdot
.65097 .72155 Mdot
.64705 .71763 Mdot
.63528 .70194 Mdot
.64313 .70194 Mdot
.64705 .70587 Mdot
.64313 .70194 Mdot
.63528 .6941 Mdot
.63528 .6941 Mdot
.6392 .6941 Mdot
.62744 .6941 Mdot
.62744 .70194 Mdot
.62744 .69018 Mdot
.62352 .68234 Mdot
.6196 .68626 Mdot
.61568 .67842 Mdot
.6196 .68234 Mdot
.62352 .67842 Mdot
.61176 .66665 Mdot
.59607 .65097 Mdot
.59607 .64705 Mdot
.59607 .64705 Mdot
.59607 .6392 Mdot
.59215 .63136 Mdot
.59215 .62744 Mdot
.58431 .6196 Mdot
.58039 .61568 Mdot
.56862 .61176 Mdot
.57646 .61568 Mdot
.58039 .60783 Mdot
.57254 .59607 Mdot
.5647 .58823 Mdot
.55686 .58823 Mdot
.56078 .59999 Mdot
.55686 .59999 Mdot
.54509 .58823 Mdot
.54117 .58039 Mdot
.53333 .58039 Mdot
.52549 .57254 Mdot
.51765 .55686 Mdot
.51765 .54902 Mdot
.51372 .53725 Mdot
.50196 .5098 Mdot
.50196 .4902 Mdot
.46667 .54509 Mdot
.52157 .62352 Mdot
.54117 .65489 Mdot
.54117 .6745 Mdot
.54117 .6745 Mdot
.53725 .67057 Mdot
.52157 .65489 Mdot
.52157 .65489 Mdot
.52941 .65489 Mdot
.54902 .65881 Mdot
.54117 .64705 Mdot
.54902 .65097 Mdot
.55686 .65489 Mdot
.54902 .65097 Mdot
.56078 .65881 Mdot
.5647 .65881 Mdot
.56862 .66273 Mdot
.57646 .68234 Mdot
.55294 .67057 Mdot
.5647 .67057 Mdot
.56862 .67057 Mdot
.56862 .67057 Mdot
.56862 .67057 Mdot
.58039 .69018 Mdot
.57254 .6941 Mdot
.56862 .69802 Mdot
.57646 .70194 Mdot
.57646 .69802 Mdot
.58823 .70194 Mdot
.59215 .70194 Mdot
.59999 .70587 Mdot
.59607 .71371 Mdot
.59999 .72547 Mdot
.58823 .71763 Mdot
.59215 .72547 Mdot
.59999 .72547 Mdot
.60391 .71763 Mdot
.60783 .71371 Mdot
.61176 .72547 Mdot
.61176 .72155 Mdot
.62352 .72155 Mdot
.61568 .71763 Mdot
.63136 .71371 Mdot
.63136 .70979 Mdot
.62744 .71371 Mdot
.63136 .72155 Mdot
.63528 .73724 Mdot
.63528 .74508 Mdot
.62744 .73332 Mdot
.65097 .749 Mdot
.64313 .74116 Mdot
.64313 .74508 Mdot
.6392 .75292 Mdot
.64705 .75684 Mdot
.64705 .75684 Mdot
.65489 .76076 Mdot
.65489 .76076 Mdot
.65489 .75684 Mdot
.65489 .75292 Mdot
.65097 .75292 Mdot
.65489 .75684 Mdot
.65097 .749 Mdot
.65881 .749 Mdot
.66273 .74508 Mdot
.66273 .74508 Mdot
.66273 .74508 Mdot
.65881 .74116 Mdot
.65881 .74116 Mdot
.65881 .74508 Mdot
.65881 .749 Mdot
.66273 .76076 Mdot
.65881 .75684 Mdot
.65881 .75292 Mdot
.65881 .75292 Mdot
.65881 .749 Mdot
.65881 .75292 Mdot
.65097 .75684 Mdot
.65489 .76469 Mdot
.65489 .75684 Mdot
.67057 .76469 Mdot
.66273 .75292 Mdot
.65881 .75292 Mdot
.66665 .75684 Mdot
.65881 .75292 Mdot
.65881 .76469 Mdot
.66665 .77645 Mdot
.67057 .78429 Mdot
.66665 .77645 Mdot
.66665 .77645 Mdot
.66665 .77253 Mdot
.66273 .76469 Mdot
.66273 .76469 Mdot
.65881 .76469 Mdot
.6745 .77253 Mdot
.66273 .76469 Mdot
.65489 .76469 Mdot
.66273 .76861 Mdot
.66273 .76469 Mdot
.67057 .76469 Mdot
.66665 .75684 Mdot
.67057 .75292 Mdot
.67057 .75292 Mdot
.65881 .74508 Mdot
.66665 .74116 Mdot
.67057 .73724 Mdot
.66665 .74116 Mdot
.65881 .73724 Mdot
.66665 .749 Mdot
.66665 .74508 Mdot
.66273 .73724 Mdot
.65097 .72939 Mdot
.65489 .73332 Mdot
.65881 .73332 Mdot
.65097 .72155 Mdot
.64313 .71371 Mdot
.65097 .71763 Mdot
.6392 .70979 Mdot
.65097 .71763 Mdot
.64313 .70979 Mdot
.6392 .70979 Mdot
.6392 .70587 Mdot
.64313 .70587 Mdot
.6392 .70587 Mdot
.63528 .70194 Mdot
.62352 .69018 Mdot
.62744 .68626 Mdot
.63136 .6941 Mdot
.62352 .6941 Mdot
.63528 .70194 Mdot
.62744 .69018 Mdot
.6196 .67842 Mdot
.61176 .6745 Mdot
.61176 .67842 Mdot
.60391 .67057 Mdot
.61176 .6745 Mdot
.61568 .67057 Mdot
.60783 .65489 Mdot
.60783 .65489 Mdot
.59607 .64313 Mdot
.59215 .64313 Mdot
.59215 .64705 Mdot
.58823 .6392 Mdot
.57254 .62744 Mdot
.57254 .63136 Mdot
.57646 .62744 Mdot
.57646 .61568 Mdot
.58431 .61176 Mdot
.56862 .61176 Mdot
.5647 .61568 Mdot
.54902 .6196 Mdot
.53333 .61568 Mdot
.52549 .60391 Mdot
.52549 .59215 Mdot
.52941 .58431 Mdot
.53333 .57646 Mdot
.53333 .56862 Mdot
.53333 .55686 Mdot
.52549 .54117 Mdot
.52157 .51765 Mdot
.50588 .48628 Mdot
.45883 .54117 Mdot
.52157 .61568 Mdot
.53333 .64313 Mdot
.54117 .65881 Mdot
.52549 .66273 Mdot
.51765 .65881 Mdot
.5098 .65097 Mdot
.53333 .66665 Mdot
.52941 .65881 Mdot
.53333 .65881 Mdot
.54117 .65489 Mdot
.53725 .65097 Mdot
.53333 .64313 Mdot
.55294 .65489 Mdot
.53725 .65881 Mdot
.55294 .67057 Mdot
.5647 .67057 Mdot
.56862 .6745 Mdot
.56862 .6745 Mdot
.56862 .67057 Mdot
.57646 .67057 Mdot
.58431 .67842 Mdot
.58431 .67842 Mdot
.58823 .6745 Mdot
.58039 .67057 Mdot
.58431 .67842 Mdot
.57254 .67842 Mdot
.58431 .68626 Mdot
.58039 .68626 Mdot
.58823 .68626 Mdot
.59215 .69018 Mdot
.59215 .69802 Mdot
.59607 .71371 Mdot
.59999 .72155 Mdot
.59215 .72155 Mdot
.59999 .72547 Mdot
.59607 .72155 Mdot
.60391 .71371 Mdot
.60391 .70587 Mdot
.61176 .71371 Mdot
.61568 .72547 Mdot
.61568 .72155 Mdot
.6196 .71763 Mdot
.6196 .70587 Mdot
.61568 .70194 Mdot
.6196 .70979 Mdot
.6392 .72939 Mdot
.6392 .73724 Mdot
.63136 .72939 Mdot
.62744 .73724 Mdot
.63528 .74508 Mdot
.63136 .74116 Mdot
.63528 .74508 Mdot
.64705 .76076 Mdot
.65489 .76469 Mdot
.65097 .76076 Mdot
.64313 .75292 Mdot
.65881 .75292 Mdot
.65097 .74508 Mdot
.65489 .749 Mdot
.64705 .74116 Mdot
.65881 .74508 Mdot
.66273 .74116 Mdot
.65489 .73332 Mdot
.65097 .72939 Mdot
.65097 .73724 Mdot
.65881 .74116 Mdot
.65097 .73724 Mdot
.65489 .74116 Mdot
.64705 .73724 Mdot
.65097 .74508 Mdot
.64313 .74116 Mdot
.65881 .75292 Mdot
.65881 .749 Mdot
.65097 .74116 Mdot
.65489 .74508 Mdot
.65097 .749 Mdot
.65097 .75684 Mdot
.66273 .77253 Mdot
.66665 .77253 Mdot
.66273 .76076 Mdot
.66665 .75684 Mdot
.66273 .75292 Mdot
.65881 .75292 Mdot
.66273 .75292 Mdot
.66665 .76469 Mdot
.67057 .77253 Mdot
.65489 .76469 Mdot
.66273 .75684 Mdot
.66273 .749 Mdot
.66273 .75684 Mdot
.65097 .75292 Mdot
.64705 .749 Mdot
.65489 .75292 Mdot
.65489 .76076 Mdot
.66273 .76469 Mdot
.66273 .76469 Mdot
.66273 .76076 Mdot
.66273 .75684 Mdot
.65881 .75292 Mdot
.65881 .749 Mdot
.66665 .74508 Mdot
.66273 .74508 Mdot
.65881 .73332 Mdot
.66273 .73332 Mdot
.65097 .73332 Mdot
.65881 .74116 Mdot
.67057 .75292 Mdot
.67057 .75684 Mdot
.66665 .74508 Mdot
.65097 .73332 Mdot
.64705 .72547 Mdot
.65097 .72155 Mdot
.65489 .72155 Mdot
.64705 .70979 Mdot
.65097 .70979 Mdot
.65881 .71763 Mdot
.64705 .72547 Mdot
.63136 .71763 Mdot
.63528 .71371 Mdot
.63528 .70979 Mdot
.63528 .6941 Mdot
.63136 .69018 Mdot
.63136 .68626 Mdot
.62352 .68626 Mdot
.6196 .68626 Mdot
.62352 .69018 Mdot
.61568 .69018 Mdot
.62352 .69018 Mdot
.60783 .69018 Mdot
.61568 .6941 Mdot
.61176 .68626 Mdot
.60783 .6745 Mdot
.59607 .65881 Mdot
.59607 .65489 Mdot
.60391 .66665 Mdot
.59607 .65489 Mdot
.59999 .65489 Mdot
.59607 .65097 Mdot
.58823 .64313 Mdot
.58039 .64313 Mdot
.56862 .63136 Mdot
.56078 .62352 Mdot
.56862 .62352 Mdot
.5647 .61568 Mdot
.56862 .60391 Mdot
.5647 .59999 Mdot
.56078 .59607 Mdot
.55686 .59999 Mdot
.54902 .61568 Mdot
.55294 .62744 Mdot
.54117 .61568 Mdot
.53725 .59999 Mdot
.53725 .58823 Mdot
.52941 .57646 Mdot
.52157 .55294 Mdot
.52549 .54117 Mdot
.52157 .52549 Mdot
.5098 .50196 Mdot
.51765 .48628 Mdot
.46667 .54902 Mdot
.50196 .60783 Mdot
.51765 .63136 Mdot
.52157 .6392 Mdot
.52549 .65097 Mdot
.52941 .65881 Mdot
.52549 .65489 Mdot
.52549 .65881 Mdot
.5098 .64705 Mdot
.52549 .65881 Mdot
.54117 .66273 Mdot
.52941 .65097 Mdot
.54509 .65881 Mdot
.54902 .65881 Mdot
.54509 .65881 Mdot
.56078 .66273 Mdot
.55686 .65881 Mdot
.55686 .66273 Mdot
.54902 .65881 Mdot
.56078 .65881 Mdot
.56078 .65881 Mdot
.56862 .66665 Mdot
.57254 .66665 Mdot
.56862 .66273 Mdot
.57254 .66273 Mdot
.57646 .67057 Mdot
.58039 .67842 Mdot
.57646 .68626 Mdot
.58039 .6941 Mdot
.58823 .6941 Mdot
.57646 .68234 Mdot
.57646 .69018 Mdot
.58823 .70194 Mdot
.60391 .71371 Mdot
.59999 .72155 Mdot
.59607 .71763 Mdot
.61176 .72155 Mdot
.60391 .70194 Mdot
.61176 .70194 Mdot
.59607 .69802 Mdot
.59999 .71763 Mdot
.59999 .71763 Mdot
.59999 .70587 Mdot
.61176 .70587 Mdot
.61176 .70587 Mdot
.6196 .70979 Mdot
.62352 .71371 Mdot
.62352 .71763 Mdot
.62744 .72547 Mdot
.61176 .72155 Mdot
.61176 .73332 Mdot
.61176 .72939 Mdot
.62352 .72939 Mdot
.62744 .73332 Mdot
.62744 .73332 Mdot
.62744 .73724 Mdot
.63528 .74116 Mdot
.63528 .74116 Mdot
.62744 .72939 Mdot
.62352 .72939 Mdot
.6392 .749 Mdot
.63136 .74116 Mdot
.6392 .72939 Mdot
.64705 .73332 Mdot
.64313 .72939 Mdot
.64313 .72939 Mdot
.64705 .73332 Mdot
.65097 .74116 Mdot
.64313 .72939 Mdot
.64705 .72939 Mdot
.6392 .72547 Mdot
.64313 .72939 Mdot
.64705 .73724 Mdot
.65489 .73724 Mdot
.65097 .72547 Mdot
.65097 .73332 Mdot
.65489 .749 Mdot
.65097 .75684 Mdot
.65097 .75292 Mdot
.65881 .76469 Mdot
.65881 .76469 Mdot
.66273 .76469 Mdot
.65097 .75292 Mdot
.65881 .75292 Mdot
.65489 .74508 Mdot
.64705 .749 Mdot
.64705 .74508 Mdot
.64705 .73724 Mdot
.65097 .73724 Mdot
.64705 .73332 Mdot
.65489 .74508 Mdot
.65489 .74116 Mdot
.64313 .72939 Mdot
.64313 .74116 Mdot
.65489 .75292 Mdot
.65097 .75292 Mdot
.65489 .75292 Mdot
.65097 .749 Mdot
.65097 .749 Mdot
.65097 .74116 Mdot
.65097 .72939 Mdot
.65489 .72547 Mdot
.66665 .72939 Mdot
.66273 .73332 Mdot
.65489 .72939 Mdot
.6392 .72155 Mdot
.64705 .72155 Mdot
.64705 .72939 Mdot
.64705 .72547 Mdot
.65097 .72939 Mdot
.64705 .72939 Mdot
.64313 .71763 Mdot
.63528 .71371 Mdot
.6392 .71763 Mdot
.6392 .71371 Mdot
.64313 .72155 Mdot
.64705 .72155 Mdot
.63528 .72155 Mdot
.62744 .71371 Mdot
.6196 .70587 Mdot
.62352 .70587 Mdot
.62352 .6941 Mdot
.63136 .68626 Mdot
.62352 .67842 Mdot
.61568 .67842 Mdot
.61176 .67842 Mdot
.60391 .67842 Mdot
.61176 .67842 Mdot
.59999 .66665 Mdot
.59999 .66665 Mdot
.60391 .6745 Mdot
.61176 .68626 Mdot
.60391 .67842 Mdot
.60391 .67057 Mdot
.59215 .66273 Mdot
.58039 .65097 Mdot
.56862 .64313 Mdot
.57646 .64705 Mdot
.57254 .64705 Mdot
.57254 .6392 Mdot
.56862 .63528 Mdot
.56862 .63528 Mdot
.55686 .62352 Mdot
.55294 .62352 Mdot
.5647 .62744 Mdot
.56078 .6196 Mdot
.55686 .60783 Mdot
.56078 .60783 Mdot
.5647 .61176 Mdot
.54902 .59607 Mdot
.54509 .59607 Mdot
.52549 .59215 Mdot
.52941 .58823 Mdot
.54117 .59215 Mdot
.51765 .56862 Mdot
.51372 .55294 Mdot
.51765 .53725 Mdot
.51372 .51372 Mdot
.50588 .49804 Mdot
.4902 .46667 Mdot
.45098 .5647 Mdot
.4902 .61568 Mdot
.51765 .64705 Mdot
.52157 .65097 Mdot
.51765 .65097 Mdot
.52941 .66273 Mdot
.52157 .66273 Mdot
.52549 .67057 Mdot
.52941 .66665 Mdot
.54117 .66665 Mdot
.54509 .65881 Mdot
.54902 .65881 Mdot
.54509 .65881 Mdot
.54902 .65881 Mdot
.54902 .65881 Mdot
.55686 .66273 Mdot
.5647 .66273 Mdot
.56862 .66273 Mdot
.56862 .66273 Mdot
.55294 .65489 Mdot
.55686 .65881 Mdot
.56862 .66665 Mdot
.56862 .67057 Mdot
.57646 .67057 Mdot
.57254 .66665 Mdot
.56862 .65881 Mdot
.58039 .67842 Mdot
.58431 .6941 Mdot
.58039 .69802 Mdot
.58431 .6941 Mdot
.59999 .6941 Mdot
.59999 .6941 Mdot
.59607 .69018 Mdot
.59215 .70194 Mdot
.59607 .72155 Mdot
.59215 .72155 Mdot
.59215 .72155 Mdot
.59999 .72547 Mdot
.60391 .71763 Mdot
.61176 .72547 Mdot
.61176 .73332 Mdot
.60783 .72939 Mdot
.60391 .71763 Mdot
.61176 .70979 Mdot
.61568 .70979 Mdot
.61568 .70979 Mdot
.6196 .71763 Mdot
.61568 .72547 Mdot
.62352 .73332 Mdot
.6196 .73332 Mdot
.61568 .72939 Mdot
.61568 .73332 Mdot
.6196 .73332 Mdot
.61176 .72547 Mdot
.63136 .73724 Mdot
.63528 .74116 Mdot
.63136 .74116 Mdot
.63528 .74508 Mdot
.64705 .75292 Mdot
.63136 .749 Mdot
.63136 .749 Mdot
.62744 .74116 Mdot
.63136 .74116 Mdot
.62744 .73724 Mdot
.63528 .749 Mdot
.64705 .75684 Mdot
.65489 .75292 Mdot
.65097 .74508 Mdot
.64705 .73724 Mdot
.65489 .73724 Mdot
.65489 .73332 Mdot
.64313 .72547 Mdot
.65097 .73332 Mdot
.65489 .74508 Mdot
.65881 .73724 Mdot
.65097 .72547 Mdot
.65489 .74116 Mdot
.65097 .76076 Mdot
.65489 .76469 Mdot
.65881 .76861 Mdot
.65881 .76861 Mdot
.65881 .76861 Mdot
.65489 .76861 Mdot
.65881 .76861 Mdot
.65881 .76861 Mdot
.65881 .76469 Mdot
.66273 .76076 Mdot
.66273 .75684 Mdot
.66273 .749 Mdot
.65489 .74116 Mdot
.65489 .749 Mdot
.66273 .75684 Mdot
.65489 .749 Mdot
.64705 .74116 Mdot
.64313 .74116 Mdot
.64705 .75292 Mdot
.64313 .75292 Mdot
.65881 .76076 Mdot
.66273 .75684 Mdot
.66273 .749 Mdot
.66273 .73724 Mdot
.67057 .73332 Mdot
.6745 .72547 Mdot
.6745 .72547 Mdot
.67057 .72547 Mdot
.67057 .72939 Mdot
.66665 .73724 Mdot
.65881 .74116 Mdot
.65881 .74508 Mdot
.66273 .74508 Mdot
.65489 .73724 Mdot
.64313 .72939 Mdot
.64705 .72939 Mdot
.64313 .72939 Mdot
.65881 .74508 Mdot
.65881 .73724 Mdot
.65881 .73724 Mdot
.64705 .72547 Mdot
.64705 .72939 Mdot
.6392 .72155 Mdot
.6392 .72155 Mdot
.63136 .71371 Mdot
.62744 .71371 Mdot
.63136 .71371 Mdot
.62744 .70979 Mdot
.6196 .69802 Mdot
.61568 .69802 Mdot
.6196 .6941 Mdot
.62352 .68234 Mdot
.6196 .68626 Mdot
.61176 .67842 Mdot
.61176 .69018 Mdot
.60391 .6941 Mdot
.59999 .68234 Mdot
.59607 .67842 Mdot
.59999 .68234 Mdot
.59215 .66665 Mdot
.60391 .6745 Mdot
.59607 .66273 Mdot
.58823 .65097 Mdot
.58823 .65097 Mdot
.58039 .65097 Mdot
.5647 .6392 Mdot
.57254 .65489 Mdot
.56862 .65881 Mdot
.57646 .65489 Mdot
.5647 .6392 Mdot
.55294 .63528 Mdot
.55686 .63136 Mdot
.56078 .6196 Mdot
.55686 .61176 Mdot
.53333 .60783 Mdot
.52941 .61176 Mdot
.54509 .61568 Mdot
.52941 .58823 Mdot
.53725 .57646 Mdot
.53333 .55294 Mdot
.52549 .52549 Mdot
.52549 .50588 Mdot
.52157 .48235 Mdot
.45883 .58039 Mdot
.52157 .65489 Mdot
.53333 .67057 Mdot
.52549 .66665 Mdot
.51372 .65489 Mdot
.52549 .66273 Mdot
.53333 .67842 Mdot
.52941 .68234 Mdot
.52941 .67057 Mdot
.52941 .66273 Mdot
.54117 .65881 Mdot
.54509 .66665 Mdot
.54117 .66273 Mdot
.54902 .66665 Mdot
.56078 .66665 Mdot
.56078 .66273 Mdot
.5647 .65489 Mdot
.56078 .65489 Mdot
.56078 .66273 Mdot
.56862 .6745 Mdot
.56862 .67842 Mdot
.56078 .68626 Mdot
.5647 .69018 Mdot
.5647 .69018 Mdot
.57646 .69802 Mdot
.57646 .69802 Mdot
.57646 .69802 Mdot
.57254 .69802 Mdot
.56862 .69018 Mdot
.58039 .6941 Mdot
.58431 .69018 Mdot
.59607 .69802 Mdot
.60783 .70587 Mdot
.59215 .70194 Mdot
.59999 .72547 Mdot
.59999 .73724 Mdot
.59215 .72939 Mdot
.58431 .71371 Mdot
.58431 .71371 Mdot
.59999 .73332 Mdot
.60783 .73332 Mdot
.60391 .73332 Mdot
.59999 .72155 Mdot
.61176 .70979 Mdot
.6196 .70979 Mdot
.61176 .70587 Mdot
.61568 .71371 Mdot
.6196 .71763 Mdot
.62352 .71371 Mdot
.61568 .70587 Mdot
.6196 .71371 Mdot
.61176 .71763 Mdot
.62744 .72547 Mdot
.61176 .72155 Mdot
.62352 .72547 Mdot
.6392 .73724 Mdot
.63528 .73724 Mdot
.6196 .73332 Mdot
.62744 .74116 Mdot
.64313 .74508 Mdot
.6392 .73724 Mdot
.63136 .73332 Mdot
.63528 .73332 Mdot
.63136 .74116 Mdot
.62352 .74508 Mdot
.63136 .75292 Mdot
.6392 .75684 Mdot
.6392 .75292 Mdot
.64705 .76076 Mdot
.6392 .75292 Mdot
.65097 .74508 Mdot
.64313 .72939 Mdot
.63136 .71763 Mdot
.65097 .73332 Mdot
.65881 .74116 Mdot
.64313 .72939 Mdot
.64705 .73332 Mdot
.65489 .749 Mdot
.64705 .76076 Mdot
.65097 .76861 Mdot
.65489 .76861 Mdot
.65881 .76469 Mdot
.65881 .76469 Mdot
.65881 .76469 Mdot
.64313 .76076 Mdot
.65097 .76076 Mdot
.65097 .76469 Mdot
.64705 .75684 Mdot
.65097 .75292 Mdot
.65097 .75292 Mdot
.65097 .76076 Mdot
.65881 .76076 Mdot
.64705 .749 Mdot
.65881 .74116 Mdot
.65489 .73724 Mdot
.64705 .73724 Mdot
.6392 .74116 Mdot
.64313 .749 Mdot
.6392 .74508 Mdot
.65489 .749 Mdot
.65489 .749 Mdot
.65489 .74508 Mdot
.65097 .72547 Mdot
.65489 .72155 Mdot
.64705 .71763 Mdot
.65097 .71763 Mdot
.65489 .72547 Mdot
.65881 .72547 Mdot
.65881 .73724 Mdot
.65097 .73724 Mdot
.65097 .73332 Mdot
.64705 .72939 Mdot
.63136 .71371 Mdot
.63136 .70979 Mdot
.63136 .71371 Mdot
.6392 .72155 Mdot
.6392 .72155 Mdot
.63136 .70979 Mdot
.63136 .70979 Mdot
.63136 .70587 Mdot
.62744 .70979 Mdot
.62744 .70979 Mdot
.62352 .70979 Mdot
.61568 .71371 Mdot
.61568 .71371 Mdot
.61176 .70979 Mdot
.61568 .69802 Mdot
.6196 .6941 Mdot
.61568 .68626 Mdot
.60783 .69018 Mdot
.59215 .68234 Mdot
.58431 .67057 Mdot
.58823 .67057 Mdot
.59215 .6745 Mdot
.57646 .66273 Mdot
.57646 .67057 Mdot
.57646 .65489 Mdot
.58823 .65489 Mdot
.58431 .64705 Mdot
.58039 .63528 Mdot
.57254 .63528 Mdot
.57646 .64705 Mdot
.56078 .64313 Mdot
.56078 .64705 Mdot
.5647 .66273 Mdot
.54902 .65097 Mdot
.53333 .63136 Mdot
.54509 .63136 Mdot
.54509 .62352 Mdot
.54117 .60783 Mdot
.52549 .59607 Mdot
.51765 .59215 Mdot
.52549 .59999 Mdot
.52157 .59607 Mdot
.5098 .57646 Mdot
.52549 .56862 Mdot
.51765 .55686 Mdot
.51765 .53333 Mdot
.50588 .50196 Mdot
.48628 .46667 Mdot
.42746 .54117 Mdot
.49412 .61568 Mdot
.50588 .64705 Mdot
.50196 .64313 Mdot
.51372 .65489 Mdot
.50588 .65881 Mdot
.50588 .65881 Mdot
.52157 .66273 Mdot
.52549 .66273 Mdot
.52941 .66273 Mdot
.52941 .65881 Mdot
.52941 .66273 Mdot
.54117 .66273 Mdot
.54902 .66273 Mdot
.54902 .65489 Mdot
.55294 .65097 Mdot
.55294 .65097 Mdot
.56862 .66665 Mdot
.55294 .65881 Mdot
.5647 .6745 Mdot
.55686 .68234 Mdot
.56078 .6941 Mdot
.56862 .70979 Mdot
.56078 .70587 Mdot
.56078 .70587 Mdot
.56862 .70194 Mdot
.57646 .70194 Mdot
.58039 .69802 Mdot
.58039 .6941 Mdot
.57646 .69802 Mdot
.58039 .70194 Mdot
.58039 .70587 Mdot
.59607 .71371 Mdot
.59607 .71763 Mdot
.59607 .72547 Mdot
.59999 .72939 Mdot
.58823 .71371 Mdot
.58823 .71763 Mdot
.59607 .72155 Mdot
.60783 .72547 Mdot
.59999 .71371 Mdot
.58823 .70194 Mdot
.59607 .70587 Mdot
.59999 .70587 Mdot
.61176 .70979 Mdot
.61568 .70979 Mdot
.61176 .70587 Mdot
.61568 .70587 Mdot
.61568 .70194 Mdot
.61568 .69802 Mdot
.62744 .70587 Mdot
.61568 .70587 Mdot
.6196 .71371 Mdot
.61568 .70979 Mdot
.6196 .71763 Mdot
.6196 .72155 Mdot
.6196 .72547 Mdot
.62744 .73332 Mdot
.63136 .74508 Mdot
.62744 .74508 Mdot
.62744 .72939 Mdot
.63136 .73332 Mdot
.63528 .73724 Mdot
.63528 .74116 Mdot
.63136 .749 Mdot
.63528 .75292 Mdot
.63136 .749 Mdot
.63136 .74508 Mdot
.6392 .75292 Mdot
.6392 .74508 Mdot
.63528 .73332 Mdot
.64705 .72939 Mdot
.64705 .72939 Mdot
.65097 .72939 Mdot
.64705 .72155 Mdot
.65097 .72547 Mdot
.64705 .72939 Mdot
.6392 .72939 Mdot
.62744 .72547 Mdot
.63528 .73724 Mdot
.64313 .749 Mdot
.65097 .75292 Mdot
.64313 .74508 Mdot
.64705 .75684 Mdot
.64313 .76076 Mdot
.64313 .76469 Mdot
.6392 .76076 Mdot
.64705 .76469 Mdot
.64313 .75292 Mdot
.64313 .75292 Mdot
.65097 .75292 Mdot
.65489 .74508 Mdot
.65881 .73724 Mdot
.65881 .72939 Mdot
.6392 .71763 Mdot
.63528 .72155 Mdot
.64705 .73724 Mdot
.64705 .74116 Mdot
.63528 .73724 Mdot
.64705 .74116 Mdot
.64705 .749 Mdot
.65097 .74508 Mdot
.63136 .72547 Mdot
.63528 .72547 Mdot
.64313 .72547 Mdot
.63136 .71763 Mdot
.64313 .72547 Mdot
.64313 .72155 Mdot
.63528 .71763 Mdot
.6392 .71763 Mdot
.63136 .71763 Mdot
.6392 .72155 Mdot
.63528 .71371 Mdot
.6196 .69802 Mdot
.63528 .70587 Mdot
.63136 .71371 Mdot
.62744 .71371 Mdot
.62744 .70979 Mdot
.63136 .71371 Mdot
.62352 .70587 Mdot
.62352 .6941 Mdot
.62352 .68626 Mdot
.61176 .68626 Mdot
.62352 .70194 Mdot
.61176 .70194 Mdot
.60783 .6941 Mdot
.60783 .69018 Mdot
.59215 .67842 Mdot
.60783 .69018 Mdot
.60783 .6941 Mdot
.58823 .67842 Mdot
.57646 .66273 Mdot
.58823 .66273 Mdot
.58039 .65489 Mdot
.58823 .66665 Mdot
.57646 .65881 Mdot
.56862 .64313 Mdot
.58039 .6392 Mdot
.57254 .6196 Mdot
.56862 .61568 Mdot
.57646 .62352 Mdot
.55294 .6196 Mdot
.56078 .62744 Mdot
.55294 .63136 Mdot
.54902 .64313 Mdot
.53725 .64313 Mdot
.53333 .6392 Mdot
.54117 .63136 Mdot
.55686 .62744 Mdot
.53333 .60783 Mdot
.52941 .60391 Mdot
.51372 .58823 Mdot
.50588 .57646 Mdot
.51765 .58823 Mdot
.5098 .58431 Mdot
.50588 .57254 Mdot
.50196 .56078 Mdot
.50196 .53725 Mdot
.50588 .50588 Mdot
.48628 .46275 Mdot
.4353 .54509 Mdot
.48628 .60783 Mdot
.51372 .64313 Mdot
.51765 .65881 Mdot
.5098 .65097 Mdot
.5098 .65097 Mdot
.5098 .65097 Mdot
.52941 .66665 Mdot
.53725 .67057 Mdot
.54509 .6745 Mdot
.54117 .66665 Mdot
.54509 .65881 Mdot
.54509 .65097 Mdot
.55294 .64705 Mdot
.55294 .64313 Mdot
.56078 .65097 Mdot
.55294 .65489 Mdot
.55686 .66665 Mdot
.54509 .66273 Mdot
.55294 .67842 Mdot
.55686 .68626 Mdot
.55686 .69018 Mdot
.56078 .69018 Mdot
.5647 .69802 Mdot
.5647 .69018 Mdot
.56862 .68234 Mdot
.57254 .67842 Mdot
.57646 .67842 Mdot
.58431 .68234 Mdot
.58039 .68234 Mdot
.58039 .69018 Mdot
.58039 .70194 Mdot
.58431 .70194 Mdot
.58431 .70194 Mdot
.58431 .69802 Mdot
.58431 .6941 Mdot
.59607 .71371 Mdot
.59607 .71763 Mdot
.59999 .71371 Mdot
.61568 .72155 Mdot
.60783 .70194 Mdot
.60391 .70194 Mdot
.59215 .69802 Mdot
.60391 .70979 Mdot
.60391 .70587 Mdot
.61568 .70979 Mdot
.61176 .70194 Mdot
.61176 .70194 Mdot
.59999 .69802 Mdot
.61568 .70587 Mdot
.62352 .70979 Mdot
.61568 .71371 Mdot
.61176 .72155 Mdot
.61568 .72547 Mdot
.61176 .72547 Mdot
.6196 .72939 Mdot
.61568 .72547 Mdot
.61176 .72547 Mdot
.62352 .73724 Mdot
.63528 .74508 Mdot
.6392 .74116 Mdot
.6392 .73332 Mdot
.63136 .72547 Mdot
.62744 .72939 Mdot
.6392 .74508 Mdot
.63136 .74116 Mdot
.63136 .73724 Mdot
.63528 .72939 Mdot
.6392 .72939 Mdot
.6392 .72547 Mdot
.63528 .71371 Mdot
.65097 .71763 Mdot
.65097 .71371 Mdot
.64313 .70587 Mdot
.63528 .69802 Mdot
.64313 .70979 Mdot
.64705 .72547 Mdot
.64313 .72547 Mdot
.6392 .71763 Mdot
.65097 .72547 Mdot
.64313 .72939 Mdot
.65097 .74508 Mdot
.65097 .74508 Mdot
.64705 .75292 Mdot
.64313 .76469 Mdot
.64313 .76076 Mdot
.65097 .76861 Mdot
.64313 .76076 Mdot
.6392 .75684 Mdot
.6392 .749 Mdot
.65097 .74116 Mdot
.64313 .72155 Mdot
.64313 .71371 Mdot
.64313 .71763 Mdot
.6392 .71371 Mdot
.6392 .71371 Mdot
.64313 .72939 Mdot
.64705 .74116 Mdot
.64313 .74116 Mdot
.64705 .73724 Mdot
.63136 .72155 Mdot
.6392 .72155 Mdot
.6392 .72155 Mdot
.62352 .71371 Mdot
.63136 .72547 Mdot
.63528 .72547 Mdot
.63528 .72155 Mdot
.64313 .72939 Mdot
.64313 .72547 Mdot
.6392 .72547 Mdot
.6196 .70979 Mdot
.6196 .70979 Mdot
.63528 .71763 Mdot
.62352 .70587 Mdot
.62744 .70194 Mdot
.63136 .70979 Mdot
.63528 .71763 Mdot
.6196 .71371 Mdot
.61176 .70587 Mdot
.6196 .70194 Mdot
.62744 .70194 Mdot
.62352 .6941 Mdot
.61568 .68626 Mdot
.61568 .69018 Mdot
.61176 .70194 Mdot
.60391 .6941 Mdot
.59999 .68626 Mdot
.58431 .66665 Mdot
.59999 .6745 Mdot
.59215 .67057 Mdot
.58431 .66273 Mdot
.57646 .65097 Mdot
.57254 .65489 Mdot
.5647 .64313 Mdot
.5647 .6392 Mdot
.57254 .6392 Mdot
.5647 .63528 Mdot
.57646 .64313 Mdot
.57646 .63136 Mdot
.57254 .6196 Mdot
.56862 .60783 Mdot
.56078 .60391 Mdot
.56862 .62352 Mdot
.55294 .62352 Mdot
.55294 .62744 Mdot
.54902 .63528 Mdot
.54509 .63136 Mdot
.53725 .62352 Mdot
.53725 .61568 Mdot
.52941 .59999 Mdot
.51765 .58431 Mdot
.51372 .57646 Mdot
.50196 .57254 Mdot
.50588 .58039 Mdot
.51372 .59215 Mdot
.50196 .56862 Mdot
.49804 .54902 Mdot
.50196 .52941 Mdot
.4902 .49804 Mdot
.48628 .46275 Mdot
.4353 .54117 Mdot
.4902 .60783 Mdot
.50196 .6392 Mdot
.50588 .65097 Mdot
.50588 .65097 Mdot
.50196 .64313 Mdot
.51372 .64313 Mdot
.53333 .65881 Mdot
.54117 .67057 Mdot
.53725 .67057 Mdot
.53725 .66665 Mdot
.54117 .65097 Mdot
.53725 .64705 Mdot
.54117 .64705 Mdot
.54509 .64313 Mdot
.55294 .64705 Mdot
.55686 .66273 Mdot
.55294 .67842 Mdot
.54902 .67842 Mdot
.55686 .67842 Mdot
.54902 .65881 Mdot
.5647 .67057 Mdot
.57254 .68234 Mdot
.56862 .68626 Mdot
.5647 .68626 Mdot
.5647 .67842 Mdot
.56862 .66665 Mdot
.57254 .66273 Mdot
.57254 .65881 Mdot
.56862 .67057 Mdot
.5647 .69018 Mdot
.57646 .70587 Mdot
.59607 .71371 Mdot
.59607 .70194 Mdot
.59607 .6941 Mdot
.58823 .69018 Mdot
.59607 .70587 Mdot
.59607 .71763 Mdot
.60783 .72939 Mdot
.59999 .72155 Mdot
.60391 .71371 Mdot
.59215 .69802 Mdot
.59607 .6941 Mdot
.59215 .69018 Mdot
.59607 .69802 Mdot
.59607 .6941 Mdot
.59215 .69018 Mdot
.59999 .6941 Mdot
.60783 .70194 Mdot
.59999 .70194 Mdot
.61176 .71763 Mdot
.60783 .72547 Mdot
.59999 .72155 Mdot
.61176 .72939 Mdot
.61568 .72939 Mdot
.6196 .72939 Mdot
.61176 .73332 Mdot
.61176 .73724 Mdot
.6196 .73724 Mdot
.6196 .72547 Mdot
.62744 .71763 Mdot
.62352 .70979 Mdot
.63136 .71371 Mdot
.6392 .72155 Mdot
.63136 .72547 Mdot
.6392 .73332 Mdot
.64313 .73724 Mdot
.62352 .71763 Mdot
.62352 .70979 Mdot
.63528 .70587 Mdot
.63528 .70194 Mdot
.6392 .70194 Mdot
.63528 .69802 Mdot
.64313 .70194 Mdot
.64313 .70194 Mdot
.6392 .70194 Mdot
.64705 .71371 Mdot
.65097 .72547 Mdot
.65489 .73332 Mdot
.65097 .72155 Mdot
.64705 .70979 Mdot
.64313 .70979 Mdot
.63528 .71371 Mdot
.6392 .72547 Mdot
.64313 .73724 Mdot
.64705 .74116 Mdot
.65097 .74508 Mdot
.63528 .73332 Mdot
.62352 .73332 Mdot
.63528 .74116 Mdot
.63528 .74116 Mdot
.62744 .72155 Mdot
.6392 .71763 Mdot
.64313 .71763 Mdot
.64313 .72155 Mdot
.64705 .72939 Mdot
.63136 .72939 Mdot
.62744 .73332 Mdot
.6392 .73332 Mdot
.64705 .72547 Mdot
.63136 .71371 Mdot
.6392 .70979 Mdot
.64313 .71763 Mdot
.6392 .72547 Mdot
.62352 .71371 Mdot
.62352 .70587 Mdot
.6196 .69802 Mdot
.62744 .70587 Mdot
.64313 .71371 Mdot
.63528 .70587 Mdot
.6196 .70194 Mdot
.61568 .70979 Mdot
.62352 .70587 Mdot
.63136 .6941 Mdot
.6196 .69018 Mdot
.61176 .6941 Mdot
.6196 .70979 Mdot
.6196 .70979 Mdot
.61568 .70194 Mdot
.61568 .70194 Mdot
.61176 .6941 Mdot
.61176 .6941 Mdot
.59999 .68626 Mdot
.59999 .6941 Mdot
.59215 .68234 Mdot
.58431 .66273 Mdot
.58823 .65489 Mdot
.59607 .65489 Mdot
.58823 .65097 Mdot
.58431 .65097 Mdot
.58431 .64705 Mdot
.57254 .64313 Mdot
.56862 .63136 Mdot
.58039 .6392 Mdot
.56862 .63136 Mdot
.57254 .63136 Mdot
.56862 .6392 Mdot
.5647 .63528 Mdot
.56862 .63528 Mdot
.5647 .61568 Mdot
.56078 .60391 Mdot
.55686 .59999 Mdot
.56078 .61176 Mdot
.54902 .61568 Mdot
.54509 .62744 Mdot
.53725 .62352 Mdot
.53333 .62352 Mdot
.53333 .63136 Mdot
.53725 .62352 Mdot
.52549 .59999 Mdot
.5098 .57646 Mdot
.51372 .58431 Mdot
.50588 .58823 Mdot
.49804 .58823 Mdot
.50588 .59607 Mdot
.49412 .56862 Mdot
.50196 .54902 Mdot
.48628 .5098 Mdot
.49412 .49412 Mdot
.48628 .46667 Mdot
.42746 .52157 Mdot
.48235 .59607 Mdot
.49412 .62352 Mdot
.50196 .64313 Mdot
.4902 .6392 Mdot
.50196 .64313 Mdot
.51372 .63528 Mdot
.5098 .6392 Mdot
.52157 .65489 Mdot
.53333 .66665 Mdot
.53333 .65881 Mdot
.54117 .65489 Mdot
.54117 .65489 Mdot
.54509 .65097 Mdot
.54117 .64705 Mdot
.54509 .64705 Mdot
.54509 .65097 Mdot
.54902 .65881 Mdot
.54902 .66665 Mdot
.54902 .66273 Mdot
.54902 .64705 Mdot
.55294 .6392 Mdot
.5647 .65097 Mdot
.5647 .65881 Mdot
.5647 .67057 Mdot
.57254 .67057 Mdot
.57254 .66665 Mdot
.57646 .66273 Mdot
.58039 .66273 Mdot
.58039 .66273 Mdot
.57646 .6745 Mdot
.57254 .68234 Mdot
.57254 .68234 Mdot
.58431 .68234 Mdot
.57646 .67057 Mdot
.58823 .67842 Mdot
.58823 .69018 Mdot
.59215 .70587 Mdot
.58823 .71371 Mdot
.59215 .71763 Mdot
.58823 .70587 Mdot
.58431 .6941 Mdot
.59607 .6941 Mdot
.59607 .6941 Mdot
.58431 .68234 Mdot
.59607 .68626 Mdot
.59999 .69802 Mdot
.60391 .69018 Mdot
.58823 .6745 Mdot
.59607 .69018 Mdot
.59607 .6941 Mdot
.59999 .70587 Mdot
.60391 .72939 Mdot
.59999 .73332 Mdot
.60391 .72547 Mdot
.60783 .71371 Mdot
.60783 .71371 Mdot
.60391 .71371 Mdot
.59999 .71763 Mdot
.61568 .72547 Mdot
.62744 .72155 Mdot
.62352 .70979 Mdot
.62352 .70194 Mdot
.6196 .70587 Mdot
.61568 .71763 Mdot
.60391 .72155 Mdot
.6196 .71763 Mdot
.62352 .70587 Mdot
.62352 .69018 Mdot
.62352 .68626 Mdot
.62352 .68626 Mdot
.6196 .6941 Mdot
.62352 .69802 Mdot
.63136 .69802 Mdot
.6196 .68626 Mdot
.63136 .69018 Mdot
.62352 .69018 Mdot
.62744 .70979 Mdot
.62744 .71763 Mdot
.62744 .71371 Mdot
.63136 .69802 Mdot
.6392 .6941 Mdot
.64313 .6941 Mdot
.64705 .70194 Mdot
.6392 .70979 Mdot
.6392 .71763 Mdot
.64705 .72547 Mdot
.6392 .71763 Mdot
.63136 .71371 Mdot
.62744 .70979 Mdot
.63136 .72155 Mdot
.6196 .70587 Mdot
.62352 .70587 Mdot
.62744 .70979 Mdot
.6196 .70979 Mdot
.63528 .72547 Mdot
.6392 .73332 Mdot
.62352 .71763 Mdot
.63136 .72547 Mdot
.62744 .71763 Mdot
.62352 .70194 Mdot
.62744 .70194 Mdot
.63136 .69802 Mdot
.63528 .71371 Mdot
.63528 .71371 Mdot
.62352 .70587 Mdot
.6196 .69802 Mdot
.61568 .6941 Mdot
.62352 .70587 Mdot
.6196 .69802 Mdot
.62352 .70979 Mdot
.62352 .71371 Mdot
.61568 .70194 Mdot
.61176 .68626 Mdot
.60783 .67842 Mdot
.61176 .68626 Mdot
.60391 .69018 Mdot
.60783 .70194 Mdot
.61176 .69802 Mdot
.6196 .6941 Mdot
.60783 .67842 Mdot
.58823 .66665 Mdot
.59607 .67842 Mdot
.59999 .68626 Mdot
.58431 .6745 Mdot
.57646 .65097 Mdot
.58823 .64313 Mdot
.59215 .6392 Mdot
.58823 .63136 Mdot
.58431 .63136 Mdot
.58431 .6392 Mdot
.57254 .63528 Mdot
.57646 .6392 Mdot
.57254 .63136 Mdot
.5647 .6196 Mdot
.56078 .61568 Mdot
.56078 .6196 Mdot
.57254 .6392 Mdot
.55686 .63136 Mdot
.54902 .6196 Mdot
.54509 .60783 Mdot
.54117 .59215 Mdot
.55294 .60391 Mdot
.53725 .60391 Mdot
.54509 .61568 Mdot
.54117 .6196 Mdot
.52941 .62352 Mdot
.51372 .6196 Mdot
.5098 .6196 Mdot
.51372 .60783 Mdot
.50588 .59607 Mdot
.49412 .59215 Mdot
.4902 .59999 Mdot
.49412 .59607 Mdot
.49804 .58823 Mdot
.49412 .5647 Mdot
.4902 .52941 Mdot
.49412 .51372 Mdot
.50196 .49412 Mdot
.4902 .46667 Mdot
.42746 .53725 Mdot
.48235 .59999 Mdot
.50196 .62352 Mdot
.50196 .63136 Mdot
.49412 .6392 Mdot
.50196 .64313 Mdot
.51372 .65097 Mdot
.50196 .64313 Mdot
.51765 .65881 Mdot
.52549 .66273 Mdot
.51372 .65489 Mdot
.52549 .65881 Mdot
.54117 .66273 Mdot
.54902 .66665 Mdot
.54902 .66665 Mdot
.54509 .66273 Mdot
.54902 .65881 Mdot
.56078 .66273 Mdot
.55686 .65881 Mdot
.54902 .65097 Mdot
.55686 .65489 Mdot
.55294 .65097 Mdot
.55686 .65489 Mdot
.55686 .66273 Mdot
.55294 .65881 Mdot
.55686 .65881 Mdot
.55686 .65881 Mdot
.5647 .66665 Mdot
.56862 .66273 Mdot
.57646 .67057 Mdot
.58039 .6745 Mdot
.58431 .68234 Mdot
.58431 .67842 Mdot
.58431 .6745 Mdot
.58431 .66665 Mdot
.59215 .67842 Mdot
.58823 .67842 Mdot
.58431 .6745 Mdot
.58431 .68234 Mdot
.58823 .68626 Mdot
.59607 .6941 Mdot
.58823 .69018 Mdot
.58431 .69018 Mdot
.59607 .70194 Mdot
.58823 .69018 Mdot
.60391 .69018 Mdot
.60391 .68626 Mdot
.59999 .69018 Mdot
.59999 .69018 Mdot
.59999 .69802 Mdot
.59999 .70587 Mdot
.60391 .71371 Mdot
.60391 .72939 Mdot
.60783 .73332 Mdot
.61176 .73724 Mdot
.60783 .72939 Mdot
.60391 .72547 Mdot
.60391 .72547 Mdot
.59999 .71763 Mdot
.61176 .71371 Mdot
.6196 .71371 Mdot
.61568 .70587 Mdot
.60783 .70194 Mdot
.6196 .71371 Mdot
.61568 .71371 Mdot
.60783 .71763 Mdot
.6196 .72547 Mdot
.62352 .71763 Mdot
.62352 .70587 Mdot
.62352 .70979 Mdot
.62744 .71371 Mdot
.62352 .70194 Mdot
.63136 .6941 Mdot
.63136 .69018 Mdot
.62744 .68626 Mdot
.6196 .68234 Mdot
.6196 .68234 Mdot
.6196 .69802 Mdot
.61568 .70587 Mdot
.63136 .70979 Mdot
.62744 .70194 Mdot
.64313 .70587 Mdot
.63136 .69802 Mdot
.63528 .70979 Mdot
.63528 .70979 Mdot
.6392 .72155 Mdot
.63528 .72547 Mdot
.63528 .72155 Mdot
.64313 .72939 Mdot
.6392 .72547 Mdot
.63136 .71763 Mdot
.63136 .72155 Mdot
.6392 .72155 Mdot
.62744 .71763 Mdot
.61568 .70979 Mdot
.61568 .70979 Mdot
.62352 .71371 Mdot
.62352 .71763 Mdot
.62352 .71763 Mdot
.62744 .72155 Mdot
.61568 .70979 Mdot
.62744 .71371 Mdot
.62744 .70979 Mdot
.63136 .71371 Mdot
.63136 .70979 Mdot
.62352 .70587 Mdot
.62744 .70587 Mdot
.6196 .70587 Mdot
.61176 .70979 Mdot
.60783 .71371 Mdot
.61176 .71371 Mdot
.6196 .70979 Mdot
.6196 .69018 Mdot
.61568 .68234 Mdot
.61176 .6745 Mdot
.61176 .6745 Mdot
.61176 .68234 Mdot
.60391 .68234 Mdot
.60391 .68234 Mdot
.60391 .68234 Mdot
.60391 .68626 Mdot
.60783 .68234 Mdot
.59215 .67057 Mdot
.58823 .66665 Mdot
.59215 .66665 Mdot
.58039 .64705 Mdot
.59215 .64705 Mdot
.58039 .63528 Mdot
.57646 .62744 Mdot
.58431 .6392 Mdot
.5647 .62744 Mdot
.56862 .62352 Mdot
.58039 .62352 Mdot
.58431 .62744 Mdot
.56078 .61176 Mdot
.55294 .6196 Mdot
.54509 .62352 Mdot
.55686 .63136 Mdot
.55686 .63136 Mdot
.54509 .62744 Mdot
.54117 .62744 Mdot
.53725 .6196 Mdot
.53333 .61176 Mdot
.52941 .61176 Mdot
.52549 .6196 Mdot
.52157 .6196 Mdot
.51765 .61568 Mdot
.51372 .61568 Mdot
.5098 .6196 Mdot
.5098 .61568 Mdot
.49412 .60391 Mdot
.49804 .60783 Mdot
.49412 .60391 Mdot
.49804 .59999 Mdot
.49804 .58039 Mdot
.47843 .54902 Mdot
.48235 .54117 Mdot
.48235 .51372 Mdot
.47451 .4902 Mdot
.47451 .47059 Mdot
.4353 .53333 Mdot
.4902 .60783 Mdot
.50196 .62352 Mdot
.5098 .63528 Mdot
.50588 .63136 Mdot
.49804 .63528 Mdot
.50588 .64313 Mdot
.50196 .64705 Mdot
.51765 .65489 Mdot
.51372 .64705 Mdot
.52157 .65489 Mdot
.54509 .67057 Mdot
.54117 .67057 Mdot
.54902 .6745 Mdot
.54117 .66665 Mdot
.54509 .67057 Mdot
.54902 .67057 Mdot
.56862 .68234 Mdot
.55294 .66665 Mdot
.54902 .67057 Mdot
.55294 .66665 Mdot
.56078 .66665 Mdot
.55686 .66273 Mdot
.55686 .66273 Mdot
.55686 .66665 Mdot
.56078 .66665 Mdot
.56078 .66273 Mdot
.5647 .66273 Mdot
.57646 .67057 Mdot
.56862 .66273 Mdot
.57254 .67057 Mdot
.57254 .6745 Mdot
.57646 .6745 Mdot
.58431 .67842 Mdot
.59607 .68626 Mdot
.58431 .66665 Mdot
.59607 .67057 Mdot
.58431 .66273 Mdot
.58039 .6745 Mdot
.57646 .67842 Mdot
.57646 .67842 Mdot
.59215 .69802 Mdot
.58431 .69802 Mdot
.58823 .69802 Mdot
.58039 .68234 Mdot
.58823 .68626 Mdot
.58431 .69018 Mdot
.58431 .68626 Mdot
.58431 .68626 Mdot
.59215 .70194 Mdot
.59607 .70979 Mdot
.58823 .70979 Mdot
.59215 .71371 Mdot
.59607 .71763 Mdot
.60783 .73332 Mdot
.60783 .73332 Mdot
.60783 .73332 Mdot
.60391 .72939 Mdot
.61176 .72939 Mdot
.61176 .72155 Mdot
.6196 .71763 Mdot
.62352 .71371 Mdot
.6196 .70587 Mdot
.61568 .69802 Mdot
.61568 .70194 Mdot
.61176 .70587 Mdot
.61176 .71371 Mdot
.61176 .71763 Mdot
.6196 .72547 Mdot
.61568 .72155 Mdot
.60783 .70979 Mdot
.62352 .70979 Mdot
.62352 .70194 Mdot
.6196 .69018 Mdot
.61176 .67842 Mdot
.61176 .67842 Mdot
.62352 .68626 Mdot
.61176 .69018 Mdot
.62352 .71371 Mdot
.63528 .72155 Mdot
.63528 .72155 Mdot
.62744 .71763 Mdot
.62352 .70979 Mdot
.63136 .71371 Mdot
.62744 .70979 Mdot
.62352 .71763 Mdot
.62352 .72155 Mdot
.63528 .74116 Mdot
.64313 .74116 Mdot
.64313 .73724 Mdot
.64705 .72939 Mdot
.63136 .70587 Mdot
.63136 .70194 Mdot
.62352 .69802 Mdot
.62352 .70587 Mdot
.62744 .71371 Mdot
.62352 .71371 Mdot
.62744 .71763 Mdot
.62744 .71763 Mdot
.62744 .72939 Mdot
.62352 .72547 Mdot
.6196 .71763 Mdot
.62352 .72155 Mdot
.61568 .71763 Mdot
.61568 .72155 Mdot
.60783 .71371 Mdot
.61568 .70587 Mdot
.6196 .70979 Mdot
.61568 .70979 Mdot
.61176 .71371 Mdot
.61568 .71371 Mdot
.60783 .69018 Mdot
.61176 .67842 Mdot
.61568 .68626 Mdot
.61176 .68626 Mdot
.60391 .6745 Mdot
.60783 .6745 Mdot
.60391 .67842 Mdot
.59215 .67057 Mdot
.59999 .67842 Mdot
.58431 .67057 Mdot
.58823 .66665 Mdot
.59215 .66665 Mdot
.59607 .67057 Mdot
.59215 .67057 Mdot
.58823 .65489 Mdot
.57646 .64313 Mdot
.57646 .64313 Mdot
.56862 .63528 Mdot
.5647 .63528 Mdot
.57254 .64313 Mdot
.56078 .62352 Mdot
.57254 .61568 Mdot
.56078 .60391 Mdot
.5647 .6196 Mdot
.55686 .62352 Mdot
.54902 .6196 Mdot
.54117 .6196 Mdot
.55686 .63136 Mdot
.54509 .62352 Mdot
.54117 .62352 Mdot
.53333 .6196 Mdot
.52549 .62352 Mdot
.52157 .62352 Mdot
.51765 .62744 Mdot
.51765 .63136 Mdot
.50588 .62352 Mdot
.50588 .6196 Mdot
.50588 .61568 Mdot
.49804 .60783 Mdot
.49412 .59607 Mdot
.48628 .58431 Mdot
.4902 .58823 Mdot
.49804 .58823 Mdot
.49412 .5647 Mdot
.48235 .54902 Mdot
.47451 .54117 Mdot
.47059 .52941 Mdot
.47059 .5098 Mdot
.46275 .48235 Mdot
.42746 .52941 Mdot
.47059 .58823 Mdot
.4902 .61568 Mdot
.49804 .63136 Mdot
.50196 .64313 Mdot
.49804 .6392 Mdot
.49804 .6392 Mdot
.50196 .6392 Mdot
.5098 .64705 Mdot
.5098 .6392 Mdot
.52549 .64705 Mdot
.53333 .66273 Mdot
.54509 .66665 Mdot
.54509 .65489 Mdot
.54509 .65489 Mdot
.55294 .66273 Mdot
.54902 .65881 Mdot
.56078 .6745 Mdot
.56078 .67842 Mdot
.55294 .68234 Mdot
.54509 .6745 Mdot
.54117 .66273 Mdot
.5647 .67842 Mdot
.56078 .6745 Mdot
.56862 .68234 Mdot
.5647 .68234 Mdot
.5647 .6745 Mdot
.5647 .6745 Mdot
.57254 .68234 Mdot
.56078 .6745 Mdot
.56862 .68234 Mdot
.58431 .6941 Mdot
.57254 .68234 Mdot
.57646 .68626 Mdot
.57646 .67842 Mdot
.58823 .67842 Mdot
.59215 .68234 Mdot
.58039 .67842 Mdot
.58431 .68234 Mdot
.57254 .6745 Mdot
.58039 .67842 Mdot
.57646 .68626 Mdot
.58431 .6941 Mdot
.57646 .68234 Mdot
.58823 .69018 Mdot
.58431 .69802 Mdot
.58823 .69802 Mdot
.58823 .69802 Mdot
.59215 .69802 Mdot
.59607 .6941 Mdot
.60391 .69802 Mdot
.59999 .70587 Mdot
.59999 .70587 Mdot
.60391 .70979 Mdot
.59999 .71763 Mdot
.59607 .72155 Mdot
.59607 .72547 Mdot
.60391 .72547 Mdot
.60391 .71763 Mdot
.61568 .72155 Mdot
.62352 .72155 Mdot
.61176 .71371 Mdot
.60783 .70979 Mdot
.59999 .70194 Mdot
.61568 .70587 Mdot
.61176 .70587 Mdot
.6196 .71371 Mdot
.6196 .72155 Mdot
.61568 .72547 Mdot
.61568 .70979 Mdot
.62744 .70587 Mdot
.61568 .6941 Mdot
.61176 .69802 Mdot
.61568 .70194 Mdot
.6196 .69802 Mdot
.61568 .6941 Mdot
.6196 .6941 Mdot
.61176 .6941 Mdot
.61568 .70194 Mdot
.62352 .71371 Mdot
.62744 .72547 Mdot
.62744 .72547 Mdot
.62744 .72547 Mdot
.62352 .72155 Mdot
.62352 .71763 Mdot
.62352 .71763 Mdot
.62352 .72155 Mdot
.61568 .72155 Mdot
.6196 .72155 Mdot
.62744 .71371 Mdot
.62352 .70587 Mdot
.62352 .69802 Mdot
.6196 .6941 Mdot
.63136 .70587 Mdot
.63136 .72155 Mdot
.62352 .72155 Mdot
.62352 .72155 Mdot
.61568 .71763 Mdot
.62352 .72155 Mdot
.62352 .72547 Mdot
.61176 .71371 Mdot
.6196 .71763 Mdot
.61176 .72547 Mdot
.61568 .72155 Mdot
.6196 .71763 Mdot
.61176 .70979 Mdot
.60783 .70194 Mdot
.61176 .69802 Mdot
.61568 .70194 Mdot
.60391 .69802 Mdot
.60391 .69802 Mdot
.60391 .68626 Mdot
.61176 .68234 Mdot
.60391 .69018 Mdot
.60783 .69802 Mdot
.59999 .69018 Mdot
.59999 .69018 Mdot
.59999 .68626 Mdot
.60391 .67842 Mdot
.59607 .6745 Mdot
.58431 .66665 Mdot
.58039 .6745 Mdot
.58823 .68234 Mdot
.57254 .65881 Mdot
.58431 .66665 Mdot
.58431 .66273 Mdot
.57254 .65881 Mdot
.56078 .64705 Mdot
.56862 .65097 Mdot
.56078 .64313 Mdot
.55686 .6392 Mdot
.55686 .6392 Mdot
.55686 .63528 Mdot
.54509 .62352 Mdot
.55686 .6392 Mdot
.54902 .63136 Mdot
.54509 .63136 Mdot
.54117 .6392 Mdot
.53725 .63528 Mdot
.52941 .63528 Mdot
.52941 .63136 Mdot
.52157 .62352 Mdot
.51372 .62352 Mdot
.50196 .61176 Mdot
.50588 .6196 Mdot
.49804 .61568 Mdot
.5098 .6196 Mdot
.49804 .60391 Mdot
.49412 .59215 Mdot
.48628 .58431 Mdot
.48235 .57254 Mdot
.47451 .55686 Mdot
.47843 .55686 Mdot
.47451 .5647 Mdot
.48235 .5647 Mdot
.47451 .56078 Mdot
.46275 .54902 Mdot
.46275 .53333 Mdot
.46275 .5098 Mdot
.45098 .47843 Mdot
.44706 .54509 Mdot
.47843 .59607 Mdot
.49412 .62352 Mdot
.49412 .6392 Mdot
.49804 .64705 Mdot
.4902 .64313 Mdot
.4902 .6392 Mdot
.50196 .64313 Mdot
.51372 .65097 Mdot
.51765 .64313 Mdot
.51765 .63528 Mdot
.52157 .65097 Mdot
.52941 .65881 Mdot
.53725 .65881 Mdot
.54509 .65097 Mdot
.54902 .65097 Mdot
.56078 .66273 Mdot
.55294 .65881 Mdot
.55294 .6745 Mdot
.55294 .68626 Mdot
.56078 .68626 Mdot
.55686 .66273 Mdot
.5647 .65881 Mdot
.55686 .65489 Mdot
.5647 .65881 Mdot
.56078 .66665 Mdot
.55686 .6745 Mdot
.55686 .6745 Mdot
.5647 .68234 Mdot
.5647 .67057 Mdot
.56078 .66273 Mdot
.56862 .67842 Mdot
.57254 .68234 Mdot
.5647 .6745 Mdot
.56078 .66665 Mdot
.58039 .6745 Mdot
.58823 .67842 Mdot
.58823 .67842 Mdot
.58823 .68626 Mdot
.59215 .69018 Mdot
.58823 .69018 Mdot
.59999 .70979 Mdot
.58039 .69018 Mdot
.59215 .6941 Mdot
.58823 .68234 Mdot
.59607 .6941 Mdot
.58039 .6941 Mdot
.59607 .70587 Mdot
.59999 .69802 Mdot
.61176 .69802 Mdot
.61176 .6941 Mdot
.60783 .69018 Mdot
.59215 .69018 Mdot
.59999 .70587 Mdot
.59607 .70979 Mdot
.59999 .71371 Mdot
.59999 .71371 Mdot
.60391 .70979 Mdot
.61176 .70979 Mdot
.60391 .70194 Mdot
.60783 .70587 Mdot
.60783 .70587 Mdot
.59215 .70194 Mdot
.59999 .70979 Mdot
.60391 .70587 Mdot
.60783 .70979 Mdot
.61176 .71371 Mdot
.60783 .71763 Mdot
.60783 .72155 Mdot
.61176 .70979 Mdot
.6196 .70979 Mdot
.61568 .70194 Mdot
.6196 .70587 Mdot
.61176 .69802 Mdot
.61568 .70194 Mdot
.60391 .69018 Mdot
.61176 .69018 Mdot
.61568 .68626 Mdot
.6196 .69018 Mdot
.6196 .69802 Mdot
.62352 .70979 Mdot
.6196 .70979 Mdot
.6196 .71371 Mdot
.62352 .71371 Mdot
.61176 .70194 Mdot
.61176 .69802 Mdot
.61568 .70979 Mdot
.6196 .71763 Mdot
.61568 .70979 Mdot
.61568 .70194 Mdot
.61176 .69018 Mdot
.6196 .6941 Mdot
.62352 .70587 Mdot
.62352 .70979 Mdot
.61568 .71371 Mdot
.62352 .72155 Mdot
.61176 .71371 Mdot
.61568 .70979 Mdot
.62744 .71371 Mdot
.62744 .70587 Mdot
.61176 .6941 Mdot
.61568 .69802 Mdot
.61176 .70194 Mdot
.60391 .69802 Mdot
.61176 .69802 Mdot
.61568 .69802 Mdot
.61176 .6941 Mdot
.61568 .70194 Mdot
.61176 .70194 Mdot
.60783 .70194 Mdot
.60391 .70194 Mdot
.59607 .69018 Mdot
.58823 .67842 Mdot
.58823 .68234 Mdot
.59607 .6941 Mdot
.58431 .6941 Mdot
.58431 .68626 Mdot
.58431 .67842 Mdot
.58039 .65881 Mdot
.58823 .66273 Mdot
.58039 .65881 Mdot
.58431 .6745 Mdot
.58039 .68234 Mdot
.57646 .6745 Mdot
.57254 .66665 Mdot
.56078 .64313 Mdot
.57646 .65097 Mdot
.5647 .65097 Mdot
.55686 .65097 Mdot
.55686 .65881 Mdot
.56862 .66665 Mdot
.55294 .65881 Mdot
.55686 .65489 Mdot
.54509 .6392 Mdot
.54117 .63136 Mdot
.54509 .63136 Mdot
.53333 .63528 Mdot
.53333 .64313 Mdot
.52941 .64313 Mdot
.53333 .65097 Mdot
.51765 .63136 Mdot
.50588 .61176 Mdot
.51765 .60783 Mdot
.5098 .60391 Mdot
.50588 .60783 Mdot
.49804 .61176 Mdot
.50196 .60783 Mdot
.50588 .60783 Mdot
.48628 .59215 Mdot
.4902 .58431 Mdot
.4902 .58431 Mdot
.48235 .57646 Mdot
.48235 .5647 Mdot
.47059 .5647 Mdot
.46275 .55686 Mdot
.45491 .55294 Mdot
.45491 .54509 Mdot
.45491 .52941 Mdot
.45491 .50588 Mdot
.44314 .47451 Mdot
.4353 .53725 Mdot
.46667 .58039 Mdot
.49412 .61568 Mdot
.50196 .64705 Mdot
.4902 .64705 Mdot
.49412 .64705 Mdot
.48628 .6392 Mdot
.4902 .6392 Mdot
.50588 .64313 Mdot
.51372 .64313 Mdot
.5098 .6392 Mdot
.52549 .65881 Mdot
.52549 .65097 Mdot
.53333 .65489 Mdot
.54509 .65881 Mdot
.55294 .65881 Mdot
.54117 .65097 Mdot
.55294 .65881 Mdot
.55686 .65489 Mdot
.55686 .65881 Mdot
.5647 .66273 Mdot
.56078 .65489 Mdot
.55686 .6392 Mdot
.56078 .63528 Mdot
.57646 .64313 Mdot
.5647 .64313 Mdot
.57254 .65881 Mdot
.56862 .65489 Mdot
.56078 .65881 Mdot
.57646 .67057 Mdot
.56862 .66273 Mdot
.56862 .65881 Mdot
.57254 .67057 Mdot
.56862 .67057 Mdot
.5647 .67842 Mdot
.57254 .68626 Mdot
.57254 .68626 Mdot
.58039 .68626 Mdot
.59215 .69802 Mdot
.58823 .70587 Mdot
.59215 .70979 Mdot
.58431 .69802 Mdot
.58039 .69802 Mdot
.58823 .70587 Mdot
.58823 .70194 Mdot
.58823 .68626 Mdot
.58823 .6941 Mdot
.59607 .69802 Mdot
.59607 .69018 Mdot
.60391 .69018 Mdot
.60783 .69018 Mdot
.59607 .67842 Mdot
.59999 .67842 Mdot
.59607 .69018 Mdot
.59607 .69802 Mdot
.59999 .70587 Mdot
.60391 .69802 Mdot
.59607 .69018 Mdot
.60391 .69802 Mdot
.59999 .69802 Mdot
.59999 .70194 Mdot
.58823 .69018 Mdot
.58823 .6941 Mdot
.58823 .70587 Mdot
.58431 .70194 Mdot
.59607 .70587 Mdot
.60391 .71763 Mdot
.60391 .72155 Mdot
.60391 .70979 Mdot
.60391 .70194 Mdot
.61176 .70194 Mdot
.61176 .69802 Mdot
.61176 .70587 Mdot
.6196 .71371 Mdot
.60783 .70587 Mdot
.60391 .6941 Mdot
.6196 .68626 Mdot
.62352 .68234 Mdot
.62352 .68234 Mdot
.6196 .6941 Mdot
.6196 .70587 Mdot
.61176 .70587 Mdot
.62352 .71371 Mdot
.61568 .70979 Mdot
.61568 .70194 Mdot
.60783 .68626 Mdot
.61176 .70194 Mdot
.6196 .71763 Mdot
.61176 .70587 Mdot
.61568 .70194 Mdot
.61568 .6941 Mdot
.61176 .68234 Mdot
.61568 .6941 Mdot
.61568 .69802 Mdot
.60783 .69802 Mdot
.61176 .71763 Mdot
.60783 .70979 Mdot
.60391 .70194 Mdot
.61176 .69018 Mdot
.60391 .6745 Mdot
.61176 .67842 Mdot
.61176 .6745 Mdot
.60783 .68234 Mdot
.59999 .69018 Mdot
.59999 .6941 Mdot
.59607 .6941 Mdot
.59607 .6941 Mdot
.60391 .70194 Mdot
.59607 .70587 Mdot
.59215 .70194 Mdot
.58823 .6941 Mdot
.59215 .69018 Mdot
.59607 .69018 Mdot
.58431 .6745 Mdot
.58431 .67842 Mdot
.58431 .67842 Mdot
.58431 .68234 Mdot
.58039 .67057 Mdot
.58431 .67057 Mdot
.58431 .66665 Mdot
.57254 .65097 Mdot
.57646 .66273 Mdot
.57254 .66665 Mdot
.56862 .66273 Mdot
.58039 .66665 Mdot
.56862 .65097 Mdot
.57254 .63528 Mdot
.56078 .62352 Mdot
.55294 .63136 Mdot
.55686 .64705 Mdot
.54902 .64705 Mdot
.54902 .65489 Mdot
.54509 .64705 Mdot
.53725 .6196 Mdot
.54509 .61568 Mdot
.52941 .60391 Mdot
.53725 .61568 Mdot
.52941 .62352 Mdot
.52157 .62352 Mdot
.53333 .6392 Mdot
.52157 .62744 Mdot
.51765 .61176 Mdot
.51372 .59999 Mdot
.50196 .58823 Mdot
.49804 .59607 Mdot
.49412 .59999 Mdot
.48628 .60391 Mdot
.4902 .61176 Mdot
.48235 .59999 Mdot
.47451 .58823 Mdot
.46275 .57254 Mdot
.46667 .56862 Mdot
.45491 .56078 Mdot
.44706 .56078 Mdot
.44706 .5647 Mdot
.44314 .55294 Mdot
.4353 .53333 Mdot
.44706 .53333 Mdot
.44314 .50588 Mdot
.4353 .45883 Mdot
.4353 .52157 Mdot
.45098 .57254 Mdot
.48235 .60783 Mdot
.4902 .62352 Mdot
.49804 .63136 Mdot
.49412 .63528 Mdot
.47843 .6392 Mdot
.47843 .63528 Mdot
.49804 .64705 Mdot
.50196 .6392 Mdot
.51372 .64313 Mdot
.52941 .64313 Mdot
.53333 .6392 Mdot
.53725 .6392 Mdot
.54117 .6392 Mdot
.54902 .64313 Mdot
.55294 .65489 Mdot
.55686 .65881 Mdot
.55686 .65097 Mdot
.55294 .64313 Mdot
.55686 .64313 Mdot
.53725 .63136 Mdot
.54902 .63528 Mdot
.54902 .63528 Mdot
.5647 .64313 Mdot
.56078 .63136 Mdot
.5647 .63528 Mdot
.55294 .63136 Mdot
.56078 .65489 Mdot
.56078 .67057 Mdot
.56862 .68234 Mdot
.57254 .68234 Mdot
.57646 .67842 Mdot
.56862 .67057 Mdot
.56862 .67842 Mdot
.56078 .68234 Mdot
.57254 .70587 Mdot
.56078 .69802 Mdot
.56862 .69802 Mdot
.58431 .70194 Mdot
.57646 .67842 Mdot
.5647 .67057 Mdot
.58039 .68626 Mdot
.58431 .6941 Mdot
.58039 .69802 Mdot
.56862 .68234 Mdot
.57646 .68234 Mdot
.58039 .67842 Mdot
.58431 .6745 Mdot
.59999 .67057 Mdot
.60391 .6745 Mdot
.58823 .67057 Mdot
.59215 .6745 Mdot
.59215 .67057 Mdot
.59607 .6745 Mdot
.59999 .6745 Mdot
.59215 .66665 Mdot
.60391 .6745 Mdot
.60391 .6745 Mdot
.59607 .67842 Mdot
.58823 .68234 Mdot
.59607 .68626 Mdot
.60783 .6941 Mdot
.59999 .68626 Mdot
.59999 .68626 Mdot
.59999 .69018 Mdot
.58431 .68626 Mdot
.59215 .6941 Mdot
.59999 .69018 Mdot
.59215 .68234 Mdot
.59607 .67057 Mdot
.59215 .66665 Mdot
.58823 .66273 Mdot
.59607 .6745 Mdot
.59999 .68234 Mdot
.60391 .67842 Mdot
.60783 .6745 Mdot
.60391 .65881 Mdot
.61176 .66665 Mdot
.60783 .6745 Mdot
.60391 .68626 Mdot
.59999 .69018 Mdot
.60391 .6941 Mdot
.60783 .6941 Mdot
.59999 .68626 Mdot
.60391 .69018 Mdot
.59999 .69018 Mdot
.60391 .6941 Mdot
.60391 .69018 Mdot
.60391 .68234 Mdot
.61176 .6745 Mdot
.60783 .65881 Mdot
.59999 .65881 Mdot
.60783 .68626 Mdot
.60783 .69802 Mdot
.60391 .70194 Mdot
.59999 .69018 Mdot
.59607 .67842 Mdot
.60391 .67842 Mdot
.59999 .67057 Mdot
.60391 .66665 Mdot
.60391 .66665 Mdot
.59999 .66665 Mdot
.58431 .67057 Mdot
.58823 .68234 Mdot
.58431 .69018 Mdot
.59215 .70194 Mdot
.59215 .70194 Mdot
.59215 .69802 Mdot
.59215 .69802 Mdot
.58431 .69018 Mdot
.59215 .69018 Mdot
.58431 .68234 Mdot
.58823 .68234 Mdot
.58431 .67842 Mdot
.58039 .66665 Mdot
.57646 .66273 Mdot
.58431 .6745 Mdot
.57646 .66665 Mdot
.56078 .64705 Mdot
.56862 .65097 Mdot
.56078 .64705 Mdot
.56862 .65881 Mdot
.5647 .64705 Mdot
.56862 .6392 Mdot
.57646 .64313 Mdot
.56862 .63136 Mdot
.56078 .62352 Mdot
.55294 .62744 Mdot
.56078 .63528 Mdot
.54509 .63136 Mdot
.53333 .64313 Mdot
.54117 .65097 Mdot
.52941 .63136 Mdot
.53725 .62352 Mdot
.52157 .60391 Mdot
.51765 .59607 Mdot
.51372 .59607 Mdot
.51765 .60391 Mdot
.51765 .60783 Mdot
.5098 .59999 Mdot
.50196 .59999 Mdot
.49804 .59999 Mdot
.48628 .58823 Mdot
.48628 .59215 Mdot
.49412 .59607 Mdot
.47843 .59607 Mdot
.47451 .59607 Mdot
.47059 .59215 Mdot
.47059 .58823 Mdot
.45883 .57646 Mdot
.45098 .57254 Mdot
.45491 .58039 Mdot
.43922 .56078 Mdot
.42746 .54509 Mdot
.4353 .54509 Mdot
.43922 .54117 Mdot
.42746 .52157 Mdot
.4353 .50196 Mdot
.42746 .46275 Mdot
.42746 .5098 Mdot
.45491 .5647 Mdot
.47843 .59607 Mdot
.48628 .60391 Mdot
.4902 .61568 Mdot
.47843 .61568 Mdot
.47843 .63136 Mdot
.48235 .64313 Mdot
.49804 .65097 Mdot
.51372 .64705 Mdot
.53333 .6392 Mdot
.52941 .63136 Mdot
.51372 .62744 Mdot
.52549 .63136 Mdot
.52549 .62744 Mdot
.52941 .62744 Mdot
.54902 .64705 Mdot
.55686 .65097 Mdot
.56078 .64313 Mdot
.55686 .63528 Mdot
.54902 .6392 Mdot
.54902 .65097 Mdot
.55294 .65489 Mdot
.54509 .65097 Mdot
.5647 .65881 Mdot
.57254 .65097 Mdot
.56862 .64705 Mdot
.5647 .64705 Mdot
.55686 .65881 Mdot
.5647 .68234 Mdot
.57254 .6941 Mdot
.5647 .68234 Mdot
.57254 .67842 Mdot
.56862 .67057 Mdot
.56078 .67842 Mdot
.57254 .69018 Mdot
.58039 .70587 Mdot
.57254 .70587 Mdot
.56078 .68626 Mdot
.56862 .68626 Mdot
.57646 .6745 Mdot
.58039 .67057 Mdot
.56862 .66665 Mdot
.56862 .66273 Mdot
.56078 .67057 Mdot
.55294 .66273 Mdot
.54509 .65489 Mdot
.55294 .65097 Mdot
.54902 .63528 Mdot
.54117 .62352 Mdot
.54902 .6392 Mdot
.55294 .65097 Mdot
.5647 .65097 Mdot
.56862 .64705 Mdot
.56862 .64313 Mdot
.58431 .64313 Mdot
.58823 .64313 Mdot
.58823 .64313 Mdot
.58823 .65097 Mdot
.59607 .65881 Mdot
.60783 .6745 Mdot
.59215 .66273 Mdot
.60391 .67057 Mdot
.60391 .67057 Mdot
.60783 .67057 Mdot
.60783 .67057 Mdot
.59999 .67842 Mdot
.60783 .69018 Mdot
.59215 .6745 Mdot
.59215 .66273 Mdot
.60391 .66665 Mdot
.59215 .65489 Mdot
.59607 .65881 Mdot
.59999 .66665 Mdot
.61568 .67842 Mdot
.59999 .66665 Mdot
.59607 .65881 Mdot
.60783 .66273 Mdot
.60783 .66665 Mdot
.60391 .67057 Mdot
.60391 .68234 Mdot
.59215 .67842 Mdot
.60391 .69018 Mdot
.59215 .68234 Mdot
.59999 .68626 Mdot
.59607 .68626 Mdot
.60391 .69018 Mdot
.60783 .69802 Mdot
.61176 .69802 Mdot
.59999 .68234 Mdot
.60391 .6745 Mdot
.60391 .66273 Mdot
.59999 .65881 Mdot
.59999 .66665 Mdot
.59215 .67057 Mdot
.59607 .68234 Mdot
.59607 .67842 Mdot
.60391 .68234 Mdot
.59607 .67057 Mdot
.59999 .66665 Mdot
.59999 .67057 Mdot
.59607 .66665 Mdot
.59607 .67057 Mdot
.58039 .66665 Mdot
.58039 .6745 Mdot
.58823 .68234 Mdot
.57646 .6745 Mdot
.58039 .68234 Mdot
.59215 .69018 Mdot
.59215 .69018 Mdot
.57646 .67842 Mdot
.58431 .68234 Mdot
.57646 .67842 Mdot
.57254 .66273 Mdot
.58039 .66273 Mdot
.57646 .65097 Mdot
.57646 .64705 Mdot
.56862 .64705 Mdot
.56862 .64313 Mdot
.5647 .63528 Mdot
.57254 .63528 Mdot
.57646 .64313 Mdot
.55686 .63136 Mdot
.55294 .63528 Mdot
.55686 .6392 Mdot
.56078 .6392 Mdot
.55294 .63136 Mdot
.54509 .61568 Mdot
.54902 .61568 Mdot
.55686 .62352 Mdot
.53333 .6196 Mdot
.52941 .63136 Mdot
.52549 .6392 Mdot
.52157 .63528 Mdot
.51765 .62352 Mdot
.52157 .60391 Mdot
.52157 .59215 Mdot
.51765 .58823 Mdot
.51372 .59215 Mdot
.52157 .59999 Mdot
.50588 .59215 Mdot
.49804 .59999 Mdot
.50196 .60391 Mdot
.49412 .59999 Mdot
.4902 .58823 Mdot
.48235 .58039 Mdot
.47059 .57646 Mdot
.47059 .58431 Mdot
.47059 .59215 Mdot
.45491 .59215 Mdot
.44706 .58039 Mdot
.45883 .57646 Mdot
.45883 .56862 Mdot
.45491 .56078 Mdot
.44314 .54117 Mdot
.43922 .54117 Mdot
.43138 .53333 Mdot
.41961 .51372 Mdot
.41177 .48628 Mdot
.41961 .46275 Mdot
.43138 .5098 Mdot
.48235 .57646 Mdot
.50588 .60783 Mdot
.50196 .61568 Mdot
.50196 .6196 Mdot
.4902 .61176 Mdot
.48235 .6196 Mdot
.49804 .6392 Mdot
.50588 .64705 Mdot
.5098 .64313 Mdot
.52549 .63136 Mdot
.53333 .6196 Mdot
.52157 .61176 Mdot
.53333 .62744 Mdot
.53725 .63528 Mdot
.53725 .6392 Mdot
.54509 .64313 Mdot
.56078 .64313 Mdot
.5647 .63528 Mdot
.56078 .63136 Mdot
.55686 .62744 Mdot
.55686 .6392 Mdot
.54902 .65097 Mdot
.53333 .64705 Mdot
.54117 .64313 Mdot
.55686 .6392 Mdot
.56862 .63528 Mdot
.5647 .63528 Mdot
.56078 .64705 Mdot
.5647 .67057 Mdot
.56078 .68234 Mdot
.5647 .68234 Mdot
.5647 .68234 Mdot
.56078 .67057 Mdot
.56862 .67057 Mdot
.5647 .67057 Mdot
.57254 .68234 Mdot
.56862 .69018 Mdot
.5647 .67842 Mdot
.5647 .67057 Mdot
.58039 .66273 Mdot
.58823 .66273 Mdot
.57646 .65097 Mdot
.57254 .64705 Mdot
.56078 .65097 Mdot
.55686 .66273 Mdot
.55294 .66273 Mdot
.54902 .64313 Mdot
.54117 .6196 Mdot
.52941 .60783 Mdot
.52941 .61568 Mdot
.51372 .61568 Mdot
.51372 .62352 Mdot
.5098 .61568 Mdot
.50588 .59999 Mdot
.52549 .59999 Mdot
.52941 .58431 Mdot
.53725 .58823 Mdot
.54117 .59607 Mdot
.55686 .60783 Mdot
.5647 .6196 Mdot
.56862 .62352 Mdot
.58431 .63528 Mdot
.60391 .65097 Mdot
.61568 .65881 Mdot
.60783 .65489 Mdot
.60783 .66273 Mdot
.60783 .67057 Mdot
.58823 .66273 Mdot
.60391 .66665 Mdot
.60783 .65489 Mdot
.60783 .64705 Mdot
.60783 .65097 Mdot
.60391 .66273 Mdot
.61176 .6745 Mdot
.61176 .67842 Mdot
.59215 .65881 Mdot
.60783 .65881 Mdot
.61176 .65489 Mdot
.60391 .65489 Mdot
.59607 .66273 Mdot
.59999 .67842 Mdot
.60391 .68234 Mdot
.59999 .67842 Mdot
.59215 .67057 Mdot
.59999 .67842 Mdot
.60783 .68234 Mdot
.59607 .67057 Mdot
.58823 .67842 Mdot
.58431 .6745 Mdot
.59607 .67057 Mdot
.59999 .66273 Mdot
.59607 .66273 Mdot
.60391 .67057 Mdot
.59607 .66273 Mdot
.59215 .67057 Mdot
.59215 .67057 Mdot
.59607 .67057 Mdot
.58823 .66273 Mdot
.58431 .65489 Mdot
.60391 .66665 Mdot
.59999 .67057 Mdot
.60391 .68626 Mdot
.58431 .67057 Mdot
.58039 .65881 Mdot
.58039 .65489 Mdot
.58039 .65881 Mdot
.58431 .65881 Mdot
.58431 .66273 Mdot
.58039 .66665 Mdot
.57254 .67057 Mdot
.58823 .67842 Mdot
.58431 .65881 Mdot
.58431 .64705 Mdot
.57646 .64705 Mdot
.56862 .6392 Mdot
.56862 .6392 Mdot
.5647 .63136 Mdot
.5647 .62744 Mdot
.56862 .62744 Mdot
.57254 .62352 Mdot
.57646 .62744 Mdot
.56862 .63136 Mdot
.55294 .63528 Mdot
.54902 .6392 Mdot
.53725 .62352 Mdot
.55294 .63136 Mdot
.54509 .62352 Mdot
.55294 .62352 Mdot
.55294 .61568 Mdot
.54117 .61568 Mdot
.53333 .62352 Mdot
.52549 .63136 Mdot
.52157 .63136 Mdot
.51765 .6196 Mdot
.51372 .59215 Mdot
.51765 .58431 Mdot
.5098 .58431 Mdot
.50588 .58431 Mdot
.5098 .59607 Mdot
.50588 .60391 Mdot
.49804 .59999 Mdot
.49412 .58823 Mdot
.49412 .58431 Mdot
.48628 .57254 Mdot
.48628 .57254 Mdot
.48235 .57254 Mdot
.47059 .57254 Mdot
.46667 .58039 Mdot
.45491 .58039 Mdot
.44314 .57254 Mdot
.44314 .56078 Mdot
.45491 .54509 Mdot
.45098 .52549 Mdot
.4353 .52157 Mdot
.43138 .52157 Mdot
.41177 .50588 Mdot
.41569 .51372 Mdot
.41177 .4902 Mdot
.38432 .43922 Mdot
.43138 .5098 Mdot
.48628 .56862 Mdot
.4902 .58431 Mdot
.48628 .58823 Mdot
.48235 .58823 Mdot
.49412 .59607 Mdot
.4902 .59999 Mdot
.49804 .61176 Mdot
.49804 .6196 Mdot
.51372 .62352 Mdot
.52157 .62352 Mdot
.51765 .60391 Mdot
.52549 .60783 Mdot
.52941 .6196 Mdot
.54509 .63528 Mdot
.54117 .63136 Mdot
.54902 .63136 Mdot
.56078 .63136 Mdot
.56078 .61568 Mdot
.5647 .61568 Mdot
.55294 .61568 Mdot
.5647 .63528 Mdot
.55294 .63136 Mdot
.55294 .6392 Mdot
.55686 .63528 Mdot
.5647 .63136 Mdot
.57254 .63528 Mdot
.5647 .64313 Mdot
.5647 .65097 Mdot
.56078 .65881 Mdot
.55686 .65881 Mdot
.5647 .66273 Mdot
.56078 .65881 Mdot
.5647 .65881 Mdot
.56078 .65097 Mdot
.57254 .65489 Mdot
.57646 .65881 Mdot
.56862 .66665 Mdot
.57254 .6745 Mdot
.57646 .66665 Mdot
.58823 .66273 Mdot
.58431 .64705 Mdot
.58431 .64313 Mdot
.56862 .6392 Mdot
.57254 .65097 Mdot
.57646 .65881 Mdot
.57646 .65881 Mdot
.58039 .65881 Mdot
.56862 .64705 Mdot
.56862 .64313 Mdot
.55294 .63136 Mdot
.54509 .63528 Mdot
.51765 .62352 Mdot
.52157 .61568 Mdot
.5098 .59999 Mdot
.5098 .58039 Mdot
.50588 .56078 Mdot
.50588 .55686 Mdot
.50196 .56078 Mdot
.49804 .5647 Mdot
.49412 .5647 Mdot
.4902 .55686 Mdot
.49804 .56078 Mdot
.49804 .56078 Mdot
.50196 .56078 Mdot
.53333 .57646 Mdot
.55294 .58823 Mdot
.57254 .60783 Mdot
.58039 .61568 Mdot
.59999 .62744 Mdot
.60391 .62352 Mdot
.60783 .62352 Mdot
.60391 .63136 Mdot
.59999 .64705 Mdot
.59215 .64705 Mdot
.60783 .65097 Mdot
.59607 .6392 Mdot
.61176 .65097 Mdot
.60391 .63528 Mdot
.60783 .63136 Mdot
.60783 .6392 Mdot
.60783 .65097 Mdot
.58823 .64705 Mdot
.58823 .64705 Mdot
.59607 .65097 Mdot
.60391 .66273 Mdot
.59607 .66273 Mdot
.59999 .66273 Mdot
.59215 .66273 Mdot
.58039 .65489 Mdot
.58431 .65097 Mdot
.58823 .64705 Mdot
.59215 .64705 Mdot
.59215 .64313 Mdot
.58039 .63528 Mdot
.58431 .65097 Mdot
.59215 .65881 Mdot
.58823 .65489 Mdot
.59215 .65881 Mdot
.59999 .65881 Mdot
.60391 .65881 Mdot
.58823 .65489 Mdot
.59607 .67057 Mdot
.59215 .67057 Mdot
.58431 .65489 Mdot
.58039 .65097 Mdot
.59607 .65489 Mdot
.58431 .6392 Mdot
.58431 .6392 Mdot
.57254 .63528 Mdot
.58823 .64705 Mdot
.57254 .63528 Mdot
.58039 .62352 Mdot
.58039 .61568 Mdot
.58039 .61568 Mdot
.57254 .61176 Mdot
.5647 .60783 Mdot
.56862 .61568 Mdot
.56078 .61568 Mdot
.5647 .60783 Mdot
.55686 .59607 Mdot
.56862 .59215 Mdot
.56862 .59607 Mdot
.55686 .59999 Mdot
.54509 .61568 Mdot
.53725 .62744 Mdot
.53333 .61568 Mdot
.54117 .61568 Mdot
.55294 .61568 Mdot
.54117 .59999 Mdot
.53333 .59607 Mdot
.53333 .60783 Mdot
.5098 .59999 Mdot
.50588 .60391 Mdot
.51765 .61176 Mdot
.5098 .59607 Mdot
.50588 .58039 Mdot
.5098 .57254 Mdot
.5098 .57254 Mdot
.50196 .58039 Mdot
.50588 .58431 Mdot
.49412 .57646 Mdot
.47843 .55686 Mdot
.48628 .56078 Mdot
.47843 .55686 Mdot
.46667 .54509 Mdot
.46275 .54509 Mdot
.46275 .55294 Mdot
.45098 .55294 Mdot
.45491 .55686 Mdot
.44314 .54902 Mdot
.43138 .52941 Mdot
.4353 .51765 Mdot
.43922 .51372 Mdot
.4353 .50588 Mdot
.42746 .49412 Mdot
.40393 .48235 Mdot
.40785 .47843 Mdot
.40785 .46667 Mdot
.40393 .44314 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo000No`3o0004ooooool0o`3o0?l0o`3o0?cooooo0Ol00001oooo
o`008ol0o`3kooooo`7o00000Oooool002?o0?l0noooool1o`00007ooooo000To`3o0?[ooooo0Ol0
0001ooooo`009Ol0o`3iooooo`7o00000Oooool002Go0?l0nOooool1o`00007ooooo000Uo`3o0?Wo
oooo0Ol00001ooooo`009_l0o`3hooooo`7o00000Oooool002Ko0?l0n?ooool1o`00007ooooo000V
o`3o0003ooooool0o`3o0?l000;o0?l0loooool1o`00007ooooo0004o`3o00?o003o9Ol0o`3boooo
o`7o00000Oooool00003o`000?oooooo0?l000Go003o9Ol0o`3aooooo`7o00000Oooool00003o`00
0?oooooo0?l000Go003o9Ol0o`3aooooo`7o00000Oooool00003o`000?oooooooooo00Go003o9Ol0
o`3aooooo`7o00000Oooool00004o`000?ooooooooooo`3o00?o003o9ol0o`3`ooooo`7o00000Ooo
ool00003o`000?oooooo0?l002co0?l0koooool1o`00007ooooo00000ol0003oooooo`3o0005o`3o
00?o003o9?l0o`3_ooooo`7o00000Oooool00003o`000?oooooo0?l000Co0?l01Ol00?lSo`3o0>oo
oooo0Ol00001ooooo`0000?o0000ooooooooool01?l0o`05o`00obCo0?l000Coooooo`3o0?l0o`3o
0?l0j_ooool1o`00007ooooo00001?l0003oooooooooooooool3o`3o00Go003o:Ol0o`3Yooooo`7o
00000Oooool00003o`000?oooooooooo00;ooooo0ol0o`03o`00ob[o0?l0jOooool1o`00007ooooo
00000ol0003oooooooooo`06ooooocKo0?l0goooool1o`00007ooooo00000ol0003oooooooooo`06
ooooocgo0?l0f?ooool1o`00007ooooo00000ol0003oooooooooo`07ooooocgo0?l0eoooool1o`00
007ooooo00000ol0003oooooooooo`08ooooo`04o`3o0?l00?oo003oo`00ocSo0?l0eoooool1o`00
007ooooo00000ol0003oooooooooo`08ooooo`Go003o0ol0o`03o`00oc7o0?l0eoooool1o`00007o
oooo00000ol0003oooooooooo`08ooooo`Go003o0_l0o`05o`00oc7o0?l0e_ooool1o`00007ooooo
00000ol0003oooooooooo`08ooooo`Go003o0_l0o`06o`00o`ko0?l00ol00?lOo`3o0=Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool02Oooool3o`00o`?o0?l01_l00?l=o`3o00Go003o7_l0o`3F
ooooo`7o00000Oooool00003o`000?oooooooooo00cooooo1?l0o`05o`00o`go0?l01Ol00?lMo`3o
0=Oooooo0Ol00001ooooo`0000?o0000ooooooooool03Oooool4o`3o00Co003o3Ol0o`05o`00oaco
0?l0f?ooool1o`00007ooooo00000ol0003oooooooooo`0>ooooo`?o0?l01Ol00?l=o`3o00?o003o
7?l0o`3Iooooo`7o00000Oooool00003o`000?oooooooooo00gooooo0ol00?l00ol0o`3o003oo`00
o`03o`00obgo0?l0f?ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`[o003o1_l0o`03
o`00obGo0?l0eoooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`Go003o00Co0?l0o`00
ool00?oo003o1_l0o`05o`00obGo0?l0e_ooool1o`00007ooooo00000ol0003oooooooooo`0<oooo
o`Go003o2Ol0o`06o`00obOo0?l0e?ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`?o
003o1?l0o`03o`00o`;o0?l01ol00?l3o`3o00?o003o8ol0o`3Booooo`7o00000Oooool00003o`00
0?oooooooooo017ooooo0_l0o`0<o`00o`?o0?l01Ol00?lTo`3o0=3ooooo0Ol00001ooooo`0000?o
0000ooooooooool04oooool;o`00o`Co0?l01Ol00?lUo`3o0<oooooo0Ol00001ooooo`0000?o0000
ooooooooool04oooool:o`00o`Go0?l01Ol00?l4o`3o00?o003o7_l0o`3?ooooo`7o00000Oooool0
0003o`000?oooooooooo01Cooooo0ol00?l2o`3o00?o003o1ol0o`03o`00o`Co0?l01Ol00?lMo`3o
0<oooooo0Ol00001ooooo`0000?o0000ooooooooool05oooool2o`3o00?o003o3_l0o`05o`00oaco
0?l0d?ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`Go003o3Ol0o`05o`00ob3o0?l0
c?ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`Go003o1ol0o`03o`00o`Co0?l00ol0
0?lTo`3o0<Wooooo0Ol00001ooooo`0000?o0000ooooooooool06?ooool5o`00o`Ko0?l01Ol00?l[
o`3o0<Sooooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool3o`00o`Oo0?l01_l00?l[o`3o
0<Oooooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool:o`3o00So003o;?l0o`34ooooo`7o
00000Oooool00003o`000?oooooooooo01[ooooo2_l0o`08o`00obco0?l0`oooool1o`00007ooooo
00000ol0003oooooooooo`0Looooo`So0?l02?l00?l/o`3o0<?ooooo0Ol00001ooooo`0000?o0000
ooooooooool07?ooool9o`3o00Oo003o0_l0o`03o`00obSo0?l0`_ooool1o`00007ooooo00000ol0
003oooooooooo`0Mooooo`04o`3o0?l00?oo003oo`00o`Co0?l01ol00?l00ol0o`3o003oo`00o`03
o`00obOo0?l0`_ooool1o`00007ooooo00000ol0003oooooooooo`0Mooooo`Go003o0ol0o`0=o`00
obOo0?l0`_ooool1o`00007ooooo00000ol0003oooooooooo`0Mooooo`Go003o0ol0o`0=o`00obOo
0?l0`_ooool1o`00007ooooo00000ol0003oooooooooo`0Mooooo`Go003o1?l0o`0?o`00obCo0?l0
`_ooool1o`00007ooooo00000ol0003oooooooooo`0Nooooo`?o003o0_l0o`000ooooooo0?l0o`3o
0003o`3o00go003o9ol0o`2nooooo`7o00000Oooool00003o`000?oooooooooo01oooooo0ol0o`02
ooooo`Oo0?l02ol00?lXo`3o0;gooooo0Ol00001ooooo`0000?o0000ooooooooool09?ooool6o`3o
00co003o:?l0o`2mooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo1Ol0o`05o`00o`03
o`3o0?l00?oo003o00Go003o1_l0o`03o`00oako0?l0_Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Xooooo`;o0?l01Ol00?l2o`3o00Oo003o1?l0o`05o`00oako0?l0_?ooool1o`00007ooooo
00000ol0003oooooooooo`0Yooooo`;o0?l00ol00?l2o`3o00So003o1?l0o`05o`00oaoo0?l0^ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`?o003o00?o0?l0ooooool0o`000ol0o`09
o`00o`03o`3o0?l00?oo003o00Ko003o8?l0o`2jooooo`7o00000Oooool00003o`000?oooooooooo
02Gooooo1ol00?l3o`3o017o003o8_l0o`2iooooo`7o00000Oooool00003o`000?oooooooooo02Go
oooo2?l00?l2o`3o00ko003o9Ol0o`2iooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo
2?l00?l3o`3o00go003o9Ol0o`000ooooooo0?l0o`3o0004o`3o0;;ooooo0Ol00001ooooo`0000?o
0000ooooooooool09_ooool7o`00o`04ooooool0o`3o0?l0o`3o00_o003o;_l0o`2aooooo`7o0000
0Oooool00003o`000?oooooooooo02Oooooo1Ol00?l5ooooo`Go003o00?o0?l0o`00ool00?l00ol0
0?l^o`3o0;7ooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool3o`00o`Oooooo0ol00?l2
o`3o00Go003o;_l0o`2aooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo0ol0o`06o`00
obko0?l000Coooooo`3o0?l0o`3o0?l0[_ooool1o`00007ooooo00000ol0003oooooooooo`0aoooo
o`?o0?l01Ol00?l_o`3o0003ooooool0o`3o0?l000?o0?l0[Oooool1o`00007ooooo00000ol0003o
ooooooooo`0`ooooo`Co0?l01Ol00?leo`3o0:gooooo0Ol00001ooooo`0000?o0000ooooooooool0
<?ooool4o`3o00Ko003o2_l0o`03o`00obOo0?l0[Oooool1o`00007ooooo00000ol0003ooooooooo
o`0`ooooo`Go0?l01Ol00?l6o`3o00So003o9_l0o`2]ooooo`7o00000Oooool00003o`000?oooooo
oooo037ooooo0ol0o`000ooooooo003oo`00o`06o`00o`;o0?l02ol00?l<o`3o00?o003o5ol0o`2[
ooooo`7o00000Oooool00003o`000?oooooooooo03Cooooo2_l00?l00ol0o`3o003oo`00o`0:o`00
o`[o0?l01Ol00?lGo`3o0:[ooooo0Ol00001ooooo`0000?o0000ooooooooool0<oooool;o`00o`03
o`3o0?l00?oo003o00[o003o2_l0o`05o`00o`go0?l00_ooool8o`3o0:[ooooo0Ol00001ooooo`00
00?o0000ooooooooool0<oooool;o`00o`;o0?l00ol00?l3o`3o00Go003o2_l0o`05o`00o`oo0?l0
00?oooooo`3o0?l0o`001Ol0o`2Zooooo`7o00000Oooool00003o`000?oooooooooo03?ooooo1_l0
0?l01?oooooo003oo`00ool00?l9o`3o00Go003o2ol0o`03o`00o`So0?l00_ooool=o`3o0:_ooooo
0Ol00001ooooo`0000?o0000ooooooooool0=?ooool3o`00o`Cooooo2Ol0o`06o`00oaKo0?l00_oo
oolAo`3o0:Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>_ooool9o`3o00Go003o;?l0o`2W
ooooo`7o00000Oooool00003o`000?oooooooooo03[ooooo1_l0o`08o`00obco0?l0Yoooool1o`00
007ooooo00000ol0003oooooooooo`0jooooo`Go0?l02Ol00?l/o`3o0:Oooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool3o`3o0003ooooool00?oo003o00Ko003o1_l0o`03o`00ob?o0?l0
00Coooooo`3o0?l0o`3o0?l0Y?ooool1o`00007ooooo00000ol0003oooooooooo`0oooooo`Oo003o
1_l0o`05o`00obSo0?l0X_ooool1o`00007ooooo00000ol0003oooooooooo`10ooooo`?o003o2Ol0
o`05o`00obWo0?l0XOooool1o`00007ooooo00000ol0003oooooooooo`11ooooo`?o0?l000?ooooo
o`3o0?l00?l00ol00?l2o`3o00Go003o:Ol0o`2Qooooo`7o00000Oooool00003o`000?oooooooooo
04Gooooo1_l00?l2o`3o00?o003o:_l0o`2Qooooo`7o00000Oooool00003o`000?oooooooooo04Go
oooo1_l00?lTo`3o00;ooooo2?l0o`2Rooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo
1_l00?l]o`3o0:?ooooo0Ol00001ooooo`0000?o0000ooooooooool0AOooool00ol0o`3o003oo`00
o`02o`00o`Wo0?l00ol00?lSo`3o0:;ooooo0Ol00001ooooo`0000?o0000ooooooooool0A_ooool<
o`3o00Go003o8_l0o`2Rooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo2Ol0o`06o`00
ob7o0?l0X_ooool1o`00007ooooo00000ol0003oooooooooo`19ooooo`Co0?l00ol00?l00ol0o`3o
003oo`00o`05o`00ob7o0?l0X_ooool1o`00007ooooo00000ol0003oooooooooo`1:ooooo`;o0?l0
3?l00?lQo`3o0:;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Boooool00ol0o`3o003oo`00
o`0:o`00o`Wo0?l00ol00?lEo`3o0:;ooooo0Ol00001ooooo`0000?o0000ooooooooool0C?ooool5
o`00o`03o`3o0?l00?oo003o00Go003o1ol0o`05o`00oa[o0?l0W?ooool1o`00007ooooo00000ol0
003oooooooooo`1=ooooo`?o003o0_l0o`02ooooo`Go003o00?oooooo`3o0?l0o`001?l0o`05o`00
oa_o0?l0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Ko003o1ol0o`06o`00oa[o
0?l0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Go003o2?l0o`07o`00oa_o0?l0
VOooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Go003o2?l0o`07o`00oaoo0?l0UOoo
ool1o`00007ooooo00000ol0003oooooooooo`1Dooooo`?o003o1Ol0o`03o`00o`;o0?l01_l00?lP
o`3o09Cooooo0Ol00001ooooo`0000?o0000ooooooooool0F?ooool3o`3o00_o003o8Ol0o`2Doooo
o`7o00000Oooool00003o`000?oooooooooo05Sooooo0ol0o`0:o`00ob;o0?l0U?ooool1o`00007o
oooo00000ol0003oooooooooo`1;ooooo`?o003o2_ooool3o`3o00[o003o8Ol0o`2Eooooo`7o0000
0Oooool00003o`000?oooooooooo04[ooooo2?l00?l6ooooo`Co0?l02?l00?lTo`3o00;ooooo0ol0
o`2>ooooo`7o00000Oooool00003o`000?oooooooooo04[ooooo2Ol00?l5ooooo`Co0?l01ol00?l[
o`3o08gooooo0Ol00001ooooo`0000?o0000ooooooooool0B_ooool9o`00o`Gooooo1?l0o`07o`00
o`co0?l00ol00?lLo`3o08gooooo0Ol00001ooooo`0000?o0000ooooooooool0Boooool8o`00o`Go
oooo1?l0o`06o`00o`co0?l01Ol00?lKo`3o08gooooo0Ol00001ooooo`0000?o0000ooooooooool0
Coooool3o`00o`Oooooo1?l0o`05o`00o`co0?l01Ol00?lJo`3o08kooooo0Ol00001ooooo`0000?o
0000ooooooooool0Foooool00ol0o`3o003oo`00o`05o`00o`Co0?l000?oooooo`3o0?l0o`001?l0
o`05o`00oaWo0?l0Soooool1o`00007ooooo00000ol0003oooooooooo`1Looooo`Oo003o0ol0o`03
ooooo`Ko0?l00ol00?lJo`3o08oooooo0Ol00001ooooo`0000?o0000ooooooooool0G?ooool7o`00
o`;o0?l01?oooolSo`3o08oooooo0Ol00001ooooo`0000?o0000ooooooooool0GOooool5o`00o`?o
0?l01?ooool;o`3o0003ooooool0o`3o0?l001Co0?l0T?ooool1o`00007ooooo00000ol0003ooooo
ooooo`1Qooooo`?o0?l01_ooool3o`3o00;ooooo0ol0o`000ooooooo0?l0o`3o000:o`3o00;ooooo
2ol0o`2?ooooo`7o00000Oooool00003o`000?oooooooooo06[ooooo0ol0o`05ooooo`co0?l00ooo
ool<o`3o08kooooo0Ol00001ooooo`0000?o0000ooooooooool0JOooool4o`3o00?o003o0_ooool5
o`3o0003ooooool0o`3o003o00;o003o4_l0o`02ooooo`?o0?l0R?ooool1o`00007ooooo00000ol0
003oooooooooo`1Yooooo`?o0?l01Ol00?l00ooooooo0?l0o`3o0003o`3o0003ooooool00?oo003o
00?o003o5ol0o`27ooooo`7o00000Oooool00003o`000?oooooooooo06Wooooo0ol0o`05o`00o`;o
oooo00Go0?l0o`00ool00?oo003oooooo`05o`00oaOo0?l000Coooooo`3o0?l0o`3o0?l0Poooool1
o`00007ooooo00000ol0003oooooooooo`1Zooooo`;o0?l01_l00?l00ooooooo003oo`00o`08o`00
oaco0?l0P_ooool1o`00007ooooo00000ol0003oooooooooo`1]ooooo`Go003o00?oooooo`00ool0
0?l00ol00?l01Ol0o`3o003oo`00ool00?oooooo00Wo0?l00ol00?l:o`3o0003ooooool0o`3o0?l0
00?o0?l0P_ooool1o`00007ooooo00000ol0003oooooooooo`1]ooooo`Go003o00?oooooo`00ool0
0?l00ol00?l3o`3o00?ooooo1ol0o`05o`00o`oo0?l0P_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1^ooooo`?o003o0oooool3o`00o`Co0?l000?oooooo`3o0?l0o`001ol0o`05o`00o`ko0?l0
00?oooooo`3o0?l0o`000ol0o`1mooooo`7o00000Oooool00003o`000?oooooooooo07Cooooo0_l0
o`07o`00o`So0?l01Ol00?l=o`3o0003ooooool0o`3o0?l000Go0?l0O?ooool1o`00007ooooo0000
0ol0003oooooooooo`1cooooo`;o0?l02_l00?l00ol0o`3oooooo`3o0004o`3o00?o003o0ol0o`03
o`00o`So0?l000?oooooo`3o0?l0o`001Ol0o`1looooo`7o00000Oooool00003o`000?oooooooooo
06[ooooo0ol00?l6ooooo`;o0?l02ol00?l4ooooo`Oo0?l01Ol00?l7o`3o0003ooooool0o`3o0?l0
00Go0?l00oooool3o`3o07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0JOooool5o`00o`05
ooooool00?oo003oo`00ooooool00_l0o`0;o`00o`;ooooo1Ol0o`03o`00o`03o`3o0?l00?oo003o
00?o003o3_l0o`03ooooo`Go0?l0MOooool1o`00007ooooo00000ol0003oooooooooo`1Yooooo`[o
003o00?oooooo`3o0?l00?l02_l00?l00ooooooo0?l0o`3o0003o`3o00[o003o3?l0o`001Ooooooo
0?l0o`3o0?l0o`3ooooo00Go0?l0MOooool1o`00007ooooo00000ol0003oooooooooo`1Yooooo`[o
003o0_ooool5o`00o`;ooooo0ol00?l2ooooo`Go0?l02Ol00?lGo`3o07Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0J_ooool9o`00o`?ooooo1ol00?l4ooooo`Go0?l02?l00?lHo`3o07Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0KOooool5o`00o`?ooooo0ol0o`06o`00o`Cooooo1Ol0
o`07o`00oaSo0?l0MOooool1o`00007ooooo00000ol0003oooooooooo`1^ooooo`?o003o1?ooool3
o`3o00Ko003o1?ooool5o`3o0003ooooool0o`3o003o00Co003o4_l0o`000ooooooo0?l0o`3o0003
o`3o07Gooooo0Ol00001ooooo`0000?o0000ooooooooool0M?ooool:o`00o`Gooooo0ol0o`000ooo
oooo003oo`00o`04o`00oa?o0?l00_ooool3o`3o07Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0L?ooool=o`00o`Wooooo1Ol00?l01?l0o`3o003oo`00ool00?lAo`3o07_ooooo0Ol00001oooo
o`0000?o0000ooooooooool0Koooool=o`00o`Oooooo3Ol00?lFo`3o00Kooooo0ol0o`1/ooooo`7o
00000Oooool00003o`000?oooooooooo06oooooo3_l00?l5ooooo`ko003o5ol0o`04ooooo`Go0?l0
Joooool1o`00007ooooo00000ol0003oooooooooo`1_ooooob;o003o5_l0o`04ooooo`Ko0?l0J_oo
ool1o`00007ooooo00000ol0003oooooooooo`1_ooooo`Go003o1OoooolKo`00oa?o0?l01?ooool7
o`3o06Wooooo0Ol00001ooooo`0000?o0000ooooooooool0K_ooool6o`00o`Gooooo7?l00?lCo`3o
00;ooooo2?l0o`1Yooooo`7o00000Oooool00003o`000?oooooooooo06kooooo1ol00?l5oooooa_o
003o5?l0o`000ooooooo0?l0o`3o0006o`3o06Wooooo0Ol00001ooooo`0000?o0000ooooooooool0
K_ooool7o`00o`Oooooo6Ol00?l2o`3o00;ooooo4?l0o`000ooooooo0?l0o`3o0005o`3o06[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Koooool6o`00o`04ooooool00?oo003oo`00o`Cooooo
5ol00?l3o`3o00?ooooo3ol0o`02ooooo`Go0?l0Joooool1o`00007ooooo00000ol0003ooooooooo
o`1`ooooo`[o003o1oooool6o`00o`03ooooool00?oo003o00[o003o1?l0o`000ooooooo0?l0o`3o
000?o`3o0004ooooool0o`3o0?l0o`3o06gooooo0Ol00001ooooo`0000?o0000ooooooooool0L?oo
ool;o`00o`Kooooo5Ol00?l2o`3o0003ooooool0o`3o0?l001Co0?l0K?ooool1o`00007ooooo0000
0ol0003oooooooooo`1aooooo`?o003o00?oooooo`00ool00?l01_l00?l00ooooooo003oo`00o`0G
o`00o`03o`3o0?oooooo0?l001Go0?l0K?ooool1o`00007ooooo00000ol0003oooooooooo`1`oooo
o`Go003o00?oooooo`00ool00?l07ol00?l00ol0o`3oooooooooo`0Ho`3o06Wooooo0Ol00001oooo
o`0000?o0000ooooooooool0L?oooolWo`00o`05ooooool00?oo003oo`00ooooool05ol0o`1Xoooo
o`7o00000Oooool00003o`000?oooooooooo073ooooo9_l00?l00ooooooo003oo`00o`03o`00o`04
ooooool00?oo003oo`00o`;o0?l000?oooooo`3o0?l0o`003_l0o`1Xooooo`7o00000Oooool00003
o`000?oooooooooo077ooooo3?l00?l00ooooooo003oo`00o`0Eo`00o`;ooooo2_l00?l3oooooa;o
0?l0IOooool1o`00007ooooo00000ol0003oooooooooo`1booooo`_o003o0ooooolEo`00o`;ooooo
2_l00?l3oooooa?o0?l0I?ooool1o`00007ooooo00000ol0003oooooooooo`1cooooo`Wo003o00Co
ooooo`00ool00?oo003o1_oooolEo`00o`03ooooool00?oo003o00?o003o1?oooolBo`3o06Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0MOooool<o`00o`05ooooool00?oo003oo`00ooooool0
5?l00?l3ooooo`?o003o1oooool@o`3o06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0MOoo
ool6o`00o`03ooooool00?oo003o01ko003o3Oooool?o`3o06?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0MOoooolXo`00o`05ooooool00?oo003oo`00ool0o`000ol00?l2ooooo`?o003o3_l0
o`1Sooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo=_l00?l>o`3o00Gooooo0ol0o`05
ooooo`?o0?l0D_ooool1o`00007ooooo00000ol0003oooooooooo`1eooooob;o003o00?oooooo`00
ool00?l04Ol00?l>o`3o00Cooooo1Ol0o`03ooooo`Go0?l0DOooool1o`00007ooooo00000ol0003o
ooooooooo`1eooooob?o003o00?oooooo`00ool00?l04?l00?l2o`3o00?o003o2Ol0o`03ooooo`Ko
0?l00oooool5o`3o057ooooo0Ol00001ooooo`0000?o0000ooooooooool0MOoooolTo`00o`;ooooo
00?o0?l0o`00ool00?l03?l00?l2o`3o00Go003o2?l0o`02ooooo`Oo0?l00oooool5o`3o057ooooo
0Ol00001ooooo`0000?o0000ooooooooool0MOoooolTo`00o`;ooooo00?o0?l0o`00ool00?l03Ol0
0?l00ol0o`3o003oo`00o`03o`00o`Oo0?l00oooool7o`3o00Cooooo0ol0o`1Booooo`7o00000Ooo
ool00003o`000?oooooooooo07Kooooo8ol00?l2ooooo`03o`3o0?l00?oo003o00go003o00?o0?l0
o`00ool00?l00ol00?l5o`3o0005ooooool0o`3o0?l0o`3o0?ooool02_l0o`1Fooooo`7o00000Ooo
ool00003o`000?oooooooooo07Wooooo<_l00?l2o`3o00?o003o00?o0?l0ooooooooool00oooool5
o`3o0003ooooool0o`3o0?l000So0?l0EOooool1o`00007ooooo00000ol0003oooooooooo`1hoooo
oc;o003o00?o0?l0ooooool0o`000_l0o`03o`00o`?ooooo1_l0o`000ooooooo0?l0o`3o0008o`3o
05Gooooo0Ol00001ooooo`0000?o0000ooooooooool0N?ooooleo`00o`03o`3o0?l00?oo003o00?o
003o00Coooooo`00ool00?oo003o1?l0o`000ooooooo0?l0o`3o0008o`3o05Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0N?oooom0o`00o`;o0?l00_ooool9o`3o05Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0NOooooloo`00o`;o0?l000?oooooo`3o0?l0o`002?l0o`1Fooooo`7o0000
0Oooool00003o`000?oooooooooo07Wooooo>Ol00?l00ol0o`3o003oo`00o`03o`00o`;o0?l000?o
ooooo`3o0?l0o`002?l0o`1Fooooo`7o00000Oooool00003o`000?oooooooooo07Wooooo>_l00?l0
1?l0o`3o003oo`00ool00?l3o`3o0003ooooool0o`3o0?l000So0?l0E_ooool1o`00007ooooo0000
0ol0003oooooooooo`1joooooc[o003o00?o0?l0ooooool0o`000_l0o`03ooooo`So0?l0Eoooool1
o`00007ooooo00000ol0003oooooooooo`1kooooocWo003o00Co0?l0oooooooooooooooo0ol0o`05
ooooo`?o0?l0F?ooool1o`00007ooooo00000ol0003oooooooooo`1loooooc[o003o00?oooooo`3o
0?l0o`000ol0o`03ooooo`Go0?l01?ooool3o`3o053ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0OOooooljo`00o`Go0?l00oooool5o`3o00?ooooo1Ol0o`1?ooooo`7o00000Oooool00003o`00
0?oooooooooo07gooooo??l00?l3o`3o00;ooooo1_l0o`03ooooo`Go0?l01?ooool3o`3o04Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0OOoooolmo`00o`04o`3o0?ooooooooooooooo`?o003o
0_l0o`03o`00o`Ko0?l00oooool5o`3o00?o003oA?ooool1o`00007ooooo00000ol0003ooooooooo
o`1nooooo`?o003o00?oooooo`00ool00?l0=ol00?l2ooooo`[o003o1?l0o`04ooooo`Co0?l01Ol0
0?m3ooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo>Ol00?l00ooooooo003oo`00o`08
o`00o`Co0?l01?ooool4o`3o00Go003o@oooool1o`00007ooooo00000ol0003oooooooooo`25oooo
od;o003o0ol0o`06ooooo`?o0?l01Ol00?m3ooooo`7o00000Oooool00003o`000?oooooooooo08Co
oooo@_l00?l>ooooo`?o003oA?ooool1o`00007ooooo00000ol0003oooooooooo`24ooooocco003o
00?o0?l0o`00ool00?l00ol00?lDooooo`?o003o0_l0o`0looooo`7o00000Oooool00003o`000?oo
oooooooo08CoooooA?l00?l01?l0o`3oooooooooooooool6o`3o00Oooooo1_l00?l00ol0o`3ooooo
ooooo`0iooooo`7o00000Oooool00003o`000?oooooooooo08GoooooA?l00?l00ol0o`3oooooo`3o
0007o`3o00Cooooo2Ol00?lkooooo`7o00000Oooool00003o`000?oooooooooo08GoooooA?l00?l6
o`3o00?o003o00Co0?l0oooooooooooooooo2_l00?lkooooo`7o00000Oooool00003o`000?oooooo
oooo08CoooooAOl00?l01Ol0o`3o003oo`00ool00?oo0?l000Go003o0oooool:o`00oc_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Q?oooom?o`00o`?ooooo2Ol00?llooooo`7o00000Oooool0
0003o`000?oooooooooo08CoooooDOl00?l00ooooooo003oo`00o`08o`00oc_ooooo0Ol00001oooo
o`0000?o0000ooooooooool0Q?oooomPo`00ocOooooo0Ol00001ooooo`0000?o0000ooooooooool0
Q?oooomQo`00ocKooooo0Ol00001ooooo`0000?o0000ooooooooool0QOoooom4o`00o`03o`3o0?l0
0?oo003o01Wo003o=_ooool1o`00007ooooo00000ol0003oooooooooo`26oooood?o003o0_l0o`0J
o`00ocKooooo0Ol00001ooooo`0000?o0000ooooooooool0R?oooomLo`00ocOooooo0Ol00001oooo
o`0000?o0000ooooooooool0ROoooomLo`00ocKooooo0Ol00001ooooo`0000?o0000ooooooooool0
R_oooomKo`00o`Cooooo0ol0o`0_ooooo`7o00000Oooool00003o`000?oooooooooo08_oooooF_l0
0?l3ooooo`Go0?l0;_ooool1o`00007ooooo00000ol0003oooooooooo`2<ooooo`?o003o00?ooooo
o`00ool00?l0D_l00?l4ooooo`Go0?l0;_ooool1o`00007ooooo00000ol0003oooooooooo`2Aoooo
oe7o003o1_ooool5o`3o02kooooo0Ol00001ooooo`0000?o0000ooooooooool0TOoooomAo`00o`Oo
oooo0ol0o`0_ooooo`7o00000Oooool00003o`000?oooooooooo09;oooooDOl00?lhooooo`7o0000
0Oooool00003o`000?oooooooooo09;oooooD_l00?lgooooo`7o00000Oooool00003o`000?oooooo
oooo09;ooooo1Ol00?l2ooooodco003o=_ooool1o`00007ooooo00000ol0003oooooooooo`2Boooo
o`Go003o0_oooom<o`00ocKooooo0Ol00001ooooo`0000?o0000ooooooooool0Toooool3o`00o`?o
ooooC?l00?lfooooo`7o00000Oooool00003o`000?oooooooooo09[oooooB_l00?lgooooo`7o0000
0Oooool00003o`000?oooooooooo09_oooooBOl00?l;ooooo`?o0?l0:Oooool1o`00007ooooo0000
0ol0003oooooooooo`2KooooodWo003o2_ooool5o`3o02Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Vooooom:o`00o`Wooooo1Ol0o`0Xooooo`7o00000Oooool00003o`000?oooooooooo09_o
ooooB_l00?l9ooooo`Go0?l0:?ooool1o`00007ooooo00000ol0003oooooooooo`2Loooood[o003o
2Oooool3o`3o02Wooooo0Ol00001ooooo`0000?o0000ooooooooool0W_oooom8o`00o`?o0?l0<_oo
ool1o`00007ooooo00000ol0003oooooooooo`2QooooodOo003o0_l0o`0aooooo`7o00000Oooool0
0003o`000?oooooooooo0:;oooooAol00?l00ol0o`3oooooooooo`0_ooooo`7o00000Oooool00003
o`000?oooooooooo0:CoooooAOl00?l00ol0o`3oooooooooo`0_ooooo`7o00000Oooool00003o`00
0?oooooooooo0:CoooooAOl00?l2ooooo`?o003o;Oooool1o`00007ooooo00000ol0003ooooooooo
o`2TooooodCo003o0_ooool5o`00obcooooo0Ol00001ooooo`0000?o0000ooooooooool0YOoooom2
o`00o`?ooooo1Ol00?l/ooooo`7o00000Oooool00003o`000?oooooooooo0:Kooooo>ol00?l00ooo
oooo003oo`00o`03o`00o`?ooooo1Ol00?l/ooooo`7o00000Oooool00003o`000?oooooooooo0:Oo
oooo0ol00?l00ooooooo003oo`00o`0jo`00o`Cooooo0ol00?l]ooooo`7o00000Oooool00003o`00
0?oooooooooo0:gooooo>Ol00?leooooo`7o00000Oooool00003o`000?oooooooooo0:gooooo>?l0
0?lfooooo`7o00000Oooool00003o`000?oooooooooo0:kooooo=ol00?l3o`3o03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0[oooooleo`00o`?o0?l00ol00?laooooo`7o00000Oooool00003
o`000?oooooooooo0;3ooooo<_l00?l2ooooo`;o0?l01Ol00?l`ooooo`7o00000Oooool00003o`00
0?oooooooooo0;;ooooo<?l00?l2ooooo`;o0?l01Ol00?l2o`3o02kooooo0Ol00001ooooo`0000?o
0000ooooooooool0/oooool^o`00o`Cooooo00?o0?l0o`00ool00?l00ol00?l3o`3o02gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0]?ooool]o`00o`03ooooool0o`3o0?l000?o0?l00ol00?l4
o`3o02gooooo0Ol00001ooooo`0000?o0000ooooooooool0]_ooool[o`00o`go0?l0;Oooool1o`00
007ooooo00000ol0003oooooooooo`2gooooob;o003o0_l0o`05o`00o`03ooooool0o`3o0?l000Ko
003o00Coooooo`3o0?l0o`3o0?l01Oooool3o`3o02Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0]ooooolRo`00o`;o0?l01Ol00?l00ooooooo0?l0o`00o`07o`00o`;ooooo0ol0o`02ooooo`Go
0?l09Oooool1o`00007ooooo00000ol0003oooooooooo`2hooooob7o003o00?o0?l0o`00ool00?l0
1?l00?l2ooooo`So003o00?oooooo`3o0?l0o`000ol0o`000ooooooo0?l0o`3o0003o`3o02Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0^oooool5o`00o`Gooooo1ol00?l6ooooo`Ko003o0_l0
o`07o`00o`03ooooool00?oo003o00Ko003o00?oooooo`3o0?l0o`000ol0o`000ooooooo0?l0o`3o
0003o`3o02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0_?ooool3o`00oaCooooo0ol00?l3
ooooo`03o`3o0?l00?oo003o00Go003o00?oooooo`00ool00?l01Ol00?l01?l0o`3o003oo`00ool0
0?l3o`3o00;ooooo00Co0?l0o`00ool00?oo003o9Oooool1o`00007ooooo00000ol0003ooooooooo
o`3Kooooo`Ko003o00?oooooo`00ool00?l00ol00?l2o`3o00Go003o0_l0o`02ooooo`Go003o9?oo
ool1o`00007ooooo00000ol0003oooooooooo`3Looooo`Co003o00?oooooo`3o0?l0o`000ol00?l3
o`3o00Ko003o00?o0?l0ooooooooool01Ol00?lTooooo`7o00000Oooool00003o`000?oooooooooo
0>7ooooo2?l0o`0>o`00o`Cooooo0ol00?lMooooo`7o00000Oooool00003o`000?oooooooooo0>7o
oooo2?l0o`000ooooooo003oo`00o`0;o`00o`?o0?l01Ol00?lLooooo`7o00000Oooool00003o`00
0?oooooooooo0>;ooooo0ol0o`04o`00o`;ooooo3Ol00?l2o`3o00Go003o7?ooool1o`00007ooooo
00000ol0003oooooooooo`3Sooooo`03o`3o0?l00?oo003o00Co003o00?oooooo`3o0?l00?l02ol0
0?l2o`3o00Go003o7?ooool1o`00007ooooo00000ol0003oooooooooo`3Sooooo`03o`3o0?l00?oo
003o00Co003o0_l0o`0Bo`00oagooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool6o`00
o`;o0?l04ol00?lLooooo`7o00000Oooool00003o`000?oooooooooo0>Gooooo1ol00?l00ol0o`3o
003oo`00o`0@o`00oacooooo0Ol00001ooooo`0000?o0000ooooooooool0iOooool8o`00o`03o`3o
0?l00?oo003o00Go003o0_ooool8o`00oacooooo0Ol00001ooooo`0000?o0000ooooooooool0i_oo
ool7o`00o`;ooooo1Ol00?l3ooooo`Oo003o7Oooool1o`00007ooooo00000ol0003oooooooooo`3X
ooooo`Go003o0_ooool5o`00o`;ooooo1Ol00?lPooooo`7o00000Oooool00003o`000?oooooooooo
0>Wooooo0ol00?l3ooooo`Go003o00?oooooo`00ool00?l00ol00?lQooooo`7o00000Oooool00003
o`000?oooooooooo0>cooooo0ol00?l00ol0o`3o003oo`00o`08o`00ob7ooooo0Ol00001ooooo`00
00?o0000ooooooooool0joooool5o`00o`03o`3o0?l00?oo003o00Oo003o8Oooool1o`00007ooooo
00000ol0003oooooooooo`3[ooooo`Go003o00?o0?l0o`00ool00?l01ol00?l00ol0o`3ooooooooo
o`0Nooooo`7o00000Oooool00003o`000?oooooooooo0>_ooooo1Ol00?l00ol0o`3o003oo`00o`07
o`00o`03o`3o0?oooooooooo01kooooo0Ol00001ooooo`0000?o0000ooooooooool0k?ooool3o`00
o`?o0?l01ol00?l2o`3o023ooooo0Ol00001ooooo`0000?o0000ooooooooool0loooool5o`00o`;o
0?l08Oooool1o`00007ooooo00000ol0003oooooooooo`3dooooo`?o003o0ol0o`0Qooooo`7o0000
0Oooool00003o`000?oooooooooo0?Gooooo2?l0o`03o`00oa_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0m_ooool6o`3o00Go003o6_ooool1o`00007ooooo00000ol0003oooooooooo`3eoooo
o`Ko0?l01_l00?lJooooo`7o00000Oooool00003o`000?oooooooooo0?Gooooo1Ol0o`09o`00oaSo
oooo0Ol00001ooooo`0000?o0000ooooooooool0mOooool5o`3o00[o003o5oooool1o`00007ooooo
00000ol0003oooooooooo`3fooooo`Co0?l02_l00?lGooooo`7o00000Oooool00003o`000?oooooo
oooo0?Sooooo0ol0o`09o`00o`03o`3o0?oooooo0?l000;o0?l04_ooool1o`00007ooooo00000ol0
003oooooooooo`3looooo`_o003o0ol0o`0Aooooo`7o00000Oooool00003o`000?oooooooooo0?co
oooo00?o0?l0o`00ool00?l02Ol00?l2o`3o017ooooo0Ol00001ooooo`0000?o0000ooooooooool0
o?ooool00ol0o`3o003oo`00o`09o`00o`;o0?l04Oooool1o`00007ooooo00000ol0003ooooooooo
o`3looooo`co003o00Co0?l0o`00ool00?oo003o3oooool1o`00007ooooo00000ol0003ooooooooo
o`3loooooa7o003o3_ooool1o`00007ooooo00000ol0003oooooooooo`3loooooa;o003o3Oooool1
o`00007ooooo00000ol0003oooooooooo`3moooooa;o003o3?ooool1o`00007ooooo00000ol0003o
ooooooooo`3oooooo`7ooooo3ol00?l<ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
0_ooool3o`00o`03ooooool0o`3o003o00So003o3?ooool1o`00007ooooo00000ol0003ooooooooo
o`3oooooo`Kooooo00?o0?l0o`00ool00?l01_l00?l=ooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo1oooool5o`00oa3ooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool8oooo
o`?o003o4Oooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.122445, -0.122445, 0.889355, \
0.889355}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Compute two-dimensional pdfs and corresponding error on 2d color \
channel combinations\
\>", "Subsection"],

Cell[BoxData[{
    \(\(p1rg = 
        gaussian[\({#[\([1]\)], #[\([2]\)]} &\)\  /@ \ d1\  // N, {x, 
            y}];\)\), "\[IndentingNewLine]", 
    \(\(p1rb = 
        gaussian[\({#[\([1]\)], #[\([3]\)]} &\)\  /@ \ d1\  // N, {x, 
            y}];\)\), "\[IndentingNewLine]", 
    \(\(\(p1gb = 
        gaussian[\({#[\([2]\)], #[\([3]\)]} &\)\  /@ \ d1\  // N, {x, 
            y}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(p2rg = 
        gaussian[\({#[\([1]\)], #[\([2]\)]} &\)\  /@ \ d2\  // N, {x, 
            y}];\)\), "\[IndentingNewLine]", 
    \(\(p2rb = 
        gaussian[\({#[\([1]\)], #[\([3]\)]} &\)\  /@ \ d2\  // N, {x, 
            y}];\)\), "\[IndentingNewLine]", 
    \(\(p2gb = 
        gaussian[\({#[\([2]\)], #[\([3]\)]} &\)\  /@ \ d2\  // N, {x, 
            y}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show two-dimensional pdfs (skip)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[p1rg, p2rg, {{0, 255}, {0, 255}}, x, y, \ 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .04838 m
.03482 .06854 L
.04389 .08169 L
.05096 .0932 L
.06854 .1113 L
.07275 .11785 L
.0932 .13877 L
.09576 .1425 L
.11785 .16515 L
.11934 .16716 L
.1425 .19101 L
.14315 .19181 L
.16671 .21647 L
.16716 .21696 L
.1888 .24112 L
.19181 .24417 L
.21002 .26578 L
.21647 .27185 L
.23072 .29043 L
.24112 .29986 L
.25217 .31509 L
.26578 .32749 L
.27503 .33974 L
.29043 .35408 L
.29907 .3644 L
.31509 .37955 L
.32406 .38905 L
.33974 .404 L
.35009 .41371 L
.3644 .42734 L
.37769 .43836 L
.38905 .44907 L
.40875 .46302 L
.41371 .46747 L
.42185 .46302 L
.41371 .44606 L
.40962 .43836 L
.39714 .41371 L
.38905 .40491 L
.37987 .38905 L
.3644 .37293 L
.35913 .3644 L
.33974 .3443 L
.33674 .33974 L
.31509 .31718 L
.31361 .31509 L
.29043 .29073 L
.29021 .29043 L
.26859 .26578 L
.26578 .26255 L
.24843 .24112 L
.24112 .23336 L
.22904 .21647 L
.21647 .20391 L
.20848 .19181 L
.19181 .17546 L
.18614 .16716 L
.16716 .14846 L
.16267 .1425 L
.1425 .12252 L
.13858 .11785 L
.11785 .09722 L
.11407 .0932 L
.0932 .07238 L
.08919 .06854 L
.06854 .04795 L
.06383 .04389 L
.04389 .02162 L
.03321 .01923 L
.01923 .01923 L
F
0 g
.01923 .04838 m
.03482 .06854 L
.04389 .08169 L
.05096 .0932 L
.06854 .1113 L
.07275 .11785 L
.0932 .13877 L
.09576 .1425 L
.11785 .16515 L
.11934 .16716 L
.1425 .19101 L
.14315 .19181 L
.16671 .21647 L
.16716 .21696 L
.1888 .24112 L
.19181 .24417 L
.21002 .26578 L
.21647 .27185 L
.23072 .29043 L
.24112 .29986 L
.25217 .31509 L
.26578 .32749 L
.27503 .33974 L
.29043 .35408 L
.29907 .3644 L
.31509 .37955 L
.32406 .38905 L
.33974 .404 L
.35009 .41371 L
.3644 .42734 L
.37769 .43836 L
.38905 .44907 L
.40875 .46302 L
.41371 .46747 L
.42185 .46302 L
.41371 .44606 L
.40962 .43836 L
.39714 .41371 L
.38905 .40491 L
.37987 .38905 L
.3644 .37293 L
.35913 .3644 L
.33974 .3443 L
.33674 .33974 L
.31509 .31718 L
.31361 .31509 L
.29043 .29073 L
.29021 .29043 L
.26859 .26578 L
.26578 .26255 L
Mistroke
.24843 .24112 L
.24112 .23336 L
.22904 .21647 L
.21647 .20391 L
.20848 .19181 L
.19181 .17546 L
.18614 .16716 L
.16716 .14846 L
.16267 .1425 L
.1425 .12252 L
.13858 .11785 L
.11785 .09722 L
.11407 .0932 L
.0932 .07238 L
.08919 .06854 L
.06854 .04795 L
.06383 .04389 L
.04389 .02162 L
.03321 .01923 L
Mfstroke
.2 g
.01923 .02837 m
.02237 .04389 L
.04389 .06823 L
.04411 .06854 L
.05939 .0932 L
.06854 .10279 L
.07837 .11785 L
.0932 .13305 L
.09979 .1425 L
.11785 .16099 L
.12248 .16716 L
.1425 .18773 L
.14582 .19181 L
.16716 .21385 L
.16947 .21647 L
.19181 .23966 L
.19322 .24112 L
.21647 .26537 L
.2169 .26578 L
.23962 .29043 L
.24112 .29177 L
.2619 .31509 L
.26578 .31845 L
.28497 .33974 L
.29043 .34445 L
.30947 .3644 L
.31509 .36925 L
.33598 .38905 L
.33974 .39226 L
.3644 .41148 L
.36772 .38905 L
.3644 .38544 L
.35185 .3644 L
.33974 .35177 L
.33179 .33974 L
.31509 .32234 L
.30991 .31509 L
.29043 .29466 L
.28718 .29043 L
.26578 .26775 L
.26413 .26578 L
.24117 .24112 L
.24112 .24108 L
.22088 .21647 L
.21647 .21208 L
.20079 .19181 L
.19181 .18318 L
.17961 .16716 L
.16716 .15522 L
.15698 .1425 L
.1425 .1285 L
.13321 .11785 L
.11785 .10288 L
.10855 .0932 L
.0932 .07818 L
.08295 .06854 L
.06854 .05444 L
.05605 .04389 L
.04389 .02706 L
.02276 .01923 L
.01923 .01923 L
F
0 g
.01923 .02837 m
.02237 .04389 L
.04389 .06823 L
.04411 .06854 L
.05939 .0932 L
.06854 .10279 L
.07837 .11785 L
.0932 .13305 L
.09979 .1425 L
.11785 .16099 L
.12248 .16716 L
.1425 .18773 L
.14582 .19181 L
.16716 .21385 L
.16947 .21647 L
.19181 .23966 L
.19322 .24112 L
.21647 .26537 L
.2169 .26578 L
.23962 .29043 L
.24112 .29177 L
.2619 .31509 L
.26578 .31845 L
.28497 .33974 L
.29043 .34445 L
.30947 .3644 L
.31509 .36925 L
.33598 .38905 L
.33974 .39226 L
.3644 .41148 L
.36772 .38905 L
.3644 .38544 L
.35185 .3644 L
.33974 .35177 L
.33179 .33974 L
.31509 .32234 L
.30991 .31509 L
.29043 .29466 L
.28718 .29043 L
.26578 .26775 L
.26413 .26578 L
.24117 .24112 L
.24112 .24108 L
.22088 .21647 L
.21647 .21208 L
.20079 .19181 L
.19181 .18318 L
.17961 .16716 L
.16716 .15522 L
.15698 .1425 L
Mistroke
.1425 .1285 L
.13321 .11785 L
.11785 .10288 L
.10855 .0932 L
.0932 .07818 L
.08295 .06854 L
.06854 .05444 L
.05605 .04389 L
.04389 .02706 L
.02276 .01923 L
Mfstroke
.3 g
.04389 .03648 m
.04704 .04389 L
.06854 .06092 L
.07658 .06854 L
.0932 .08372 L
.10313 .0932 L
.11785 .10813 L
.12808 .11785 L
.1425 .13387 L
.15168 .1425 L
.16716 .16091 L
.17384 .16716 L
.19181 .18907 L
.19471 .19181 L
.2158 .21647 L
.21647 .21714 L
.23861 .24112 L
.24112 .24389 L
.26157 .26578 L
.26578 .27081 L
.28432 .29043 L
.29043 .29835 L
.3064 .31509 L
.31509 .32732 L
.32699 .33974 L
.33974 .35972 L
.34416 .3644 L
.33974 .37969 L
.32148 .3644 L
.31509 .3611 L
.29319 .33974 L
.29043 .33791 L
.26806 .31509 L
.26578 .31334 L
.2437 .29043 L
.24112 .28823 L
.21959 .26578 L
.21647 .26283 L
.19561 .24112 L
.19181 .23719 L
.17182 .21647 L
.16716 .21121 L
.14834 .19181 L
.1425 .18465 L
.12544 .16716 L
.11785 .15708 L
.10359 .1425 L
.0932 .12758 L
.08374 .11785 L
.06854 .09417 L
.06764 .0932 L
.05304 .06854 L
.04389 .05416 L
.02834 .04389 L
F
0 g
.04389 .03648 m
.04704 .04389 L
.06854 .06092 L
.07658 .06854 L
.0932 .08372 L
.10313 .0932 L
.11785 .10813 L
.12808 .11785 L
.1425 .13387 L
.15168 .1425 L
.16716 .16091 L
.17384 .16716 L
.19181 .18907 L
.19471 .19181 L
.2158 .21647 L
.21647 .21714 L
.23861 .24112 L
.24112 .24389 L
.26157 .26578 L
.26578 .27081 L
.28432 .29043 L
.29043 .29835 L
.3064 .31509 L
.31509 .32732 L
.32699 .33974 L
.33974 .35972 L
.34416 .3644 L
.33974 .37969 L
.32148 .3644 L
.31509 .3611 L
.29319 .33974 L
.29043 .33791 L
.26806 .31509 L
.26578 .31334 L
.2437 .29043 L
.24112 .28823 L
.21959 .26578 L
.21647 .26283 L
.19561 .24112 L
.19181 .23719 L
.17182 .21647 L
.16716 .21121 L
.14834 .19181 L
.1425 .18465 L
.12544 .16716 L
.11785 .15708 L
.10359 .1425 L
.0932 .12758 L
.08374 .11785 L
.06854 .09417 L
Mistroke
.06764 .0932 L
.05304 .06854 L
.04389 .05416 L
.02834 .04389 L
.04389 .03648 L
Mfstroke
.4 g
.0932 .08956 m
.09718 .0932 L
.11785 .11338 L
.12273 .11785 L
.1425 .139 L
.14636 .1425 L
.16716 .16604 L
.16839 .16716 L
.19036 .19181 L
.19181 .19313 L
.21316 .21647 L
.21647 .21978 L
.23618 .24112 L
.24112 .24655 L
.2591 .26578 L
.26578 .27376 L
.28153 .29043 L
.29043 .30202 L
.30289 .31509 L
.31509 .33262 L
.32187 .33974 L
.31509 .35375 L
.30056 .33974 L
.29043 .33338 L
.27248 .31509 L
.26578 .31002 L
.24689 .29043 L
.24112 .28551 L
.22217 .26578 L
.21647 .2604 L
.19792 .24112 L
.19181 .23481 L
.17409 .21647 L
.16716 .20865 L
.15079 .19181 L
.1425 .18166 L
.12834 .16716 L
.11785 .1532 L
.10739 .1425 L
.0932 .12183 L
.08936 .11785 L
.07739 .0932 L
F
0 g
.0932 .08956 m
.09718 .0932 L
.11785 .11338 L
.12273 .11785 L
.1425 .139 L
.14636 .1425 L
.16716 .16604 L
.16839 .16716 L
.19036 .19181 L
.19181 .19313 L
.21316 .21647 L
.21647 .21978 L
.23618 .24112 L
.24112 .24655 L
.2591 .26578 L
.26578 .27376 L
.28153 .29043 L
.29043 .30202 L
.30289 .31509 L
.31509 .33262 L
.32187 .33974 L
.31509 .35375 L
.30056 .33974 L
.29043 .33338 L
.27248 .31509 L
.26578 .31002 L
.24689 .29043 L
.24112 .28551 L
.22217 .26578 L
.21647 .2604 L
.19792 .24112 L
.19181 .23481 L
.17409 .21647 L
.16716 .20865 L
.15079 .19181 L
.1425 .18166 L
.12834 .16716 L
.11785 .1532 L
.10739 .1425 L
.0932 .12183 L
.08936 .11785 L
.07739 .0932 L
.0932 .08956 L
s
.5 g
.11785 .11921 m
.14041 .1425 L
.1425 .14391 L
.1639 .16716 L
.16716 .16974 L
.18724 .19181 L
.19181 .19593 L
.21058 .21647 L
.21647 .22236 L
.2338 .24112 L
.24112 .24916 L
.25665 .26578 L
.26578 .27673 L
.27872 .29043 L
.29043 .30586 L
.29921 .31509 L
.31509 .33931 L
.3155 .33974 L
.31509 .34194 L
.31249 .33974 L
.29043 .32865 L
.27711 .31509 L
.26578 .30671 L
.25007 .29043 L
.24112 .28285 L
.22471 .26578 L
.21647 .25802 L
.2002 .24112 L
.19181 .23246 L
.17633 .21647 L
.16716 .20613 L
.15322 .19181 L
.1425 .17865 L
.13126 .16716 L
.11785 .14912 L
.11137 .1425 L
F
0 g
.11785 .11921 m
.14041 .1425 L
.1425 .14391 L
.1639 .16716 L
.16716 .16974 L
.18724 .19181 L
.19181 .19593 L
.21058 .21647 L
.21647 .22236 L
.2338 .24112 L
.24112 .24916 L
.25665 .26578 L
.26578 .27673 L
.27872 .29043 L
.29043 .30586 L
.29921 .31509 L
.31509 .33931 L
.3155 .33974 L
.31509 .34194 L
.31249 .33974 L
.29043 .32865 L
.27711 .31509 L
.26578 .30671 L
.25007 .29043 L
.24112 .28285 L
.22471 .26578 L
.21647 .25802 L
.2002 .24112 L
.19181 .23246 L
.17633 .21647 L
.16716 .20613 L
.15322 .19181 L
.1425 .17865 L
.13126 .16716 L
.11785 .14912 L
.11137 .1425 L
.11785 .11921 L
s
.6 g
.11785 .12746 m
.13219 .1425 L
.1425 .14853 L
.15948 .16716 L
.16716 .17311 L
.1841 .19181 L
.19181 .19872 L
.20801 .21647 L
.21647 .22492 L
.23141 .24112 L
.24112 .2518 L
.25417 .26578 L
.26578 .27981 L
.2758 .29043 L
.29043 .31021 L
.29504 .31509 L
.29043 .32311 L
.28254 .31509 L
.26578 .30328 L
.25338 .29043 L
.24112 .28016 L
.22729 .26578 L
.21647 .25563 L
.20248 .24112 L
.19181 .23011 L
.17859 .21647 L
.16716 .20356 L
.1557 .19181 L
.1425 .17551 L
.13432 .16716 L
.11785 .14451 L
.11589 .1425 L
F
0 g
.11785 .12746 m
.13219 .1425 L
.1425 .14853 L
.15948 .16716 L
.16716 .17311 L
.1841 .19181 L
.19181 .19872 L
.20801 .21647 L
.21647 .22492 L
.23141 .24112 L
.24112 .2518 L
.25417 .26578 L
.26578 .27981 L
.2758 .29043 L
.29043 .31021 L
.29504 .31509 L
.29043 .32311 L
.28254 .31509 L
.26578 .30328 L
.25338 .29043 L
.24112 .28016 L
.22729 .26578 L
.21647 .25563 L
.20248 .24112 L
.19181 .23011 L
.17859 .21647 L
.16716 .20356 L
.1557 .19181 L
.1425 .17551 L
.13432 .16716 L
.11785 .14451 L
.11589 .1425 L
.11785 .12746 L
s
.7 g
.1425 .15384 m
.15441 .16716 L
.16716 .17663 L
.18082 .19181 L
.19181 .20156 L
.20536 .21647 L
.21647 .22755 L
.22896 .24112 L
.24112 .25456 L
.25157 .26578 L
.26578 .28316 L
.2726 .29043 L
.26578 .29951 L
.25702 .29043 L
.24112 .27736 L
.22998 .26578 L
.21647 .25317 L
.20484 .24112 L
.19181 .2277 L
.18092 .21647 L
.16716 .20089 L
.15829 .19181 L
.1425 .17208 L
.13767 .16716 L
F
0 g
.1425 .15384 m
.15441 .16716 L
.16716 .17663 L
.18082 .19181 L
.19181 .20156 L
.20536 .21647 L
.21647 .22755 L
.22896 .24112 L
.24112 .25456 L
.25157 .26578 L
.26578 .28316 L
.2726 .29043 L
.26578 .29951 L
.25702 .29043 L
.24112 .27736 L
.22998 .26578 L
.21647 .25317 L
.20484 .24112 L
.19181 .2277 L
.18092 .21647 L
.16716 .20089 L
.15829 .19181 L
.1425 .17208 L
.13767 .16716 L
.1425 .15384 L
s
.8 g
.1425 .16185 m
.14672 .16716 L
.16716 .18052 L
.17718 .19181 L
.19181 .20458 L
.20254 .21647 L
.21647 .23033 L
.22635 .24112 L
.24112 .25753 L
.24877 .26578 L
.26578 .28715 L
.26884 .29043 L
.26578 .29487 L
.26151 .29043 L
.24112 .27433 L
.2329 .26578 L
.21647 .25059 L
.20733 .24112 L
.19181 .22515 L
.18338 .21647 L
.16716 .198 L
.1611 .19181 L
.1425 .16801 L
.14167 .16716 L
F
0 g
.1425 .16185 m
.14672 .16716 L
.16716 .18052 L
.17718 .19181 L
.19181 .20458 L
.20254 .21647 L
.21647 .23033 L
.22635 .24112 L
.24112 .25753 L
.24877 .26578 L
.26578 .28715 L
.26884 .29043 L
.26578 .29487 L
.26151 .29043 L
.24112 .27433 L
.2329 .26578 L
.21647 .25059 L
.20733 .24112 L
.19181 .22515 L
.18338 .21647 L
.16716 .198 L
.1611 .19181 L
.1425 .16801 L
.14167 .16716 L
.1425 .16185 L
s
.9 g
.16716 .1854 m
.17265 .19181 L
.19181 .20796 L
.1994 .21647 L
.21647 .23341 L
.22348 .24112 L
.24112 .26097 L
.24554 .26578 L
.24112 .27081 L
.23629 .26578 L
.21647 .24775 L
.21006 .24112 L
.19181 .22235 L
.18609 .21647 L
.16716 .19469 L
.16434 .19181 L
F
0 g
.16716 .1854 m
.17265 .19181 L
.19181 .20796 L
.1994 .21647 L
.21647 .23341 L
.22348 .24112 L
.24112 .26097 L
.24554 .26578 L
.24112 .27081 L
.23629 .26578 L
.21647 .24775 L
.21006 .24112 L
.19181 .22235 L
.18609 .21647 L
.16716 .19469 L
.16434 .19181 L
.16716 .1854 L
s
1 g
.19181 .2122 m
.1955 .21647 L
.21647 .23712 L
.22004 .24112 L
.24112 .2657 L
.2412 .26578 L
.24112 .26587 L
.24104 .26578 L
.21647 .24441 L
.21329 .24112 L
.19181 .21908 L
.18927 .21647 L
F
0 g
.19181 .2122 m
.1955 .21647 L
.21647 .23712 L
.22004 .24112 L
.24112 .2657 L
.2412 .26578 L
.24112 .26587 L
.24104 .26578 L
.21647 .24441 L
.21329 .24112 L
.19181 .21908 L
.18927 .21647 L
.19181 .2122 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.38905 .43073 m
.40395 .43836 L
.41371 .44234 L
.43836 .45711 L
.44612 .46302 L
.46302 .47359 L
.4794 .48767 L
.48767 .49316 L
.50893 .51233 L
.51233 .51467 L
.53656 .53698 L
.53698 .53729 L
.56164 .55932 L
.56452 .56164 L
.58629 .58129 L
.59208 .58629 L
.61095 .60341 L
.61905 .61095 L
.6356 .6258 L
.64543 .6356 L
.66026 .64873 L
.67119 .66026 L
.68491 .67242 L
.69626 .68491 L
.70957 .69708 L
.72051 .70957 L
.73422 .72288 L
.74378 .73422 L
.75888 .75025 L
.76577 .75888 L
.78353 .78026 L
.78592 .78353 L
.80482 .80819 L
.80819 .81563 L
.81896 .83284 L
.80819 .84212 L
.79265 .83284 L
.78353 .82882 L
.75888 .81298 L
.75244 .80819 L
.73422 .79647 L
.719 .78353 L
.70957 .77713 L
.68931 .75888 L
.68491 .75578 L
.6616 .73422 L
.66026 .73324 L
.6356 .71047 L
.63448 .70957 L
.61095 .68817 L
.60717 .68491 L
.58629 .6657 L
.58044 .66026 L
.56164 .643 L
.55425 .6356 L
.53698 .61988 L
.52862 .61095 L
.51233 .59608 L
.50365 .58629 L
.48767 .57132 L
.47947 .56164 L
.46302 .5453 L
.45629 .53698 L
.43836 .5175 L
.43443 .51233 L
.41414 .48767 L
.41371 .48692 L
.39462 .46302 L
.38905 .45061 L
.38143 .43836 L
F
0 g
.38905 .43073 m
.40395 .43836 L
.41371 .44234 L
.43836 .45711 L
.44612 .46302 L
.46302 .47359 L
.4794 .48767 L
.48767 .49316 L
.50893 .51233 L
.51233 .51467 L
.53656 .53698 L
.53698 .53729 L
.56164 .55932 L
.56452 .56164 L
.58629 .58129 L
.59208 .58629 L
.61095 .60341 L
.61905 .61095 L
.6356 .6258 L
.64543 .6356 L
.66026 .64873 L
.67119 .66026 L
.68491 .67242 L
.69626 .68491 L
.70957 .69708 L
.72051 .70957 L
.73422 .72288 L
.74378 .73422 L
.75888 .75025 L
.76577 .75888 L
.78353 .78026 L
.78592 .78353 L
.80482 .80819 L
.80819 .81563 L
.81896 .83284 L
.80819 .84212 L
.79265 .83284 L
.78353 .82882 L
.75888 .81298 L
.75244 .80819 L
.73422 .79647 L
.719 .78353 L
.70957 .77713 L
.68931 .75888 L
.68491 .75578 L
.6616 .73422 L
.66026 .73324 L
.6356 .71047 L
.63448 .70957 L
.61095 .68817 L
Mistroke
.60717 .68491 L
.58629 .6657 L
.58044 .66026 L
.56164 .643 L
.55425 .6356 L
.53698 .61988 L
.52862 .61095 L
.51233 .59608 L
.50365 .58629 L
.48767 .57132 L
.47947 .56164 L
.46302 .5453 L
.45629 .53698 L
.43836 .5175 L
.43443 .51233 L
.41414 .48767 L
.41371 .48692 L
.39462 .46302 L
.38905 .45061 L
.38143 .43836 L
.38905 .43073 L
Mfstroke
.2 g
.43836 .47157 m
.46302 .48623 L
.46495 .48767 L
.48767 .50199 L
.49969 .51233 L
.51233 .52102 L
.52996 .53698 L
.53698 .54211 L
.55805 .56164 L
.56164 .56441 L
.58492 .58629 L
.58629 .58742 L
.61095 .61082 L
.61108 .61095 L
.6356 .63381 L
.63739 .6356 L
.66026 .65746 L
.66288 .66026 L
.68491 .68201 L
.68747 .68491 L
.70957 .70787 L
.71098 .70957 L
.73353 .73422 L
.73422 .73519 L
.7552 .75888 L
.75888 .76484 L
.77405 .78353 L
.78353 .80784 L
.78364 .80819 L
.78353 .80829 L
.78286 .80819 L
.75888 .80003 L
.73422 .78391 L
.7337 .78353 L
.70957 .76797 L
.6989 .75888 L
.68491 .74909 L
.66848 .73422 L
.66026 .72814 L
.6403 .70957 L
.6356 .7059 L
.6134 .68491 L
.61095 .68287 L
.58732 .66026 L
.58629 .65934 L
.56181 .6356 L
.56164 .63543 L
.53698 .61133 L
.53662 .61095 L
.51233 .58646 L
.51218 .58629 L
.48833 .56164 L
.48767 .56081 L
.46535 .53698 L
.46302 .53372 L
.44393 .51233 L
.43836 .50338 L
.42553 .48767 L
F
0 g
.43836 .47157 m
.46302 .48623 L
.46495 .48767 L
.48767 .50199 L
.49969 .51233 L
.51233 .52102 L
.52996 .53698 L
.53698 .54211 L
.55805 .56164 L
.56164 .56441 L
.58492 .58629 L
.58629 .58742 L
.61095 .61082 L
.61108 .61095 L
.6356 .63381 L
.63739 .6356 L
.66026 .65746 L
.66288 .66026 L
.68491 .68201 L
.68747 .68491 L
.70957 .70787 L
.71098 .70957 L
.73353 .73422 L
.73422 .73519 L
.7552 .75888 L
.75888 .76484 L
.77405 .78353 L
.78353 .80784 L
.78364 .80819 L
.78353 .80829 L
.78286 .80819 L
.75888 .80003 L
.73422 .78391 L
.7337 .78353 L
.70957 .76797 L
.6989 .75888 L
.68491 .74909 L
.66848 .73422 L
.66026 .72814 L
.6403 .70957 L
.6356 .7059 L
.6134 .68491 L
.61095 .68287 L
.58732 .66026 L
.58629 .65934 L
.56181 .6356 L
.56164 .63543 L
.53698 .61133 L
.53662 .61095 L
.51233 .58646 L
Mistroke
.51218 .58629 L
.48833 .56164 L
.48767 .56081 L
.46535 .53698 L
.46302 .53372 L
.44393 .51233 L
.43836 .50338 L
.42553 .48767 L
.43836 .47157 L
Mfstroke
.3 g
.46302 .49511 m
.48767 .50982 L
.49081 .51233 L
.51233 .52666 L
.52401 .53698 L
.53698 .54641 L
.55355 .56164 L
.56164 .56792 L
.58121 .58629 L
.58629 .59051 L
.60774 .61095 L
.61095 .61381 L
.63347 .6356 L
.6356 .63766 L
.65854 .66026 L
.66026 .66207 L
.68291 .68491 L
.68491 .68722 L
.7064 .70957 L
.70957 .71362 L
.72855 .73422 L
.73422 .74247 L
.74832 .75888 L
.75888 .77912 L
.76168 .78353 L
.75888 .78697 L
.75072 .78353 L
.73422 .77628 L
.70957 .76014 L
.70796 .75888 L
.68491 .74325 L
.67466 .73422 L
.66026 .72364 L
.64499 .70957 L
.6356 .70222 L
.61726 .68491 L
.61095 .67964 L
.59073 .66026 L
.58629 .65629 L
.56504 .6356 L
.56164 .63232 L
.54005 .61095 L
.53698 .60773 L
.51578 .58629 L
.51233 .58232 L
.49245 .56164 L
.48767 .55557 L
.47052 .53698 L
.46302 .52614 L
.45115 .51233 L
F
0 g
.46302 .49511 m
.48767 .50982 L
.49081 .51233 L
.51233 .52666 L
.52401 .53698 L
.53698 .54641 L
.55355 .56164 L
.56164 .56792 L
.58121 .58629 L
.58629 .59051 L
.60774 .61095 L
.61095 .61381 L
.63347 .6356 L
.6356 .63766 L
.65854 .66026 L
.66026 .66207 L
.68291 .68491 L
.68491 .68722 L
.7064 .70957 L
.70957 .71362 L
.72855 .73422 L
.73422 .74247 L
.74832 .75888 L
.75888 .77912 L
.76168 .78353 L
.75888 .78697 L
.75072 .78353 L
.73422 .77628 L
.70957 .76014 L
.70796 .75888 L
.68491 .74325 L
.67466 .73422 L
.66026 .72364 L
.64499 .70957 L
.6356 .70222 L
.61726 .68491 L
.61095 .67964 L
.59073 .66026 L
.58629 .65629 L
.56504 .6356 L
.56164 .63232 L
.54005 .61095 L
.53698 .60773 L
.51578 .58629 L
.51233 .58232 L
.49245 .56164 L
.48767 .55557 L
.47052 .53698 L
.46302 .52614 L
.45115 .51233 L
Mistroke
.46302 .49511 L
Mfstroke
.4 g
.46302 .50537 m
.47906 .51233 L
.48767 .51664 L
.51233 .53207 L
.51808 .53698 L
.53698 .55047 L
.54926 .56164 L
.56164 .57122 L
.57774 .58629 L
.58629 .5934 L
.60469 .61095 L
.61095 .61655 L
.63059 .6356 L
.6356 .64046 L
.65562 .66026 L
.66026 .66516 L
.67973 .68491 L
.68491 .69094 L
.70267 .70957 L
.70957 .71855 L
.72374 .73422 L
.73422 .75051 L
.74089 .75888 L
.73422 .76795 L
.71814 .75888 L
.70957 .75419 L
.68491 .73774 L
.68075 .73422 L
.66026 .7194 L
.64945 .70957 L
.6356 .69876 L
.62088 .68491 L
.61095 .67661 L
.5939 .66026 L
.58629 .65343 L
.56803 .6356 L
.56164 .62941 L
.54308 .61095 L
.53698 .60452 L
.51909 .58629 L
.51233 .57847 L
.49634 .56164 L
.48767 .5504 L
.47557 .53698 L
.46302 .51721 L
.45926 .51233 L
F
0 g
.46302 .50537 m
.47906 .51233 L
.48767 .51664 L
.51233 .53207 L
.51808 .53698 L
.53698 .55047 L
.54926 .56164 L
.56164 .57122 L
.57774 .58629 L
.58629 .5934 L
.60469 .61095 L
.61095 .61655 L
.63059 .6356 L
.6356 .64046 L
.65562 .66026 L
.66026 .66516 L
.67973 .68491 L
.68491 .69094 L
.70267 .70957 L
.70957 .71855 L
.72374 .73422 L
.73422 .75051 L
.74089 .75888 L
.73422 .76795 L
.71814 .75888 L
.70957 .75419 L
.68491 .73774 L
.68075 .73422 L
.66026 .7194 L
.64945 .70957 L
.6356 .69876 L
.62088 .68491 L
.61095 .67661 L
.5939 .66026 L
.58629 .65343 L
.56803 .6356 L
.56164 .62941 L
.54308 .61095 L
.53698 .60452 L
.51909 .58629 L
.51233 .57847 L
.49634 .56164 L
.48767 .5504 L
.47557 .53698 L
.46302 .51721 L
.45926 .51233 L
.46302 .50537 L
s
.5 g
.48767 .5237 m
.51145 .53698 L
.51233 .53753 L
.53698 .55448 L
.54497 .56164 L
.56164 .57443 L
.57437 .58629 L
.58629 .59619 L
.60176 .61095 L
.61095 .61918 L
.62783 .6356 L
.6356 .64316 L
.65282 .66026 L
.66026 .66816 L
.67667 .68491 L
.68491 .69461 L
.69901 .70957 L
.70957 .72375 L
.71875 .73422 L
.70957 .74823 L
.68743 .73422 L
.68491 .73259 L
.66026 .71526 L
.6539 .70957 L
.6356 .6954 L
.62439 .68491 L
.61095 .67368 L
.59696 .66026 L
.58629 .65066 L
.57091 .6356 L
.56164 .62658 L
.546 .61095 L
.53698 .60138 L
.52229 .58629 L
.51233 .57461 L
.50018 .56164 L
.48767 .54479 L
.48093 .53698 L
F
0 g
.48767 .5237 m
.51145 .53698 L
.51233 .53753 L
.53698 .55448 L
.54497 .56164 L
.56164 .57443 L
.57437 .58629 L
.58629 .59619 L
.60176 .61095 L
.61095 .61918 L
.62783 .6356 L
.6356 .64316 L
.65282 .66026 L
.66026 .66816 L
.67667 .68491 L
.68491 .69461 L
.69901 .70957 L
.70957 .72375 L
.71875 .73422 L
.70957 .74823 L
.68743 .73422 L
.68491 .73259 L
.66026 .71526 L
.6539 .70957 L
.6356 .6954 L
.62439 .68491 L
.61095 .67368 L
.59696 .66026 L
.58629 .65066 L
.57091 .6356 L
.56164 .62658 L
.546 .61095 L
.53698 .60138 L
.52229 .58629 L
.51233 .57461 L
.50018 .56164 L
.48767 .54479 L
.48093 .53698 L
.48767 .5237 L
s
.6 g
.48767 .53557 m
.4998 .53698 L
.51233 .54306 L
.53698 .55859 L
.54046 .56164 L
.56164 .57763 L
.57098 .58629 L
.58629 .59896 L
.59887 .61095 L
.61095 .62178 L
.62513 .6356 L
.6356 .64582 L
.65007 .66026 L
.66026 .67116 L
.67363 .68491 L
.68491 .6984 L
.69526 .70957 L
.70957 .73001 L
.71298 .73422 L
.70957 .74073 L
.69624 .73422 L
.68491 .72781 L
.66026 .71106 L
.65855 .70957 L
.6356 .69205 L
.62792 .68491 L
.61095 .67078 L
.59998 .66026 L
.58629 .64793 L
.57374 .6356 L
.56164 .62378 L
.54888 .61095 L
.53698 .59822 L
.52548 .58629 L
.51233 .57055 L
.50417 .56164 L
.48767 .53733 L
.48741 .53698 L
F
0 g
.48767 .53557 m
.4998 .53698 L
.51233 .54306 L
.53698 .55859 L
.54046 .56164 L
.56164 .57763 L
.57098 .58629 L
.58629 .59896 L
.59887 .61095 L
.61095 .62178 L
.62513 .6356 L
.6356 .64582 L
.65007 .66026 L
.66026 .67116 L
.67363 .68491 L
.68491 .6984 L
.69526 .70957 L
.70957 .73001 L
.71298 .73422 L
.70957 .74073 L
.69624 .73422 L
.68491 .72781 L
.66026 .71106 L
.65855 .70957 L
.6356 .69205 L
.62792 .68491 L
.61095 .67078 L
.59998 .66026 L
.58629 .64793 L
.57374 .6356 L
.56164 .62378 L
.54888 .61095 L
.53698 .59822 L
.52548 .58629 L
.51233 .57055 L
.50417 .56164 L
.48767 .53733 L
.48741 .53698 L
.48767 .53557 L
s
.7 g
.51233 .54982 m
.53487 .56164 L
.53698 .56308 L
.56164 .58092 L
.56748 .58629 L
.58629 .60175 L
.59595 .61095 L
.61095 .6244 L
.62242 .6356 L
.6356 .64852 L
.64731 .66026 L
.66026 .67424 L
.67052 .68491 L
.68491 .70256 L
.69123 .70957 L
.68491 .72241 L
.6642 .70957 L
.66026 .70679 L
.6356 .68863 L
.63157 .68491 L
.61095 .66785 L
.60303 .66026 L
.58629 .64518 L
.57658 .6356 L
.56164 .62093 L
.55178 .61095 L
.53698 .59493 L
.52877 .58629 L
.51233 .56595 L
.50854 .56164 L
F
0 g
.51233 .54982 m
.53487 .56164 L
.53698 .56308 L
.56164 .58092 L
.56748 .58629 L
.58629 .60175 L
.59595 .61095 L
.61095 .6244 L
.62242 .6356 L
.6356 .64852 L
.64731 .66026 L
.66026 .67424 L
.67052 .68491 L
.68491 .70256 L
.69123 .70957 L
.68491 .72241 L
.6642 .70957 L
.66026 .70679 L
.6356 .68863 L
.63157 .68491 L
.61095 .66785 L
.60303 .66026 L
.58629 .64518 L
.57658 .6356 L
.56164 .62093 L
.55178 .61095 L
.53698 .59493 L
.52877 .58629 L
.51233 .56595 L
.50854 .56164 L
.51233 .54982 L
s
.8 g
.53698 .56857 m
.56164 .58442 L
.5637 .58629 L
.58629 .60463 L
.59293 .61095 L
.61095 .62708 L
.61964 .6356 L
.6356 .6513 L
.64447 .66026 L
.66026 .67753 L
.66725 .68491 L
.68491 .70767 L
.68651 .70957 L
.68491 .71479 L
.67233 .70957 L
.66026 .70214 L
.6356 .685 L
.6355 .68491 L
.61095 .6648 L
.6062 .66026 L
.58629 .64233 L
.5795 .6356 L
.56164 .61796 L
.55478 .61095 L
.53698 .59135 L
.53228 .58629 L
F
0 g
.53698 .56857 m
.56164 .58442 L
.5637 .58629 L
.58629 .60463 L
.59293 .61095 L
.61095 .62708 L
.61964 .6356 L
.6356 .6513 L
.64447 .66026 L
.66026 .67753 L
.66725 .68491 L
.68491 .70767 L
.68651 .70957 L
.68491 .71479 L
.67233 .70957 L
.66026 .70214 L
.6356 .685 L
.6355 .68491 L
.61095 .6648 L
.6062 .66026 L
.58629 .64233 L
.5795 .6356 L
.56164 .61796 L
.55478 .61095 L
.53698 .59135 L
.53228 .58629 L
.53698 .56857 L
s
.9 g
.53698 .5767 m
.55819 .58629 L
.56164 .58892 L
.58629 .60771 L
.58971 .61095 L
.61095 .62991 L
.61673 .6356 L
.6356 .65427 L
.64147 .66026 L
.66026 .68126 L
.66363 .68491 L
.66026 .69641 L
.64116 .68491 L
.6356 .68054 L
.61095 .66155 L
.6096 .66026 L
.58629 .6393 L
.58258 .6356 L
.56164 .61473 L
.55799 .61095 L
.53698 .58711 L
.53625 .58629 L
F
0 g
.53698 .5767 m
.55819 .58629 L
.56164 .58892 L
.58629 .60771 L
.58971 .61095 L
.61095 .62991 L
.61673 .6356 L
.6356 .65427 L
.64147 .66026 L
.66026 .68126 L
.66363 .68491 L
.66026 .69641 L
.64116 .68491 L
.6356 .68054 L
.61095 .66155 L
.6096 .66026 L
.58629 .6393 L
.58258 .6356 L
.56164 .61473 L
.55799 .61095 L
.53698 .58711 L
.53625 .58629 L
.53698 .5767 L
s
1 g
.56164 .59608 m
.58597 .61095 L
.58629 .61125 L
.61095 .63301 L
.61357 .6356 L
.6356 .6576 L
.63817 .66026 L
.6356 .6749 L
.61435 .66026 L
.61095 .65702 L
.58629 .63593 L
.58597 .6356 L
.56164 .61101 L
.56157 .61095 L
F
0 g
.56164 .59608 m
.58597 .61095 L
.58629 .61125 L
.61095 .63301 L
.61357 .6356 L
.6356 .6576 L
.63817 .66026 L
.6356 .6749 L
.61435 .66026 L
.61095 .65702 L
.58629 .63593 L
.58597 .6356 L
.56164 .61101 L
.56157 .61095 L
.56164 .59608 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Mtetra
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Mtetra
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Mtetra
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Mtetra
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Mtetra
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Mtetra
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Mtetra
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Mtetra
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Mtetra
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Mtetra
.57384 .54314 .58111 .55092 .59512 .54671 .5879 .53889 Mtetra
.5879 .53889 .59512 .54671 .60921 .54249 .60203 .53463 Mtetra
.60203 .53463 .60921 .54249 .62337 .53824 .61624 .53034 Mtetra
.61624 .53034 .62337 .53824 .63759 .53397 .63052 .52603 Mtetra
.63052 .52603 .63759 .53397 .6519 .52968 .64487 .5217 Mtetra
.64487 .5217 .6519 .52968 .66627 .52537 .6593 .51735 Mtetra
.6593 .51735 .66627 .52537 .68072 .52103 .67379 .51297 Mtetra
.67379 .51297 .68072 .52103 .69524 .51668 .68837 .50857 Mtetra
.68837 .50857 .69524 .51668 .70984 .5123 .70302 .50415 Mtetra
.70302 .50415 .70984 .5123 .72452 .5079 .71774 .49971 Mtetra
.71774 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Mtetra
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Mtetra
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Mtetra
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Mtetra
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Mtetra
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Mtetra
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Mtetra
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Mtetra
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Mtetra
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Mtetra
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .53529 Mtetra
.5665 .53529 .57384 .54314 .5879 .53889 .58061 .531 Mtetra
.58061 .531 .5879 .53889 .60203 .53463 .59479 .5267 Mtetra
.59479 .5267 .60203 .53463 .61624 .53034 .60905 .52237 Mtetra
.60905 .52237 .61624 .53034 .63052 .52603 .62338 .51802 Mtetra
.62338 .51802 .63052 .52603 .64487 .5217 .63778 .51365 Mtetra
.63778 .51365 .64487 .5217 .6593 .51735 .65225 .50925 Mtetra
.65225 .50925 .6593 .51735 .67379 .51297 .6668 .50483 Mtetra
.6668 .50483 .67379 .51297 .68837 .50857 .68143 .50039 Mtetra
.68143 .50039 .68837 .50857 .70302 .50415 .69613 .49593 Mtetra
.69613 .49593 .70302 .50415 .71774 .49971 .71091 .49144 Mtetra
.71091 .49144 .71774 .49971 .73255 .49524 .72577 .48693 Mtetra
.72577 .48693 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Mtetra
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Mtetra
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Mtetra
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55702 Mtetra
.46198 .55702 .4697 .56468 .48332 .56054 .47564 .55285 Mtetra
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Mtetra
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Mtetra
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .5402 Mtetra
.51705 .5402 .5246 .54801 .5385 .54379 .531 .53594 Mtetra
.531 .53594 .5385 .54379 .55246 .53955 .54501 .53166 Mtetra
.54501 .53166 .55246 .53955 .5665 .53529 .5591 .52736 Mtetra
.5591 .52736 .5665 .53529 .58061 .531 .57325 .52304 Mtetra
.57325 .52304 .58061 .531 .59479 .5267 .58748 .51869 Mtetra
.58748 .51869 .59479 .5267 .60905 .52237 .60179 .51432 Mtetra
.60179 .51432 .60905 .52237 .62338 .51802 .61616 .50993 Mtetra
.61616 .50993 .62338 .51802 .63778 .51365 .63062 .50552 Mtetra
.63062 .50552 .63778 .51365 .65225 .50925 .64514 .50108 Mtetra
.64514 .50108 .65225 .50925 .6668 .50483 .65974 .49662 Mtetra
.65974 .49662 .6668 .50483 .68143 .50039 .67442 .49214 Mtetra
.67442 .49214 .68143 .50039 .69613 .49593 .68918 .48763 Mtetra
.68918 .48763 .69613 .49593 .71091 .49144 .70401 .4831 Mtetra
.70401 .4831 .71091 .49144 .72577 .48693 .71892 .47854 Mtetra
.71892 .47854 .72577 .48693 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46936 Mtetra
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Mtetra
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56181 Mtetra
.41347 .56181 .42139 .56942 .43486 .56531 .42697 .55767 Mtetra
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .55349 Mtetra
.44054 .55349 .44838 .56118 .46198 .55702 .45418 .5493 Mtetra
.45418 .5493 .46198 .55702 .47564 .55285 .46789 .54509 Mtetra
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Mtetra
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Mtetra
.49552 .5366 .50318 .54444 .51705 .5402 .50944 .53232 Mtetra
.50944 .53232 .51705 .5402 .531 .53594 .52343 .52802 Mtetra
.52343 .52802 .531 .53594 .54501 .53166 .53749 .5237 Mtetra
.53749 .5237 .54501 .53166 .5591 .52736 .55162 .51936 Mtetra
.55162 .51936 .5591 .52736 .57325 .52304 .56582 .51499 Mtetra
.56582 .51499 .57325 .52304 .58748 .51869 .5801 .51061 Mtetra
.5801 .51061 .58748 .51869 .60179 .51432 .59446 .5062 Mtetra
.59446 .5062 .60179 .51432 .61616 .50993 .60888 .50176 Mtetra
.60888 .50176 .61616 .50993 .63062 .50552 .62338 .49731 Mtetra
.62338 .49731 .63062 .50552 .64514 .50108 .63796 .49283 Mtetra
.63796 .49283 .64514 .50108 .65974 .49662 .65262 .48832 Mtetra
.65262 .48832 .65974 .49662 .67442 .49214 .66735 .4838 Mtetra
.66735 .4838 .67442 .49214 .68918 .48763 .68215 .47925 Mtetra
.68215 .47925 .68918 .48763 .70401 .4831 .69704 .47467 Mtetra
.69704 .47467 .70401 .4831 .71892 .47854 .712 .47007 Mtetra
.712 .47007 .71892 .47854 .73391 .47397 .72705 .46545 Mtetra
.72705 .46545 .73391 .47397 .74897 .46936 .74217 .4608 Mtetra
.74217 .4608 .74897 .46936 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Mtetra
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Mtetra
.39199 .55831 .40003 .56594 .41347 .56181 .40547 .55414 Mtetra
.40547 .55414 .41347 .56181 .42697 .55767 .41902 .54995 Mtetra
.41902 .54995 .42697 .55767 .44054 .55349 .43263 .54574 Mtetra
.43263 .54574 .44054 .55349 .45418 .5493 .44632 .54151 Mtetra
.44632 .54151 .45418 .5493 .46789 .54509 .46007 .53726 Mtetra
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .53298 Mtetra
.47389 .53298 .48167 .54086 .49552 .5366 .48778 .52869 Mtetra
.48778 .52869 .49552 .5366 .50944 .53232 .50175 .52437 Mtetra
.50175 .52437 .50944 .53232 .52343 .52802 .51578 .52003 Mtetra
.51578 .52003 .52343 .52802 .53749 .5237 .52989 .51567 Mtetra
.52989 .51567 .53749 .5237 .55162 .51936 .54407 .51128 Mtetra
.54407 .51128 .55162 .51936 .56582 .51499 .55833 .50688 Mtetra
.55833 .50688 .56582 .51499 .5801 .51061 .57265 .50245 Mtetra
.57265 .50245 .5801 .51061 .59446 .5062 .58706 .49799 Mtetra
.58706 .49799 .59446 .5062 .60888 .50176 .60153 .49352 Mtetra
.60153 .49352 .60888 .50176 .62338 .49731 .61609 .48902 Mtetra
.61609 .48902 .62338 .49731 .63796 .49283 .63071 .48449 Mtetra
.63071 .48449 .63796 .49283 .65262 .48832 .64542 .47995 Mtetra
.64542 .47995 .65262 .48832 .66735 .4838 .6602 .47538 Mtetra
.6602 .47538 .66735 .4838 .68215 .47925 .67506 .47078 Mtetra
.67506 .47078 .68215 .47925 .69704 .47467 .69 .46616 Mtetra
.69 .46616 .69704 .47467 .712 .47007 .70502 .46152 Mtetra
.70502 .46152 .712 .47007 .72705 .46545 .72012 .45685 Mtetra
.72012 .45685 .72705 .46545 .74217 .4608 .7353 .45216 Mtetra
.7353 .45216 .74217 .4608 .75737 .45613 .75056 .44744 Mtetra
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Mtetra
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Mtetra
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Mtetra
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Mtetra
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Mtetra
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53791 Mtetra
.42465 .53791 .43263 .54574 .44632 .54151 .43837 .53364 Mtetra
.43837 .53364 .44632 .54151 .46007 .53726 .45217 .52935 Mtetra
.45217 .52935 .46007 .53726 .47389 .53298 .46604 .52504 Mtetra
.46604 .52504 .47389 .53298 .48778 .52869 .47998 .5207 Mtetra
.47998 .5207 .48778 .52869 .50175 .52437 .49399 .51634 Mtetra
.49399 .51634 .50175 .52437 .51578 .52003 .50807 .51196 Mtetra
.50807 .51196 .51578 .52003 .52989 .51567 .52222 .50756 Mtetra
.52222 .50756 .52989 .51567 .54407 .51128 .53645 .50313 Mtetra
.53645 .50313 .54407 .51128 .55833 .50688 .55076 .49868 Mtetra
.55076 .49868 .55833 .50688 .57265 .50245 .56513 .49421 Mtetra
.56513 .49421 .57265 .50245 .58706 .49799 .57958 .48971 Mtetra
.57958 .48971 .58706 .49799 .60153 .49352 .59411 .48519 Mtetra
.59411 .48519 .60153 .49352 .61609 .48902 .60871 .48065 Mtetra
.60871 .48065 .61609 .48902 .63071 .48449 .6234 .47608 Mtetra
.6234 .47608 .63071 .48449 .64542 .47995 .63815 .47149 Mtetra
.63815 .47149 .64542 .47995 .6602 .47538 .65299 .46688 Mtetra
.65299 .46688 .6602 .47538 .67506 .47078 .6679 .46224 Mtetra
.6679 .46224 .67506 .47078 .69 .46616 .6829 .45757 Mtetra
.6829 .45757 .69 .46616 .70502 .46152 .69797 .45288 Mtetra
.69797 .45288 .70502 .46152 .72012 .45685 .71312 .44817 Mtetra
.71312 .44817 .72012 .45685 .7353 .45216 .72836 .44343 Mtetra
.72836 .44343 .7353 .45216 .75056 .44744 .74368 .43866 Mtetra
.74368 .43866 .75056 .44744 .7659 .4427 .75908 .43387 Mtetra
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42905 Mtetra
.77456 .42905 .78132 .43793 .79683 .43313 .79013 .42421 Mtetra
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Mtetra
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .5343 Mtetra
.40288 .5343 .41099 .54216 .42465 .53791 .41658 .53001 Mtetra
.41658 .53001 .42465 .53791 .43837 .53364 .43036 .5257 Mtetra
.43036 .5257 .43837 .53364 .45217 .52935 .4442 .52137 Mtetra
.4442 .52137 .45217 .52935 .46604 .52504 .45811 .51701 Mtetra
.45811 .51701 .46604 .52504 .47998 .5207 .4721 .51263 Mtetra
.4721 .51263 .47998 .5207 .49399 .51634 .48615 .50823 Mtetra
.48615 .50823 .49399 .51634 .50807 .51196 .50028 .50381 Mtetra
.50028 .50381 .50807 .51196 .52222 .50756 .51448 .49937 Mtetra
.51448 .49937 .52222 .50756 .53645 .50313 .52876 .4949 Mtetra
.52876 .4949 .53645 .50313 .55076 .49868 .54311 .4904 Mtetra
.54311 .4904 .55076 .49868 .56513 .49421 .55754 .48589 Mtetra
.55754 .48589 .56513 .49421 .57958 .48971 .57204 .48135 Mtetra
.57204 .48135 .57958 .48971 .59411 .48519 .58662 .47679 Mtetra
.58662 .47679 .59411 .48519 .60871 .48065 .60127 .4722 Mtetra
.60127 .4722 .60871 .48065 .6234 .47608 .616 .46759 Mtetra
.616 .46759 .6234 .47608 .63815 .47149 .63082 .46295 Mtetra
.63082 .46295 .63815 .47149 .65299 .46688 .6457 .45829 Mtetra
.6457 .45829 .65299 .46688 .6679 .46224 .66067 .4536 Mtetra
.66067 .4536 .6679 .46224 .6829 .45757 .67572 .44889 Mtetra
.67572 .44889 .6829 .45757 .69797 .45288 .69085 .44416 Mtetra
.69085 .44416 .69797 .45288 .71312 .44817 .70606 .4394 Mtetra
.70606 .4394 .71312 .44817 .72836 .44343 .72135 .43461 Mtetra
.72135 .43461 .72836 .44343 .74368 .43866 .73673 .4298 Mtetra
.73673 .4298 .74368 .43866 .75908 .43387 .75218 .42496 Mtetra
.75218 .42496 .75908 .43387 .77456 .42905 .76773 .42009 Mtetra
.76773 .42009 .77456 .42905 .79013 .42421 .78335 .4152 Mtetra
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Mtetra
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Mtetra
.38103 .53067 .38925 .53857 .40288 .5343 .3947 .52637 Mtetra
.3947 .52637 .40288 .5343 .41658 .53001 .40845 .52204 Mtetra
.40845 .52204 .41658 .53001 .43036 .5257 .42226 .51768 Mtetra
.42226 .51768 .43036 .5257 .4442 .52137 .43615 .51331 Mtetra
.43615 .51331 .4442 .52137 .45811 .51701 .45011 .50891 Mtetra
.45011 .50891 .45811 .51701 .4721 .51263 .46414 .50449 Mtetra
.46414 .50449 .4721 .51263 .48615 .50823 .47824 .50005 Mtetra
.47824 .50005 .48615 .50823 .50028 .50381 .49242 .49559 Mtetra
.49242 .49559 .50028 .50381 .51448 .49937 .50667 .4911 Mtetra
.50667 .4911 .51448 .49937 .52876 .4949 .52099 .48658 Mtetra
.52099 .48658 .52876 .4949 .54311 .4904 .53539 .48205 Mtetra
.53539 .48205 .54311 .4904 .55754 .48589 .54987 .47749 Mtetra
.54987 .47749 .55754 .48589 .57204 .48135 .56442 .47291 Mtetra
.56442 .47291 .57204 .48135 .58662 .47679 .57905 .4683 Mtetra
.57905 .4683 .58662 .47679 .60127 .4722 .59376 .46367 Mtetra
.59376 .46367 .60127 .4722 .616 .46759 .60854 .45901 Mtetra
.60854 .45901 .616 .46759 .63082 .46295 .62341 .45433 Mtetra
.62341 .45433 .63082 .46295 .6457 .45829 .63835 .44962 Mtetra
.63835 .44962 .6457 .45829 .66067 .4536 .65337 .44489 Mtetra
.65337 .44489 .66067 .4536 .67572 .44889 .66847 .44013 Mtetra
.66847 .44013 .67572 .44889 .69085 .44416 .68366 .43535 Mtetra
.68366 .43535 .69085 .44416 .70606 .4394 .69892 .43054 Mtetra
.69892 .43054 .70606 .4394 .72135 .43461 .71427 .4257 Mtetra
.71427 .4257 .72135 .43461 .73673 .4298 .72971 .42084 Mtetra
.72971 .42084 .73673 .4298 .75218 .42496 .74522 .41596 Mtetra
.74522 .41596 .75218 .42496 .76773 .42009 .76082 .41104 Mtetra
.76082 .41104 .76773 .42009 .78335 .4152 .77651 .4061 Mtetra
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Mtetra
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Mtetra
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Mtetra
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51835 Mtetra
.38644 .51835 .3947 .52637 .40845 .52204 .40023 .51398 Mtetra
.40023 .51398 .40845 .52204 .42226 .51768 .41409 .50959 Mtetra
.41409 .50959 .42226 .51768 .43615 .51331 .42802 .50518 Mtetra
.42802 .50518 .43615 .51331 .45011 .50891 .44203 .50074 Mtetra
.44203 .50074 .45011 .50891 .46414 .50449 .45611 .49627 Mtetra
.45611 .49627 .46414 .50449 .47824 .50005 .47026 .49179 Mtetra
.47026 .49179 .47824 .50005 .49242 .49559 .48448 .48728 Mtetra
.48448 .48728 .49242 .49559 .50667 .4911 .49878 .48275 Mtetra
.49878 .48275 .50667 .4911 .52099 .48658 .51315 .47819 Mtetra
.51315 .47819 .52099 .48658 .53539 .48205 .5276 .47361 Mtetra
.5276 .47361 .53539 .48205 .54987 .47749 .54213 .46901 Mtetra
.54213 .46901 .54987 .47749 .56442 .47291 .55673 .46438 Mtetra
.55673 .46438 .56442 .47291 .57905 .4683 .57141 .45973 Mtetra
.57141 .45973 .57905 .4683 .59376 .46367 .58617 .45505 Mtetra
.58617 .45505 .59376 .46367 .60854 .45901 .60101 .45035 Mtetra
.60101 .45035 .60854 .45901 .62341 .45433 .61592 .44562 Mtetra
.61592 .44562 .62341 .45433 .63835 .44962 .63092 .44086 Mtetra
.63092 .44086 .63835 .44962 .65337 .44489 .646 .43609 Mtetra
.646 .43609 .65337 .44489 .66847 .44013 .66115 .43128 Mtetra
.66115 .43128 .66847 .44013 .68366 .43535 .6764 .42645 Mtetra
.6764 .42645 .68366 .43535 .69892 .43054 .69172 .42159 Mtetra
.69172 .42159 .69892 .43054 .71427 .4257 .70712 .41671 Mtetra
.70712 .41671 .71427 .4257 .72971 .42084 .72262 .4118 Mtetra
.72262 .4118 .72971 .42084 .74522 .41596 .73819 .40686 Mtetra
.73819 .40686 .74522 .41596 .76082 .41104 .75385 .4019 Mtetra
.75385 .4019 .76082 .41104 .77651 .4061 .7696 .39691 Mtetra
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Mtetra
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Mtetra
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Mtetra
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Mtetra
.36434 .51466 .37272 .5227 .38644 .51835 .37811 .51027 Mtetra
.37811 .51027 .38644 .51835 .40023 .51398 .39194 .50586 Mtetra
.39194 .50586 .40023 .51398 .41409 .50959 .40584 .50142 Mtetra
.40584 .50142 .41409 .50959 .42802 .50518 .41982 .49696 Mtetra
.41982 .49696 .42802 .50518 .44203 .50074 .43387 .49248 Mtetra
.43387 .49248 .44203 .50074 .45611 .49627 .44799 .48798 Mtetra
.44799 .48798 .45611 .49627 .47026 .49179 .46219 .48345 Mtetra
.46219 .48345 .47026 .49179 .48448 .48728 .47646 .47889 Mtetra
.47646 .47889 .48448 .48728 .49878 .48275 .49081 .47432 Mtetra
.49081 .47432 .49878 .48275 .51315 .47819 .50523 .46972 Mtetra
.50523 .46972 .51315 .47819 .5276 .47361 .51973 .46509 Mtetra
.51973 .46509 .5276 .47361 .54213 .46901 .53431 .46044 Mtetra
.53431 .46044 .54213 .46901 .55673 .46438 .54896 .45577 Mtetra
.54896 .45577 .55673 .46438 .57141 .45973 .56369 .45107 Mtetra
.56369 .45107 .57141 .45973 .58617 .45505 .57851 .44635 Mtetra
.57851 .44635 .58617 .45505 .60101 .45035 .5934 .4416 Mtetra
.5934 .4416 .60101 .45035 .61592 .44562 .60837 .43682 Mtetra
.60837 .43682 .61592 .44562 .63092 .44086 .62342 .43202 Mtetra
.62342 .43202 .63092 .44086 .646 .43609 .63855 .4272 Mtetra
.63855 .4272 .646 .43609 .66115 .43128 .65376 .42234 Mtetra
.65376 .42234 .66115 .43128 .6764 .42645 .66906 .41746 Mtetra
.66906 .41746 .6764 .42645 .69172 .42159 .68444 .41256 Mtetra
.663 .741 .908 r
.68444 .41256 .69172 .42159 .70712 .41671 .6999 .40763 Mtetra
.664 .741 .908 r
.6999 .40763 .70712 .41671 .72262 .4118 .71545 .40267 Mtetra
.71545 .40267 .72262 .4118 .73819 .40686 .73109 .39768 Mtetra
.73109 .39768 .73819 .40686 .75385 .4019 .74681 .39266 Mtetra
.74681 .39266 .75385 .4019 .7696 .39691 .76262 .38762 Mtetra
.76262 .38762 .7696 .39691 .78543 .39189 .77851 .38255 Mtetra
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Mtetra
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .5021 Mtetra
.36969 .5021 .37811 .51027 .39194 .50586 .38357 .49765 Mtetra
.38357 .49765 .39194 .50586 .40584 .50142 .39752 .49317 Mtetra
.39752 .49317 .40584 .50142 .41982 .49696 .41154 .48867 Mtetra
.41154 .48867 .41982 .49696 .43387 .49248 .42564 .48415 Mtetra
.42564 .48415 .43387 .49248 .44799 .48798 .43981 .4796 Mtetra
.43981 .4796 .44799 .48798 .46219 .48345 .45405 .47502 Mtetra
.45405 .47502 .46219 .48345 .47646 .47889 .46837 .47043 Mtetra
.46837 .47043 .47646 .47889 .49081 .47432 .48277 .46581 Mtetra
.48277 .46581 .49081 .47432 .50523 .46972 .49724 .46116 Mtetra
.49724 .46116 .50523 .46972 .51973 .46509 .51179 .45649 Mtetra
.51179 .45649 .51973 .46509 .53431 .46044 .52641 .4518 Mtetra
.52641 .4518 .53431 .46044 .54896 .45577 .54112 .44708 Mtetra
.54112 .44708 .54896 .45577 .56369 .45107 .5559 .44233 Mtetra
.5559 .44233 .56369 .45107 .57851 .44635 .57077 .43756 Mtetra
.57077 .43756 .57851 .44635 .5934 .4416 .58571 .43276 Mtetra
.58571 .43276 .5934 .4416 .60837 .43682 .60073 .42794 Mtetra
.60073 .42794 .60837 .43682 .62342 .43202 .61584 .42309 Mtetra
.61584 .42309 .62342 .43202 .63855 .4272 .63103 .41822 Mtetra
.63103 .41822 .63855 .4272 .65376 .42234 .6463 .41331 Mtetra
.6463 .41331 .65376 .42234 .66906 .41746 .66165 .40839 Mtetra
.663 .741 .908 r
.66165 .40839 .66906 .41746 .68444 .41256 .67709 .40344 Mtetra
.664 .742 .908 r
.67709 .40344 .68444 .41256 .6999 .40763 .69261 .39845 Mtetra
.664 .741 .908 r
.69261 .39845 .6999 .40763 .71545 .40267 .70822 .39344 Mtetra
.70822 .39344 .71545 .40267 .73109 .39768 .72391 .3884 Mtetra
.72391 .3884 .73109 .39768 .74681 .39266 .73969 .38333 Mtetra
.73969 .38333 .74681 .39266 .76262 .38762 .75556 .37824 Mtetra
.75556 .37824 .76262 .38762 .77851 .38255 .77152 .37312 Mtetra
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Mtetra
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Mtetra
.34734 .49834 .35588 .50654 .36969 .5021 .36119 .49386 Mtetra
.36119 .49386 .36969 .5021 .38357 .49765 .37511 .48936 Mtetra
.37511 .48936 .38357 .49765 .39752 .49317 .38911 .48484 Mtetra
.38911 .48484 .39752 .49317 .41154 .48867 .40318 .4803 Mtetra
.40318 .4803 .41154 .48867 .42564 .48415 .41732 .47573 Mtetra
.41732 .47573 .42564 .48415 .43981 .4796 .43154 .47114 Mtetra
.43154 .47114 .43981 .4796 .45405 .47502 .44583 .46652 Mtetra
.44583 .46652 .45405 .47502 .46837 .47043 .4602 .46188 Mtetra
.4602 .46188 .46837 .47043 .48277 .46581 .47464 .45721 Mtetra
.47464 .45721 .48277 .46581 .49724 .46116 .48916 .45252 Mtetra
.48916 .45252 .49724 .46116 .51179 .45649 .50376 .4478 Mtetra
.50376 .4478 .51179 .45649 .52641 .4518 .51844 .44306 Mtetra
.51844 .44306 .52641 .4518 .54112 .44708 .5332 .43829 Mtetra
.5332 .43829 .54112 .44708 .5559 .44233 .54803 .4335 Mtetra
.54803 .4335 .5559 .44233 .57077 .43756 .56295 .42868 Mtetra
.56295 .42868 .57077 .43756 .58571 .43276 .57795 .42384 Mtetra
.57795 .42384 .58571 .43276 .60073 .42794 .59302 .41897 Mtetra
.59302 .41897 .60073 .42794 .61584 .42309 .60818 .41407 Mtetra
.60818 .41407 .61584 .42309 .63103 .41822 .62343 .40915 Mtetra
.62343 .40915 .63103 .41822 .6463 .41331 .63875 .40419 Mtetra
.663 .741 .908 r
.63875 .40419 .6463 .41331 .66165 .40839 .65417 .39924 Mtetra
.664 .742 .908 r
.65417 .39924 .66165 .40839 .67709 .40344 .66966 .39422 Mtetra
.66966 .39422 .67709 .40344 .69261 .39845 .68524 .38918 Mtetra
.664 .741 .908 r
.68524 .38918 .69261 .39845 .70822 .39344 .70091 .38411 Mtetra
.70091 .38411 .70822 .39344 .72391 .3884 .71666 .37903 Mtetra
.71666 .37903 .72391 .3884 .73969 .38333 .7325 .37391 Mtetra
.7325 .37391 .73969 .38333 .75556 .37824 .74843 .36876 Mtetra
.74843 .36876 .75556 .37824 .77152 .37312 .76445 .36359 Mtetra
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Mtetra
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Mtetra
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Mtetra
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Mtetra
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Mtetra
.35261 .48554 .36119 .49386 .37511 .48936 .36658 .481 Mtetra
.36658 .481 .37511 .48936 .38911 .48484 .38062 .47643 Mtetra
.38062 .47643 .38911 .48484 .40318 .4803 .39473 .47184 Mtetra
.39473 .47184 .40318 .4803 .41732 .47573 .40892 .46723 Mtetra
.40892 .46723 .41732 .47573 .43154 .47114 .42319 .46259 Mtetra
.42319 .46259 .43154 .47114 .44583 .46652 .43753 .45793 Mtetra
.43753 .45793 .44583 .46652 .4602 .46188 .45194 .45324 Mtetra
.45194 .45324 .4602 .46188 .47464 .45721 .46644 .44853 Mtetra
.46644 .44853 .47464 .45721 .48916 .45252 .48101 .44379 Mtetra
.48101 .44379 .48916 .45252 .50376 .4478 .49566 .43903 Mtetra
.49566 .43903 .50376 .4478 .51844 .44306 .51039 .43424 Mtetra
.51039 .43424 .51844 .44306 .5332 .43829 .5252 .42943 Mtetra
.5252 .42943 .5332 .43829 .54803 .4335 .54008 .42459 Mtetra
.54008 .42459 .54803 .4335 .56295 .42868 .55505 .41972 Mtetra
.55505 .41972 .56295 .42868 .57795 .42384 .5701 .41482 Mtetra
.5701 .41482 .57795 .42384 .59302 .41897 .58524 .4099 Mtetra
.58524 .4099 .59302 .41897 .60818 .41407 .60045 .40496 Mtetra
.60045 .40496 .60818 .41407 .62343 .40915 .61575 .39998 Mtetra
.662 .741 .908 r
.61575 .39998 .62343 .40915 .63875 .40419 .63114 .39503 Mtetra
.664 .742 .909 r
.63114 .39503 .63875 .40419 .65417 .39924 .6466 .39 Mtetra
.665 .742 .908 r
.6466 .39 .65417 .39924 .66966 .39422 .66216 .3849 Mtetra
.664 .741 .908 r
.66216 .3849 .66966 .39422 .68524 .38918 .6778 .37981 Mtetra
.6778 .37981 .68524 .38918 .70091 .38411 .69352 .3747 Mtetra
.69352 .3747 .70091 .38411 .71666 .37903 .70934 .36955 Mtetra
.70934 .36955 .71666 .37903 .7325 .37391 .72524 .36438 Mtetra
.72524 .36438 .7325 .37391 .74843 .36876 .74123 .35918 Mtetra
.74123 .35918 .74843 .36876 .76445 .36359 .75732 .35396 Mtetra
.75732 .35396 .76445 .36359 .78056 .35838 .77349 .3487 Mtetra
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Mtetra
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Mtetra
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Mtetra
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Mtetra
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47255 Mtetra
.35796 .47255 .36658 .481 .38062 .47643 .37205 .46794 Mtetra
.37205 .46794 .38062 .47643 .39473 .47184 .38621 .46331 Mtetra
.38621 .46331 .39473 .47184 .40892 .46723 .40044 .45865 Mtetra
.40044 .45865 .40892 .46723 .42319 .46259 .41476 .45397 Mtetra
.41476 .45397 .42319 .46259 .43753 .45793 .42914 .44926 Mtetra
.42914 .44926 .43753 .45793 .45194 .45324 .44361 .44452 Mtetra
.44361 .44452 .45194 .45324 .46644 .44853 .45815 .43976 Mtetra
.45815 .43976 .46644 .44853 .48101 .44379 .47277 .43498 Mtetra
.47277 .43498 .48101 .44379 .49566 .43903 .48747 .43017 Mtetra
.48747 .43017 .49566 .43903 .51039 .43424 .50225 .42533 Mtetra
.50225 .42533 .51039 .43424 .5252 .42943 .51712 .42047 Mtetra
.51712 .42047 .5252 .42943 .54008 .42459 .53206 .41558 Mtetra
.53206 .41558 .54008 .42459 .55505 .41972 .54708 .41066 Mtetra
.54708 .41066 .55505 .41972 .5701 .41482 .56218 .40572 Mtetra
.56218 .40572 .5701 .41482 .58524 .4099 .57737 .40075 Mtetra
.57737 .40075 .58524 .4099 .60045 .40496 .59264 .39575 Mtetra
.661 .741 .909 r
.59264 .39575 .60045 .40496 .61575 .39998 .608 .39082 Mtetra
.663 .743 .91 r
.608 .39082 .61575 .39998 .63114 .39503 .62344 .3858 Mtetra
.667 .744 .908 r
.62344 .3858 .63114 .39503 .6466 .39 .63896 .3806 Mtetra
.664 .74 .907 r
.63896 .3806 .6466 .39 .66216 .3849 .65458 .37549 Mtetra
.664 .741 .908 r
.65458 .37549 .66216 .3849 .6778 .37981 .67028 .37035 Mtetra
.67028 .37035 .6778 .37981 .69352 .3747 .68606 .36518 Mtetra
.68606 .36518 .69352 .3747 .70934 .36955 .70194 .35999 Mtetra
.70194 .35999 .70934 .36955 .72524 .36438 .7179 .35476 Mtetra
.7179 .35476 .72524 .36438 .74123 .35918 .73396 .34951 Mtetra
.73396 .34951 .74123 .35918 .75732 .35396 .75011 .34422 Mtetra
.75011 .34422 .75732 .35396 .77349 .3487 .76634 .33891 Mtetra
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Mtetra
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Mtetra
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Mtetra
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46865 Mtetra
.3352 .46865 .34395 .47714 .35796 .47255 .34926 .46402 Mtetra
.34926 .46402 .35796 .47255 .37205 .46794 .36339 .45937 Mtetra
.36339 .45937 .37205 .46794 .38621 .46331 .3776 .45469 Mtetra
.3776 .45469 .38621 .46331 .40044 .45865 .39188 .44998 Mtetra
.39188 .44998 .40044 .45865 .41476 .45397 .40624 .44525 Mtetra
.40624 .44525 .41476 .45397 .42914 .44926 .42068 .4405 Mtetra
.42068 .4405 .42914 .44926 .44361 .44452 .43519 .43572 Mtetra
.43519 .43572 .44361 .44452 .45815 .43976 .44978 .43091 Mtetra
.44978 .43091 .45815 .43976 .47277 .43498 .46446 .42608 Mtetra
.46446 .42608 .47277 .43498 .48747 .43017 .47921 .42122 Mtetra
.47921 .42122 .48747 .43017 .50225 .42533 .49404 .41633 Mtetra
.49404 .41633 .50225 .42533 .51712 .42047 .50895 .41142 Mtetra
.50895 .41142 .51712 .42047 .53206 .41558 .52395 .40648 Mtetra
.52395 .40648 .53206 .41558 .54708 .41066 .53902 .40152 Mtetra
.53902 .40152 .54708 .41066 .56218 .40572 .55418 .39652 Mtetra
.55418 .39652 .56218 .40572 .57737 .40075 .56943 .3915 Mtetra
.659 .74 .909 r
.56943 .3915 .57737 .40075 .59264 .39575 .58476 .38662 Mtetra
.66 .744 .912 r
.58476 .38662 .59264 .39575 .608 .39082 .60017 .3817 Mtetra
.671 .749 .909 r
.60017 .3817 .608 .39082 .62344 .3858 .61566 .37628 Mtetra
.664 .739 .906 r
.61566 .37628 .62344 .3858 .63896 .3806 .63125 .37114 Mtetra
.664 .741 .908 r
.63125 .37114 .63896 .3806 .65458 .37549 .64692 .36598 Mtetra
.64692 .36598 .65458 .37549 .67028 .37035 .66268 .36079 Mtetra
.66268 .36079 .67028 .37035 .68606 .36518 .67853 .35557 Mtetra
.67853 .35557 .68606 .36518 .70194 .35999 .69446 .35032 Mtetra
.69446 .35032 .70194 .35999 .7179 .35476 .71049 .34504 Mtetra
.71049 .34504 .7179 .35476 .73396 .34951 .72661 .33973 Mtetra
.72661 .33973 .73396 .34951 .75011 .34422 .74282 .33439 Mtetra
.74282 .33439 .75011 .34422 .76634 .33891 .75912 .32902 Mtetra
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Mtetra
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46936 Mtetra
.29838 .46936 .3073 .47784 .32121 .47326 .31234 .46474 Mtetra
.31234 .46474 .32121 .47326 .3352 .46865 .32636 .46009 Mtetra
.32636 .46009 .3352 .46865 .34926 .46402 .34047 .45541 Mtetra
.34047 .45541 .34926 .46402 .36339 .45937 .35465 .45071 Mtetra
.35465 .45071 .36339 .45937 .3776 .45469 .3689 .44598 Mtetra
.3689 .44598 .3776 .45469 .39188 .44998 .38323 .44123 Mtetra
.38323 .44123 .39188 .44998 .40624 .44525 .39764 .43645 Mtetra
.39764 .43645 .40624 .44525 .42068 .4405 .41213 .43165 Mtetra
.41213 .43165 .42068 .4405 .43519 .43572 .42669 .42682 Mtetra
.42669 .42682 .43519 .43572 .44978 .43091 .44133 .42197 Mtetra
.44133 .42197 .44978 .43091 .46446 .42608 .45606 .41709 Mtetra
.45606 .41709 .46446 .42608 .47921 .42122 .47086 .41218 Mtetra
.47086 .41218 .47921 .42122 .49404 .41633 .48574 .40724 Mtetra
.48574 .40724 .49404 .41633 .50895 .41142 .50071 .40228 Mtetra
.50071 .40228 .50895 .41142 .52395 .40648 .51576 .39729 Mtetra
.51576 .39729 .52395 .40648 .53902 .40152 .53089 .39228 Mtetra
.663 .741 .908 r
.53089 .39228 .53902 .40152 .55418 .39652 .5461 .38723 Mtetra
.657 .739 .911 r
.5461 .38723 .55418 .39652 .56943 .3915 .5614 .38244 Mtetra
.651 .743 .917 r
.5614 .38244 .56943 .3915 .58476 .38662 .57679 .37783 Mtetra
.682 .761 .912 r
.57679 .37783 .58476 .38662 .60017 .3817 .59225 .37197 Mtetra
.664 .735 .902 r
.59225 .37197 .60017 .3817 .61566 .37628 .60781 .36677 Mtetra
.664 .741 .908 r
.60781 .36677 .61566 .37628 .63125 .37114 .62345 .36159 Mtetra
.62345 .36159 .63125 .37114 .64692 .36598 .63918 .35637 Mtetra
.63918 .35637 .64692 .36598 .66268 .36079 .655 .35113 Mtetra
.655 .35113 .66268 .36079 .67853 .35557 .67091 .34585 Mtetra
.67091 .34585 .67853 .35557 .69446 .35032 .68691 .34055 Mtetra
.68691 .34055 .69446 .35032 .71049 .34504 .703 .33521 Mtetra
.703 .33521 .71049 .34504 .72661 .33973 .71918 .32985 Mtetra
.71918 .32985 .72661 .33973 .74282 .33439 .73545 .32445 Mtetra
.73545 .32445 .74282 .33439 .75912 .32902 .75182 .31903 Mtetra
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Mtetra
.27545 .46545 .2845 .47397 .29838 .46936 .28937 .4608 Mtetra
.28937 .4608 .29838 .46936 .31234 .46474 .30337 .45613 Mtetra
.30337 .45613 .31234 .46474 .32636 .46009 .31744 .45143 Mtetra
.31744 .45143 .32636 .46009 .34047 .45541 .33159 .44671 Mtetra
.33159 .44671 .34047 .45541 .35465 .45071 .34582 .44196 Mtetra
.34582 .44196 .35465 .45071 .3689 .44598 .36012 .43719 Mtetra
.36012 .43719 .3689 .44598 .38323 .44123 .3745 .43239 Mtetra
.3745 .43239 .38323 .44123 .39764 .43645 .38896 .42757 Mtetra
.38896 .42757 .39764 .43645 .41213 .43165 .40349 .42272 Mtetra
.40349 .42272 .41213 .43165 .42669 .42682 .4181 .41784 Mtetra
.4181 .41784 .42669 .42682 .44133 .42197 .4328 .41294 Mtetra
.4328 .41294 .44133 .42197 .45606 .41709 .44757 .40801 Mtetra
.44757 .40801 .45606 .41709 .47086 .41218 .46242 .40305 Mtetra
.46242 .40305 .47086 .41218 .48574 .40724 .47736 .39806 Mtetra
.47736 .39806 .48574 .40724 .50071 .40228 .49238 .39305 Mtetra
.49238 .39305 .50071 .40228 .51576 .39729 .50748 .38801 Mtetra
.663 .741 .908 r
.50748 .38801 .51576 .39729 .53089 .39228 .52267 .38294 Mtetra
.653 .738 .912 r
.52267 .38294 .53089 .39228 .5461 .38723 .53794 .37827 Mtetra
.628 .739 .927 r
.53794 .37827 .5461 .38723 .5614 .38244 .5533 .37441 Mtetra
.703 .787 .916 r
.5533 .37441 .5614 .38244 .57679 .37783 .56873 .3677 Mtetra
.666 .728 .896 r
.56873 .3677 .57679 .37783 .59225 .37197 .58426 .36239 Mtetra
.664 .74 .907 r
.58426 .36239 .59225 .37197 .60781 .36677 .59987 .35718 Mtetra
.664 .741 .908 r
.59987 .35718 .60781 .36677 .62345 .36159 .61557 .35194 Mtetra
.61557 .35194 .62345 .36159 .63918 .35637 .63136 .34667 Mtetra
.63136 .34667 .63918 .35637 .655 .35113 .64724 .34137 Mtetra
.64724 .34137 .655 .35113 .67091 .34585 .66321 .33604 Mtetra
.66321 .33604 .67091 .34585 .68691 .34055 .67927 .33068 Mtetra
.67927 .33068 .68691 .34055 .703 .33521 .69543 .32529 Mtetra
.69543 .32529 .703 .33521 .71918 .32985 .71167 .31986 Mtetra
.71167 .31986 .71918 .32985 .73545 .32445 .72801 .31441 Mtetra
.72801 .31441 .73545 .32445 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Mtetra
.2663 .45685 .27545 .46545 .28937 .4608 .28027 .45216 Mtetra
.28027 .45216 .28937 .4608 .30337 .45613 .29432 .44744 Mtetra
.29432 .44744 .30337 .45613 .31744 .45143 .30844 .4427 Mtetra
.30844 .4427 .31744 .45143 .33159 .44671 .32263 .43793 Mtetra
.32263 .43793 .33159 .44671 .34582 .44196 .3369 .43313 Mtetra
.3369 .43313 .34582 .44196 .36012 .43719 .35125 .42831 Mtetra
.35125 .42831 .36012 .43719 .3745 .43239 .36568 .42346 Mtetra
.36568 .42346 .3745 .43239 .38896 .42757 .38018 .41859 Mtetra
.38018 .41859 .38896 .42757 .40349 .42272 .39477 .41369 Mtetra
.39477 .41369 .40349 .42272 .4181 .41784 .40943 .40877 Mtetra
.40943 .40877 .4181 .41784 .4328 .41294 .42417 .40381 Mtetra
.42417 .40381 .4328 .41294 .44757 .40801 .439 .39883 Mtetra
.439 .39883 .44757 .40801 .46242 .40305 .4539 .39382 Mtetra
.4539 .39382 .46242 .40305 .47736 .39806 .46889 .38879 Mtetra
.46889 .38879 .47736 .39806 .49238 .39305 .48397 .38372 Mtetra
.663 .741 .908 r
.48397 .38372 .49238 .39305 .50748 .38801 .49912 .37863 Mtetra
.648 .736 .913 r
.49912 .37863 .50748 .38801 .52267 .38294 .51436 .3741 Mtetra
.577 .724 .943 r
.51436 .3741 .52267 .38294 .53794 .37827 .52969 .37176 Mtetra
.739 .834 .923 r
.52969 .37176 .53794 .37827 .5533 .37441 .5451 .36356 Mtetra
.67 .715 .882 r
.5451 .36356 .5533 .37441 .56873 .3677 .56059 .35798 Mtetra
.664 .738 .906 r
.56059 .35798 .56873 .3677 .58426 .36239 .57618 .35274 Mtetra
.664 .741 .908 r
.57618 .35274 .58426 .36239 .59987 .35718 .59185 .34748 Mtetra
.59185 .34748 .59987 .35718 .61557 .35194 .60761 .34218 Mtetra
.60761 .34218 .61557 .35194 .63136 .34667 .62346 .33686 Mtetra
.62346 .33686 .63136 .34667 .64724 .34137 .6394 .3315 Mtetra
.6394 .3315 .64724 .34137 .66321 .33604 .65543 .32612 Mtetra
.65543 .32612 .66321 .33604 .67927 .33068 .67156 .3207 Mtetra
.67156 .3207 .67927 .33068 .69543 .32529 .68777 .31525 Mtetra
.68777 .31525 .69543 .32529 .71167 .31986 .70408 .30977 Mtetra
.70408 .30977 .71167 .31986 .72801 .31441 .72049 .30426 Mtetra
.72049 .30426 .72801 .31441 .74444 .30893 .73699 .29872 Mtetra
.73699 .29872 .74444 .30893 .76097 .30341 .75358 .29314 Mtetra
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28753 Mtetra
.77027 .28753 .7776 .29786 .79432 .29228 .78706 .28189 Mtetra
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Mtetra
.25707 .44817 .2663 .45685 .28027 .45216 .27108 .44343 Mtetra
.27108 .44343 .28027 .45216 .29432 .44744 .28517 .43866 Mtetra
.28517 .43866 .29432 .44744 .30844 .4427 .29934 .43387 Mtetra
.29934 .43387 .30844 .4427 .32263 .43793 .31358 .42905 Mtetra
.31358 .42905 .32263 .43793 .3369 .43313 .3279 .42421 Mtetra
.3279 .42421 .3369 .43313 .35125 .42831 .34229 .41934 Mtetra
.34229 .41934 .35125 .42831 .36568 .42346 .35677 .41445 Mtetra
.35677 .41445 .36568 .42346 .38018 .41859 .37132 .40953 Mtetra
.37132 .40953 .38018 .41859 .39477 .41369 .38595 .40458 Mtetra
.38595 .40458 .39477 .41369 .40943 .40877 .40067 .3996 Mtetra
.40067 .3996 .40943 .40877 .42417 .40381 .41546 .3946 Mtetra
.41546 .3946 .42417 .40381 .439 .39883 .43034 .38956 Mtetra
.43034 .38956 .439 .39883 .4539 .39382 .4453 .38451 Mtetra
.4453 .38451 .4539 .39382 .46889 .38879 .46034 .37942 Mtetra
.46034 .37942 .46889 .38879 .48397 .38372 .47546 .3743 Mtetra
.644 .735 .915 r
.47546 .3743 .48397 .38372 .49912 .37863 .49067 .36991 Mtetra
.461 .678 .959 r
.49067 .36991 .49912 .37863 .51436 .3741 .50593 .37027 Mtetra
.789 .908 .923 r
.50593 .37027 .51436 .3741 .52969 .37176 .52135 .35977 Mtetra
.68 .698 .861 r
.52135 .35977 .52969 .37176 .5451 .36356 .53682 .35355 Mtetra
.663 .733 .902 r
.53682 .35355 .5451 .36356 .56059 .35798 .55237 .34829 Mtetra
.664 .741 .908 r
.55237 .34829 .56059 .35798 .57618 .35274 .56801 .343 Mtetra
.56801 .343 .57618 .35274 .59185 .34748 .58375 .33768 Mtetra
.58375 .33768 .59185 .34748 .60761 .34218 .59957 .33233 Mtetra
.59957 .33233 .60761 .34218 .62346 .33686 .61548 .32695 Mtetra
.61548 .32695 .62346 .33686 .6394 .3315 .63148 .32154 Mtetra
.63148 .32154 .6394 .3315 .65543 .32612 .64757 .31609 Mtetra
.64757 .31609 .65543 .32612 .67156 .3207 .66376 .31062 Mtetra
.66376 .31062 .67156 .3207 .68777 .31525 .68004 .30511 Mtetra
.68004 .30511 .68777 .31525 .70408 .30977 .69642 .29957 Mtetra
.69642 .29957 .70408 .30977 .72049 .30426 .71289 .294 Mtetra
.71289 .294 .72049 .30426 .73699 .29872 .72945 .2884 Mtetra
.72945 .2884 .73699 .29872 .75358 .29314 .74611 .28276 Mtetra
.74611 .28276 .75358 .29314 .77027 .28753 .76287 .2771 Mtetra
.76287 .2771 .77027 .28753 .78706 .28189 .77973 .27139 Mtetra
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.23376 .44416 .24313 .45288 .25707 .44817 .24775 .4394 Mtetra
.24775 .4394 .25707 .44817 .27108 .44343 .2618 .43461 Mtetra
.2618 .43461 .27108 .44343 .28517 .43866 .27594 .4298 Mtetra
.27594 .4298 .28517 .43866 .29934 .43387 .29015 .42496 Mtetra
.29015 .42496 .29934 .43387 .31358 .42905 .30444 .42009 Mtetra
.30444 .42009 .31358 .42905 .3279 .42421 .3188 .4152 Mtetra
.3188 .4152 .3279 .42421 .34229 .41934 .33325 .41028 Mtetra
.33325 .41028 .34229 .41934 .35677 .41445 .34777 .40534 Mtetra
.34777 .40534 .35677 .41445 .37132 .40953 .36237 .40037 Mtetra
.36237 .40037 .37132 .40953 .38595 .40458 .37705 .39537 Mtetra
.37705 .39537 .38595 .40458 .40067 .3996 .39182 .39034 Mtetra
.39182 .39034 .40067 .3996 .41546 .3946 .40666 .38529 Mtetra
.40666 .38529 .41546 .3946 .43034 .38956 .42159 .3802 Mtetra
.42159 .3802 .43034 .38956 .4453 .38451 .4366 .37509 Mtetra
.4366 .37509 .4453 .38451 .46034 .37942 .4517 .36995 Mtetra
.64 .734 .916 r
.4517 .36995 .46034 .37942 .47546 .3743 .46686 .36567 Mtetra
.199 .54 .927 r
.46686 .36567 .47546 .3743 .49067 .36991 .482 .3703 Mtetra
.821 .988 .875 r
.482 .3703 .49067 .36991 .50593 .37027 .49747 .35678 Mtetra
.698 .682 .831 r
.49747 .35678 .50593 .37027 .52135 .35977 .51293 .34911 Mtetra
.663 .72 .891 r
.51293 .34911 .52135 .35977 .53682 .35355 .52845 .34382 Mtetra
.664 .741 .908 r
.52845 .34382 .53682 .35355 .55237 .34829 .54406 .3385 Mtetra
.54406 .3385 .55237 .34829 .56801 .343 .55977 .33315 Mtetra
.55977 .33315 .56801 .343 .58375 .33768 .57556 .32778 Mtetra
.57556 .32778 .58375 .33768 .59957 .33233 .59144 .32237 Mtetra
.59144 .32237 .59957 .33233 .61548 .32695 .60741 .31693 Mtetra
.60741 .31693 .61548 .32695 .63148 .32154 .62347 .31146 Mtetra
.62347 .31146 .63148 .32154 .64757 .31609 .63963 .30596 Mtetra
.63963 .30596 .64757 .31609 .66376 .31062 .65588 .30043 Mtetra
.65588 .30043 .66376 .31062 .68004 .30511 .67223 .29486 Mtetra
.67223 .29486 .68004 .30511 .69642 .29957 .68867 .28926 Mtetra
.68867 .28926 .69642 .29957 .71289 .294 .7052 .28363 Mtetra
.7052 .28363 .71289 .294 .72945 .2884 .72183 .27797 Mtetra
.72183 .27797 .72945 .2884 .74611 .28276 .73856 .27227 Mtetra
.73856 .27227 .74611 .28276 .76287 .2771 .75539 .26654 Mtetra
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.2243 .43535 .23376 .44416 .24775 .4394 .23833 .43054 Mtetra
.23833 .43054 .24775 .4394 .2618 .43461 .25243 .4257 Mtetra
.25243 .4257 .2618 .43461 .27594 .4298 .26661 .42084 Mtetra
.26661 .42084 .27594 .4298 .29015 .42496 .28087 .41596 Mtetra
.28087 .41596 .29015 .42496 .30444 .42009 .2952 .41104 Mtetra
.2952 .41104 .30444 .42009 .3188 .4152 .30961 .4061 Mtetra
.30961 .4061 .3188 .4152 .33325 .41028 .32411 .40113 Mtetra
.32411 .40113 .33325 .41028 .34777 .40534 .33868 .39614 Mtetra
.33868 .39614 .34777 .40534 .36237 .40037 .35333 .39112 Mtetra
.35333 .39112 .36237 .40037 .37705 .39537 .36806 .38606 Mtetra
.36806 .38606 .37705 .39537 .39182 .39034 .38288 .38099 Mtetra
.38288 .38099 .39182 .39034 .40666 .38529 .39777 .37588 Mtetra
.39777 .37588 .40666 .38529 .42159 .3802 .41275 .37074 Mtetra
.41275 .37074 .42159 .3802 .4366 .37509 .42782 .36558 Mtetra
.638 .733 .917 r
.42782 .36558 .4366 .37509 .4517 .36995 .44294 .36135 Mtetra
0 .217 .704 r
.44294 .36135 .4517 .36995 .46686 .36567 .45785 .37198 Mtetra
.716 .956 .679 r
.45785 .37198 .46686 .36567 .482 .3703 .47343 .35539 Mtetra
.732 .676 .796 r
.47343 .35539 .482 .3703 .49747 .35678 .48892 .34466 Mtetra
.66 .692 .869 r
.48892 .34466 .49747 .35678 .51293 .34911 .50442 .33932 Mtetra
.664 .741 .908 r
.50442 .33932 .51293 .34911 .52845 .34382 .52 .33398 Mtetra
.52 .33398 .52845 .34382 .54406 .3385 .53567 .32861 Mtetra
.53567 .32861 .54406 .3385 .55977 .33315 .55143 .3232 Mtetra
.55143 .3232 .55977 .33315 .57556 .32778 .56728 .31777 Mtetra
.56728 .31777 .57556 .32778 .59144 .32237 .58322 .3123 Mtetra
.58322 .3123 .59144 .32237 .60741 .31693 .59926 .30681 Mtetra
.59926 .30681 .60741 .31693 .62347 .31146 .61538 .30128 Mtetra
.61538 .30128 .62347 .31146 .63963 .30596 .6316 .29572 Mtetra
.6316 .29572 .63963 .30596 .65588 .30043 .64792 .29013 Mtetra
.64792 .29013 .65588 .30043 .67223 .29486 .66433 .2845 Mtetra
.66433 .2845 .67223 .29486 .68867 .28926 .68083 .27884 Mtetra
.68083 .27884 .68867 .28926 .7052 .28363 .69743 .27315 Mtetra
.69743 .27315 .7052 .28363 .72183 .27797 .71413 .26743 Mtetra
.71413 .26743 .72183 .27797 .73856 .27227 .73093 .26167 Mtetra
.73093 .26167 .73856 .27227 .75539 .26654 .74783 .25587 Mtetra
.74783 .25587 .75539 .26654 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24418 Mtetra
.78193 .24418 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.21474 .42645 .2243 .43535 .23833 .43054 .22882 .42159 Mtetra
.22882 .42159 .23833 .43054 .25243 .4257 .24296 .41671 Mtetra
.24296 .41671 .25243 .4257 .26661 .42084 .25719 .4118 Mtetra
.25719 .4118 .26661 .42084 .28087 .41596 .27149 .40686 Mtetra
.27149 .40686 .28087 .41596 .2952 .41104 .28587 .4019 Mtetra
.28587 .4019 .2952 .41104 .30961 .4061 .30033 .39691 Mtetra
.30033 .39691 .30961 .4061 .32411 .40113 .31487 .39189 Mtetra
.31487 .39189 .32411 .40113 .33868 .39614 .32949 .38684 Mtetra
.32949 .38684 .33868 .39614 .35333 .39112 .34419 .38177 Mtetra
.34419 .38177 .35333 .39112 .36806 .38606 .35898 .37667 Mtetra
.35898 .37667 .36806 .38606 .38288 .38099 .37384 .37154 Mtetra
.37384 .37154 .38288 .38099 .39777 .37588 .38879 .36638 Mtetra
.38879 .36638 .39777 .37588 .41275 .37074 .40382 .36119 Mtetra
.638 .733 .917 r
.40382 .36119 .41275 .37074 .42782 .36558 .41891 .35693 Mtetra
.655 .154 0 r
.41891 .35693 .42782 .36558 .44294 .36135 .43345 .37505 Mtetra
0 0 0 r
.43345 .37505 .44294 .36135 .45785 .37198 .44916 .35688 Mtetra
.787 .693 .761 r
.44916 .35688 .45785 .37198 .47343 .35539 .4648 .34024 Mtetra
.653 .643 .827 r
.4648 .34024 .47343 .35539 .48892 .34466 .48027 .3348 Mtetra
.664 .741 .907 r
.48027 .3348 .48892 .34466 .50442 .33932 .49582 .32943 Mtetra
.664 .741 .908 r
.49582 .32943 .50442 .33932 .52 .33398 .51146 .32404 Mtetra
.51146 .32404 .52 .33398 .53567 .32861 .52719 .31861 Mtetra
.52719 .31861 .53567 .32861 .55143 .3232 .54301 .31315 Mtetra
.54301 .31315 .55143 .3232 .56728 .31777 .55892 .30766 Mtetra
.55892 .30766 .56728 .31777 .58322 .3123 .57492 .30213 Mtetra
.57492 .30213 .58322 .3123 .59926 .30681 .59101 .29658 Mtetra
.59101 .29658 .59926 .30681 .61538 .30128 .6072 .29099 Mtetra
.6072 .29099 .61538 .30128 .6316 .29572 .62349 .28537 Mtetra
.62349 .28537 .6316 .29572 .64792 .29013 .63987 .27972 Mtetra
.63987 .27972 .64792 .29013 .66433 .2845 .65634 .27403 Mtetra
.65634 .27403 .66433 .2845 .68083 .27884 .67291 .26831 Mtetra
.67291 .26831 .68083 .27884 .69743 .27315 .68958 .26256 Mtetra
.68958 .26256 .69743 .27315 .71413 .26743 .70635 .25677 Mtetra
.70635 .25677 .71413 .26743 .73093 .26167 .72322 .25095 Mtetra
.72322 .25095 .73093 .26167 .74783 .25587 .74019 .24509 Mtetra
.74019 .24509 .74783 .25587 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24418 .77443 .23327 Mtetra
.77443 .23327 .78193 .24418 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.20509 .41746 .21474 .42645 .22882 .42159 .21921 .41256 Mtetra
.21921 .41256 .22882 .42159 .24296 .41671 .2334 .40762 Mtetra
.2334 .40762 .24296 .41671 .25719 .4118 .24767 .40267 Mtetra
.24767 .40267 .25719 .4118 .27149 .40686 .26202 .39768 Mtetra
.26202 .39768 .27149 .40686 .28587 .4019 .27645 .39266 Mtetra
.27645 .39266 .28587 .4019 .30033 .39691 .29096 .38762 Mtetra
.29096 .38762 .30033 .39691 .31487 .39189 .30555 .38255 Mtetra
.30555 .38255 .31487 .39189 .32949 .38684 .32021 .37745 Mtetra
.32021 .37745 .32949 .38684 .34419 .38177 .33497 .37233 Mtetra
.33497 .37233 .34419 .38177 .35898 .37667 .3498 .36717 Mtetra
.3498 .36717 .35898 .37667 .37384 .37154 .36472 .36199 Mtetra
.36472 .36199 .37384 .37154 .38879 .36638 .37972 .35677 Mtetra
.64 .734 .917 r
.37972 .35677 .38879 .36638 .40382 .36119 .39477 .35241 Mtetra
.828 .368 0 r
.39477 .35241 .40382 .36119 .41891 .35693 .4088 .37867 Mtetra
.063 0 .054 r
.4088 .37867 .41891 .35693 .43345 .37505 .42454 .36297 Mtetra
.867 .74 .721 r
.42454 .36297 .43345 .37505 .44916 .35688 .44056 .3359 Mtetra
.638 .575 .767 r
.44056 .3359 .44916 .35688 .4648 .34024 .456 .33026 Mtetra
.663 .739 .906 r
.456 .33026 .4648 .34024 .48027 .3348 .47152 .32487 Mtetra
.664 .741 .908 r
.47152 .32487 .48027 .3348 .49582 .32943 .48713 .31945 Mtetra
.48713 .31945 .49582 .32943 .51146 .32404 .50282 .31399 Mtetra
.50282 .31399 .51146 .32404 .52719 .31861 .51861 .3085 Mtetra
.51861 .3085 .52719 .31861 .54301 .31315 .53449 .30298 Mtetra
.53449 .30298 .54301 .31315 .55892 .30766 .55046 .29743 Mtetra
.55046 .29743 .55892 .30766 .57492 .30213 .56653 .29185 Mtetra
.56653 .29185 .57492 .30213 .59101 .29658 .58268 .28624 Mtetra
.58268 .28624 .59101 .29658 .6072 .29099 .59894 .28059 Mtetra
.59894 .28059 .6072 .29099 .62349 .28537 .61528 .27491 Mtetra
.61528 .27491 .62349 .28537 .63987 .27972 .63173 .26919 Mtetra
.63173 .26919 .63987 .27972 .65634 .27403 .64827 .26344 Mtetra
.64827 .26344 .65634 .27403 .67291 .26831 .66491 .25766 Mtetra
.66491 .25766 .67291 .26831 .68958 .26256 .68164 .25184 Mtetra
.68164 .25184 .68958 .26256 .70635 .25677 .69848 .24599 Mtetra
.69848 .24599 .70635 .25677 .72322 .25095 .71542 .24011 Mtetra
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23418 Mtetra
.73246 .23418 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Mtetra
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .2162 Mtetra
.78419 .2162 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.19534 .40839 .20509 .41746 .21921 .41256 .2095 .40343 Mtetra
.2095 .40343 .21921 .41256 .2334 .40762 .22374 .39845 Mtetra
.22374 .39845 .2334 .40762 .24767 .40267 .23806 .39344 Mtetra
.23806 .39344 .24767 .40267 .26202 .39768 .25245 .3884 Mtetra
.25245 .3884 .26202 .39768 .27645 .39266 .26693 .38333 Mtetra
.26693 .38333 .27645 .39266 .29096 .38762 .28149 .37824 Mtetra
.28149 .37824 .29096 .38762 .30555 .38255 .29612 .37312 Mtetra
.29612 .37312 .30555 .38255 .32021 .37745 .31084 .36797 Mtetra
.31084 .36797 .32021 .37745 .33497 .37233 .32564 .36279 Mtetra
.32564 .36279 .33497 .37233 .3498 .36717 .34053 .35758 Mtetra
.34053 .35758 .3498 .36717 .36472 .36199 .35549 .35234 Mtetra
.644 .735 .915 r
.35549 .35234 .36472 .36199 .37972 .35677 .37051 .34782 Mtetra
.89 .467 .094 r
.37051 .34782 .37972 .35677 .39477 .35241 .38394 .38151 Mtetra
.402 .065 .277 r
.38394 .38151 .39477 .35241 .4088 .37867 .39938 .37552 Mtetra
.954 .807 .659 r
.39938 .37552 .4088 .37867 .42454 .36297 .4162 .3318 Mtetra
.619 .505 .702 r
.4162 .3318 .42454 .36297 .44056 .3359 .43162 .3257 Mtetra
.663 .735 .903 r
.43162 .3257 .44056 .3359 .456 .33026 .4471 .32028 Mtetra
.664 .741 .908 r
.4471 .32028 .456 .33026 .47152 .32487 .46268 .31483 Mtetra
.46268 .31483 .47152 .32487 .48713 .31945 .47834 .30935 Mtetra
.47834 .30935 .48713 .31945 .50282 .31399 .4941 .30384 Mtetra
.4941 .30384 .50282 .31399 .51861 .3085 .50995 .29829 Mtetra
.50995 .29829 .51861 .3085 .53449 .30298 .52589 .29271 Mtetra
.52589 .29271 .53449 .30298 .55046 .29743 .54192 .2871 Mtetra
.54192 .2871 .55046 .29743 .56653 .29185 .55804 .28146 Mtetra
.55804 .28146 .56653 .29185 .58268 .28624 .57426 .27578 Mtetra
.57426 .27578 .58268 .28624 .59894 .28059 .59058 .27007 Mtetra
.59058 .27007 .59894 .28059 .61528 .27491 .60699 .26433 Mtetra
.60699 .26433 .61528 .27491 .63173 .26919 .6235 .25855 Mtetra
.6235 .25855 .63173 .26919 .64827 .26344 .64011 .25274 Mtetra
.64011 .25274 .64827 .26344 .66491 .25766 .65681 .24689 Mtetra
.65681 .24689 .66491 .25766 .68164 .25184 .67362 .24101 Mtetra
.67362 .24101 .68164 .25184 .69848 .24599 .69052 .2351 Mtetra
.69052 .2351 .69848 .24599 .71542 .24011 .70753 .22915 Mtetra
.70753 .22915 .71542 .24011 .73246 .23418 .72464 .22316 Mtetra
.72464 .22316 .73246 .23418 .7496 .22823 .74185 .21713 Mtetra
.74185 .21713 .7496 .22823 .76684 .22223 .75917 .21107 Mtetra
.75917 .21107 .76684 .22223 .78419 .2162 .77659 .20498 Mtetra
.77659 .20498 .78419 .2162 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.18549 .39922 .19534 .40839 .2095 .40343 .1997 .39421 Mtetra
.1997 .39421 .2095 .40343 .22374 .39845 .21398 .38918 Mtetra
.21398 .38918 .22374 .39845 .23806 .39344 .22835 .38411 Mtetra
.22835 .38411 .23806 .39344 .25245 .3884 .24279 .37903 Mtetra
.24279 .37903 .25245 .3884 .26693 .38333 .25731 .37391 Mtetra
.25731 .37391 .26693 .38333 .28149 .37824 .27192 .36876 Mtetra
.27192 .36876 .28149 .37824 .29612 .37312 .2866 .36359 Mtetra
.2866 .36359 .29612 .37312 .31084 .36797 .30137 .35838 Mtetra
.30137 .35838 .31084 .36797 .32564 .36279 .31622 .35315 Mtetra
.31622 .35315 .32564 .36279 .34053 .35758 .33116 .34789 Mtetra
.648 .737 .914 r
.33116 .34789 .34053 .35758 .35549 .35234 .34614 .34318 Mtetra
.914 .511 .165 r
.34614 .34318 .35549 .35234 .37051 .34782 .35896 .38209 Mtetra
.625 .295 .391 r
.35896 .38209 .37051 .34782 .38394 .38151 .37346 .39593 Mtetra
.998 .853 .548 r
.37346 .39593 .38394 .38151 .39938 .37552 .39168 .3282 Mtetra
.601 .449 .647 r
.39168 .3282 .39938 .37552 .4162 .3318 .40712 .32112 Mtetra
.663 .726 .896 r
.40712 .32112 .4162 .3318 .43162 .3257 .42257 .31567 Mtetra
.664 .741 .908 r
.42257 .31567 .43162 .3257 .4471 .32028 .43811 .31019 Mtetra
.43811 .31019 .4471 .32028 .46268 .31483 .45374 .30469 Mtetra
.45374 .30469 .46268 .31483 .47834 .30935 .46947 .29915 Mtetra
.46947 .29915 .47834 .30935 .4941 .30384 .48528 .29357 Mtetra
.48528 .29357 .4941 .30384 .50995 .29829 .50119 .28797 Mtetra
.50119 .28797 .50995 .29829 .52589 .29271 .51719 .28233 Mtetra
.51719 .28233 .52589 .29271 .54192 .2871 .53328 .27666 Mtetra
.53328 .27666 .54192 .2871 .55804 .28146 .54947 .27095 Mtetra
.54947 .27095 .55804 .28146 .57426 .27578 .56575 .26522 Mtetra
.56575 .26522 .57426 .27578 .59058 .27007 .58213 .25944 Mtetra
.58213 .25944 .59058 .27007 .60699 .26433 .59861 .25364 Mtetra
.59861 .25364 .60699 .26433 .6235 .25855 .61518 .2478 Mtetra
.61518 .2478 .6235 .25855 .64011 .25274 .63185 .24192 Mtetra
.63185 .24192 .64011 .25274 .65681 .24689 .64863 .23601 Mtetra
.64863 .23601 .65681 .24689 .67362 .24101 .6655 .23006 Mtetra
.6655 .23006 .67362 .24101 .69052 .2351 .68248 .22408 Mtetra
.68248 .22408 .69052 .2351 .70753 .22915 .69955 .21806 Mtetra
.69955 .21806 .70753 .22915 .72464 .22316 .71674 .21201 Mtetra
.71674 .21201 .72464 .22316 .74185 .21713 .73402 .20592 Mtetra
.73402 .20592 .74185 .21713 .75917 .21107 .75141 .19979 Mtetra
.75141 .19979 .75917 .21107 .77659 .20498 .76891 .19362 Mtetra
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.17555 .38995 .18549 .39922 .1997 .39421 .1898 .3849 Mtetra
.1898 .3849 .1997 .39421 .21398 .38918 .20413 .37981 Mtetra
.20413 .37981 .21398 .38918 .22835 .38411 .21853 .3747 Mtetra
.21853 .3747 .22835 .38411 .24279 .37903 .23302 .36955 Mtetra
.23302 .36955 .24279 .37903 .25731 .37391 .2476 .36438 Mtetra
.2476 .36438 .25731 .37391 .27192 .36876 .26225 .35918 Mtetra
.26225 .35918 .27192 .36876 .2866 .36359 .27698 .35396 Mtetra
.27698 .35396 .2866 .36359 .30137 .35838 .2918 .3487 Mtetra
.2918 .3487 .30137 .35838 .31622 .35315 .3067 .34341 Mtetra
.653 .738 .912 r
.3067 .34341 .31622 .35315 .33116 .34789 .32166 .33851 Mtetra
.921 .526 .19 r
.32166 .33851 .33116 .34789 .34614 .34318 .33399 .37924 Mtetra
.76 .44 .444 r
.33399 .37924 .34614 .34318 .35896 .38209 .3466 .42416 Mtetra
.945 .829 .386 r
.3466 .42416 .35896 .38209 .37346 .39593 .36698 .32557 Mtetra
.591 .413 .609 r
.36698 .32557 .37346 .39593 .39168 .3282 .3825 .31651 Mtetra
.661 .707 .881 r
.3825 .31651 .39168 .3282 .40712 .32112 .39792 .31104 Mtetra
.664 .741 .908 r
.39792 .31104 .40712 .32112 .42257 .31567 .41343 .30554 Mtetra
.41343 .30554 .42257 .31567 .43811 .31019 .42902 .3 Mtetra
.42902 .3 .43811 .31019 .45374 .30469 .44471 .29443 Mtetra
.44471 .29443 .45374 .30469 .46947 .29915 .4605 .28883 Mtetra
.4605 .28883 .46947 .29915 .48528 .29357 .47637 .2832 Mtetra
.47637 .2832 .48528 .29357 .50119 .28797 .49233 .27753 Mtetra
.49233 .27753 .50119 .28797 .51719 .28233 .50839 .27183 Mtetra
.50839 .27183 .51719 .28233 .53328 .27666 .52455 .2661 Mtetra
.52455 .2661 .53328 .27666 .54947 .27095 .5408 .26033 Mtetra
.5408 .26033 .54947 .27095 .56575 .26522 .55715 .25453 Mtetra
.55715 .25453 .56575 .26522 .58213 .25944 .57359 .2487 Mtetra
.57359 .2487 .58213 .25944 .59861 .25364 .59013 .24283 Mtetra
.59013 .24283 .59861 .25364 .61518 .2478 .60677 .23692 Mtetra
.60677 .23692 .61518 .2478 .63185 .24192 .62351 .23098 Mtetra
.62351 .23098 .63185 .24192 .64863 .23601 .64035 .225 Mtetra
.64035 .225 .64863 .23601 .6655 .23006 .6573 .21899 Mtetra
.6573 .21899 .6655 .23006 .68248 .22408 .67434 .21294 Mtetra
.67434 .21294 .68248 .22408 .69955 .21806 .69149 .20686 Mtetra
.69149 .20686 .69955 .21806 .71674 .21201 .70874 .20073 Mtetra
.70874 .20073 .71674 .21201 .73402 .20592 .7261 .19457 Mtetra
.7261 .19457 .73402 .20592 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Mtetra
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.1655 .38059 .17555 .38995 .1898 .3849 .17979 .37549 Mtetra
.17979 .37549 .1898 .3849 .20413 .37981 .19417 .37035 Mtetra
.19417 .37035 .20413 .37981 .21853 .3747 .20862 .36518 Mtetra
.20862 .36518 .21853 .3747 .23302 .36955 .22316 .35999 Mtetra
.22316 .35999 .23302 .36955 .2476 .36438 .23778 .35476 Mtetra
.23778 .35476 .2476 .36438 .26225 .35918 .25248 .34951 Mtetra
.25248 .34951 .26225 .35918 .27698 .35396 .26726 .34422 Mtetra
.26726 .34422 .27698 .35396 .2918 .3487 .28213 .33891 Mtetra
.656 .739 .911 r
.28213 .33891 .2918 .3487 .3067 .34341 .29706 .33384 Mtetra
.917 .519 .18 r
.29706 .33384 .3067 .34341 .32166 .33851 .30913 .37255 Mtetra
.837 .527 .465 r
.30913 .37255 .32166 .33851 .33399 .37924 .31877 .45775 Mtetra
.82 .747 .226 r
.31877 .45775 .33399 .37924 .3466 .42416 .34204 .32455 Mtetra
.587 .392 .584 r
.34204 .32455 .3466 .42416 .36698 .32557 .35775 .31189 Mtetra
.656 .672 .853 r
.35775 .31189 .36698 .32557 .3825 .31651 .37314 .30638 Mtetra
.664 .741 .908 r
.37314 .30638 .3825 .31651 .39792 .31104 .38862 .30085 Mtetra
.38862 .30085 .39792 .31104 .41343 .30554 .40418 .29529 Mtetra
.40418 .29529 .41343 .30554 .42902 .3 .41984 .2897 Mtetra
.41984 .2897 .42902 .3 .44471 .29443 .43559 .28407 Mtetra
.43559 .28407 .44471 .29443 .4605 .28883 .45143 .27841 Mtetra
.45143 .27841 .4605 .28883 .47637 .2832 .46736 .27271 Mtetra
.46736 .27271 .47637 .2832 .49233 .27753 .48338 .26698 Mtetra
.48338 .26698 .49233 .27753 .50839 .27183 .49951 .26122 Mtetra
.49951 .26122 .50839 .27183 .52455 .2661 .51572 .25543 Mtetra
.51572 .25543 .52455 .2661 .5408 .26033 .53204 .2496 Mtetra
.53204 .2496 .5408 .26033 .55715 .25453 .54845 .24373 Mtetra
.54845 .24373 .55715 .25453 .57359 .2487 .56495 .23783 Mtetra
.56495 .23783 .57359 .2487 .59013 .24283 .58156 .2319 Mtetra
.58156 .2319 .59013 .24283 .60677 .23692 .59827 .22593 Mtetra
.59827 .22593 .60677 .23692 .62351 .23098 .61508 .21992 Mtetra
.61508 .21992 .62351 .23098 .64035 .225 .63199 .21388 Mtetra
.63199 .21388 .64035 .225 .6573 .21899 .649 .2078 Mtetra
.649 .2078 .6573 .21899 .67434 .21294 .66611 .20168 Mtetra
.66611 .20168 .67434 .21294 .69149 .20686 .68334 .19552 Mtetra
.68334 .19552 .69149 .20686 .70874 .20073 .70066 .18933 Mtetra
.70066 .18933 .70874 .20073 .7261 .19457 .71809 .1831 Mtetra
.71809 .1831 .7261 .19457 .74357 .18838 .73563 .17683 Mtetra
.73563 .17683 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.15534 .37114 .1655 .38059 .17979 .37549 .16968 .36598 Mtetra
.16968 .36598 .17979 .37549 .19417 .37035 .1841 .36079 Mtetra
.1841 .36079 .19417 .37035 .20862 .36518 .19861 .35557 Mtetra
.19861 .35557 .20862 .36518 .22316 .35999 .21319 .35032 Mtetra
.21319 .35032 .22316 .35999 .23778 .35476 .22786 .34504 Mtetra
.22786 .34504 .23778 .35476 .25248 .34951 .24261 .33973 Mtetra
.24261 .33973 .25248 .34951 .26726 .34422 .25744 .33439 Mtetra
.659 .74 .91 r
.25744 .33439 .26726 .34422 .28213 .33891 .27235 .32919 Mtetra
.9 .485 .126 r
.27235 .32919 .28213 .33891 .29706 .33384 .28442 .36254 Mtetra
.881 .58 .474 r
.28442 .36254 .29706 .33384 .30913 .37255 .29018 .49143 Mtetra
0 0 0 r
.29018 .49143 .30913 .37255 .31877 .45775 .31676 .32593 Mtetra
.59 .384 .569 r
.31676 .32593 .31877 .45775 .34204 .32455 .33289 .30725 Mtetra
.645 .619 .809 r
.33289 .30725 .34204 .32455 .35775 .31189 .34825 .30171 Mtetra
.664 .741 .908 r
.34825 .30171 .35775 .31189 .37314 .30638 .36369 .29615 Mtetra
.36369 .29615 .37314 .30638 .38862 .30085 .37922 .29056 Mtetra
.37922 .29056 .38862 .30085 .40418 .29529 .39484 .28494 Mtetra
.39484 .28494 .40418 .29529 .41984 .2897 .41055 .27928 Mtetra
.41055 .27928 .41984 .2897 .43559 .28407 .42636 .27359 Mtetra
.42636 .27359 .43559 .28407 .45143 .27841 .44226 .26787 Mtetra
.44226 .26787 .45143 .27841 .46736 .27271 .45825 .26211 Mtetra
.45825 .26211 .46736 .27271 .48338 .26698 .47434 .25632 Mtetra
.47434 .25632 .48338 .26698 .49951 .26122 .49052 .2505 Mtetra
.49052 .2505 .49951 .26122 .51572 .25543 .5068 .24464 Mtetra
.5068 .24464 .51572 .25543 .53204 .2496 .52318 .23874 Mtetra
.52318 .23874 .53204 .2496 .54845 .24373 .53965 .23281 Mtetra
.53965 .23281 .54845 .24373 .56495 .23783 .55622 .22685 Mtetra
.55622 .22685 .56495 .23783 .58156 .2319 .5729 .22085 Mtetra
.5729 .22085 .58156 .2319 .59827 .22593 .58967 .21481 Mtetra
.58967 .21481 .59827 .22593 .61508 .21992 .60655 .20873 Mtetra
.60655 .20873 .61508 .21992 .63199 .21388 .62353 .20262 Mtetra
.62353 .20262 .63199 .21388 .649 .2078 .64061 .19647 Mtetra
.64061 .19647 .649 .2078 .66611 .20168 .6578 .19029 Mtetra
.6578 .19029 .66611 .20168 .68334 .19552 .67509 .18406 Mtetra
.67509 .18406 .68334 .19552 .70066 .18933 .69249 .1778 Mtetra
.69249 .1778 .70066 .18933 .71809 .1831 .70999 .1715 Mtetra
.70999 .1715 .71809 .1831 .73563 .17683 .72761 .16516 Mtetra
.72761 .16516 .73563 .17683 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.14508 .36159 .15534 .37114 .16968 .36598 .15947 .35637 Mtetra
.15947 .35637 .16968 .36598 .1841 .36079 .17394 .35113 Mtetra
.17394 .35113 .1841 .36079 .19861 .35557 .18849 .34585 Mtetra
.18849 .34585 .19861 .35557 .21319 .35032 .20312 .34055 Mtetra
.20312 .34055 .21319 .35032 .22786 .34504 .21783 .33521 Mtetra
.21783 .33521 .22786 .34504 .24261 .33973 .23263 .32985 Mtetra
.661 .741 .909 r
.23263 .32985 .24261 .33973 .25744 .33439 .24751 .32455 Mtetra
.852 .402 .003 r
.24751 .32455 .25744 .33439 .27235 .32919 .25986 .35045 Mtetra
.906 .612 .477 r
.25986 .35045 .27235 .32919 .28442 .36254 .26143 .51784 Mtetra
0 0 0 r
.26143 .51784 .28442 .36254 .29018 .49143 .29103 .3304 Mtetra
.6 .385 .561 r
.29103 .3304 .29018 .49143 .31676 .32593 .30791 .30261 Mtetra
.627 .555 .753 r
.30791 .30261 .31676 .32593 .33289 .30725 .32323 .29701 Mtetra
.664 .741 .908 r
.32323 .29701 .33289 .30725 .34825 .30171 .33863 .29142 Mtetra
.33863 .29142 .34825 .30171 .36369 .29615 .35413 .2858 Mtetra
.35413 .2858 .36369 .29615 .37922 .29056 .36972 .28015 Mtetra
.36972 .28015 .37922 .29056 .39484 .28494 .3854 .27447 Mtetra
.3854 .27447 .39484 .28494 .41055 .27928 .40117 .26875 Mtetra
.40117 .26875 .41055 .27928 .42636 .27359 .41703 .263 Mtetra
.41703 .263 .42636 .27359 .44226 .26787 .43299 .25721 Mtetra
.43299 .25721 .44226 .26787 .45825 .26211 .44904 .25139 Mtetra
.44904 .25139 .45825 .26211 .47434 .25632 .46519 .24554 Mtetra
.46519 .24554 .47434 .25632 .49052 .2505 .48143 .23965 Mtetra
.48143 .23965 .49052 .2505 .5068 .24464 .49778 .23373 Mtetra
.49778 .23373 .5068 .24464 .52318 .23874 .51422 .22777 Mtetra
.51422 .22777 .52318 .23874 .53965 .23281 .53076 .22177 Mtetra
.53076 .22177 .53965 .23281 .55622 .22685 .5474 .21574 Mtetra
.5474 .21574 .55622 .22685 .5729 .22085 .56414 .20967 Mtetra
.56414 .20967 .5729 .22085 .58967 .21481 .58098 .20357 Mtetra
.58098 .20357 .58967 .21481 .60655 .20873 .59792 .19742 Mtetra
.59792 .19742 .60655 .20873 .62353 .20262 .61497 .19124 Mtetra
.61497 .19124 .62353 .20262 .64061 .19647 .63212 .18502 Mtetra
.63212 .18502 .64061 .19647 .6578 .19029 .64938 .17877 Mtetra
.64938 .17877 .6578 .19029 .67509 .18406 .66675 .17247 Mtetra
.66675 .17247 .67509 .18406 .69249 .1778 .68422 .16614 Mtetra
.68422 .16614 .69249 .1778 .70999 .1715 .7018 .15976 Mtetra
.7018 .15976 .70999 .1715 .72761 .16516 .71949 .15335 Mtetra
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Mtetra
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.13472 .35194 .14508 .36159 .15947 .35637 .14915 .34667 Mtetra
.14915 .34667 .15947 .35637 .17394 .35113 .16366 .34137 Mtetra
.16366 .34137 .17394 .35113 .18849 .34585 .17826 .33604 Mtetra
.17826 .33604 .18849 .34585 .20312 .34055 .19294 .33068 Mtetra
.19294 .33068 .20312 .34055 .21783 .33521 .2077 .32529 Mtetra
.662 .741 .908 r
.2077 .32529 .21783 .33521 .23263 .32985 .22255 .31991 Mtetra
.708 .214 0 r
.22255 .31991 .23263 .32985 .24751 .32455 .23535 .33776 Mtetra
.921 .631 .477 r
.23535 .33776 .24751 .32455 .25986 .35045 .2333 .52972 Mtetra
0 0 .056 r
.2333 .52972 .25986 .35045 .26143 .51784 .26475 .33821 Mtetra
.617 .395 .558 r
.26475 .33821 .26143 .51784 .29103 .3304 .2828 .29797 Mtetra
.607 .493 .698 r
.2828 .29797 .29103 .3304 .30791 .30261 .29809 .29228 Mtetra
.663 .74 .907 r
.29809 .29228 .30791 .30261 .32323 .29701 .31346 .28667 Mtetra
.664 .741 .908 r
.31346 .28667 .32323 .29701 .33863 .29142 .32892 .28102 Mtetra
.32892 .28102 .33863 .29142 .35413 .2858 .34447 .27534 Mtetra
.34447 .27534 .35413 .2858 .36972 .28015 .36011 .26963 Mtetra
.36011 .26963 .36972 .28015 .3854 .27447 .37585 .26389 Mtetra
.37585 .26389 .3854 .27447 .40117 .26875 .39168 .25811 Mtetra
.39168 .25811 .40117 .26875 .41703 .263 .4076 .25229 Mtetra
.4076 .25229 .41703 .263 .43299 .25721 .42362 .24644 Mtetra
.42362 .24644 .43299 .25721 .44904 .25139 .43973 .24056 Mtetra
.43973 .24056 .44904 .25139 .46519 .24554 .45594 .23464 Mtetra
.45594 .23464 .46519 .24554 .48143 .23965 .47225 .22869 Mtetra
.47225 .22869 .48143 .23965 .49778 .23373 .48865 .2227 Mtetra
.48865 .2227 .49778 .23373 .51422 .22777 .50516 .21667 Mtetra
.50516 .21667 .51422 .22777 .53076 .22177 .52176 .21061 Mtetra
.52176 .21061 .53076 .22177 .5474 .21574 .53847 .20451 Mtetra
.53847 .20451 .5474 .21574 .56414 .20967 .55527 .19837 Mtetra
.55527 .19837 .56414 .20967 .58098 .20357 .57218 .1922 Mtetra
.57218 .1922 .58098 .20357 .59792 .19742 .5892 .18598 Mtetra
.5892 .18598 .59792 .19742 .61497 .19124 .60632 .17973 Mtetra
.60632 .17973 .61497 .19124 .63212 .18502 .62354 .17344 Mtetra
.62354 .17344 .63212 .18502 .64938 .17877 .64087 .16711 Mtetra
.64087 .16711 .64938 .17877 .66675 .17247 .65831 .16075 Mtetra
.65831 .16075 .66675 .17247 .68422 .16614 .67586 .15434 Mtetra
.67586 .15434 .68422 .16614 .7018 .15976 .69351 .14789 Mtetra
.69351 .14789 .7018 .15976 .71949 .15335 .71128 .14141 Mtetra
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Mtetra
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Mtetra
.12424 .34218 .13472 .35194 .14915 .34667 .13872 .33686 Mtetra
.13872 .33686 .14915 .34667 .16366 .34137 .15328 .3315 Mtetra
.15328 .3315 .16366 .34137 .17826 .33604 .16793 .32612 Mtetra
.16793 .32612 .17826 .33604 .19294 .33068 .18265 .3207 Mtetra
.663 .741 .908 r
.18265 .3207 .19294 .33068 .2077 .32529 .19746 .31527 Mtetra
0 .15 .646 r
.19746 .31527 .2077 .32529 .22255 .31991 .21077 .32575 Mtetra
.93 .643 .475 r
.21077 .32575 .22255 .31991 .23535 .33776 .20656 .52274 Mtetra
0 0 .12 r
.20656 .52274 .23535 .33776 .2333 .52972 .2379 .34869 Mtetra
.642 .416 .559 r
.2379 .34869 .2333 .52972 .26475 .33821 .25756 .29336 Mtetra
.588 .443 .652 r
.25756 .29336 .26475 .33821 .2828 .29797 .27282 .28753 Mtetra
.663 .739 .906 r
.27282 .28753 .2828 .29797 .29809 .29228 .28816 .28189 Mtetra
.664 .741 .908 r
.28816 .28189 .29809 .29228 .31346 .28667 .30358 .27622 Mtetra
.30358 .27622 .31346 .28667 .32892 .28102 .3191 .27051 Mtetra
.3191 .27051 .32892 .28102 .34447 .27534 .33471 .26477 Mtetra
.33471 .26477 .34447 .27534 .36011 .26963 .35041 .259 Mtetra
.35041 .259 .36011 .26963 .37585 .26389 .3662 .25319 Mtetra
.3662 .25319 .37585 .26389 .39168 .25811 .38209 .24735 Mtetra
.38209 .24735 .39168 .25811 .4076 .25229 .39807 .24147 Mtetra
.39807 .24147 .4076 .25229 .42362 .24644 .41415 .23555 Mtetra
.41415 .23555 .42362 .24644 .43973 .24056 .43032 .22961 Mtetra
.43032 .22961 .43973 .24056 .45594 .23464 .44659 .22362 Mtetra
.44659 .22362 .45594 .23464 .47225 .22869 .46296 .2176 Mtetra
.46296 .2176 .47225 .22869 .48865 .2227 .47943 .21154 Mtetra
.47943 .21154 .48865 .2227 .50516 .21667 .496 .20545 Mtetra
.496 .20545 .50516 .21667 .52176 .21061 .51267 .19932 Mtetra
.51267 .19932 .52176 .21061 .53847 .20451 .52944 .19315 Mtetra
.52944 .19315 .53847 .20451 .55527 .19837 .54631 .18694 Mtetra
.54631 .18694 .55527 .19837 .57218 .1922 .56329 .1807 Mtetra
.56329 .1807 .57218 .1922 .5892 .18598 .58037 .17441 Mtetra
.58037 .17441 .5892 .18598 .60632 .17973 .59756 .16809 Mtetra
.59756 .16809 .60632 .17973 .62354 .17344 .61486 .16173 Mtetra
.61486 .16173 .62354 .17344 .64087 .16711 .63226 .15533 Mtetra
.63226 .15533 .64087 .16711 .65831 .16075 .64977 .14889 Mtetra
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Mtetra
.6674 .14241 .67586 .15434 .69351 .14789 .68513 .13588 Mtetra
.68513 .13588 .69351 .14789 .71128 .14141 .70297 .12932 Mtetra
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.11366 .33233 .12424 .34218 .13872 .33686 .12818 .32695 Mtetra
.12818 .32695 .13872 .33686 .15328 .3315 .14279 .32154 Mtetra
.14279 .32154 .15328 .3315 .16793 .32612 .15748 .31609 Mtetra
.663 .741 .908 r
.15748 .31609 .16793 .32612 .18265 .3207 .17226 .31063 Mtetra
.152 .504 .91 r
.17226 .31063 .18265 .3207 .19746 .31527 .18603 .31518 Mtetra
.936 .648 .471 r
.18603 .31518 .19746 .31527 .21077 .32575 .1816 .49754 Mtetra
0 0 .188 r
.1816 .49754 .21077 .32575 .20656 .52274 .21057 .3601 Mtetra
.678 .447 .564 r
.21057 .3601 .20656 .52274 .2379 .34869 .23218 .28882 Mtetra
.573 .407 .618 r
.23218 .28882 .2379 .34869 .25756 .29336 .24743 .28276 Mtetra
.663 .737 .904 r
.24743 .28276 .25756 .29336 .27282 .28753 .26273 .2771 Mtetra
.664 .741 .908 r
.26273 .2771 .27282 .28753 .28816 .28189 .27812 .27139 Mtetra
.27812 .27139 .28816 .28189 .30358 .27622 .2936 .26566 Mtetra
.2936 .26566 .30358 .27622 .3191 .27051 .30917 .25989 Mtetra
.30917 .25989 .3191 .27051 .33471 .26477 .32484 .25409 Mtetra
.32484 .25409 .33471 .26477 .35041 .259 .34059 .24825 Mtetra
.34059 .24825 .35041 .259 .3662 .25319 .35644 .24237 Mtetra
.35644 .24237 .3662 .25319 .38209 .24735 .37239 .23647 Mtetra
.37239 .23647 .38209 .24735 .39807 .24147 .38843 .23052 Mtetra
.38843 .23052 .39807 .24147 .41415 .23555 .40457 .22454 Mtetra
.40457 .22454 .41415 .23555 .43032 .22961 .4208 .21853 Mtetra
.4208 .21853 .43032 .22961 .44659 .22362 .43714 .21248 Mtetra
.43714 .21248 .44659 .22362 .46296 .2176 .45357 .20639 Mtetra
.45357 .20639 .46296 .2176 .47943 .21154 .4701 .20026 Mtetra
.4701 .20026 .47943 .21154 .496 .20545 .48673 .1941 Mtetra
.48673 .1941 .496 .20545 .51267 .19932 .50347 .1879 Mtetra
.50347 .1879 .51267 .19932 .52944 .19315 .52031 .18166 Mtetra
.52031 .18166 .52944 .19315 .54631 .18694 .53725 .17538 Mtetra
.53725 .17538 .54631 .18694 .56329 .1807 .5543 .16907 Mtetra
.5543 .16907 .56329 .1807 .58037 .17441 .57145 .16271 Mtetra
.57145 .16271 .58037 .17441 .59756 .16809 .58871 .15632 Mtetra
.58871 .15632 .59756 .16809 .61486 .16173 .60608 .14988 Mtetra
.60608 .14988 .61486 .16173 .63226 .15533 .62355 .14341 Mtetra
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Mtetra
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Mtetra
.65884 .13033 .6674 .14241 .68513 .13588 .67665 .12373 Mtetra
.67665 .12373 .68513 .13588 .70297 .12932 .69457 .11709 Mtetra
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.10296 .32237 .11366 .33233 .12818 .32695 .11753 .31693 Mtetra
.11753 .31693 .12818 .32695 .14279 .32154 .13219 .31146 Mtetra
.663 .741 .908 r
.13219 .31146 .14279 .32154 .15748 .31609 .14693 .30596 Mtetra
.438 .659 .954 r
.14693 .30596 .15748 .31609 .17226 .31063 .16107 .30627 Mtetra
.939 .648 .462 r
.16107 .30627 .17226 .31063 .18603 .31518 .15829 .45935 Mtetra
.018 0 .264 r
.15829 .45935 .18603 .31518 .1816 .49754 .18304 .3697 Mtetra
.727 .493 .573 r
.18304 .3697 .1816 .49754 .21057 .3601 .20667 .28437 Mtetra
.563 .383 .595 r
.20667 .28437 .21057 .3601 .23218 .28882 .22192 .27797 Mtetra
.663 .733 .901 r
.22192 .27797 .23218 .28882 .24743 .28276 .23718 .27227 Mtetra
.664 .741 .908 r
.23718 .27227 .24743 .28276 .26273 .2771 .25253 .26654 Mtetra
.25253 .26654 .26273 .2771 .27812 .27139 .26797 .26078 Mtetra
.26797 .26078 .27812 .27139 .2936 .26566 .28351 .25498 Mtetra
.28351 .25498 .2936 .26566 .30917 .25989 .29914 .24915 Mtetra
.29914 .24915 .30917 .25989 .32484 .25409 .31485 .24328 Mtetra
.31485 .24328 .32484 .25409 .34059 .24825 .33067 .23738 Mtetra
.33067 .23738 .34059 .24825 .35644 .24237 .34658 .23144 Mtetra
.34658 .23144 .35644 .24237 .37239 .23647 .36258 .22547 Mtetra
.36258 .22547 .37239 .23647 .38843 .23052 .37868 .21946 Mtetra
.37868 .21946 .38843 .23052 .40457 .22454 .39488 .21341 Mtetra
.39488 .21341 .40457 .22454 .4208 .21853 .41118 .20733 Mtetra
.41118 .20733 .4208 .21853 .43714 .21248 .42757 .20121 Mtetra
.42757 .20121 .43714 .21248 .45357 .20639 .44407 .19505 Mtetra
.44407 .19505 .45357 .20639 .4701 .20026 .46067 .18886 Mtetra
.46067 .18886 .4701 .20026 .48673 .1941 .47737 .18262 Mtetra
.47737 .18262 .48673 .1941 .50347 .1879 .49417 .17635 Mtetra
.49417 .17635 .50347 .1879 .52031 .18166 .51107 .17004 Mtetra
.51107 .17004 .52031 .18166 .53725 .17538 .52808 .16369 Mtetra
.52808 .16369 .53725 .17538 .5543 .16907 .5452 .1573 Mtetra
.5452 .1573 .5543 .16907 .57145 .16271 .56242 .15087 Mtetra
.56242 .15087 .57145 .16271 .58871 .15632 .57976 .1444 Mtetra
.57976 .1444 .58871 .15632 .60608 .14988 .5972 .1379 Mtetra
.5972 .1379 .60608 .14988 .62355 .14341 .61475 .13134 Mtetra
.61475 .13134 .62355 .14341 .64114 .13689 .63241 .12475 Mtetra
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Mtetra
.65018 .11812 .65884 .13033 .67665 .12373 .66806 .11144 Mtetra
.66806 .11144 .67665 .12373 .69457 .11709 .68606 .10472 Mtetra
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Mtetra
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.09215 .3123 .10296 .32237 .11753 .31693 .10677 .30681 Mtetra
.10677 .30681 .11753 .31693 .13219 .31146 .12147 .30128 Mtetra
.564 .711 .94 r
.12147 .30128 .13219 .31146 .14693 .30596 .13587 .29885 Mtetra
.941 .643 .445 r
.13587 .29885 .14693 .30596 .16107 .30627 .13605 .41573 Mtetra
.252 .011 .34 r
.13605 .41573 .16107 .30627 .15829 .45935 .1557 .3745 Mtetra
.787 .554 .584 r
.1557 .3745 .15829 .45935 .18304 .3697 .18101 .28003 Mtetra
.557 .368 .581 r
.18101 .28003 .18304 .3697 .20667 .28437 .19627 .27315 Mtetra
.662 .726 .897 r
.19627 .27315 .20667 .28437 .22192 .27797 .2115 .26743 Mtetra
.664 .741 .908 r
.2115 .26743 .22192 .27797 .23718 .27227 .22681 .26167 Mtetra
.22681 .26167 .23718 .27227 .25253 .26654 .24222 .25587 Mtetra
.24222 .25587 .25253 .26654 .26797 .26078 .25772 .25005 Mtetra
.25772 .25005 .26797 .26078 .28351 .25498 .27331 .24418 Mtetra
.27331 .24418 .28351 .25498 .29914 .24915 .28899 .23829 Mtetra
.28899 .23829 .29914 .24915 .31485 .24328 .30476 .23236 Mtetra
.30476 .23236 .31485 .24328 .33067 .23738 .32064 .22639 Mtetra
.32064 .22639 .33067 .23738 .34658 .23144 .3366 .22038 Mtetra
.3366 .22038 .34658 .23144 .36258 .22547 .35267 .21434 Mtetra
.35267 .21434 .36258 .22547 .37868 .21946 .36883 .20827 Mtetra
.36883 .20827 .37868 .21946 .39488 .21341 .38509 .20215 Mtetra
.38509 .20215 .39488 .21341 .41118 .20733 .40145 .196 Mtetra
.40145 .196 .41118 .20733 .42757 .20121 .4179 .18981 Mtetra
.4179 .18981 .42757 .20121 .44407 .19505 .43446 .18358 Mtetra
.43446 .18358 .44407 .19505 .46067 .18886 .45113 .17732 Mtetra
.45113 .17732 .46067 .18886 .47737 .18262 .46789 .17101 Mtetra
.46789 .17101 .47737 .18262 .49417 .17635 .48476 .16467 Mtetra
.48476 .16467 .49417 .17635 .51107 .17004 .50173 .15829 Mtetra
.50173 .15829 .51107 .17004 .52808 .16369 .51881 .15187 Mtetra
.51881 .15187 .52808 .16369 .5452 .1573 .536 .1454 Mtetra
.536 .1454 .5452 .1573 .56242 .15087 .55329 .1389 Mtetra
.55329 .1389 .56242 .15087 .57976 .1444 .5707 .13236 Mtetra
.5707 .13236 .57976 .1444 .5972 .1379 .58821 .12577 Mtetra
.58821 .12577 .5972 .1379 .61475 .13134 .60583 .11914 Mtetra
.60583 .11914 .61475 .13134 .63241 .12475 .62357 .11247 Mtetra
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Mtetra
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Mtetra
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Mtetra
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Mtetra
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.08123 .30213 .09215 .3123 .10677 .30681 .09589 .29658 Mtetra
.62 .729 .925 r
.09589 .29658 .10677 .30681 .12147 .30128 .11044 .29253 Mtetra
.942 .627 .41 r
.11044 .29253 .12147 .30128 .13587 .29885 .11412 .3737 Mtetra
.482 .192 .396 r
.11412 .3737 .13587 .29885 .13605 .41573 .12893 .37222 Mtetra
.856 .631 .595 r
.12893 .37222 .13605 .41573 .1557 .3745 .1552 .27579 Mtetra
.554 .36 .573 r
.1552 .27579 .1557 .3745 .18101 .28003 .1705 .26831 Mtetra
.661 .717 .89 r
.1705 .26831 .18101 .28003 .19627 .27315 .18569 .26256 Mtetra
.664 .741 .908 r
.18569 .26256 .19627 .27315 .2115 .26743 .20097 .25677 Mtetra
.20097 .25677 .2115 .26743 .22681 .26167 .21634 .25095 Mtetra
.21634 .25095 .22681 .26167 .24222 .25587 .23179 .24509 Mtetra
.23179 .24509 .24222 .25587 .25772 .25005 .24735 .2392 Mtetra
.24735 .2392 .25772 .25005 .27331 .24418 .26299 .23327 Mtetra
.26299 .23327 .27331 .24418 .28899 .23829 .27873 .22731 Mtetra
.27873 .22731 .28899 .23829 .30476 .23236 .29456 .22131 Mtetra
.29456 .22131 .30476 .23236 .32064 .22639 .31049 .21527 Mtetra
.31049 .21527 .32064 .22639 .3366 .22038 .32652 .2092 Mtetra
.32652 .2092 .3366 .22038 .35267 .21434 .34264 .20309 Mtetra
.34264 .20309 .35267 .21434 .36883 .20827 .35886 .19695 Mtetra
.35886 .19695 .36883 .20827 .38509 .20215 .37518 .19077 Mtetra
.37518 .19077 .38509 .20215 .40145 .196 .3916 .18454 Mtetra
.3916 .18454 .40145 .196 .4179 .18981 .40812 .17828 Mtetra
.40812 .17828 .4179 .18981 .43446 .18358 .42475 .17199 Mtetra
.42475 .17199 .43446 .18358 .45113 .17732 .44148 .16565 Mtetra
.44148 .16565 .45113 .17732 .46789 .17101 .45831 .15927 Mtetra
.45831 .15927 .46789 .17101 .48476 .16467 .47524 .15286 Mtetra
.47524 .15286 .48476 .16467 .50173 .15829 .49228 .1464 Mtetra
.49228 .1464 .50173 .15829 .51881 .15187 .50943 .1399 Mtetra
.50943 .1399 .51881 .15187 .536 .1454 .52669 .13336 Mtetra
.52669 .13336 .536 .1454 .55329 .1389 .54406 .12679 Mtetra
.54406 .12679 .55329 .1389 .5707 .13236 .56153 .12016 Mtetra
.56153 .12016 .5707 .13236 .58821 .12577 .57912 .1135 Mtetra
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Mtetra
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Mtetra
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Mtetra
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Mtetra
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Mtetra
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Mtetra
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Mtetra
.645 .736 .916 r
.07019 .29185 .08123 .30213 .09589 .29658 .0848 .28693 Mtetra
.937 .588 .335 r
.0848 .28693 .09589 .29658 .11044 .29253 .09184 .33789 Mtetra
.658 .337 .418 r
.09184 .33789 .11044 .29253 .11412 .3737 .10301 .36223 Mtetra
.923 .715 .604 r
.10301 .36223 .11412 .3737 .12893 .37222 .12924 .2716 Mtetra
.555 .359 .57 r
.12924 .2716 .12893 .37222 .1552 .27579 .14461 .26344 Mtetra
.66 .706 .882 r
.14461 .26344 .1552 .27579 .1705 .26831 .15975 .25766 Mtetra
.664 .741 .908 r
.15975 .25766 .1705 .26831 .18569 .26256 .17499 .25184 Mtetra
.17499 .25184 .18569 .26256 .20097 .25677 .19032 .24599 Mtetra
.19032 .24599 .20097 .25677 .21634 .25095 .20574 .24011 Mtetra
.20574 .24011 .21634 .25095 .23179 .24509 .22125 .23418 Mtetra
.22125 .23418 .23179 .24509 .24735 .2392 .23686 .22823 Mtetra
.23686 .22823 .24735 .2392 .26299 .23327 .25256 .22223 Mtetra
.25256 .22223 .26299 .23327 .27873 .22731 .26835 .2162 Mtetra
.26835 .2162 .27873 .22731 .29456 .22131 .28424 .21014 Mtetra
.28424 .21014 .29456 .22131 .31049 .21527 .30023 .20404 Mtetra
.30023 .20404 .31049 .21527 .32652 .2092 .31632 .1979 Mtetra
.31632 .1979 .32652 .2092 .34264 .20309 .3325 .19172 Mtetra
.3325 .19172 .34264 .20309 .35886 .19695 .34878 .1855 Mtetra
.34878 .1855 .35886 .19695 .37518 .19077 .36516 .17925 Mtetra
.36516 .17925 .37518 .19077 .3916 .18454 .38165 .17296 Mtetra
.38165 .17296 .3916 .18454 .40812 .17828 .39823 .16663 Mtetra
.39823 .16663 .40812 .17828 .42475 .17199 .41492 .16026 Mtetra
.41492 .16026 .42475 .17199 .44148 .16565 .43171 .15385 Mtetra
.43171 .15385 .44148 .16565 .45831 .15927 .44861 .1474 Mtetra
.44861 .1474 .45831 .15927 .47524 .15286 .46562 .1409 Mtetra
.46562 .1409 .47524 .15286 .49228 .1464 .48273 .13437 Mtetra
.48273 .13437 .49228 .1464 .50943 .1399 .49994 .1278 Mtetra
.49994 .1278 .50943 .1399 .52669 .13336 .51727 .12119 Mtetra
.51727 .12119 .52669 .13336 .54406 .12679 .53471 .11453 Mtetra
.53471 .11453 .54406 .12679 .56153 .12016 .55226 .10783 Mtetra
.55226 .10783 .56153 .12016 .57912 .1135 .56992 .10109 Mtetra
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Mtetra
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Mtetra
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Mtetra
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Mtetra
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Mtetra
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Mtetra
.897 .477 .144 r
.05898 .28175 .07019 .29185 .0848 .28693 .06879 .31009 Mtetra
.771 .43 .408 r
.06879 .31009 .0848 .28693 .09184 .33789 .07794 .34582 Mtetra
.97 .794 .609 r
.07794 .34582 .09184 .33789 .10301 .36223 .10314 .26735 Mtetra
.559 .364 .573 r
.10314 .26735 .10301 .36223 .12924 .2716 .11858 .25855 Mtetra
.658 .695 .873 r
.11858 .25855 .12924 .2716 .14461 .26344 .13369 .25274 Mtetra
.664 .741 .908 r
.13369 .25274 .14461 .26344 .15975 .25766 .14889 .24689 Mtetra
.14889 .24689 .15975 .25766 .17499 .25184 .16417 .24101 Mtetra
.16417 .24101 .17499 .25184 .19032 .24599 .17956 .2351 Mtetra
.17956 .2351 .19032 .24599 .20574 .24011 .19503 .22915 Mtetra
.19503 .22915 .20574 .24011 .22125 .23418 .2106 .22316 Mtetra
.2106 .22316 .22125 .23418 .23686 .22823 .22626 .21713 Mtetra
.22626 .21713 .23686 .22823 .25256 .22223 .24201 .21107 Mtetra
.24201 .21107 .25256 .22223 .26835 .2162 .25786 .20498 Mtetra
.25786 .20498 .26835 .2162 .28424 .21014 .27381 .19884 Mtetra
.27381 .19884 .28424 .21014 .30023 .20404 .28986 .19267 Mtetra
.28986 .19267 .30023 .20404 .31632 .1979 .306 .18646 Mtetra
.306 .18646 .31632 .1979 .3325 .19172 .32224 .18021 Mtetra
.32224 .18021 .3325 .19172 .34878 .1855 .33859 .17393 Mtetra
.33859 .17393 .34878 .1855 .36516 .17925 .35503 .1676 Mtetra
.35503 .1676 .36516 .17925 .38165 .17296 .37158 .16124 Mtetra
.37158 .16124 .38165 .17296 .39823 .16663 .38823 .15483 Mtetra
.38823 .15483 .39823 .16663 .41492 .16026 .40498 .14839 Mtetra
.40498 .14839 .41492 .16026 .43171 .15385 .42184 .14191 Mtetra
.42184 .14191 .43171 .15385 .44861 .1474 .4388 .13538 Mtetra
.4388 .13538 .44861 .1474 .46562 .1409 .45588 .12881 Mtetra
.45588 .12881 .46562 .1409 .48273 .13437 .47306 .12221 Mtetra
.47306 .12221 .48273 .13437 .49994 .1278 .49034 .11556 Mtetra
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Mtetra
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Mtetra
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Mtetra
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Mtetra
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Mtetra
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Mtetra
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Mtetra
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Mtetra
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Mtetra
.836 .472 .366 r
.04482 .28991 .05898 .28175 .06879 .31009 .0535 .32563 Mtetra
.988 .857 .62 r
.0535 .32563 .06879 .31009 .07794 .34582 .07693 .26294 Mtetra
.567 .377 .583 r
.07693 .26294 .07794 .34582 .10314 .26735 .09242 .25364 Mtetra
.656 .684 .865 r
.09242 .25364 .10314 .26735 .11858 .25855 .10749 .2478 Mtetra
.664 .741 .908 r
.10749 .2478 .11858 .25855 .13369 .25274 .12265 .24192 Mtetra
.12265 .24192 .13369 .25274 .14889 .24689 .1379 .23601 Mtetra
.1379 .23601 .14889 .24689 .16417 .24101 .15324 .23006 Mtetra
.15324 .23006 .16417 .24101 .17956 .2351 .16867 .22408 Mtetra
.16867 .22408 .17956 .2351 .19503 .22915 .1842 .21806 Mtetra
.1842 .21806 .19503 .22915 .2106 .22316 .19982 .21201 Mtetra
.19982 .21201 .2106 .22316 .22626 .21713 .21553 .20592 Mtetra
.21553 .20592 .22626 .21713 .24201 .21107 .23135 .19979 Mtetra
.23135 .19979 .24201 .21107 .25786 .20498 .24725 .19362 Mtetra
.24725 .19362 .25786 .20498 .27381 .19884 .26326 .18742 Mtetra
.26326 .18742 .27381 .19884 .28986 .19267 .27936 .18118 Mtetra
.27936 .18118 .28986 .19267 .306 .18646 .29557 .1749 Mtetra
.29557 .1749 .306 .18646 .32224 .18021 .31187 .16858 Mtetra
.31187 .16858 .32224 .18021 .33859 .17393 .32828 .16222 Mtetra
.32828 .16222 .33859 .17393 .35503 .1676 .34478 .15582 Mtetra
.34478 .15582 .35503 .1676 .37158 .16124 .36139 .14938 Mtetra
.36139 .14938 .37158 .16124 .38823 .15483 .37811 .14291 Mtetra
.37811 .14291 .38823 .15483 .40498 .14839 .39493 .13639 Mtetra
.39493 .13639 .40498 .14839 .42184 .14191 .41185 .12983 Mtetra
.41185 .12983 .42184 .14191 .4388 .13538 .42888 .12323 Mtetra
.42888 .12323 .4388 .13538 .45588 .12881 .44602 .11658 Mtetra
.44602 .11658 .45588 .12881 .47306 .12221 .46327 .1099 Mtetra
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Mtetra
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Mtetra
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Mtetra
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Mtetra
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Mtetra
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Mtetra
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Mtetra
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Mtetra
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Mtetra
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.982 .904 .652 r
.02931 .30469 .04482 .28991 .0535 .32563 .05061 .25826 Mtetra
.58 .4 .602 r
.05061 .25826 .0535 .32563 .07693 .26294 .06613 .2487 Mtetra
.654 .676 .859 r
.06613 .2487 .07693 .26294 .09242 .25364 .08116 .24283 Mtetra
.664 .741 .908 r
.08116 .24283 .09242 .25364 .10749 .2478 .09628 .23692 Mtetra
.09628 .23692 .10749 .2478 .12265 .24192 .11148 .23098 Mtetra
.11148 .23098 .12265 .24192 .1379 .23601 .12679 .225 Mtetra
.12679 .225 .1379 .23601 .15324 .23006 .14218 .21899 Mtetra
.14218 .21899 .15324 .23006 .16867 .22408 .15767 .21294 Mtetra
.15767 .21294 .16867 .22408 .1842 .21806 .17325 .20686 Mtetra
.17325 .20686 .1842 .21806 .19982 .21201 .18892 .20073 Mtetra
.18892 .20073 .19982 .21201 .21553 .20592 .20469 .19457 Mtetra
.20469 .19457 .21553 .20592 .23135 .19979 .22056 .18838 Mtetra
.22056 .18838 .23135 .19979 .24725 .19362 .23652 .18214 Mtetra
.23652 .18214 .24725 .19362 .26326 .18742 .25259 .17587 Mtetra
.25259 .17587 .26326 .18742 .27936 .18118 .26875 .16955 Mtetra
.26875 .16955 .27936 .18118 .29557 .1749 .28501 .1632 Mtetra
.28501 .1632 .29557 .1749 .31187 .16858 .30138 .15681 Mtetra
.30138 .15681 .31187 .16858 .32828 .16222 .31785 .15038 Mtetra
.31785 .15038 .32828 .16222 .34478 .15582 .33442 .14391 Mtetra
.33442 .14391 .34478 .15582 .36139 .14938 .35109 .13739 Mtetra
.35109 .13739 .36139 .14938 .37811 .14291 .36787 .13084 Mtetra
.36787 .13084 .37811 .14291 .39493 .13639 .38475 .12424 Mtetra
.38475 .12424 .39493 .13639 .41185 .12983 .40174 .11761 Mtetra
.40174 .11761 .41185 .12983 .42888 .12323 .41884 .11093 Mtetra
.41884 .11093 .42888 .12323 .44602 .11658 .43605 .10421 Mtetra
.43605 .10421 .44602 .11658 .46327 .1099 .45337 .09744 Mtetra
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Mtetra
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Mtetra
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Mtetra
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Mtetra
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Mtetra
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Mtetra
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Mtetra
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Mtetra
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Mtetra
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Mtetra
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Mtetra
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Mtetra
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Mtetra
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Mtetra
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Mtetra
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Mtetra
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Mtetra
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Mtetra
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Mtetra
.57384 .54314 .58111 .55092 .59512 .54671 .5879 .53889 Mtetra
.5879 .53889 .59512 .54671 .60921 .54249 .60203 .53463 Mtetra
.60203 .53463 .60921 .54249 .62337 .53824 .61624 .53034 Mtetra
.61624 .53034 .62337 .53824 .63759 .53397 .63052 .52603 Mtetra
.63052 .52603 .63759 .53397 .6519 .52968 .64487 .5217 Mtetra
.64487 .5217 .6519 .52968 .66627 .52537 .6593 .51735 Mtetra
.6593 .51735 .66627 .52537 .68072 .52103 .67379 .51297 Mtetra
.67379 .51297 .68072 .52103 .69524 .51668 .68837 .50857 Mtetra
.68837 .50857 .69524 .51668 .70984 .5123 .70302 .50415 Mtetra
.70302 .50415 .70984 .5123 .72452 .5079 .71774 .49971 Mtetra
.71774 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.663 .741 .908 r
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44453 Mtetra
.661 .741 .909 r
.9006 .44453 .90669 .45324 .9224 .44853 .91638 .43987 Mtetra
.659 .742 .911 r
.91638 .43987 .9224 .44853 .9382 .44382 .93226 .43525 Mtetra
.667 .749 .912 r
.93226 .43525 .9382 .44382 .95408 .43912 .94819 .4303 Mtetra
.666 .744 .908 r
.94819 .4303 .95408 .43912 .97004 .43429 .9642 .42534 Mtetra
.664 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Mtetra
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Mtetra
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Mtetra
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Mtetra
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Mtetra
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Mtetra
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Mtetra
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Mtetra
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Mtetra
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Mtetra
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .53529 Mtetra
.5665 .53529 .57384 .54314 .5879 .53889 .58061 .531 Mtetra
.58061 .531 .5879 .53889 .60203 .53463 .59479 .5267 Mtetra
.59479 .5267 .60203 .53463 .61624 .53034 .60905 .52237 Mtetra
.60905 .52237 .61624 .53034 .63052 .52603 .62338 .51802 Mtetra
.62338 .51802 .63052 .52603 .64487 .5217 .63778 .51365 Mtetra
.63778 .51365 .64487 .5217 .6593 .51735 .65225 .50925 Mtetra
.65225 .50925 .6593 .51735 .67379 .51297 .6668 .50483 Mtetra
.6668 .50483 .67379 .51297 .68837 .50857 .68143 .50039 Mtetra
.68143 .50039 .68837 .50857 .70302 .50415 .69613 .49593 Mtetra
.69613 .49593 .70302 .50415 .71774 .49971 .71091 .49144 Mtetra
.71091 .49144 .71774 .49971 .73255 .49524 .72577 .48693 Mtetra
.72577 .48693 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.663 .741 .908 r
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .44052 Mtetra
.657 .739 .91 r
.87871 .44052 .88492 .44926 .9006 .44453 .89449 .43602 Mtetra
.652 .744 .917 r
.89449 .43602 .9006 .44453 .91638 .43987 .91038 .43166 Mtetra
.673 .762 .918 r
.91038 .43166 .91638 .43987 .93226 .43525 .92625 .42642 Mtetra
.671 .746 .907 r
.92625 .42642 .93226 .43525 .94819 .4303 .94221 .42125 Mtetra
.664 .739 .906 r
.94221 .42125 .94819 .4303 .9642 .42534 .9583 .41633 Mtetra
.664 .741 .908 r
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Mtetra
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Mtetra
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Mtetra
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55702 Mtetra
.46198 .55702 .4697 .56468 .48332 .56054 .47564 .55285 Mtetra
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Mtetra
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Mtetra
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .5402 Mtetra
.51705 .5402 .5246 .54801 .5385 .54379 .531 .53594 Mtetra
.531 .53594 .5385 .54379 .55246 .53955 .54501 .53166 Mtetra
.54501 .53166 .55246 .53955 .5665 .53529 .5591 .52736 Mtetra
.5591 .52736 .5665 .53529 .58061 .531 .57325 .52304 Mtetra
.57325 .52304 .58061 .531 .59479 .5267 .58748 .51869 Mtetra
.58748 .51869 .59479 .5267 .60905 .52237 .60179 .51432 Mtetra
.60179 .51432 .60905 .52237 .62338 .51802 .61616 .50993 Mtetra
.61616 .50993 .62338 .51802 .63778 .51365 .63062 .50552 Mtetra
.63062 .50552 .63778 .51365 .65225 .50925 .64514 .50108 Mtetra
.64514 .50108 .65225 .50925 .6668 .50483 .65974 .49662 Mtetra
.65974 .49662 .6668 .50483 .68143 .50039 .67442 .49214 Mtetra
.67442 .49214 .68143 .50039 .69613 .49593 .68918 .48763 Mtetra
.68918 .48763 .69613 .49593 .71091 .49144 .70401 .4831 Mtetra
.70401 .4831 .71091 .49144 .72577 .48693 .71892 .47854 Mtetra
.71892 .47854 .72577 .48693 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46936 Mtetra
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.662 .741 .908 r
.84107 .44123 .84747 .44998 .86305 .44525 .85672 .43652 Mtetra
.645 .735 .915 r
.85672 .43652 .86305 .44525 .87871 .44052 .87252 .43247 Mtetra
.633 .75 .932 r
.87252 .43247 .87871 .44052 .89449 .43602 .88846 .42872 Mtetra
.689 .794 .93 r
.88846 .42872 .89449 .43602 .91038 .43166 .90423 .42278 Mtetra
.681 .75 .903 r
.90423 .42278 .91038 .43166 .92625 .42642 .92013 .41715 Mtetra
.665 .735 .902 r
.92013 .41715 .92625 .42642 .94221 .42125 .93619 .41218 Mtetra
.664 .741 .907 r
.93619 .41218 .94221 .42125 .9583 .41633 .95234 .40724 Mtetra
.664 .741 .908 r
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Mtetra
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56181 Mtetra
.41347 .56181 .42139 .56942 .43486 .56531 .42697 .55767 Mtetra
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .55349 Mtetra
.44054 .55349 .44838 .56118 .46198 .55702 .45418 .5493 Mtetra
.45418 .5493 .46198 .55702 .47564 .55285 .46789 .54509 Mtetra
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Mtetra
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Mtetra
.49552 .5366 .50318 .54444 .51705 .5402 .50944 .53232 Mtetra
.50944 .53232 .51705 .5402 .531 .53594 .52343 .52802 Mtetra
.52343 .52802 .531 .53594 .54501 .53166 .53749 .5237 Mtetra
.53749 .5237 .54501 .53166 .5591 .52736 .55162 .51936 Mtetra
.55162 .51936 .5591 .52736 .57325 .52304 .56582 .51499 Mtetra
.56582 .51499 .57325 .52304 .58748 .51869 .5801 .51061 Mtetra
.5801 .51061 .58748 .51869 .60179 .51432 .59446 .5062 Mtetra
.59446 .5062 .60179 .51432 .61616 .50993 .60888 .50176 Mtetra
.60888 .50176 .61616 .50993 .63062 .50552 .62338 .49731 Mtetra
.62338 .49731 .63062 .50552 .64514 .50108 .63796 .49283 Mtetra
.63796 .49283 .64514 .50108 .65974 .49662 .65262 .48832 Mtetra
.65262 .48832 .65974 .49662 .67442 .49214 .66735 .4838 Mtetra
.66735 .4838 .67442 .49214 .68918 .48763 .68215 .47925 Mtetra
.68215 .47925 .68918 .48763 .70401 .4831 .69704 .47467 Mtetra
.69704 .47467 .70401 .4831 .71892 .47854 .712 .47007 Mtetra
.712 .47007 .71892 .47854 .73391 .47397 .72705 .46545 Mtetra
.72705 .46545 .73391 .47397 .74897 .46936 .74217 .4608 Mtetra
.74217 .4608 .74897 .46936 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Mtetra
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.663 .741 .908 r
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.659 .74 .909 r
.819 .43719 .82552 .44598 .84107 .44123 .83463 .43256 Mtetra
.614 .725 .925 r
.83463 .43256 .84107 .44123 .85672 .43652 .85052 .4296 Mtetra
.579 .762 .965 r
.85052 .4296 .85672 .43652 .87252 .43247 .86657 .42713 Mtetra
.725 .866 .948 r
.86657 .42713 .87252 .43247 .88846 .42872 .88217 .41959 Mtetra
.7 .752 .892 r
.88217 .41959 .88846 .42872 .90423 .42278 .89795 .41306 Mtetra
.666 .726 .894 r
.89795 .41306 .90423 .42278 .92013 .41715 .91398 .40801 Mtetra
.664 .74 .907 r
.91398 .40801 .92013 .41715 .93619 .41218 .93011 .40305 Mtetra
.664 .741 .908 r
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Mtetra
.39199 .55831 .40003 .56594 .41347 .56181 .40547 .55414 Mtetra
.40547 .55414 .41347 .56181 .42697 .55767 .41902 .54995 Mtetra
.41902 .54995 .42697 .55767 .44054 .55349 .43263 .54574 Mtetra
.43263 .54574 .44054 .55349 .45418 .5493 .44632 .54151 Mtetra
.44632 .54151 .45418 .5493 .46789 .54509 .46007 .53726 Mtetra
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .53298 Mtetra
.47389 .53298 .48167 .54086 .49552 .5366 .48778 .52869 Mtetra
.48778 .52869 .49552 .5366 .50944 .53232 .50175 .52437 Mtetra
.50175 .52437 .50944 .53232 .52343 .52802 .51578 .52003 Mtetra
.51578 .52003 .52343 .52802 .53749 .5237 .52989 .51567 Mtetra
.52989 .51567 .53749 .5237 .55162 .51936 .54407 .51128 Mtetra
.54407 .51128 .55162 .51936 .56582 .51499 .55833 .50688 Mtetra
.55833 .50688 .56582 .51499 .5801 .51061 .57265 .50245 Mtetra
.57265 .50245 .5801 .51061 .59446 .5062 .58706 .49799 Mtetra
.58706 .49799 .59446 .5062 .60888 .50176 .60153 .49352 Mtetra
.60153 .49352 .60888 .50176 .62338 .49731 .61609 .48902 Mtetra
.61609 .48902 .62338 .49731 .63796 .49283 .63071 .48449 Mtetra
.63071 .48449 .63796 .49283 .65262 .48832 .64542 .47995 Mtetra
.64542 .47995 .65262 .48832 .66735 .4838 .6602 .47538 Mtetra
.6602 .47538 .66735 .4838 .68215 .47925 .67506 .47078 Mtetra
.67506 .47078 .68215 .47925 .69704 .47467 .69 .46616 Mtetra
.69 .46616 .69704 .47467 .712 .47007 .70502 .46152 Mtetra
.70502 .46152 .712 .47007 .72705 .46545 .72012 .45685 Mtetra
.72012 .45685 .72705 .46545 .74217 .4608 .7353 .45216 Mtetra
.7353 .45216 .74217 .4608 .75737 .45613 .75056 .44744 Mtetra
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Mtetra
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Mtetra
.663 .741 .908 r
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43314 Mtetra
.653 .737 .911 r
.79683 .43314 .80347 .44196 .819 .43719 .81246 .42873 Mtetra
.534 .696 .943 r
.81246 .42873 .819 .43719 .83463 .43256 .82853 .42814 Mtetra
.381 .748 .991 r
.82853 .42814 .83463 .43256 .85052 .4296 .84479 .42805 Mtetra
.769 .98 .912 r
.84479 .42805 .85052 .4296 .86657 .42713 .86007 .41718 Mtetra
.728 .745 .865 r
.86007 .41718 .86657 .42713 .88217 .41959 .87566 .409 Mtetra
.668 .709 .878 r
.87566 .409 .88217 .41959 .89795 .41306 .89166 .40382 Mtetra
.664 .738 .906 r
.89166 .40382 .89795 .41306 .91398 .40801 .90777 .39883 Mtetra
.664 .741 .908 r
.90777 .39883 .91398 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Mtetra
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Mtetra
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53791 Mtetra
.42465 .53791 .43263 .54574 .44632 .54151 .43837 .53364 Mtetra
.43837 .53364 .44632 .54151 .46007 .53726 .45217 .52935 Mtetra
.45217 .52935 .46007 .53726 .47389 .53298 .46604 .52504 Mtetra
.46604 .52504 .47389 .53298 .48778 .52869 .47998 .5207 Mtetra
.47998 .5207 .48778 .52869 .50175 .52437 .49399 .51634 Mtetra
.49399 .51634 .50175 .52437 .51578 .52003 .50807 .51196 Mtetra
.50807 .51196 .51578 .52003 .52989 .51567 .52222 .50756 Mtetra
.52222 .50756 .52989 .51567 .54407 .51128 .53645 .50313 Mtetra
.53645 .50313 .54407 .51128 .55833 .50688 .55076 .49868 Mtetra
.55076 .49868 .55833 .50688 .57265 .50245 .56513 .49421 Mtetra
.56513 .49421 .57265 .50245 .58706 .49799 .57958 .48971 Mtetra
.57958 .48971 .58706 .49799 .60153 .49352 .59411 .48519 Mtetra
.59411 .48519 .60153 .49352 .61609 .48902 .60871 .48065 Mtetra
.60871 .48065 .61609 .48902 .63071 .48449 .6234 .47608 Mtetra
.6234 .47608 .63071 .48449 .64542 .47995 .63815 .47149 Mtetra
.63815 .47149 .64542 .47995 .6602 .47538 .65299 .46688 Mtetra
.65299 .46688 .6602 .47538 .67506 .47078 .6679 .46224 Mtetra
.6679 .46224 .67506 .47078 .69 .46616 .6829 .45757 Mtetra
.6829 .45757 .69 .46616 .70502 .46152 .69797 .45288 Mtetra
.69797 .45288 .70502 .46152 .72012 .45685 .71312 .44817 Mtetra
.71312 .44817 .72012 .45685 .7353 .45216 .72836 .44343 Mtetra
.72836 .44343 .7353 .45216 .75056 .44744 .74368 .43866 Mtetra
.74368 .43866 .75056 .44744 .7659 .4427 .75908 .43387 Mtetra
.663 .741 .908 r
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42907 Mtetra
.639 .732 .916 r
.77456 .42907 .78132 .43793 .79683 .43314 .7902 .42517 Mtetra
.312 .592 .944 r
.7902 .42517 .79683 .43314 .81246 .42873 .80663 .42922 Mtetra
.305 0 0 r
.80663 .42922 .81246 .42873 .82853 .42814 .82322 .43309 Mtetra
.629 .884 .549 r
.82322 .43309 .82853 .42814 .84479 .42805 .83795 .41592 Mtetra
.754 .715 .816 r
.83795 .41592 .84479 .42805 .86007 .41718 .85328 .40498 Mtetra
.667 .679 .852 r
.85328 .40498 .86007 .41718 .87566 .409 .86924 .3996 Mtetra
.664 .736 .903 r
.86924 .3996 .87566 .409 .89166 .40382 .88532 .3946 Mtetra
.664 .741 .908 r
.88532 .3946 .89166 .40382 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .5343 Mtetra
.40288 .5343 .41099 .54216 .42465 .53791 .41658 .53001 Mtetra
.41658 .53001 .42465 .53791 .43837 .53364 .43036 .5257 Mtetra
.43036 .5257 .43837 .53364 .45217 .52935 .4442 .52137 Mtetra
.4442 .52137 .45217 .52935 .46604 .52504 .45811 .51701 Mtetra
.45811 .51701 .46604 .52504 .47998 .5207 .4721 .51263 Mtetra
.4721 .51263 .47998 .5207 .49399 .51634 .48615 .50823 Mtetra
.48615 .50823 .49399 .51634 .50807 .51196 .50028 .50381 Mtetra
.50028 .50381 .50807 .51196 .52222 .50756 .51448 .49937 Mtetra
.51448 .49937 .52222 .50756 .53645 .50313 .52876 .4949 Mtetra
.52876 .4949 .53645 .50313 .55076 .49868 .54311 .4904 Mtetra
.54311 .4904 .55076 .49868 .56513 .49421 .55754 .48589 Mtetra
.55754 .48589 .56513 .49421 .57958 .48971 .57204 .48135 Mtetra
.57204 .48135 .57958 .48971 .59411 .48519 .58662 .47679 Mtetra
.58662 .47679 .59411 .48519 .60871 .48065 .60127 .4722 Mtetra
.60127 .4722 .60871 .48065 .6234 .47608 .616 .46759 Mtetra
.616 .46759 .6234 .47608 .63815 .47149 .63082 .46295 Mtetra
.63082 .46295 .63815 .47149 .65299 .46688 .6457 .45829 Mtetra
.6457 .45829 .65299 .46688 .6679 .46224 .66067 .4536 Mtetra
.66067 .4536 .6679 .46224 .6829 .45757 .67572 .44889 Mtetra
.67572 .44889 .6829 .45757 .69797 .45288 .69085 .44416 Mtetra
.69085 .44416 .69797 .45288 .71312 .44817 .70606 .4394 Mtetra
.70606 .4394 .71312 .44817 .72836 .44343 .72135 .43461 Mtetra
.72135 .43461 .72836 .44343 .74368 .43866 .73673 .4298 Mtetra
.663 .741 .908 r
.73673 .4298 .74368 .43866 .75908 .43387 .75219 .425 Mtetra
.611 .721 .924 r
.75219 .425 .75908 .43387 .77456 .42907 .76787 .42209 Mtetra
0 .224 .713 r
.76787 .42209 .77456 .42907 .7902 .42517 .78489 .43443 Mtetra
.643 .196 .175 r
.78489 .43443 .7902 .42517 .80663 .42922 .80193 .44414 Mtetra
0 0 0 r
.80193 .44414 .80663 .42922 .82322 .43309 .81583 .41612 Mtetra
.763 .661 .75 r
.81583 .41612 .82322 .43309 .83795 .41592 .8308 .401 Mtetra
.663 .638 .814 r
.8308 .401 .83795 .41592 .85328 .40498 .84672 .39537 Mtetra
.664 .732 .9 r
.84672 .39537 .85328 .40498 .86924 .3996 .86278 .39034 Mtetra
.664 .741 .908 r
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Mtetra
.38103 .53067 .38925 .53857 .40288 .5343 .3947 .52637 Mtetra
.3947 .52637 .40288 .5343 .41658 .53001 .40845 .52204 Mtetra
.40845 .52204 .41658 .53001 .43036 .5257 .42226 .51768 Mtetra
.42226 .51768 .43036 .5257 .4442 .52137 .43615 .51331 Mtetra
.43615 .51331 .4442 .52137 .45811 .51701 .45011 .50891 Mtetra
.45011 .50891 .45811 .51701 .4721 .51263 .46414 .50449 Mtetra
.46414 .50449 .4721 .51263 .48615 .50823 .47824 .50005 Mtetra
.47824 .50005 .48615 .50823 .50028 .50381 .49242 .49559 Mtetra
.49242 .49559 .50028 .50381 .51448 .49937 .50667 .4911 Mtetra
.50667 .4911 .51448 .49937 .52876 .4949 .52099 .48658 Mtetra
.52099 .48658 .52876 .4949 .54311 .4904 .53539 .48205 Mtetra
.53539 .48205 .54311 .4904 .55754 .48589 .54987 .47749 Mtetra
.54987 .47749 .55754 .48589 .57204 .48135 .56442 .47291 Mtetra
.56442 .47291 .57204 .48135 .58662 .47679 .57905 .4683 Mtetra
.57905 .4683 .58662 .47679 .60127 .4722 .59376 .46367 Mtetra
.59376 .46367 .60127 .4722 .616 .46759 .60854 .45901 Mtetra
.60854 .45901 .616 .46759 .63082 .46295 .62341 .45433 Mtetra
.62341 .45433 .63082 .46295 .6457 .45829 .63835 .44962 Mtetra
.63835 .44962 .6457 .45829 .66067 .4536 .65337 .44489 Mtetra
.65337 .44489 .66067 .4536 .67572 .44889 .66847 .44013 Mtetra
.66847 .44013 .67572 .44889 .69085 .44416 .68366 .43535 Mtetra
.68366 .43535 .69085 .44416 .70606 .4394 .69892 .43054 Mtetra
.69892 .43054 .70606 .4394 .72135 .43461 .71427 .42571 Mtetra
.662 .741 .909 r
.71427 .42571 .72135 .43461 .73673 .4298 .72971 .42092 Mtetra
.553 .697 .936 r
.72971 .42092 .73673 .4298 .75219 .425 .74548 .41978 Mtetra
.762 .273 0 r
.74548 .41978 .75219 .425 .76787 .42209 .76334 .44552 Mtetra
.681 .333 .379 r
.76334 .44552 .76787 .42209 .78489 .43443 .78093 .46279 Mtetra
0 0 .123 r
.78093 .46279 .78489 .43443 .80193 .44414 .79367 .41787 Mtetra
.75 .598 .688 r
.79367 .41787 .80193 .44414 .81583 .41612 .80822 .39705 Mtetra
.654 .59 .771 r
.80822 .39705 .81583 .41612 .8308 .401 .82409 .39112 Mtetra
.664 .727 .896 r
.82409 .39112 .8308 .401 .84672 .39537 .84012 .38606 Mtetra
.664 .741 .908 r
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Mtetra
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51835 Mtetra
.38644 .51835 .3947 .52637 .40845 .52204 .40023 .51398 Mtetra
.40023 .51398 .40845 .52204 .42226 .51768 .41409 .50959 Mtetra
.41409 .50959 .42226 .51768 .43615 .51331 .42802 .50518 Mtetra
.42802 .50518 .43615 .51331 .45011 .50891 .44203 .50074 Mtetra
.44203 .50074 .45011 .50891 .46414 .50449 .45611 .49627 Mtetra
.45611 .49627 .46414 .50449 .47824 .50005 .47026 .49179 Mtetra
.47026 .49179 .47824 .50005 .49242 .49559 .48448 .48728 Mtetra
.48448 .48728 .49242 .49559 .50667 .4911 .49878 .48275 Mtetra
.49878 .48275 .50667 .4911 .52099 .48658 .51315 .47819 Mtetra
.51315 .47819 .52099 .48658 .53539 .48205 .5276 .47361 Mtetra
.5276 .47361 .53539 .48205 .54987 .47749 .54213 .46901 Mtetra
.54213 .46901 .54987 .47749 .56442 .47291 .55673 .46438 Mtetra
.55673 .46438 .56442 .47291 .57905 .4683 .57141 .45973 Mtetra
.57141 .45973 .57905 .4683 .59376 .46367 .58617 .45505 Mtetra
.58617 .45505 .59376 .46367 .60854 .45901 .60101 .45035 Mtetra
.60101 .45035 .60854 .45901 .62341 .45433 .61592 .44562 Mtetra
.61592 .44562 .62341 .45433 .63835 .44962 .63092 .44086 Mtetra
.63092 .44086 .63835 .44962 .65337 .44489 .646 .43609 Mtetra
.646 .43609 .65337 .44489 .66847 .44013 .66115 .43128 Mtetra
.66115 .43128 .66847 .44013 .68366 .43535 .6764 .42645 Mtetra
.6764 .42645 .68366 .43535 .69892 .43054 .69172 .42159 Mtetra
.66 .74 .909 r
.69172 .42159 .69892 .43054 .71427 .42571 .70713 .41686 Mtetra
.439 .644 .944 r
.70713 .41686 .71427 .42571 .72971 .42092 .72303 .41855 Mtetra
.9 .484 .157 r
.72303 .41855 .72971 .42092 .74548 .41978 .74195 .46386 Mtetra
.676 .374 .454 r
.74195 .46386 .74548 .41978 .76334 .44552 .76006 .48941 Mtetra
0 0 .18 r
.76006 .48941 .76334 .44552 .78093 .46279 .77141 .4208 Mtetra
.727 .543 .643 r
.77141 .4208 .78093 .46279 .79367 .41787 .78553 .3931 Mtetra
.642 .545 .729 r
.78553 .3931 .79367 .41787 .80822 .39705 .80135 .38685 Mtetra
.663 .721 .891 r
.80135 .38685 .80822 .39705 .82409 .39112 .81736 .38177 Mtetra
.664 .741 .908 r
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Mtetra
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Mtetra
.36434 .51466 .37272 .5227 .38644 .51835 .37811 .51027 Mtetra
.37811 .51027 .38644 .51835 .40023 .51398 .39194 .50586 Mtetra
.39194 .50586 .40023 .51398 .41409 .50959 .40584 .50142 Mtetra
.40584 .50142 .41409 .50959 .42802 .50518 .41982 .49696 Mtetra
.41982 .49696 .42802 .50518 .44203 .50074 .43387 .49248 Mtetra
.43387 .49248 .44203 .50074 .45611 .49627 .44799 .48798 Mtetra
.44799 .48798 .45611 .49627 .47026 .49179 .46219 .48345 Mtetra
.46219 .48345 .47026 .49179 .48448 .48728 .47646 .47889 Mtetra
.47646 .47889 .48448 .48728 .49878 .48275 .49081 .47432 Mtetra
.49081 .47432 .49878 .48275 .51315 .47819 .50523 .46972 Mtetra
.50523 .46972 .51315 .47819 .5276 .47361 .51973 .46509 Mtetra
.51973 .46509 .5276 .47361 .54213 .46901 .53431 .46044 Mtetra
.53431 .46044 .54213 .46901 .55673 .46438 .54896 .45577 Mtetra
.54896 .45577 .55673 .46438 .57141 .45973 .56369 .45107 Mtetra
.56369 .45107 .57141 .45973 .58617 .45505 .57851 .44635 Mtetra
.57851 .44635 .58617 .45505 .60101 .45035 .5934 .4416 Mtetra
.5934 .4416 .60101 .45035 .61592 .44562 .60837 .43682 Mtetra
.60837 .43682 .61592 .44562 .63092 .44086 .62342 .43202 Mtetra
.62342 .43202 .63092 .44086 .646 .43609 .63855 .4272 Mtetra
.63855 .4272 .646 .43609 .66115 .43128 .65376 .42234 Mtetra
.65376 .42234 .66115 .43128 .6764 .42645 .66906 .41746 Mtetra
.657 .739 .91 r
.66906 .41746 .6764 .42645 .69172 .42159 .68445 .41282 Mtetra
.222 .524 .918 r
.68445 .41282 .69172 .42159 .70713 .41686 .7005 .41858 Mtetra
.927 .558 .295 r
.7005 .41858 .70713 .41686 .72303 .41855 .72058 .4895 Mtetra
.661 .383 .488 r
.72058 .4895 .72303 .41855 .74195 .46386 .73906 .52214 Mtetra
0 0 .157 r
.73906 .52214 .74195 .46386 .76006 .48941 .74897 .42404 Mtetra
.702 .501 .614 r
.74897 .42404 .76006 .48941 .77141 .4208 .76272 .3891 Mtetra
.631 .509 .696 r
.76272 .3891 .77141 .4208 .78553 .3931 .77851 .38256 Mtetra
.663 .714 .886 r
.77851 .38256 .78553 .3931 .80135 .38685 .79449 .37745 Mtetra
.664 .741 .908 r
.79449 .37745 .80135 .38685 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .5021 Mtetra
.36969 .5021 .37811 .51027 .39194 .50586 .38357 .49765 Mtetra
.38357 .49765 .39194 .50586 .40584 .50142 .39752 .49317 Mtetra
.39752 .49317 .40584 .50142 .41982 .49696 .41154 .48867 Mtetra
.41154 .48867 .41982 .49696 .43387 .49248 .42564 .48415 Mtetra
.42564 .48415 .43387 .49248 .44799 .48798 .43981 .4796 Mtetra
.43981 .4796 .44799 .48798 .46219 .48345 .45405 .47502 Mtetra
.45405 .47502 .46219 .48345 .47646 .47889 .46837 .47043 Mtetra
.46837 .47043 .47646 .47889 .49081 .47432 .48277 .46581 Mtetra
.48277 .46581 .49081 .47432 .50523 .46972 .49724 .46116 Mtetra
.49724 .46116 .50523 .46972 .51973 .46509 .51179 .45649 Mtetra
.51179 .45649 .51973 .46509 .53431 .46044 .52641 .4518 Mtetra
.52641 .4518 .53431 .46044 .54896 .45577 .54112 .44708 Mtetra
.54112 .44708 .54896 .45577 .56369 .45107 .5559 .44233 Mtetra
.5559 .44233 .56369 .45107 .57851 .44635 .57077 .43756 Mtetra
.57077 .43756 .57851 .44635 .5934 .4416 .58571 .43276 Mtetra
.58571 .43276 .5934 .4416 .60837 .43682 .60073 .42794 Mtetra
.60073 .42794 .60837 .43682 .62342 .43202 .61584 .42309 Mtetra
.61584 .42309 .62342 .43202 .63855 .4272 .63103 .41822 Mtetra
.663 .741 .908 r
.63103 .41822 .63855 .4272 .65376 .42234 .6463 .41332 Mtetra
.653 .738 .912 r
.6463 .41332 .65376 .42234 .66906 .41746 .66167 .4088 Mtetra
0 .295 .783 r
.66167 .4088 .66906 .41746 .68445 .41282 .67786 .41979 Mtetra
.93 .588 .361 r
.67786 .41979 .68445 .41282 .7005 .41858 .69895 .52031 Mtetra
.642 .378 .505 r
.69895 .52031 .7005 .41858 .72058 .4895 .7175 .55629 Mtetra
0 0 .067 r
.7175 .55629 .72058 .4895 .73906 .52214 .72626 .42628 Mtetra
.68 .471 .596 r
.72626 .42628 .73906 .52214 .74897 .42404 .7398 .38499 Mtetra
.62 .482 .671 r
.7398 .38499 .74897 .42404 .76272 .3891 .75556 .37825 Mtetra
.663 .709 .882 r
.75556 .37825 .76272 .3891 .77851 .38256 .77152 .37312 Mtetra
.664 .741 .908 r
.77152 .37312 .77851 .38256 .79449 .37745 .78756 .36797 Mtetra
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Mtetra
.34734 .49834 .35588 .50654 .36969 .5021 .36119 .49386 Mtetra
.36119 .49386 .36969 .5021 .38357 .49765 .37511 .48936 Mtetra
.37511 .48936 .38357 .49765 .39752 .49317 .38911 .48484 Mtetra
.38911 .48484 .39752 .49317 .41154 .48867 .40318 .4803 Mtetra
.40318 .4803 .41154 .48867 .42564 .48415 .41732 .47573 Mtetra
.41732 .47573 .42564 .48415 .43981 .4796 .43154 .47114 Mtetra
.43154 .47114 .43981 .4796 .45405 .47502 .44583 .46652 Mtetra
.44583 .46652 .45405 .47502 .46837 .47043 .4602 .46188 Mtetra
.4602 .46188 .46837 .47043 .48277 .46581 .47464 .45721 Mtetra
.47464 .45721 .48277 .46581 .49724 .46116 .48916 .45252 Mtetra
.48916 .45252 .49724 .46116 .51179 .45649 .50376 .4478 Mtetra
.50376 .4478 .51179 .45649 .52641 .4518 .51844 .44306 Mtetra
.51844 .44306 .52641 .4518 .54112 .44708 .5332 .43829 Mtetra
.5332 .43829 .54112 .44708 .5559 .44233 .54803 .4335 Mtetra
.54803 .4335 .5559 .44233 .57077 .43756 .56295 .42868 Mtetra
.56295 .42868 .57077 .43756 .58571 .43276 .57795 .42384 Mtetra
.57795 .42384 .58571 .43276 .60073 .42794 .59302 .41897 Mtetra
.59302 .41897 .60073 .42794 .61584 .42309 .60818 .41407 Mtetra
.663 .741 .908 r
.60818 .41407 .61584 .42309 .63103 .41822 .62343 .40915 Mtetra
.648 .736 .913 r
.62343 .40915 .63103 .41822 .6463 .41332 .63878 .4048 Mtetra
0 .013 .533 r
.63878 .4048 .6463 .41332 .66167 .4088 .65507 .42168 Mtetra
.928 .6 .398 r
.65507 .42168 .66167 .4088 .67786 .41979 .67674 .55149 Mtetra
.62 .366 .512 r
.67674 .55149 .67786 .41979 .69895 .52031 .69501 .58482 Mtetra
.767 .646 .088 r
.69501 .58482 .69895 .52031 .7175 .55629 .70322 .42615 Mtetra
.661 .448 .585 r
.70322 .42615 .7175 .55629 .72626 .42628 .71676 .38073 Mtetra
.613 .463 .655 r
.71676 .38073 .72626 .42628 .7398 .38499 .73251 .37392 Mtetra
.662 .705 .879 r
.73251 .37392 .7398 .38499 .75556 .37825 .74843 .36876 Mtetra
.664 .741 .908 r
.74843 .36876 .75556 .37825 .77152 .37312 .76445 .36359 Mtetra
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Mtetra
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Mtetra
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Mtetra
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Mtetra
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Mtetra
.35261 .48554 .36119 .49386 .37511 .48936 .36658 .481 Mtetra
.36658 .481 .37511 .48936 .38911 .48484 .38062 .47643 Mtetra
.38062 .47643 .38911 .48484 .40318 .4803 .39473 .47184 Mtetra
.39473 .47184 .40318 .4803 .41732 .47573 .40892 .46723 Mtetra
.40892 .46723 .41732 .47573 .43154 .47114 .42319 .46259 Mtetra
.42319 .46259 .43154 .47114 .44583 .46652 .43753 .45793 Mtetra
.43753 .45793 .44583 .46652 .4602 .46188 .45194 .45324 Mtetra
.45194 .45324 .4602 .46188 .47464 .45721 .46644 .44853 Mtetra
.46644 .44853 .47464 .45721 .48916 .45252 .48101 .44379 Mtetra
.48101 .44379 .48916 .45252 .50376 .4478 .49566 .43903 Mtetra
.49566 .43903 .50376 .4478 .51844 .44306 .51039 .43424 Mtetra
.51039 .43424 .51844 .44306 .5332 .43829 .5252 .42943 Mtetra
.5252 .42943 .5332 .43829 .54803 .4335 .54008 .42459 Mtetra
.54008 .42459 .54803 .4335 .56295 .42868 .55505 .41972 Mtetra
.55505 .41972 .56295 .42868 .57795 .42384 .5701 .41482 Mtetra
.5701 .41482 .57795 .42384 .59302 .41897 .58524 .4099 Mtetra
.663 .741 .908 r
.58524 .4099 .59302 .41897 .60818 .41407 .60045 .40496 Mtetra
.642 .734 .915 r
.60045 .40496 .60818 .41407 .62343 .40915 .61577 .40081 Mtetra
.677 .197 0 r
.61577 .40081 .62343 .40915 .63878 .4048 .63207 .42336 Mtetra
.923 .604 .42 r
.63207 .42336 .63878 .4048 .65507 .42168 .65366 .57629 Mtetra
.595 .349 .514 r
.65366 .57629 .65507 .42168 .67674 .55149 .67137 .60021 Mtetra
.94 .745 .273 r
.67137 .60021 .67674 .55149 .69501 .58482 .67984 .42267 Mtetra
.645 .43 .578 r
.67984 .42267 .69501 .58482 .70322 .42615 .69361 .37632 Mtetra
.607 .453 .646 r
.69361 .37632 .70322 .42615 .71676 .38073 .70934 .36957 Mtetra
.662 .704 .878 r
.70934 .36957 .71676 .38073 .73251 .37392 .72524 .36438 Mtetra
.664 .741 .908 r
.72524 .36438 .73251 .37392 .74843 .36876 .74123 .35918 Mtetra
.74123 .35918 .74843 .36876 .76445 .36359 .75732 .35396 Mtetra
.75732 .35396 .76445 .36359 .78056 .35838 .77349 .3487 Mtetra
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Mtetra
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Mtetra
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Mtetra
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Mtetra
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47255 Mtetra
.35796 .47255 .36658 .481 .38062 .47643 .37205 .46794 Mtetra
.37205 .46794 .38062 .47643 .39473 .47184 .38621 .46331 Mtetra
.38621 .46331 .39473 .47184 .40892 .46723 .40044 .45865 Mtetra
.40044 .45865 .40892 .46723 .42319 .46259 .41476 .45397 Mtetra
.41476 .45397 .42319 .46259 .43753 .45793 .42914 .44926 Mtetra
.42914 .44926 .43753 .45793 .45194 .45324 .44361 .44452 Mtetra
.44361 .44452 .45194 .45324 .46644 .44853 .45815 .43976 Mtetra
.45815 .43976 .46644 .44853 .48101 .44379 .47277 .43498 Mtetra
.47277 .43498 .48101 .44379 .49566 .43903 .48747 .43017 Mtetra
.48747 .43017 .49566 .43903 .51039 .43424 .50225 .42533 Mtetra
.50225 .42533 .51039 .43424 .5252 .42943 .51712 .42047 Mtetra
.51712 .42047 .5252 .42943 .54008 .42459 .53206 .41558 Mtetra
.53206 .41558 .54008 .42459 .55505 .41972 .54708 .41066 Mtetra
.54708 .41066 .55505 .41972 .5701 .41482 .56218 .40572 Mtetra
.663 .741 .908 r
.56218 .40572 .5701 .41482 .58524 .4099 .57737 .40076 Mtetra
.637 .732 .917 r
.57737 .40076 .58524 .4099 .60045 .40496 .59266 .39678 Mtetra
.776 .309 0 r
.59266 .39678 .60045 .40496 .61577 .40081 .60885 .42368 Mtetra
.918 .604 .433 r
.60885 .42368 .61577 .40081 .63207 .42336 .62965 .58792 Mtetra
.566 .326 .511 r
.62965 .58792 .63207 .42336 .65366 .57629 .64669 .59738 Mtetra
.995 .756 .42 r
.64669 .59738 .65366 .57629 .67137 .60021 .6562 .41563 Mtetra
.631 .417 .574 r
.6562 .41563 .67137 .60021 .67984 .42267 .67034 .37176 Mtetra
.605 .449 .644 r
.67034 .37176 .67984 .42267 .69361 .37632 .68606 .36519 Mtetra
.662 .706 .88 r
.68606 .36519 .69361 .37632 .70934 .36957 .70194 .35999 Mtetra
.664 .741 .908 r
.70194 .35999 .70934 .36957 .72524 .36438 .7179 .35476 Mtetra
.7179 .35476 .72524 .36438 .74123 .35918 .73396 .34951 Mtetra
.73396 .34951 .74123 .35918 .75732 .35396 .75011 .34422 Mtetra
.75011 .34422 .75732 .35396 .77349 .3487 .76634 .33891 Mtetra
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Mtetra
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Mtetra
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Mtetra
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46865 Mtetra
.3352 .46865 .34395 .47714 .35796 .47255 .34926 .46402 Mtetra
.34926 .46402 .35796 .47255 .37205 .46794 .36339 .45937 Mtetra
.36339 .45937 .37205 .46794 .38621 .46331 .3776 .45469 Mtetra
.3776 .45469 .38621 .46331 .40044 .45865 .39188 .44998 Mtetra
.39188 .44998 .40044 .45865 .41476 .45397 .40624 .44525 Mtetra
.40624 .44525 .41476 .45397 .42914 .44926 .42068 .4405 Mtetra
.42068 .4405 .42914 .44926 .44361 .44452 .43519 .43572 Mtetra
.43519 .43572 .44361 .44452 .45815 .43976 .44978 .43091 Mtetra
.44978 .43091 .45815 .43976 .47277 .43498 .46446 .42608 Mtetra
.46446 .42608 .47277 .43498 .48747 .43017 .47921 .42122 Mtetra
.47921 .42122 .48747 .43017 .50225 .42533 .49404 .41633 Mtetra
.49404 .41633 .50225 .42533 .51712 .42047 .50895 .41142 Mtetra
.50895 .41142 .51712 .42047 .53206 .41558 .52395 .40648 Mtetra
.52395 .40648 .53206 .41558 .54708 .41066 .53902 .40152 Mtetra
.663 .741 .908 r
.53902 .40152 .54708 .41066 .56218 .40572 .55418 .39653 Mtetra
.633 .731 .919 r
.55418 .39653 .56218 .40572 .57737 .40076 .56944 .39267 Mtetra
.814 .355 0 r
.56944 .39267 .57737 .40076 .59266 .39678 .58541 .42162 Mtetra
.912 .6 .44 r
.58541 .42162 .59266 .39678 .60885 .42368 .60488 .58225 Mtetra
.534 .298 .504 r
.60488 .58225 .60885 .42368 .62965 .58792 .62133 .57592 Mtetra
.964 .712 .505 r
.62133 .57592 .62965 .58792 .64669 .59738 .6324 .40569 Mtetra
.621 .408 .572 r
.6324 .40569 .64669 .59738 .6562 .41563 .64696 .36712 Mtetra
.604 .452 .648 r
.64696 .36712 .6562 .41563 .67034 .37176 .66268 .36079 Mtetra
.662 .71 .883 r
.66268 .36079 .67034 .37176 .68606 .36519 .67853 .35557 Mtetra
.664 .741 .908 r
.67853 .35557 .68606 .36519 .70194 .35999 .69446 .35032 Mtetra
.69446 .35032 .70194 .35999 .7179 .35476 .71049 .34504 Mtetra
.71049 .34504 .7179 .35476 .73396 .34951 .72661 .33973 Mtetra
.72661 .33973 .73396 .34951 .75011 .34422 .74282 .33439 Mtetra
.74282 .33439 .75011 .34422 .76634 .33891 .75912 .32902 Mtetra
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Mtetra
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46936 Mtetra
.29838 .46936 .3073 .47784 .32121 .47326 .31234 .46474 Mtetra
.31234 .46474 .32121 .47326 .3352 .46865 .32636 .46009 Mtetra
.32636 .46009 .3352 .46865 .34926 .46402 .34047 .45541 Mtetra
.34047 .45541 .34926 .46402 .36339 .45937 .35465 .45071 Mtetra
.35465 .45071 .36339 .45937 .3776 .45469 .3689 .44598 Mtetra
.3689 .44598 .3776 .45469 .39188 .44998 .38323 .44123 Mtetra
.38323 .44123 .39188 .44998 .40624 .44525 .39764 .43645 Mtetra
.39764 .43645 .40624 .44525 .42068 .4405 .41213 .43165 Mtetra
.41213 .43165 .42068 .4405 .43519 .43572 .42669 .42682 Mtetra
.42669 .42682 .43519 .43572 .44978 .43091 .44133 .42197 Mtetra
.44133 .42197 .44978 .43091 .46446 .42608 .45606 .41709 Mtetra
.45606 .41709 .46446 .42608 .47921 .42122 .47086 .41218 Mtetra
.47086 .41218 .47921 .42122 .49404 .41633 .48574 .40724 Mtetra
.48574 .40724 .49404 .41633 .50895 .41142 .50071 .40228 Mtetra
.50071 .40228 .50895 .41142 .52395 .40648 .51576 .39729 Mtetra
.663 .741 .908 r
.51576 .39729 .52395 .40648 .53902 .40152 .53089 .39229 Mtetra
.631 .73 .919 r
.53089 .39229 .53902 .40152 .55418 .39653 .54611 .38847 Mtetra
.814 .353 0 r
.54611 .38847 .55418 .39653 .56944 .39267 .56179 .41665 Mtetra
.906 .593 .441 r
.56179 .41665 .56944 .39267 .58541 .42162 .57974 .55963 Mtetra
.494 .261 .49 r
.57974 .55963 .58541 .42162 .60488 .58225 .5958 .54032 Mtetra
.906 .656 .549 r
.5958 .54032 .60488 .58225 .62133 .57592 .60852 .39411 Mtetra
.612 .402 .572 r
.60852 .39411 .62133 .57592 .6324 .40569 .62348 .36243 Mtetra
.607 .463 .66 r
.62348 .36243 .6324 .40569 .64696 .36712 .63918 .35638 Mtetra
.663 .716 .888 r
.63918 .35638 .64696 .36712 .66268 .36079 .655 .35113 Mtetra
.664 .741 .908 r
.655 .35113 .66268 .36079 .67853 .35557 .67091 .34585 Mtetra
.67091 .34585 .67853 .35557 .69446 .35032 .68691 .34055 Mtetra
.68691 .34055 .69446 .35032 .71049 .34504 .703 .33521 Mtetra
.703 .33521 .71049 .34504 .72661 .33973 .71918 .32985 Mtetra
.71918 .32985 .72661 .33973 .74282 .33439 .73545 .32445 Mtetra
.73545 .32445 .74282 .33439 .75912 .32902 .75182 .31903 Mtetra
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Mtetra
.27545 .46545 .2845 .47397 .29838 .46936 .28937 .4608 Mtetra
.28937 .4608 .29838 .46936 .31234 .46474 .30337 .45613 Mtetra
.30337 .45613 .31234 .46474 .32636 .46009 .31744 .45143 Mtetra
.31744 .45143 .32636 .46009 .34047 .45541 .33159 .44671 Mtetra
.33159 .44671 .34047 .45541 .35465 .45071 .34582 .44196 Mtetra
.34582 .44196 .35465 .45071 .3689 .44598 .36012 .43719 Mtetra
.36012 .43719 .3689 .44598 .38323 .44123 .3745 .43239 Mtetra
.3745 .43239 .38323 .44123 .39764 .43645 .38896 .42757 Mtetra
.38896 .42757 .39764 .43645 .41213 .43165 .40349 .42272 Mtetra
.40349 .42272 .41213 .43165 .42669 .42682 .4181 .41784 Mtetra
.4181 .41784 .42669 .42682 .44133 .42197 .4328 .41294 Mtetra
.4328 .41294 .44133 .42197 .45606 .41709 .44757 .40801 Mtetra
.44757 .40801 .45606 .41709 .47086 .41218 .46242 .40305 Mtetra
.46242 .40305 .47086 .41218 .48574 .40724 .47736 .39806 Mtetra
.47736 .39806 .48574 .40724 .50071 .40228 .49238 .39305 Mtetra
.663 .741 .908 r
.49238 .39305 .50071 .40228 .51576 .39729 .50748 .38802 Mtetra
.632 .731 .919 r
.50748 .38802 .51576 .39729 .53089 .39229 .52266 .38414 Mtetra
.775 .3 0 r
.52266 .38414 .53089 .39229 .54611 .38847 .53806 .40892 Mtetra
.9 .581 .434 r
.53806 .40892 .54611 .38847 .56179 .41665 .55464 .52477 Mtetra
.443 .211 .465 r
.55464 .52477 .56179 .41665 .57974 .55963 .57052 .49791 Mtetra
.849 .606 .572 r
.57052 .49791 .57974 .55963 .5958 .54032 .58463 .38228 Mtetra
.605 .399 .575 r
.58463 .38228 .5958 .54032 .60852 .39411 .59988 .35775 Mtetra
.613 .483 .68 r
.59988 .35775 .60852 .39411 .62348 .36243 .61557 .35194 Mtetra
.663 .723 .893 r
.61557 .35194 .62348 .36243 .63918 .35638 .63136 .34667 Mtetra
.664 .741 .908 r
.63136 .34667 .63918 .35638 .655 .35113 .64724 .34137 Mtetra
.64724 .34137 .655 .35113 .67091 .34585 .66321 .33604 Mtetra
.66321 .33604 .67091 .34585 .68691 .34055 .67927 .33068 Mtetra
.67927 .33068 .68691 .34055 .703 .33521 .69543 .32529 Mtetra
.69543 .32529 .703 .33521 .71918 .32985 .71167 .31986 Mtetra
.71167 .31986 .71918 .32985 .73545 .32445 .72801 .31441 Mtetra
.72801 .31441 .73545 .32445 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Mtetra
.2663 .45685 .27545 .46545 .28937 .4608 .28027 .45216 Mtetra
.28027 .45216 .28937 .4608 .30337 .45613 .29432 .44744 Mtetra
.29432 .44744 .30337 .45613 .31744 .45143 .30844 .4427 Mtetra
.30844 .4427 .31744 .45143 .33159 .44671 .32263 .43793 Mtetra
.32263 .43793 .33159 .44671 .34582 .44196 .3369 .43313 Mtetra
.3369 .43313 .34582 .44196 .36012 .43719 .35125 .42831 Mtetra
.35125 .42831 .36012 .43719 .3745 .43239 .36568 .42346 Mtetra
.36568 .42346 .3745 .43239 .38896 .42757 .38018 .41859 Mtetra
.38018 .41859 .38896 .42757 .40349 .42272 .39477 .41369 Mtetra
.39477 .41369 .40349 .42272 .4181 .41784 .40943 .40877 Mtetra
.40943 .40877 .4181 .41784 .4328 .41294 .42417 .40381 Mtetra
.42417 .40381 .4328 .41294 .44757 .40801 .439 .39883 Mtetra
.439 .39883 .44757 .40801 .46242 .40305 .4539 .39382 Mtetra
.4539 .39382 .46242 .40305 .47736 .39806 .46889 .38879 Mtetra
.663 .741 .908 r
.46889 .38879 .47736 .39806 .49238 .39305 .48396 .38373 Mtetra
.635 .732 .918 r
.48396 .38373 .49238 .39305 .50748 .38802 .49911 .3797 Mtetra
.667 .172 0 r
.49911 .3797 .50748 .38802 .52266 .38414 .51428 .39925 Mtetra
.893 .563 .415 r
.51428 .39925 .52266 .38414 .53806 .40892 .52986 .48463 Mtetra
.37 .132 .418 r
.52986 .48463 .53806 .40892 .55464 .52477 .54568 .45597 Mtetra
.8 .568 .587 r
.54568 .45597 .55464 .52477 .57052 .49791 .56074 .37129 Mtetra
.601 .401 .582 r
.56074 .37129 .57052 .49791 .58463 .38228 .57618 .3531 Mtetra
.622 .514 .71 r
.57618 .3531 .58463 .38228 .59988 .35775 .59185 .34748 Mtetra
.663 .729 .898 r
.59185 .34748 .59988 .35775 .61557 .35194 .60761 .34218 Mtetra
.664 .741 .908 r
.60761 .34218 .61557 .35194 .63136 .34667 .62346 .33686 Mtetra
.62346 .33686 .63136 .34667 .64724 .34137 .6394 .3315 Mtetra
.6394 .3315 .64724 .34137 .66321 .33604 .65543 .32612 Mtetra
.65543 .32612 .66321 .33604 .67927 .33068 .67156 .3207 Mtetra
.67156 .3207 .67927 .33068 .69543 .32529 .68777 .31525 Mtetra
.68777 .31525 .69543 .32529 .71167 .31986 .70408 .30977 Mtetra
.70408 .30977 .71167 .31986 .72801 .31441 .72049 .30426 Mtetra
.72049 .30426 .72801 .31441 .74444 .30893 .73699 .29872 Mtetra
.73699 .29872 .74444 .30893 .76097 .30341 .75358 .29314 Mtetra
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28753 Mtetra
.77027 .28753 .7776 .29786 .79432 .29228 .78706 .28189 Mtetra
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Mtetra
.25707 .44817 .2663 .45685 .28027 .45216 .27108 .44343 Mtetra
.27108 .44343 .28027 .45216 .29432 .44744 .28517 .43866 Mtetra
.28517 .43866 .29432 .44744 .30844 .4427 .29934 .43387 Mtetra
.29934 .43387 .30844 .4427 .32263 .43793 .31358 .42905 Mtetra
.31358 .42905 .32263 .43793 .3369 .43313 .3279 .42421 Mtetra
.3279 .42421 .3369 .43313 .35125 .42831 .34229 .41934 Mtetra
.34229 .41934 .35125 .42831 .36568 .42346 .35677 .41445 Mtetra
.35677 .41445 .36568 .42346 .38018 .41859 .37132 .40953 Mtetra
.37132 .40953 .38018 .41859 .39477 .41369 .38595 .40458 Mtetra
.38595 .40458 .39477 .41369 .40943 .40877 .40067 .3996 Mtetra
.40067 .3996 .40943 .40877 .42417 .40381 .41546 .3946 Mtetra
.41546 .3946 .42417 .40381 .439 .39883 .43034 .38956 Mtetra
.43034 .38956 .439 .39883 .4539 .39382 .4453 .38451 Mtetra
.663 .741 .908 r
.4453 .38451 .4539 .39382 .46889 .38879 .46034 .37942 Mtetra
.641 .734 .916 r
.46034 .37942 .46889 .38879 .48396 .38373 .47545 .37517 Mtetra
0 .07 .572 r
.47545 .37517 .48396 .38373 .49911 .3797 .49046 .38876 Mtetra
.883 .529 .372 r
.49046 .38876 .49911 .3797 .51428 .39925 .50548 .44577 Mtetra
.244 0 .319 r
.50548 .44577 .51428 .39925 .52986 .48463 .52128 .41963 Mtetra
.761 .543 .601 r
.52128 .41963 .52986 .48463 .54568 .45597 .53685 .36175 Mtetra
.6 .41 .595 r
.53685 .36175 .54568 .45597 .56074 .37129 .55237 .3485 Mtetra
.634 .557 .75 r
.55237 .3485 .56074 .37129 .57618 .3531 .56801 .343 Mtetra
.663 .733 .902 r
.56801 .343 .57618 .3531 .59185 .34748 .58375 .33768 Mtetra
.664 .741 .908 r
.58375 .33768 .59185 .34748 .60761 .34218 .59957 .33233 Mtetra
.59957 .33233 .60761 .34218 .62346 .33686 .61548 .32695 Mtetra
.61548 .32695 .62346 .33686 .6394 .3315 .63148 .32154 Mtetra
.63148 .32154 .6394 .3315 .65543 .32612 .64757 .31609 Mtetra
.64757 .31609 .65543 .32612 .67156 .3207 .66376 .31062 Mtetra
.66376 .31062 .67156 .3207 .68777 .31525 .68004 .30511 Mtetra
.68004 .30511 .68777 .31525 .70408 .30977 .69642 .29957 Mtetra
.69642 .29957 .70408 .30977 .72049 .30426 .71289 .294 Mtetra
.71289 .294 .72049 .30426 .73699 .29872 .72945 .2884 Mtetra
.72945 .2884 .73699 .29872 .75358 .29314 .74611 .28276 Mtetra
.74611 .28276 .75358 .29314 .77027 .28753 .76287 .2771 Mtetra
.76287 .2771 .77027 .28753 .78706 .28189 .77973 .27139 Mtetra
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.23376 .44416 .24313 .45288 .25707 .44817 .24775 .4394 Mtetra
.24775 .4394 .25707 .44817 .27108 .44343 .2618 .43461 Mtetra
.2618 .43461 .27108 .44343 .28517 .43866 .27594 .4298 Mtetra
.27594 .4298 .28517 .43866 .29934 .43387 .29015 .42496 Mtetra
.29015 .42496 .29934 .43387 .31358 .42905 .30444 .42009 Mtetra
.30444 .42009 .31358 .42905 .3279 .42421 .3188 .4152 Mtetra
.3188 .4152 .3279 .42421 .34229 .41934 .33325 .41028 Mtetra
.33325 .41028 .34229 .41934 .35677 .41445 .34777 .40534 Mtetra
.34777 .40534 .35677 .41445 .37132 .40953 .36237 .40037 Mtetra
.36237 .40037 .37132 .40953 .38595 .40458 .37705 .39537 Mtetra
.37705 .39537 .38595 .40458 .40067 .3996 .39182 .39034 Mtetra
.39182 .39034 .40067 .3996 .41546 .3946 .40666 .38529 Mtetra
.40666 .38529 .41546 .3946 .43034 .38956 .42159 .3802 Mtetra
.663 .741 .908 r
.42159 .3802 .43034 .38956 .4453 .38451 .4366 .3751 Mtetra
.646 .736 .914 r
.4366 .3751 .4453 .38451 .46034 .37942 .45168 .37061 Mtetra
0 .38 .835 r
.45168 .37061 .46034 .37942 .47545 .37517 .46663 .37852 Mtetra
.861 .458 .27 r
.46663 .37852 .47545 .37517 .49046 .38876 .48143 .41258 Mtetra
0 0 .06 r
.48143 .41258 .49046 .38876 .50548 .44577 .49717 .39114 Mtetra
.73 .53 .62 r
.49717 .39114 .50548 .44577 .52128 .41963 .51291 .35375 Mtetra
.604 .429 .618 r
.51291 .35375 .52128 .41963 .53685 .36175 .52845 .34392 Mtetra
.646 .606 .795 r
.52845 .34392 .53685 .36175 .55237 .3485 .54406 .3385 Mtetra
.663 .737 .904 r
.54406 .3385 .55237 .3485 .56801 .343 .55977 .33315 Mtetra
.664 .741 .908 r
.55977 .33315 .56801 .343 .58375 .33768 .57556 .32778 Mtetra
.57556 .32778 .58375 .33768 .59957 .33233 .59144 .32237 Mtetra
.59144 .32237 .59957 .33233 .61548 .32695 .60741 .31693 Mtetra
.60741 .31693 .61548 .32695 .63148 .32154 .62347 .31146 Mtetra
.62347 .31146 .63148 .32154 .64757 .31609 .63963 .30596 Mtetra
.63963 .30596 .64757 .31609 .66376 .31062 .65588 .30043 Mtetra
.65588 .30043 .66376 .31062 .68004 .30511 .67223 .29486 Mtetra
.67223 .29486 .68004 .30511 .69642 .29957 .68867 .28926 Mtetra
.68867 .28926 .69642 .29957 .71289 .294 .7052 .28363 Mtetra
.7052 .28363 .71289 .294 .72945 .2884 .72183 .27797 Mtetra
.72183 .27797 .72945 .2884 .74611 .28276 .73856 .27227 Mtetra
.73856 .27227 .74611 .28276 .76287 .2771 .75539 .26654 Mtetra
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.2243 .43535 .23376 .44416 .24775 .4394 .23833 .43054 Mtetra
.23833 .43054 .24775 .4394 .2618 .43461 .25243 .4257 Mtetra
.25243 .4257 .2618 .43461 .27594 .4298 .26661 .42084 Mtetra
.26661 .42084 .27594 .4298 .29015 .42496 .28087 .41596 Mtetra
.28087 .41596 .29015 .42496 .30444 .42009 .2952 .41104 Mtetra
.2952 .41104 .30444 .42009 .3188 .4152 .30961 .4061 Mtetra
.30961 .4061 .3188 .4152 .33325 .41028 .32411 .40113 Mtetra
.32411 .40113 .33325 .41028 .34777 .40534 .33868 .39614 Mtetra
.33868 .39614 .34777 .40534 .36237 .40037 .35333 .39112 Mtetra
.35333 .39112 .36237 .40037 .37705 .39537 .36806 .38606 Mtetra
.36806 .38606 .37705 .39537 .39182 .39034 .38288 .38099 Mtetra
.38288 .38099 .39182 .39034 .40666 .38529 .39777 .37588 Mtetra
.663 .741 .908 r
.39777 .37588 .40666 .38529 .42159 .3802 .41275 .37075 Mtetra
.652 .738 .912 r
.41275 .37075 .42159 .3802 .4366 .3751 .4278 .36603 Mtetra
.302 .591 .945 r
.4278 .36603 .4366 .3751 .45168 .37061 .44274 .36924 Mtetra
.767 .261 0 r
.44274 .36924 .45168 .37061 .46663 .37852 .45753 .38682 Mtetra
.592 .878 .566 r
.45753 .38682 .46663 .37852 .48143 .41258 .47319 .37041 Mtetra
.708 .531 .647 r
.47319 .37041 .48143 .41258 .49717 .39114 .4889 .34705 Mtetra
.613 .464 .656 r
.4889 .34705 .49717 .39114 .51291 .35375 .50442 .33937 Mtetra
.655 .654 .837 r
.50442 .33937 .51291 .35375 .52845 .34392 .52 .33398 Mtetra
.663 .739 .906 r
.52 .33398 .52845 .34392 .54406 .3385 .53567 .32861 Mtetra
.664 .741 .908 r
.53567 .32861 .54406 .3385 .55977 .33315 .55143 .3232 Mtetra
.55143 .3232 .55977 .33315 .57556 .32778 .56728 .31777 Mtetra
.56728 .31777 .57556 .32778 .59144 .32237 .58322 .3123 Mtetra
.58322 .3123 .59144 .32237 .60741 .31693 .59926 .30681 Mtetra
.59926 .30681 .60741 .31693 .62347 .31146 .61538 .30128 Mtetra
.61538 .30128 .62347 .31146 .63963 .30596 .6316 .29572 Mtetra
.6316 .29572 .63963 .30596 .65588 .30043 .64792 .29013 Mtetra
.64792 .29013 .65588 .30043 .67223 .29486 .66433 .2845 Mtetra
.66433 .2845 .67223 .29486 .68867 .28926 .68083 .27884 Mtetra
.68083 .27884 .68867 .28926 .7052 .28363 .69743 .27315 Mtetra
.69743 .27315 .7052 .28363 .72183 .27797 .71413 .26743 Mtetra
.71413 .26743 .72183 .27797 .73856 .27227 .73093 .26167 Mtetra
.73093 .26167 .73856 .27227 .75539 .26654 .74783 .25587 Mtetra
.74783 .25587 .75539 .26654 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24418 Mtetra
.78193 .24418 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.21474 .42645 .2243 .43535 .23833 .43054 .22882 .42159 Mtetra
.22882 .42159 .23833 .43054 .25243 .4257 .24296 .41671 Mtetra
.24296 .41671 .25243 .4257 .26661 .42084 .25719 .4118 Mtetra
.25719 .4118 .26661 .42084 .28087 .41596 .27149 .40686 Mtetra
.27149 .40686 .28087 .41596 .2952 .41104 .28587 .4019 Mtetra
.28587 .4019 .2952 .41104 .30961 .4061 .30033 .39691 Mtetra
.30033 .39691 .30961 .4061 .32411 .40113 .31487 .39189 Mtetra
.31487 .39189 .32411 .40113 .33868 .39614 .32949 .38684 Mtetra
.32949 .38684 .33868 .39614 .35333 .39112 .34419 .38177 Mtetra
.34419 .38177 .35333 .39112 .36806 .38606 .35898 .37667 Mtetra
.35898 .37667 .36806 .38606 .38288 .38099 .37384 .37154 Mtetra
.663 .741 .908 r
.37384 .37154 .38288 .38099 .39777 .37588 .38879 .36638 Mtetra
.656 .739 .911 r
.38879 .36638 .39777 .37588 .41275 .37075 .40381 .36148 Mtetra
.491 .683 .951 r
.40381 .36148 .41275 .37075 .4278 .36603 .41877 .36122 Mtetra
0 .305 .685 r
.41877 .36122 .4278 .36603 .44274 .36924 .43364 .36815 Mtetra
.81 .965 .906 r
.43364 .36815 .44274 .36924 .45753 .38682 .44918 .35597 Mtetra
.693 .551 .688 r
.44918 .35597 .45753 .38682 .47319 .37041 .46478 .3413 Mtetra
.628 .519 .71 r
.46478 .3413 .47319 .37041 .4889 .34705 .48027 .33483 Mtetra
.66 .692 .869 r
.48027 .33483 .4889 .34705 .50442 .33937 .49582 .32943 Mtetra
.664 .74 .907 r
.49582 .32943 .50442 .33937 .52 .33398 .51146 .32404 Mtetra
.664 .741 .908 r
.51146 .32404 .52 .33398 .53567 .32861 .52719 .31861 Mtetra
.52719 .31861 .53567 .32861 .55143 .3232 .54301 .31315 Mtetra
.54301 .31315 .55143 .3232 .56728 .31777 .55892 .30766 Mtetra
.55892 .30766 .56728 .31777 .58322 .3123 .57492 .30213 Mtetra
.57492 .30213 .58322 .3123 .59926 .30681 .59101 .29658 Mtetra
.59101 .29658 .59926 .30681 .61538 .30128 .6072 .29099 Mtetra
.6072 .29099 .61538 .30128 .6316 .29572 .62349 .28537 Mtetra
.62349 .28537 .6316 .29572 .64792 .29013 .63987 .27972 Mtetra
.63987 .27972 .64792 .29013 .66433 .2845 .65634 .27403 Mtetra
.65634 .27403 .66433 .2845 .68083 .27884 .67291 .26831 Mtetra
.67291 .26831 .68083 .27884 .69743 .27315 .68958 .26256 Mtetra
.68958 .26256 .69743 .27315 .71413 .26743 .70635 .25677 Mtetra
.70635 .25677 .71413 .26743 .73093 .26167 .72322 .25095 Mtetra
.72322 .25095 .73093 .26167 .74783 .25587 .74019 .24509 Mtetra
.74019 .24509 .74783 .25587 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24418 .77443 .23327 Mtetra
.77443 .23327 .78193 .24418 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.20509 .41746 .21474 .42645 .22882 .42159 .21921 .41256 Mtetra
.21921 .41256 .22882 .42159 .24296 .41671 .2334 .40762 Mtetra
.2334 .40762 .24296 .41671 .25719 .4118 .24767 .40267 Mtetra
.24767 .40267 .25719 .4118 .27149 .40686 .26202 .39768 Mtetra
.26202 .39768 .27149 .40686 .28587 .4019 .27645 .39266 Mtetra
.27645 .39266 .28587 .4019 .30033 .39691 .29096 .38762 Mtetra
.29096 .38762 .30033 .39691 .31487 .39189 .30555 .38255 Mtetra
.30555 .38255 .31487 .39189 .32949 .38684 .32021 .37745 Mtetra
.32021 .37745 .32949 .38684 .34419 .38177 .33497 .37233 Mtetra
.33497 .37233 .34419 .38177 .35898 .37667 .3498 .36717 Mtetra
.663 .741 .908 r
.3498 .36717 .35898 .37667 .37384 .37154 .36472 .36199 Mtetra
.659 .74 .91 r
.36472 .36199 .37384 .37154 .38879 .36638 .37971 .35694 Mtetra
.583 .718 .936 r
.37971 .35694 .38879 .36638 .40381 .36148 .39468 .35439 Mtetra
.379 .692 .981 r
.39468 .35439 .40381 .36148 .41877 .36122 .40965 .3551 Mtetra
.758 .846 .917 r
.40965 .3551 .41877 .36122 .43364 .36815 .42507 .34594 Mtetra
.684 .589 .743 r
.42507 .34594 .43364 .36815 .44918 .35597 .44056 .33614 Mtetra
.645 .588 .776 r
.44056 .33614 .44918 .35597 .46478 .3413 .456 .33027 Mtetra
.662 .717 .889 r
.456 .33027 .46478 .3413 .48027 .33483 .47152 .32487 Mtetra
.664 .741 .908 r
.47152 .32487 .48027 .33483 .49582 .32943 .48713 .31945 Mtetra
.48713 .31945 .49582 .32943 .51146 .32404 .50282 .31399 Mtetra
.50282 .31399 .51146 .32404 .52719 .31861 .51861 .3085 Mtetra
.51861 .3085 .52719 .31861 .54301 .31315 .53449 .30298 Mtetra
.53449 .30298 .54301 .31315 .55892 .30766 .55046 .29743 Mtetra
.55046 .29743 .55892 .30766 .57492 .30213 .56653 .29185 Mtetra
.56653 .29185 .57492 .30213 .59101 .29658 .58268 .28624 Mtetra
.58268 .28624 .59101 .29658 .6072 .29099 .59894 .28059 Mtetra
.59894 .28059 .6072 .29099 .62349 .28537 .61528 .27491 Mtetra
.61528 .27491 .62349 .28537 .63987 .27972 .63173 .26919 Mtetra
.63173 .26919 .63987 .27972 .65634 .27403 .64827 .26344 Mtetra
.64827 .26344 .65634 .27403 .67291 .26831 .66491 .25766 Mtetra
.66491 .25766 .67291 .26831 .68958 .26256 .68164 .25184 Mtetra
.68164 .25184 .68958 .26256 .70635 .25677 .69848 .24599 Mtetra
.69848 .24599 .70635 .25677 .72322 .25095 .71542 .24011 Mtetra
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23418 Mtetra
.73246 .23418 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Mtetra
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .2162 Mtetra
.78419 .2162 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.19534 .40839 .20509 .41746 .21921 .41256 .2095 .40343 Mtetra
.2095 .40343 .21921 .41256 .2334 .40762 .22374 .39845 Mtetra
.22374 .39845 .2334 .40762 .24767 .40267 .23806 .39344 Mtetra
.23806 .39344 .24767 .40267 .26202 .39768 .25245 .3884 Mtetra
.25245 .3884 .26202 .39768 .27645 .39266 .26693 .38333 Mtetra
.26693 .38333 .27645 .39266 .29096 .38762 .28149 .37824 Mtetra
.28149 .37824 .29096 .38762 .30555 .38255 .29612 .37312 Mtetra
.29612 .37312 .30555 .38255 .32021 .37745 .31084 .36797 Mtetra
.31084 .36797 .32021 .37745 .33497 .37233 .32564 .36279 Mtetra
.32564 .36279 .33497 .37233 .3498 .36717 .34053 .35758 Mtetra
.661 .741 .909 r
.34053 .35758 .3498 .36717 .36472 .36199 .35549 .35243 Mtetra
.626 .732 .923 r
.35549 .35243 .36472 .36199 .37971 .35694 .37048 .34851 Mtetra
.574 .742 .956 r
.37048 .34851 .37971 .35694 .39468 .35439 .3855 .3459 Mtetra
.712 .782 .907 r
.3855 .3459 .39468 .35439 .40965 .3551 .40082 .33861 Mtetra
.678 .638 .802 r
.40082 .33861 .40965 .3551 .42507 .34594 .41621 .3313 Mtetra
.657 .653 .835 r
.41621 .3313 .42507 .34594 .44056 .33614 .43162 .3257 Mtetra
.663 .73 .899 r
.43162 .3257 .44056 .33614 .456 .33027 .4471 .32028 Mtetra
.664 .741 .908 r
.4471 .32028 .456 .33027 .47152 .32487 .46268 .31483 Mtetra
.46268 .31483 .47152 .32487 .48713 .31945 .47834 .30935 Mtetra
.47834 .30935 .48713 .31945 .50282 .31399 .4941 .30384 Mtetra
.4941 .30384 .50282 .31399 .51861 .3085 .50995 .29829 Mtetra
.50995 .29829 .51861 .3085 .53449 .30298 .52589 .29271 Mtetra
.52589 .29271 .53449 .30298 .55046 .29743 .54192 .2871 Mtetra
.54192 .2871 .55046 .29743 .56653 .29185 .55804 .28146 Mtetra
.55804 .28146 .56653 .29185 .58268 .28624 .57426 .27578 Mtetra
.57426 .27578 .58268 .28624 .59894 .28059 .59058 .27007 Mtetra
.59058 .27007 .59894 .28059 .61528 .27491 .60699 .26433 Mtetra
.60699 .26433 .61528 .27491 .63173 .26919 .6235 .25855 Mtetra
.6235 .25855 .63173 .26919 .64827 .26344 .64011 .25274 Mtetra
.64011 .25274 .64827 .26344 .66491 .25766 .65681 .24689 Mtetra
.65681 .24689 .66491 .25766 .68164 .25184 .67362 .24101 Mtetra
.67362 .24101 .68164 .25184 .69848 .24599 .69052 .2351 Mtetra
.69052 .2351 .69848 .24599 .71542 .24011 .70753 .22915 Mtetra
.70753 .22915 .71542 .24011 .73246 .23418 .72464 .22316 Mtetra
.72464 .22316 .73246 .23418 .7496 .22823 .74185 .21713 Mtetra
.74185 .21713 .7496 .22823 .76684 .22223 .75917 .21107 Mtetra
.75917 .21107 .76684 .22223 .78419 .2162 .77659 .20498 Mtetra
.77659 .20498 .78419 .2162 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.18549 .39922 .19534 .40839 .2095 .40343 .1997 .39421 Mtetra
.1997 .39421 .2095 .40343 .22374 .39845 .21398 .38918 Mtetra
.21398 .38918 .22374 .39845 .23806 .39344 .22835 .38411 Mtetra
.22835 .38411 .23806 .39344 .25245 .3884 .24279 .37903 Mtetra
.24279 .37903 .25245 .3884 .26693 .38333 .25731 .37391 Mtetra
.25731 .37391 .26693 .38333 .28149 .37824 .27192 .36876 Mtetra
.27192 .36876 .28149 .37824 .29612 .37312 .2866 .36359 Mtetra
.2866 .36359 .29612 .37312 .31084 .36797 .30137 .35838 Mtetra
.30137 .35838 .31084 .36797 .32564 .36279 .31622 .35315 Mtetra
.662 .741 .908 r
.31622 .35315 .32564 .36279 .34053 .35758 .33115 .34793 Mtetra
.647 .737 .915 r
.33115 .34793 .34053 .35758 .35549 .35243 .34614 .34326 Mtetra
.632 .745 .929 r
.34614 .34326 .35549 .35243 .37048 .34851 .36119 .33904 Mtetra
.686 .755 .904 r
.36119 .33904 .37048 .34851 .3855 .3459 .37643 .33278 Mtetra
.672 .683 .851 r
.37643 .33278 .3855 .3459 .40082 .33861 .39175 .32661 Mtetra
.662 .699 .874 r
.39175 .32661 .40082 .33861 .41621 .3313 .40712 .32112 Mtetra
.663 .737 .904 r
.40712 .32112 .41621 .3313 .43162 .3257 .42257 .31567 Mtetra
.664 .741 .908 r
.42257 .31567 .43162 .3257 .4471 .32028 .43811 .31019 Mtetra
.43811 .31019 .4471 .32028 .46268 .31483 .45374 .30469 Mtetra
.45374 .30469 .46268 .31483 .47834 .30935 .46947 .29915 Mtetra
.46947 .29915 .47834 .30935 .4941 .30384 .48528 .29357 Mtetra
.48528 .29357 .4941 .30384 .50995 .29829 .50119 .28797 Mtetra
.50119 .28797 .50995 .29829 .52589 .29271 .51719 .28233 Mtetra
.51719 .28233 .52589 .29271 .54192 .2871 .53328 .27666 Mtetra
.53328 .27666 .54192 .2871 .55804 .28146 .54947 .27095 Mtetra
.54947 .27095 .55804 .28146 .57426 .27578 .56575 .26522 Mtetra
.56575 .26522 .57426 .27578 .59058 .27007 .58213 .25944 Mtetra
.58213 .25944 .59058 .27007 .60699 .26433 .59861 .25364 Mtetra
.59861 .25364 .60699 .26433 .6235 .25855 .61518 .2478 Mtetra
.61518 .2478 .6235 .25855 .64011 .25274 .63185 .24192 Mtetra
.63185 .24192 .64011 .25274 .65681 .24689 .64863 .23601 Mtetra
.64863 .23601 .65681 .24689 .67362 .24101 .6655 .23006 Mtetra
.6655 .23006 .67362 .24101 .69052 .2351 .68248 .22408 Mtetra
.68248 .22408 .69052 .2351 .70753 .22915 .69955 .21806 Mtetra
.69955 .21806 .70753 .22915 .72464 .22316 .71674 .21201 Mtetra
.71674 .21201 .72464 .22316 .74185 .21713 .73402 .20592 Mtetra
.73402 .20592 .74185 .21713 .75917 .21107 .75141 .19979 Mtetra
.75141 .19979 .75917 .21107 .77659 .20498 .76891 .19362 Mtetra
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.17555 .38995 .18549 .39922 .1997 .39421 .1898 .3849 Mtetra
.1898 .3849 .1997 .39421 .21398 .38918 .20413 .37981 Mtetra
.20413 .37981 .21398 .38918 .22835 .38411 .21853 .3747 Mtetra
.21853 .3747 .22835 .38411 .24279 .37903 .23302 .36955 Mtetra
.23302 .36955 .24279 .37903 .25731 .37391 .2476 .36438 Mtetra
.2476 .36438 .25731 .37391 .27192 .36876 .26225 .35918 Mtetra
.26225 .35918 .27192 .36876 .2866 .36359 .27698 .35396 Mtetra
.27698 .35396 .2866 .36359 .30137 .35838 .2918 .3487 Mtetra
.663 .741 .908 r
.2918 .3487 .30137 .35838 .31622 .35315 .3067 .34343 Mtetra
.657 .74 .911 r
.3067 .34343 .31622 .35315 .33115 .34793 .32167 .33837 Mtetra
.653 .743 .916 r
.32167 .33837 .33115 .34793 .34614 .34326 .33672 .33344 Mtetra
.673 .745 .905 r
.33672 .33344 .34614 .34326 .36119 .33904 .3519 .32768 Mtetra
.668 .713 .882 r
.3519 .32768 .36119 .33904 .37643 .33278 .36716 .32198 Mtetra
.663 .724 .894 r
.36716 .32198 .37643 .33278 .39175 .32661 .3825 .31651 Mtetra
.663 .74 .907 r
.3825 .31651 .39175 .32661 .40712 .32112 .39792 .31104 Mtetra
.664 .741 .908 r
.39792 .31104 .40712 .32112 .42257 .31567 .41343 .30554 Mtetra
.41343 .30554 .42257 .31567 .43811 .31019 .42902 .3 Mtetra
.42902 .3 .43811 .31019 .45374 .30469 .44471 .29443 Mtetra
.44471 .29443 .45374 .30469 .46947 .29915 .4605 .28883 Mtetra
.4605 .28883 .46947 .29915 .48528 .29357 .47637 .2832 Mtetra
.47637 .2832 .48528 .29357 .50119 .28797 .49233 .27753 Mtetra
.49233 .27753 .50119 .28797 .51719 .28233 .50839 .27183 Mtetra
.50839 .27183 .51719 .28233 .53328 .27666 .52455 .2661 Mtetra
.52455 .2661 .53328 .27666 .54947 .27095 .5408 .26033 Mtetra
.5408 .26033 .54947 .27095 .56575 .26522 .55715 .25453 Mtetra
.55715 .25453 .56575 .26522 .58213 .25944 .57359 .2487 Mtetra
.57359 .2487 .58213 .25944 .59861 .25364 .59013 .24283 Mtetra
.59013 .24283 .59861 .25364 .61518 .2478 .60677 .23692 Mtetra
.60677 .23692 .61518 .2478 .63185 .24192 .62351 .23098 Mtetra
.62351 .23098 .63185 .24192 .64863 .23601 .64035 .225 Mtetra
.64035 .225 .64863 .23601 .6655 .23006 .6573 .21899 Mtetra
.6573 .21899 .6655 .23006 .68248 .22408 .67434 .21294 Mtetra
.67434 .21294 .68248 .22408 .69955 .21806 .69149 .20686 Mtetra
.69149 .20686 .69955 .21806 .71674 .21201 .70874 .20073 Mtetra
.70874 .20073 .71674 .21201 .73402 .20592 .7261 .19457 Mtetra
.7261 .19457 .73402 .20592 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Mtetra
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.1655 .38059 .17555 .38995 .1898 .3849 .17979 .37549 Mtetra
.17979 .37549 .1898 .3849 .20413 .37981 .19417 .37035 Mtetra
.19417 .37035 .20413 .37981 .21853 .3747 .20862 .36518 Mtetra
.20862 .36518 .21853 .3747 .23302 .36955 .22316 .35999 Mtetra
.22316 .35999 .23302 .36955 .2476 .36438 .23778 .35476 Mtetra
.23778 .35476 .2476 .36438 .26225 .35918 .25248 .34951 Mtetra
.25248 .34951 .26225 .35918 .27698 .35396 .26726 .34422 Mtetra
.663 .741 .908 r
.26726 .34422 .27698 .35396 .2918 .3487 .28213 .33892 Mtetra
.661 .741 .909 r
.28213 .33892 .2918 .3487 .3067 .34343 .29708 .33368 Mtetra
.66 .742 .911 r
.29708 .33368 .3067 .34343 .32167 .33837 .3121 .32845 Mtetra
.667 .742 .906 r
.3121 .32845 .32167 .33837 .33672 .33344 .32724 .3229 Mtetra
.665 .729 .897 r
.32724 .3229 .33672 .33344 .3519 .32768 .34246 .31736 Mtetra
.663 .735 .903 r
.34246 .31736 .3519 .32768 .36716 .32198 .35775 .31188 Mtetra
.664 .741 .907 r
.35775 .31188 .36716 .32198 .3825 .31651 .37314 .30638 Mtetra
.664 .741 .908 r
.37314 .30638 .3825 .31651 .39792 .31104 .38862 .30085 Mtetra
.38862 .30085 .39792 .31104 .41343 .30554 .40418 .29529 Mtetra
.40418 .29529 .41343 .30554 .42902 .3 .41984 .2897 Mtetra
.41984 .2897 .42902 .3 .44471 .29443 .43559 .28407 Mtetra
.43559 .28407 .44471 .29443 .4605 .28883 .45143 .27841 Mtetra
.45143 .27841 .4605 .28883 .47637 .2832 .46736 .27271 Mtetra
.46736 .27271 .47637 .2832 .49233 .27753 .48338 .26698 Mtetra
.48338 .26698 .49233 .27753 .50839 .27183 .49951 .26122 Mtetra
.49951 .26122 .50839 .27183 .52455 .2661 .51572 .25543 Mtetra
.51572 .25543 .52455 .2661 .5408 .26033 .53204 .2496 Mtetra
.53204 .2496 .5408 .26033 .55715 .25453 .54845 .24373 Mtetra
.54845 .24373 .55715 .25453 .57359 .2487 .56495 .23783 Mtetra
.56495 .23783 .57359 .2487 .59013 .24283 .58156 .2319 Mtetra
.58156 .2319 .59013 .24283 .60677 .23692 .59827 .22593 Mtetra
.59827 .22593 .60677 .23692 .62351 .23098 .61508 .21992 Mtetra
.61508 .21992 .62351 .23098 .64035 .225 .63199 .21388 Mtetra
.63199 .21388 .64035 .225 .6573 .21899 .649 .2078 Mtetra
.649 .2078 .6573 .21899 .67434 .21294 .66611 .20168 Mtetra
.66611 .20168 .67434 .21294 .69149 .20686 .68334 .19552 Mtetra
.68334 .19552 .69149 .20686 .70874 .20073 .70066 .18933 Mtetra
.70066 .18933 .70874 .20073 .7261 .19457 .71809 .1831 Mtetra
.71809 .1831 .7261 .19457 .74357 .18838 .73563 .17683 Mtetra
.73563 .17683 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.15534 .37114 .1655 .38059 .17979 .37549 .16968 .36598 Mtetra
.16968 .36598 .17979 .37549 .19417 .37035 .1841 .36079 Mtetra
.1841 .36079 .19417 .37035 .20862 .36518 .19861 .35557 Mtetra
.19861 .35557 .20862 .36518 .22316 .35999 .21319 .35032 Mtetra
.21319 .35032 .22316 .35999 .23778 .35476 .22786 .34504 Mtetra
.22786 .34504 .23778 .35476 .25248 .34951 .24261 .33973 Mtetra
.663 .741 .908 r
.24261 .33973 .25248 .34951 .26726 .34422 .25744 .33439 Mtetra
.25744 .33439 .26726 .34422 .28213 .33892 .27236 .32906 Mtetra
.662 .742 .909 r
.27236 .32906 .28213 .33892 .29708 .33368 .28736 .32371 Mtetra
.665 .741 .907 r
.28736 .32371 .29708 .33368 .3121 .32845 .30245 .31822 Mtetra
.664 .737 .904 r
.30245 .31822 .3121 .32845 .32724 .3229 .31763 .31273 Mtetra
.663 .739 .906 r
.31763 .31273 .32724 .3229 .34246 .31736 .33289 .30723 Mtetra
.664 .741 .908 r
.33289 .30723 .34246 .31736 .35775 .31188 .34825 .30171 Mtetra
.34825 .30171 .35775 .31188 .37314 .30638 .36369 .29615 Mtetra
.36369 .29615 .37314 .30638 .38862 .30085 .37922 .29056 Mtetra
.37922 .29056 .38862 .30085 .40418 .29529 .39484 .28494 Mtetra
.39484 .28494 .40418 .29529 .41984 .2897 .41055 .27928 Mtetra
.41055 .27928 .41984 .2897 .43559 .28407 .42636 .27359 Mtetra
.42636 .27359 .43559 .28407 .45143 .27841 .44226 .26787 Mtetra
.44226 .26787 .45143 .27841 .46736 .27271 .45825 .26211 Mtetra
.45825 .26211 .46736 .27271 .48338 .26698 .47434 .25632 Mtetra
.47434 .25632 .48338 .26698 .49951 .26122 .49052 .2505 Mtetra
.49052 .2505 .49951 .26122 .51572 .25543 .5068 .24464 Mtetra
.5068 .24464 .51572 .25543 .53204 .2496 .52318 .23874 Mtetra
.52318 .23874 .53204 .2496 .54845 .24373 .53965 .23281 Mtetra
.53965 .23281 .54845 .24373 .56495 .23783 .55622 .22685 Mtetra
.55622 .22685 .56495 .23783 .58156 .2319 .5729 .22085 Mtetra
.5729 .22085 .58156 .2319 .59827 .22593 .58967 .21481 Mtetra
.58967 .21481 .59827 .22593 .61508 .21992 .60655 .20873 Mtetra
.60655 .20873 .61508 .21992 .63199 .21388 .62353 .20262 Mtetra
.62353 .20262 .63199 .21388 .649 .2078 .64061 .19647 Mtetra
.64061 .19647 .649 .2078 .66611 .20168 .6578 .19029 Mtetra
.6578 .19029 .66611 .20168 .68334 .19552 .67509 .18406 Mtetra
.67509 .18406 .68334 .19552 .70066 .18933 .69249 .1778 Mtetra
.69249 .1778 .70066 .18933 .71809 .1831 .70999 .1715 Mtetra
.70999 .1715 .71809 .1831 .73563 .17683 .72761 .16516 Mtetra
.72761 .16516 .73563 .17683 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.14508 .36159 .15534 .37114 .16968 .36598 .15947 .35637 Mtetra
.15947 .35637 .16968 .36598 .1841 .36079 .17394 .35113 Mtetra
.17394 .35113 .1841 .36079 .19861 .35557 .18849 .34585 Mtetra
.18849 .34585 .19861 .35557 .21319 .35032 .20312 .34055 Mtetra
.20312 .34055 .21319 .35032 .22786 .34504 .21783 .33521 Mtetra
.21783 .33521 .22786 .34504 .24261 .33973 .23263 .32985 Mtetra
.663 .741 .908 r
.23263 .32985 .24261 .33973 .25744 .33439 .24751 .32447 Mtetra
.24751 .32447 .25744 .33439 .27236 .32906 .26248 .31905 Mtetra
.664 .741 .908 r
.26248 .31905 .27236 .32906 .28736 .32371 .27754 .31358 Mtetra
.664 .74 .907 r
.27754 .31358 .28736 .32371 .30245 .31822 .29268 .30808 Mtetra
.664 .741 .907 r
.29268 .30808 .30245 .31822 .31763 .31273 .30791 .30256 Mtetra
.664 .741 .908 r
.30791 .30256 .31763 .31273 .33289 .30723 .32323 .29701 Mtetra
.32323 .29701 .33289 .30723 .34825 .30171 .33863 .29142 Mtetra
.33863 .29142 .34825 .30171 .36369 .29615 .35413 .2858 Mtetra
.35413 .2858 .36369 .29615 .37922 .29056 .36972 .28015 Mtetra
.36972 .28015 .37922 .29056 .39484 .28494 .3854 .27447 Mtetra
.3854 .27447 .39484 .28494 .41055 .27928 .40117 .26875 Mtetra
.40117 .26875 .41055 .27928 .42636 .27359 .41703 .263 Mtetra
.41703 .263 .42636 .27359 .44226 .26787 .43299 .25721 Mtetra
.43299 .25721 .44226 .26787 .45825 .26211 .44904 .25139 Mtetra
.44904 .25139 .45825 .26211 .47434 .25632 .46519 .24554 Mtetra
.46519 .24554 .47434 .25632 .49052 .2505 .48143 .23965 Mtetra
.48143 .23965 .49052 .2505 .5068 .24464 .49778 .23373 Mtetra
.49778 .23373 .5068 .24464 .52318 .23874 .51422 .22777 Mtetra
.51422 .22777 .52318 .23874 .53965 .23281 .53076 .22177 Mtetra
.53076 .22177 .53965 .23281 .55622 .22685 .5474 .21574 Mtetra
.5474 .21574 .55622 .22685 .5729 .22085 .56414 .20967 Mtetra
.56414 .20967 .5729 .22085 .58967 .21481 .58098 .20357 Mtetra
.58098 .20357 .58967 .21481 .60655 .20873 .59792 .19742 Mtetra
.59792 .19742 .60655 .20873 .62353 .20262 .61497 .19124 Mtetra
.61497 .19124 .62353 .20262 .64061 .19647 .63212 .18502 Mtetra
.63212 .18502 .64061 .19647 .6578 .19029 .64938 .17877 Mtetra
.64938 .17877 .6578 .19029 .67509 .18406 .66675 .17247 Mtetra
.66675 .17247 .67509 .18406 .69249 .1778 .68422 .16614 Mtetra
.68422 .16614 .69249 .1778 .70999 .1715 .7018 .15976 Mtetra
.7018 .15976 .70999 .1715 .72761 .16516 .71949 .15335 Mtetra
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Mtetra
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.13472 .35194 .14508 .36159 .15947 .35637 .14915 .34667 Mtetra
.14915 .34667 .15947 .35637 .17394 .35113 .16366 .34137 Mtetra
.16366 .34137 .17394 .35113 .18849 .34585 .17826 .33604 Mtetra
.17826 .33604 .18849 .34585 .20312 .34055 .19294 .33068 Mtetra
.19294 .33068 .20312 .34055 .21783 .33521 .2077 .32529 Mtetra
.663 .741 .908 r
.2077 .32529 .21783 .33521 .23263 .32985 .22255 .31987 Mtetra
.22255 .31987 .23263 .32985 .24751 .32447 .23748 .31442 Mtetra
.664 .741 .908 r
.23748 .31442 .24751 .32447 .26248 .31905 .2525 .30893 Mtetra
.664 .741 .907 r
.2525 .30893 .26248 .31905 .27754 .31358 .26761 .30341 Mtetra
.664 .741 .908 r
.26761 .30341 .27754 .31358 .29268 .30808 .2828 .29786 Mtetra
.2828 .29786 .29268 .30808 .30791 .30256 .29809 .29228 Mtetra
.29809 .29228 .30791 .30256 .32323 .29701 .31346 .28667 Mtetra
.31346 .28667 .32323 .29701 .33863 .29142 .32892 .28102 Mtetra
.32892 .28102 .33863 .29142 .35413 .2858 .34447 .27534 Mtetra
.34447 .27534 .35413 .2858 .36972 .28015 .36011 .26963 Mtetra
.36011 .26963 .36972 .28015 .3854 .27447 .37585 .26389 Mtetra
.37585 .26389 .3854 .27447 .40117 .26875 .39168 .25811 Mtetra
.39168 .25811 .40117 .26875 .41703 .263 .4076 .25229 Mtetra
.4076 .25229 .41703 .263 .43299 .25721 .42362 .24644 Mtetra
.42362 .24644 .43299 .25721 .44904 .25139 .43973 .24056 Mtetra
.43973 .24056 .44904 .25139 .46519 .24554 .45594 .23464 Mtetra
.45594 .23464 .46519 .24554 .48143 .23965 .47225 .22869 Mtetra
.47225 .22869 .48143 .23965 .49778 .23373 .48865 .2227 Mtetra
.48865 .2227 .49778 .23373 .51422 .22777 .50516 .21667 Mtetra
.50516 .21667 .51422 .22777 .53076 .22177 .52176 .21061 Mtetra
.52176 .21061 .53076 .22177 .5474 .21574 .53847 .20451 Mtetra
.53847 .20451 .5474 .21574 .56414 .20967 .55527 .19837 Mtetra
.55527 .19837 .56414 .20967 .58098 .20357 .57218 .1922 Mtetra
.57218 .1922 .58098 .20357 .59792 .19742 .5892 .18598 Mtetra
.5892 .18598 .59792 .19742 .61497 .19124 .60632 .17973 Mtetra
.60632 .17973 .61497 .19124 .63212 .18502 .62354 .17344 Mtetra
.62354 .17344 .63212 .18502 .64938 .17877 .64087 .16711 Mtetra
.64087 .16711 .64938 .17877 .66675 .17247 .65831 .16075 Mtetra
.65831 .16075 .66675 .17247 .68422 .16614 .67586 .15434 Mtetra
.67586 .15434 .68422 .16614 .7018 .15976 .69351 .14789 Mtetra
.69351 .14789 .7018 .15976 .71949 .15335 .71128 .14141 Mtetra
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Mtetra
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Mtetra
.12424 .34218 .13472 .35194 .14915 .34667 .13872 .33686 Mtetra
.13872 .33686 .14915 .34667 .16366 .34137 .15328 .3315 Mtetra
.15328 .3315 .16366 .34137 .17826 .33604 .16793 .32612 Mtetra
.16793 .32612 .17826 .33604 .19294 .33068 .18265 .3207 Mtetra
.18265 .3207 .19294 .33068 .2077 .32529 .19747 .31525 Mtetra
.19747 .31525 .2077 .32529 .22255 .31987 .21236 .30977 Mtetra
.21236 .30977 .22255 .31987 .23748 .31442 .22735 .30426 Mtetra
.22735 .30426 .23748 .31442 .2525 .30893 .24242 .29872 Mtetra
.24242 .29872 .2525 .30893 .26761 .30341 .25758 .29314 Mtetra
.25758 .29314 .26761 .30341 .2828 .29786 .27282 .28753 Mtetra
.27282 .28753 .2828 .29786 .29809 .29228 .28816 .28189 Mtetra
.28816 .28189 .29809 .29228 .31346 .28667 .30358 .27622 Mtetra
.30358 .27622 .31346 .28667 .32892 .28102 .3191 .27051 Mtetra
.3191 .27051 .32892 .28102 .34447 .27534 .33471 .26477 Mtetra
.33471 .26477 .34447 .27534 .36011 .26963 .35041 .259 Mtetra
.35041 .259 .36011 .26963 .37585 .26389 .3662 .25319 Mtetra
.3662 .25319 .37585 .26389 .39168 .25811 .38209 .24735 Mtetra
.38209 .24735 .39168 .25811 .4076 .25229 .39807 .24147 Mtetra
.39807 .24147 .4076 .25229 .42362 .24644 .41415 .23555 Mtetra
.41415 .23555 .42362 .24644 .43973 .24056 .43032 .22961 Mtetra
.43032 .22961 .43973 .24056 .45594 .23464 .44659 .22362 Mtetra
.44659 .22362 .45594 .23464 .47225 .22869 .46296 .2176 Mtetra
.46296 .2176 .47225 .22869 .48865 .2227 .47943 .21154 Mtetra
.47943 .21154 .48865 .2227 .50516 .21667 .496 .20545 Mtetra
.496 .20545 .50516 .21667 .52176 .21061 .51267 .19932 Mtetra
.51267 .19932 .52176 .21061 .53847 .20451 .52944 .19315 Mtetra
.52944 .19315 .53847 .20451 .55527 .19837 .54631 .18694 Mtetra
.54631 .18694 .55527 .19837 .57218 .1922 .56329 .1807 Mtetra
.56329 .1807 .57218 .1922 .5892 .18598 .58037 .17441 Mtetra
.58037 .17441 .5892 .18598 .60632 .17973 .59756 .16809 Mtetra
.59756 .16809 .60632 .17973 .62354 .17344 .61486 .16173 Mtetra
.61486 .16173 .62354 .17344 .64087 .16711 .63226 .15533 Mtetra
.63226 .15533 .64087 .16711 .65831 .16075 .64977 .14889 Mtetra
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Mtetra
.6674 .14241 .67586 .15434 .69351 .14789 .68513 .13588 Mtetra
.68513 .13588 .69351 .14789 .71128 .14141 .70297 .12932 Mtetra
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.11366 .33233 .12424 .34218 .13872 .33686 .12818 .32695 Mtetra
.12818 .32695 .13872 .33686 .15328 .3315 .14279 .32154 Mtetra
.14279 .32154 .15328 .3315 .16793 .32612 .15748 .31609 Mtetra
.15748 .31609 .16793 .32612 .18265 .3207 .17226 .31062 Mtetra
.17226 .31062 .18265 .3207 .19747 .31525 .18712 .30511 Mtetra
.18712 .30511 .19747 .31525 .21236 .30977 .20207 .29957 Mtetra
.20207 .29957 .21236 .30977 .22735 .30426 .2171 .294 Mtetra
.2171 .294 .22735 .30426 .24242 .29872 .23222 .2884 Mtetra
.23222 .2884 .24242 .29872 .25758 .29314 .24743 .28276 Mtetra
.24743 .28276 .25758 .29314 .27282 .28753 .26273 .2771 Mtetra
.26273 .2771 .27282 .28753 .28816 .28189 .27812 .27139 Mtetra
.27812 .27139 .28816 .28189 .30358 .27622 .2936 .26566 Mtetra
.2936 .26566 .30358 .27622 .3191 .27051 .30917 .25989 Mtetra
.30917 .25989 .3191 .27051 .33471 .26477 .32484 .25409 Mtetra
.32484 .25409 .33471 .26477 .35041 .259 .34059 .24825 Mtetra
.34059 .24825 .35041 .259 .3662 .25319 .35644 .24237 Mtetra
.35644 .24237 .3662 .25319 .38209 .24735 .37239 .23647 Mtetra
.37239 .23647 .38209 .24735 .39807 .24147 .38843 .23052 Mtetra
.38843 .23052 .39807 .24147 .41415 .23555 .40457 .22454 Mtetra
.40457 .22454 .41415 .23555 .43032 .22961 .4208 .21853 Mtetra
.4208 .21853 .43032 .22961 .44659 .22362 .43714 .21248 Mtetra
.43714 .21248 .44659 .22362 .46296 .2176 .45357 .20639 Mtetra
.45357 .20639 .46296 .2176 .47943 .21154 .4701 .20026 Mtetra
.4701 .20026 .47943 .21154 .496 .20545 .48673 .1941 Mtetra
.48673 .1941 .496 .20545 .51267 .19932 .50347 .1879 Mtetra
.50347 .1879 .51267 .19932 .52944 .19315 .52031 .18166 Mtetra
.52031 .18166 .52944 .19315 .54631 .18694 .53725 .17538 Mtetra
.53725 .17538 .54631 .18694 .56329 .1807 .5543 .16907 Mtetra
.5543 .16907 .56329 .1807 .58037 .17441 .57145 .16271 Mtetra
.57145 .16271 .58037 .17441 .59756 .16809 .58871 .15632 Mtetra
.58871 .15632 .59756 .16809 .61486 .16173 .60608 .14988 Mtetra
.60608 .14988 .61486 .16173 .63226 .15533 .62355 .14341 Mtetra
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Mtetra
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Mtetra
.65884 .13033 .6674 .14241 .68513 .13588 .67665 .12373 Mtetra
.67665 .12373 .68513 .13588 .70297 .12932 .69457 .11709 Mtetra
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.10296 .32237 .11366 .33233 .12818 .32695 .11753 .31693 Mtetra
.11753 .31693 .12818 .32695 .14279 .32154 .13219 .31146 Mtetra
.13219 .31146 .14279 .32154 .15748 .31609 .14693 .30596 Mtetra
.14693 .30596 .15748 .31609 .17226 .31062 .16175 .30043 Mtetra
.16175 .30043 .17226 .31062 .18712 .30511 .17666 .29486 Mtetra
.17666 .29486 .18712 .30511 .20207 .29957 .19166 .28926 Mtetra
.19166 .28926 .20207 .29957 .2171 .294 .20674 .28363 Mtetra
.20674 .28363 .2171 .294 .23222 .2884 .22192 .27797 Mtetra
.22192 .27797 .23222 .2884 .24743 .28276 .23718 .27227 Mtetra
.23718 .27227 .24743 .28276 .26273 .2771 .25253 .26654 Mtetra
.25253 .26654 .26273 .2771 .27812 .27139 .26797 .26078 Mtetra
.26797 .26078 .27812 .27139 .2936 .26566 .28351 .25498 Mtetra
.28351 .25498 .2936 .26566 .30917 .25989 .29914 .24915 Mtetra
.29914 .24915 .30917 .25989 .32484 .25409 .31485 .24328 Mtetra
.31485 .24328 .32484 .25409 .34059 .24825 .33067 .23738 Mtetra
.33067 .23738 .34059 .24825 .35644 .24237 .34658 .23144 Mtetra
.34658 .23144 .35644 .24237 .37239 .23647 .36258 .22547 Mtetra
.36258 .22547 .37239 .23647 .38843 .23052 .37868 .21946 Mtetra
.37868 .21946 .38843 .23052 .40457 .22454 .39488 .21341 Mtetra
.39488 .21341 .40457 .22454 .4208 .21853 .41118 .20733 Mtetra
.41118 .20733 .4208 .21853 .43714 .21248 .42757 .20121 Mtetra
.42757 .20121 .43714 .21248 .45357 .20639 .44407 .19505 Mtetra
.44407 .19505 .45357 .20639 .4701 .20026 .46067 .18886 Mtetra
.46067 .18886 .4701 .20026 .48673 .1941 .47737 .18262 Mtetra
.47737 .18262 .48673 .1941 .50347 .1879 .49417 .17635 Mtetra
.49417 .17635 .50347 .1879 .52031 .18166 .51107 .17004 Mtetra
.51107 .17004 .52031 .18166 .53725 .17538 .52808 .16369 Mtetra
.52808 .16369 .53725 .17538 .5543 .16907 .5452 .1573 Mtetra
.5452 .1573 .5543 .16907 .57145 .16271 .56242 .15087 Mtetra
.56242 .15087 .57145 .16271 .58871 .15632 .57976 .1444 Mtetra
.57976 .1444 .58871 .15632 .60608 .14988 .5972 .1379 Mtetra
.5972 .1379 .60608 .14988 .62355 .14341 .61475 .13134 Mtetra
.61475 .13134 .62355 .14341 .64114 .13689 .63241 .12475 Mtetra
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Mtetra
.65018 .11812 .65884 .13033 .67665 .12373 .66806 .11144 Mtetra
.66806 .11144 .67665 .12373 .69457 .11709 .68606 .10472 Mtetra
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Mtetra
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.09215 .3123 .10296 .32237 .11753 .31693 .10677 .30681 Mtetra
.10677 .30681 .11753 .31693 .13219 .31146 .12147 .30128 Mtetra
.12147 .30128 .13219 .31146 .14693 .30596 .13626 .29572 Mtetra
.13626 .29572 .14693 .30596 .16175 .30043 .15113 .29013 Mtetra
.15113 .29013 .16175 .30043 .17666 .29486 .16609 .2845 Mtetra
.16609 .2845 .17666 .29486 .19166 .28926 .18114 .27884 Mtetra
.18114 .27884 .19166 .28926 .20674 .28363 .19627 .27315 Mtetra
.19627 .27315 .20674 .28363 .22192 .27797 .2115 .26743 Mtetra
.2115 .26743 .22192 .27797 .23718 .27227 .22681 .26167 Mtetra
.22681 .26167 .23718 .27227 .25253 .26654 .24222 .25587 Mtetra
.24222 .25587 .25253 .26654 .26797 .26078 .25772 .25005 Mtetra
.25772 .25005 .26797 .26078 .28351 .25498 .27331 .24418 Mtetra
.27331 .24418 .28351 .25498 .29914 .24915 .28899 .23829 Mtetra
.28899 .23829 .29914 .24915 .31485 .24328 .30476 .23236 Mtetra
.30476 .23236 .31485 .24328 .33067 .23738 .32064 .22639 Mtetra
.32064 .22639 .33067 .23738 .34658 .23144 .3366 .22038 Mtetra
.3366 .22038 .34658 .23144 .36258 .22547 .35267 .21434 Mtetra
.35267 .21434 .36258 .22547 .37868 .21946 .36883 .20827 Mtetra
.36883 .20827 .37868 .21946 .39488 .21341 .38509 .20215 Mtetra
.38509 .20215 .39488 .21341 .41118 .20733 .40145 .196 Mtetra
.40145 .196 .41118 .20733 .42757 .20121 .4179 .18981 Mtetra
.4179 .18981 .42757 .20121 .44407 .19505 .43446 .18358 Mtetra
.43446 .18358 .44407 .19505 .46067 .18886 .45113 .17732 Mtetra
.45113 .17732 .46067 .18886 .47737 .18262 .46789 .17101 Mtetra
.46789 .17101 .47737 .18262 .49417 .17635 .48476 .16467 Mtetra
.48476 .16467 .49417 .17635 .51107 .17004 .50173 .15829 Mtetra
.50173 .15829 .51107 .17004 .52808 .16369 .51881 .15187 Mtetra
.51881 .15187 .52808 .16369 .5452 .1573 .536 .1454 Mtetra
.536 .1454 .5452 .1573 .56242 .15087 .55329 .1389 Mtetra
.55329 .1389 .56242 .15087 .57976 .1444 .5707 .13236 Mtetra
.5707 .13236 .57976 .1444 .5972 .1379 .58821 .12577 Mtetra
.58821 .12577 .5972 .1379 .61475 .13134 .60583 .11914 Mtetra
.60583 .11914 .61475 .13134 .63241 .12475 .62357 .11247 Mtetra
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Mtetra
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Mtetra
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Mtetra
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Mtetra
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.08123 .30213 .09215 .3123 .10677 .30681 .09589 .29658 Mtetra
.09589 .29658 .10677 .30681 .12147 .30128 .11064 .29099 Mtetra
.11064 .29099 .12147 .30128 .13626 .29572 .12548 .28537 Mtetra
.12548 .28537 .13626 .29572 .15113 .29013 .1404 .27972 Mtetra
.1404 .27972 .15113 .29013 .16609 .2845 .15541 .27403 Mtetra
.15541 .27403 .16609 .2845 .18114 .27884 .1705 .26831 Mtetra
.1705 .26831 .18114 .27884 .19627 .27315 .18569 .26256 Mtetra
.18569 .26256 .19627 .27315 .2115 .26743 .20097 .25677 Mtetra
.20097 .25677 .2115 .26743 .22681 .26167 .21634 .25095 Mtetra
.21634 .25095 .22681 .26167 .24222 .25587 .23179 .24509 Mtetra
.23179 .24509 .24222 .25587 .25772 .25005 .24735 .2392 Mtetra
.24735 .2392 .25772 .25005 .27331 .24418 .26299 .23327 Mtetra
.26299 .23327 .27331 .24418 .28899 .23829 .27873 .22731 Mtetra
.27873 .22731 .28899 .23829 .30476 .23236 .29456 .22131 Mtetra
.29456 .22131 .30476 .23236 .32064 .22639 .31049 .21527 Mtetra
.31049 .21527 .32064 .22639 .3366 .22038 .32652 .2092 Mtetra
.32652 .2092 .3366 .22038 .35267 .21434 .34264 .20309 Mtetra
.34264 .20309 .35267 .21434 .36883 .20827 .35886 .19695 Mtetra
.35886 .19695 .36883 .20827 .38509 .20215 .37518 .19077 Mtetra
.37518 .19077 .38509 .20215 .40145 .196 .3916 .18454 Mtetra
.3916 .18454 .40145 .196 .4179 .18981 .40812 .17828 Mtetra
.40812 .17828 .4179 .18981 .43446 .18358 .42475 .17199 Mtetra
.42475 .17199 .43446 .18358 .45113 .17732 .44148 .16565 Mtetra
.44148 .16565 .45113 .17732 .46789 .17101 .45831 .15927 Mtetra
.45831 .15927 .46789 .17101 .48476 .16467 .47524 .15286 Mtetra
.47524 .15286 .48476 .16467 .50173 .15829 .49228 .1464 Mtetra
.49228 .1464 .50173 .15829 .51881 .15187 .50943 .1399 Mtetra
.50943 .1399 .51881 .15187 .536 .1454 .52669 .13336 Mtetra
.52669 .13336 .536 .1454 .55329 .1389 .54406 .12679 Mtetra
.54406 .12679 .55329 .1389 .5707 .13236 .56153 .12016 Mtetra
.56153 .12016 .5707 .13236 .58821 .12577 .57912 .1135 Mtetra
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Mtetra
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Mtetra
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Mtetra
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Mtetra
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Mtetra
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Mtetra
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Mtetra
.07019 .29185 .08123 .30213 .09589 .29658 .0849 .28624 Mtetra
.0849 .28624 .09589 .29658 .11064 .29099 .09969 .28059 Mtetra
.09969 .28059 .11064 .29099 .12548 .28537 .11458 .27491 Mtetra
.11458 .27491 .12548 .28537 .1404 .27972 .12955 .26919 Mtetra
.12955 .26919 .1404 .27972 .15541 .27403 .14461 .26344 Mtetra
.14461 .26344 .15541 .27403 .1705 .26831 .15975 .25766 Mtetra
.15975 .25766 .1705 .26831 .18569 .26256 .17499 .25184 Mtetra
.17499 .25184 .18569 .26256 .20097 .25677 .19032 .24599 Mtetra
.19032 .24599 .20097 .25677 .21634 .25095 .20574 .24011 Mtetra
.20574 .24011 .21634 .25095 .23179 .24509 .22125 .23418 Mtetra
.22125 .23418 .23179 .24509 .24735 .2392 .23686 .22823 Mtetra
.23686 .22823 .24735 .2392 .26299 .23327 .25256 .22223 Mtetra
.25256 .22223 .26299 .23327 .27873 .22731 .26835 .2162 Mtetra
.26835 .2162 .27873 .22731 .29456 .22131 .28424 .21014 Mtetra
.28424 .21014 .29456 .22131 .31049 .21527 .30023 .20404 Mtetra
.30023 .20404 .31049 .21527 .32652 .2092 .31632 .1979 Mtetra
.31632 .1979 .32652 .2092 .34264 .20309 .3325 .19172 Mtetra
.3325 .19172 .34264 .20309 .35886 .19695 .34878 .1855 Mtetra
.34878 .1855 .35886 .19695 .37518 .19077 .36516 .17925 Mtetra
.36516 .17925 .37518 .19077 .3916 .18454 .38165 .17296 Mtetra
.38165 .17296 .3916 .18454 .40812 .17828 .39823 .16663 Mtetra
.39823 .16663 .40812 .17828 .42475 .17199 .41492 .16026 Mtetra
.41492 .16026 .42475 .17199 .44148 .16565 .43171 .15385 Mtetra
.43171 .15385 .44148 .16565 .45831 .15927 .44861 .1474 Mtetra
.44861 .1474 .45831 .15927 .47524 .15286 .46562 .1409 Mtetra
.46562 .1409 .47524 .15286 .49228 .1464 .48273 .13437 Mtetra
.48273 .13437 .49228 .1464 .50943 .1399 .49994 .1278 Mtetra
.49994 .1278 .50943 .1399 .52669 .13336 .51727 .12119 Mtetra
.51727 .12119 .52669 .13336 .54406 .12679 .53471 .11453 Mtetra
.53471 .11453 .54406 .12679 .56153 .12016 .55226 .10783 Mtetra
.55226 .10783 .56153 .12016 .57912 .1135 .56992 .10109 Mtetra
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Mtetra
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Mtetra
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Mtetra
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Mtetra
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Mtetra
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Mtetra
.05902 .28146 .07019 .29185 .0849 .28624 .07378 .27578 Mtetra
.07378 .27578 .0849 .28624 .09969 .28059 .08863 .27007 Mtetra
.08863 .27007 .09969 .28059 .11458 .27491 .10356 .26433 Mtetra
.10356 .26433 .11458 .27491 .12955 .26919 .11858 .25855 Mtetra
.11858 .25855 .12955 .26919 .14461 .26344 .13369 .25274 Mtetra
.13369 .25274 .14461 .26344 .15975 .25766 .14889 .24689 Mtetra
.14889 .24689 .15975 .25766 .17499 .25184 .16417 .24101 Mtetra
.16417 .24101 .17499 .25184 .19032 .24599 .17956 .2351 Mtetra
.17956 .2351 .19032 .24599 .20574 .24011 .19503 .22915 Mtetra
.19503 .22915 .20574 .24011 .22125 .23418 .2106 .22316 Mtetra
.2106 .22316 .22125 .23418 .23686 .22823 .22626 .21713 Mtetra
.22626 .21713 .23686 .22823 .25256 .22223 .24201 .21107 Mtetra
.24201 .21107 .25256 .22223 .26835 .2162 .25786 .20498 Mtetra
.25786 .20498 .26835 .2162 .28424 .21014 .27381 .19884 Mtetra
.27381 .19884 .28424 .21014 .30023 .20404 .28986 .19267 Mtetra
.28986 .19267 .30023 .20404 .31632 .1979 .306 .18646 Mtetra
.306 .18646 .31632 .1979 .3325 .19172 .32224 .18021 Mtetra
.32224 .18021 .3325 .19172 .34878 .1855 .33859 .17393 Mtetra
.33859 .17393 .34878 .1855 .36516 .17925 .35503 .1676 Mtetra
.35503 .1676 .36516 .17925 .38165 .17296 .37158 .16124 Mtetra
.37158 .16124 .38165 .17296 .39823 .16663 .38823 .15483 Mtetra
.38823 .15483 .39823 .16663 .41492 .16026 .40498 .14839 Mtetra
.40498 .14839 .41492 .16026 .43171 .15385 .42184 .14191 Mtetra
.42184 .14191 .43171 .15385 .44861 .1474 .4388 .13538 Mtetra
.4388 .13538 .44861 .1474 .46562 .1409 .45588 .12881 Mtetra
.45588 .12881 .46562 .1409 .48273 .13437 .47306 .12221 Mtetra
.47306 .12221 .48273 .13437 .49994 .1278 .49034 .11556 Mtetra
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Mtetra
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Mtetra
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Mtetra
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Mtetra
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Mtetra
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Mtetra
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Mtetra
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Mtetra
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Mtetra
.04774 .27095 .05902 .28146 .07378 .27578 .06255 .26522 Mtetra
.06255 .26522 .07378 .27578 .08863 .27007 .07744 .25944 Mtetra
.07744 .25944 .08863 .27007 .10356 .26433 .09242 .25364 Mtetra
.09242 .25364 .10356 .26433 .11858 .25855 .10749 .2478 Mtetra
.10749 .2478 .11858 .25855 .13369 .25274 .12265 .24192 Mtetra
.12265 .24192 .13369 .25274 .14889 .24689 .1379 .23601 Mtetra
.1379 .23601 .14889 .24689 .16417 .24101 .15324 .23006 Mtetra
.15324 .23006 .16417 .24101 .17956 .2351 .16867 .22408 Mtetra
.16867 .22408 .17956 .2351 .19503 .22915 .1842 .21806 Mtetra
.1842 .21806 .19503 .22915 .2106 .22316 .19982 .21201 Mtetra
.19982 .21201 .2106 .22316 .22626 .21713 .21553 .20592 Mtetra
.21553 .20592 .22626 .21713 .24201 .21107 .23135 .19979 Mtetra
.23135 .19979 .24201 .21107 .25786 .20498 .24725 .19362 Mtetra
.24725 .19362 .25786 .20498 .27381 .19884 .26326 .18742 Mtetra
.26326 .18742 .27381 .19884 .28986 .19267 .27936 .18118 Mtetra
.27936 .18118 .28986 .19267 .306 .18646 .29557 .1749 Mtetra
.29557 .1749 .306 .18646 .32224 .18021 .31187 .16858 Mtetra
.31187 .16858 .32224 .18021 .33859 .17393 .32828 .16222 Mtetra
.32828 .16222 .33859 .17393 .35503 .1676 .34478 .15582 Mtetra
.34478 .15582 .35503 .1676 .37158 .16124 .36139 .14938 Mtetra
.36139 .14938 .37158 .16124 .38823 .15483 .37811 .14291 Mtetra
.37811 .14291 .38823 .15483 .40498 .14839 .39493 .13639 Mtetra
.39493 .13639 .40498 .14839 .42184 .14191 .41185 .12983 Mtetra
.41185 .12983 .42184 .14191 .4388 .13538 .42888 .12323 Mtetra
.42888 .12323 .4388 .13538 .45588 .12881 .44602 .11658 Mtetra
.44602 .11658 .45588 .12881 .47306 .12221 .46327 .1099 Mtetra
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Mtetra
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Mtetra
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Mtetra
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Mtetra
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Mtetra
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Mtetra
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Mtetra
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Mtetra
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Mtetra
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.03634 .26033 .04774 .27095 .06255 .26522 .05119 .25453 Mtetra
.05119 .25453 .06255 .26522 .07744 .25944 .06613 .2487 Mtetra
.06613 .2487 .07744 .25944 .09242 .25364 .08116 .24283 Mtetra
.08116 .24283 .09242 .25364 .10749 .2478 .09628 .23692 Mtetra
.09628 .23692 .10749 .2478 .12265 .24192 .11148 .23098 Mtetra
.11148 .23098 .12265 .24192 .1379 .23601 .12679 .225 Mtetra
.12679 .225 .1379 .23601 .15324 .23006 .14218 .21899 Mtetra
.14218 .21899 .15324 .23006 .16867 .22408 .15767 .21294 Mtetra
.15767 .21294 .16867 .22408 .1842 .21806 .17325 .20686 Mtetra
.17325 .20686 .1842 .21806 .19982 .21201 .18892 .20073 Mtetra
.18892 .20073 .19982 .21201 .21553 .20592 .20469 .19457 Mtetra
.20469 .19457 .21553 .20592 .23135 .19979 .22056 .18838 Mtetra
.22056 .18838 .23135 .19979 .24725 .19362 .23652 .18214 Mtetra
.23652 .18214 .24725 .19362 .26326 .18742 .25259 .17587 Mtetra
.25259 .17587 .26326 .18742 .27936 .18118 .26875 .16955 Mtetra
.26875 .16955 .27936 .18118 .29557 .1749 .28501 .1632 Mtetra
.28501 .1632 .29557 .1749 .31187 .16858 .30138 .15681 Mtetra
.30138 .15681 .31187 .16858 .32828 .16222 .31785 .15038 Mtetra
.31785 .15038 .32828 .16222 .34478 .15582 .33442 .14391 Mtetra
.33442 .14391 .34478 .15582 .36139 .14938 .35109 .13739 Mtetra
.35109 .13739 .36139 .14938 .37811 .14291 .36787 .13084 Mtetra
.36787 .13084 .37811 .14291 .39493 .13639 .38475 .12424 Mtetra
.38475 .12424 .39493 .13639 .41185 .12983 .40174 .11761 Mtetra
.40174 .11761 .41185 .12983 .42888 .12323 .41884 .11093 Mtetra
.41884 .11093 .42888 .12323 .44602 .11658 .43605 .10421 Mtetra
.43605 .10421 .44602 .11658 .46327 .1099 .45337 .09744 Mtetra
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Mtetra
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Mtetra
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Mtetra
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Mtetra
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Mtetra
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Mtetra
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Mtetra
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Mtetra
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Mtetra
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`006_oooonDo`0003?oooooU000000Kooooo`006_oo
ool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0T?oo
ool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooo
oooo037ooooo00<00000ooooooooool0T?ooool00`00003oooooooooo`0Iooooo`006_ooool01?l0
003oooooooooooooool4000008_ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2@
ooooo`0300000?oooooooooo01Wooooo000Jooooo`04o`000?oooooooooo000000<0<c<c0P000027
o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000
ooooooooool06Oooool001[ooooo00Co0000ooooooooool000000P0c<c<20000000301TI6@00003o
000008Go00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d000000oooool0
0`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`030000000504a<C00000000000
01TI6@000000QOl00003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0S@000003
ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo0080000000<0<c<c0000
001<C4`00P000026o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=0000
00?ooooo00<00000ooooooooool06Oooool001[ooooo00Wo0000ooooooooool0000001TI6@000000
<c<c0000001<C4`00`000024o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003ooooooooo
o`2=000000?ooooo00<00000ooooooooool06Oooool001[ooooo00Ko0000oooooooooooo00000000
000I6AT200000080C4a<00?o0000000000000000Pol00003ooooo`03o`000?oooooooooo037ooooo
00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oo
oooooooo00;o000000@0000001TI6@00000000000P1<C4`3000008;o00000oooool00ol0003ooooo
ooooo`0aooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0Iooooo`006_oo
ool00ol0003oooooooooo`03o`0000<00000101<C4`30000083o00000oooool00ol0003ooooooooo
o`0aooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0Iooooo`006_ooool0
0ol0003oooooooooo`05o`0000800000101<C4`00ol0000000000000001oo`0000?ooooo00?o0000
ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool06Oooool0
01[ooooo00?o0000ooooooooool01Ol000030000000404a<C?l0003o0000o`0000<00000O_l00003
ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooo
oooo01Wooooo000Jooooo`03o`000?oooooooooo00Go00000P0000000ol00000C4a<o`00000206IV
IP04o`000000003o0000000007go00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooo
oooo08d000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`06o`00
0080000000<0C4a<o`00001VIVH00P1VIVH01?l00000000000000000001lo`0000?ooooo00?o0000
ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool06Oooool0
01[ooooo00?o0000ooooooooool02?l000000`000000C4a<o`00000306IVIP04o`00000000000000
000007_o00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d000000oooool0
0`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`08o`000080000000Co000006IV
IP1VIVH0IVIV0_l00003000007[o00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooo
oooo08d000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`09o`00
0080000000?o000006IVIP1VIVH00ol000000`00003o0000o`00001io`0000?ooooo00?o0000oooo
ooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool06Oooool001[o
oooo00?o0000ooooooooool02_l000001000003o000006IVIP1VIVH4o`0000800000NOl00003oooo
o`03o`000?oooooooooo037ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo00_o000000D00000o`00001VIVKo000009VIV@03o`00
00800000N?l00003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0S@000003oooo
o`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00_o00000P000002o`000080
VIVI0ol00002000007Oo00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d0
00000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0<o`0000800000
0_l0000209VIV@?o000000<00000o`000?l00000MOl00003ooooo`03o`000?oooooooooo037ooooo
00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oo
oooooooo00go00000P000002o`00000309VIVOl0003o000000?o000000<00000o`000?l00000Lol0
0003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0S@000003ooooo`0300000?oo
oooooooo01Wooooo000Jooooo`03o`000?oooooooooo00oo000000<00000o`000?l000001Ol00002
000007Co00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d000000oooool0
0`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0?o`00008000000_l000020<c<
c0;o00000P00001do`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=0000
00?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool04?l00002000000;o
00000P3<c<`2o`0000<00000L_l00003ooooo`03o`000?oooooooooo037ooooo00<00000oooooooo
ool0S@000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo017o0000
00D00000o`000?l0003o00000<c<c003o`0000<00000LOl00003ooooo`03o`000?oooooooooo037o
oooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`00
0?oooooooooo01;o000000<00000o`000?l000001Ol000030000073o00000oooool00ol0003ooooo
ooooo`0aooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0Iooooo`006_oo
ool00ol0003oooooooooo`0Co`00008000000_l000000`3Vi^Ko0000o`0000030000073o00000ooo
ool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d000000oooool00`00003ooooooooo
o`0Iooooo`006_ooool00ol0003oooooooooo`0Do`00008000000_l000000`3Vi^Ko0000o`000003
000006oo00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d000000oooool0
0`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Eo`00000400000?l0003o0000
0>KViP?o00000`00001^o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=
000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool06_l000000`00
003o0000o`000002o`00000300000?l0003o000006_o00000oooool00ol0003oooooooooo`0aoooo
o`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003o
ooooooooo`0Go`00000300000?l0003o0000008000000ol00002000006co00000oooool00ol0003o
ooooooooo`0aooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0Iooooo`00
6_ooool00ol0003oooooooooo`0Ho`00000300000?l0003o0000008000000ol00002000006_o0000
0oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d000000oooool00`00003ooooo
ooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Io`00000300000?l0003o0000008000000ol0
00000`00003o0000o`00001Yo`0000?ooooo00?o0000ooooooooool0<Oooool00`00003ooooooooo
o`2=000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool06Ol00002
000000?o000000D00000o`000?l0003o00000000001Zo`0000?ooooo00?o0000ooooooooool0<Ooo
ool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000
ooooooooool06_l00002000000?o000000<00000o`000?l000000P00001Yo`0000?ooooo00?o0000
ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool06Oooool0
01[ooooo00?o0000ooooooooool06ol00002000000?o000000<00000o`000?l000000P00001Xo`00
00?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000oooo
ooooool06Oooool001[ooooo00?o0000ooooooooool08Ol000000`00003o0000o`00001Yo`0000?o
oooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000oooooooo
ool06Oooool001[ooooo00?o0000ooooooooool07Ol00002000000Ko00000P00001Vo`0000?ooooo
00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0
6Oooool001[ooooo00?o0000ooooooooool07_l00002000000Ko00000P00001Uo`0000?ooooo00?o
0000ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool06Ooo
ool001[ooooo00?o0000ooooooooool07ol000000`00003o0000o`000005o`0000800000I?l00003
ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooo
oooo01Wooooo000Jooooo`03o`000?oooooooooo023o00000P00001[o`0000?ooooo00?o0000oooo
ooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool06Oooool001[o
oooo00?o0000ooooooooool08Ol00002000000?o000000@0VIVIo`000?l000000000Hol00003oooo
o`03o`000?oooooooooo037ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo027o000000<0000001TI6@0000000ol00000102IVIWo
0000o`000000001Ro`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=0000
00?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool08_l000000`000000
6ATI00000006o`00000300000?l0003o000005oo00000oooool00ol0003oooooooooo`0aooooo`03
00000?oooooooooo08d000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003ooooo
ooooo`0So`000080000000<0<c<co`000?l000001?l000000`00003o0000o`00001No`0000?ooooo
00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0
6Oooool001[ooooo00?o0000ooooooooool09?l000020000000303<c<ol0003o000000?o00000P00
001Oo`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<0
0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool09Ol000020000000303<c<ol00000
IVIV00;o00000`00001No`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=
000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool09_l000001@00
003o0000o`000?l00000IVIV00;o00000`00001Mo`0000?ooooo00?o0000ooooooooool0<Oooool0
0`00003oooooooooo`2=000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool09ol000002P0000006ATI00000?l00000IVIVo`0000000000<c<co`000000001Lo`0000?o
oooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000oooooooo
ool06Oooool001[ooooo00?o0000ooooooooool0:Ol000000`0I6AT00000o`00000204a<C0040000
000c<c<00000000005_o00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d0
00000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Yo`0000040000
000I6AT00000o`000080C4a<00Co00000000000000000000F_l00003ooooo`03o`000?oooooooooo
037ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03
o`000?oooooooooo02[o00000P000000100c<c<0000004a<C01<C4`3000005[o00000oooool00ol0
003oooooooooo`0aooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0Ioooo
o`006_ooool00ol0003oooooooooo`0[o`000080000000<0<c<c0000000000000P0c<c<2000005Wo
00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d000000oooool00`00003o
ooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0/o`000080000000<0<c<c0000000c<c<0
0P0c<c<2000005So00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d00000
0oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0]o`00000400000?l0
0000000000000080<c<c00?o000001TI6@000000Eol00003ooooo`03o`000?oooooooooo037ooooo
00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oo
oooooooo02ko000000P0000001TI6@0I6AT0000003<c<`0000006ATI000005Oo00000oooool00ol0
003oooooooooo`0aooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0Ioooo
o`006_ooool00ol0003oooooooooo`0_o`000080000000<06ATI0000000000000P0I6AT00`00003o
0000o`00001Do`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=000000?o
oooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0<Ol000000`0000006ATI
0000000301TI6EKo00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d00000
0oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0bo`0000030000000I
6AT06ATI00806ATI00<00000o`000?l00000Dol00003ooooo`03o`000?oooooooooo037ooooo00<0
0000ooooooooool0S@000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooo
oooo03?o000000<0000001TI6@0I6AT00P0I6AT00`00003o0000o`00001Bo`0000?ooooo00?o0000
ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool06Oooool0
01[ooooo00?o0000ooooooooool0=?l000001@0000006ATI01TI6@0I6AT0000005Co00000oooool0
0ol0003oooooooooo`0aooooo`0300000?oooooooooo03H0000000?o0000000000000000E0000003
ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo03Go000000D0000001TI
6@0I6AT06ATI0000001Co`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`0e
00000003o`00000I6AT06ATI05D000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0
003oooooooooo`0eo`0000030000000I6AT06ATI00806ATIDol00003ooooo`03o`000?oooooooooo
037ooooo00<00000ooooooooool0=P00000401TI6E<000000oooool00`00003oooooooooo`0Ioooo
o`006_ooool00ol0003oooooooooo`0fo`00008000000P0I6AT00`00003o0000o`00001@o`0000?o
oooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`0g000000D06ATID@000003ooooo`03
00000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo03So000000@0000001TI6@0I6AT0
0000DOl00003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0=`00000601TI6E00
00000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0ko`0000030000
0?l0003o000004oo00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo03P00000
1`0I6AU>000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl0
0003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0>@00000401TI6@8000000P0I
6AU<000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003
ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0>P00000301TI6@050000000c<c<0
00000000000I6AT0B`000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooo
oooo08go00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo03/0000000<06ATI
0000000c<c<00`0c<c=<000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0>`0000000`0I
6AT0000003<c<`0303<c<d`000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003o
ooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`0l00000003
01TI6@000000<c<c0080<c<c00@0000004a<C0000000<c<cB0000003ooooo`0300000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03
00000?oooooooooo03h000000P0c<c<01000003o0000o`00001<C4`20000000301TI6@0000000000
04@000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?o
oooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`0n00000003o`000000003o00000080
IVIV0_l00018000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0
SOl00003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0?@0000001Ol000006ATI
00000000003o000000<0IVIV0_l00016000000?ooooo00<00000ooooooooool06Oooool001[ooooo
00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0
?`0000000`0I6AT00000o`00000306IVIP?o0000A@000003ooooo`0300000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`0300000?oo
oooooooo0400000000<06ATI00000?l000000P1VIVH01?l00000Ogmoo`000?l00014000000?ooooo
00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oo
oooooooo037ooooo00<00000ooooooooool0@@0000000ol000000000o`000007o`00048000000ooo
ool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000
ooooooooool0<Oooool00`00003oooooooooo`1100000003o`00000I6AT0000000;o00000P2IVIT4
o`00044000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`00
00?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`130000000701TI6@00003o0000
o`00002IVIWo00000;>c/`04o`0003l000000oooool00`00003oooooooooo`0Iooooo`006_ooool0
0ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`14
0000000301TI6Ol0003o000000;o00000`2c/k<4o`0003d000000oooool00`00003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00`00
003oooooooooo`16000000?o00000`2c/k<00`00003o0000o`00000n000000?ooooo00<00000oooo
ooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037o
oooo00<00000ooooooooool0A`000003o`000080/k>c1Ol0000l000000?ooooo00<00000oooooooo
ool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo
00<00000ooooooooool0B0000003o`00000300000?l00000i^KV00Co000000<00000o`0000000000
>0000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000ooo
ool00ol0003oooooooooo`0aooooo`0300000?oooooooooo04T000000_l000001000003o00000>KV
iP3Vi^H4o`0003X000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`1800000003o`000000
0000000000?o000000<0i^KVo`000?l000001?l0000h000000?ooooo00<00000ooooooooool06Ooo
ool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00<00000
ooooooooool0C00000001Ol000000000o`000?l00000oooo00Go000000<00000o`0000000000=000
0003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool0
0ol0003oooooooooo`0aooooo`0300000?oooooooooo04d0000000?o000000000?l000000`3oool4
o`0003H000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`00
00?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`1=000000Co00000`3oool4o`00
03D000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?o
oooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`1>000000;o000000<00000o`00003o
ool00P3oool4o`0003@000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003ooooo
ooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`1?000000;o0000
00<00000o`00003oool00P3oool4o`0003<000000oooool00`00003oooooooooo`0Iooooo`006_oo
ool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003ooooooooo
o`1@000000;o000000<00000o`000?l000000P3oool4o`00038000000oooool00`00003ooooooooo
o`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool0
0`00003oooooooooo`1?00000003o`000000003o000000Co00000P3oool00ol000000000o`00000b
000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003oooo
o`03o`000?oooooooooo037ooooo00<00000ooooooooool0DP000002o`00000300000?l0003o0000
0080oooo00?o000000000?l00000<@000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03
o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo05<0
00000_l000000`00003o0000o`0000020?ooo`05o`000000003o000000000?l00000;P000003oooo
o`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003o
ooooooooo`0aooooo`0300000?oooooooooo05@000000_l000000`00003o0000o`0000020?ooo`04
o`000000003o0000o`0002h000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003o
ooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`1F000000Co
000000@0ooooo`000?l0000000000_l000000`0000006ATI0000000Z000000?ooooo00<00000oooo
ooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037o
oooo00<00000ooooooooool0E`000004o`000080i^KV1?l0000/000000?ooooo00<00000oooooooo
ool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo
00<00000ooooooooool0F0000005o`0000030>KVi_l00000000000;o0000:`000003ooooo`030000
0?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooooooo
o`0aooooo`0300000?oooooooooo05L0000000?o000000000?l000000_l000001000003o0000o`00
00000003o`00000301TI6@000000000002L000000oooool00`00003oooooooooo`0Iooooo`006_oo
ool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003ooooooooo
o`1J000000?o000000@00000o`00003<c<`000000_l000000`0000006ATI0000000W000000?ooooo
00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oo
oooooooo037ooooo00<00000ooooooooool0F`000003o`000080000000H0c<c<00000?l0003o0000
0000000I6ATW000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0
SOl00003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0F`000005o`0000800000
0ol000000`0000006ATI0000000U000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o
0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0GP00
0004o`00000600000?l0003o0000o`00000000006ATI9@000003ooooo`0300000?oooooooooo01Wo
oooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`030000
0?oooooooooo05l000001?l000000`2IVIWo0000o`0000020000000301TI6@000000000002800000
0oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o
0000ooooooooool0<Oooool00`00003oooooooooo`1P00000003o`00001VIVKo00000080VIVI0_l0
000V000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003
ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0GP000002o`00000300000?l0003o
000000Ko000090000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo
08go00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo06@0000000Go000007mo
Ool00000IVIVo`00000T000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0I@0000001Ol0
0000IVIV06IVIP1VIVKo00000080000000?o00000000000000007P000003ooooo`0300000?oooooo
oooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aoooo
o`0300000?oooooooooo06<0000000<06ATI0000000000000ol00000101VIVKo000000000?l0000P
000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003oooo
o`03o`000?oooooooooo037ooooo00<00000ooooooooool0I00000001`0I6AWo0000000000000000
C4a<o`00001<C4`00P0000000`0I6AT000000000000M000000?ooooo00<00000ooooooooool06Ooo
ool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00<00000
ooooooooool0I@00000201TI6@8000000`1<C4`20000000301TI6@000000000001`000000oooool0
0`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooo
ooooool0<Oooool00`00003oooooooooo`1W0000000:01TI6@00000000000000001<C4co000003<c
<`0000006ATIo`0001`000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003ooooo
ooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`1X0000000401TI
6@0000000000000000;o000000<0<c<c00000000000070000003ooooo`0300000?oooooooooo01Wo
oooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`030000
0?oooooooooo06T000000P0I6AT01P000000<c<c03<c<`0c<c<0000001TI6A`000000oooool00`00
003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooooooo
ool0<Oooool00`00003oooooooooo`1[0000000701TI6@00000000000000000c<c<0000001TI6@0K
000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003oooo
o`03o`000?oooooooooo037ooooo00<00000ooooooooool0K000000301TI6@8000000P0I6AT00ol0
000000000000000G000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000oooooooo
ool0SOl00003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0K00000000ol00000
000001TI6@0501TI6AT000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003ooooo
ooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`1`000000@06ATI
6@000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000ooo
ool00ol0003oooooooooo`0aooooo`0300000?oooooooooo07400000100I6ATH000000?ooooo00<0
0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooo
oooo037ooooo00<00000ooooooooool0L@0000001Ol0000000000000000I6AWo000001L000000ooo
ool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000
ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool06Oooool0
01[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00<00000oooo
ooooool0S@000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go
00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d000000oooool00`00003o
ooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0
<Oooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o
0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0S@00
0003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool0
0ol0003oooooooooo`0aooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00`00
003oooooooooo`2=000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000oooooooo
ool0SOl00003ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0S@000003ooooo`03
00000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooo
ooooo`0aooooo`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0Iooooo`006_oo
ool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003ooooooooo
o`2=000000?ooooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003
ooooo`03o`000?oooooooooo037ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooo
oooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aoooo
o`0300000?oooooooooo08d000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003o
ooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=000000?o
oooo00<00000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`00
0?oooooooooo037ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`0300000?oo
oooooooo08d000000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=
o`0000?ooooo00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000
ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo
037ooooo00<00000ooooooooool0S@000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03
o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d0
00000oooool00`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo
00?o0000ooooooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool0
6Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00<0
0000ooooooooool0S@000003ooooo`0300000?oooooooooo01Wooooo000Jooooo`03o`000?oooooo
oooo08go00000oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo08d000000oooool0
0`00003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooo
ooooool0<Oooool00`00003oooooooooo`2=000000?ooooo00<00000ooooooooool06Oooool001[o
oooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo093o
oooo00<00000ooooooooool06Oooool001[oooooU?l0000coooooi@000006oooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool008Gooooo0_l00035ooooo`;o0000
@_ooool008;ooooo0ol000000ooooooo0000ooooo`31ooooo`?o000000?oooooo`000?ooool0@Ooo
ool0083ooooo0_l00002ooooo`80ZKgX0_l0002oooooo`;o00000_ooool20:Vmj0;o0000@Oooool0
07gooooo0ol000000oooool0ZKgX0:Vmj0030:Vmj003o`000?oooooo00000;_ooooo0ol000000ooo
ool0ZKgX0:Vmj0030:Vmj003o`000?oooooo0000043ooooo001jooooo`?o00000oooool60:Vmj003
o`000?oooooo00000;Sooooo0ol00003ooooo`H0ZKgX00?o0000ooooool00000@?ooool007Sooooo
0_l00004ooooo`P0ZKgX00Co00000:Vmj?oooooo0000]Oooool2o`0000?ooooo2@2Y_NP01?l00000
ZKgXooooool0000oooooo`00MOooool3o`0000;ooooo302Y_NP01Ol00000ZKgX0:Vmj?oooooo0000
0;7ooooo0ol00002ooooo``0ZKgX00Go00000:Vmj02Y_NSoooooo`00000nooooo`00Loooool2o`00
00;ooooo3`2Y_NP01Ol00000ZKgX0:Vmj?oooooo00000:oooooo0_l00002ooooo`l0ZKgX00Go0000
0:Vmj02Y_NSoooooo`00000nooooo`00L?ooool3o`0000?ooooo402Y_NP01_l00000ZKgX0:Vmj02Y
_NSoooooo`000:_ooooo0ol00003oooooa00ZKgX00Ko00000:Vmj02Y_NP0ZKgXooooool0000moooo
o`00K_ooool2o`0000Cooooo4P2Y_NP01_l00000ZKgX0:Vmj02Y_NSoooooo`000:Wooooo0_l00004
oooooa80ZKgX00Ko00000:Vmj02Y_NP0ZKgXooooool0000mooooo`00Joooool3o`0000;ooooo5P2Y
_NP00ol00000ZKgX0:Vmj0020:Vmj003ooooool0003ooooo0:Cooooo0ol00002oooooaH0ZKgX00?o
00000:Vmj02Y_NP00P2Y_NP00ooooooo0000ooooo`0kooooo`00J?ooool3o`0000;ooooo6@2Y_NP0
0ol00000ZKgX0:Vmj0030:Vmj003ooooool0003ooooo0:3ooooo0ol00002oooooaT0ZKgX00?o0000
0:Vmj02Y_NP00`2Y_NP00ooooooo0000ooooo`0jooooo`00I_ooool2o`0000Cooooo6`2Y_NP00ol0
0000ZKgX0:Vmj0030:Vmj003o`000?oooooooooo09gooooo0_l00004oooooa/0ZKgX00?o00000:Vm
j02Y_NP00P2Y_NP00ooooooo0000ooooo`0jooooo`00Hoooool3o`0000Cooooo7@2Y_NP00ol00000
ZKgX0:Vmj0040:Vmj003o`000?oooooooooo09Wooooo0ol00004oooooad0ZKgX00?o00000:Vmj02Y
_NP00`2Y_NP00ooooooo0000ooooo`0iooooo`00HOooool2o`0000Cooooo802Y_NP00ol00000ZKgX
0:Vmj0040:Vmj003ooooool0003ooooo09Oooooo0_l00004ooooob00ZKgX00?o00000:Vmj02Y_NP0
102Y_NP00ooooooo0000ooooo`0hooooo`00G_ooool3o`0000;ooooo902Y_NP00ol00000ZKgX0:Vm
j0050:Vmj003o`000?oooooooooo09?ooooo0ol00002ooooob@0ZKgX00?o00000:Vmj02Y_NP01@2Y
_NP00ol0003oooooooooo`0gooooo`00G?ooool2o`0000;ooooo9`2Y_NP00ol00000ZKgX0:Vmj005
0:Vmj003ooooool0003ooooo097ooooo0_l00002ooooobL0ZKgX00?o00000:Vmj02Y_NP01@2Y_NP0
0ooooooo0000ooooo`0gooooo`00FOooool3o`0000?ooooo:02Y_NP00ol00000ZKgX0:Vmj0060:Vm
j003ooooool0003ooooo08gooooo0ol00003ooooobP0ZKgX00?o00000:Vmj02Y_NP01P2Y_NP00ooo
oooo0000ooooo`0fooooo`00Eoooool2o`0000Cooooo:P2Y_NP00ol00000ZKgX0:Vmj0070:Vmj003
o`000?oooooooooo08[ooooo0_l00004ooooobX0ZKgX00?o00000:Vmj02Y_NP01P2Y_NP00ooooooo
0000ooooo`0fooooo`00E?ooool3o`0000?ooooo;@2Y_NP00ol00000ZKgX0:Vmj0070:Vmj003oooo
ool0003ooooo08Oooooo0ol00003ooooobd0ZKgX00?o00000:Vmj02Y_NP01`2Y_NP00ooooooo0000
ooooo`0eooooo`00DOooool3o`0000?ooooo<02Y_NP00ol00000ZKgX0:Vmj0080:Vmj003ooooool0
003ooooo08?ooooo0ol00003oooooc00ZKgX00?o00000:Vmj02Y_NP0202Y_NP00ooooooo0000oooo
o`0dooooo`00Coooool2o`0000?ooooo<`2Y_NP00ol00000ZKgX0:Vmj0080:Vmj003ooooool0003o
oooo087ooooo0_l00003oooooc<0ZKgX00?o00000:Vmj02Y_NP0202Y_NP00ooooooo0000ooooo`0d
ooooo`00C?ooool3o`0000;ooooo=P2Y_NP00ol00000ZKgX0:Vmj0090:Vmj003ooooool0003ooooo
07gooooo0ol00002ooooocH0ZKgX00?o00000:Vmj02Y_NP02@2Y_NP00ooooooo0000ooooo`0coooo
o`00B_ooool2o`0000Cooooo=`2Y_NP00ol00000ZKgX0:Vmj00:0:Vmj003o`000?oooooooooo07[o
oooo0_l00004ooooocL0ZKgX00?o00000:Vmj02Y_NP02P2Y_NP00ol0003oooooooooo`0booooo`00
Aoooool3o`0000Cooooo>@2Y_NP00ol00000ZKgX0:Vmj00;0:Vmj003o`000?oooooooooo07Kooooo
0ol00004ooooocT0ZKgX00?o00000:Vmj02Y_NP02`2Y_NP00ol0003oooooooooo`0aooooo`00AOoo
ool2o`0000Cooooo?02Y_NP00ol00000ZKgX0:Vmj00;0:Vmj003ooooool0003ooooo07Cooooo0_l0
0004oooooc`0ZKgX00?o00000:Vmj02Y_NP02`2Y_NP00ooooooo0000ooooo`0aooooo`00@_ooool3
o`0000?ooooo?`2Y_NP00ol00000ZKgX0:Vmj00<0:Vmj003o`000?oooooooooo073ooooo0ol00002
oooood00ZKgX00?o00000:Vmj02Y_NP0302Y_NP00ol0003oooooooooo`0`ooooo`00?oooool3o`00
00?ooooo@P2Y_NP00ol00000ZKgX0:Vmj00<0:Vmj003ooooool0003ooooo06gooooo0ol00002oooo
od<0ZKgX00?o00000:Vmj02Y_NP0302Y_NP00ooooooo0000ooooo`0`ooooo`00?Oooool2o`0000?o
ooooA@2Y_NP00ol00000ZKgX0:Vmj00=0:Vmj003ooooool0003ooooo06[ooooo0_l00002ooooodH0
ZKgX00?o00000:Vmj02Y_NP03@2Y_NP00ooooooo0000ooooo`0_ooooo`00>_ooool3o`0000;ooooo
B02Y_NP00ol00000ZKgX0:Vmj00>0:Vmj003o`000?oooooooooo06Kooooo0ol00002ooooodP0ZKgX
00?o00000:Vmj02Y_NP03P2Y_NP00ol0003oooooooooo`0^ooooo`00>?ooool2o`0000CoooooB@2Y
_NP00ol00000ZKgX0:Vmj00>0:Vmj003ooooool0003ooooo06Cooooo0_l00004ooooodT0ZKgX00?o
00000:Vmj02Y_NP03P2Y_NP00ooooooo0000ooooo`0^ooooo`00=Oooool3o`0000CoooooB`2Y_NP0
0ol00000ZKgX0:Vmj00?0:Vmj003ooooool0003ooooo063ooooo0ol00004oooood/0ZKgX00?o0000
0:Vmj02Y_NP03`2Y_NP00ooooooo0000ooooo`0]ooooo`00<oooool2o`0000CoooooCP2Y_NP00ol0
0000ZKgX0:Vmj00@0:Vmj003o`000?oooooooooo05gooooo0_l00004ooooodh0ZKgX00?o00000:Vm
j02Y_NP03`2Y_NP00ooooooo0000ooooo`0]ooooo`00<?ooool3o`0000?oooooD@2Y_NP00ol00000
ZKgX0:Vmj00A0:Vmj003o`000?oooooooooo05Wooooo0ol00003oooooe40ZKgX00?o00000:Vmj02Y
_NP0402Y_NP00ooooooo0000ooooo`0/ooooo`00;Oooool3o`0000?oooooE02Y_NP00ol00000ZKgX
0:Vmj00A0:Vmj003o`000?oooooooooo05Kooooo0ol00003oooooe@0ZKgX00?o00000:Vmj02Y_NP0
4@2Y_NP00ol0003oooooooooo`0[ooooo`00:oooool2o`0000?oooooF02Y_NP00ol00000ZKgX0:Vm
j00A0:Vmj003o`000?oooooooooo05?ooooo0_l00003oooooeP0ZKgX00?o00000:Vmj02Y_NP04@2Y
_NP00ol0003oooooooooo`0Zooooo`00:?ooool3o`0000;oooooF`2Y_NP00ol00000ZKgX0:Vmj00A
0:Vmj003ooooool0003ooooo053ooooo0ol00002oooooe/0ZKgX00?o00000:Vmj02Y_NP04@2Y_NP0
0ooooooo0000ooooo`0Zooooo`009_ooool2o`0000;oooooGP2Y_NP00ol00000ZKgX0:Vmj00B0:Vm
j003o`000?oooooooooo04gooooo0_l00002oooooeh0ZKgX00?o00000:Vmj02Y_NP04P2Y_NP00ol0
003oooooooooo`0Yooooo`008oooool3o`0000?oooooG`2Y_NP00ol00000ZKgX0:Vmj00C0:Vmj003
o`000?oooooooooo04Wooooo0ol00003oooooel0ZKgX00?o00000:Vmj02Y_NP04P2Y_NP00ooooooo
0000ooooo`0Yooooo`008Oooool2o`0000CoooooH@2Y_NP00ol00000ZKgX0:Vmj00D0:Vmj003o`00
0?oooooooooo04Kooooo0_l00004ooooof40ZKgX00?o00000:Vmj02Y_NP04`2Y_NP00ooooooo0000
ooooo`0Xooooo`007_ooool3o`0000CoooooH`2Y_NP00ol00000ZKgX0:Vmj00D0:Vmj003o`000?oo
oooooooo04?ooooo0ol00004ooooof<0ZKgX00?o00000:Vmj02Y_NP0502Y_NP00ol0003ooooooooo
o`0Wooooo`007?ooool2o`0000CoooooIP2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003o`000?oooooo
oooo043ooooo0_l00004ooooofH0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ol0003oooooooooo`0V
ooooo`006Oooool3o`0000?oooooJ@2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003ooooool0003ooooo
03gooooo0ol00003ooooofT0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ooooooo0000ooooo`0Voooo
o`005_ooool3o`0000?oooooK02Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oooooooooo03Wo
oooo0ol00003ooooof`0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Uooooo`00
5?ooool2o`0000CoooooKP2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003ooooool0003ooooo03Oooooo
0_l00003ooooofl0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ooooooo0000ooooo`0Uooooo`004Ooo
ool3o`0000?ooooo0P2W[M]^0:Vmj0;o00006@2Y_NP00ooooooo0000ooooo`0cooooo`?o00000ooo
oom`0:Vmj0;o00006@2Y_NP00ooooooo0000ooooo`0Tooooo`004?ooool2o`0000;ooooo00<0U6JJ
0:N]f`2W[M/00`2W[M/20:Vmj080YjoMIP2Y_NP3o`0000030:Vmj?l00000ZKgX01T0ZKgX00?o0000
ooooooooool0<Oooool2o`0000;oooooL02Y_NP3o`0000030:Vmj?l00000ZKgX01T0ZKgX00?o0000
ooooooooool08oooool0013ooooo00?o0000ooooool000000`2DIYX30:N]f`80TF2E102W[md00`2Y
_NP0Z;7O0:Rag`1O0:Vmj0?o00001@2Y_NP00ol00000ZKgX0:Vmj00H0:Vmj003o`000?oooooooooo
033ooooo00?o00000:Vmj02Y_NP0KP2Y_NP3o`0000D0ZKgX00?o00000:Vmj02Y_NP0602Y_NP00ol0
003oooooooooo`0Rooooo`004?ooool00ol0003ooooo09AVVP0409AVVP030:N]f`2AH9D0TF2E0080
TF2E0P2W[md00`2?GI80Z;7O0:Rag`020:Rag`80ZKgX0P2X]>5G0:Vmj0?o00002@2Y_NP00ol00000
ZKgX0:Vmj00G0:Vmj003o`000?oooooooooo033ooooo00?o00000:Vmj02Y_NP0J`2Y_NP3o`0000T0
ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol0003oooooooooo`0Rooooo`004?ooool00ol0003ooooo
09AVVP0409AVVPD0TF2E102?GI820:Rag`80SU^A102X]>420:Vmj080ZKOS0`2Y_NP00`2Y^ND0ZKgX
0:Vmj0190:Vmj0?o00003@2Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`000?oooooooooo02oooooo
00?o0000ooooo`2Y_NP0J02Y_NP3o`0000d0ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol0003ooooo
ooooo`0Qooooo`003oooool00ol0003ooooo0?_WYP0509AVVPD0TF2E102?GI8508iKT@80Z;CQ0P2=
G9840:Vgh`040:Vmj02Y^ND0ZKWU0:Vii@80ZKgX0P2Y^nI30:Vmj0?o0000402Y_NP00ol00000ZKgX
0:Vmj00G0:Vmj003ooooool0003ooooo02kooooo00Co0000ooooooooooooooooI@2Y_NP3o`000100
ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ooooooo0000ooooo`0Qooooo`003oooool00ol0003ooooo
0?_WYP0409AVVP030?cKWP2AH9D0TF2E0080TF2E00<0n<^K08mMTP2?GI800P2?GI8508iKT@D0SEbB
0P2Y]n<0102>GY@0ZKWU0:Vii@2Y^ND2091RV0@0ZK_V0P2Y_NP00`2Y_>L0ZKgX0:Vmj00j0:Vmj0?o
0000502Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`000?oooooooooo02gooooo00?o0000oooooooo
ool00_oooomQ0:Vmj0?o0000502Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`000?oooooooooo023o
oooo000?ooooo`03o`00003kijH0nnNV00@0U6JJ00<0o=^N095PU@2AH9D00P2AH9D00`3hbi/0SefB
08mMTP0208mMTPD0SU^A1@2=G98408iNU0030:Vii@2@HYP0T6:H0080T6:H0P2Y^nH2099XWP<0ZKcW
0P2Y_NP20:Vmic@0ZKgX0ol0000H0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?oooooo`000?ooool0
;Oooool00ol0003oooooooooo`03oooooed0ZKgX0ol0000H0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX
00?oooooo`000?ooool08?ooool000oooooo00?o00000?_WYP3kijH0102DIYX00`3lfih0TF2E095P
U@02095PU@050?S;V`2?GI80SefB08mMTP3/]iX01@2>Fi4508eLTP@0SUjD1@2@HYP5099XWP030:Vl
i`2FLJH0UW6V00@0ZKgW<02Y_NP3o`0001`0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ooooooo0000
ooooo`0/ooooo`03o`000?oooooooooo00CoooooF@2Y_NP3o`0001`0ZKgX00?o00000:Vmj02Y_NP0
5P2Y_NP00ooooooo0000ooooo`0Oooooo`003oooool01?l0003ooooo0?_WYP3kijH209AVVP80o=^N
0`2AH9D20?S;V`<0SefB00<0k;NJ08iKT@2>Fi400P2>Fi400`3KXIP0SEbB08eLTP0308eLTP@0SUjD
1@2@HYP5099XWP@0UW6V0P2Y_NL209]n/Rd0ZKgX0_l0000O0:Vmj003o`00002Y_NP0ZKgX01L0ZKgX
00?o0000ooooooooool0:oooool00ol0003oooooooooo`05oooooeH0ZKgX0_l0000O0:Vmj003o`00
002Y_NP0ZKgX01L0ZKgX00?o0000ooooooooool07_ooool000oooooo00Co0000ooooooooool0nnNV
0P2DIYX20?cKWP<0TF2E0P3hbi/308mMTP030>bgVP2>Fi40SU^A0080SU^A00<0fj6H08eLTP2=G980
0P2=G9800`39SID0SUjD08iNU00208iNU0D0T6:H1@2BJ9h409IaYPD0Vgjb0P2Y_NP00`2PS/00ZKgX
0:Vmj00T0:Vmj0?o00008P2Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`000?oooooooooo02[ooooo
00?o0000ooooooooool01_oooomB0:Vmj0?o00008P2Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`00
0?oooooooooo01gooooo000>ooooo`05o`000?ooooooooooooooo`3kijH00P2DIYX20?cKWP<0TF2E
0P3hbi/308mMTP030>bgVP2>Fi40SU^A0080SU^A00<0fj6H08eLTP2=G9800P2=G9801@39SID0SUjD
08iNU02>GY@0^WjB00@0T6:H00<0[G:@099XWP2BJ9h00P2BJ9h00`2TJXl0UW6V09IaYP0209IaYP03
09eUSP2KO[80Vgjb0080Vgjb102PS/020:Vmj080YIk?7P2Y_NP3o`0002H0ZKgX00?o00000:Vmj02Y
_NP05`2Y_NP00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00SoooooCP2Y_NP3o`0002H0
ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol0003oooooooooo`0Looooo`003_ooool01_l0003ooooo
ooooooooool0nnNV09AVVP<0o=^N0P2AH9D30?S;V`80SefB0P3/]iX308iKT@80fj6H102=G9801@39
SID0SUjD08iNU02>GY@0^WjB00@0T6:H00<0[G:@099XWP2BJ9h00P2BJ9h0102TJXl0UW6V09IaYP2F
LJH209eUSP@0Vgjb102PS/050:FNc`80ZKgX0P2W[=X20:Vmj080ZKCQ4P2Y_NP3o`0002X0ZKgX00?o
00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Wooooo:P2Y
_NP20:Vmiah0ZKgX0ol0000Z0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o0000ooooooooool07?oo
ool000kooooo00?o0000ooooooooool00_ooool0102DIYX0o=^Nooooo`3lfih2095PU@<0n<^K0P2?
GI820>bgVP<0SU^A0P3KXIP308eLTP80bHfE0`2>GY@00`2jOY80T6:H091RV002091RV080[G:@0`2B
J9h20:AZS`80UW6V0P2MIHh309]n/P80VF:?0P2PS/0209MRT@<0YIk?00@0UVBE0:N/fP2W[=X0YjcJ
0P2GJI/40:Vdh@80ZKgX00<0ZKWU0:Vmj02Y_NP02@2Y_NP3o`0002d0ZKgX00?o00000:Vmj02Y_NP0
5`2Y_NP00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo9@2Y_NP20:Vli`@0ZKgW
0P2Y_NP20:Vli`80ZKgX0P2Y^N@50:Vmj080ZKcW2`2Y_NP3o`0002d0ZKgX00?o00000:Vmj02Y_NP0
5`2Y_NP00ol0003oooooooooo`0Kooooo`003_ooool00ol0003oooooooooo`02ooooo`0409AVV_oo
oooooooo0?cKWP80TF2E0`3hbi/208mMTP80k;NJ0`2>Fi420=^QV0<0SEbB0P39SID308iNU080^WjB
0P2@HYP30:ebT080TVRN0`2TJXl00`2FLJH0WFF>09eUSP0209eUSP0509]n/P2IHXl0VF:?09URS`2P
S/00102GHY401@2UW/l0UVBE09ITU@2FI9D0YjcJ00@0UfVK0P2Y]>400`2ILZD0ZKWU0:Vii@020:Vi
i@80ZKgX0P2Y_>L30:Vmj0?o0000<@2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003ooooool0003ooooo
02Oooooo00?o0000ooooooooool03?oooolR0:Vmj0030:Zmj02Y_>L0ZKcW0080ZKcW0P2Y_NL30:Zj
i@030:Vli`2[]^40ZkKQ00@0ZKWT0P2Y_NP00`2Y/]l0ZKcW0:Vli`020:Vli`80ZKgX00<0ZK[V0:Vm
j02Y_NP00P2Y_NP3o`000340ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ooooooo0000ooooo`0Koooo
o`003_ooool00ol0003oooooooooo`06ooooo`03095PU@3hbi/0n<^K0080n<^K0P2?GI820>bgVP80
SU^A0`3KXIP308eLTP80bHfE0P2>GY@30;YnTP80T6:H0`2]LY02099XWP<0Y6Z?00<0UW6V09eUSP2M
IHh00P2MIHh0102KO[80VF:?09URS`2IHXl509MRT@@0UVBE1@2GJI/409UbY@80ZKWU0P2NPK<30:Vl
i`?o000000<0ZKgW0:Vmj02Y_NP0<P2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oooooooooo
02Kooooo00?o0000ooooooooool03OoooolQ0:Vmj080Z[gX0P2Y_>L30:Zmi`80Z[[U00<0[;kW0:^f
h@2[]^400P2[]^420:Vii080[:kI0`2Y/]l20:Vli`80Z:OE0`2Y^^H3o`0000030:Vgh`2Y_NP0ZKgX
0380ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Jooooo`003_ooool00ol0003o
ooooooooo`06ooooo`03095PU@3hbi/0n<^K0080n<^K0P2?GI820>bgVP80SU^A0`3KXIP208eLTP<0
bHfE0P2>GY@30;YnTP80T6:H0`2]LY000`2BJ9h0Y6Z?0:AZS`020:AZS`0309IaYP2MIHh0WFF>0080
WFF>102IHXl509MRT@@0UVBE1@2GJI/409UbY@@0WX6c0ol000000`2STl@0ZKgW0:Vmi`020:Vmic<0
ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ooooooo0000ooooo`0Vooooo`03o`000?oooooooooo00go
oooo8@2Y_NP40:Rmj@80Z[gW0P2W_^X30:bni`80ZkKQ00<0[l7W0:b^f@2/[]T00`2/[]T00`2Y/]l0
[J?=0:RWe@030:RWe@?o000000<0YIK60:Vgh`2Y]n<00P2Y]n<20:Vmj080Z;7N1@2Y_NP20:Vmi`80
ZKgX0P2Y_>LT0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?oooooo`000?ooool06_ooool000gooooo
00?o0000ooooooooool01oooool00`2AH9D0n<^Kooooo`020?S;V`0408mMTP3/]iX0k;NJ0>bgVP80
SU^A0`3KXIP208eLTP<0bHfE0P2>GY@30;YnTP03091RV02]LY00[G:@0080[G:@00<0TVRN0:AZS`2T
JXl00P2TJXl509eUSP@0VF:?1@2GHY4409ITU@D0UfVK102ILZD01@3dcZSo0000o`000?l00000WX6c
00@0Xi?40P2Y_NL30:NTd`030:Vmj02X/Mh0Z;7N02l0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo8@2Y_NP40:Rmj@@0YkkZ00<0[;kW0:6n
k@2Q_^d00`2_`NL30:b^f@040;K8j02]Xld0[J?=0:fSc@?o000000<0[iJn0:FFaP2UU/H00P2UU/H2
0:Vgh`050:24]@2X/Mh0Z;7N0:RagP2LMZL01@2WYmH00`2Y_NL0YI_;0:FKb`040:Vli`80ZKgX00<0
ZK_V0:Vmj02Y_NP07`2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oooooooooo01Wooooo000=
ooooo`03o`000?oooooooooo00Oooooo00H0n<^Koooooooooooooooo0?S;V`2?GI830>bgVP80SU^A
0`3KXIP208eLTP<0bHfE00<0SUjD0;YnTP2jOY800P2jOY800`2@HYP0[G:@0:ebT0020:ebT003099X
WP2TJXl0Y6Z?0080Y6Z?1@2MIHh409URS`D0Uf:A102FI9D01@3ae680UfVK09MYV`2GJI/0omZ<00<0
VG:U0_l0000409j1/`@0Xi?400D0bK720:NTd`2WY=<0YjCC0;^]b`040:RagP80ZKgX00<0ZKST0:Vm
j02Y_NP0:P2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oooooooooo02?ooooo00?o0000oooo
ooooool04?oooolQ0:Vmj0@0Z;gY0P2W_^X00`2U_>X0XKk]0:6nk@020:6nk@<0[l7W00@0[:kI0;K8
j02fb>P0]/SX0_l000000`2]Xld0Z:OE0:nF_P020:nF_P80YIK600<0/Hf`0:24]@2PQ;D00P2PQ;D0
102X/Mh0W7JW09afY`2LMZL30:NWeP0309Y]WP2UVl/0YI_;0080YI_;0P2Y_>L00`2RS[l0ZK_V0:Vk
iP020:VkiP80ZKgX00<0ZK[U0:Vmj02Y_NP0702Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oo
oooooooo01Sooooo000=ooooo`03o`000?oooooooooo00_ooooo00<0n<^K08mMTP3/]iX00P3/]iX0
0`2>Fi40fj6H0=^QV0020=^QV080SEbB0`39SID00`2>GY@0^WjB0;YnTP020;YnTP03091RV02]LY00
[G:@0080[G:@1@2TJXl509eUSP@0VF:?102GHY40103A_cT0UVBE09ITU@2FI9D20?7DHP<0UfVK00@0
omZ<o`000?l0003o00000P3dcZP309j1/`80gKfh0P2STl@30<Va`P040:NTd`2k[L/0^jg;0;^]b`80
Z;7N00<0/ZkD0:Vhi02Y^>@00P2Y^>@20:Vmj0030:VkiP2Y_NP0ZKgX02L0ZKgX00?o00000:Vmj02Y
_NP05P2Y_NP00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo017ooooo8@2Y_NP20:Rmj@80
ZKgX0`2U_>X20:6nk@80X;_/0`2B_O@3o`000080[J?=00<0`]SZ0:nF_P2_U[h00P2_U[h0102UU/H0
/Hf`0;6=/02aSK030:24]@D0W7JW00<0YjOF09Y]WP2JKIh0102UVl/40::>_`80ZK_V0P2OPkD30:Vj
i@80ZKgX0P2Y^N@J0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o0000ooooooooool05oooool000go
oooo00?o0000ooooooooool02oooool00`3hbi/0SefB0>bgVP020>bgVP0308iKT@3KXIP0fj6H0080
fj6H00<0SEbB0<V=U@39SID00P39SID00`2>GY@0^WjB0;YnTP020;YnTPD0[G:@1@2TJXl409eUSP05
0000002IHXl0VF:?09URS`000000102GHY40103A_cT0UVBE09ITU@2FI9D20?7DHP0509MYVol0003o
0000o`00003ofX`00P2ILZD30?C>Z00509j1/`3M_KP0gKfh0=fm^02STl@01039/L840;^]b`040:Ra
gP2b[]@0/ZkD0;:^e080ZKST0P2^/]`30:VkiP80ZKgX0P2Y_>LT0:Vmj003o`00002Y_NP0ZKgX01H0
ZKgX00?o0000ooooooooool08_ooool00ol0003oooooooooo`0BooooobD0ZKgX00<0YKcZ0:Vmj02Y
_NP00`2P^n`3o`000080UKO_0`1Q/O/00`32f>X0[iJn0:nF_P020:nF_P@0/Hf`0`2PQ;D509afY`@0
VVfN0P2UVl/00`2IJ9P0XXjo0::>_`020::>_`D0Wh>e00<0ZK[U09ak[P2LNjh0102Y^N@0102Y_NP0
ZKOS0:Vgh`2Y]n<20:Vmj0030:VehP2Y_NP0ZKgX0100ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0
003oooooooooo`0Gooooo`003Oooool00ol0003oooooooooo`0<ooooo`@0k;NJ00<0SU^A0=^QV03K
XIP00P3KXIP00`2=G980bHfE0<V=U@020<V=U@0308iNU02jOY80^WjB0080^WjB1@2]LY040:AZS`03
00003P2MIHh0WFF>0080WFF>00D0000009URS`2IHXl0VF:?0000000409MRT@040=6o>@2FI9D0UVBE
09ITU@?o00000P2GJI/20?oJS00309UbY@3dcZP0m<jX0080m<jX00D0WX6c0=fm^03M_KP0gKfh000g
]0030<Va`P80]oB]0P2k[L/20=;lg`<0/ZkD00<0bNS/0:jbg02^/]`00P2^/]`00`2Y^nH0ZkOQ0:^g
h@040:Vlib@0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo01?ooooo9`2Y_NP3o`000080Z;gX0P2E]nl20:Nmj@<0OJkc00<0`]SZ0:nF_P2_U[h00P3?
mnL30;6=/080X8Be0P2eQjD409afY`@0VVfN00@0YI_;09UXV02IJ9P0VFRH0P2RS[l209UVU0@0Wh>e
102LNjh20:Vii00509]fZ02Y]n<0ZKOS0:Vgh`2JLjD0102Y]N820:Vmj0030:Vdh@2Y_NP0ZKgX00d0
ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Fooooo`003Oooool00ol0003ooooo
ooooo`0=ooooo`<0k;NJ1@3KXIP00`2=G980bHfE0<V=U@020<V=U@D0^WjB1@2]LY040:AZS`030000
3P2MIHh0WFF>0080WFF>00D0000009URS`2IHXl0VF:?0000000409MRT@040=6o>Ol0003o0000o`00
0080lMAR0P2GJI/30?oJS00309UbY@3dcZP0m<jX0080m<jX00P0ZKgX0=fm^03M_KP0gKfh0:>kjP00
=k@0bK720:>kjP80<X[]00<0^jg;0=;lg`3Bo=l00P3Bo=l0102b[]@0bNS/0<WXk039j>`20:jbg003
0;gEk02[]n40ZkOQ0080ZkOQ0P2Y_>L20:Zji@80ZKgX00<0ZKcV0:Vmj02Y_NP07`2Y_NP00ol00000
ZKgX0:Vmj00F0:Vmj003o`000?oooooooooo023ooooo00?o0000ooooooooool05OoooolR0:Vmj0?o
00000`2Y_NP00`2X_NP0ZKgX0:Vmj0040:Nmj@0407f^l`2V_>T0Y[cY0:nF_P<0coOW102aSK000`2P
Q;D0]HNU0;F7Y@0309afY`030;Z7WP2JKIh0VVfN0080VVfN102IJ9P0102RS[l0VFJD09UVU02IIY@4
09n3]@@0W7^^102KMZP0102Y]n<0VW>U09YcY@2JLjD20:VehP0309YbY02Y]>40ZKCQ0080ZKCQ0P2Y
_NP00`2Y]>00ZKgX0:Vmj00:0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o0000ooooooooool05Ooo
ool000cooooo00?o0000ooooooooool03oooool00`3/]i[ooooo0=^QV0040=^QV0D0bHfE1@2jOY84
0:ebT0030:Vmj02TJXl0Y6Z?0080Y6Z?00<0000>09eUSP2MIHh00P2MIHh01@000000VF:?09URS`2I
HXl000000080Uf:A0ol0000309ITU@80lMAR0P2GJI/30?oJS00409UbY@3dcZP0m<jX0?C>Z0<0ZKgX
00<0gKfh0:>kjP2Y_NP0102S^nX203::k@030:BljP1f[OD0MZge0080MZge0P39j>`00`2C^O40_MG/
0;gEk0020;gEk080ZkOQ0P2cbNX20:Zji@80[/;Y0`2Y_>H20:Vmj080ZKgW7@2Y_NP00ol00000ZKgX
0:Vmj00E0:Vmj003o`000?oooooooooo01oooooo00?o0000ooooooooool05ooooolN0:Vmj0?o0000
2P2Y_NP20:Nmj@030:Vmj02V_>T0Y[cY0080Y[cY0P1=Uo400`3?mnL0/Hf`0;6=/0020;6=/0<0]HNU
0`2LMZL00`2jQih0VVfN09Y]WP0209Y]WP@0VFRH102IIY@309n3]@0309YVT`2LNjh0W7^^0080W7^^
102KMZP409YcY@@0VW:T0P2Y]>4209]cY@<0ZKCP0P2Y_NP20:Vdh@P0ZKgX00?o00000:Vmj02Y_NP0
5@2Y_NP00ol0003oooooooooo`0Eooooo`003?ooool00ol0003oooooooooo`0Aooooo`D0fj6H1@39
SID40;YnTP030:Vmj02]LY00[G:@0080[G:@00<0ZKgX0:AZS`2TJXl00P2TJXl00`0000h0WFF>09eU
SP0209eUSP040000002IHXl0VF:?09URS`?o00000P2GHY420=6o>@80UVBE0P3ae68209MYV`80omZ<
0`2Y_NP00`3dcZP0ZKgX0:Vmj0060:Vmj080Xk_Z0P2Y_NP30:BljP80MZge0`2U_>T209>il@80_MG/
0`2P_Nd00`2cbNX0Y[kZ0:JnjP040:k2j@030:VliP2[_nP0ZkoX00@0ZKgW702Y_NP00ol00000ZKgX
0:Vmj00F0:Vmj003o`000?oooooooooo01kooooo00?o0000ooooooooool06?oooolJ0:Vmj0?o0000
4@2Y_NP20:Jlj@80ZKgX0P2U_>T0103?mnL0/Hf`0;6=/02Gh9030;F7Y@80W7JW0P2jQih409Y]WP@0
VFRH1@2IIY@0102OPkD0VVJC09YVT`2JIY<209ak[P0309aVTP2KMZP0VgJX0080VgJX102JLjD409Yb
Y0D0Vg>U00<0ZKCP09afY`2LMZL0102Y]>420:Vmj080ZKGQ0P2Y_NP00`2Y]^;o00000:Vmj00G0:Vm
j003o`000?oooooooooo01Cooooo000<ooooo`03o`000?oooooooooo01;ooooo103KXIP50<V=U@@0
^WjB00<0ZKgX0:ebT02]LY000P2]LY000`2Y_NP0Y6Z?0:AZS`020:AZS`0400003P2MIHh0WFF>09eU
SP8000000ol0000010000000Uf:A09MRT@2GHY430=6o>@0309ITU@3ae680ZKgX0080lMAR00<0UfVK
0?oJS02Y_NP04@2Y_NP0102T_>X0ZKgX0:Vmj02Y_NP20:Flj@030:Vmj02W_>T0YkcY0080YkcY0P2P
_Nd00`2X_NT0Y[kZ0:JnjP020:JnjP80[/;Y00<0Z;kY0:^oj02[_nP00P2[_nP20:Vmi`030:Znj02Y
_NP0ZKgX01/0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01Wooooo5P2Y_NP3o`0001T0ZKgX00<0YKcY0:Vmj02aSK000P2Gh9040;F7Y@0309afY`2j
Qih0^XNN00<0VVfN00<0`X^I09UXV02IJ9P00P2IJ9P509UVU0@0VVJC00@0W7^^09aVTP2LIY80W6JB
0P2KMZP209iXTP<0VW>U00@0XFZB09YbY02JLZ@0VW:T1@2KLjD409afY`80ZKCQ0P2NNj/20:Veh@03
0:62/P2Y]^80ZKKR0080ZKKR00?o00000:Vmj02Y^>@05P2Y_NP00ol0003oooooooooo`0Cooooo`00
3?ooool00ol0003oooooooooo`0Booooo`<0fj6H00?ooooo0<V=U@39SID00P39SID00`2Y_NP0^WjB
0;YnTP020;YnTP030:Vmj02]LY00[G:@0080[G:@00<0ZKgX0:AZS`2TJXl00P2TJXl0100000h0WFF>
09eUSP2MIHh2o`0000<0VF:?00@0000009MRT@2GHY40Uf:A0`3A_cT01`2FI9D0lMAR0:Vmj02Y_NP0
lMAR09MYV`3ofX`06P2Y_NP20:Nlj@030:Vmj02X_NT0Z;gY0080Z;gY0P2V_^X00`2X_NP0Z;kY0:Rn
j@020:Rnj@80ZkoX00<0ZKkX0:Znj02Z_^P00P2Z_^P20:Vmj080Z[gX6@2Y_NP00ol00000ZKgX0:Vm
j00E0:Vmj003o`000?oooooooooo01gooooo00?o0000ooooooooool06_oooolC0:Vmj0;o0000802Y
_NP00`2Gh900]HNU0;F7Y@020;F7Y@0409afY`2jQih0^XNN0;Z7WP80VVfN0P32RiT309UXV0D0VFJD
102JIY<0102LNjh0W6JB09aVTP2LIY8209]fZ080WVRB0P2JLjD20:5ZTP<0VW:T00<0YFjC09]cY@2K
LjD00P2KLjD409afY`@0WW^[102QP[820:VfhP030:B;^P2Y^>Co00000080ZKST0P2Y_NP00`2Y^^D0
ZKgX0:Vmj00@0:Vmj003o`000?oooooooooo01?ooooo000<ooooo`03o`000?oooooooooo01;ooooo
0`3KXIP00oooool0bHfE0<V=U@020<V=U@03ooooo`2jOY80^WjB0080^WjB00<0ZKgX0:ebT02]LY00
0P2]LY001P2Y_NP0Y6Z?0:AZS`2TJXl0ZKgX00003P?o000000L0ZKgX0000002IHXl0VF:?0000002Y
_NP000000080Uf:A00D0dKli0:Vmj03A_cT0UVBE0?7DHP030:Vmj0030?oJS02Y_NP0ZKgX01d0ZKgX
0P2X_NT20:Vmj0<0Z;gX0P2X_^T20:Vmj0<0ZKkX0P2Z_^P20:Vmj080Z[gX6`2Y_NP00ol00000ZKgX
0:Vmj00E0:Vmj003o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool>0:Vmj0?o0000
8P2Y_NP209OPT0<0]HNU102jQih209Y]WP80`X^I0`2IJ9P509UVU0@0VVJC102LIY80102KMZP0WVRB
09iXTP2NJ98209YcY@80XFZB0P2JLZ@20:E^T`<0Vg>U00<0ZG:E09afY`2LMZL00P2LMZL409ikZ`04
0;>0W@2QP[80XH:b0:62/P@0Y8^j00<0ZKSTo`00002WUlD0102Y^^D20:Vmj080ZK_V0P2Y_NP00`2Y
_>L0ZKgX0:Vmj0090:Vmj003o`000?oooooooooo01;ooooo000<ooooo`03o`000?oooooooooo01;o
oooo0P3KXIP2ooooo`@0bHfE00?ooooo0;YnTP2jOY800P2jOY80102Y_NP0[G:@0:ebT02]LY020:Vm
j080Y6Z?0ol0000309eUSP040:Vmj0000000VF:?09URS`80ZKgX00<0000009MRT@2GHY400P2Y_NP0
0`3A_cT0UVBE0:Vmj00X0:Vmj0030:Rmj02Y_NP0ZKgX02L0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo2`2Y_NP3o`0002H0ZKgX00@0Un2@
0;F7Y@2eQjD0]HNU102jQih0102JKIh0`X^I0<:;V@32RiT209UXV0030<bAUP2IIY@0VFJD00<0VFJD
102JIY<409aVTP0409]fZ02NJ980WVRB09iXTP80VW>U0P2QJY8209YbY080YFjC0`2KLjD01@2YLYD0
W7JW09afY`2LMZL0[WRH00<0WW^[0P2cP9d30:62/P060;Z;Y02TRkX0Y8^j0:B;^P2WUlGo00000P2W
UlD20:Vji@80ZJ?@0P2Y^nH00`2Z[MX0ZKcW0:Vli`020:Vli`80ZKgX00<0ZKcW0:Vmj02Y_NP01@2Y
_NP00ol0003oooooooooo`0Booooo`003?ooool00ol0003oooooooooo`0Cooooo`030=^QV?oooooo
oooo00@0bHfE00Cooooo0;YnTP2jOY80^WjB0P2Y_NP30:ebT0070:Vmj?l0003o0000o`00002TJXl0
ZKgX00003P0309eUSP040:Vmj0000000VF:?09URS`80ZKgX00<0000009MRT@2GHY400P2Y_NP00`3A
_cT0UVBE0:Vmj01C0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Mooooo`L0ZKgX0ol0000Y0:Vmj00409OPT02eQjD0]HNU0:Vmj0@0^XNN00@0VVfN
0<:;V@32RiT0`X^I0P2IJ9P20<bAUP<0VFJD00<0fI^B09YVT`2JIY<00P2JIY<409aVTPD0WVRB00<0
VW>U0:5ZTP2QJY800P2JLZ@20:E^T`<0Vg>U0P2YLYD209afY`80[WRH0P2NNj/20;>0W@80XH:b0P2j
Rj@30:B;^P050;nI/02WUlGo00000:NGa@33ZKl00`2YXm040:Z]fP80ZKcW00<0ZkGP0:Vli`2Y_>L0
0P2Y_>L70:Vmj003o`000?oooooooooo017ooooo000;ooooo`03o`000?oooooooooo01Cooooo00<0
fj6Hooooooooool00`39SID2ooooo`<0^WjB0P2Y_NP01@2]LY3o0000o`000?l00000ZKgX00<0Y6Z?
00<0ZKgX00003P2MIHh00P2MIHh0102Y_NP0000009URS`2IHXl20:Vmj0030000002GHY40Uf:A0080
ZKgX00<0dKli09ITU@2Y_NP0E02Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003o`000?oooooooooo01Wo
oooo00?o0000ooooooooool07oooool30:Vmj0?o0000;@2Y_NP00`2eQjD0ZKgX0:Vmj0040;Z7WP04
09Y]WP32RiT0`X^I0<:;V@80VFRH0P3<TIH309UVU0030=VKTP2JIY<0VVJC0080VVJC102LIY8509iX
TP@0XFZB00<0VW:T0:E^T`2UKY<00P2KLjD30:UbU@0509afY`2^N9P0[WRH0:ihV02NNj/0102cP9d0
0`2QP[80^X^T0;Z;Y0020:B;^P<0_iV`00D0YiO5o`000033ZKl0`jVo0:VSd0020<6gd0<0ZZgJ00@0
^[kM0:^eh02[]N00ZkGP0P2Y_>L00`2Z^N@0ZKgX0:Vmj0060:Vmj003o`000?oooooooooo013ooooo
000;ooooo`03o`000?oooooooooo01Sooooo0P39SID2ooooo`<0^WjB0ol000020:ebT080ZKgX0`2T
JXl0102Y_NP0000>09eUSP2MIHh20:Vmj0030000002IHXl0VF:?0080ZKgX00<0000009MRT@3A_cT0
0`2Y_NP00`3ae680ZKgX0:Vmj01D0:Vmj003o`00002Y_NP0ZKgX01@0ZKgX00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Oooooo`?o0000<`2Y_NP40;Z7WP@0`X^I0P2IJ9P20<bAUP<0VFJD
00<0fI^B09YVT`2JIY<00P2JIY<409aVTPD0WVRB102QJY801@2JLZ@0YFjC0:E^T`2UKY<0Vg>U00<0
ZG:E00D0W7JW0:ihV02^N9P0[WRH09ikZ`040;>0W@050:62/P2jRj@0^X^T0;Z;Y02TRkX00`2oVK02
0<>Y_`03o`000033ZKl0`KO@00<0`KO@00D0ZZgJ0;Zng@2j_]d0^[kM0:^eh0020;?0i0<0Z[WT0P2Y
_NP20:ZliP80ZKgX00<0ZKgWo`000?ooool04Oooool000_ooooo00?o0000ooooooooool06?ooool2
0<V=U@;ooooo0ol00002ooooo`<0[G:@0P2Y_NP30:AZS`040:Vmj00000h0WFF>09eUSP80ZKgX00<0
000009URS`2IHXl00P2Y_NP00`000000Uf:A0=6o>@1J0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Looooo`?o00000ooooolc0:Vmj00400003`2j
Qih0^XNN0;Z7WP@0`X^I0P2IJ9P20<bAUP<0VFJD0P3IVi8309YVT`@0W6JB1@2NJ9840:5ZTP@0YFjC
00D0Vg>U0:UbU@2YLYD0ZG:E09afY`030:ihV00309ikZ`2cP9d0/h2M0080/h2M102jRj@40;nI/003
00000033ZKoo00000080XN:<0P31]m020<Cjj@80^[kM00<0^Mgb0;?0i02c`>@00P2c`>@01P2Z^N@0
[[oW0:joi`2^_nL0Z[cV0:^nj0@0ZKgW00?o0000ooooooooool03oooool000_ooooo00?o0000oooo
ooooool06?ooool01039SIGo0000o`000?l000030;YnTP;ooooo0P2]LY030:Vmj080Y6Z?0P2Y_NP0
0`0000h0WFF>09eUSP030:Vmj080VF:?0P2Y_NP00`000000Uf:A0:Vmj01K0:Vmj003o`00002Y_NP0
ZKgX01D0ZKgX00?o0000ooooooooool05oooool00ol0003oooooooooo`0Iooooo`?o00001ooooolb
0:Vmj00400003`2jQih0^XNN0;Z7WP@0`X^I0P2IJ9P20<bAUP<0VFJD0P3IVi8309YVT`@0W6JB1@2N
J9840:5ZTP@0YFjC102YLYD40:ihV0D0/h2M102jRj@30;nI/080000000D0`jVo0:7RS?l00000XN:<
0<6gd0020<Cjj@80U<?g0`2igO820;?0i080/<_^0P2^_nL0102/`n/0ZkkX0:^nj02[_^P20:Vmi`03
0:Znj?l0003o0000013ooooo000;ooooo`03o`000?oooooooooo01Kooooo0ol00003ooooo`80^WjB
0_ooool010000300[G:@0:ebT?ooool20:Vmj080Y6Z?0P2Y_NP309eUSP<0ZKgX0P2IHXl20:Vmj003
0000002GHY40ZKgX05`0ZKgX00?o00000:Vmj02Y_NP0502Y_NP00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01Kooooo0ol0000;oooooc80ZKgX0P2jQih00`2Y_NP0`X^I0<:;V@020<:;V@80
VFRH0P3<TIH309UVU080fI^B0`2JIY<409aVTPD0WVRB102QJY840:E^T`@0ZG:E102^N9P50;>0W@<0
^X^T0P0001l00`2oVK00YkcY0:Nlj@0208Rbl@030:Rmj02M^Nco00000080WKW/0P2D`oL00`2U_>X0
X[o^0::okP020::okP80/<_^00<0Y[kZ0:c3j`2/`n/00P2/`n/00`2[_^P0Z[oY0:Zoj@030:Znj003
o`000?oooooooooo00kooooo000;ooooo`03o`000?oooooooooo01Cooooo0_l00002ooooo`040<V=
UOooooooooooooooo`80^WjB0_ooool00`000300[G:@0:ebT002ooooo`0300007P2TJXl0Y6Z?0080
ZKgX0`2MIHh30:Vmj00309URS`2Y_NP0ZKgX0080ZKgX00<0Uf:A0:Vmj02Y_NP0G02Y_NP00ol00000
ZKgX0:Vmj00C0:Vmj003o`000?oooooooooo01Oooooo00?o0000ooooooooool05?ooool2o`0000oo
oooo<@2Y_NP0102jQih0ZKgX0:Vmj00n05440<:;V@0309UXV03<TIH0c96F00<0VFJD0P3IVi8209YV
T`80ijN<0`2LIY800`3f]X40WVRB09iXTP0209iXTP@0XFZB102UKY<40:UbU@@0[WRH102cP9d01000
02h0^X^T0;Z;Y02jRj@20:Vmj0030;nI/02W_>T0ZKgX00@0Z;gX00<0WKW/o`00002Y_NP0102U_>X2
0::okP030:Rmj02V_^X0Y[kZ0080Y[kZ0P2/`n/20:Rmj@<0Z[oY00<0Z[kXooooool000004?ooool0
00[ooooo00?o0000ooooooooool04_ooool3o`0000Cooooo00@0bHfEoooooooooooooooo0P2jOY82
ooooo`030000<02]LY00[G:@00;ooooo0`2TJXl20:Vmj0<0WFF>0`2Y_NP00`2IHXl0ZKgX0:Vmj002
0:Vmj00309MRT@2Y_NP0ZKgX05`0ZKgX00?o00000:Vmj02Y_NP03@2Y_NP6ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool04_ooool3o`0001;ooooo<02Y_NP0102jQih0ZKgX0:Vmj02Y
_NP40<:;V@<0c96F0P2IIY@30=VKTP80VVJC0P3WYh`309aVTP030?JfP@2NJ980WVRB0080WVRB102Q
JY840:E^T`@0ZG:E00D0000A0:ihV02^N9P0[WRH0000:0030;>0W@80000^0P2jRj@60:Vmj080Z;gX
0P2Y_NP00ol00000ZKgX0:Vmj0020:FljP80ZKgX0`2X_NP20:JnjP80ZKgX0P2X_NT6ooooo`03o`00
0?oooooooooo00kooooo000:ooooo`03o`000?oooooooooo00oooooo0ol00007ooooo`040<V=UOoo
ooooooooooooo`80^WjB0_ooool30:ebT0;ooooo0`2TJXl20:Vmj080WFF>102Y_NP00`2IHXl0ZKgX
0:Vmj0020:Vmj0030=6o>@2Y_NP0ZKgX05d0ZKgX00?o00000:Vmj02Y_NP02@2Y_NP:ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool03oooool3o`0001Kooooo<`2Y_NP40<:;V@<0c96F
0P2IIY@30=VKTP80VVJC0P3WYh`309aVTP030?JfP@2NJ980WVRB0080WVRB102QJY840:E^T`050<BU
5P2YLYD0ZG:E0:UbU@0001400`2^N9P0100002P0/h2M0;>0W@2cP9d20000;P030;Z;Y02Y_NP0ZKgX
00X0ZKgX00?o00000:Vmj02Y_NP02@2Y_NP:ooooo`03o`000?oooooooooo00gooooo000:ooooo`03
o`000?oooooooooo00cooooo0ol0000>ooooo`80^WjB0_ooool30:ebT0;ooooo0P2TJXl00oooool0
ZKgX0:Vmj00209eUSP@0ZKgX00<0VF:?0:Vmj02Y_NP0H`2Y_NP00ol00000ZKgX0:Vmj0050:Vmj0go
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0<ooooo`?o00006_oooolb0:Vmj0@0
`X^I0`3<TIH209UVU0<0fI^B0P2JIY<20>NWS080W6JB0P3f]X4409iXTP@0XFZB00D0l;i50:E^T`2U
KY<0YFjC0<BU5P030:UbU@0500004@2^N9P0[WRH0:ihV00002P00`2cP9d00`2Y_NP0000^0;Z;Y00=
0:Vmj003o`00002Y_NP0ZKgX00D0ZKgX3Oooool00ol0003oooooooooo`0=ooooo`002_ooool00ol0
003oooooooooo`09ooooo`?o00004Oooool0102jOY;oooooooooooooool20:ebT0?ooooo0P2TJXl2
ooooo`030:Vmj02MIHh0WFF>00@0ZKgX00<0VF:?0:Vmj02Y_NP0H`2Y_NP00ol00000ZKgX0:Vmj002
0:Vmj13ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`?o00007_oooola
0:Vmj0@0`X^I0`3<TIH209UVU0<0fI^B0P2JIY<20>NWS080W6JB0P3f]X4409iXTP050?k1J`2QJY80
XFZB0:5ZTP3`_TD00`2UKY<01@34YAH0ZG:E0:UbU@2YLYD0000A00<0[WRH00<0000X0;>0W@2cP9d0
0`2Y_NP00`2jRj@0ZKgX0:Vmj00;0:Vmj003o`00002Y_NP0ZKgX0080ZKgX4?ooool00ol0003ooooo
ooooo`0=ooooo`002_ooool00ol0003oooooooooo`06ooooo`?o00005?ooool0102jOY;ooooooooo
ooooool20:ebT0?ooooo0P2TJXl3ooooo`80WFF>102Y_NP00`2IHXl0ZKgX0:Vmj01T0:Vmj003o`00
0?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`?o0000
8_ooool`0:Vmj0@0`X^I103<TIH0102IIY@0fI^B0=VKTP3IVi8209YVT`80ijN<0P2LIY820?JfP@<0
WVRB0P3n`F/30:5ZTP050?2nA@2UKY<0YFjC0:E^T`34YAH00`2YLYD01@000140[WRH0:ihV02^N9P0
000X0080/h2M4P2Y_NP00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo000:oooo
o`03o`000?oooooooooo00?ooooo0ol0000Gooooo`040;YnT_ooooooooooooooo`80[G:@0oooool2
0:AZS`?ooooo0P2MIHh40:Vmj00309URS`2Y_NP0ZKgX0600ZKgX1Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool3o`0002Kooooo<02Y_NP2
0<:;V@030:Vmj03<TIH0c96F0080c96F00@0VFJD0=VKTP3IVi80fI^B0P2JIY<20>NWS080W6JB0P3f
]X4309iXTP80o/5[0`2QJY801@3`_TD0YFjC0:E^T`2UKY<0a:DF00<0ZG:E00D0000A0:ihV02^N9P0
[WRH0000:0020;>0W@h0ZKgX1Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00go
oooo0009ooooo`04o`000?ooooooooooooooo`?o00006_ooool0102jOY;oooooooooooooool20:eb
T0?ooooo0P2TJXl3ooooo`0309eUSP000000ZKgX06<0ZKgX2Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Cooooo00Co0000oooooooooooooooo0ol0000Zooooobl0ZKgX00<0`X^I
0:Vmj02Y_NP0103<TIH0102IIY@0fI^B0=VKTP3IVi8209YVT`80ijN<0P2LIY820?JfP@<0WVRB0P3n
`F/20:5ZTP80l;i50`2UKY<01034YAH0ZG:E0:UbU@2YLYD200004@80[WRH00<0ZKgX0000:02cP9d0
2`2Y_NP9ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool000Wooooo1?l0
000Mooooo`040;YnT_ooooooooooooooo`80[G:@0oooool20:AZS`?ooooo00@0WFF>oooooooooooo
ooooG`2Y_NP<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool4o`0002oo
oooo;@2Y_NP00`32RiT0ZKgX0:Vmj0040<bAUP@0fI^B0P2JIY<20>NWS080W6JB0P3f]X4309iXTP80
o/5[0P2QJY820?2nA@<0YFjC00@0a:DF0:UbU@2YLYD0ZG:E0P0001401@2^N9P0ZKgX0:Vmj00002P0
/h2M00P0ZKgX3?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo0009oooo
o`;o00008oooool00`2]LY3oooooooooo`02ooooo`030:AZSooooooooooo00;ooooo00@0WFF>oooo
ooooooooooooG@2Y_NP?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool2
o`00037ooooo<02Y_NP40<bAUP@0fI^B0P2JIY<20>NWS080W6JB0P3f]X4309iXTP80o/5[0P2QJY82
0?2nA@<0YFjC00@0a:DF0:UbU@2YLYD0ZG:E0P0001400`2^N9P0ZKgX0:Vmj0080:Vmj0oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`002oooool00ol0003oooooooooo`0P
ooooo`030:ebT?oooooooooo00;ooooo00<0Y6Z?ooooooooool00_ooool00`2MIHkoooooooooo`02
oooooeT0ZKgX4oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0;oooool_0:Vmj00405hQJ`3<TIH0c96F0<bAUP@0fI^B0P2JIY<20>NWS080W6JB0P3f
]X4309iXTP80o/5[0P2QJY820?2nA@<0YFjC0P34YAH20:UbU@80000A00<0[WRH0:Vmj02Y_NP01@2Y
_NPCooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool000cooooo00?o0000
ooooooooool07oooool00`2]LY3oooooooooo`02ooooo`030:AZSooooooooooo00;ooooo00<0WFF>
ooooooooool01?oooomA0:Vmj1[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo033ooooo;@2Y_NP0101N8F/0c96F0<bAUP3<TIH40=VKTP80VVJC0P3W
Yh`209aVTP<0m[J10P2NJ9820?k1J`80XFZB0P3`_TD30:E^T`80a:DF00H0ZG:E0:Vmj0000140000A
0:ihV02Y_NPJooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool000gooooo
00?o0000ooooooooool07_ooool00`2]LY3oooooooooo`02ooooo`030:AZSooooooooooo00;ooooo
00<0WFF>ooooooooool01?oooom?0:Vmj1cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo02oooooo;P2Y_NP30<bAUPD0fI^B00<0VVJC0>NWS03WYh`0
0P2LIY830?JfP@80WVRB0P3n`F/20:5ZTP<0l;i50P2UKY<20<BU5P050:UbU@2Y_NP0ZKgX00004@2^
N9P06oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo000>ooooo`;o0000
7_ooool00`2]LY3oooooooooo`02ooooo`030:AZSooooooooooo00[oooooB`2Y_NPPooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool06?ooool2o`00033ooooo;@2Y_NP20<bAUP030:Vm
j03IVi80fI^B00<0fI^B0`3WYh`209aVTP<0m[J10P2NJ9820?k1J`80XFZB0`3`_TD01@2UKY<0a:DF
0<BU5P34YAH0ZG:E00;ooooo0P00014Looooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool0013ooooo00?o0000ooooooooool08?ooool00`2TJXooooooooooo`0<ooooodH0ZKgX
9?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
;oooool[0:Vmj0040<bAUP2Y_NP0ZKgX0:Vmj0@0fI^B0`3WYh`209aVTP<0m[J10P2NJ9820?k1J`80
XFZB0`3`_TD01@2UKY<0a:DF0<BU5P34YAH0ZG:E00?ooooo00<0000Aooooooooool06oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo000Aooooo`03o`000?oooooooooo02oo
oooo@02Y_NPZooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0_ooooobX0ZKgX00@0c96F0:Vmj02Y_NP0ZKgX103IVi830>NWS080W6JB0`3f]X4209iX
TP80o/5[0P2QJY830?2nA@050:E^T`34YAH0a:DF0<BU5P2YLYD08_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00cooooo000Booooo`03o`000?oooooooooo02oooooo?@2Y_NP/oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0_oooo
obd0ZKgX103IVi830>NWS080W6JB0`3f]X4209iXTP80o/5[0P2QJY830?2nA@050:E^Toooool0a:DF
0<BU5P2YLYD08_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo000Coooo
o`;o0000<?ooooli0:Vmj33ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Loooo
o`;o0000<?ooool/0:Vmj0@0fI^B103WYh`0102LIY80m[J10?JfP@3f]X4209iXTP80o/5[0P2QJY83
0?2nA@050:E^Toooool0a:DF0<BU5P2YLYD08oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00_ooooo000Eooooo`03o`000?oooooooooo02oooooo<P2Y_NPfooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0_ooooobX0ZKgX103IVi84
0>NWS0@0m[J10P2NJ9820?k1J`80XFZB0`3`_TD00`2UKY?oooooooooo`020<BU5RCooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`005_ooool00ol0003oooooooooo`0^oooo
obl0ZKgX>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0;_ooool[0:Vmj0<0fI^B103WYh`40?JfP@80WVRB0P3n`F/20:5ZTP<0l;i500D0YFjCoooo
oooooooooooo0<BU5P0Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool0
01Oooooo00?o0000ooooooooool0;_ooool/0:Vmj3cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02kooooo:P2Y_NP20=VKTP03ooooo`3WYh`0ijN<
0080ijN<103f]X4209iXTP80o/5[0P2QJY830?2nA@050:E^Toooooooooooooooo`34YAH09Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo000Hooooo`;o0000<?oooolW0:Vm
j43ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`;o0000<?oooolW0:Vm
j004ooooo`3IVi;oooooooooo`@0ijN<103f]X4209iXTP<0o/5[00D0XFZB0?2nA@3`_TD0l;i50:E^
T`0Zooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool001[ooooo00?o0000
ooooooooool0;OoooolR0:Vmj4Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo02gooooo8P2Y_NP:ooooo`<0ijN<103f]X400`2NJ980o/5[0?k1J`02
0?k1J`030:5ZT_ooool0l;i50080l;i5:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00[ooooo000Kooooo`03o`000?oooooooooo02gooooo7`2Y_NQ9ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0]oooooal0ZKgX3?ooool30>NW
S0D0m[J1103n`F/00`3`_TGoooooooooo`020?2nABcooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`0^oooooaP0ZKgXC_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0;_oooolH0:Vmj17o
oooo0`3WYh`50?JfP@@0o/5[00<0l;i5ooooooooool00P3`_TD/ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02_ooool001gooooo00?o0000ooooooooool0;_oooolD0:Vmj5;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02kooooo
502Y_NPDooooo`80ijN<0_ooool40?JfP@@0o/5[00D0l;i5oooooooooooooooo0?2nA@0]ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool001kooooo0_l0000_oooooa40ZKgX
EOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo0_l0000^oooooa80ZKgX
6oooool30?JfP@040?k1Joooool0o/5[0?k1Jc?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`008?ooool00ol0003oooooooooo`0]ooooo`/0ZKgXF_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0;?ooool<0:Vmj2;ooooo
00D0m[J10?k1Jooooooooooo0?k1J`0cooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool0027ooooo00?o0000ooooooooool0;Oooool80:Vmj5gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02gooooo1`2Y_NPYooooo`030?k1
Jooooooooooo03;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`008_oo
ool00ol0003oooooooooo`0]ooooo`@0ZKgXHOooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0;Oooool40:Vmj67ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`008oooool2o`0002gooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo0_l0000]ooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Hoooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo000Vooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0I?ooool01Ol0003ooooooooooooooooo000002oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1Tooooo`05o`000?ooooooooooooooool000002oooool0
02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Uooooo`04o`000?oooooooooo
o`00033ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Uooooo`04o`000?oooooo
ooooo`0000_ooooo000Xooooo`;o0000:?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo
0000037ooooo0_l0000Xooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool000002oooool0
02[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo0000
03?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo0000
00_ooooo000[ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooo`00000cooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooo`00000:ooooo`00;?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Sooooo
0_l0000dooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J?ooool2o`0000[ooooo
000]ooooo`;o00008oooool00ol0003oooooooooo`1Wooooo`?o0000=Oooool2o`0002?ooooo00?o
0000ooooooooool0Ioooool3o`0000[ooooo000_ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0Hoooool4o`0003[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1S
ooooo`Co00003Oooool0033ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Poooo
o`?o0000?oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo063ooooo0ol0000Aoooo
o`00<Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05cooooo1?l00013ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0G?ooool4o`0001Cooooo000booooo`;o0000
7_ooool00ol0003oooooooooo`1Hooooo`Co0000B?ooool2o`0001kooooo00?o0000ooooooooool0
F?ooool4o`0001Sooooo000dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E?oo
ool4o`0004kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Dooooo`Co00007?oo
ool003Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`?o0000Doooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo0ol0000Pooooo`00=_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04gooooo1?l0001Gooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0COooool4o`0002?ooooo000gooooo`;o00006Oooool00ol0003o
ooooooooo`19ooooo`Co0000G?ooool2o`0001Wooooo00?o0000ooooooooool0BOooool4o`0002Oo
oooo000iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOooool4o`0006;ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`Co0000:oooool003[ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`13ooooo`?o0000Ioooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04?ooooo0ol0000_ooooo`00>oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo03oooooo1?l0001[ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0?oooool4o`0003;ooooo000looooo`;o00004oooool00ol0003oooooooooo`0koooo
o`Co0000L?ooool2o`0001?ooooo00?o0000ooooooooool0>oooool4o`0003Kooooo000nooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0=oooool4o`0007Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0gooooo`Co0000>_ooool003oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0cooooo`Co0000Noooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03?ooooo1?l0000nooooo`00@?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo033ooooo0ol00020ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?oo
ool3o`0004;ooooo0011ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool4
o`0008Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`Co0000AOooool0
04;ooooo0_l0000=ooooo`03o`000?oooooooooo02Sooooo1?l00029ooooo`;o00003Oooool00ol0
003oooooooooo`0Xooooo`Co0000BOooool004Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Tooooo`Co0000Soooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Co
oooo1?l0001=ooooo`00AOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo
0ol0002Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`00057ooooo
0016ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`0009Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co0000E?ooool004Oooooo0_l00008
ooooo`03o`000?oooooooooo01Wooooo1?l0002Mooooo`;o00002?ooool00ol0003oooooooooo`0I
ooooo`Co0000F?ooool004Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eoooo
o`Co0000Xoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0001Loooo
o`00B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol0002Xooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool3o`00063ooooo001;ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000:cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0>ooooo`Co0000Hoooool004cooooo0_l00003ooooo`03o`000?oo
oooooooo00[ooooo1?l0002aooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000Iooo
ool004kooooo00Co0000oooooooooooo00002?ooool4o`000;Oooooo00Co0000oooooooooooo0000
2?ooool4o`0006_ooooo001?ooooo`03o`000?oooooo000000Gooooo0ol0002looooo`03o`000?oo
oooo000000Gooooo0ol0001_ooooo`00D?ooool2o`000003ooooool0003o000000;o0000`?ooool2
o`000003ooooool0003o000000;o0000L_ooool0057ooooo0_l00035ooooo`;o0000M_ooool00?oo
ooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oo
ooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-53.3508, \
-19.1129, 1.80794, 1.80794}, {{208.5, 389.375}, {315.688, 169}} -> {-412.962, \
-19.1129, 1.80794, 1.80794}, {{9.625, 190.438}, {154.375, 7.6875}} -> \
{-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, 389.375}, {154.375, \
7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[p1rb, p2rb, {{0, 255}, {0, 255}}, x, y, \ 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .03328 m
.02974 .04389 L
.04389 .06099 L
.04707 .06854 L
.06854 .09156 L
.06921 .0932 L
.09172 .11785 L
.0932 .11956 L
.11469 .1425 L
.11785 .14599 L
.13829 .16716 L
.1425 .1716 L
.16249 .19181 L
.16716 .19648 L
.18735 .21647 L
.19181 .22072 L
.21293 .24112 L
.21647 .24434 L
.23932 .26578 L
.24112 .26733 L
.26578 .28985 L
.26721 .29043 L
.29043 .31202 L
.29771 .31509 L
.31509 .33315 L
.3293 .33974 L
.33974 .35286 L
.36022 .3644 L
.3644 .37059 L
.38905 .38634 L
.39477 .38905 L
.41371 .39906 L
.43081 .38905 L
.4176 .3644 L
.41371 .35208 L
.40195 .33974 L
.38905 .31701 L
.38678 .31509 L
.3685 .29043 L
.3644 .28507 L
.34844 .26578 L
.33974 .25517 L
.32737 .24112 L
.31509 .22697 L
.30541 .21647 L
.29043 .19997 L
.28267 .19181 L
.26578 .17388 L
.25923 .16716 L
.24112 .14853 L
.23515 .1425 L
.21647 .12383 L
.21044 .11785 L
.19181 .09976 L
.18508 .0932 L
.16716 .07633 L
.15898 .06854 L
.1425 .05359 L
.13197 .04389 L
.11785 .02959 L
.10375 .01923 L
.01923 .01923 L
F
0 g
.01923 .03328 m
.02974 .04389 L
.04389 .06099 L
.04707 .06854 L
.06854 .09156 L
.06921 .0932 L
.09172 .11785 L
.0932 .11956 L
.11469 .1425 L
.11785 .14599 L
.13829 .16716 L
.1425 .1716 L
.16249 .19181 L
.16716 .19648 L
.18735 .21647 L
.19181 .22072 L
.21293 .24112 L
.21647 .24434 L
.23932 .26578 L
.24112 .26733 L
.26578 .28985 L
.26721 .29043 L
.29043 .31202 L
.29771 .31509 L
.31509 .33315 L
.3293 .33974 L
.33974 .35286 L
.36022 .3644 L
.3644 .37059 L
.38905 .38634 L
.39477 .38905 L
.41371 .39906 L
.43081 .38905 L
.4176 .3644 L
.41371 .35208 L
.40195 .33974 L
.38905 .31701 L
.38678 .31509 L
.3685 .29043 L
.3644 .28507 L
.34844 .26578 L
.33974 .25517 L
.32737 .24112 L
.31509 .22697 L
.30541 .21647 L
.29043 .19997 L
.28267 .19181 L
.26578 .17388 L
.25923 .16716 L
.24112 .14853 L
Mistroke
.23515 .1425 L
.21647 .12383 L
.21044 .11785 L
.19181 .09976 L
.18508 .0932 L
.16716 .07633 L
.15898 .06854 L
.1425 .05359 L
.13197 .04389 L
.11785 .02959 L
.10375 .01923 L
Mfstroke
.2 g
.08868 .01923 m
.0932 .02247 L
.11785 .04378 L
.11796 .04389 L
.1425 .06508 L
.14647 .06854 L
.16716 .08736 L
.17353 .0932 L
.19181 .11053 L
.19945 .11785 L
.21647 .13458 L
.2244 .1425 L
.24112 .15951 L
.24846 .16716 L
.26578 .18542 L
.27165 .19181 L
.29043 .21246 L
.29393 .21647 L
.31509 .24094 L
.31524 .24112 L
.33457 .26578 L
.33974 .27019 L
.35255 .29043 L
.3644 .30254 L
.37017 .31509 L
.3865 .33974 L
.3644 .35295 L
.34377 .33974 L
.33974 .33742 L
.31509 .31985 L
.31318 .31509 L
.29043 .30073 L
.28546 .29043 L
.26578 .28 L
.25719 .26578 L
.24112 .25805 L
.22296 .24112 L
.21647 .23515 L
.19703 .21647 L
.19181 .21146 L
.17192 .19181 L
.16716 .18705 L
.14754 .16716 L
.1425 .16191 L
.12388 .1425 L
.11785 .13595 L
.10101 .11785 L
.0932 .10163 L
.0791 .0932 L
.06854 .07335 L
.05841 .06854 L
.04389 .04567 L
.04036 .04389 L
.02101 .01923 L
F
0 g
.08868 .01923 m
.0932 .02247 L
.11785 .04378 L
.11796 .04389 L
.1425 .06508 L
.14647 .06854 L
.16716 .08736 L
.17353 .0932 L
.19181 .11053 L
.19945 .11785 L
.21647 .13458 L
.2244 .1425 L
.24112 .15951 L
.24846 .16716 L
.26578 .18542 L
.27165 .19181 L
.29043 .21246 L
.29393 .21647 L
.31509 .24094 L
.31524 .24112 L
.33457 .26578 L
.33974 .27019 L
.35255 .29043 L
.3644 .30254 L
.37017 .31509 L
.3865 .33974 L
.3644 .35295 L
.34377 .33974 L
.33974 .33742 L
.31509 .31985 L
.31318 .31509 L
.29043 .30073 L
.28546 .29043 L
.26578 .28 L
.25719 .26578 L
.24112 .25805 L
.22296 .24112 L
.21647 .23515 L
.19703 .21647 L
.19181 .21146 L
.17192 .19181 L
.16716 .18705 L
.14754 .16716 L
.1425 .16191 L
.12388 .1425 L
.11785 .13595 L
.10101 .11785 L
.0932 .10163 L
.0791 .0932 L
.06854 .07335 L
Mistroke
.05841 .06854 L
.04389 .04567 L
.04036 .04389 L
.02101 .01923 L
Mfstroke
.3 g
.07767 .01923 m
.0932 .02992 L
.10973 .04389 L
.11785 .05261 L
.13865 .06854 L
.1425 .0731 L
.16636 .0932 L
.16716 .09487 L
.19177 .11785 L
.19181 .1179 L
.21647 .14202 L
.21696 .1425 L
.24109 .16716 L
.24112 .16719 L
.26414 .19181 L
.26578 .19262 L
.28593 .21647 L
.29043 .22027 L
.30644 .24112 L
.31509 .24914 L
.32586 .26578 L
.33974 .28109 L
.34467 .29043 L
.36016 .31509 L
.33974 .3266 L
.3224 .31509 L
.31509 .31063 L
.29043 .29195 L
.29008 .29043 L
.26578 .27229 L
.26437 .26578 L
.24112 .25108 L
.23022 .24112 L
.21647 .22863 L
.20368 .21647 L
.19181 .20513 L
.17828 .19181 L
.16716 .18068 L
.15387 .16716 L
.1425 .15525 L
.13041 .1425 L
.11785 .12867 L
.108 .11785 L
.0932 .09454 L
.08683 .0932 L
.06854 .06884 L
.06723 .06854 L
.04857 .04389 L
.04389 .03988 L
.03037 .01923 L
F
0 g
.07767 .01923 m
.0932 .02992 L
.10973 .04389 L
.11785 .05261 L
.13865 .06854 L
.1425 .0731 L
.16636 .0932 L
.16716 .09487 L
.19177 .11785 L
.19181 .1179 L
.21647 .14202 L
.21696 .1425 L
.24109 .16716 L
.24112 .16719 L
.26414 .19181 L
.26578 .19262 L
.28593 .21647 L
.29043 .22027 L
.30644 .24112 L
.31509 .24914 L
.32586 .26578 L
.33974 .28109 L
.34467 .29043 L
.36016 .31509 L
.33974 .3266 L
.3224 .31509 L
.31509 .31063 L
.29043 .29195 L
.29008 .29043 L
.26578 .27229 L
.26437 .26578 L
.24112 .25108 L
.23022 .24112 L
.21647 .22863 L
.20368 .21647 L
.19181 .20513 L
.17828 .19181 L
.16716 .18068 L
.15387 .16716 L
.1425 .15525 L
.13041 .1425 L
.11785 .12867 L
.108 .11785 L
.0932 .09454 L
.08683 .0932 L
.06854 .06884 L
.06723 .06854 L
.04857 .04389 L
.04389 .03988 L
.03037 .01923 L
Mistroke
Mfstroke
.4 g
.06854 .02092 m
.0932 .03711 L
.10163 .04389 L
.11785 .05815 L
.13239 .06854 L
.1425 .07871 L
.16488 .0932 L
.16716 .10033 L
.18825 .11785 L
.19181 .12304 L
.21233 .1425 L
.21647 .14667 L
.23596 .16716 L
.24112 .17077 L
.25868 .19181 L
.26578 .19424 L
.28031 .21647 L
.29043 .2265 L
.30089 .24112 L
.31509 .25718 L
.32047 .26578 L
.33702 .29043 L
.31509 .30271 L
.29793 .29043 L
.29043 .28544 L
.26599 .26578 L
.26578 .26562 L
.24112 .24499 L
.23679 .24112 L
.21647 .22291 L
.20961 .21647 L
.19181 .19957 L
.1839 .19181 L
.16716 .17506 L
.15943 .16716 L
.1425 .1493 L
.13613 .1425 L
.11785 .12206 L
.1141 .11785 L
.09349 .0932 L
.0932 .0928 L
.07373 .06854 L
.06854 .06072 L
.05656 .04389 L
F
0 g
.06854 .02092 m
.0932 .03711 L
.10163 .04389 L
.11785 .05815 L
.13239 .06854 L
.1425 .07871 L
.16488 .0932 L
.16716 .10033 L
.18825 .11785 L
.19181 .12304 L
.21233 .1425 L
.21647 .14667 L
.23596 .16716 L
.24112 .17077 L
.25868 .19181 L
.26578 .19424 L
.28031 .21647 L
.29043 .2265 L
.30089 .24112 L
.31509 .25718 L
.32047 .26578 L
.33702 .29043 L
.31509 .30271 L
.29793 .29043 L
.29043 .28544 L
.26599 .26578 L
.26578 .26562 L
.24112 .24499 L
.23679 .24112 L
.21647 .22291 L
.20961 .21647 L
.19181 .19957 L
.1839 .19181 L
.16716 .17506 L
.15943 .16716 L
.1425 .1493 L
.13613 .1425 L
.11785 .12206 L
.1141 .11785 L
.09349 .0932 L
.0932 .0928 L
.07373 .06854 L
.06854 .06072 L
.05656 .04389 L
.06854 .02092 L
s
.5 g
.06854 .02945 m
.09169 .04389 L
.0932 .04468 L
.11785 .06246 L
.12607 .06854 L
.1425 .08274 L
.16364 .0932 L
.16716 .10418 L
.18613 .11785 L
.19181 .12657 L
.20935 .1425 L
.21647 .14967 L
.23244 .16716 L
.24112 .17294 L
.25484 .19181 L
.26578 .19554 L
.27629 .21647 L
.29043 .23278 L
.2966 .24112 L
.31452 .26578 L
.31509 .26683 L
.32397 .29043 L
.31509 .29363 L
.30954 .29043 L
.29043 .27929 L
.27292 .26578 L
.26578 .26056 L
.24284 .24112 L
.24112 .23972 L
.21647 .21766 L
.21518 .21647 L
.19181 .19444 L
.18912 .19181 L
.16716 .16983 L
.16456 .16716 L
.1425 .14371 L
.14139 .1425 L
.11936 .11785 L
.11785 .116 L
.09857 .0932 L
.0932 .08581 L
.07992 .06854 L
.06854 .04879 L
.06579 .04389 L
F
0 g
.06854 .02945 m
.09169 .04389 L
.0932 .04468 L
.11785 .06246 L
.12607 .06854 L
.1425 .08274 L
.16364 .0932 L
.16716 .10418 L
.18613 .11785 L
.19181 .12657 L
.20935 .1425 L
.21647 .14967 L
.23244 .16716 L
.24112 .17294 L
.25484 .19181 L
.26578 .19554 L
.27629 .21647 L
.29043 .23278 L
.2966 .24112 L
.31452 .26578 L
.31509 .26683 L
.32397 .29043 L
.31509 .29363 L
.30954 .29043 L
.29043 .27929 L
.27292 .26578 L
.26578 .26056 L
.24284 .24112 L
.24112 .23972 L
.21647 .21766 L
.21518 .21647 L
.19181 .19444 L
.18912 .19181 L
.16716 .16983 L
.16456 .16716 L
.1425 .14371 L
.14139 .1425 L
.11936 .11785 L
.11785 .116 L
.09857 .0932 L
.0932 .08581 L
.07992 .06854 L
.06854 .04879 L
.06579 .04389 L
.06854 .02945 L
s
.6 g
.0932 .05376 m
.11785 .0676 L
.11901 .06854 L
.1425 .08651 L
.1591 .0932 L
.16716 .10747 L
.18354 .11785 L
.19181 .12954 L
.20671 .1425 L
.21647 .15232 L
.22949 .16716 L
.24112 .17553 L
.25156 .19181 L
.26578 .19997 L
.27254 .21647 L
.29043 .23976 L
.29154 .24112 L
.3056 .26578 L
.29043 .27258 L
.28081 .26578 L
.26578 .25549 L
.24839 .24112 L
.24112 .23532 L
.22002 .21647 L
.21647 .21334 L
.19377 .19181 L
.19181 .18994 L
.16906 .16716 L
.16716 .16518 L
.1457 .1425 L
.1425 .13887 L
.12376 .11785 L
.11785 .11041 L
.10366 .0932 L
.0932 .0778 L
.0867 .06854 L
F
0 g
.0932 .05376 m
.11785 .0676 L
.11901 .06854 L
.1425 .08651 L
.1591 .0932 L
.16716 .10747 L
.18354 .11785 L
.19181 .12954 L
.20671 .1425 L
.21647 .15232 L
.22949 .16716 L
.24112 .17553 L
.25156 .19181 L
.26578 .19997 L
.27254 .21647 L
.29043 .23976 L
.29154 .24112 L
.3056 .26578 L
.29043 .27258 L
.28081 .26578 L
.26578 .25549 L
.24839 .24112 L
.24112 .23532 L
.22002 .21647 L
.21647 .21334 L
.19377 .19181 L
.19181 .18994 L
.16906 .16716 L
.16716 .16518 L
.1457 .1425 L
.1425 .13887 L
.12376 .11785 L
.11785 .11041 L
.10366 .0932 L
.0932 .0778 L
.0867 .06854 L
.0932 .05376 L
s
.7 g
.11785 .07463 m
.1425 .09136 L
.14769 .0932 L
.16716 .11126 L
.17861 .11785 L
.19181 .13295 L
.20318 .1425 L
.21647 .15585 L
.22607 .16716 L
.24112 .18039 L
.24778 .19181 L
.26578 .21102 L
.26774 .21647 L
.28459 .24112 L
.26578 .25006 L
.25446 .24112 L
.24112 .23086 L
.22476 .21647 L
.21647 .20925 L
.19798 .19181 L
.19181 .18591 L
.17308 .16716 L
.16716 .16096 L
.14979 .1425 L
.1425 .1341 L
.12825 .11785 L
.11785 .10429 L
.10913 .0932 L
F
0 g
.11785 .07463 m
.1425 .09136 L
.14769 .0932 L
.16716 .11126 L
.17861 .11785 L
.19181 .13295 L
.20318 .1425 L
.21647 .15585 L
.22607 .16716 L
.24112 .18039 L
.24778 .19181 L
.26578 .21102 L
.26774 .21647 L
.28459 .24112 L
.26578 .25006 L
.25446 .24112 L
.24112 .23086 L
.22476 .21647 L
.21647 .20925 L
.19798 .19181 L
.19181 .18591 L
.17308 .16716 L
.16716 .16096 L
.14979 .1425 L
.1425 .1341 L
.12825 .11785 L
.11785 .10429 L
.10913 .0932 L
.11785 .07463 L
s
.8 g
.11785 .0848 m
.1356 .0932 L
.1425 .09757 L
.16716 .11661 L
.16946 .11785 L
.19181 .13785 L
.19749 .1425 L
.21647 .16149 L
.22117 .16716 L
.24112 .18936 L
.24247 .19181 L
.26158 .21647 L
.26578 .22301 L
.27474 .24112 L
.26578 .24361 L
.26223 .24112 L
.24112 .22609 L
.2299 .21647 L
.21647 .20502 L
.20235 .19181 L
.19181 .18178 L
.17721 .16716 L
.16716 .15658 L
.15404 .1425 L
.1425 .12893 L
.13304 .11785 L
.11785 .09635 L
.11567 .0932 L
F
0 g
.11785 .0848 m
.1356 .0932 L
.1425 .09757 L
.16716 .11661 L
.16946 .11785 L
.19181 .13785 L
.19749 .1425 L
.21647 .16149 L
.22117 .16716 L
.24112 .18936 L
.24247 .19181 L
.26158 .21647 L
.26578 .22301 L
.27474 .24112 L
.26578 .24361 L
.26223 .24112 L
.24112 .22609 L
.2299 .21647 L
.21647 .20502 L
.20235 .19181 L
.19181 .18178 L
.17721 .16716 L
.16716 .15658 L
.15404 .1425 L
.1425 .12893 L
.13304 .11785 L
.11785 .09635 L
.11567 .0932 L
.11785 .0848 L
s
.9 g
.1425 .10553 m
.16081 .11785 L
.16716 .12269 L
.18982 .1425 L
.19181 .14436 L
.21465 .16716 L
.21647 .16911 L
.23639 .19181 L
.24112 .19797 L
.25373 .21647 L
.24112 .22056 L
.23607 .21647 L
.21647 .20041 L
.20715 .19181 L
.19181 .17733 L
.18165 .16716 L
.16716 .15176 L
.15865 .1425 L
.1425 .12269 L
.13861 .11785 L
F
0 g
.1425 .10553 m
.16081 .11785 L
.16716 .12269 L
.18982 .1425 L
.19181 .14436 L
.21465 .16716 L
.21647 .16911 L
.23639 .19181 L
.24112 .19797 L
.25373 .21647 L
.24112 .22056 L
.23607 .21647 L
.21647 .20041 L
.20715 .19181 L
.19181 .17733 L
.18165 .16716 L
.16716 .15176 L
.15865 .1425 L
.1425 .12269 L
.13861 .11785 L
.1425 .10553 L
s
1 g
.16716 .13071 m
.18205 .1425 L
.19181 .15118 L
.20783 .16716 L
.21647 .17682 L
.22845 .19181 L
.21647 .19492 L
.21299 .19181 L
.19181 .17217 L
.18681 .16716 L
.16716 .14587 L
.16417 .1425 L
F
0 g
.16716 .13071 m
.18205 .1425 L
.19181 .15118 L
.20783 .16716 L
.21647 .17682 L
.22845 .19181 L
.21647 .19492 L
.21299 .19181 L
.19181 .17217 L
.18681 .16716 L
.16716 .14587 L
.16417 .1425 L
.16716 .13071 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.41371 .52653 m
.43836 .52424 L
.46302 .52758 L
.48767 .53034 L
.50974 .53698 L
.51233 .53821 L
.53698 .54701 L
.56164 .55803 L
.5687 .56164 L
.58629 .57011 L
.61095 .58387 L
.61428 .58629 L
.6356 .5987 L
.6533 .61095 L
.66026 .61501 L
.68491 .63304 L
.68684 .6356 L
.70957 .65252 L
.71607 .66026 L
.73422 .67712 L
.74274 .68491 L
.75888 .70069 L
.76593 .70957 L
.78353 .72909 L
.78614 .73422 L
.80204 .75888 L
.80819 .77145 L
.81146 .78353 L
.81199 .80819 L
.80819 .81649 L
.78353 .83189 L
.77755 .83284 L
.75888 .83337 L
.74673 .83284 L
.73422 .83078 L
.70957 .82347 L
.68491 .81779 L
.66046 .80819 L
.66026 .80807 L
.6356 .79716 L
.61095 .78455 L
.60937 .78353 L
.58629 .7708 L
.56744 .75888 L
.56164 .75566 L
.53698 .73895 L
.5322 .73422 L
.51233 .72095 L
.50002 .70957 L
.48767 .69852 L
.47103 .68491 L
.46302 .67746 L
.44601 .66026 L
.43836 .65258 L
.42505 .6356 L
.41371 .62253 L
.40771 .61095 L
.39386 .58629 L
.38905 .57082 L
.38797 .56164 L
.38905 .55084 L
.39566 .53698 L
F
0 g
.41371 .52653 m
.43836 .52424 L
.46302 .52758 L
.48767 .53034 L
.50974 .53698 L
.51233 .53821 L
.53698 .54701 L
.56164 .55803 L
.5687 .56164 L
.58629 .57011 L
.61095 .58387 L
.61428 .58629 L
.6356 .5987 L
.6533 .61095 L
.66026 .61501 L
.68491 .63304 L
.68684 .6356 L
.70957 .65252 L
.71607 .66026 L
.73422 .67712 L
.74274 .68491 L
.75888 .70069 L
.76593 .70957 L
.78353 .72909 L
.78614 .73422 L
.80204 .75888 L
.80819 .77145 L
.81146 .78353 L
.81199 .80819 L
.80819 .81649 L
.78353 .83189 L
.77755 .83284 L
.75888 .83337 L
.74673 .83284 L
.73422 .83078 L
.70957 .82347 L
.68491 .81779 L
.66046 .80819 L
.66026 .80807 L
.6356 .79716 L
.61095 .78455 L
.60937 .78353 L
.58629 .7708 L
.56744 .75888 L
.56164 .75566 L
.53698 .73895 L
.5322 .73422 L
.51233 .72095 L
.50002 .70957 L
.48767 .69852 L
Mistroke
.47103 .68491 L
.46302 .67746 L
.44601 .66026 L
.43836 .65258 L
.42505 .6356 L
.41371 .62253 L
.40771 .61095 L
.39386 .58629 L
.38905 .57082 L
.38797 .56164 L
.38905 .55084 L
.39566 .53698 L
.41371 .52653 L
Mfstroke
.2 g
.43836 .55593 m
.46302 .55102 L
.48767 .55363 L
.51233 .55944 L
.5255 .56164 L
.53698 .56673 L
.56164 .5791 L
.5828 .58629 L
.58629 .58839 L
.61095 .60493 L
.62587 .61095 L
.6356 .61807 L
.66026 .63377 L
.66219 .6356 L
.68491 .65488 L
.69271 .66026 L
.70957 .67548 L
.71952 .68491 L
.73422 .69962 L
.74213 .70957 L
.75888 .73045 L
.76068 .73422 L
.77261 .75888 L
.77537 .78353 L
.75888 .8022 L
.73422 .80651 L
.70957 .80359 L
.68491 .79641 L
.66026 .78685 L
.64574 .78353 L
.6356 .77808 L
.61095 .76342 L
.59689 .75888 L
.58629 .75163 L
.56164 .7375 L
.55756 .73422 L
.53698 .71765 L
.52409 .70957 L
.51233 .69958 L
.49477 .68491 L
.48767 .6784 L
.46998 .66026 L
.46302 .65324 L
.44984 .6356 L
.43836 .62255 L
.43433 .61095 L
.42599 .58629 L
.43218 .56164 L
F
0 g
.43836 .55593 m
.46302 .55102 L
.48767 .55363 L
.51233 .55944 L
.5255 .56164 L
.53698 .56673 L
.56164 .5791 L
.5828 .58629 L
.58629 .58839 L
.61095 .60493 L
.62587 .61095 L
.6356 .61807 L
.66026 .63377 L
.66219 .6356 L
.68491 .65488 L
.69271 .66026 L
.70957 .67548 L
.71952 .68491 L
.73422 .69962 L
.74213 .70957 L
.75888 .73045 L
.76068 .73422 L
.77261 .75888 L
.77537 .78353 L
.75888 .8022 L
.73422 .80651 L
.70957 .80359 L
.68491 .79641 L
.66026 .78685 L
.64574 .78353 L
.6356 .77808 L
.61095 .76342 L
.59689 .75888 L
.58629 .75163 L
.56164 .7375 L
.55756 .73422 L
.53698 .71765 L
.52409 .70957 L
.51233 .69958 L
.49477 .68491 L
.48767 .6784 L
.46998 .66026 L
.46302 .65324 L
.44984 .6356 L
.43836 .62255 L
.43433 .61095 L
.42599 .58629 L
.43218 .56164 L
.43836 .55593 L
s
.3 g
.46302 .5721 m
.48767 .56744 L
.51233 .57173 L
.53698 .57954 L
.55885 .58629 L
.56164 .58779 L
.58629 .60103 L
.60767 .61095 L
.61095 .61305 L
.6356 .63009 L
.64573 .6356 L
.66026 .64686 L
.67802 .66026 L
.68491 .6661 L
.7051 .68491 L
.70957 .68889 L
.727 .70957 L
.73422 .71886 L
.74332 .73422 L
.7522 .75888 L
.7445 .78353 L
.73422 .7871 L
.70957 .78852 L
.68491 .78451 L
.67787 .78353 L
.66026 .77687 L
.6356 .76574 L
.61731 .75888 L
.61095 .75518 L
.58629 .73974 L
.57461 .73422 L
.56164 .72489 L
.53915 .70957 L
.53698 .70786 L
.51233 .68694 L
.50991 .68491 L
.48767 .66308 L
.48529 .66026 L
.46556 .6356 L
.46302 .63173 L
.4527 .61095 L
.44981 .58629 L
F
0 g
.46302 .5721 m
.48767 .56744 L
.51233 .57173 L
.53698 .57954 L
.55885 .58629 L
.56164 .58779 L
.58629 .60103 L
.60767 .61095 L
.61095 .61305 L
.6356 .63009 L
.64573 .6356 L
.66026 .64686 L
.67802 .66026 L
.68491 .6661 L
.7051 .68491 L
.70957 .68889 L
.727 .70957 L
.73422 .71886 L
.74332 .73422 L
.7522 .75888 L
.7445 .78353 L
.73422 .7871 L
.70957 .78852 L
.68491 .78451 L
.67787 .78353 L
.66026 .77687 L
.6356 .76574 L
.61731 .75888 L
.61095 .75518 L
.58629 .73974 L
.57461 .73422 L
.56164 .72489 L
.53915 .70957 L
.53698 .70786 L
.51233 .68694 L
.50991 .68491 L
.48767 .66308 L
.48529 .66026 L
.46556 .6356 L
.46302 .63173 L
.4527 .61095 L
.44981 .58629 L
.46302 .5721 L
s
.4 g
.48767 .58207 m
.51233 .5827 L
.53073 .58629 L
.53698 .58796 L
.56164 .5975 L
.58629 .60888 L
.59174 .61095 L
.61095 .62251 L
.63296 .6356 L
.6356 .63744 L
.66026 .65619 L
.66575 .66026 L
.68491 .67701 L
.69282 .68491 L
.70957 .70221 L
.7144 .70957 L
.72941 .73422 L
.73352 .75888 L
.70957 .78051 L
.68491 .77413 L
.66026 .76703 L
.63611 .75888 L
.6356 .75845 L
.61095 .74578 L
.58854 .73422 L
.58629 .73279 L
.56164 .71575 L
.55204 .70957 L
.53698 .69769 L
.5219 .68491 L
.51233 .67669 L
.49746 .66026 L
.48767 .65467 L
.47899 .6356 L
.46821 .61095 L
.47786 .58629 L
F
0 g
.48767 .58207 m
.51233 .5827 L
.53073 .58629 L
.53698 .58796 L
.56164 .5975 L
.58629 .60888 L
.59174 .61095 L
.61095 .62251 L
.63296 .6356 L
.6356 .63744 L
.66026 .65619 L
.66575 .66026 L
.68491 .67701 L
.69282 .68491 L
.70957 .70221 L
.7144 .70957 L
.72941 .73422 L
.73352 .75888 L
.70957 .78051 L
.68491 .77413 L
.66026 .76703 L
.63611 .75888 L
.6356 .75845 L
.61095 .74578 L
.58854 .73422 L
.58629 .73279 L
.56164 .71575 L
.55204 .70957 L
.53698 .69769 L
.5219 .68491 L
.51233 .67669 L
.49746 .66026 L
.48767 .65467 L
.47899 .6356 L
.46821 .61095 L
.47786 .58629 L
.48767 .58207 L
s
.5 g
.48767 .60244 m
.51233 .59338 L
.53698 .5965 L
.56164 .60534 L
.5773 .61095 L
.58629 .61582 L
.61095 .62996 L
.62107 .6356 L
.6356 .64548 L
.65539 .66026 L
.66026 .6636 L
.68274 .68491 L
.68491 .68716 L
.70355 .70957 L
.70957 .71947 L
.71621 .73422 L
.70999 .75888 L
.70957 .75925 L
.68491 .76382 L
.66026 .75903 L
.65937 .75888 L
.6356 .75045 L
.61095 .73849 L
.60168 .73422 L
.58629 .72492 L
.56283 .70957 L
.56164 .70879 L
.53698 .68904 L
.53229 .68491 L
.51233 .66586 L
.50803 .66026 L
.49053 .6356 L
.48767 .62875 L
.48392 .61095 L
F
0 g
.48767 .60244 m
.51233 .59338 L
.53698 .5965 L
.56164 .60534 L
.5773 .61095 L
.58629 .61582 L
.61095 .62996 L
.62107 .6356 L
.6356 .64548 L
.65539 .66026 L
.66026 .6636 L
.68274 .68491 L
.68491 .68716 L
.70355 .70957 L
.70957 .71947 L
.71621 .73422 L
.70999 .75888 L
.70957 .75925 L
.68491 .76382 L
.66026 .75903 L
.65937 .75888 L
.6356 .75045 L
.61095 .73849 L
.60168 .73422 L
.58629 .72492 L
.56283 .70957 L
.56164 .70879 L
.53698 .68904 L
.53229 .68491 L
.51233 .66586 L
.50803 .66026 L
.49053 .6356 L
.48767 .62875 L
.48392 .61095 L
.48767 .60244 L
s
.6 g
.51233 .60557 m
.53698 .60519 L
.55731 .61095 L
.56164 .61162 L
.58629 .6228 L
.60988 .6356 L
.61095 .63617 L
.6356 .6528 L
.64548 .66026 L
.66026 .6711 L
.67305 .68491 L
.68491 .69841 L
.6931 .70957 L
.70477 .73422 L
.68491 .75222 L
.66026 .75348 L
.6356 .74313 L
.61305 .73422 L
.61095 .73248 L
.58629 .7179 L
.57319 .70957 L
.56164 .70206 L
.54169 .68491 L
.53698 .68051 L
.51766 .66026 L
.51233 .65292 L
.50181 .6356 L
.50287 .61095 L
F
0 g
.51233 .60557 m
.53698 .60519 L
.55731 .61095 L
.56164 .61162 L
.58629 .6228 L
.60988 .6356 L
.61095 .63617 L
.6356 .6528 L
.64548 .66026 L
.66026 .6711 L
.67305 .68491 L
.68491 .69841 L
.6931 .70957 L
.70477 .73422 L
.68491 .75222 L
.66026 .75348 L
.6356 .74313 L
.61305 .73422 L
.61095 .73248 L
.58629 .7179 L
.57319 .70957 L
.56164 .70206 L
.54169 .68491 L
.53698 .68051 L
.51766 .66026 L
.51233 .65292 L
.50181 .6356 L
.50287 .61095 L
.51233 .60557 L
s
.7 g
.53698 .61502 m
.56164 .61583 L
.58629 .62965 L
.59913 .6356 L
.61095 .64124 L
.6356 .66012 L
.63578 .66026 L
.66026 .68062 L
.66367 .68491 L
.68328 .70957 L
.68491 .71502 L
.68704 .73422 L
.68491 .73623 L
.66026 .74488 L
.6356 .73576 L
.62938 .73422 L
.61095 .72687 L
.58629 .71113 L
.58377 .70957 L
.56164 .69479 L
.55099 .68491 L
.53698 .67115 L
.52726 .66026 L
.51412 .6356 L
F
0 g
.53698 .61502 m
.56164 .61583 L
.58629 .62965 L
.59913 .6356 L
.61095 .64124 L
.6356 .66012 L
.63578 .66026 L
.66026 .68062 L
.66367 .68491 L
.68328 .70957 L
.68491 .71502 L
.68704 .73422 L
.68491 .73623 L
.66026 .74488 L
.6356 .73576 L
.62938 .73422 L
.61095 .72687 L
.58629 .71113 L
.58377 .70957 L
.56164 .69479 L
.55099 .68491 L
.53698 .67115 L
.52726 .66026 L
.51412 .6356 L
.53698 .61502 L
s
.8 g
.53698 .6271 m
.56164 .62383 L
.58328 .6356 L
.58629 .63695 L
.61095 .64766 L
.62737 .66026 L
.6356 .66799 L
.65549 .68491 L
.66026 .69241 L
.67362 .70957 L
.66026 .73103 L
.6356 .72785 L
.61095 .72005 L
.59052 .70957 L
.58629 .70399 L
.56164 .6858 L
.56076 .68491 L
.53756 .66026 L
.53698 .65936 L
.52846 .6356 L
F
0 g
.53698 .6271 m
.56164 .62383 L
.58328 .6356 L
.58629 .63695 L
.61095 .64766 L
.62737 .66026 L
.6356 .66799 L
.65549 .68491 L
.66026 .69241 L
.67362 .70957 L
.66026 .73103 L
.6356 .72785 L
.61095 .72005 L
.59052 .70957 L
.58629 .70399 L
.56164 .6858 L
.56076 .68491 L
.53756 .66026 L
.53698 .65936 L
.52846 .6356 L
.53698 .6271 L
s
.9 g
.56164 .63766 m
.58629 .64491 L
.61095 .65702 L
.61527 .66026 L
.6356 .6771 L
.64535 .68491 L
.65721 .70957 L
.6356 .71869 L
.61095 .71075 L
.60786 .70957 L
.58629 .69614 L
.56536 .68491 L
.56164 .67561 L
.54893 .66026 L
F
0 g
.56164 .63766 m
.58629 .64491 L
.61095 .65702 L
.61527 .66026 L
.6356 .6771 L
.64535 .68491 L
.65721 .70957 L
.6356 .71869 L
.61095 .71075 L
.60786 .70957 L
.58629 .69614 L
.56536 .68491 L
.56164 .67561 L
.54893 .66026 L
.56164 .63766 L
s
1 g
.58629 .65482 m
.59871 .66026 L
.61095 .66808 L
.63036 .68491 L
.61095 .7003 L
.58629 .68638 L
.58275 .68491 L
.56437 .66026 L
F
0 g
.58629 .65482 m
.59871 .66026 L
.61095 .66808 L
.63036 .68491 L
.61095 .7003 L
.58629 .68638 L
.58275 .68491 L
.56437 .66026 L
.58629 .65482 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Mtetra
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Mtetra
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Mtetra
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Mtetra
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Mtetra
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Mtetra
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Mtetra
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Mtetra
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Mtetra
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Mtetra
.57384 .54314 .58111 .55092 .59512 .54671 .5879 .53889 Mtetra
.5879 .53889 .59512 .54671 .60921 .54249 .60203 .53463 Mtetra
.60203 .53463 .60921 .54249 .62337 .53824 .61624 .53034 Mtetra
.61624 .53034 .62337 .53824 .63759 .53397 .63052 .52603 Mtetra
.63052 .52603 .63759 .53397 .6519 .52968 .64487 .5217 Mtetra
.64487 .5217 .6519 .52968 .66627 .52537 .6593 .51735 Mtetra
.6593 .51735 .66627 .52537 .68072 .52103 .67379 .51297 Mtetra
.67379 .51297 .68072 .52103 .69524 .51668 .68837 .50857 Mtetra
.68837 .50857 .69524 .51668 .70984 .5123 .70302 .50415 Mtetra
.70302 .50415 .70984 .5123 .72452 .5079 .71774 .49971 Mtetra
.71774 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Mtetra
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Mtetra
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Mtetra
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Mtetra
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Mtetra
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Mtetra
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Mtetra
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Mtetra
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Mtetra
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Mtetra
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .53529 Mtetra
.5665 .53529 .57384 .54314 .5879 .53889 .58061 .531 Mtetra
.58061 .531 .5879 .53889 .60203 .53463 .59479 .5267 Mtetra
.59479 .5267 .60203 .53463 .61624 .53034 .60905 .52237 Mtetra
.60905 .52237 .61624 .53034 .63052 .52603 .62338 .51802 Mtetra
.62338 .51802 .63052 .52603 .64487 .5217 .63778 .51365 Mtetra
.63778 .51365 .64487 .5217 .6593 .51735 .65225 .50925 Mtetra
.65225 .50925 .6593 .51735 .67379 .51297 .6668 .50483 Mtetra
.6668 .50483 .67379 .51297 .68837 .50857 .68143 .50039 Mtetra
.68143 .50039 .68837 .50857 .70302 .50415 .69613 .49593 Mtetra
.69613 .49593 .70302 .50415 .71774 .49971 .71091 .49144 Mtetra
.71091 .49144 .71774 .49971 .73255 .49524 .72577 .48693 Mtetra
.72577 .48693 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Mtetra
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Mtetra
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Mtetra
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55702 Mtetra
.46198 .55702 .4697 .56468 .48332 .56054 .47564 .55285 Mtetra
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Mtetra
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Mtetra
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .5402 Mtetra
.51705 .5402 .5246 .54801 .5385 .54379 .531 .53594 Mtetra
.531 .53594 .5385 .54379 .55246 .53955 .54501 .53166 Mtetra
.54501 .53166 .55246 .53955 .5665 .53529 .5591 .52736 Mtetra
.5591 .52736 .5665 .53529 .58061 .531 .57325 .52304 Mtetra
.57325 .52304 .58061 .531 .59479 .5267 .58748 .51869 Mtetra
.58748 .51869 .59479 .5267 .60905 .52237 .60179 .51432 Mtetra
.60179 .51432 .60905 .52237 .62338 .51802 .61616 .50993 Mtetra
.61616 .50993 .62338 .51802 .63778 .51365 .63062 .50552 Mtetra
.63062 .50552 .63778 .51365 .65225 .50925 .64514 .50108 Mtetra
.64514 .50108 .65225 .50925 .6668 .50483 .65974 .49662 Mtetra
.65974 .49662 .6668 .50483 .68143 .50039 .67442 .49214 Mtetra
.67442 .49214 .68143 .50039 .69613 .49593 .68918 .48763 Mtetra
.68918 .48763 .69613 .49593 .71091 .49144 .70401 .4831 Mtetra
.70401 .4831 .71091 .49144 .72577 .48693 .71892 .47854 Mtetra
.71892 .47854 .72577 .48693 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46936 Mtetra
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Mtetra
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56181 Mtetra
.41347 .56181 .42139 .56942 .43486 .56531 .42697 .55767 Mtetra
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .55349 Mtetra
.44054 .55349 .44838 .56118 .46198 .55702 .45418 .5493 Mtetra
.45418 .5493 .46198 .55702 .47564 .55285 .46789 .54509 Mtetra
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Mtetra
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Mtetra
.49552 .5366 .50318 .54444 .51705 .5402 .50944 .53232 Mtetra
.50944 .53232 .51705 .5402 .531 .53594 .52343 .52802 Mtetra
.52343 .52802 .531 .53594 .54501 .53166 .53749 .5237 Mtetra
.53749 .5237 .54501 .53166 .5591 .52736 .55162 .51936 Mtetra
.55162 .51936 .5591 .52736 .57325 .52304 .56582 .51499 Mtetra
.56582 .51499 .57325 .52304 .58748 .51869 .5801 .51061 Mtetra
.5801 .51061 .58748 .51869 .60179 .51432 .59446 .5062 Mtetra
.59446 .5062 .60179 .51432 .61616 .50993 .60888 .50176 Mtetra
.60888 .50176 .61616 .50993 .63062 .50552 .62338 .49731 Mtetra
.62338 .49731 .63062 .50552 .64514 .50108 .63796 .49283 Mtetra
.63796 .49283 .64514 .50108 .65974 .49662 .65262 .48832 Mtetra
.65262 .48832 .65974 .49662 .67442 .49214 .66735 .4838 Mtetra
.66735 .4838 .67442 .49214 .68918 .48763 .68215 .47925 Mtetra
.68215 .47925 .68918 .48763 .70401 .4831 .69704 .47467 Mtetra
.69704 .47467 .70401 .4831 .71892 .47854 .712 .47007 Mtetra
.712 .47007 .71892 .47854 .73391 .47397 .72705 .46545 Mtetra
.72705 .46545 .73391 .47397 .74897 .46936 .74217 .4608 Mtetra
.74217 .4608 .74897 .46936 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Mtetra
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Mtetra
.39199 .55831 .40003 .56594 .41347 .56181 .40547 .55414 Mtetra
.40547 .55414 .41347 .56181 .42697 .55767 .41902 .54995 Mtetra
.41902 .54995 .42697 .55767 .44054 .55349 .43263 .54574 Mtetra
.43263 .54574 .44054 .55349 .45418 .5493 .44632 .54151 Mtetra
.44632 .54151 .45418 .5493 .46789 .54509 .46007 .53726 Mtetra
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .53298 Mtetra
.47389 .53298 .48167 .54086 .49552 .5366 .48778 .52869 Mtetra
.48778 .52869 .49552 .5366 .50944 .53232 .50175 .52437 Mtetra
.50175 .52437 .50944 .53232 .52343 .52802 .51578 .52003 Mtetra
.51578 .52003 .52343 .52802 .53749 .5237 .52989 .51567 Mtetra
.52989 .51567 .53749 .5237 .55162 .51936 .54407 .51128 Mtetra
.54407 .51128 .55162 .51936 .56582 .51499 .55833 .50688 Mtetra
.55833 .50688 .56582 .51499 .5801 .51061 .57265 .50245 Mtetra
.57265 .50245 .5801 .51061 .59446 .5062 .58706 .49799 Mtetra
.58706 .49799 .59446 .5062 .60888 .50176 .60153 .49352 Mtetra
.60153 .49352 .60888 .50176 .62338 .49731 .61609 .48902 Mtetra
.61609 .48902 .62338 .49731 .63796 .49283 .63071 .48449 Mtetra
.63071 .48449 .63796 .49283 .65262 .48832 .64542 .47995 Mtetra
.64542 .47995 .65262 .48832 .66735 .4838 .6602 .47538 Mtetra
.6602 .47538 .66735 .4838 .68215 .47925 .67506 .47078 Mtetra
.67506 .47078 .68215 .47925 .69704 .47467 .69 .46616 Mtetra
.69 .46616 .69704 .47467 .712 .47007 .70502 .46152 Mtetra
.70502 .46152 .712 .47007 .72705 .46545 .72012 .45685 Mtetra
.72012 .45685 .72705 .46545 .74217 .4608 .7353 .45216 Mtetra
.7353 .45216 .74217 .4608 .75737 .45613 .75056 .44744 Mtetra
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Mtetra
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Mtetra
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Mtetra
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Mtetra
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Mtetra
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53791 Mtetra
.42465 .53791 .43263 .54574 .44632 .54151 .43837 .53364 Mtetra
.43837 .53364 .44632 .54151 .46007 .53726 .45217 .52935 Mtetra
.45217 .52935 .46007 .53726 .47389 .53298 .46604 .52504 Mtetra
.46604 .52504 .47389 .53298 .48778 .52869 .47998 .5207 Mtetra
.47998 .5207 .48778 .52869 .50175 .52437 .49399 .51634 Mtetra
.49399 .51634 .50175 .52437 .51578 .52003 .50807 .51196 Mtetra
.50807 .51196 .51578 .52003 .52989 .51567 .52222 .50756 Mtetra
.52222 .50756 .52989 .51567 .54407 .51128 .53645 .50313 Mtetra
.53645 .50313 .54407 .51128 .55833 .50688 .55076 .49868 Mtetra
.55076 .49868 .55833 .50688 .57265 .50245 .56513 .49421 Mtetra
.56513 .49421 .57265 .50245 .58706 .49799 .57958 .48971 Mtetra
.57958 .48971 .58706 .49799 .60153 .49352 .59411 .48519 Mtetra
.59411 .48519 .60153 .49352 .61609 .48902 .60871 .48065 Mtetra
.60871 .48065 .61609 .48902 .63071 .48449 .6234 .47608 Mtetra
.6234 .47608 .63071 .48449 .64542 .47995 .63815 .47149 Mtetra
.63815 .47149 .64542 .47995 .6602 .47538 .65299 .46688 Mtetra
.65299 .46688 .6602 .47538 .67506 .47078 .6679 .46224 Mtetra
.6679 .46224 .67506 .47078 .69 .46616 .6829 .45757 Mtetra
.6829 .45757 .69 .46616 .70502 .46152 .69797 .45288 Mtetra
.69797 .45288 .70502 .46152 .72012 .45685 .71312 .44817 Mtetra
.71312 .44817 .72012 .45685 .7353 .45216 .72836 .44343 Mtetra
.72836 .44343 .7353 .45216 .75056 .44744 .74368 .43866 Mtetra
.74368 .43866 .75056 .44744 .7659 .4427 .75908 .43387 Mtetra
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42905 Mtetra
.77456 .42905 .78132 .43793 .79683 .43313 .79013 .42421 Mtetra
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Mtetra
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .5343 Mtetra
.40288 .5343 .41099 .54216 .42465 .53791 .41658 .53001 Mtetra
.41658 .53001 .42465 .53791 .43837 .53364 .43036 .5257 Mtetra
.43036 .5257 .43837 .53364 .45217 .52935 .4442 .52137 Mtetra
.4442 .52137 .45217 .52935 .46604 .52504 .45811 .51701 Mtetra
.45811 .51701 .46604 .52504 .47998 .5207 .4721 .51263 Mtetra
.4721 .51263 .47998 .5207 .49399 .51634 .48615 .50823 Mtetra
.48615 .50823 .49399 .51634 .50807 .51196 .50028 .50381 Mtetra
.50028 .50381 .50807 .51196 .52222 .50756 .51448 .49937 Mtetra
.51448 .49937 .52222 .50756 .53645 .50313 .52876 .4949 Mtetra
.52876 .4949 .53645 .50313 .55076 .49868 .54311 .4904 Mtetra
.54311 .4904 .55076 .49868 .56513 .49421 .55754 .48589 Mtetra
.55754 .48589 .56513 .49421 .57958 .48971 .57204 .48135 Mtetra
.57204 .48135 .57958 .48971 .59411 .48519 .58662 .47679 Mtetra
.58662 .47679 .59411 .48519 .60871 .48065 .60127 .4722 Mtetra
.60127 .4722 .60871 .48065 .6234 .47608 .616 .46759 Mtetra
.616 .46759 .6234 .47608 .63815 .47149 .63082 .46295 Mtetra
.63082 .46295 .63815 .47149 .65299 .46688 .6457 .45829 Mtetra
.6457 .45829 .65299 .46688 .6679 .46224 .66067 .4536 Mtetra
.66067 .4536 .6679 .46224 .6829 .45757 .67572 .44889 Mtetra
.67572 .44889 .6829 .45757 .69797 .45288 .69085 .44416 Mtetra
.69085 .44416 .69797 .45288 .71312 .44817 .70606 .4394 Mtetra
.70606 .4394 .71312 .44817 .72836 .44343 .72135 .43461 Mtetra
.72135 .43461 .72836 .44343 .74368 .43866 .73673 .4298 Mtetra
.73673 .4298 .74368 .43866 .75908 .43387 .75218 .42496 Mtetra
.75218 .42496 .75908 .43387 .77456 .42905 .76773 .42009 Mtetra
.76773 .42009 .77456 .42905 .79013 .42421 .78335 .4152 Mtetra
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Mtetra
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Mtetra
.38103 .53067 .38925 .53857 .40288 .5343 .3947 .52637 Mtetra
.3947 .52637 .40288 .5343 .41658 .53001 .40845 .52204 Mtetra
.40845 .52204 .41658 .53001 .43036 .5257 .42226 .51768 Mtetra
.42226 .51768 .43036 .5257 .4442 .52137 .43615 .51331 Mtetra
.43615 .51331 .4442 .52137 .45811 .51701 .45011 .50891 Mtetra
.45011 .50891 .45811 .51701 .4721 .51263 .46414 .50449 Mtetra
.46414 .50449 .4721 .51263 .48615 .50823 .47824 .50005 Mtetra
.47824 .50005 .48615 .50823 .50028 .50381 .49242 .49559 Mtetra
.49242 .49559 .50028 .50381 .51448 .49937 .50667 .4911 Mtetra
.50667 .4911 .51448 .49937 .52876 .4949 .52099 .48658 Mtetra
.52099 .48658 .52876 .4949 .54311 .4904 .53539 .48205 Mtetra
.53539 .48205 .54311 .4904 .55754 .48589 .54987 .47749 Mtetra
.54987 .47749 .55754 .48589 .57204 .48135 .56442 .47291 Mtetra
.56442 .47291 .57204 .48135 .58662 .47679 .57905 .4683 Mtetra
.57905 .4683 .58662 .47679 .60127 .4722 .59376 .46367 Mtetra
.59376 .46367 .60127 .4722 .616 .46759 .60854 .45901 Mtetra
.60854 .45901 .616 .46759 .63082 .46295 .62341 .45433 Mtetra
.62341 .45433 .63082 .46295 .6457 .45829 .63835 .44962 Mtetra
.63835 .44962 .6457 .45829 .66067 .4536 .65337 .44489 Mtetra
.65337 .44489 .66067 .4536 .67572 .44889 .66847 .44013 Mtetra
.66847 .44013 .67572 .44889 .69085 .44416 .68366 .43535 Mtetra
.68366 .43535 .69085 .44416 .70606 .4394 .69892 .43054 Mtetra
.69892 .43054 .70606 .4394 .72135 .43461 .71427 .4257 Mtetra
.71427 .4257 .72135 .43461 .73673 .4298 .72971 .42084 Mtetra
.72971 .42084 .73673 .4298 .75218 .42496 .74522 .41596 Mtetra
.74522 .41596 .75218 .42496 .76773 .42009 .76082 .41104 Mtetra
.76082 .41104 .76773 .42009 .78335 .4152 .77651 .4061 Mtetra
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Mtetra
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Mtetra
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Mtetra
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51835 Mtetra
.38644 .51835 .3947 .52637 .40845 .52204 .40023 .51398 Mtetra
.40023 .51398 .40845 .52204 .42226 .51768 .41409 .50959 Mtetra
.41409 .50959 .42226 .51768 .43615 .51331 .42802 .50518 Mtetra
.42802 .50518 .43615 .51331 .45011 .50891 .44203 .50074 Mtetra
.44203 .50074 .45011 .50891 .46414 .50449 .45611 .49627 Mtetra
.45611 .49627 .46414 .50449 .47824 .50005 .47026 .49179 Mtetra
.47026 .49179 .47824 .50005 .49242 .49559 .48448 .48728 Mtetra
.48448 .48728 .49242 .49559 .50667 .4911 .49878 .48275 Mtetra
.49878 .48275 .50667 .4911 .52099 .48658 .51315 .47819 Mtetra
.51315 .47819 .52099 .48658 .53539 .48205 .5276 .47361 Mtetra
.5276 .47361 .53539 .48205 .54987 .47749 .54213 .46901 Mtetra
.54213 .46901 .54987 .47749 .56442 .47291 .55673 .46438 Mtetra
.55673 .46438 .56442 .47291 .57905 .4683 .57141 .45973 Mtetra
.57141 .45973 .57905 .4683 .59376 .46367 .58617 .45505 Mtetra
.58617 .45505 .59376 .46367 .60854 .45901 .60101 .45035 Mtetra
.60101 .45035 .60854 .45901 .62341 .45433 .61592 .44562 Mtetra
.61592 .44562 .62341 .45433 .63835 .44962 .63092 .44086 Mtetra
.63092 .44086 .63835 .44962 .65337 .44489 .646 .43609 Mtetra
.646 .43609 .65337 .44489 .66847 .44013 .66115 .43128 Mtetra
.66115 .43128 .66847 .44013 .68366 .43535 .6764 .42645 Mtetra
.6764 .42645 .68366 .43535 .69892 .43054 .69172 .42159 Mtetra
.69172 .42159 .69892 .43054 .71427 .4257 .70712 .41671 Mtetra
.70712 .41671 .71427 .4257 .72971 .42084 .72262 .4118 Mtetra
.72262 .4118 .72971 .42084 .74522 .41596 .73819 .40686 Mtetra
.73819 .40686 .74522 .41596 .76082 .41104 .75385 .4019 Mtetra
.75385 .4019 .76082 .41104 .77651 .4061 .7696 .39691 Mtetra
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Mtetra
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Mtetra
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Mtetra
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Mtetra
.36434 .51466 .37272 .5227 .38644 .51835 .37811 .51027 Mtetra
.37811 .51027 .38644 .51835 .40023 .51398 .39194 .50586 Mtetra
.39194 .50586 .40023 .51398 .41409 .50959 .40584 .50142 Mtetra
.40584 .50142 .41409 .50959 .42802 .50518 .41982 .49696 Mtetra
.41982 .49696 .42802 .50518 .44203 .50074 .43387 .49248 Mtetra
.43387 .49248 .44203 .50074 .45611 .49627 .44799 .48798 Mtetra
.44799 .48798 .45611 .49627 .47026 .49179 .46219 .48345 Mtetra
.46219 .48345 .47026 .49179 .48448 .48728 .47646 .47889 Mtetra
.47646 .47889 .48448 .48728 .49878 .48275 .49081 .47432 Mtetra
.49081 .47432 .49878 .48275 .51315 .47819 .50523 .46972 Mtetra
.50523 .46972 .51315 .47819 .5276 .47361 .51973 .46509 Mtetra
.51973 .46509 .5276 .47361 .54213 .46901 .53431 .46044 Mtetra
.53431 .46044 .54213 .46901 .55673 .46438 .54896 .45577 Mtetra
.54896 .45577 .55673 .46438 .57141 .45973 .56369 .45107 Mtetra
.56369 .45107 .57141 .45973 .58617 .45505 .57851 .44635 Mtetra
.57851 .44635 .58617 .45505 .60101 .45035 .5934 .4416 Mtetra
.5934 .4416 .60101 .45035 .61592 .44562 .60837 .43682 Mtetra
.60837 .43682 .61592 .44562 .63092 .44086 .62342 .43202 Mtetra
.62342 .43202 .63092 .44086 .646 .43609 .63855 .4272 Mtetra
.63855 .4272 .646 .43609 .66115 .43128 .65376 .42234 Mtetra
.65376 .42234 .66115 .43128 .6764 .42645 .66906 .41746 Mtetra
.66906 .41746 .6764 .42645 .69172 .42159 .68444 .41256 Mtetra
.68444 .41256 .69172 .42159 .70712 .41671 .6999 .40762 Mtetra
.6999 .40762 .70712 .41671 .72262 .4118 .71545 .40267 Mtetra
.71545 .40267 .72262 .4118 .73819 .40686 .73109 .39768 Mtetra
.73109 .39768 .73819 .40686 .75385 .4019 .74681 .39266 Mtetra
.74681 .39266 .75385 .4019 .7696 .39691 .76262 .38762 Mtetra
.76262 .38762 .7696 .39691 .78543 .39189 .77851 .38255 Mtetra
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Mtetra
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .5021 Mtetra
.36969 .5021 .37811 .51027 .39194 .50586 .38357 .49765 Mtetra
.38357 .49765 .39194 .50586 .40584 .50142 .39752 .49317 Mtetra
.39752 .49317 .40584 .50142 .41982 .49696 .41154 .48867 Mtetra
.41154 .48867 .41982 .49696 .43387 .49248 .42564 .48415 Mtetra
.42564 .48415 .43387 .49248 .44799 .48798 .43981 .4796 Mtetra
.43981 .4796 .44799 .48798 .46219 .48345 .45405 .47502 Mtetra
.45405 .47502 .46219 .48345 .47646 .47889 .46837 .47043 Mtetra
.46837 .47043 .47646 .47889 .49081 .47432 .48277 .46581 Mtetra
.48277 .46581 .49081 .47432 .50523 .46972 .49724 .46116 Mtetra
.49724 .46116 .50523 .46972 .51973 .46509 .51179 .45649 Mtetra
.51179 .45649 .51973 .46509 .53431 .46044 .52641 .4518 Mtetra
.52641 .4518 .53431 .46044 .54896 .45577 .54112 .44708 Mtetra
.54112 .44708 .54896 .45577 .56369 .45107 .5559 .44233 Mtetra
.5559 .44233 .56369 .45107 .57851 .44635 .57077 .43756 Mtetra
.57077 .43756 .57851 .44635 .5934 .4416 .58571 .43276 Mtetra
.58571 .43276 .5934 .4416 .60837 .43682 .60073 .42794 Mtetra
.60073 .42794 .60837 .43682 .62342 .43202 .61584 .42309 Mtetra
.61584 .42309 .62342 .43202 .63855 .4272 .63103 .41822 Mtetra
.63103 .41822 .63855 .4272 .65376 .42234 .6463 .41331 Mtetra
.6463 .41331 .65376 .42234 .66906 .41746 .66165 .40839 Mtetra
.66165 .40839 .66906 .41746 .68444 .41256 .67709 .40343 Mtetra
.67709 .40343 .68444 .41256 .6999 .40762 .69261 .39845 Mtetra
.69261 .39845 .6999 .40762 .71545 .40267 .70822 .39344 Mtetra
.70822 .39344 .71545 .40267 .73109 .39768 .72391 .3884 Mtetra
.72391 .3884 .73109 .39768 .74681 .39266 .73969 .38333 Mtetra
.73969 .38333 .74681 .39266 .76262 .38762 .75556 .37824 Mtetra
.75556 .37824 .76262 .38762 .77851 .38255 .77152 .37312 Mtetra
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Mtetra
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Mtetra
.34734 .49834 .35588 .50654 .36969 .5021 .36119 .49386 Mtetra
.36119 .49386 .36969 .5021 .38357 .49765 .37511 .48936 Mtetra
.37511 .48936 .38357 .49765 .39752 .49317 .38911 .48484 Mtetra
.38911 .48484 .39752 .49317 .41154 .48867 .40318 .4803 Mtetra
.40318 .4803 .41154 .48867 .42564 .48415 .41732 .47573 Mtetra
.41732 .47573 .42564 .48415 .43981 .4796 .43154 .47114 Mtetra
.43154 .47114 .43981 .4796 .45405 .47502 .44583 .46652 Mtetra
.44583 .46652 .45405 .47502 .46837 .47043 .4602 .46188 Mtetra
.4602 .46188 .46837 .47043 .48277 .46581 .47464 .45721 Mtetra
.47464 .45721 .48277 .46581 .49724 .46116 .48916 .45252 Mtetra
.48916 .45252 .49724 .46116 .51179 .45649 .50376 .4478 Mtetra
.50376 .4478 .51179 .45649 .52641 .4518 .51844 .44306 Mtetra
.51844 .44306 .52641 .4518 .54112 .44708 .5332 .43829 Mtetra
.5332 .43829 .54112 .44708 .5559 .44233 .54803 .4335 Mtetra
.54803 .4335 .5559 .44233 .57077 .43756 .56295 .42868 Mtetra
.56295 .42868 .57077 .43756 .58571 .43276 .57795 .42384 Mtetra
.57795 .42384 .58571 .43276 .60073 .42794 .59302 .41897 Mtetra
.59302 .41897 .60073 .42794 .61584 .42309 .60818 .41407 Mtetra
.60818 .41407 .61584 .42309 .63103 .41822 .62343 .40915 Mtetra
.62343 .40915 .63103 .41822 .6463 .41331 .63875 .40419 Mtetra
.63875 .40419 .6463 .41331 .66165 .40839 .65416 .39922 Mtetra
.65416 .39922 .66165 .40839 .67709 .40343 .66966 .39421 Mtetra
.66966 .39421 .67709 .40343 .69261 .39845 .68524 .38918 Mtetra
.68524 .38918 .69261 .39845 .70822 .39344 .70091 .38412 Mtetra
.70091 .38412 .70822 .39344 .72391 .3884 .71666 .37903 Mtetra
.71666 .37903 .72391 .3884 .73969 .38333 .7325 .37391 Mtetra
.7325 .37391 .73969 .38333 .75556 .37824 .74843 .36876 Mtetra
.74843 .36876 .75556 .37824 .77152 .37312 .76445 .36359 Mtetra
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Mtetra
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Mtetra
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Mtetra
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Mtetra
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Mtetra
.35261 .48554 .36119 .49386 .37511 .48936 .36658 .481 Mtetra
.36658 .481 .37511 .48936 .38911 .48484 .38062 .47643 Mtetra
.38062 .47643 .38911 .48484 .40318 .4803 .39473 .47184 Mtetra
.39473 .47184 .40318 .4803 .41732 .47573 .40892 .46723 Mtetra
.40892 .46723 .41732 .47573 .43154 .47114 .42319 .46259 Mtetra
.42319 .46259 .43154 .47114 .44583 .46652 .43753 .45793 Mtetra
.43753 .45793 .44583 .46652 .4602 .46188 .45194 .45324 Mtetra
.45194 .45324 .4602 .46188 .47464 .45721 .46644 .44853 Mtetra
.46644 .44853 .47464 .45721 .48916 .45252 .48101 .44379 Mtetra
.48101 .44379 .48916 .45252 .50376 .4478 .49566 .43903 Mtetra
.49566 .43903 .50376 .4478 .51844 .44306 .51039 .43424 Mtetra
.51039 .43424 .51844 .44306 .5332 .43829 .5252 .42943 Mtetra
.5252 .42943 .5332 .43829 .54803 .4335 .54008 .42459 Mtetra
.54008 .42459 .54803 .4335 .56295 .42868 .55505 .41972 Mtetra
.55505 .41972 .56295 .42868 .57795 .42384 .5701 .41482 Mtetra
.5701 .41482 .57795 .42384 .59302 .41897 .58524 .4099 Mtetra
.58524 .4099 .59302 .41897 .60818 .41407 .60045 .40496 Mtetra
.60045 .40496 .60818 .41407 .62343 .40915 .61575 .39998 Mtetra
.61575 .39998 .62343 .40915 .63875 .40419 .63113 .39498 Mtetra
.63113 .39498 .63875 .40419 .65416 .39922 .6466 .38995 Mtetra
.6466 .38995 .65416 .39922 .66966 .39421 .66216 .3849 Mtetra
.66216 .3849 .66966 .39421 .68524 .38918 .6778 .37981 Mtetra
.6778 .37981 .68524 .38918 .70091 .38412 .69352 .3747 Mtetra
.69352 .3747 .70091 .38412 .71666 .37903 .70934 .36956 Mtetra
.70934 .36956 .71666 .37903 .7325 .37391 .72524 .36438 Mtetra
.72524 .36438 .7325 .37391 .74843 .36876 .74123 .35918 Mtetra
.74123 .35918 .74843 .36876 .76445 .36359 .75732 .35396 Mtetra
.75732 .35396 .76445 .36359 .78056 .35838 .77349 .3487 Mtetra
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Mtetra
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Mtetra
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Mtetra
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Mtetra
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47255 Mtetra
.35796 .47255 .36658 .481 .38062 .47643 .37205 .46794 Mtetra
.37205 .46794 .38062 .47643 .39473 .47184 .38621 .46331 Mtetra
.38621 .46331 .39473 .47184 .40892 .46723 .40044 .45865 Mtetra
.40044 .45865 .40892 .46723 .42319 .46259 .41476 .45397 Mtetra
.41476 .45397 .42319 .46259 .43753 .45793 .42914 .44926 Mtetra
.42914 .44926 .43753 .45793 .45194 .45324 .44361 .44452 Mtetra
.44361 .44452 .45194 .45324 .46644 .44853 .45815 .43976 Mtetra
.45815 .43976 .46644 .44853 .48101 .44379 .47277 .43498 Mtetra
.47277 .43498 .48101 .44379 .49566 .43903 .48747 .43017 Mtetra
.48747 .43017 .49566 .43903 .51039 .43424 .50225 .42533 Mtetra
.50225 .42533 .51039 .43424 .5252 .42943 .51712 .42047 Mtetra
.51712 .42047 .5252 .42943 .54008 .42459 .53206 .41558 Mtetra
.53206 .41558 .54008 .42459 .55505 .41972 .54708 .41066 Mtetra
.54708 .41066 .55505 .41972 .5701 .41482 .56218 .40572 Mtetra
.56218 .40572 .5701 .41482 .58524 .4099 .57737 .40075 Mtetra
.57737 .40075 .58524 .4099 .60045 .40496 .59264 .39575 Mtetra
.59264 .39575 .60045 .40496 .61575 .39998 .608 .39073 Mtetra
.608 .39073 .61575 .39998 .63113 .39498 .62344 .38568 Mtetra
.62344 .38568 .63113 .39498 .6466 .38995 .63896 .3806 Mtetra
.663 .741 .908 r
.63896 .3806 .6466 .38995 .66216 .3849 .65458 .37549 Mtetra
.664 .741 .908 r
.65458 .37549 .66216 .3849 .6778 .37981 .67028 .37035 Mtetra
.67028 .37035 .6778 .37981 .69352 .3747 .68606 .36518 Mtetra
.68606 .36518 .69352 .3747 .70934 .36956 .70194 .35999 Mtetra
.70194 .35999 .70934 .36956 .72524 .36438 .7179 .35476 Mtetra
.7179 .35476 .72524 .36438 .74123 .35918 .73396 .34951 Mtetra
.73396 .34951 .74123 .35918 .75732 .35396 .75011 .34422 Mtetra
.75011 .34422 .75732 .35396 .77349 .3487 .76634 .33891 Mtetra
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Mtetra
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Mtetra
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Mtetra
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46865 Mtetra
.3352 .46865 .34395 .47714 .35796 .47255 .34926 .46402 Mtetra
.34926 .46402 .35796 .47255 .37205 .46794 .36339 .45937 Mtetra
.36339 .45937 .37205 .46794 .38621 .46331 .3776 .45469 Mtetra
.3776 .45469 .38621 .46331 .40044 .45865 .39188 .44998 Mtetra
.39188 .44998 .40044 .45865 .41476 .45397 .40624 .44525 Mtetra
.40624 .44525 .41476 .45397 .42914 .44926 .42068 .4405 Mtetra
.42068 .4405 .42914 .44926 .44361 .44452 .43519 .43572 Mtetra
.43519 .43572 .44361 .44452 .45815 .43976 .44978 .43091 Mtetra
.44978 .43091 .45815 .43976 .47277 .43498 .46446 .42608 Mtetra
.46446 .42608 .47277 .43498 .48747 .43017 .47921 .42122 Mtetra
.47921 .42122 .48747 .43017 .50225 .42533 .49404 .41633 Mtetra
.49404 .41633 .50225 .42533 .51712 .42047 .50895 .41142 Mtetra
.50895 .41142 .51712 .42047 .53206 .41558 .52395 .40648 Mtetra
.52395 .40648 .53206 .41558 .54708 .41066 .53902 .40152 Mtetra
.53902 .40152 .54708 .41066 .56218 .40572 .55418 .39652 Mtetra
.55418 .39652 .56218 .40572 .57737 .40075 .56943 .3915 Mtetra
.56943 .3915 .57737 .40075 .59264 .39575 .58475 .38645 Mtetra
.58475 .38645 .59264 .39575 .608 .39073 .60016 .38138 Mtetra
.663 .741 .908 r
.60016 .38138 .608 .39073 .62344 .38568 .61566 .37628 Mtetra
.61566 .37628 .62344 .38568 .63896 .3806 .63125 .37115 Mtetra
.663 .742 .908 r
.63125 .37115 .63896 .3806 .65458 .37549 .64692 .36599 Mtetra
.664 .742 .908 r
.64692 .36599 .65458 .37549 .67028 .37035 .66268 .36079 Mtetra
.664 .741 .908 r
.66268 .36079 .67028 .37035 .68606 .36518 .67853 .35557 Mtetra
.67853 .35557 .68606 .36518 .70194 .35999 .69446 .35032 Mtetra
.69446 .35032 .70194 .35999 .7179 .35476 .71049 .34504 Mtetra
.71049 .34504 .7179 .35476 .73396 .34951 .72661 .33973 Mtetra
.72661 .33973 .73396 .34951 .75011 .34422 .74282 .33439 Mtetra
.74282 .33439 .75011 .34422 .76634 .33891 .75912 .32902 Mtetra
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Mtetra
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46936 Mtetra
.29838 .46936 .3073 .47784 .32121 .47326 .31234 .46474 Mtetra
.31234 .46474 .32121 .47326 .3352 .46865 .32636 .46009 Mtetra
.32636 .46009 .3352 .46865 .34926 .46402 .34047 .45541 Mtetra
.34047 .45541 .34926 .46402 .36339 .45937 .35465 .45071 Mtetra
.35465 .45071 .36339 .45937 .3776 .45469 .3689 .44598 Mtetra
.3689 .44598 .3776 .45469 .39188 .44998 .38323 .44123 Mtetra
.38323 .44123 .39188 .44998 .40624 .44525 .39764 .43645 Mtetra
.39764 .43645 .40624 .44525 .42068 .4405 .41213 .43165 Mtetra
.41213 .43165 .42068 .4405 .43519 .43572 .42669 .42682 Mtetra
.42669 .42682 .43519 .43572 .44978 .43091 .44133 .42197 Mtetra
.44133 .42197 .44978 .43091 .46446 .42608 .45606 .41709 Mtetra
.45606 .41709 .46446 .42608 .47921 .42122 .47086 .41218 Mtetra
.47086 .41218 .47921 .42122 .49404 .41633 .48574 .40724 Mtetra
.48574 .40724 .49404 .41633 .50895 .41142 .50071 .40228 Mtetra
.50071 .40228 .50895 .41142 .52395 .40648 .51576 .39729 Mtetra
.51576 .39729 .52395 .40648 .53902 .40152 .53089 .39228 Mtetra
.53089 .39228 .53902 .40152 .55418 .39652 .5461 .38723 Mtetra
.5461 .38723 .55418 .39652 .56943 .3915 .5614 .38216 Mtetra
.5614 .38216 .56943 .3915 .58475 .38645 .57678 .37706 Mtetra
.663 .741 .908 r
.57678 .37706 .58475 .38645 .60016 .38138 .59225 .37194 Mtetra
.59225 .37194 .60016 .38138 .61566 .37628 .60781 .36681 Mtetra
.663 .742 .908 r
.60781 .36681 .61566 .37628 .63125 .37115 .62345 .36163 Mtetra
.664 .742 .908 r
.62345 .36163 .63125 .37115 .64692 .36599 .63918 .35639 Mtetra
.63918 .35639 .64692 .36599 .66268 .36079 .655 .35113 Mtetra
.664 .741 .908 r
.655 .35113 .66268 .36079 .67853 .35557 .67091 .34585 Mtetra
.67091 .34585 .67853 .35557 .69446 .35032 .68691 .34055 Mtetra
.68691 .34055 .69446 .35032 .71049 .34504 .703 .33521 Mtetra
.703 .33521 .71049 .34504 .72661 .33973 .71918 .32985 Mtetra
.71918 .32985 .72661 .33973 .74282 .33439 .73545 .32445 Mtetra
.73545 .32445 .74282 .33439 .75912 .32902 .75182 .31903 Mtetra
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Mtetra
.27545 .46545 .2845 .47397 .29838 .46936 .28937 .4608 Mtetra
.28937 .4608 .29838 .46936 .31234 .46474 .30337 .45613 Mtetra
.30337 .45613 .31234 .46474 .32636 .46009 .31744 .45143 Mtetra
.31744 .45143 .32636 .46009 .34047 .45541 .33159 .44671 Mtetra
.33159 .44671 .34047 .45541 .35465 .45071 .34582 .44196 Mtetra
.34582 .44196 .35465 .45071 .3689 .44598 .36012 .43719 Mtetra
.36012 .43719 .3689 .44598 .38323 .44123 .3745 .43239 Mtetra
.3745 .43239 .38323 .44123 .39764 .43645 .38896 .42757 Mtetra
.38896 .42757 .39764 .43645 .41213 .43165 .40349 .42272 Mtetra
.40349 .42272 .41213 .43165 .42669 .42682 .4181 .41784 Mtetra
.4181 .41784 .42669 .42682 .44133 .42197 .4328 .41294 Mtetra
.4328 .41294 .44133 .42197 .45606 .41709 .44757 .40801 Mtetra
.44757 .40801 .45606 .41709 .47086 .41218 .46242 .40305 Mtetra
.46242 .40305 .47086 .41218 .48574 .40724 .47736 .39806 Mtetra
.47736 .39806 .48574 .40724 .50071 .40228 .49238 .39305 Mtetra
.49238 .39305 .50071 .40228 .51576 .39729 .50748 .38801 Mtetra
.50748 .38801 .51576 .39729 .53089 .39228 .52267 .38294 Mtetra
.52267 .38294 .53089 .39228 .5461 .38723 .53793 .37785 Mtetra
.663 .741 .908 r
.53793 .37785 .5461 .38723 .5614 .38216 .55329 .37273 Mtetra
.55329 .37273 .5614 .38216 .57678 .37706 .56873 .3676 Mtetra
.662 .741 .909 r
.56873 .3676 .57678 .37706 .59225 .37194 .58426 .36247 Mtetra
.663 .743 .909 r
.58426 .36247 .59225 .37194 .60781 .36681 .59987 .35728 Mtetra
.665 .743 .909 r
.59987 .35728 .60781 .36681 .62345 .36163 .61557 .35199 Mtetra
.665 .742 .908 r
.61557 .35199 .62345 .36163 .63918 .35639 .63136 .34668 Mtetra
.664 .741 .908 r
.63136 .34668 .63918 .35639 .655 .35113 .64724 .34137 Mtetra
.64724 .34137 .655 .35113 .67091 .34585 .66321 .33604 Mtetra
.66321 .33604 .67091 .34585 .68691 .34055 .67927 .33068 Mtetra
.67927 .33068 .68691 .34055 .703 .33521 .69543 .32529 Mtetra
.69543 .32529 .703 .33521 .71918 .32985 .71167 .31986 Mtetra
.71167 .31986 .71918 .32985 .73545 .32445 .72801 .31441 Mtetra
.72801 .31441 .73545 .32445 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Mtetra
.2663 .45685 .27545 .46545 .28937 .4608 .28027 .45216 Mtetra
.28027 .45216 .28937 .4608 .30337 .45613 .29432 .44744 Mtetra
.29432 .44744 .30337 .45613 .31744 .45143 .30844 .4427 Mtetra
.30844 .4427 .31744 .45143 .33159 .44671 .32263 .43793 Mtetra
.32263 .43793 .33159 .44671 .34582 .44196 .3369 .43313 Mtetra
.3369 .43313 .34582 .44196 .36012 .43719 .35125 .42831 Mtetra
.35125 .42831 .36012 .43719 .3745 .43239 .36568 .42346 Mtetra
.36568 .42346 .3745 .43239 .38896 .42757 .38018 .41859 Mtetra
.38018 .41859 .38896 .42757 .40349 .42272 .39477 .41369 Mtetra
.39477 .41369 .40349 .42272 .4181 .41784 .40943 .40877 Mtetra
.40943 .40877 .4181 .41784 .4328 .41294 .42417 .40381 Mtetra
.42417 .40381 .4328 .41294 .44757 .40801 .439 .39883 Mtetra
.439 .39883 .44757 .40801 .46242 .40305 .4539 .39382 Mtetra
.4539 .39382 .46242 .40305 .47736 .39806 .46889 .38879 Mtetra
.46889 .38879 .47736 .39806 .49238 .39305 .48397 .38372 Mtetra
.48397 .38372 .49238 .39305 .50748 .38801 .49912 .37863 Mtetra
.49912 .37863 .50748 .38801 .52267 .38294 .51436 .37351 Mtetra
.663 .741 .908 r
.51436 .37351 .52267 .38294 .53793 .37785 .52969 .36837 Mtetra
.662 .741 .909 r
.52969 .36837 .53793 .37785 .55329 .37273 .5451 .36325 Mtetra
.66 .742 .91 r
.5451 .36325 .55329 .37273 .56873 .3676 .5606 .35819 Mtetra
.662 .745 .912 r
.5606 .35819 .56873 .3676 .58426 .36247 .57618 .35301 Mtetra
.667 .746 .91 r
.57618 .35301 .58426 .36247 .59987 .35728 .59185 .34761 Mtetra
.666 .743 .907 r
.59185 .34761 .59987 .35728 .61557 .35199 .60761 .34221 Mtetra
.664 .741 .907 r
.60761 .34221 .61557 .35199 .63136 .34668 .62346 .33686 Mtetra
.664 .741 .908 r
.62346 .33686 .63136 .34668 .64724 .34137 .6394 .3315 Mtetra
.6394 .3315 .64724 .34137 .66321 .33604 .65543 .32612 Mtetra
.65543 .32612 .66321 .33604 .67927 .33068 .67156 .3207 Mtetra
.67156 .3207 .67927 .33068 .69543 .32529 .68777 .31525 Mtetra
.68777 .31525 .69543 .32529 .71167 .31986 .70408 .30977 Mtetra
.70408 .30977 .71167 .31986 .72801 .31441 .72049 .30426 Mtetra
.72049 .30426 .72801 .31441 .74444 .30893 .73699 .29872 Mtetra
.73699 .29872 .74444 .30893 .76097 .30341 .75358 .29314 Mtetra
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28753 Mtetra
.77027 .28753 .7776 .29786 .79432 .29228 .78706 .28189 Mtetra
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Mtetra
.25707 .44817 .2663 .45685 .28027 .45216 .27108 .44343 Mtetra
.27108 .44343 .28027 .45216 .29432 .44744 .28517 .43866 Mtetra
.28517 .43866 .29432 .44744 .30844 .4427 .29934 .43387 Mtetra
.29934 .43387 .30844 .4427 .32263 .43793 .31358 .42905 Mtetra
.31358 .42905 .32263 .43793 .3369 .43313 .3279 .42421 Mtetra
.3279 .42421 .3369 .43313 .35125 .42831 .34229 .41934 Mtetra
.34229 .41934 .35125 .42831 .36568 .42346 .35677 .41445 Mtetra
.35677 .41445 .36568 .42346 .38018 .41859 .37132 .40953 Mtetra
.37132 .40953 .38018 .41859 .39477 .41369 .38595 .40458 Mtetra
.38595 .40458 .39477 .41369 .40943 .40877 .40067 .3996 Mtetra
.40067 .3996 .40943 .40877 .42417 .40381 .41546 .3946 Mtetra
.41546 .3946 .42417 .40381 .439 .39883 .43034 .38956 Mtetra
.43034 .38956 .439 .39883 .4539 .39382 .4453 .38451 Mtetra
.4453 .38451 .4539 .39382 .46889 .38879 .46034 .37942 Mtetra
.46034 .37942 .46889 .38879 .48397 .38372 .47546 .3743 Mtetra
.47546 .3743 .48397 .38372 .49912 .37863 .49067 .36916 Mtetra
.663 .741 .908 r
.49067 .36916 .49912 .37863 .51436 .37351 .50597 .364 Mtetra
.66 .741 .909 r
.50597 .364 .51436 .37351 .52969 .36837 .52135 .35893 Mtetra
.655 .742 .913 r
.52135 .35893 .52969 .36837 .5451 .36325 .53682 .35403 Mtetra
.66 .749 .916 r
.53682 .35403 .5451 .36325 .5606 .35819 .55238 .34891 Mtetra
.671 .753 .912 r
.55238 .34891 .5606 .35819 .57618 .35301 .56802 .34333 Mtetra
.67 .745 .907 r
.56802 .34333 .57618 .35301 .59185 .34761 .58375 .33775 Mtetra
.665 .74 .906 r
.58375 .33775 .59185 .34761 .60761 .34221 .59957 .33233 Mtetra
.664 .741 .907 r
.59957 .33233 .60761 .34221 .62346 .33686 .61548 .32695 Mtetra
.664 .741 .908 r
.61548 .32695 .62346 .33686 .6394 .3315 .63148 .32154 Mtetra
.63148 .32154 .6394 .3315 .65543 .32612 .64757 .31609 Mtetra
.64757 .31609 .65543 .32612 .67156 .3207 .66376 .31062 Mtetra
.66376 .31062 .67156 .3207 .68777 .31525 .68004 .30511 Mtetra
.68004 .30511 .68777 .31525 .70408 .30977 .69642 .29957 Mtetra
.69642 .29957 .70408 .30977 .72049 .30426 .71289 .294 Mtetra
.71289 .294 .72049 .30426 .73699 .29872 .72945 .2884 Mtetra
.72945 .2884 .73699 .29872 .75358 .29314 .74611 .28276 Mtetra
.74611 .28276 .75358 .29314 .77027 .28753 .76287 .2771 Mtetra
.76287 .2771 .77027 .28753 .78706 .28189 .77973 .27139 Mtetra
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.23376 .44416 .24313 .45288 .25707 .44817 .24775 .4394 Mtetra
.24775 .4394 .25707 .44817 .27108 .44343 .2618 .43461 Mtetra
.2618 .43461 .27108 .44343 .28517 .43866 .27594 .4298 Mtetra
.27594 .4298 .28517 .43866 .29934 .43387 .29015 .42496 Mtetra
.29015 .42496 .29934 .43387 .31358 .42905 .30444 .42009 Mtetra
.30444 .42009 .31358 .42905 .3279 .42421 .3188 .4152 Mtetra
.3188 .4152 .3279 .42421 .34229 .41934 .33325 .41028 Mtetra
.33325 .41028 .34229 .41934 .35677 .41445 .34777 .40534 Mtetra
.34777 .40534 .35677 .41445 .37132 .40953 .36237 .40037 Mtetra
.36237 .40037 .37132 .40953 .38595 .40458 .37705 .39537 Mtetra
.37705 .39537 .38595 .40458 .40067 .3996 .39182 .39034 Mtetra
.39182 .39034 .40067 .3996 .41546 .3946 .40666 .38529 Mtetra
.40666 .38529 .41546 .3946 .43034 .38956 .42159 .3802 Mtetra
.42159 .3802 .43034 .38956 .4453 .38451 .4366 .37509 Mtetra
.4366 .37509 .4453 .38451 .46034 .37942 .4517 .36995 Mtetra
.4517 .36995 .46034 .37942 .47546 .3743 .46688 .36478 Mtetra
.663 .741 .908 r
.46688 .36478 .47546 .3743 .49067 .36916 .48214 .35962 Mtetra
.657 .74 .911 r
.48214 .35962 .49067 .36916 .50597 .364 .49749 .35466 Mtetra
.645 .742 .92 r
.49749 .35466 .50597 .364 .52135 .35893 .51292 .35013 Mtetra
.654 .759 .927 r
.51292 .35013 .52135 .35893 .53682 .35403 .52845 .3452 Mtetra
.68 .767 .917 r
.52845 .3452 .53682 .35403 .55238 .34891 .54407 .33926 Mtetra
.678 .749 .905 r
.54407 .33926 .55238 .34891 .56802 .34333 .55977 .33332 Mtetra
.667 .739 .904 r
.55977 .33332 .56802 .34333 .58375 .33775 .57556 .32779 Mtetra
.664 .74 .907 r
.57556 .32779 .58375 .33775 .59957 .33233 .59144 .32237 Mtetra
.664 .741 .908 r
.59144 .32237 .59957 .33233 .61548 .32695 .60741 .31693 Mtetra
.60741 .31693 .61548 .32695 .63148 .32154 .62347 .31146 Mtetra
.62347 .31146 .63148 .32154 .64757 .31609 .63963 .30596 Mtetra
.63963 .30596 .64757 .31609 .66376 .31062 .65588 .30043 Mtetra
.65588 .30043 .66376 .31062 .68004 .30511 .67223 .29486 Mtetra
.67223 .29486 .68004 .30511 .69642 .29957 .68867 .28926 Mtetra
.68867 .28926 .69642 .29957 .71289 .294 .7052 .28363 Mtetra
.7052 .28363 .71289 .294 .72945 .2884 .72183 .27797 Mtetra
.72183 .27797 .72945 .2884 .74611 .28276 .73856 .27227 Mtetra
.73856 .27227 .74611 .28276 .76287 .2771 .75539 .26654 Mtetra
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.2243 .43535 .23376 .44416 .24775 .4394 .23833 .43054 Mtetra
.23833 .43054 .24775 .4394 .2618 .43461 .25243 .4257 Mtetra
.25243 .4257 .2618 .43461 .27594 .4298 .26661 .42084 Mtetra
.26661 .42084 .27594 .4298 .29015 .42496 .28087 .41596 Mtetra
.28087 .41596 .29015 .42496 .30444 .42009 .2952 .41104 Mtetra
.2952 .41104 .30444 .42009 .3188 .4152 .30961 .4061 Mtetra
.30961 .4061 .3188 .4152 .33325 .41028 .32411 .40113 Mtetra
.32411 .40113 .33325 .41028 .34777 .40534 .33868 .39614 Mtetra
.33868 .39614 .34777 .40534 .36237 .40037 .35333 .39112 Mtetra
.35333 .39112 .36237 .40037 .37705 .39537 .36806 .38606 Mtetra
.36806 .38606 .37705 .39537 .39182 .39034 .38288 .38099 Mtetra
.38288 .38099 .39182 .39034 .40666 .38529 .39777 .37588 Mtetra
.39777 .37588 .40666 .38529 .42159 .3802 .41275 .37074 Mtetra
.41275 .37074 .42159 .3802 .4366 .37509 .42782 .36558 Mtetra
.663 .741 .908 r
.42782 .36558 .4366 .37509 .4517 .36995 .44297 .36039 Mtetra
.662 .741 .909 r
.44297 .36039 .4517 .36995 .46688 .36478 .4582 .35524 Mtetra
.65 .738 .914 r
.4582 .35524 .46688 .36478 .48214 .35962 .47351 .35052 Mtetra
.622 .741 .932 r
.47351 .35052 .48214 .35962 .49749 .35466 .4889 .34672 Mtetra
.637 .776 .947 r
.4889 .34672 .49749 .35466 .51292 .35013 .5044 .34223 Mtetra
.696 .795 .926 r
.5044 .34223 .51292 .35013 .52845 .3452 .52 .33561 Mtetra
.693 .756 .9 r
.52 .33561 .52845 .3452 .54407 .33926 .53567 .32898 Mtetra
.671 .736 .898 r
.53567 .32898 .54407 .33926 .55977 .33332 .55143 .32324 Mtetra
.664 .739 .905 r
.55143 .32324 .55977 .33332 .57556 .32779 .56728 .31777 Mtetra
.664 .741 .908 r
.56728 .31777 .57556 .32779 .59144 .32237 .58322 .3123 Mtetra
.58322 .3123 .59144 .32237 .60741 .31693 .59926 .30681 Mtetra
.59926 .30681 .60741 .31693 .62347 .31146 .61538 .30128 Mtetra
.61538 .30128 .62347 .31146 .63963 .30596 .6316 .29572 Mtetra
.6316 .29572 .63963 .30596 .65588 .30043 .64792 .29013 Mtetra
.64792 .29013 .65588 .30043 .67223 .29486 .66433 .2845 Mtetra
.66433 .2845 .67223 .29486 .68867 .28926 .68083 .27884 Mtetra
.68083 .27884 .68867 .28926 .7052 .28363 .69743 .27315 Mtetra
.69743 .27315 .7052 .28363 .72183 .27797 .71413 .26743 Mtetra
.71413 .26743 .72183 .27797 .73856 .27227 .73093 .26167 Mtetra
.73093 .26167 .73856 .27227 .75539 .26654 .74783 .25587 Mtetra
.74783 .25587 .75539 .26654 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24418 Mtetra
.78193 .24418 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.21474 .42645 .2243 .43535 .23833 .43054 .22882 .42159 Mtetra
.22882 .42159 .23833 .43054 .25243 .4257 .24296 .41671 Mtetra
.24296 .41671 .25243 .4257 .26661 .42084 .25719 .4118 Mtetra
.25719 .4118 .26661 .42084 .28087 .41596 .27149 .40686 Mtetra
.27149 .40686 .28087 .41596 .2952 .41104 .28587 .4019 Mtetra
.28587 .4019 .2952 .41104 .30961 .4061 .30033 .39691 Mtetra
.30033 .39691 .30961 .4061 .32411 .40113 .31487 .39189 Mtetra
.31487 .39189 .32411 .40113 .33868 .39614 .32949 .38684 Mtetra
.32949 .38684 .33868 .39614 .35333 .39112 .34419 .38177 Mtetra
.34419 .38177 .35333 .39112 .36806 .38606 .35898 .37667 Mtetra
.35898 .37667 .36806 .38606 .38288 .38099 .37384 .37154 Mtetra
.37384 .37154 .38288 .38099 .39777 .37588 .38879 .36638 Mtetra
.38879 .36638 .39777 .37588 .41275 .37074 .40382 .36119 Mtetra
.663 .741 .908 r
.40382 .36119 .41275 .37074 .42782 .36558 .41894 .35598 Mtetra
.66 .74 .909 r
.41894 .35598 .42782 .36558 .44297 .36039 .43414 .35085 Mtetra
.637 .736 .92 r
.43414 .35085 .44297 .36039 .4582 .35524 .4494 .34657 Mtetra
.571 .734 .952 r
.4494 .34657 .4582 .35524 .47351 .35052 .46473 .34415 Mtetra
.589 .804 .982 r
.46473 .34415 .47351 .35052 .4889 .34672 .48019 .34055 Mtetra
.725 .847 .939 r
.48019 .34055 .4889 .34672 .5044 .34223 .49579 .33277 Mtetra
.721 .767 .89 r
.49579 .33277 .5044 .34223 .52 .33561 .51145 .32482 Mtetra
.678 .728 .888 r
.51145 .32482 .52 .33561 .53567 .32898 .52719 .31868 Mtetra
.665 .735 .902 r
.52719 .31868 .53567 .32898 .55143 .32324 .54301 .31315 Mtetra
.664 .741 .907 r
.54301 .31315 .55143 .32324 .56728 .31777 .55892 .30766 Mtetra
.664 .741 .908 r
.55892 .30766 .56728 .31777 .58322 .3123 .57492 .30213 Mtetra
.57492 .30213 .58322 .3123 .59926 .30681 .59101 .29658 Mtetra
.59101 .29658 .59926 .30681 .61538 .30128 .6072 .29099 Mtetra
.6072 .29099 .61538 .30128 .6316 .29572 .62349 .28537 Mtetra
.62349 .28537 .6316 .29572 .64792 .29013 .63987 .27972 Mtetra
.63987 .27972 .64792 .29013 .66433 .2845 .65634 .27403 Mtetra
.65634 .27403 .66433 .2845 .68083 .27884 .67291 .26831 Mtetra
.67291 .26831 .68083 .27884 .69743 .27315 .68958 .26256 Mtetra
.68958 .26256 .69743 .27315 .71413 .26743 .70635 .25677 Mtetra
.70635 .25677 .71413 .26743 .73093 .26167 .72322 .25095 Mtetra
.72322 .25095 .73093 .26167 .74783 .25587 .74019 .24509 Mtetra
.74019 .24509 .74783 .25587 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24418 .77443 .23327 Mtetra
.77443 .23327 .78193 .24418 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.20509 .41746 .21474 .42645 .22882 .42159 .21921 .41256 Mtetra
.21921 .41256 .22882 .42159 .24296 .41671 .2334 .40762 Mtetra
.2334 .40762 .24296 .41671 .25719 .4118 .24767 .40267 Mtetra
.24767 .40267 .25719 .4118 .27149 .40686 .26202 .39768 Mtetra
.26202 .39768 .27149 .40686 .28587 .4019 .27645 .39266 Mtetra
.27645 .39266 .28587 .4019 .30033 .39691 .29096 .38762 Mtetra
.29096 .38762 .30033 .39691 .31487 .39189 .30555 .38255 Mtetra
.30555 .38255 .31487 .39189 .32949 .38684 .32021 .37745 Mtetra
.32021 .37745 .32949 .38684 .34419 .38177 .33497 .37233 Mtetra
.33497 .37233 .34419 .38177 .35898 .37667 .3498 .36717 Mtetra
.3498 .36717 .35898 .37667 .37384 .37154 .36472 .36199 Mtetra
.36472 .36199 .37384 .37154 .38879 .36638 .37972 .35677 Mtetra
.663 .741 .908 r
.37972 .35677 .38879 .36638 .40382 .36119 .3948 .35154 Mtetra
.658 .74 .91 r
.3948 .35154 .40382 .36119 .41894 .35598 .40996 .34648 Mtetra
.614 .73 .928 r
.40996 .34648 .41894 .35598 .43414 .35085 .42517 .34294 Mtetra
.448 .704 .976 r
.42517 .34294 .43414 .35085 .4494 .34657 .44038 .34288 Mtetra
.412 .803 .988 r
.44038 .34288 .4494 .34657 .46473 .34415 .45577 .341 Mtetra
.763 .927 .941 r
.45577 .341 .46473 .34415 .48019 .34055 .47141 .33127 Mtetra
.762 .781 .868 r
.47141 .33127 .48019 .34055 .49579 .33277 .48711 .32099 Mtetra
.689 .714 .868 r
.48711 .32099 .49579 .33277 .51145 .32482 .50282 .31414 Mtetra
.666 .729 .896 r
.50282 .31414 .51145 .32482 .52719 .31868 .51861 .30851 Mtetra
.664 .74 .907 r
.51861 .30851 .52719 .31868 .54301 .31315 .53449 .30298 Mtetra
.664 .741 .908 r
.53449 .30298 .54301 .31315 .55892 .30766 .55046 .29743 Mtetra
.55046 .29743 .55892 .30766 .57492 .30213 .56653 .29185 Mtetra
.56653 .29185 .57492 .30213 .59101 .29658 .58268 .28624 Mtetra
.58268 .28624 .59101 .29658 .6072 .29099 .59894 .28059 Mtetra
.59894 .28059 .6072 .29099 .62349 .28537 .61528 .27491 Mtetra
.61528 .27491 .62349 .28537 .63987 .27972 .63173 .26919 Mtetra
.63173 .26919 .63987 .27972 .65634 .27403 .64827 .26344 Mtetra
.64827 .26344 .65634 .27403 .67291 .26831 .66491 .25766 Mtetra
.66491 .25766 .67291 .26831 .68958 .26256 .68164 .25184 Mtetra
.68164 .25184 .68958 .26256 .70635 .25677 .69848 .24599 Mtetra
.69848 .24599 .70635 .25677 .72322 .25095 .71542 .24011 Mtetra
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23418 Mtetra
.73246 .23418 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Mtetra
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .2162 Mtetra
.78419 .2162 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.19534 .40839 .20509 .41746 .21921 .41256 .2095 .40343 Mtetra
.2095 .40343 .21921 .41256 .2334 .40762 .22374 .39845 Mtetra
.22374 .39845 .2334 .40762 .24767 .40267 .23806 .39344 Mtetra
.23806 .39344 .24767 .40267 .26202 .39768 .25245 .3884 Mtetra
.25245 .3884 .26202 .39768 .27645 .39266 .26693 .38333 Mtetra
.26693 .38333 .27645 .39266 .29096 .38762 .28149 .37824 Mtetra
.28149 .37824 .29096 .38762 .30555 .38255 .29612 .37312 Mtetra
.29612 .37312 .30555 .38255 .32021 .37745 .31084 .36797 Mtetra
.31084 .36797 .32021 .37745 .33497 .37233 .32564 .36279 Mtetra
.32564 .36279 .33497 .37233 .3498 .36717 .34053 .35758 Mtetra
.34053 .35758 .3498 .36717 .36472 .36199 .35549 .35234 Mtetra
.663 .741 .908 r
.35549 .35234 .36472 .36199 .37972 .35677 .37055 .34709 Mtetra
.655 .739 .912 r
.37055 .34709 .37972 .35677 .3948 .35154 .38567 .34213 Mtetra
.574 .718 .941 r
.38567 .34213 .3948 .35154 .40996 .34648 .40078 .33972 Mtetra
.132 .561 .924 r
.40078 .33972 .40996 .34648 .42517 .34294 .41579 .34348 Mtetra
.134 0 0 r
.41579 .34348 .42517 .34294 .44038 .34288 .43106 .3446 Mtetra
.764 .995 .862 r
.43106 .3446 .44038 .34288 .45577 .341 .44682 .33188 Mtetra
.812 .79 .831 r
.44682 .33188 .45577 .341 .47141 .33127 .46262 .31771 Mtetra
.702 .69 .835 r
.46262 .31771 .47141 .33127 .48711 .32099 .47834 .30964 Mtetra
.668 .717 .885 r
.47834 .30964 .48711 .32099 .50282 .31414 .4941 .30385 Mtetra
.664 .738 .906 r
.4941 .30385 .50282 .31414 .51861 .30851 .50995 .29829 Mtetra
.664 .741 .908 r
.50995 .29829 .51861 .30851 .53449 .30298 .52589 .29271 Mtetra
.52589 .29271 .53449 .30298 .55046 .29743 .54192 .2871 Mtetra
.54192 .2871 .55046 .29743 .56653 .29185 .55804 .28146 Mtetra
.55804 .28146 .56653 .29185 .58268 .28624 .57426 .27578 Mtetra
.57426 .27578 .58268 .28624 .59894 .28059 .59058 .27007 Mtetra
.59058 .27007 .59894 .28059 .61528 .27491 .60699 .26433 Mtetra
.60699 .26433 .61528 .27491 .63173 .26919 .6235 .25855 Mtetra
.6235 .25855 .63173 .26919 .64827 .26344 .64011 .25274 Mtetra
.64011 .25274 .64827 .26344 .66491 .25766 .65681 .24689 Mtetra
.65681 .24689 .66491 .25766 .68164 .25184 .67362 .24101 Mtetra
.67362 .24101 .68164 .25184 .69848 .24599 .69052 .2351 Mtetra
.69052 .2351 .69848 .24599 .71542 .24011 .70753 .22915 Mtetra
.70753 .22915 .71542 .24011 .73246 .23418 .72464 .22316 Mtetra
.72464 .22316 .73246 .23418 .7496 .22823 .74185 .21713 Mtetra
.74185 .21713 .7496 .22823 .76684 .22223 .75917 .21107 Mtetra
.75917 .21107 .76684 .22223 .78419 .2162 .77659 .20498 Mtetra
.77659 .20498 .78419 .2162 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.18549 .39922 .19534 .40839 .2095 .40343 .1997 .39421 Mtetra
.1997 .39421 .2095 .40343 .22374 .39845 .21398 .38918 Mtetra
.21398 .38918 .22374 .39845 .23806 .39344 .22835 .38411 Mtetra
.22835 .38411 .23806 .39344 .25245 .3884 .24279 .37903 Mtetra
.24279 .37903 .25245 .3884 .26693 .38333 .25731 .37391 Mtetra
.25731 .37391 .26693 .38333 .28149 .37824 .27192 .36876 Mtetra
.27192 .36876 .28149 .37824 .29612 .37312 .2866 .36359 Mtetra
.2866 .36359 .29612 .37312 .31084 .36797 .30137 .35838 Mtetra
.30137 .35838 .31084 .36797 .32564 .36279 .31622 .35315 Mtetra
.31622 .35315 .32564 .36279 .34053 .35758 .33116 .34789 Mtetra
.663 .741 .908 r
.33116 .34789 .34053 .35758 .35549 .35234 .34618 .34261 Mtetra
.65 .738 .913 r
.34618 .34261 .35549 .35234 .37055 .34709 .36125 .3378 Mtetra
.505 .695 .954 r
.36125 .3378 .37055 .34709 .38567 .34213 .37623 .33703 Mtetra
.435 0 0 r
.37623 .33703 .38567 .34213 .40078 .33972 .39091 .34648 Mtetra
.551 .05 .018 r
.39091 .34648 .40078 .33972 .41579 .34348 .40594 .35252 Mtetra
.604 .884 .57 r
.40594 .35252 .41579 .34348 .43106 .3446 .42192 .3355 Mtetra
.86 .788 .779 r
.42192 .3355 .43106 .3446 .44682 .33188 .43797 .31525 Mtetra
.713 .655 .791 r
.43797 .31525 .44682 .33188 .46262 .31771 .45373 .30521 Mtetra
.67 .697 .867 r
.45373 .30521 .46262 .31771 .47834 .30964 .46947 .29917 Mtetra
.664 .736 .903 r
.46947 .29917 .47834 .30964 .4941 .30385 .48528 .29357 Mtetra
.664 .741 .908 r
.48528 .29357 .4941 .30385 .50995 .29829 .50119 .28797 Mtetra
.50119 .28797 .50995 .29829 .52589 .29271 .51719 .28233 Mtetra
.51719 .28233 .52589 .29271 .54192 .2871 .53328 .27666 Mtetra
.53328 .27666 .54192 .2871 .55804 .28146 .54947 .27095 Mtetra
.54947 .27095 .55804 .28146 .57426 .27578 .56575 .26522 Mtetra
.56575 .26522 .57426 .27578 .59058 .27007 .58213 .25944 Mtetra
.58213 .25944 .59058 .27007 .60699 .26433 .59861 .25364 Mtetra
.59861 .25364 .60699 .26433 .6235 .25855 .61518 .2478 Mtetra
.61518 .2478 .6235 .25855 .64011 .25274 .63185 .24192 Mtetra
.63185 .24192 .64011 .25274 .65681 .24689 .64863 .23601 Mtetra
.64863 .23601 .65681 .24689 .67362 .24101 .6655 .23006 Mtetra
.6655 .23006 .67362 .24101 .69052 .2351 .68248 .22408 Mtetra
.68248 .22408 .69052 .2351 .70753 .22915 .69955 .21806 Mtetra
.69955 .21806 .70753 .22915 .72464 .22316 .71674 .21201 Mtetra
.71674 .21201 .72464 .22316 .74185 .21713 .73402 .20592 Mtetra
.73402 .20592 .74185 .21713 .75917 .21107 .75141 .19979 Mtetra
.75141 .19979 .75917 .21107 .77659 .20498 .76891 .19362 Mtetra
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.17555 .38995 .18549 .39922 .1997 .39421 .1898 .3849 Mtetra
.1898 .3849 .1997 .39421 .21398 .38918 .20413 .37981 Mtetra
.20413 .37981 .21398 .38918 .22835 .38411 .21853 .3747 Mtetra
.21853 .3747 .22835 .38411 .24279 .37903 .23302 .36955 Mtetra
.23302 .36955 .24279 .37903 .25731 .37391 .2476 .36438 Mtetra
.2476 .36438 .25731 .37391 .27192 .36876 .26225 .35918 Mtetra
.26225 .35918 .27192 .36876 .2866 .36359 .27698 .35396 Mtetra
.27698 .35396 .2866 .36359 .30137 .35838 .2918 .3487 Mtetra
.2918 .3487 .30137 .35838 .31622 .35315 .3067 .34341 Mtetra
.663 .741 .908 r
.3067 .34341 .31622 .35315 .33116 .34789 .32169 .33812 Mtetra
.644 .736 .916 r
.32169 .33812 .33116 .34789 .34618 .34261 .33672 .3335 Mtetra
.386 .646 .96 r
.33672 .3335 .34618 .34261 .36125 .3378 .35151 .33488 Mtetra
.764 .252 0 r
.35151 .33488 .36125 .3378 .37623 .33703 .36564 .35225 Mtetra
.668 .267 .277 r
.36564 .35225 .37623 .33703 .39091 .34648 .38026 .36577 Mtetra
0 0 0 r
.38026 .36577 .39091 .34648 .40594 .35252 .39662 .34303 Mtetra
.894 .773 .721 r
.39662 .34303 .40594 .35252 .42192 .3355 .41313 .31391 Mtetra
.718 .614 .74 r
.41313 .31391 .42192 .3355 .43797 .31525 .429 .30089 Mtetra
.67 .669 .84 r
.429 .30089 .43797 .31525 .45373 .30521 .44471 .29447 Mtetra
.664 .731 .9 r
.44471 .29447 .45373 .30521 .46947 .29917 .4605 .28883 Mtetra
.664 .741 .908 r
.4605 .28883 .46947 .29917 .48528 .29357 .47637 .2832 Mtetra
.47637 .2832 .48528 .29357 .50119 .28797 .49233 .27753 Mtetra
.49233 .27753 .50119 .28797 .51719 .28233 .50839 .27183 Mtetra
.50839 .27183 .51719 .28233 .53328 .27666 .52455 .2661 Mtetra
.52455 .2661 .53328 .27666 .54947 .27095 .5408 .26033 Mtetra
.5408 .26033 .54947 .27095 .56575 .26522 .55715 .25453 Mtetra
.55715 .25453 .56575 .26522 .58213 .25944 .57359 .2487 Mtetra
.57359 .2487 .58213 .25944 .59861 .25364 .59013 .24283 Mtetra
.59013 .24283 .59861 .25364 .61518 .2478 .60677 .23692 Mtetra
.60677 .23692 .61518 .2478 .63185 .24192 .62351 .23098 Mtetra
.62351 .23098 .63185 .24192 .64863 .23601 .64035 .225 Mtetra
.64035 .225 .64863 .23601 .6655 .23006 .6573 .21899 Mtetra
.6573 .21899 .6655 .23006 .68248 .22408 .67434 .21294 Mtetra
.67434 .21294 .68248 .22408 .69955 .21806 .69149 .20686 Mtetra
.69149 .20686 .69955 .21806 .71674 .21201 .70874 .20073 Mtetra
.70874 .20073 .71674 .21201 .73402 .20592 .7261 .19457 Mtetra
.7261 .19457 .73402 .20592 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Mtetra
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.1655 .38059 .17555 .38995 .1898 .3849 .17979 .37549 Mtetra
.17979 .37549 .1898 .3849 .20413 .37981 .19417 .37035 Mtetra
.19417 .37035 .20413 .37981 .21853 .3747 .20862 .36518 Mtetra
.20862 .36518 .21853 .3747 .23302 .36955 .22316 .35999 Mtetra
.22316 .35999 .23302 .36955 .2476 .36438 .23778 .35476 Mtetra
.23778 .35476 .2476 .36438 .26225 .35918 .25248 .34951 Mtetra
.25248 .34951 .26225 .35918 .27698 .35396 .26726 .34422 Mtetra
.26726 .34422 .27698 .35396 .2918 .3487 .28213 .33891 Mtetra
.663 .741 .908 r
.28213 .33891 .2918 .3487 .3067 .34341 .29708 .33361 Mtetra
.637 .734 .919 r
.29708 .33361 .3067 .34341 .32169 .33812 .31205 .32921 Mtetra
.196 .549 .931 r
.31205 .32921 .32169 .33812 .33672 .3335 .32659 .33321 Mtetra
.853 .422 .2 r
.32659 .33321 .33672 .3335 .35151 .33488 .33993 .36076 Mtetra
.71 .36 .383 r
.33993 .36076 .35151 .33488 .36564 .35225 .35386 .38484 Mtetra
0 0 .027 r
.35386 .38484 .36564 .35225 .38026 .36577 .37078 .35509 Mtetra
.911 .75 .67 r
.37078 .35509 .38026 .36577 .39662 .34303 .38805 .31394 Mtetra
.717 .574 .693 r
.38805 .31394 .39662 .34303 .41313 .31391 .40413 .29672 Mtetra
.668 .632 .804 r
.40413 .29672 .41313 .31391 .429 .30089 .41984 .28976 Mtetra
.664 .724 .894 r
.41984 .28976 .429 .30089 .44471 .29447 .43559 .28407 Mtetra
.664 .74 .907 r
.43559 .28407 .44471 .29447 .4605 .28883 .45143 .27841 Mtetra
.664 .741 .908 r
.45143 .27841 .4605 .28883 .47637 .2832 .46736 .27271 Mtetra
.46736 .27271 .47637 .2832 .49233 .27753 .48338 .26698 Mtetra
.48338 .26698 .49233 .27753 .50839 .27183 .49951 .26122 Mtetra
.49951 .26122 .50839 .27183 .52455 .2661 .51572 .25543 Mtetra
.51572 .25543 .52455 .2661 .5408 .26033 .53204 .2496 Mtetra
.53204 .2496 .5408 .26033 .55715 .25453 .54845 .24373 Mtetra
.54845 .24373 .55715 .25453 .57359 .2487 .56495 .23783 Mtetra
.56495 .23783 .57359 .2487 .59013 .24283 .58156 .2319 Mtetra
.58156 .2319 .59013 .24283 .60677 .23692 .59827 .22593 Mtetra
.59827 .22593 .60677 .23692 .62351 .23098 .61508 .21992 Mtetra
.61508 .21992 .62351 .23098 .64035 .225 .63199 .21388 Mtetra
.63199 .21388 .64035 .225 .6573 .21899 .649 .2078 Mtetra
.649 .2078 .6573 .21899 .67434 .21294 .66611 .20168 Mtetra
.66611 .20168 .67434 .21294 .69149 .20686 .68334 .19552 Mtetra
.68334 .19552 .69149 .20686 .70874 .20073 .70066 .18933 Mtetra
.70066 .18933 .70874 .20073 .7261 .19457 .71809 .1831 Mtetra
.71809 .1831 .7261 .19457 .74357 .18838 .73563 .17683 Mtetra
.73563 .17683 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.15534 .37114 .1655 .38059 .17979 .37549 .16968 .36598 Mtetra
.16968 .36598 .17979 .37549 .19417 .37035 .1841 .36079 Mtetra
.1841 .36079 .19417 .37035 .20862 .36518 .19861 .35557 Mtetra
.19861 .35557 .20862 .36518 .22316 .35999 .21319 .35032 Mtetra
.21319 .35032 .22316 .35999 .23778 .35476 .22786 .34504 Mtetra
.22786 .34504 .23778 .35476 .25248 .34951 .24261 .33973 Mtetra
.24261 .33973 .25248 .34951 .26726 .34422 .25744 .33439 Mtetra
.662 .741 .908 r
.25744 .33439 .26726 .34422 .28213 .33891 .27236 .32907 Mtetra
.629 .732 .922 r
.27236 .32907 .28213 .33891 .29708 .33361 .28727 .32491 Mtetra
0 .384 .828 r
.28727 .32491 .29708 .33361 .31205 .32921 .30149 .33181 Mtetra
.877 .496 .315 r
.30149 .33181 .31205 .32921 .32659 .33321 .31375 .37139 Mtetra
.732 .409 .435 r
.31375 .37139 .32659 .33321 .33993 .36076 .32664 .40923 Mtetra
0 0 .152 r
.32664 .40923 .33993 .36076 .35386 .38484 .34429 .3717 Mtetra
.915 .726 .633 r
.34429 .3717 .35386 .38484 .37078 .35509 .36269 .31543 Mtetra
.712 .54 .654 r
.36269 .31543 .37078 .35509 .38805 .31394 .37912 .29273 Mtetra
.662 .591 .765 r
.37912 .29273 .38805 .31394 .40413 .29672 .39484 .28503 Mtetra
.664 .714 .886 r
.39484 .28503 .40413 .29672 .41984 .28976 .41055 .27928 Mtetra
.664 .74 .907 r
.41055 .27928 .41984 .28976 .43559 .28407 .42636 .27359 Mtetra
.664 .741 .908 r
.42636 .27359 .43559 .28407 .45143 .27841 .44226 .26787 Mtetra
.44226 .26787 .45143 .27841 .46736 .27271 .45825 .26211 Mtetra
.45825 .26211 .46736 .27271 .48338 .26698 .47434 .25632 Mtetra
.47434 .25632 .48338 .26698 .49951 .26122 .49052 .2505 Mtetra
.49052 .2505 .49951 .26122 .51572 .25543 .5068 .24464 Mtetra
.5068 .24464 .51572 .25543 .53204 .2496 .52318 .23874 Mtetra
.52318 .23874 .53204 .2496 .54845 .24373 .53965 .23281 Mtetra
.53965 .23281 .54845 .24373 .56495 .23783 .55622 .22685 Mtetra
.55622 .22685 .56495 .23783 .58156 .2319 .5729 .22085 Mtetra
.5729 .22085 .58156 .2319 .59827 .22593 .58967 .21481 Mtetra
.58967 .21481 .59827 .22593 .61508 .21992 .60655 .20873 Mtetra
.60655 .20873 .61508 .21992 .63199 .21388 .62353 .20262 Mtetra
.62353 .20262 .63199 .21388 .649 .2078 .64061 .19647 Mtetra
.64061 .19647 .649 .2078 .66611 .20168 .6578 .19029 Mtetra
.6578 .19029 .66611 .20168 .68334 .19552 .67509 .18406 Mtetra
.67509 .18406 .68334 .19552 .70066 .18933 .69249 .1778 Mtetra
.69249 .1778 .70066 .18933 .71809 .1831 .70999 .1715 Mtetra
.70999 .1715 .71809 .1831 .73563 .17683 .72761 .16516 Mtetra
.72761 .16516 .73563 .17683 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.14508 .36159 .15534 .37114 .16968 .36598 .15947 .35637 Mtetra
.15947 .35637 .16968 .36598 .1841 .36079 .17394 .35113 Mtetra
.17394 .35113 .1841 .36079 .19861 .35557 .18849 .34585 Mtetra
.18849 .34585 .19861 .35557 .21319 .35032 .20312 .34055 Mtetra
.20312 .34055 .21319 .35032 .22786 .34504 .21783 .33521 Mtetra
.21783 .33521 .22786 .34504 .24261 .33973 .23263 .32985 Mtetra
.662 .741 .909 r
.23263 .32985 .24261 .33973 .25744 .33439 .24751 .32451 Mtetra
.622 .73 .924 r
.24751 .32451 .25744 .33439 .27236 .32907 .26236 .32057 Mtetra
0 .183 .654 r
.26236 .32057 .27236 .32907 .28727 .32491 .27622 .33034 Mtetra
.886 .534 .374 r
.27622 .33034 .28727 .32491 .30149 .33181 .28714 .3828 Mtetra
.747 .439 .462 r
.28714 .3828 .30149 .33181 .31375 .37139 .29857 .43709 Mtetra
.027 0 .222 r
.29857 .43709 .31375 .37139 .32664 .40923 .31709 .3919 Mtetra
.912 .703 .607 r
.31709 .3919 .32664 .40923 .34429 .3717 .33703 .31821 Mtetra
.706 .512 .625 r
.33703 .31821 .34429 .3717 .36269 .31543 .35396 .2889 Mtetra
.653 .55 .726 r
.35396 .2889 .36269 .31543 .37912 .29273 .36971 .2803 Mtetra
.663 .702 .876 r
.36971 .2803 .37912 .29273 .39484 .28503 .3854 .27447 Mtetra
.664 .739 .906 r
.3854 .27447 .39484 .28503 .41055 .27928 .40117 .26875 Mtetra
.664 .741 .908 r
.40117 .26875 .41055 .27928 .42636 .27359 .41703 .263 Mtetra
.41703 .263 .42636 .27359 .44226 .26787 .43299 .25721 Mtetra
.43299 .25721 .44226 .26787 .45825 .26211 .44904 .25139 Mtetra
.44904 .25139 .45825 .26211 .47434 .25632 .46519 .24554 Mtetra
.46519 .24554 .47434 .25632 .49052 .2505 .48143 .23965 Mtetra
.48143 .23965 .49052 .2505 .5068 .24464 .49778 .23373 Mtetra
.49778 .23373 .5068 .24464 .52318 .23874 .51422 .22777 Mtetra
.51422 .22777 .52318 .23874 .53965 .23281 .53076 .22177 Mtetra
.53076 .22177 .53965 .23281 .55622 .22685 .5474 .21574 Mtetra
.5474 .21574 .55622 .22685 .5729 .22085 .56414 .20967 Mtetra
.56414 .20967 .5729 .22085 .58967 .21481 .58098 .20357 Mtetra
.58098 .20357 .58967 .21481 .60655 .20873 .59792 .19742 Mtetra
.59792 .19742 .60655 .20873 .62353 .20262 .61497 .19124 Mtetra
.61497 .19124 .62353 .20262 .64061 .19647 .63212 .18502 Mtetra
.63212 .18502 .64061 .19647 .6578 .19029 .64938 .17877 Mtetra
.64938 .17877 .6578 .19029 .67509 .18406 .66675 .17247 Mtetra
.66675 .17247 .67509 .18406 .69249 .1778 .68422 .16614 Mtetra
.68422 .16614 .69249 .1778 .70999 .1715 .7018 .15976 Mtetra
.7018 .15976 .70999 .1715 .72761 .16516 .71949 .15335 Mtetra
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Mtetra
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.13472 .35194 .14508 .36159 .15947 .35637 .14915 .34667 Mtetra
.14915 .34667 .15947 .35637 .17394 .35113 .16366 .34137 Mtetra
.16366 .34137 .17394 .35113 .18849 .34585 .17826 .33604 Mtetra
.17826 .33604 .18849 .34585 .20312 .34055 .19294 .33068 Mtetra
.19294 .33068 .20312 .34055 .21783 .33521 .2077 .32529 Mtetra
.662 .741 .909 r
.2077 .32529 .21783 .33521 .23263 .32985 .22255 .31993 Mtetra
.616 .729 .926 r
.22255 .31993 .23263 .32985 .24751 .32451 .23733 .31615 Mtetra
.515 0 0 r
.23733 .31615 .24751 .32451 .26236 .32057 .25081 .32839 Mtetra
.89 .555 .407 r
.25081 .32839 .26236 .32057 .27622 .33034 .26023 .39309 Mtetra
.758 .459 .478 r
.26023 .39309 .27622 .33034 .28714 .3828 .26983 .46509 Mtetra
.073 0 .261 r
.26983 .46509 .28714 .3828 .29857 .43709 .28925 .41359 Mtetra
.905 .683 .592 r
.28925 .41359 .29857 .43709 .31709 .3919 .31107 .32176 Mtetra
.698 .491 .604 r
.31107 .32176 .31709 .3919 .33703 .31821 .32866 .2852 Mtetra
.644 .515 .692 r
.32866 .2852 .33703 .31821 .35396 .2889 .34446 .27555 Mtetra
.661 .686 .863 r
.34446 .27555 .35396 .2889 .36971 .2803 .36011 .26964 Mtetra
.663 .738 .906 r
.36011 .26964 .36971 .2803 .3854 .27447 .37585 .26389 Mtetra
.664 .741 .908 r
.37585 .26389 .3854 .27447 .40117 .26875 .39168 .25811 Mtetra
.39168 .25811 .40117 .26875 .41703 .263 .4076 .25229 Mtetra
.4076 .25229 .41703 .263 .43299 .25721 .42362 .24644 Mtetra
.42362 .24644 .43299 .25721 .44904 .25139 .43973 .24056 Mtetra
.43973 .24056 .44904 .25139 .46519 .24554 .45594 .23464 Mtetra
.45594 .23464 .46519 .24554 .48143 .23965 .47225 .22869 Mtetra
.47225 .22869 .48143 .23965 .49778 .23373 .48865 .2227 Mtetra
.48865 .2227 .49778 .23373 .51422 .22777 .50516 .21667 Mtetra
.50516 .21667 .51422 .22777 .53076 .22177 .52176 .21061 Mtetra
.52176 .21061 .53076 .22177 .5474 .21574 .53847 .20451 Mtetra
.53847 .20451 .5474 .21574 .56414 .20967 .55527 .19837 Mtetra
.55527 .19837 .56414 .20967 .58098 .20357 .57218 .1922 Mtetra
.57218 .1922 .58098 .20357 .59792 .19742 .5892 .18598 Mtetra
.5892 .18598 .59792 .19742 .61497 .19124 .60632 .17973 Mtetra
.60632 .17973 .61497 .19124 .63212 .18502 .62354 .17344 Mtetra
.62354 .17344 .63212 .18502 .64938 .17877 .64087 .16711 Mtetra
.64087 .16711 .64938 .17877 .66675 .17247 .65831 .16075 Mtetra
.65831 .16075 .66675 .17247 .68422 .16614 .67586 .15434 Mtetra
.67586 .15434 .68422 .16614 .7018 .15976 .69351 .14789 Mtetra
.69351 .14789 .7018 .15976 .71949 .15335 .71128 .14141 Mtetra
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Mtetra
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Mtetra
.12424 .34218 .13472 .35194 .14915 .34667 .13872 .33686 Mtetra
.13872 .33686 .14915 .34667 .16366 .34137 .15328 .3315 Mtetra
.15328 .3315 .16366 .34137 .17826 .33604 .16793 .32612 Mtetra
.16793 .32612 .17826 .33604 .19294 .33068 .18265 .3207 Mtetra
.662 .741 .909 r
.18265 .3207 .19294 .33068 .2077 .32529 .19746 .31532 Mtetra
.612 .728 .928 r
.19746 .31532 .2077 .32529 .22255 .31993 .21218 .31161 Mtetra
.616 .087 0 r
.21218 .31161 .22255 .31993 .23733 .31615 .22532 .32554 Mtetra
.892 .567 .426 r
.22532 .32554 .23733 .31615 .25081 .32839 .23325 .40004 Mtetra
.769 .474 .488 r
.23325 .40004 .25081 .32839 .26023 .39309 .24079 .48879 Mtetra
.108 0 .285 r
.24079 .48879 .26023 .39309 .26983 .46509 .26098 .4336 Mtetra
.895 .665 .584 r
.26098 .4336 .26983 .46509 .28925 .41359 .28485 .32521 Mtetra
.692 .476 .59 r
.28485 .32521 .28925 .41359 .31107 .32176 .3032 .28151 Mtetra
.635 .487 .664 r
.3032 .28151 .31107 .32176 .32866 .2852 .31908 .27078 Mtetra
.659 .67 .849 r
.31908 .27078 .32866 .2852 .34446 .27555 .33471 .26478 Mtetra
.663 .737 .905 r
.33471 .26478 .34446 .27555 .36011 .26964 .35041 .259 Mtetra
.664 .741 .908 r
.35041 .259 .36011 .26964 .37585 .26389 .3662 .25319 Mtetra
.3662 .25319 .37585 .26389 .39168 .25811 .38209 .24735 Mtetra
.38209 .24735 .39168 .25811 .4076 .25229 .39807 .24147 Mtetra
.39807 .24147 .4076 .25229 .42362 .24644 .41415 .23555 Mtetra
.41415 .23555 .42362 .24644 .43973 .24056 .43032 .22961 Mtetra
.43032 .22961 .43973 .24056 .45594 .23464 .44659 .22362 Mtetra
.44659 .22362 .45594 .23464 .47225 .22869 .46296 .2176 Mtetra
.46296 .2176 .47225 .22869 .48865 .2227 .47943 .21154 Mtetra
.47943 .21154 .48865 .2227 .50516 .21667 .496 .20545 Mtetra
.496 .20545 .50516 .21667 .52176 .21061 .51267 .19932 Mtetra
.51267 .19932 .52176 .21061 .53847 .20451 .52944 .19315 Mtetra
.52944 .19315 .53847 .20451 .55527 .19837 .54631 .18694 Mtetra
.54631 .18694 .55527 .19837 .57218 .1922 .56329 .1807 Mtetra
.56329 .1807 .57218 .1922 .5892 .18598 .58037 .17441 Mtetra
.58037 .17441 .5892 .18598 .60632 .17973 .59756 .16809 Mtetra
.59756 .16809 .60632 .17973 .62354 .17344 .61486 .16173 Mtetra
.61486 .16173 .62354 .17344 .64087 .16711 .63226 .15533 Mtetra
.63226 .15533 .64087 .16711 .65831 .16075 .64977 .14889 Mtetra
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Mtetra
.6674 .14241 .67586 .15434 .69351 .14789 .68513 .13588 Mtetra
.68513 .13588 .69351 .14789 .71128 .14141 .70297 .12932 Mtetra
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.11366 .33233 .12424 .34218 .13872 .33686 .12818 .32695 Mtetra
.12818 .32695 .13872 .33686 .15328 .3315 .14279 .32154 Mtetra
.14279 .32154 .15328 .3315 .16793 .32612 .15748 .31609 Mtetra
.662 .741 .909 r
.15748 .31609 .16793 .32612 .18265 .3207 .17225 .31068 Mtetra
.612 .728 .928 r
.17225 .31068 .18265 .3207 .19746 .31532 .18692 .30695 Mtetra
.652 .126 0 r
.18692 .30695 .19746 .31532 .21218 .31161 .1998 .32149 Mtetra
.894 .574 .435 r
.1998 .32149 .21218 .31161 .22532 .32554 .20646 .40172 Mtetra
.778 .486 .493 r
.20646 .40172 .22532 .32554 .23325 .40004 .21198 .50354 Mtetra
.136 0 .298 r
.21198 .50354 .23325 .40004 .24079 .48879 .23265 .44824 Mtetra
.883 .649 .58 r
.23265 .44824 .24079 .48879 .26098 .4336 .25847 .32746 Mtetra
.685 .463 .58 r
.25847 .32746 .26098 .4336 .28485 .32521 .27762 .27772 Mtetra
.627 .466 .644 r
.27762 .27772 .28485 .32521 .3032 .28151 .29358 .26598 Mtetra
.657 .654 .835 r
.29358 .26598 .3032 .28151 .31908 .27078 .30917 .2599 Mtetra
.663 .736 .904 r
.30917 .2599 .31908 .27078 .33471 .26478 .32484 .25409 Mtetra
.664 .741 .908 r
.32484 .25409 .33471 .26478 .35041 .259 .34059 .24825 Mtetra
.34059 .24825 .35041 .259 .3662 .25319 .35644 .24237 Mtetra
.35644 .24237 .3662 .25319 .38209 .24735 .37239 .23647 Mtetra
.37239 .23647 .38209 .24735 .39807 .24147 .38843 .23052 Mtetra
.38843 .23052 .39807 .24147 .41415 .23555 .40457 .22454 Mtetra
.40457 .22454 .41415 .23555 .43032 .22961 .4208 .21853 Mtetra
.4208 .21853 .43032 .22961 .44659 .22362 .43714 .21248 Mtetra
.43714 .21248 .44659 .22362 .46296 .2176 .45357 .20639 Mtetra
.45357 .20639 .46296 .2176 .47943 .21154 .4701 .20026 Mtetra
.4701 .20026 .47943 .21154 .496 .20545 .48673 .1941 Mtetra
.48673 .1941 .496 .20545 .51267 .19932 .50347 .1879 Mtetra
.50347 .1879 .51267 .19932 .52944 .19315 .52031 .18166 Mtetra
.52031 .18166 .52944 .19315 .54631 .18694 .53725 .17538 Mtetra
.53725 .17538 .54631 .18694 .56329 .1807 .5543 .16907 Mtetra
.5543 .16907 .56329 .1807 .58037 .17441 .57145 .16271 Mtetra
.57145 .16271 .58037 .17441 .59756 .16809 .58871 .15632 Mtetra
.58871 .15632 .59756 .16809 .61486 .16173 .60608 .14988 Mtetra
.60608 .14988 .61486 .16173 .63226 .15533 .62355 .14341 Mtetra
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Mtetra
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Mtetra
.65884 .13033 .6674 .14241 .68513 .13588 .67665 .12373 Mtetra
.67665 .12373 .68513 .13588 .70297 .12932 .69457 .11709 Mtetra
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.10296 .32237 .11366 .33233 .12818 .32695 .11753 .31693 Mtetra
.11753 .31693 .12818 .32695 .14279 .32154 .13219 .31146 Mtetra
.662 .741 .909 r
.13219 .31146 .14279 .32154 .15748 .31609 .14692 .30602 Mtetra
.615 .729 .927 r
.14692 .30602 .15748 .31609 .17225 .31068 .16155 .30216 Mtetra
.636 .108 0 r
.16155 .30216 .17225 .31068 .18692 .30695 .17429 .31613 Mtetra
.895 .577 .438 r
.17429 .31613 .18692 .30695 .1998 .32149 .18012 .39698 Mtetra
.786 .495 .494 r
.18012 .39698 .1998 .32149 .20646 .40172 .18399 .50575 Mtetra
.16 0 .302 r
.18399 .50575 .20646 .40172 .21198 .50354 .2047 .45419 Mtetra
.871 .635 .579 r
.2047 .45419 .21198 .50354 .23265 .44824 .23205 .32743 Mtetra
.679 .454 .573 r
.23205 .32743 .23265 .44824 .25847 .32746 .2519 .27367 Mtetra
.621 .451 .63 r
.2519 .27367 .25847 .32746 .27762 .27772 .26794 .26116 Mtetra
.654 .64 .823 r
.26794 .26116 .27762 .27772 .29358 .26598 .28351 .25499 Mtetra
.663 .735 .903 r
.28351 .25499 .29358 .26598 .30917 .2599 .29914 .24915 Mtetra
.664 .741 .908 r
.29914 .24915 .30917 .2599 .32484 .25409 .31485 .24328 Mtetra
.31485 .24328 .32484 .25409 .34059 .24825 .33067 .23738 Mtetra
.33067 .23738 .34059 .24825 .35644 .24237 .34658 .23144 Mtetra
.34658 .23144 .35644 .24237 .37239 .23647 .36258 .22547 Mtetra
.36258 .22547 .37239 .23647 .38843 .23052 .37868 .21946 Mtetra
.37868 .21946 .38843 .23052 .40457 .22454 .39488 .21341 Mtetra
.39488 .21341 .40457 .22454 .4208 .21853 .41118 .20733 Mtetra
.41118 .20733 .4208 .21853 .43714 .21248 .42757 .20121 Mtetra
.42757 .20121 .43714 .21248 .45357 .20639 .44407 .19505 Mtetra
.44407 .19505 .45357 .20639 .4701 .20026 .46067 .18886 Mtetra
.46067 .18886 .4701 .20026 .48673 .1941 .47737 .18262 Mtetra
.47737 .18262 .48673 .1941 .50347 .1879 .49417 .17635 Mtetra
.49417 .17635 .50347 .1879 .52031 .18166 .51107 .17004 Mtetra
.51107 .17004 .52031 .18166 .53725 .17538 .52808 .16369 Mtetra
.52808 .16369 .53725 .17538 .5543 .16907 .5452 .1573 Mtetra
.5452 .1573 .5543 .16907 .57145 .16271 .56242 .15087 Mtetra
.56242 .15087 .57145 .16271 .58871 .15632 .57976 .1444 Mtetra
.57976 .1444 .58871 .15632 .60608 .14988 .5972 .1379 Mtetra
.5972 .1379 .60608 .14988 .62355 .14341 .61475 .13134 Mtetra
.61475 .13134 .62355 .14341 .64114 .13689 .63241 .12475 Mtetra
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Mtetra
.65018 .11812 .65884 .13033 .67665 .12373 .66806 .11144 Mtetra
.66806 .11144 .67665 .12373 .69457 .11709 .68606 .10472 Mtetra
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Mtetra
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.09215 .3123 .10296 .32237 .11753 .31693 .10677 .30681 Mtetra
.662 .741 .908 r
.10677 .30681 .11753 .31693 .13219 .31146 .12147 .30133 Mtetra
.621 .731 .925 r
.12147 .30133 .13219 .31146 .14692 .30602 .13607 .29726 Mtetra
.56 .027 0 r
.13607 .29726 .14692 .30602 .16155 .30216 .1488 .30957 Mtetra
.897 .576 .433 r
.1488 .30957 .16155 .30216 .17429 .31613 .15439 .38582 Mtetra
.794 .501 .493 r
.15439 .38582 .17429 .31613 .18012 .39698 .15728 .49407 Mtetra
.18 0 .3 r
.15728 .49407 .18012 .39698 .18399 .50575 .17756 .44944 Mtetra
.859 .623 .58 r
.17756 .44944 .18399 .50575 .2047 .45419 .20573 .3243 Mtetra
.673 .447 .569 r
.20573 .3243 .2047 .45419 .23205 .32743 .22608 .26924 Mtetra
.616 .441 .621 r
.22608 .26924 .23205 .32743 .2519 .27367 .24218 .25629 Mtetra
.652 .629 .815 r
.24218 .25629 .2519 .27367 .26794 .26116 .25772 .25006 Mtetra
.663 .734 .902 r
.25772 .25006 .26794 .26116 .28351 .25499 .27331 .24419 Mtetra
.664 .741 .908 r
.27331 .24419 .28351 .25499 .29914 .24915 .28899 .23829 Mtetra
.28899 .23829 .29914 .24915 .31485 .24328 .30476 .23236 Mtetra
.30476 .23236 .31485 .24328 .33067 .23738 .32064 .22639 Mtetra
.32064 .22639 .33067 .23738 .34658 .23144 .3366 .22038 Mtetra
.3366 .22038 .34658 .23144 .36258 .22547 .35267 .21434 Mtetra
.35267 .21434 .36258 .22547 .37868 .21946 .36883 .20827 Mtetra
.36883 .20827 .37868 .21946 .39488 .21341 .38509 .20215 Mtetra
.38509 .20215 .39488 .21341 .41118 .20733 .40145 .196 Mtetra
.40145 .196 .41118 .20733 .42757 .20121 .4179 .18981 Mtetra
.4179 .18981 .42757 .20121 .44407 .19505 .43446 .18358 Mtetra
.43446 .18358 .44407 .19505 .46067 .18886 .45113 .17732 Mtetra
.45113 .17732 .46067 .18886 .47737 .18262 .46789 .17101 Mtetra
.46789 .17101 .47737 .18262 .49417 .17635 .48476 .16467 Mtetra
.48476 .16467 .49417 .17635 .51107 .17004 .50173 .15829 Mtetra
.50173 .15829 .51107 .17004 .52808 .16369 .51881 .15187 Mtetra
.51881 .15187 .52808 .16369 .5452 .1573 .536 .1454 Mtetra
.536 .1454 .5452 .1573 .56242 .15087 .55329 .1389 Mtetra
.55329 .1389 .56242 .15087 .57976 .1444 .5707 .13236 Mtetra
.5707 .13236 .57976 .1444 .5972 .1379 .58821 .12577 Mtetra
.58821 .12577 .5972 .1379 .61475 .13134 .60583 .11914 Mtetra
.60583 .11914 .61475 .13134 .63241 .12475 .62357 .11247 Mtetra
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Mtetra
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Mtetra
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Mtetra
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Mtetra
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.663 .741 .908 r
.08123 .30213 .09215 .3123 .10677 .30681 .09589 .29662 Mtetra
.629 .733 .922 r
.09589 .29662 .10677 .30681 .12147 .30133 .11047 .29228 Mtetra
0 .124 .592 r
.11047 .29228 .12147 .30133 .13607 .29726 .12332 .30212 Mtetra
.898 .571 .42 r
.12332 .30212 .13607 .29726 .1488 .30957 .12928 .36938 Mtetra
.801 .506 .489 r
.12928 .36938 .1488 .30957 .15439 .38582 .13204 .46983 Mtetra
.197 0 .287 r
.13204 .46983 .15439 .38582 .15728 .49407 .15151 .43397 Mtetra
.846 .611 .583 r
.15151 .43397 .15728 .49407 .17756 .44944 .17962 .31776 Mtetra
.668 .442 .568 r
.17962 .31776 .17756 .44944 .20573 .3243 .20017 .26434 Mtetra
.613 .436 .618 r
.20017 .26434 .20573 .3243 .22608 .26924 .21629 .25137 Mtetra
.65 .624 .81 r
.21629 .25137 .22608 .26924 .24218 .25629 .23179 .2451 Mtetra
.663 .733 .902 r
.23179 .2451 .24218 .25629 .25772 .25006 .24735 .2392 Mtetra
.664 .741 .908 r
.24735 .2392 .25772 .25006 .27331 .24419 .26299 .23327 Mtetra
.26299 .23327 .27331 .24419 .28899 .23829 .27873 .22731 Mtetra
.27873 .22731 .28899 .23829 .30476 .23236 .29456 .22131 Mtetra
.29456 .22131 .30476 .23236 .32064 .22639 .31049 .21527 Mtetra
.31049 .21527 .32064 .22639 .3366 .22038 .32652 .2092 Mtetra
.32652 .2092 .3366 .22038 .35267 .21434 .34264 .20309 Mtetra
.34264 .20309 .35267 .21434 .36883 .20827 .35886 .19695 Mtetra
.35886 .19695 .36883 .20827 .38509 .20215 .37518 .19077 Mtetra
.37518 .19077 .38509 .20215 .40145 .196 .3916 .18454 Mtetra
.3916 .18454 .40145 .196 .4179 .18981 .40812 .17828 Mtetra
.40812 .17828 .4179 .18981 .43446 .18358 .42475 .17199 Mtetra
.42475 .17199 .43446 .18358 .45113 .17732 .44148 .16565 Mtetra
.44148 .16565 .45113 .17732 .46789 .17101 .45831 .15927 Mtetra
.45831 .15927 .46789 .17101 .48476 .16467 .47524 .15286 Mtetra
.47524 .15286 .48476 .16467 .50173 .15829 .49228 .1464 Mtetra
.49228 .1464 .50173 .15829 .51881 .15187 .50943 .1399 Mtetra
.50943 .1399 .51881 .15187 .536 .1454 .52669 .13336 Mtetra
.52669 .13336 .536 .1454 .55329 .1389 .54406 .12679 Mtetra
.54406 .12679 .55329 .1389 .5707 .13236 .56153 .12016 Mtetra
.56153 .12016 .5707 .13236 .58821 .12577 .57912 .1135 Mtetra
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Mtetra
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Mtetra
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Mtetra
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Mtetra
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Mtetra
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Mtetra
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Mtetra
.636 .735 .919 r
.07018 .29188 .08123 .30213 .09589 .29662 .08475 .28725 Mtetra
0 .328 .781 r
.08475 .28725 .09589 .29662 .11047 .29228 .09783 .29418 Mtetra
.898 .558 .395 r
.09783 .29418 .11047 .29228 .12332 .30212 .10468 .34961 Mtetra
.808 .507 .48 r
.10468 .34961 .12332 .30212 .12928 .36938 .10814 .4366 Mtetra
.208 0 .261 r
.10814 .4366 .12928 .36938 .13204 .46983 .12658 .40976 Mtetra
.833 .602 .589 r
.12658 .40976 .13204 .46983 .15151 .43397 .15377 .30812 Mtetra
.664 .439 .569 r
.15377 .30812 .15151 .43397 .17962 .31776 .17418 .25899 Mtetra
.612 .436 .619 r
.17418 .25899 .17962 .31776 .20017 .26434 .19028 .24641 Mtetra
.65 .624 .811 r
.19028 .24641 .20017 .26434 .21629 .25137 .20574 .24012 Mtetra
.663 .733 .902 r
.20574 .24012 .21629 .25137 .23179 .2451 .22125 .23418 Mtetra
.664 .741 .908 r
.22125 .23418 .23179 .2451 .24735 .2392 .23686 .22823 Mtetra
.23686 .22823 .24735 .2392 .26299 .23327 .25256 .22223 Mtetra
.25256 .22223 .26299 .23327 .27873 .22731 .26835 .2162 Mtetra
.26835 .2162 .27873 .22731 .29456 .22131 .28424 .21014 Mtetra
.28424 .21014 .29456 .22131 .31049 .21527 .30023 .20404 Mtetra
.30023 .20404 .31049 .21527 .32652 .2092 .31632 .1979 Mtetra
.31632 .1979 .32652 .2092 .34264 .20309 .3325 .19172 Mtetra
.3325 .19172 .34264 .20309 .35886 .19695 .34878 .1855 Mtetra
.34878 .1855 .35886 .19695 .37518 .19077 .36516 .17925 Mtetra
.36516 .17925 .37518 .19077 .3916 .18454 .38165 .17296 Mtetra
.38165 .17296 .3916 .18454 .40812 .17828 .39823 .16663 Mtetra
.39823 .16663 .40812 .17828 .42475 .17199 .41492 .16026 Mtetra
.41492 .16026 .42475 .17199 .44148 .16565 .43171 .15385 Mtetra
.43171 .15385 .44148 .16565 .45831 .15927 .44861 .1474 Mtetra
.44861 .1474 .45831 .15927 .47524 .15286 .46562 .1409 Mtetra
.46562 .1409 .47524 .15286 .49228 .1464 .48273 .13437 Mtetra
.48273 .13437 .49228 .1464 .50943 .1399 .49994 .1278 Mtetra
.49994 .1278 .50943 .1399 .52669 .13336 .51727 .12119 Mtetra
.51727 .12119 .52669 .13336 .54406 .12679 .53471 .11453 Mtetra
.53471 .11453 .54406 .12679 .56153 .12016 .55226 .10783 Mtetra
.55226 .10783 .56153 .12016 .57912 .1135 .56992 .10109 Mtetra
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Mtetra
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Mtetra
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Mtetra
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Mtetra
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Mtetra
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Mtetra
.131 .515 .913 r
.05891 .28221 .07018 .29188 .08475 .28725 .07227 .28618 Mtetra
.895 .533 .347 r
.07227 .28618 .08475 .28725 .09783 .29418 .08035 .32871 Mtetra
.814 .503 .464 r
.08035 .32871 .09783 .29418 .10468 .34961 .08517 .39904 Mtetra
.206 0 .21 r
.08517 .39904 .10468 .34961 .10814 .4366 .10254 .38014 Mtetra
.82 .595 .597 r
.10254 .38014 .10814 .4366 .12658 .40976 .12816 .29617 Mtetra
.66 .439 .573 r
.12816 .29617 .12658 .40976 .15377 .30812 .14811 .25324 Mtetra
.612 .441 .626 r
.14811 .25324 .15377 .30812 .17418 .25899 .16413 .24139 Mtetra
.65 .629 .816 r
.16413 .24139 .17418 .25899 .19028 .24641 .17955 .23511 Mtetra
.663 .733 .902 r
.17955 .23511 .19028 .24641 .20574 .24012 .19503 .22915 Mtetra
.664 .741 .908 r
.19503 .22915 .20574 .24012 .22125 .23418 .2106 .22316 Mtetra
.2106 .22316 .22125 .23418 .23686 .22823 .22626 .21713 Mtetra
.22626 .21713 .23686 .22823 .25256 .22223 .24201 .21107 Mtetra
.24201 .21107 .25256 .22223 .26835 .2162 .25786 .20498 Mtetra
.25786 .20498 .26835 .2162 .28424 .21014 .27381 .19884 Mtetra
.27381 .19884 .28424 .21014 .30023 .20404 .28986 .19267 Mtetra
.28986 .19267 .30023 .20404 .31632 .1979 .306 .18646 Mtetra
.306 .18646 .31632 .1979 .3325 .19172 .32224 .18021 Mtetra
.32224 .18021 .3325 .19172 .34878 .1855 .33859 .17393 Mtetra
.33859 .17393 .34878 .1855 .36516 .17925 .35503 .1676 Mtetra
.35503 .1676 .36516 .17925 .38165 .17296 .37158 .16124 Mtetra
.37158 .16124 .38165 .17296 .39823 .16663 .38823 .15483 Mtetra
.38823 .15483 .39823 .16663 .41492 .16026 .40498 .14839 Mtetra
.40498 .14839 .41492 .16026 .43171 .15385 .42184 .14191 Mtetra
.42184 .14191 .43171 .15385 .44861 .1474 .4388 .13538 Mtetra
.4388 .13538 .44861 .1474 .46562 .1409 .45588 .12881 Mtetra
.45588 .12881 .46562 .1409 .48273 .13437 .47306 .12221 Mtetra
.47306 .12221 .48273 .13437 .49994 .1278 .49034 .11556 Mtetra
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Mtetra
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Mtetra
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Mtetra
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Mtetra
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Mtetra
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Mtetra
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Mtetra
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Mtetra
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Mtetra
.882 .479 .254 r
.04659 .27845 .05891 .28221 .07227 .28618 .05605 .3086 Mtetra
.819 .492 .436 r
.05605 .3086 .07227 .28618 .08035 .32871 .06261 .36159 Mtetra
.177 0 .109 r
.06261 .36159 .08035 .32871 .08517 .39904 .07904 .3488 Mtetra
.807 .591 .609 r
.07904 .3488 .08517 .39904 .10254 .38014 .1027 .28301 Mtetra
.658 .442 .58 r
.1027 .28301 .10254 .38014 .12816 .29617 .12195 .24724 Mtetra
.614 .452 .639 r
.12195 .24724 .12816 .29617 .14811 .25324 .13786 .23634 Mtetra
.652 .639 .825 r
.13786 .23634 .14811 .25324 .16413 .24139 .15324 .23007 Mtetra
.663 .734 .902 r
.15324 .23007 .16413 .24139 .17955 .23511 .16867 .22408 Mtetra
.664 .741 .908 r
.16867 .22408 .17955 .23511 .19503 .22915 .1842 .21806 Mtetra
.1842 .21806 .19503 .22915 .2106 .22316 .19982 .21201 Mtetra
.19982 .21201 .2106 .22316 .22626 .21713 .21553 .20592 Mtetra
.21553 .20592 .22626 .21713 .24201 .21107 .23135 .19979 Mtetra
.23135 .19979 .24201 .21107 .25786 .20498 .24725 .19362 Mtetra
.24725 .19362 .25786 .20498 .27381 .19884 .26326 .18742 Mtetra
.26326 .18742 .27381 .19884 .28986 .19267 .27936 .18118 Mtetra
.27936 .18118 .28986 .19267 .306 .18646 .29557 .1749 Mtetra
.29557 .1749 .306 .18646 .32224 .18021 .31187 .16858 Mtetra
.31187 .16858 .32224 .18021 .33859 .17393 .32828 .16222 Mtetra
.32828 .16222 .33859 .17393 .35503 .1676 .34478 .15582 Mtetra
.34478 .15582 .35503 .1676 .37158 .16124 .36139 .14938 Mtetra
.36139 .14938 .37158 .16124 .38823 .15483 .37811 .14291 Mtetra
.37811 .14291 .38823 .15483 .40498 .14839 .39493 .13639 Mtetra
.39493 .13639 .40498 .14839 .42184 .14191 .41185 .12983 Mtetra
.41185 .12983 .42184 .14191 .4388 .13538 .42888 .12323 Mtetra
.42888 .12323 .4388 .13538 .45588 .12881 .44602 .11658 Mtetra
.44602 .11658 .45588 .12881 .47306 .12221 .46327 .1099 Mtetra
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Mtetra
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Mtetra
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Mtetra
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Mtetra
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Mtetra
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Mtetra
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Mtetra
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Mtetra
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Mtetra
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.82 .464 .382 r
.03154 .29061 .04659 .27845 .05605 .3086 .03994 .3276 Mtetra
.083 0 0 r
.03994 .3276 .05605 .3086 .06261 .36159 .05564 .31892 Mtetra
.794 .591 .626 r
.05564 .31892 .06261 .36159 .07904 .3488 .07726 .26974 Mtetra
.656 .45 .593 r
.07726 .26974 .07904 .3488 .1027 .28301 .09569 .24112 Mtetra
.619 .472 .659 r
.09569 .24112 .1027 .28301 .12195 .24724 .11145 .23125 Mtetra
.654 .654 .837 r
.11145 .23125 .12195 .24724 .13786 .23634 .12678 .22501 Mtetra
.663 .735 .903 r
.12678 .22501 .13786 .23634 .15324 .23007 .14218 .21899 Mtetra
.664 .741 .908 r
.14218 .21899 .15324 .23007 .16867 .22408 .15767 .21294 Mtetra
.15767 .21294 .16867 .22408 .1842 .21806 .17325 .20686 Mtetra
.17325 .20686 .1842 .21806 .19982 .21201 .18892 .20073 Mtetra
.18892 .20073 .19982 .21201 .21553 .20592 .20469 .19457 Mtetra
.20469 .19457 .21553 .20592 .23135 .19979 .22056 .18838 Mtetra
.22056 .18838 .23135 .19979 .24725 .19362 .23652 .18214 Mtetra
.23652 .18214 .24725 .19362 .26326 .18742 .25259 .17587 Mtetra
.25259 .17587 .26326 .18742 .27936 .18118 .26875 .16955 Mtetra
.26875 .16955 .27936 .18118 .29557 .1749 .28501 .1632 Mtetra
.28501 .1632 .29557 .1749 .31187 .16858 .30138 .15681 Mtetra
.30138 .15681 .31187 .16858 .32828 .16222 .31785 .15038 Mtetra
.31785 .15038 .32828 .16222 .34478 .15582 .33442 .14391 Mtetra
.33442 .14391 .34478 .15582 .36139 .14938 .35109 .13739 Mtetra
.35109 .13739 .36139 .14938 .37811 .14291 .36787 .13084 Mtetra
.36787 .13084 .37811 .14291 .39493 .13639 .38475 .12424 Mtetra
.38475 .12424 .39493 .13639 .41185 .12983 .40174 .11761 Mtetra
.40174 .11761 .41185 .12983 .42888 .12323 .41884 .11093 Mtetra
.41884 .11093 .42888 .12323 .44602 .11658 .43605 .10421 Mtetra
.43605 .10421 .44602 .11658 .46327 .1099 .45337 .09744 Mtetra
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Mtetra
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Mtetra
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Mtetra
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Mtetra
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Mtetra
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Mtetra
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Mtetra
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Mtetra
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Mtetra
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Mtetra
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Mtetra
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Mtetra
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Mtetra
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Mtetra
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Mtetra
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Mtetra
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Mtetra
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Mtetra
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Mtetra
.57384 .54314 .58111 .55092 .59512 .54671 .5879 .53889 Mtetra
.5879 .53889 .59512 .54671 .60921 .54249 .60203 .53463 Mtetra
.60203 .53463 .60921 .54249 .62337 .53824 .61624 .53034 Mtetra
.61624 .53034 .62337 .53824 .63759 .53397 .63052 .52603 Mtetra
.63052 .52603 .63759 .53397 .6519 .52968 .64487 .5217 Mtetra
.64487 .5217 .6519 .52968 .66627 .52537 .6593 .51735 Mtetra
.6593 .51735 .66627 .52537 .68072 .52103 .67379 .51297 Mtetra
.67379 .51297 .68072 .52103 .69524 .51668 .68837 .50857 Mtetra
.68837 .50857 .69524 .51668 .70984 .5123 .70302 .50415 Mtetra
.70302 .50415 .70984 .5123 .72452 .5079 .71774 .49971 Mtetra
.71774 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.663 .741 .908 r
.80773 .47255 .81417 .481 .82939 .47643 .823 .46795 Mtetra
.823 .46795 .82939 .47643 .84469 .47185 .83836 .46332 Mtetra
.83836 .46332 .84469 .47185 .86006 .46723 .8538 .45867 Mtetra
.663 .742 .908 r
.8538 .45867 .86006 .46723 .87552 .4626 .86932 .45399 Mtetra
.86932 .45399 .87552 .4626 .89107 .45794 .88492 .44929 Mtetra
.663 .742 .909 r
.88492 .44929 .89107 .45794 .90669 .45325 .90061 .44456 Mtetra
.664 .742 .909 r
.90061 .44456 .90669 .45325 .9224 .44854 .91638 .4398 Mtetra
.664 .742 .908 r
.91638 .4398 .9224 .44854 .93819 .4438 .93223 .43501 Mtetra
.93223 .43501 .93819 .4438 .95407 .43904 .94817 .43019 Mtetra
.94817 .43019 .95407 .43904 .97003 .43425 .9642 .42535 Mtetra
.664 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Mtetra
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Mtetra
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Mtetra
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Mtetra
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Mtetra
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Mtetra
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Mtetra
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Mtetra
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Mtetra
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Mtetra
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .53529 Mtetra
.5665 .53529 .57384 .54314 .5879 .53889 .58061 .531 Mtetra
.58061 .531 .5879 .53889 .60203 .53463 .59479 .5267 Mtetra
.59479 .5267 .60203 .53463 .61624 .53034 .60905 .52237 Mtetra
.60905 .52237 .61624 .53034 .63052 .52603 .62338 .51802 Mtetra
.62338 .51802 .63052 .52603 .64487 .5217 .63778 .51365 Mtetra
.63778 .51365 .64487 .5217 .6593 .51735 .65225 .50925 Mtetra
.65225 .50925 .6593 .51735 .67379 .51297 .6668 .50483 Mtetra
.6668 .50483 .67379 .51297 .68837 .50857 .68143 .50039 Mtetra
.68143 .50039 .68837 .50857 .70302 .50415 .69613 .49593 Mtetra
.69613 .49593 .70302 .50415 .71774 .49971 .71091 .49144 Mtetra
.71091 .49144 .71774 .49971 .73255 .49524 .72577 .48693 Mtetra
.72577 .48693 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.663 .741 .908 r
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46866 Mtetra
.78597 .46866 .79253 .47714 .80773 .47255 .80123 .46404 Mtetra
.80123 .46404 .80773 .47255 .823 .46795 .81656 .4594 Mtetra
.663 .742 .909 r
.81656 .4594 .823 .46795 .83836 .46332 .83198 .45476 Mtetra
.662 .742 .909 r
.83198 .45476 .83836 .46332 .8538 .45867 .84748 .45009 Mtetra
.662 .743 .91 r
.84748 .45009 .8538 .45867 .86932 .45399 .86306 .4454 Mtetra
.663 .744 .911 r
.86306 .4454 .86932 .45399 .88492 .44929 .87873 .44067 Mtetra
.664 .745 .911 r
.87873 .44067 .88492 .44929 .90061 .44456 .89447 .43588 Mtetra
.664 .745 .91 r
.89447 .43588 .90061 .44456 .91638 .4398 .9103 .43105 Mtetra
.664 .744 .909 r
.9103 .43105 .91638 .4398 .93223 .43501 .92622 .42617 Mtetra
.664 .743 .909 r
.92622 .42617 .93223 .43501 .94817 .43019 .94221 .42127 Mtetra
.664 .742 .908 r
.94221 .42127 .94817 .43019 .9642 .42535 .9583 .41636 Mtetra
.664 .741 .908 r
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Mtetra
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Mtetra
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Mtetra
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55702 Mtetra
.46198 .55702 .4697 .56468 .48332 .56054 .47564 .55285 Mtetra
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Mtetra
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Mtetra
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .5402 Mtetra
.51705 .5402 .5246 .54801 .5385 .54379 .531 .53594 Mtetra
.531 .53594 .5385 .54379 .55246 .53955 .54501 .53166 Mtetra
.54501 .53166 .55246 .53955 .5665 .53529 .5591 .52736 Mtetra
.5591 .52736 .5665 .53529 .58061 .531 .57325 .52304 Mtetra
.57325 .52304 .58061 .531 .59479 .5267 .58748 .51869 Mtetra
.58748 .51869 .59479 .5267 .60905 .52237 .60179 .51432 Mtetra
.60179 .51432 .60905 .52237 .62338 .51802 .61616 .50993 Mtetra
.61616 .50993 .62338 .51802 .63778 .51365 .63062 .50552 Mtetra
.63062 .50552 .63778 .51365 .65225 .50925 .64514 .50108 Mtetra
.64514 .50108 .65225 .50925 .6668 .50483 .65974 .49662 Mtetra
.65974 .49662 .6668 .50483 .68143 .50039 .67442 .49214 Mtetra
.67442 .49214 .68143 .50039 .69613 .49593 .68918 .48763 Mtetra
.68918 .48763 .69613 .49593 .71091 .49144 .70401 .4831 Mtetra
.70401 .4831 .71091 .49144 .72577 .48693 .71892 .47854 Mtetra
.71892 .47854 .72577 .48693 .7407 .4824 .73391 .47397 Mtetra
.663 .741 .908 r
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46937 Mtetra
.74897 .46937 .75571 .47784 .7708 .47326 .76412 .46476 Mtetra
.663 .741 .909 r
.76412 .46476 .7708 .47326 .78597 .46866 .77935 .46015 Mtetra
.662 .742 .91 r
.77935 .46015 .78597 .46866 .80123 .46404 .79467 .45555 Mtetra
.66 .743 .911 r
.79467 .45555 .80123 .46404 .81656 .4594 .81007 .45097 Mtetra
.659 .745 .914 r
.81007 .45097 .81656 .4594 .83198 .45476 .82556 .4464 Mtetra
.659 .749 .916 r
.82556 .4464 .83198 .45476 .84748 .45009 .84113 .44179 Mtetra
.661 .752 .918 r
.84113 .44179 .84748 .45009 .86306 .4454 .85678 .4371 Mtetra
.664 .754 .917 r
.85678 .4371 .86306 .4454 .87873 .44067 .8725 .43227 Mtetra
.666 .754 .916 r
.8725 .43227 .87873 .44067 .89447 .43588 .8883 .42732 Mtetra
.667 .751 .913 r
.8883 .42732 .89447 .43588 .9103 .43105 .90418 .42231 Mtetra
.667 .748 .911 r
.90418 .42231 .9103 .43105 .92622 .42617 .92014 .41728 Mtetra
.666 .745 .909 r
.92014 .41728 .92622 .42617 .94221 .42127 .9362 .41228 Mtetra
.665 .743 .908 r
.9362 .41228 .94221 .42127 .9583 .41636 .95235 .40728 Mtetra
.664 .741 .908 r
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Mtetra
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56181 Mtetra
.41347 .56181 .42139 .56942 .43486 .56531 .42697 .55767 Mtetra
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .55349 Mtetra
.44054 .55349 .44838 .56118 .46198 .55702 .45418 .5493 Mtetra
.45418 .5493 .46198 .55702 .47564 .55285 .46789 .54509 Mtetra
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Mtetra
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Mtetra
.49552 .5366 .50318 .54444 .51705 .5402 .50944 .53232 Mtetra
.50944 .53232 .51705 .5402 .531 .53594 .52343 .52802 Mtetra
.52343 .52802 .531 .53594 .54501 .53166 .53749 .5237 Mtetra
.53749 .5237 .54501 .53166 .5591 .52736 .55162 .51936 Mtetra
.55162 .51936 .5591 .52736 .57325 .52304 .56582 .51499 Mtetra
.56582 .51499 .57325 .52304 .58748 .51869 .5801 .51061 Mtetra
.5801 .51061 .58748 .51869 .60179 .51432 .59446 .5062 Mtetra
.59446 .5062 .60179 .51432 .61616 .50993 .60888 .50176 Mtetra
.60888 .50176 .61616 .50993 .63062 .50552 .62338 .49731 Mtetra
.62338 .49731 .63062 .50552 .64514 .50108 .63796 .49283 Mtetra
.63796 .49283 .64514 .50108 .65974 .49662 .65262 .48832 Mtetra
.65262 .48832 .65974 .49662 .67442 .49214 .66735 .4838 Mtetra
.66735 .4838 .67442 .49214 .68918 .48763 .68215 .47925 Mtetra
.68215 .47925 .68918 .48763 .70401 .4831 .69704 .47467 Mtetra
.663 .741 .908 r
.69704 .47467 .70401 .4831 .71892 .47854 .712 .47008 Mtetra
.712 .47008 .71892 .47854 .73391 .47397 .72705 .46547 Mtetra
.662 .741 .909 r
.72705 .46547 .73391 .47397 .74897 .46937 .74217 .46088 Mtetra
.66 .742 .91 r
.74217 .46088 .74897 .46937 .76412 .46476 .75739 .45633 Mtetra
.657 .743 .914 r
.75739 .45633 .76412 .46476 .77935 .46015 .77269 .45189 Mtetra
.653 .747 .919 r
.77269 .45189 .77935 .46015 .79467 .45555 .78809 .44757 Mtetra
.649 .755 .927 r
.78809 .44757 .79467 .45555 .81007 .45097 .80359 .44333 Mtetra
.648 .765 .934 r
.80359 .44333 .81007 .45097 .82556 .4464 .81917 .43903 Mtetra
.654 .776 .938 r
.81917 .43903 .82556 .4464 .84113 .44179 .83482 .43448 Mtetra
.663 .782 .937 r
.83482 .43448 .84113 .44179 .85678 .4371 .85052 .42956 Mtetra
.671 .78 .931 r
.85052 .42956 .85678 .4371 .8725 .43227 .86627 .42432 Mtetra
.675 .772 .923 r
.86627 .42432 .8725 .43227 .8883 .42732 .88209 .41893 Mtetra
.674 .761 .916 r
.88209 .41893 .8883 .42732 .90418 .42231 .898 .41356 Mtetra
.671 .751 .911 r
.898 .41356 .90418 .42231 .92014 .41728 .91401 .40831 Mtetra
.668 .746 .909 r
.91401 .40831 .92014 .41728 .9362 .41228 .93012 .40317 Mtetra
.665 .743 .908 r
.93012 .40317 .9362 .41228 .95235 .40728 .94633 .3981 Mtetra
.664 .741 .908 r
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Mtetra
.39199 .55831 .40003 .56594 .41347 .56181 .40547 .55414 Mtetra
.40547 .55414 .41347 .56181 .42697 .55767 .41902 .54995 Mtetra
.41902 .54995 .42697 .55767 .44054 .55349 .43263 .54574 Mtetra
.43263 .54574 .44054 .55349 .45418 .5493 .44632 .54151 Mtetra
.44632 .54151 .45418 .5493 .46789 .54509 .46007 .53726 Mtetra
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .53298 Mtetra
.47389 .53298 .48167 .54086 .49552 .5366 .48778 .52869 Mtetra
.48778 .52869 .49552 .5366 .50944 .53232 .50175 .52437 Mtetra
.50175 .52437 .50944 .53232 .52343 .52802 .51578 .52003 Mtetra
.51578 .52003 .52343 .52802 .53749 .5237 .52989 .51567 Mtetra
.52989 .51567 .53749 .5237 .55162 .51936 .54407 .51128 Mtetra
.54407 .51128 .55162 .51936 .56582 .51499 .55833 .50688 Mtetra
.55833 .50688 .56582 .51499 .5801 .51061 .57265 .50245 Mtetra
.57265 .50245 .5801 .51061 .59446 .5062 .58706 .49799 Mtetra
.58706 .49799 .59446 .5062 .60888 .50176 .60153 .49352 Mtetra
.60153 .49352 .60888 .50176 .62338 .49731 .61609 .48902 Mtetra
.61609 .48902 .62338 .49731 .63796 .49283 .63071 .48449 Mtetra
.63071 .48449 .63796 .49283 .65262 .48832 .64542 .47995 Mtetra
.64542 .47995 .65262 .48832 .66735 .4838 .6602 .47538 Mtetra
.663 .741 .908 r
.6602 .47538 .66735 .4838 .68215 .47925 .67506 .47079 Mtetra
.67506 .47079 .68215 .47925 .69704 .47467 .69 .46618 Mtetra
.662 .741 .909 r
.69 .46618 .69704 .47467 .712 .47008 .70502 .46159 Mtetra
.66 .742 .911 r
.70502 .46159 .712 .47008 .72705 .46547 .72013 .45708 Mtetra
.654 .743 .915 r
.72013 .45708 .72705 .46547 .74217 .46088 .73534 .45276 Mtetra
.643 .747 .925 r
.73534 .45276 .74217 .46088 .75739 .45633 .75065 .44877 Mtetra
.627 .758 .941 r
.75065 .44877 .75739 .45633 .77269 .45189 .76608 .4452 Mtetra
.61 .778 .961 r
.76608 .4452 .77269 .45189 .78809 .44757 .78163 .44188 Mtetra
.6 .808 .979 r
.78163 .44188 .78809 .44757 .80359 .44333 .79727 .4384 Mtetra
.612 .838 .986 r
.79727 .4384 .80359 .44333 .81917 .43903 .81295 .43423 Mtetra
.646 .856 .98 r
.81295 .43423 .81917 .43903 .83482 .43448 .82862 .42907 Mtetra
.681 .85 .963 r
.82862 .42907 .83482 .43448 .85052 .42956 .8443 .42307 Mtetra
.697 .822 .942 r
.8443 .42307 .85052 .42956 .86627 .42432 .86002 .41671 Mtetra
.695 .79 .924 r
.86002 .41671 .86627 .42432 .88209 .41893 .87582 .41048 Mtetra
.685 .765 .913 r
.87582 .41048 .88209 .41893 .898 .41356 .89175 .40463 Mtetra
.675 .751 .908 r
.89175 .40463 .898 .41356 .91401 .40831 .90781 .39916 Mtetra
.669 .744 .907 r
.90781 .39916 .91401 .40831 .93012 .40317 .92398 .39394 Mtetra
.665 .742 .907 r
.92398 .39394 .93012 .40317 .94633 .3981 .94026 .38882 Mtetra
.664 .741 .908 r
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Mtetra
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Mtetra
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53791 Mtetra
.42465 .53791 .43263 .54574 .44632 .54151 .43837 .53364 Mtetra
.43837 .53364 .44632 .54151 .46007 .53726 .45217 .52935 Mtetra
.45217 .52935 .46007 .53726 .47389 .53298 .46604 .52504 Mtetra
.46604 .52504 .47389 .53298 .48778 .52869 .47998 .5207 Mtetra
.47998 .5207 .48778 .52869 .50175 .52437 .49399 .51634 Mtetra
.49399 .51634 .50175 .52437 .51578 .52003 .50807 .51196 Mtetra
.50807 .51196 .51578 .52003 .52989 .51567 .52222 .50756 Mtetra
.52222 .50756 .52989 .51567 .54407 .51128 .53645 .50313 Mtetra
.53645 .50313 .54407 .51128 .55833 .50688 .55076 .49868 Mtetra
.55076 .49868 .55833 .50688 .57265 .50245 .56513 .49421 Mtetra
.56513 .49421 .57265 .50245 .58706 .49799 .57958 .48971 Mtetra
.57958 .48971 .58706 .49799 .60153 .49352 .59411 .48519 Mtetra
.59411 .48519 .60153 .49352 .61609 .48902 .60871 .48065 Mtetra
.60871 .48065 .61609 .48902 .63071 .48449 .6234 .47608 Mtetra
.663 .741 .908 r
.6234 .47608 .63071 .48449 .64542 .47995 .63815 .47149 Mtetra
.63815 .47149 .64542 .47995 .6602 .47538 .65299 .46689 Mtetra
.65299 .46689 .6602 .47538 .67506 .47079 .66791 .46229 Mtetra
.66 .741 .91 r
.66791 .46229 .67506 .47079 .69 .46618 .68291 .45776 Mtetra
.653 .742 .915 r
.68291 .45776 .69 .46618 .70502 .46159 .698 .45347 Mtetra
.637 .745 .927 r
.698 .45347 .70502 .46159 .72013 .45708 .71321 .44971 Mtetra
.603 .754 .95 r
.71321 .44971 .72013 .45708 .73534 .45276 .72857 .44684 Mtetra
.536 .773 .985 r
.72857 .44684 .73534 .45276 .75065 .44877 .7441 .44501 Mtetra
.414 .787 .993 r
.7441 .44501 .75065 .44877 .76608 .4452 .75979 .44383 Mtetra
.264 .76 .9 r
.75979 .44383 .76608 .4452 .78163 .44188 .77557 .44224 Mtetra
.237 .754 .793 r
.77557 .44224 .78163 .44188 .79727 .4384 .79133 .43891 Mtetra
.403 .857 .831 r
.79133 .43891 .79727 .4384 .81295 .43423 .80697 .43316 Mtetra
.635 .954 .934 r
.80697 .43316 .81295 .43423 .82862 .42907 .82252 .42539 Mtetra
.739 .921 .953 r
.82252 .42539 .82862 .42907 .8443 .42307 .83804 .41684 Mtetra
.74 .844 .928 r
.83804 .41684 .8443 .42307 .86002 .41671 .85366 .4087 Mtetra
.714 .788 .91 r
.85366 .4087 .86002 .41671 .87582 .41048 .86945 .40156 Mtetra
.691 .758 .903 r
.86945 .40156 .87582 .41048 .89175 .40463 .88541 .39538 Mtetra
.676 .745 .903 r
.88541 .39538 .89175 .40463 .90781 .39916 .90153 .38983 Mtetra
.668 .742 .905 r
.90153 .38983 .90781 .39916 .92398 .39394 .91777 .38458 Mtetra
.665 .741 .907 r
.91777 .38458 .92398 .39394 .94026 .38882 .93411 .37944 Mtetra
.664 .741 .908 r
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .5343 Mtetra
.40288 .5343 .41099 .54216 .42465 .53791 .41658 .53001 Mtetra
.41658 .53001 .42465 .53791 .43837 .53364 .43036 .5257 Mtetra
.43036 .5257 .43837 .53364 .45217 .52935 .4442 .52137 Mtetra
.4442 .52137 .45217 .52935 .46604 .52504 .45811 .51701 Mtetra
.45811 .51701 .46604 .52504 .47998 .5207 .4721 .51263 Mtetra
.4721 .51263 .47998 .5207 .49399 .51634 .48615 .50823 Mtetra
.48615 .50823 .49399 .51634 .50807 .51196 .50028 .50381 Mtetra
.50028 .50381 .50807 .51196 .52222 .50756 .51448 .49937 Mtetra
.51448 .49937 .52222 .50756 .53645 .50313 .52876 .4949 Mtetra
.52876 .4949 .53645 .50313 .55076 .49868 .54311 .4904 Mtetra
.54311 .4904 .55076 .49868 .56513 .49421 .55754 .48589 Mtetra
.55754 .48589 .56513 .49421 .57958 .48971 .57204 .48135 Mtetra
.57204 .48135 .57958 .48971 .59411 .48519 .58662 .47679 Mtetra
.58662 .47679 .59411 .48519 .60871 .48065 .60127 .4722 Mtetra
.663 .741 .908 r
.60127 .4722 .60871 .48065 .6234 .47608 .61601 .46759 Mtetra
.61601 .46759 .6234 .47608 .63815 .47149 .63082 .46298 Mtetra
.661 .741 .909 r
.63082 .46298 .63815 .47149 .65299 .46689 .64571 .45841 Mtetra
.655 .741 .913 r
.64571 .45841 .65299 .46689 .66791 .46229 .66069 .45404 Mtetra
.638 .742 .924 r
.66069 .45404 .66791 .46229 .68291 .45776 .67578 .45024 Mtetra
.594 .746 .95 r
.67578 .45024 .68291 .45776 .698 .45347 .69103 .44765 Mtetra
.472 .747 .989 r
.69103 .44765 .698 .45347 .71321 .44971 .70648 .44704 Mtetra
.109 .628 .885 r
.70648 .44704 .71321 .44971 .72857 .44684 .7222 .44873 Mtetra
.356 0 0 r
.7222 .44873 .72857 .44684 .7441 .44501 .73816 .45181 Mtetra
.463 0 0 r
.73816 .45181 .7441 .44501 .75979 .44383 .75421 .45389 Mtetra
.398 0 .08 r
.75421 .45389 .75979 .44383 .77557 .44224 .77012 .45213 Mtetra
.205 0 0 r
.77012 .45213 .77557 .44224 .79133 .43891 .78574 .44507 Mtetra
0 0 0 r
.78574 .44507 .79133 .43891 .80697 .43316 .80105 .43373 Mtetra
.76 .996 .836 r
.80105 .43373 .80697 .43316 .82252 .42539 .81625 .42086 Mtetra
.818 .906 .901 r
.81625 .42086 .82252 .42539 .83804 .41684 .83157 .40903 Mtetra
.764 .809 .889 r
.83157 .40903 .83804 .41684 .85366 .4087 .84712 .39945 Mtetra
.717 .761 .887 r
.84712 .39945 .85366 .4087 .86945 .40156 .86295 .39196 Mtetra
.688 .743 .893 r
.86295 .39196 .86945 .40156 .88541 .39538 .87898 .38583 Mtetra
.673 .739 .901 r
.87898 .38583 .88541 .39538 .90153 .38983 .89518 .38036 Mtetra
.666 .74 .905 r
.89518 .38036 .90153 .38983 .91777 .38458 .91149 .37513 Mtetra
.664 .741 .907 r
.91149 .37513 .91777 .38458 .93411 .37944 .92791 .36996 Mtetra
.664 .741 .908 r
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Mtetra
.38103 .53067 .38925 .53857 .40288 .5343 .3947 .52637 Mtetra
.3947 .52637 .40288 .5343 .41658 .53001 .40845 .52204 Mtetra
.40845 .52204 .41658 .53001 .43036 .5257 .42226 .51768 Mtetra
.42226 .51768 .43036 .5257 .4442 .52137 .43615 .51331 Mtetra
.43615 .51331 .4442 .52137 .45811 .51701 .45011 .50891 Mtetra
.45011 .50891 .45811 .51701 .4721 .51263 .46414 .50449 Mtetra
.46414 .50449 .4721 .51263 .48615 .50823 .47824 .50005 Mtetra
.47824 .50005 .48615 .50823 .50028 .50381 .49242 .49559 Mtetra
.49242 .49559 .50028 .50381 .51448 .49937 .50667 .4911 Mtetra
.50667 .4911 .51448 .49937 .52876 .4949 .52099 .48658 Mtetra
.52099 .48658 .52876 .4949 .54311 .4904 .53539 .48205 Mtetra
.53539 .48205 .54311 .4904 .55754 .48589 .54987 .47749 Mtetra
.54987 .47749 .55754 .48589 .57204 .48135 .56442 .47291 Mtetra
.56442 .47291 .57204 .48135 .58662 .47679 .57905 .4683 Mtetra
.663 .741 .908 r
.57905 .4683 .58662 .47679 .60127 .4722 .59376 .46368 Mtetra
.662 .741 .909 r
.59376 .46368 .60127 .4722 .61601 .46759 .60854 .45907 Mtetra
.659 .741 .911 r
.60854 .45907 .61601 .46759 .63082 .46298 .62341 .45457 Mtetra
.646 .741 .918 r
.62341 .45457 .63082 .46298 .64571 .45841 .63838 .4505 Mtetra
.609 .741 .939 r
.63838 .4505 .64571 .45841 .66069 .45404 .65348 .44756 Mtetra
.487 .734 .981 r
.65348 .44756 .66069 .45404 .67578 .45024 .66878 .44701 Mtetra
.014 .546 .85 r
.66878 .44701 .67578 .45024 .69103 .44765 .68439 .45032 Mtetra
.576 .029 0 r
.68439 .45032 .69103 .44765 .70648 .44704 .7004 .45803 Mtetra
.654 .233 .232 r
.7004 .45803 .70648 .44704 .7222 .44873 .71676 .46833 Mtetra
.615 .255 .336 r
.71676 .46833 .7222 .44873 .73816 .45181 .73322 .47654 Mtetra
.532 .202 .354 r
.73322 .47654 .73816 .45181 .75421 .45389 .74939 .4772 Mtetra
.379 .063 .297 r
.74939 .4772 .75421 .45389 .77012 .45213 .76495 .46765 Mtetra
.017 0 .059 r
.76495 .46765 .77012 .45213 .78574 .44507 .77994 .45012 Mtetra
.748 .932 .587 r
.77994 .45012 .78574 .44507 .80105 .43373 .79467 .42998 Mtetra
.9 .915 .822 r
.79467 .42998 .80105 .43373 .81625 .42086 .80954 .41209 Mtetra
.814 .797 .836 r
.80954 .41209 .81625 .42086 .83157 .40903 .82478 .39857 Mtetra
.746 .746 .851 r
.82478 .39857 .83157 .40903 .84712 .39945 .84041 .389 Mtetra
.703 .731 .873 r
.84041 .389 .84712 .39945 .86295 .39196 .85635 .38196 Mtetra
.679 .733 .891 r
.85635 .38196 .86295 .39196 .87898 .38583 .87249 .37615 Mtetra
.668 .737 .901 r
.87249 .37615 .87898 .38583 .89518 .38036 .88877 .37081 Mtetra
.665 .74 .906 r
.88877 .37081 .89518 .38036 .91149 .37513 .90516 .36559 Mtetra
.664 .741 .907 r
.90516 .36559 .91149 .37513 .92791 .36996 .92164 .36039 Mtetra
.664 .741 .908 r
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Mtetra
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51835 Mtetra
.38644 .51835 .3947 .52637 .40845 .52204 .40023 .51398 Mtetra
.40023 .51398 .40845 .52204 .42226 .51768 .41409 .50959 Mtetra
.41409 .50959 .42226 .51768 .43615 .51331 .42802 .50518 Mtetra
.42802 .50518 .43615 .51331 .45011 .50891 .44203 .50074 Mtetra
.44203 .50074 .45011 .50891 .46414 .50449 .45611 .49627 Mtetra
.45611 .49627 .46414 .50449 .47824 .50005 .47026 .49179 Mtetra
.47026 .49179 .47824 .50005 .49242 .49559 .48448 .48728 Mtetra
.48448 .48728 .49242 .49559 .50667 .4911 .49878 .48275 Mtetra
.49878 .48275 .50667 .4911 .52099 .48658 .51315 .47819 Mtetra
.51315 .47819 .52099 .48658 .53539 .48205 .5276 .47361 Mtetra
.5276 .47361 .53539 .48205 .54987 .47749 .54213 .46901 Mtetra
.663 .741 .908 r
.54213 .46901 .54987 .47749 .56442 .47291 .55673 .46438 Mtetra
.55673 .46438 .56442 .47291 .57905 .4683 .57141 .45975 Mtetra
.661 .741 .909 r
.57141 .45975 .57905 .4683 .59376 .46368 .58617 .45515 Mtetra
.655 .741 .913 r
.58617 .45515 .59376 .46368 .60854 .45907 .60102 .45077 Mtetra
.632 .74 .925 r
.60102 .45077 .60854 .45907 .62341 .45457 .61597 .44715 Mtetra
.555 .736 .96 r
.61597 .44715 .62341 .45457 .63838 .4505 .63107 .4455 Mtetra
.219 .639 .955 r
.63107 .4455 .63838 .4505 .65348 .44756 .64644 .44796 Mtetra
.575 .004 0 r
.64644 .44796 .65348 .44756 .66878 .44701 .66223 .45695 Mtetra
.727 .309 .255 r
.66223 .45695 .66878 .44701 .68439 .45032 .67858 .47335 Mtetra
.705 .36 .389 r
.67858 .47335 .68439 .45032 .7004 .45803 .69544 .49397 Mtetra
.651 .341 .433 r
.69544 .49397 .7004 .45803 .71676 .46833 .71242 .51079 Mtetra
.567 .277 .436 r
.71242 .51079 .71676 .46833 .73322 .47654 .7289 .51453 Mtetra
.413 .14 .387 r
.7289 .51453 .73322 .47654 .74939 .4772 .74441 .50098 Mtetra
.006 0 .166 r
.74441 .50098 .74939 .4772 .76495 .46765 .75899 .47433 Mtetra
.883 .922 .531 r
.75899 .47433 .76495 .46765 .77994 .45012 .77317 .44386 Mtetra
.929 .838 .734 r
.77317 .44386 .77994 .45012 .79467 .42998 .78751 .41759 Mtetra
.83 .738 .763 r
.78751 .41759 .79467 .42998 .80954 .41209 .80238 .39873 Mtetra
.762 .704 .798 r
.80238 .39873 .80954 .41209 .82478 .39857 .81779 .38642 Mtetra
.715 .705 .84 r
.81779 .38642 .82478 .39857 .84041 .389 .83361 .3782 Mtetra
.685 .719 .875 r
.83361 .3782 .84041 .389 .85635 .38196 .84969 .37196 Mtetra
.671 .732 .895 r
.84969 .37196 .85635 .38196 .87249 .37615 .86594 .36648 Mtetra
.665 .738 .904 r
.86594 .36648 .87249 .37615 .88877 .37081 .8823 .36121 Mtetra
.664 .74 .907 r
.8823 .36121 .88877 .37081 .90516 .36559 .89876 .35597 Mtetra
.664 .741 .908 r
.89876 .35597 .90516 .36559 .92164 .36039 .91531 .35072 Mtetra
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Mtetra
.36434 .51466 .37272 .5227 .38644 .51835 .37811 .51027 Mtetra
.37811 .51027 .38644 .51835 .40023 .51398 .39194 .50586 Mtetra
.39194 .50586 .40023 .51398 .41409 .50959 .40584 .50142 Mtetra
.40584 .50142 .41409 .50959 .42802 .50518 .41982 .49696 Mtetra
.41982 .49696 .42802 .50518 .44203 .50074 .43387 .49248 Mtetra
.43387 .49248 .44203 .50074 .45611 .49627 .44799 .48798 Mtetra
.44799 .48798 .45611 .49627 .47026 .49179 .46219 .48345 Mtetra
.46219 .48345 .47026 .49179 .48448 .48728 .47646 .47889 Mtetra
.47646 .47889 .48448 .48728 .49878 .48275 .49081 .47432 Mtetra
.49081 .47432 .49878 .48275 .51315 .47819 .50523 .46972 Mtetra
.50523 .46972 .51315 .47819 .5276 .47361 .51973 .46509 Mtetra
.663 .741 .908 r
.51973 .46509 .5276 .47361 .54213 .46901 .53431 .46045 Mtetra
.53431 .46045 .54213 .46901 .55673 .46438 .54896 .4558 Mtetra
.66 .741 .91 r
.54896 .4558 .55673 .46438 .57141 .45975 .5637 .45123 Mtetra
.65 .74 .915 r
.5637 .45123 .57141 .45975 .58617 .45515 .57852 .447 Mtetra
.614 .738 .935 r
.57852 .447 .58617 .45515 .60102 .45077 .59344 .44394 Mtetra
.468 .717 .977 r
.59344 .44394 .60102 .45077 .61597 .44715 .60855 .44387 Mtetra
0 .347 .692 r
.60855 .44387 .61597 .44715 .63107 .4455 .62396 .44993 Mtetra
.742 .273 .135 r
.62396 .44993 .63107 .4455 .64644 .44796 .63989 .46569 Mtetra
.759 .398 .371 r
.63989 .46569 .64644 .44796 .66223 .45695 .65654 .49236 Mtetra
.724 .408 .444 r
.65654 .49236 .66223 .45695 .67858 .47335 .67385 .52506 Mtetra
.668 .376 .469 r
.67385 .52506 .67858 .47335 .69544 .49397 .6913 .55174 Mtetra
.58 .305 .465 r
.6913 .55174 .69544 .49397 .71242 .51079 .70808 .55857 Mtetra
.396 .142 .408 r
.70808 .55857 .71242 .51079 .7289 .51453 .72355 .53967 Mtetra
0 0 .063 r
.72355 .53967 .7289 .51453 .74441 .50098 .73776 .50196 Mtetra
.992 .871 .605 r
.73776 .50196 .74441 .50098 .75899 .47433 .75142 .4595 Mtetra
.888 .723 .672 r
.75142 .4595 .75899 .47433 .77317 .44386 .7653 .42382 Mtetra
.807 .66 .699 r
.7653 .42382 .77317 .44386 .78751 .41759 .77982 .39914 Mtetra
.755 .648 .743 r
.77982 .39914 .78751 .41759 .80238 .39873 .79504 .38388 Mtetra
.717 .668 .801 r
.79504 .38388 .80238 .39873 .81779 .38642 .81075 .37443 Mtetra
.689 .699 .854 r
.81075 .37443 .81779 .38642 .83361 .3782 .82678 .36775 Mtetra
.673 .724 .888 r
.82678 .36775 .83361 .3782 .84969 .37196 .84299 .36212 Mtetra
.666 .736 .902 r
.84299 .36212 .84969 .37196 .86594 .36648 .85933 .3568 Mtetra
.664 .74 .906 r
.85933 .3568 .86594 .36648 .8823 .36121 .87576 .35154 Mtetra
.664 .741 .908 r
.87576 .35154 .8823 .36121 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .5021 Mtetra
.36969 .5021 .37811 .51027 .39194 .50586 .38357 .49765 Mtetra
.38357 .49765 .39194 .50586 .40584 .50142 .39752 .49317 Mtetra
.39752 .49317 .40584 .50142 .41982 .49696 .41154 .48867 Mtetra
.41154 .48867 .41982 .49696 .43387 .49248 .42564 .48415 Mtetra
.42564 .48415 .43387 .49248 .44799 .48798 .43981 .4796 Mtetra
.43981 .4796 .44799 .48798 .46219 .48345 .45405 .47502 Mtetra
.45405 .47502 .46219 .48345 .47646 .47889 .46837 .47043 Mtetra
.46837 .47043 .47646 .47889 .49081 .47432 .48277 .46581 Mtetra
.48277 .46581 .49081 .47432 .50523 .46972 .49724 .46116 Mtetra
.663 .741 .908 r
.49724 .46116 .50523 .46972 .51973 .46509 .51179 .4565 Mtetra
.51179 .4565 .51973 .46509 .53431 .46045 .52641 .45184 Mtetra
.659 .741 .91 r
.52641 .45184 .53431 .46045 .54896 .4558 .54112 .44729 Mtetra
.645 .74 .918 r
.54112 .44729 .54896 .4558 .5637 .45123 .55591 .44322 Mtetra
.593 .736 .943 r
.55591 .44322 .5637 .45123 .57852 .447 .57081 .44069 Mtetra
.357 .68 .978 r
.57081 .44069 .57852 .447 .59344 .44394 .58588 .44212 Mtetra
.534 0 0 r
.58588 .44212 .59344 .44394 .60855 .44387 .60128 .45156 Mtetra
.783 .367 .26 r
.60128 .45156 .60855 .44387 .62396 .44993 .61725 .47356 Mtetra
.774 .435 .413 r
.61725 .47356 .62396 .44993 .63989 .46569 .63402 .50956 Mtetra
.737 .431 .464 r
.63402 .50956 .63989 .46569 .65654 .49236 .65154 .55304 Mtetra
.681 .394 .48 r
.65154 .55304 .65654 .49236 .67385 .52506 .66926 .58816 Mtetra
.586 .313 .47 r
.66926 .58816 .67385 .52506 .6913 .55174 .68622 .59699 Mtetra
.32 .073 .374 r
.68622 .59699 .6913 .55174 .70808 .55857 .70167 .5725 Mtetra
.885 .849 .392 r
.70167 .5725 .70808 .55857 .72355 .53967 .71569 .5245 Mtetra
.919 .723 .622 r
.71569 .5245 .72355 .53967 .73776 .50196 .72906 .47149 Mtetra
.824 .626 .635 r
.72906 .47149 .73776 .50196 .75142 .4595 .74268 .42788 Mtetra
.77 .593 .658 r
.74268 .42788 .75142 .4595 .7653 .42382 .75702 .39847 Mtetra
.735 .596 .701 r
.75702 .39847 .7653 .42382 .77982 .39914 .77212 .38089 Mtetra
.71 .629 .765 r
.77212 .38089 .77982 .39914 .79504 .38388 .78777 .37049 Mtetra
.689 .677 .833 r
.78777 .37049 .79504 .38388 .81075 .37443 .80376 .36348 Mtetra
.674 .715 .879 r
.80376 .36348 .81075 .37443 .82678 .36775 .81994 .35774 Mtetra
.666 .733 .899 r
.81994 .35774 .82678 .36775 .84299 .36212 .83625 .35237 Mtetra
.664 .739 .906 r
.83625 .35237 .84299 .36212 .85933 .3568 .85266 .34708 Mtetra
.664 .741 .907 r
.85266 .34708 .85933 .3568 .87576 .35154 .86916 .34178 Mtetra
.664 .741 .908 r
.86916 .34178 .87576 .35154 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Mtetra
.34734 .49834 .35588 .50654 .36969 .5021 .36119 .49386 Mtetra
.36119 .49386 .36969 .5021 .38357 .49765 .37511 .48936 Mtetra
.37511 .48936 .38357 .49765 .39752 .49317 .38911 .48484 Mtetra
.38911 .48484 .39752 .49317 .41154 .48867 .40318 .4803 Mtetra
.40318 .4803 .41154 .48867 .42564 .48415 .41732 .47573 Mtetra
.41732 .47573 .42564 .48415 .43981 .4796 .43154 .47114 Mtetra
.43154 .47114 .43981 .4796 .45405 .47502 .44583 .46652 Mtetra
.44583 .46652 .45405 .47502 .46837 .47043 .4602 .46188 Mtetra
.4602 .46188 .46837 .47043 .48277 .46581 .47464 .45721 Mtetra
.663 .741 .908 r
.47464 .45721 .48277 .46581 .49724 .46116 .48916 .45253 Mtetra
.662 .741 .908 r
.48916 .45253 .49724 .46116 .51179 .4565 .50376 .44785 Mtetra
.658 .741 .911 r
.50376 .44785 .51179 .4565 .52641 .45184 .51844 .44331 Mtetra
.642 .739 .92 r
.51844 .44331 .52641 .45184 .54112 .44729 .5332 .43934 Mtetra
.578 .733 .948 r
.5332 .43934 .54112 .44729 .55591 .44322 .54806 .43717 Mtetra
.272 .643 .965 r
.54806 .43717 .55591 .44322 .57081 .44069 .56308 .43954 Mtetra
.637 .075 0 r
.56308 .43954 .57081 .44069 .58588 .44212 .57839 .45105 Mtetra
.799 .4 .297 r
.57839 .45105 .58588 .44212 .60128 .45156 .59424 .47674 Mtetra
.785 .451 .423 r
.59424 .47674 .60128 .45156 .61725 .47356 .61086 .51798 Mtetra
.75 .444 .466 r
.61086 .51798 .61725 .47356 .63402 .50956 .62824 .56711 Mtetra
.697 .405 .477 r
.62824 .56711 .63402 .50956 .65154 .55304 .64588 .60609 Mtetra
.588 .304 .453 r
.64588 .60609 .65154 .55304 .66926 .58816 .66282 .61491 Mtetra
0 0 .148 r
.66282 .61491 .66926 .58816 .68622 .59699 .67831 .58645 Mtetra
.941 .754 .621 r
.67831 .58645 .68622 .59699 .70167 .5725 .6924 .53257 Mtetra
.824 .609 .612 r
.6924 .53257 .70167 .5725 .71569 .5245 .70585 .47418 Mtetra
.769 .56 .616 r
.70585 .47418 .71569 .5245 .72906 .47149 .71953 .42688 Mtetra
.735 .545 .636 r
.71953 .42688 .72906 .47149 .74268 .42788 .7339 .39545 Mtetra
.712 .556 .676 r
.7339 .39545 .74268 .42788 .75702 .39847 .74901 .37698 Mtetra
.698 .598 .741 r
.74901 .37698 .75702 .39847 .77212 .38089 .76465 .36623 Mtetra
.685 .658 .818 r
.76465 .36623 .77212 .38089 .78777 .37049 .78062 .3591 Mtetra
.673 .707 .873 r
.78062 .3591 .78777 .37049 .80376 .36348 .79678 .35331 Mtetra
.666 .73 .897 r
.79678 .35331 .80376 .36348 .81994 .35774 .81306 .34792 Mtetra
.664 .739 .905 r
.81306 .34792 .81994 .35774 .83625 .35237 .82944 .3426 Mtetra
.664 .741 .907 r
.82944 .3426 .83625 .35237 .85266 .34708 .84592 .33727 Mtetra
.664 .741 .908 r
.84592 .33727 .85266 .34708 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Mtetra
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Mtetra
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Mtetra
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Mtetra
.35261 .48554 .36119 .49386 .37511 .48936 .36658 .481 Mtetra
.36658 .481 .37511 .48936 .38911 .48484 .38062 .47643 Mtetra
.38062 .47643 .38911 .48484 .40318 .4803 .39473 .47184 Mtetra
.39473 .47184 .40318 .4803 .41732 .47573 .40892 .46723 Mtetra
.40892 .46723 .41732 .47573 .43154 .47114 .42319 .46259 Mtetra
.42319 .46259 .43154 .47114 .44583 .46652 .43753 .45793 Mtetra
.43753 .45793 .44583 .46652 .4602 .46188 .45194 .45324 Mtetra
.663 .741 .908 r
.45194 .45324 .4602 .46188 .47464 .45721 .46644 .44854 Mtetra
.662 .741 .908 r
.46644 .44854 .47464 .45721 .48916 .45253 .48101 .44385 Mtetra
.658 .741 .911 r
.48101 .44385 .48916 .45253 .50376 .44785 .49566 .43929 Mtetra
.641 .739 .92 r
.49566 .43929 .50376 .44785 .51844 .44331 .51038 .43532 Mtetra
.576 .732 .949 r
.51038 .43532 .51844 .44331 .5332 .43934 .5252 .43317 Mtetra
.268 .639 .964 r
.5252 .43317 .5332 .43934 .54806 .43717 .54014 .4356 Mtetra
.631 .068 0 r
.54014 .4356 .54806 .43717 .56308 .43954 .55531 .4471 Mtetra
.805 .399 .281 r
.55531 .4471 .56308 .43954 .57839 .45105 .57091 .47251 Mtetra
.796 .455 .41 r
.57091 .47251 .57839 .45105 .59424 .47674 .58716 .51283 Mtetra
.767 .45 .451 r
.58716 .51283 .59424 .47674 .61086 .51798 .60409 .56013 Mtetra
.719 .41 .454 r
.60409 .56013 .61086 .51798 .62824 .56711 .6213 .59664 Mtetra
.585 .256 .378 r
.6213 .59664 .62824 .56711 .64588 .60609 .63801 .60332 Mtetra
.951 .876 .727 r
.63801 .60332 .64588 .60609 .66282 .61491 .65358 .57416 Mtetra
.808 .6 .62 r
.65358 .57416 .66282 .61491 .67831 .58645 .66799 .52127 Mtetra
.757 .541 .603 r
.66799 .52127 .67831 .58645 .6924 .53257 .68186 .46485 Mtetra
.727 .517 .607 r
.68186 .46485 .6924 .53257 .70585 .47418 .69589 .41956 Mtetra
.706 .513 .625 r
.69589 .41956 .70585 .47418 .71953 .42688 .7105 .38961 Mtetra
.692 .532 .664 r
.7105 .38961 .71953 .42688 .7339 .39545 .72572 .37197 Mtetra
.686 .579 .73 r
.72572 .37197 .7339 .39545 .74901 .37698 .7414 .36161 Mtetra
.68 .647 .811 r
.7414 .36161 .74901 .37698 .76465 .36623 .75737 .35461 Mtetra
.672 .703 .87 r
.75737 .35461 .76465 .36623 .78062 .3591 .7735 .34885 Mtetra
.666 .729 .897 r
.7735 .34885 .78062 .3591 .79678 .35331 .78976 .34344 Mtetra
.664 .738 .905 r
.78976 .34344 .79678 .35331 .81306 .34792 .80611 .33809 Mtetra
.664 .741 .907 r
.80611 .33809 .81306 .34792 .82944 .3426 .82256 .33274 Mtetra
.664 .741 .908 r
.82256 .33274 .82944 .3426 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Mtetra
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Mtetra
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Mtetra
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Mtetra
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47255 Mtetra
.35796 .47255 .36658 .481 .38062 .47643 .37205 .46794 Mtetra
.37205 .46794 .38062 .47643 .39473 .47184 .38621 .46331 Mtetra
.38621 .46331 .39473 .47184 .40892 .46723 .40044 .45865 Mtetra
.40044 .45865 .40892 .46723 .42319 .46259 .41476 .45397 Mtetra
.41476 .45397 .42319 .46259 .43753 .45793 .42914 .44926 Mtetra
.663 .741 .908 r
.42914 .44926 .43753 .45793 .45194 .45324 .44361 .44453 Mtetra
.44361 .44453 .45194 .45324 .46644 .44854 .45815 .43981 Mtetra
.659 .741 .911 r
.45815 .43981 .46644 .44854 .48101 .44385 .47277 .43522 Mtetra
.644 .74 .919 r
.47277 .43522 .48101 .44385 .49566 .43929 .48746 .43114 Mtetra
.588 .734 .944 r
.48746 .43114 .49566 .43929 .51038 .43532 .50223 .42868 Mtetra
.348 .67 .975 r
.50223 .42868 .51038 .43532 .5252 .43317 .51709 .43023 Mtetra
.503 0 0 r
.51709 .43023 .5252 .43317 .54014 .4356 .53211 .43965 Mtetra
.797 .356 .199 r
.53211 .43965 .54014 .4356 .55531 .4471 .54742 .46091 Mtetra
.807 .441 .362 r
.54742 .46091 .55531 .4471 .57091 .47251 .56321 .4945 Mtetra
.789 .446 .407 r
.56321 .4945 .57091 .47251 .58716 .51283 .57953 .53324 Mtetra
.756 .4 .381 r
.57953 .53324 .58716 .51283 .60409 .56013 .59614 .56198 Mtetra
.351 0 0 r
.59614 .56198 .60409 .56013 .6213 .59664 .61251 .56531 Mtetra
.757 .59 .67 r
.61251 .56531 .6213 .59664 .63801 .60332 .62815 .53895 Mtetra
.733 .525 .611 r
.62815 .53895 .63801 .60332 .65358 .57416 .64298 .49342 Mtetra
.713 .5 .6 r
.64298 .49342 .65358 .57416 .66799 .52127 .65741 .44547 Mtetra
.696 .49 .605 r
.65741 .44547 .66799 .52127 .68186 .46485 .67195 .40706 Mtetra
.684 .495 .625 r
.67195 .40706 .68186 .46485 .69589 .41956 .68689 .38148 Mtetra
.677 .52 .665 r
.68689 .38148 .69589 .41956 .7105 .38961 .70228 .36611 Mtetra
.676 .574 .733 r
.70228 .36611 .7105 .38961 .72572 .37197 .71802 .35671 Mtetra
.675 .647 .815 r
.71802 .35671 .72572 .37197 .7414 .36161 .73399 .35003 Mtetra
.67 .704 .873 r
.73399 .35003 .7414 .36161 .75737 .35461 .75011 .34434 Mtetra
.665 .73 .898 r
.75011 .34434 .75737 .35461 .7735 .34885 .76634 .33893 Mtetra
.664 .739 .905 r
.76634 .33893 .7735 .34885 .78976 .34344 .78267 .33357 Mtetra
.664 .741 .907 r
.78267 .33357 .78976 .34344 .80611 .33809 .7991 .32819 Mtetra
.664 .741 .908 r
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Mtetra
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Mtetra
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Mtetra
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46865 Mtetra
.3352 .46865 .34395 .47714 .35796 .47255 .34926 .46402 Mtetra
.34926 .46402 .35796 .47255 .37205 .46794 .36339 .45937 Mtetra
.36339 .45937 .37205 .46794 .38621 .46331 .3776 .45469 Mtetra
.3776 .45469 .38621 .46331 .40044 .45865 .39188 .44998 Mtetra
.39188 .44998 .40044 .45865 .41476 .45397 .40624 .44525 Mtetra
.663 .741 .908 r
.40624 .44525 .41476 .45397 .42914 .44926 .42068 .4405 Mtetra
.42068 .4405 .42914 .44926 .44361 .44453 .43519 .43576 Mtetra
.66 .741 .91 r
.43519 .43576 .44361 .44453 .45815 .43981 .44978 .4311 Mtetra
.648 .74 .916 r
.44978 .4311 .45815 .43981 .47277 .43522 .46444 .42684 Mtetra
.608 .736 .936 r
.46444 .42684 .47277 .43522 .48746 .43114 .47917 .42383 Mtetra
.458 .706 .975 r
.47917 .42383 .48746 .43114 .50223 .42868 .49397 .42389 Mtetra
0 .39 .77 r
.49397 .42389 .50223 .42868 .51709 .43023 .50886 .4299 Mtetra
.73 .21 0 r
.50886 .4299 .51709 .43023 .53211 .43965 .52394 .44469 Mtetra
.807 .38 .233 r
.52394 .44469 .53211 .43965 .54742 .46091 .53932 .46831 Mtetra
.81 .403 .278 r
.53932 .46831 .54742 .46091 .56321 .4945 .55508 .49508 Mtetra
.774 .281 .048 r
.55508 .49508 .56321 .4945 .57953 .53324 .57112 .51385 Mtetra
.557 .544 .796 r
.57112 .51385 .57953 .53324 .59614 .56198 .58713 .51382 Mtetra
.685 .509 .642 r
.58713 .51382 .59614 .56198 .61251 .56531 .60278 .49249 Mtetra
.69 .489 .61 r
.60278 .49249 .61251 .56531 .62815 .53895 .61797 .45768 Mtetra
.683 .479 .603 r
.61797 .45768 .62815 .53895 .64298 .49342 .63292 .42142 Mtetra
.674 .477 .611 r
.63292 .42142 .64298 .49342 .65741 .44547 .64792 .39222 Mtetra
.668 .489 .633 r
.64792 .39222 .65741 .44547 .67195 .40706 .66318 .37237 Mtetra
.667 .523 .678 r
.66318 .37237 .67195 .40706 .68689 .38148 .67873 .35989 Mtetra
.67 .584 .75 r
.67873 .35989 .68689 .38148 .70228 .36611 .69454 .35168 Mtetra
.672 .658 .828 r
.69454 .35168 .70228 .36611 .71802 .35671 .71051 .3454 Mtetra
.668 .709 .879 r
.71051 .3454 .71802 .35671 .73399 .35003 .72661 .33981 Mtetra
.665 .732 .9 r
.72661 .33981 .73399 .35003 .75011 .34434 .74282 .33441 Mtetra
.664 .739 .906 r
.74282 .33441 .75011 .34434 .76634 .33893 .75912 .32902 Mtetra
.664 .741 .908 r
.75912 .32902 .76634 .33893 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Mtetra
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46936 Mtetra
.29838 .46936 .3073 .47784 .32121 .47326 .31234 .46474 Mtetra
.31234 .46474 .32121 .47326 .3352 .46865 .32636 .46009 Mtetra
.32636 .46009 .3352 .46865 .34926 .46402 .34047 .45541 Mtetra
.34047 .45541 .34926 .46402 .36339 .45937 .35465 .45071 Mtetra
.35465 .45071 .36339 .45937 .3776 .45469 .3689 .44598 Mtetra
.3689 .44598 .3776 .45469 .39188 .44998 .38323 .44123 Mtetra
.663 .741 .908 r
.38323 .44123 .39188 .44998 .40624 .44525 .39764 .43646 Mtetra
.39764 .43646 .40624 .44525 .42068 .4405 .41213 .43168 Mtetra
.661 .741 .909 r
.41213 .43168 .42068 .4405 .43519 .43576 .42669 .42695 Mtetra
.653 .74 .914 r
.42669 .42695 .43519 .43576 .44978 .4311 .44132 .42249 Mtetra
.628 .738 .927 r
.44132 .42249 .44978 .4311 .46444 .42684 .45602 .41887 Mtetra
.547 .727 .958 r
.45602 .41887 .46444 .42684 .47917 .42383 .47077 .4173 Mtetra
.276 .638 .965 r
.47077 .4173 .47917 .42383 .49397 .42389 .48559 .41965 Mtetra
.353 0 0 r
.48559 .41965 .49397 .42389 .50886 .4299 .50052 .42768 Mtetra
.678 .129 0 r
.50052 .42768 .50886 .4299 .52394 .44469 .51563 .44121 Mtetra
.686 .143 0 r
.51563 .44121 .52394 .44469 .53932 .46831 .53101 .45635 Mtetra
.082 .375 .839 r
.53101 .45635 .53932 .46831 .55508 .49508 .54662 .46595 Mtetra
.591 .497 .716 r
.54662 .46595 .55508 .49508 .57112 .51385 .56232 .46341 Mtetra
.655 .485 .641 r
.56232 .46341 .57112 .51385 .58713 .51382 .57792 .4475 Mtetra
.666 .475 .618 r
.57792 .4475 .58713 .51382 .60278 .49249 .59333 .4233 Mtetra
.664 .472 .614 r
.59333 .4233 .60278 .49249 .61797 .45768 .60863 .39836 Mtetra
.661 .477 .625 r
.60863 .39836 .61797 .45768 .63292 .42142 .62396 .37799 Mtetra
.659 .497 .654 r
.62396 .37799 .63292 .42142 .64792 .39222 .63944 .36357 Mtetra
.663 .541 .706 r
.63944 .36357 .64792 .39222 .66318 .37237 .65511 .35379 Mtetra
.668 .608 .779 r
.65511 .35379 .66318 .37237 .67873 .35989 .67095 .34669 Mtetra
.669 .676 .848 r
.67095 .34669 .67873 .35989 .69454 .35168 .68692 .34077 Mtetra
.666 .718 .887 r
.68692 .34077 .69454 .35168 .71051 .3454 .703 .33526 Mtetra
.664 .735 .902 r
.703 .33526 .71051 .3454 .72661 .33981 .71918 .32986 Mtetra
.664 .74 .907 r
.71918 .32986 .72661 .33981 .74282 .33441 .73545 .32445 Mtetra
.664 .741 .908 r
.73545 .32445 .74282 .33441 .75912 .32902 .75182 .31903 Mtetra
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Mtetra
.27545 .46545 .2845 .47397 .29838 .46936 .28937 .4608 Mtetra
.28937 .4608 .29838 .46936 .31234 .46474 .30337 .45613 Mtetra
.30337 .45613 .31234 .46474 .32636 .46009 .31744 .45143 Mtetra
.31744 .45143 .32636 .46009 .34047 .45541 .33159 .44671 Mtetra
.33159 .44671 .34047 .45541 .35465 .45071 .34582 .44196 Mtetra
.34582 .44196 .35465 .45071 .3689 .44598 .36012 .43719 Mtetra
.663 .741 .908 r
.36012 .43719 .3689 .44598 .38323 .44123 .3745 .4324 Mtetra
.3745 .4324 .38323 .44123 .39764 .43646 .38895 .42758 Mtetra
.662 .741 .909 r
.38895 .42758 .39764 .43646 .41213 .43168 .40349 .4228 Mtetra
.657 .741 .911 r
.40349 .4228 .41213 .43168 .42669 .42695 .41809 .41816 Mtetra
.643 .74 .919 r
.41809 .41816 .42669 .42695 .44132 .42249 .43277 .414 Mtetra
.604 .735 .937 r
.43277 .414 .44132 .42249 .45602 .41887 .4475 .41104 Mtetra
.503 .715 .967 r
.4475 .41104 .45602 .41887 .47077 .4173 .46228 .41033 Mtetra
.281 .631 .963 r
.46228 .41033 .47077 .4173 .48559 .41965 .47714 .41283 Mtetra
.04 .483 .884 r
.47714 .41283 .48559 .41965 .50052 .42768 .49212 .41833 Mtetra
.148 .483 .9 r
.49212 .41833 .50052 .42768 .51563 .44121 .50728 .42451 Mtetra
.477 .527 .83 r
.50728 .42451 .51563 .44121 .53101 .45635 .52263 .42734 Mtetra
.607 .506 .713 r
.52263 .42734 .53101 .45635 .54662 .46595 .53812 .4233 Mtetra
.643 .489 .658 r
.53812 .4233 .54662 .46595 .56232 .46341 .55364 .41187 Mtetra
.653 .48 .638 r
.55364 .41187 .56232 .46341 .57792 .4475 .56912 .39597 Mtetra
.654 .481 .638 r
.56912 .39597 .57792 .4475 .59333 .4233 .58458 .37976 Mtetra
.654 .494 .654 r
.58458 .37976 .59333 .4233 .60863 .39836 .60008 .36615 Mtetra
.657 .524 .69 r
.60008 .36615 .60863 .39836 .62396 .37799 .61568 .35585 Mtetra
.663 .577 .748 r
.61568 .35585 .62396 .37799 .63944 .36357 .63141 .34811 Mtetra
.668 .643 .816 r
.63141 .34811 .63944 .36357 .65511 .35379 .64726 .34181 Mtetra
.667 .697 .869 r
.64726 .34181 .65511 .35379 .67095 .34669 .66322 .33615 Mtetra
.665 .726 .895 r
.66322 .33615 .67095 .34669 .68692 .34077 .67927 .3307 Mtetra
.664 .737 .904 r
.67927 .3307 .68692 .34077 .703 .33526 .69543 .32529 Mtetra
.664 .74 .907 r
.69543 .32529 .703 .33526 .71918 .32986 .71167 .31986 Mtetra
.664 .741 .908 r
.71167 .31986 .71918 .32986 .73545 .32445 .72801 .31441 Mtetra
.72801 .31441 .73545 .32445 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Mtetra
.2663 .45685 .27545 .46545 .28937 .4608 .28027 .45216 Mtetra
.28027 .45216 .28937 .4608 .30337 .45613 .29432 .44744 Mtetra
.29432 .44744 .30337 .45613 .31744 .45143 .30844 .4427 Mtetra
.30844 .4427 .31744 .45143 .33159 .44671 .32263 .43793 Mtetra
.32263 .43793 .33159 .44671 .34582 .44196 .3369 .43313 Mtetra
.3369 .43313 .34582 .44196 .36012 .43719 .35125 .42831 Mtetra
.663 .741 .908 r
.35125 .42831 .36012 .43719 .3745 .4324 .36568 .42347 Mtetra
.36568 .42347 .3745 .4324 .38895 .42758 .38018 .41863 Mtetra
.66 .741 .91 r
.38018 .41863 .38895 .42758 .40349 .4228 .39476 .41386 Mtetra
.653 .74 .914 r
.39476 .41386 .40349 .4228 .41809 .41816 .40941 .40932 Mtetra
.635 .738 .923 r
.40941 .40932 .41809 .41816 .43277 .414 .42412 .40538 Mtetra
.597 .732 .939 r
.42412 .40538 .43277 .414 .4475 .41104 .4389 .40257 Mtetra
.534 .713 .954 r
.4389 .40257 .4475 .41104 .46228 .41033 .45374 .40134 Mtetra
.478 .676 .951 r
.45374 .40134 .46228 .41033 .47714 .41283 .46867 .40153 Mtetra
.502 .632 .911 r
.46867 .40153 .47714 .41283 .49212 .41833 .48373 .40195 Mtetra
.576 .584 .824 r
.48373 .40195 .49212 .41833 .50728 .42451 .49894 .4006 Mtetra
.624 .542 .742 r
.49894 .4006 .50728 .42451 .52263 .42734 .51429 .39582 Mtetra
.643 .518 .695 r
.51429 .39582 .52263 .42734 .53812 .4233 .52971 .38745 Mtetra
.65 .508 .677 r
.52971 .38745 .53812 .4233 .55364 .41187 .54518 .37695 Mtetra
.653 .513 .68 r
.54518 .37695 .55364 .41187 .56912 .39597 .56069 .36635 Mtetra
.656 .533 .702 r
.56069 .36635 .56912 .39597 .58458 .37976 .57625 .35704 Mtetra
.66 .571 .744 r
.57625 .35704 .58458 .37976 .60008 .36615 .59189 .34934 Mtetra
.665 .626 .8 r
.59189 .34934 .60008 .36615 .61568 .35585 .60763 .34286 Mtetra
.667 .68 .853 r
.60763 .34286 .61568 .35585 .63141 .34811 .62347 .33707 Mtetra
.666 .716 .886 r
.62347 .33707 .63141 .34811 .64726 .34181 .6394 .33156 Mtetra
.664 .733 .901 r
.6394 .33156 .64726 .34181 .66322 .33615 .65544 .32613 Mtetra
.664 .739 .906 r
.65544 .32613 .66322 .33615 .67927 .3307 .67156 .3207 Mtetra
.664 .741 .907 r
.67156 .3207 .67927 .3307 .69543 .32529 .68777 .31525 Mtetra
.664 .741 .908 r
.68777 .31525 .69543 .32529 .71167 .31986 .70408 .30977 Mtetra
.70408 .30977 .71167 .31986 .72801 .31441 .72049 .30426 Mtetra
.72049 .30426 .72801 .31441 .74444 .30893 .73699 .29872 Mtetra
.73699 .29872 .74444 .30893 .76097 .30341 .75358 .29314 Mtetra
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28753 Mtetra
.77027 .28753 .7776 .29786 .79432 .29228 .78706 .28189 Mtetra
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Mtetra
.25707 .44817 .2663 .45685 .28027 .45216 .27108 .44343 Mtetra
.27108 .44343 .28027 .45216 .29432 .44744 .28517 .43866 Mtetra
.28517 .43866 .29432 .44744 .30844 .4427 .29934 .43387 Mtetra
.29934 .43387 .30844 .4427 .32263 .43793 .31358 .42905 Mtetra
.31358 .42905 .32263 .43793 .3369 .43313 .3279 .42421 Mtetra
.663 .741 .908 r
.3279 .42421 .3369 .43313 .35125 .42831 .34229 .41935 Mtetra
.34229 .41935 .35125 .42831 .36568 .42347 .35677 .41447 Mtetra
.662 .741 .909 r
.35677 .41447 .36568 .42347 .38018 .41863 .37132 .4096 Mtetra
.659 .741 .91 r
.37132 .4096 .38018 .41863 .39476 .41386 .38594 .40483 Mtetra
.651 .74 .914 r
.38594 .40483 .39476 .41386 .40941 .40932 .40064 .40031 Mtetra
.637 .737 .921 r
.40064 .40031 .40941 .40932 .42412 .40538 .41541 .39628 Mtetra
.616 .729 .926 r
.41541 .39628 .42412 .40538 .4389 .40257 .43024 .39291 Mtetra
.599 .711 .922 r
.43024 .39291 .4389 .40257 .45374 .40134 .44516 .39013 Mtetra
.602 .679 .895 r
.44516 .39013 .45374 .40134 .46867 .40153 .46018 .38739 Mtetra
.623 .637 .844 r
.46018 .38739 .46867 .40153 .48373 .40195 .47532 .38384 Mtetra
.641 .598 .79 r
.47532 .38384 .48373 .40195 .49894 .4006 .49057 .37876 Mtetra
.651 .571 .752 r
.49057 .37876 .49894 .4006 .51429 .39582 .50592 .37214 Mtetra
.655 .562 .737 r
.50592 .37214 .51429 .39582 .52971 .38745 .52134 .36463 Mtetra
.658 .569 .743 r
.52134 .36463 .52971 .38745 .54518 .37695 .53683 .35708 Mtetra
.662 .594 .768 r
.53683 .35708 .54518 .37695 .56069 .36635 .55239 .35009 Mtetra
.665 .632 .807 r
.55239 .35009 .56069 .36635 .57625 .35704 .56802 .34377 Mtetra
.667 .675 .849 r
.56802 .34377 .57625 .35704 .59189 .34934 .58375 .33796 Mtetra
.666 .709 .88 r
.58375 .33796 .59189 .34934 .60763 .34286 .59957 .33241 Mtetra
.665 .729 .897 r
.59957 .33241 .60763 .34286 .62347 .33707 .61548 .32697 Mtetra
.664 .737 .905 r
.61548 .32697 .62347 .33707 .6394 .33156 .63148 .32154 Mtetra
.664 .74 .907 r
.63148 .32154 .6394 .33156 .65544 .32613 .64757 .31609 Mtetra
.664 .741 .908 r
.64757 .31609 .65544 .32613 .67156 .3207 .66376 .31062 Mtetra
.66376 .31062 .67156 .3207 .68777 .31525 .68004 .30511 Mtetra
.68004 .30511 .68777 .31525 .70408 .30977 .69642 .29957 Mtetra
.69642 .29957 .70408 .30977 .72049 .30426 .71289 .294 Mtetra
.71289 .294 .72049 .30426 .73699 .29872 .72945 .2884 Mtetra
.72945 .2884 .73699 .29872 .75358 .29314 .74611 .28276 Mtetra
.74611 .28276 .75358 .29314 .77027 .28753 .76287 .2771 Mtetra
.76287 .2771 .77027 .28753 .78706 .28189 .77973 .27139 Mtetra
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.23376 .44416 .24313 .45288 .25707 .44817 .24775 .4394 Mtetra
.24775 .4394 .25707 .44817 .27108 .44343 .2618 .43461 Mtetra
.2618 .43461 .27108 .44343 .28517 .43866 .27594 .4298 Mtetra
.27594 .4298 .28517 .43866 .29934 .43387 .29015 .42496 Mtetra
.29015 .42496 .29934 .43387 .31358 .42905 .30444 .42009 Mtetra
.30444 .42009 .31358 .42905 .3279 .42421 .3188 .4152 Mtetra
.663 .741 .908 r
.3188 .4152 .3279 .42421 .34229 .41935 .33324 .41029 Mtetra
.33324 .41029 .34229 .41935 .35677 .41447 .34777 .40537 Mtetra
.662 .741 .909 r
.34777 .40537 .35677 .41447 .37132 .4096 .36237 .40047 Mtetra
.659 .741 .91 r
.36237 .40047 .37132 .4096 .38594 .40483 .37704 .39565 Mtetra
.654 .739 .912 r
.37704 .39565 .38594 .40483 .40064 .40031 .39179 .391 Mtetra
.646 .735 .914 r
.39179 .391 .40064 .40031 .41541 .39628 .40662 .38659 Mtetra
.641 .726 .91 r
.40662 .38659 .41541 .39628 .43024 .39291 .42152 .38238 Mtetra
.641 .709 .896 r
.42152 .38238 .43024 .39291 .44516 .39013 .43652 .37815 Mtetra
.647 .684 .871 r
.43652 .37815 .44516 .39013 .46018 .38739 .45161 .37358 Mtetra
.655 .657 .84 r
.45161 .37358 .46018 .38739 .47532 .38384 .46681 .36841 Mtetra
.66 .638 .817 r
.46681 .36841 .47532 .38384 .49057 .37876 .4821 .36264 Mtetra
.663 .631 .808 r
.4821 .36264 .49057 .37876 .50592 .37214 .49747 .35653 Mtetra
.664 .639 .815 r
.49747 .35653 .50592 .37214 .52134 .36463 .51292 .3504 Mtetra
.666 .659 .834 r
.51292 .3504 .52134 .36463 .53683 .35708 .52845 .34447 Mtetra
.666 .686 .859 r
.52845 .34447 .53683 .35708 .55239 .35009 .54407 .33878 Mtetra
.666 .71 .881 r
.54407 .33878 .55239 .35009 .56802 .34377 .55977 .33325 Mtetra
.665 .727 .896 r
.55977 .33325 .56802 .34377 .58375 .33796 .57556 .32781 Mtetra
.664 .736 .903 r
.57556 .32781 .58375 .33796 .59957 .33241 .59144 .32238 Mtetra
.664 .74 .907 r
.59144 .32238 .59957 .33241 .61548 .32697 .60741 .31693 Mtetra
.664 .741 .908 r
.60741 .31693 .61548 .32697 .63148 .32154 .62347 .31146 Mtetra
.62347 .31146 .63148 .32154 .64757 .31609 .63963 .30596 Mtetra
.63963 .30596 .64757 .31609 .66376 .31062 .65588 .30043 Mtetra
.65588 .30043 .66376 .31062 .68004 .30511 .67223 .29486 Mtetra
.67223 .29486 .68004 .30511 .69642 .29957 .68867 .28926 Mtetra
.68867 .28926 .69642 .29957 .71289 .294 .7052 .28363 Mtetra
.7052 .28363 .71289 .294 .72945 .2884 .72183 .27797 Mtetra
.72183 .27797 .72945 .2884 .74611 .28276 .73856 .27227 Mtetra
.73856 .27227 .74611 .28276 .76287 .2771 .75539 .26654 Mtetra
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.2243 .43535 .23376 .44416 .24775 .4394 .23833 .43054 Mtetra
.23833 .43054 .24775 .4394 .2618 .43461 .25243 .4257 Mtetra
.25243 .4257 .2618 .43461 .27594 .4298 .26661 .42084 Mtetra
.26661 .42084 .27594 .4298 .29015 .42496 .28087 .41596 Mtetra
.28087 .41596 .29015 .42496 .30444 .42009 .2952 .41104 Mtetra
.663 .741 .908 r
.2952 .41104 .30444 .42009 .3188 .4152 .30961 .4061 Mtetra
.30961 .4061 .3188 .4152 .33324 .41029 .3241 .40114 Mtetra
.3241 .40114 .33324 .41029 .34777 .40537 .33867 .39617 Mtetra
.662 .741 .909 r
.33867 .39617 .34777 .40537 .36237 .40047 .35332 .39121 Mtetra
.66 .74 .909 r
.35332 .39121 .36237 .40047 .37704 .39565 .36805 .38629 Mtetra
.658 .738 .909 r
.36805 .38629 .37704 .39565 .39179 .391 .38286 .38143 Mtetra
.656 .734 .907 r
.38286 .38143 .39179 .391 .40662 .38659 .39774 .37661 Mtetra
.656 .726 .901 r
.39774 .37661 .40662 .38659 .42152 .38238 .41272 .37177 Mtetra
.658 .715 .89 r
.41272 .37177 .42152 .38238 .43652 .37815 .42778 .36679 Mtetra
.661 .702 .877 r
.42778 .36679 .43652 .37815 .45161 .37358 .44293 .36158 Mtetra
.664 .693 .867 r
.44293 .36158 .45161 .37358 .46681 .36841 .45818 .35617 Mtetra
.665 .69 .863 r
.45818 .35617 .46681 .36841 .4821 .36264 .47351 .35062 Mtetra
.666 .695 .867 r
.47351 .35062 .4821 .36264 .49747 .35653 .48892 .34505 Mtetra
.666 .706 .877 r
.48892 .34505 .49747 .35653 .51292 .3504 .50442 .33953 Mtetra
.665 .719 .889 r
.50442 .33953 .51292 .3504 .52845 .34447 .52 .33407 Mtetra
.664 .729 .898 r
.52 .33407 .52845 .34447 .54407 .33878 .53567 .32864 Mtetra
.664 .736 .903 r
.53567 .32864 .54407 .33878 .55977 .33325 .55143 .32321 Mtetra
.664 .739 .906 r
.55143 .32321 .55977 .33325 .57556 .32781 .56728 .31777 Mtetra
.664 .741 .907 r
.56728 .31777 .57556 .32781 .59144 .32238 .58322 .31231 Mtetra
.664 .741 .908 r
.58322 .31231 .59144 .32238 .60741 .31693 .59926 .30681 Mtetra
.59926 .30681 .60741 .31693 .62347 .31146 .61538 .30128 Mtetra
.61538 .30128 .62347 .31146 .63963 .30596 .6316 .29572 Mtetra
.6316 .29572 .63963 .30596 .65588 .30043 .64792 .29013 Mtetra
.64792 .29013 .65588 .30043 .67223 .29486 .66433 .2845 Mtetra
.66433 .2845 .67223 .29486 .68867 .28926 .68083 .27884 Mtetra
.68083 .27884 .68867 .28926 .7052 .28363 .69743 .27315 Mtetra
.69743 .27315 .7052 .28363 .72183 .27797 .71413 .26743 Mtetra
.71413 .26743 .72183 .27797 .73856 .27227 .73093 .26167 Mtetra
.73093 .26167 .73856 .27227 .75539 .26654 .74783 .25587 Mtetra
.74783 .25587 .75539 .26654 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24418 Mtetra
.78193 .24418 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.21474 .42645 .2243 .43535 .23833 .43054 .22882 .42159 Mtetra
.22882 .42159 .23833 .43054 .25243 .4257 .24296 .41671 Mtetra
.24296 .41671 .25243 .4257 .26661 .42084 .25719 .4118 Mtetra
.25719 .4118 .26661 .42084 .28087 .41596 .27149 .40686 Mtetra
.27149 .40686 .28087 .41596 .2952 .41104 .28587 .4019 Mtetra
.663 .741 .908 r
.28587 .4019 .2952 .41104 .30961 .4061 .30033 .39691 Mtetra
.30033 .39691 .30961 .4061 .3241 .40114 .31487 .3919 Mtetra
.31487 .3919 .3241 .40114 .33867 .39617 .32949 .38687 Mtetra
.32949 .38687 .33867 .39617 .35332 .39121 .34419 .38184 Mtetra
.662 .74 .908 r
.34419 .38184 .35332 .39121 .36805 .38629 .35897 .3768 Mtetra
.661 .739 .907 r
.35897 .3768 .36805 .38629 .38286 .38143 .37383 .37175 Mtetra
.661 .736 .905 r
.37383 .37175 .38286 .38143 .39774 .37661 .38878 .36668 Mtetra
.662 .731 .901 r
.38878 .36668 .39774 .37661 .41272 .37177 .40381 .36154 Mtetra
.663 .727 .897 r
.40381 .36154 .41272 .37177 .42778 .36679 .41893 .35632 Mtetra
.664 .723 .893 r
.41893 .35632 .42778 .36679 .44293 .36158 .43413 .35101 Mtetra
.665 .722 .892 r
.43413 .35101 .44293 .36158 .45818 .35617 .44943 .34565 Mtetra
.665 .725 .894 r
.44943 .34565 .45818 .35617 .47351 .35062 .4648 .34026 Mtetra
.664 .729 .898 r
.4648 .34026 .47351 .35062 .48892 .34505 .48027 .33486 Mtetra
.664 .734 .902 r
.48027 .33486 .48892 .34505 .50442 .33953 .49582 .32946 Mtetra
.664 .737 .905 r
.49582 .32946 .50442 .33953 .52 .33407 .51146 .32405 Mtetra
.664 .74 .906 r
.51146 .32405 .52 .33407 .53567 .32864 .52719 .31861 Mtetra
.664 .741 .907 r
.52719 .31861 .53567 .32864 .55143 .32321 .54301 .31315 Mtetra
.664 .741 .908 r
.54301 .31315 .55143 .32321 .56728 .31777 .55892 .30766 Mtetra
.55892 .30766 .56728 .31777 .58322 .31231 .57492 .30213 Mtetra
.57492 .30213 .58322 .31231 .59926 .30681 .59101 .29658 Mtetra
.59101 .29658 .59926 .30681 .61538 .30128 .6072 .29099 Mtetra
.6072 .29099 .61538 .30128 .6316 .29572 .62349 .28537 Mtetra
.62349 .28537 .6316 .29572 .64792 .29013 .63987 .27972 Mtetra
.63987 .27972 .64792 .29013 .66433 .2845 .65634 .27403 Mtetra
.65634 .27403 .66433 .2845 .68083 .27884 .67291 .26831 Mtetra
.67291 .26831 .68083 .27884 .69743 .27315 .68958 .26256 Mtetra
.68958 .26256 .69743 .27315 .71413 .26743 .70635 .25677 Mtetra
.70635 .25677 .71413 .26743 .73093 .26167 .72322 .25095 Mtetra
.72322 .25095 .73093 .26167 .74783 .25587 .74019 .24509 Mtetra
.74019 .24509 .74783 .25587 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24418 .77443 .23327 Mtetra
.77443 .23327 .78193 .24418 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.20509 .41746 .21474 .42645 .22882 .42159 .21921 .41256 Mtetra
.21921 .41256 .22882 .42159 .24296 .41671 .2334 .40762 Mtetra
.2334 .40762 .24296 .41671 .25719 .4118 .24767 .40267 Mtetra
.24767 .40267 .25719 .4118 .27149 .40686 .26202 .39768 Mtetra
.26202 .39768 .27149 .40686 .28587 .4019 .27645 .39266 Mtetra
.663 .741 .908 r
.27645 .39266 .28587 .4019 .30033 .39691 .29096 .38762 Mtetra
.29096 .38762 .30033 .39691 .31487 .3919 .30555 .38256 Mtetra
.30555 .38256 .31487 .3919 .32949 .38687 .32021 .37747 Mtetra
.32021 .37747 .32949 .38687 .34419 .38184 .33496 .37236 Mtetra
.663 .74 .908 r
.33496 .37236 .34419 .38184 .35897 .3768 .3498 .36723 Mtetra
.663 .739 .907 r
.3498 .36723 .35897 .3768 .37383 .37175 .36471 .36206 Mtetra
.663 .738 .906 r
.36471 .36206 .37383 .37175 .38878 .36668 .37971 .35686 Mtetra
.663 .737 .904 r
.37971 .35686 .38878 .36668 .40381 .36154 .3948 .35162 Mtetra
.664 .736 .903 r
.3948 .35162 .40381 .36154 .41893 .35632 .40997 .34633 Mtetra
.664 .735 .903 r
.40997 .34633 .41893 .35632 .43413 .35101 .42523 .34101 Mtetra
.664 .736 .904 r
.42523 .34101 .43413 .35101 .44943 .34565 .44057 .33565 Mtetra
.664 .738 .905 r
.44057 .33565 .44943 .34565 .4648 .34026 .456 .33028 Mtetra
.664 .739 .906 r
.456 .33028 .4648 .34026 .48027 .33486 .47152 .32488 Mtetra
.664 .74 .907 r
.47152 .32488 .48027 .33486 .49582 .32946 .48713 .31945 Mtetra
.664 .741 .908 r
.48713 .31945 .49582 .32946 .51146 .32405 .50282 .31399 Mtetra
.50282 .31399 .51146 .32405 .52719 .31861 .51861 .3085 Mtetra
.51861 .3085 .52719 .31861 .54301 .31315 .53449 .30298 Mtetra
.53449 .30298 .54301 .31315 .55892 .30766 .55046 .29743 Mtetra
.55046 .29743 .55892 .30766 .57492 .30213 .56653 .29185 Mtetra
.56653 .29185 .57492 .30213 .59101 .29658 .58268 .28624 Mtetra
.58268 .28624 .59101 .29658 .6072 .29099 .59894 .28059 Mtetra
.59894 .28059 .6072 .29099 .62349 .28537 .61528 .27491 Mtetra
.61528 .27491 .62349 .28537 .63987 .27972 .63173 .26919 Mtetra
.63173 .26919 .63987 .27972 .65634 .27403 .64827 .26344 Mtetra
.64827 .26344 .65634 .27403 .67291 .26831 .66491 .25766 Mtetra
.66491 .25766 .67291 .26831 .68958 .26256 .68164 .25184 Mtetra
.68164 .25184 .68958 .26256 .70635 .25677 .69848 .24599 Mtetra
.69848 .24599 .70635 .25677 .72322 .25095 .71542 .24011 Mtetra
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23418 Mtetra
.73246 .23418 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Mtetra
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .2162 Mtetra
.78419 .2162 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.19534 .40839 .20509 .41746 .21921 .41256 .2095 .40343 Mtetra
.2095 .40343 .21921 .41256 .2334 .40762 .22374 .39845 Mtetra
.22374 .39845 .2334 .40762 .24767 .40267 .23806 .39344 Mtetra
.23806 .39344 .24767 .40267 .26202 .39768 .25245 .3884 Mtetra
.25245 .3884 .26202 .39768 .27645 .39266 .26693 .38333 Mtetra
.26693 .38333 .27645 .39266 .29096 .38762 .28149 .37824 Mtetra
.663 .741 .908 r
.28149 .37824 .29096 .38762 .30555 .38256 .29612 .37312 Mtetra
.29612 .37312 .30555 .38256 .32021 .37747 .31084 .36797 Mtetra
.31084 .36797 .32021 .37747 .33496 .37236 .32564 .3628 Mtetra
.32564 .3628 .33496 .37236 .3498 .36723 .34053 .3576 Mtetra
.663 .74 .907 r
.34053 .3576 .3498 .36723 .36471 .36206 .35549 .35236 Mtetra
.664 .74 .907 r
.35549 .35236 .36471 .36206 .37971 .35686 .37055 .34709 Mtetra
.37055 .34709 .37971 .35686 .3948 .35162 .38568 .34179 Mtetra
.38568 .34179 .3948 .35162 .40997 .34633 .40091 .33646 Mtetra
.40091 .33646 .40997 .34633 .42523 .34101 .41622 .3311 Mtetra
.41622 .3311 .42523 .34101 .44057 .33565 .43162 .3257 Mtetra
.664 .741 .907 r
.43162 .3257 .44057 .33565 .456 .33028 .4471 .32028 Mtetra
.664 .741 .908 r
.4471 .32028 .456 .33028 .47152 .32488 .46268 .31483 Mtetra
.46268 .31483 .47152 .32488 .48713 .31945 .47834 .30935 Mtetra
.47834 .30935 .48713 .31945 .50282 .31399 .4941 .30384 Mtetra
.4941 .30384 .50282 .31399 .51861 .3085 .50995 .29829 Mtetra
.50995 .29829 .51861 .3085 .53449 .30298 .52589 .29271 Mtetra
.52589 .29271 .53449 .30298 .55046 .29743 .54192 .2871 Mtetra
.54192 .2871 .55046 .29743 .56653 .29185 .55804 .28146 Mtetra
.55804 .28146 .56653 .29185 .58268 .28624 .57426 .27578 Mtetra
.57426 .27578 .58268 .28624 .59894 .28059 .59058 .27007 Mtetra
.59058 .27007 .59894 .28059 .61528 .27491 .60699 .26433 Mtetra
.60699 .26433 .61528 .27491 .63173 .26919 .6235 .25855 Mtetra
.6235 .25855 .63173 .26919 .64827 .26344 .64011 .25274 Mtetra
.64011 .25274 .64827 .26344 .66491 .25766 .65681 .24689 Mtetra
.65681 .24689 .66491 .25766 .68164 .25184 .67362 .24101 Mtetra
.67362 .24101 .68164 .25184 .69848 .24599 .69052 .2351 Mtetra
.69052 .2351 .69848 .24599 .71542 .24011 .70753 .22915 Mtetra
.70753 .22915 .71542 .24011 .73246 .23418 .72464 .22316 Mtetra
.72464 .22316 .73246 .23418 .7496 .22823 .74185 .21713 Mtetra
.74185 .21713 .7496 .22823 .76684 .22223 .75917 .21107 Mtetra
.75917 .21107 .76684 .22223 .78419 .2162 .77659 .20498 Mtetra
.77659 .20498 .78419 .2162 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.18549 .39922 .19534 .40839 .2095 .40343 .1997 .39421 Mtetra
.1997 .39421 .2095 .40343 .22374 .39845 .21398 .38918 Mtetra
.21398 .38918 .22374 .39845 .23806 .39344 .22835 .38411 Mtetra
.22835 .38411 .23806 .39344 .25245 .3884 .24279 .37903 Mtetra
.24279 .37903 .25245 .3884 .26693 .38333 .25731 .37391 Mtetra
.25731 .37391 .26693 .38333 .28149 .37824 .27192 .36876 Mtetra
.27192 .36876 .28149 .37824 .29612 .37312 .2866 .36359 Mtetra
.2866 .36359 .29612 .37312 .31084 .36797 .30137 .35838 Mtetra
.30137 .35838 .31084 .36797 .32564 .3628 .31622 .35315 Mtetra
.31622 .35315 .32564 .3628 .34053 .3576 .33116 .34789 Mtetra
.33116 .34789 .34053 .3576 .35549 .35236 .34618 .3426 Mtetra
.34618 .3426 .35549 .35236 .37055 .34709 .36128 .33727 Mtetra
.36128 .33727 .37055 .34709 .38568 .34179 .37647 .33192 Mtetra
.37647 .33192 .38568 .34179 .40091 .33646 .39175 .32653 Mtetra
.39175 .32653 .40091 .33646 .41622 .3311 .40712 .32112 Mtetra
.40712 .32112 .41622 .3311 .43162 .3257 .42257 .31567 Mtetra
.42257 .31567 .43162 .3257 .4471 .32028 .43811 .31019 Mtetra
.43811 .31019 .4471 .32028 .46268 .31483 .45374 .30469 Mtetra
.45374 .30469 .46268 .31483 .47834 .30935 .46947 .29915 Mtetra
.46947 .29915 .47834 .30935 .4941 .30384 .48528 .29357 Mtetra
.48528 .29357 .4941 .30384 .50995 .29829 .50119 .28797 Mtetra
.50119 .28797 .50995 .29829 .52589 .29271 .51719 .28233 Mtetra
.51719 .28233 .52589 .29271 .54192 .2871 .53328 .27666 Mtetra
.53328 .27666 .54192 .2871 .55804 .28146 .54947 .27095 Mtetra
.54947 .27095 .55804 .28146 .57426 .27578 .56575 .26522 Mtetra
.56575 .26522 .57426 .27578 .59058 .27007 .58213 .25944 Mtetra
.58213 .25944 .59058 .27007 .60699 .26433 .59861 .25364 Mtetra
.59861 .25364 .60699 .26433 .6235 .25855 .61518 .2478 Mtetra
.61518 .2478 .6235 .25855 .64011 .25274 .63185 .24192 Mtetra
.63185 .24192 .64011 .25274 .65681 .24689 .64863 .23601 Mtetra
.64863 .23601 .65681 .24689 .67362 .24101 .6655 .23006 Mtetra
.6655 .23006 .67362 .24101 .69052 .2351 .68248 .22408 Mtetra
.68248 .22408 .69052 .2351 .70753 .22915 .69955 .21806 Mtetra
.69955 .21806 .70753 .22915 .72464 .22316 .71674 .21201 Mtetra
.71674 .21201 .72464 .22316 .74185 .21713 .73402 .20592 Mtetra
.73402 .20592 .74185 .21713 .75917 .21107 .75141 .19979 Mtetra
.75141 .19979 .75917 .21107 .77659 .20498 .76891 .19362 Mtetra
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.17555 .38995 .18549 .39922 .1997 .39421 .1898 .3849 Mtetra
.1898 .3849 .1997 .39421 .21398 .38918 .20413 .37981 Mtetra
.20413 .37981 .21398 .38918 .22835 .38411 .21853 .3747 Mtetra
.21853 .3747 .22835 .38411 .24279 .37903 .23302 .36955 Mtetra
.23302 .36955 .24279 .37903 .25731 .37391 .2476 .36438 Mtetra
.2476 .36438 .25731 .37391 .27192 .36876 .26225 .35918 Mtetra
.26225 .35918 .27192 .36876 .2866 .36359 .27698 .35396 Mtetra
.27698 .35396 .2866 .36359 .30137 .35838 .2918 .3487 Mtetra
.2918 .3487 .30137 .35838 .31622 .35315 .3067 .34341 Mtetra
.3067 .34341 .31622 .35315 .33116 .34789 .32169 .33809 Mtetra
.32169 .33809 .33116 .34789 .34618 .3426 .33676 .33274 Mtetra
.33676 .33274 .34618 .3426 .36128 .33727 .35192 .32736 Mtetra
.35192 .32736 .36128 .33727 .37647 .33192 .36716 .32195 Mtetra
.36716 .32195 .37647 .33192 .39175 .32653 .3825 .31651 Mtetra
.3825 .31651 .39175 .32653 .40712 .32112 .39792 .31104 Mtetra
.39792 .31104 .40712 .32112 .42257 .31567 .41343 .30554 Mtetra
.41343 .30554 .42257 .31567 .43811 .31019 .42902 .3 Mtetra
.42902 .3 .43811 .31019 .45374 .30469 .44471 .29443 Mtetra
.44471 .29443 .45374 .30469 .46947 .29915 .4605 .28883 Mtetra
.4605 .28883 .46947 .29915 .48528 .29357 .47637 .2832 Mtetra
.47637 .2832 .48528 .29357 .50119 .28797 .49233 .27753 Mtetra
.49233 .27753 .50119 .28797 .51719 .28233 .50839 .27183 Mtetra
.50839 .27183 .51719 .28233 .53328 .27666 .52455 .2661 Mtetra
.52455 .2661 .53328 .27666 .54947 .27095 .5408 .26033 Mtetra
.5408 .26033 .54947 .27095 .56575 .26522 .55715 .25453 Mtetra
.55715 .25453 .56575 .26522 .58213 .25944 .57359 .2487 Mtetra
.57359 .2487 .58213 .25944 .59861 .25364 .59013 .24283 Mtetra
.59013 .24283 .59861 .25364 .61518 .2478 .60677 .23692 Mtetra
.60677 .23692 .61518 .2478 .63185 .24192 .62351 .23098 Mtetra
.62351 .23098 .63185 .24192 .64863 .23601 .64035 .225 Mtetra
.64035 .225 .64863 .23601 .6655 .23006 .6573 .21899 Mtetra
.6573 .21899 .6655 .23006 .68248 .22408 .67434 .21294 Mtetra
.67434 .21294 .68248 .22408 .69955 .21806 .69149 .20686 Mtetra
.69149 .20686 .69955 .21806 .71674 .21201 .70874 .20073 Mtetra
.70874 .20073 .71674 .21201 .73402 .20592 .7261 .19457 Mtetra
.7261 .19457 .73402 .20592 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Mtetra
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.1655 .38059 .17555 .38995 .1898 .3849 .17979 .37549 Mtetra
.17979 .37549 .1898 .3849 .20413 .37981 .19417 .37035 Mtetra
.19417 .37035 .20413 .37981 .21853 .3747 .20862 .36518 Mtetra
.20862 .36518 .21853 .3747 .23302 .36955 .22316 .35999 Mtetra
.22316 .35999 .23302 .36955 .2476 .36438 .23778 .35476 Mtetra
.23778 .35476 .2476 .36438 .26225 .35918 .25248 .34951 Mtetra
.25248 .34951 .26225 .35918 .27698 .35396 .26726 .34422 Mtetra
.26726 .34422 .27698 .35396 .2918 .3487 .28213 .33891 Mtetra
.28213 .33891 .2918 .3487 .3067 .34341 .29708 .33357 Mtetra
.29708 .33357 .3067 .34341 .32169 .33809 .31212 .32819 Mtetra
.31212 .32819 .32169 .33809 .33676 .33274 .32725 .32279 Mtetra
.32725 .32279 .33676 .33274 .35192 .32736 .34246 .31735 Mtetra
.34246 .31735 .35192 .32736 .36716 .32195 .35775 .31188 Mtetra
.35775 .31188 .36716 .32195 .3825 .31651 .37314 .30638 Mtetra
.37314 .30638 .3825 .31651 .39792 .31104 .38862 .30085 Mtetra
.38862 .30085 .39792 .31104 .41343 .30554 .40418 .29529 Mtetra
.40418 .29529 .41343 .30554 .42902 .3 .41984 .2897 Mtetra
.41984 .2897 .42902 .3 .44471 .29443 .43559 .28407 Mtetra
.43559 .28407 .44471 .29443 .4605 .28883 .45143 .27841 Mtetra
.45143 .27841 .4605 .28883 .47637 .2832 .46736 .27271 Mtetra
.46736 .27271 .47637 .2832 .49233 .27753 .48338 .26698 Mtetra
.48338 .26698 .49233 .27753 .50839 .27183 .49951 .26122 Mtetra
.49951 .26122 .50839 .27183 .52455 .2661 .51572 .25543 Mtetra
.51572 .25543 .52455 .2661 .5408 .26033 .53204 .2496 Mtetra
.53204 .2496 .5408 .26033 .55715 .25453 .54845 .24373 Mtetra
.54845 .24373 .55715 .25453 .57359 .2487 .56495 .23783 Mtetra
.56495 .23783 .57359 .2487 .59013 .24283 .58156 .2319 Mtetra
.58156 .2319 .59013 .24283 .60677 .23692 .59827 .22593 Mtetra
.59827 .22593 .60677 .23692 .62351 .23098 .61508 .21992 Mtetra
.61508 .21992 .62351 .23098 .64035 .225 .63199 .21388 Mtetra
.63199 .21388 .64035 .225 .6573 .21899 .649 .2078 Mtetra
.649 .2078 .6573 .21899 .67434 .21294 .66611 .20168 Mtetra
.66611 .20168 .67434 .21294 .69149 .20686 .68334 .19552 Mtetra
.68334 .19552 .69149 .20686 .70874 .20073 .70066 .18933 Mtetra
.70066 .18933 .70874 .20073 .7261 .19457 .71809 .1831 Mtetra
.71809 .1831 .7261 .19457 .74357 .18838 .73563 .17683 Mtetra
.73563 .17683 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.15534 .37114 .1655 .38059 .17979 .37549 .16968 .36598 Mtetra
.16968 .36598 .17979 .37549 .19417 .37035 .1841 .36079 Mtetra
.1841 .36079 .19417 .37035 .20862 .36518 .19861 .35557 Mtetra
.19861 .35557 .20862 .36518 .22316 .35999 .21319 .35032 Mtetra
.21319 .35032 .22316 .35999 .23778 .35476 .22786 .34504 Mtetra
.22786 .34504 .23778 .35476 .25248 .34951 .24261 .33973 Mtetra
.24261 .33973 .25248 .34951 .26726 .34422 .25744 .33439 Mtetra
.25744 .33439 .26726 .34422 .28213 .33891 .27236 .32902 Mtetra
.27236 .32902 .28213 .33891 .29708 .33357 .28736 .32362 Mtetra
.28736 .32362 .29708 .33357 .31212 .32819 .30245 .31819 Mtetra
.30245 .31819 .31212 .32819 .32725 .32279 .31763 .31273 Mtetra
.31763 .31273 .32725 .32279 .34246 .31735 .33289 .30723 Mtetra
.33289 .30723 .34246 .31735 .35775 .31188 .34825 .30171 Mtetra
.34825 .30171 .35775 .31188 .37314 .30638 .36369 .29615 Mtetra
.36369 .29615 .37314 .30638 .38862 .30085 .37922 .29056 Mtetra
.37922 .29056 .38862 .30085 .40418 .29529 .39484 .28494 Mtetra
.39484 .28494 .40418 .29529 .41984 .2897 .41055 .27928 Mtetra
.41055 .27928 .41984 .2897 .43559 .28407 .42636 .27359 Mtetra
.42636 .27359 .43559 .28407 .45143 .27841 .44226 .26787 Mtetra
.44226 .26787 .45143 .27841 .46736 .27271 .45825 .26211 Mtetra
.45825 .26211 .46736 .27271 .48338 .26698 .47434 .25632 Mtetra
.47434 .25632 .48338 .26698 .49951 .26122 .49052 .2505 Mtetra
.49052 .2505 .49951 .26122 .51572 .25543 .5068 .24464 Mtetra
.5068 .24464 .51572 .25543 .53204 .2496 .52318 .23874 Mtetra
.52318 .23874 .53204 .2496 .54845 .24373 .53965 .23281 Mtetra
.53965 .23281 .54845 .24373 .56495 .23783 .55622 .22685 Mtetra
.55622 .22685 .56495 .23783 .58156 .2319 .5729 .22085 Mtetra
.5729 .22085 .58156 .2319 .59827 .22593 .58967 .21481 Mtetra
.58967 .21481 .59827 .22593 .61508 .21992 .60655 .20873 Mtetra
.60655 .20873 .61508 .21992 .63199 .21388 .62353 .20262 Mtetra
.62353 .20262 .63199 .21388 .649 .2078 .64061 .19647 Mtetra
.64061 .19647 .649 .2078 .66611 .20168 .6578 .19029 Mtetra
.6578 .19029 .66611 .20168 .68334 .19552 .67509 .18406 Mtetra
.67509 .18406 .68334 .19552 .70066 .18933 .69249 .1778 Mtetra
.69249 .1778 .70066 .18933 .71809 .1831 .70999 .1715 Mtetra
.70999 .1715 .71809 .1831 .73563 .17683 .72761 .16516 Mtetra
.72761 .16516 .73563 .17683 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.14508 .36159 .15534 .37114 .16968 .36598 .15947 .35637 Mtetra
.15947 .35637 .16968 .36598 .1841 .36079 .17394 .35113 Mtetra
.17394 .35113 .1841 .36079 .19861 .35557 .18849 .34585 Mtetra
.18849 .34585 .19861 .35557 .21319 .35032 .20312 .34055 Mtetra
.20312 .34055 .21319 .35032 .22786 .34504 .21783 .33521 Mtetra
.21783 .33521 .22786 .34504 .24261 .33973 .23263 .32985 Mtetra
.23263 .32985 .24261 .33973 .25744 .33439 .24752 .32445 Mtetra
.24752 .32445 .25744 .33439 .27236 .32902 .26248 .31903 Mtetra
.26248 .31903 .27236 .32902 .28736 .32362 .27754 .31357 Mtetra
.27754 .31357 .28736 .32362 .30245 .31819 .29268 .30808 Mtetra
.29268 .30808 .30245 .31819 .31763 .31273 .30791 .30256 Mtetra
.30791 .30256 .31763 .31273 .33289 .30723 .32323 .29701 Mtetra
.32323 .29701 .33289 .30723 .34825 .30171 .33863 .29142 Mtetra
.33863 .29142 .34825 .30171 .36369 .29615 .35413 .2858 Mtetra
.35413 .2858 .36369 .29615 .37922 .29056 .36972 .28015 Mtetra
.36972 .28015 .37922 .29056 .39484 .28494 .3854 .27447 Mtetra
.3854 .27447 .39484 .28494 .41055 .27928 .40117 .26875 Mtetra
.40117 .26875 .41055 .27928 .42636 .27359 .41703 .263 Mtetra
.41703 .263 .42636 .27359 .44226 .26787 .43299 .25721 Mtetra
.43299 .25721 .44226 .26787 .45825 .26211 .44904 .25139 Mtetra
.44904 .25139 .45825 .26211 .47434 .25632 .46519 .24554 Mtetra
.46519 .24554 .47434 .25632 .49052 .2505 .48143 .23965 Mtetra
.48143 .23965 .49052 .2505 .5068 .24464 .49778 .23373 Mtetra
.49778 .23373 .5068 .24464 .52318 .23874 .51422 .22777 Mtetra
.51422 .22777 .52318 .23874 .53965 .23281 .53076 .22177 Mtetra
.53076 .22177 .53965 .23281 .55622 .22685 .5474 .21574 Mtetra
.5474 .21574 .55622 .22685 .5729 .22085 .56414 .20967 Mtetra
.56414 .20967 .5729 .22085 .58967 .21481 .58098 .20357 Mtetra
.58098 .20357 .58967 .21481 .60655 .20873 .59792 .19742 Mtetra
.59792 .19742 .60655 .20873 .62353 .20262 .61497 .19124 Mtetra
.61497 .19124 .62353 .20262 .64061 .19647 .63212 .18502 Mtetra
.63212 .18502 .64061 .19647 .6578 .19029 .64938 .17877 Mtetra
.64938 .17877 .6578 .19029 .67509 .18406 .66675 .17247 Mtetra
.66675 .17247 .67509 .18406 .69249 .1778 .68422 .16614 Mtetra
.68422 .16614 .69249 .1778 .70999 .1715 .7018 .15976 Mtetra
.7018 .15976 .70999 .1715 .72761 .16516 .71949 .15335 Mtetra
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Mtetra
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.13472 .35194 .14508 .36159 .15947 .35637 .14915 .34667 Mtetra
.14915 .34667 .15947 .35637 .17394 .35113 .16366 .34137 Mtetra
.16366 .34137 .17394 .35113 .18849 .34585 .17826 .33604 Mtetra
.17826 .33604 .18849 .34585 .20312 .34055 .19294 .33068 Mtetra
.19294 .33068 .20312 .34055 .21783 .33521 .2077 .32529 Mtetra
.2077 .32529 .21783 .33521 .23263 .32985 .22255 .31986 Mtetra
.22255 .31986 .23263 .32985 .24752 .32445 .23748 .31441 Mtetra
.23748 .31441 .24752 .32445 .26248 .31903 .2525 .30893 Mtetra
.2525 .30893 .26248 .31903 .27754 .31357 .26761 .30341 Mtetra
.26761 .30341 .27754 .31357 .29268 .30808 .2828 .29786 Mtetra
.2828 .29786 .29268 .30808 .30791 .30256 .29809 .29228 Mtetra
.29809 .29228 .30791 .30256 .32323 .29701 .31346 .28667 Mtetra
.31346 .28667 .32323 .29701 .33863 .29142 .32892 .28102 Mtetra
.32892 .28102 .33863 .29142 .35413 .2858 .34447 .27534 Mtetra
.34447 .27534 .35413 .2858 .36972 .28015 .36011 .26963 Mtetra
.36011 .26963 .36972 .28015 .3854 .27447 .37585 .26389 Mtetra
.37585 .26389 .3854 .27447 .40117 .26875 .39168 .25811 Mtetra
.39168 .25811 .40117 .26875 .41703 .263 .4076 .25229 Mtetra
.4076 .25229 .41703 .263 .43299 .25721 .42362 .24644 Mtetra
.42362 .24644 .43299 .25721 .44904 .25139 .43973 .24056 Mtetra
.43973 .24056 .44904 .25139 .46519 .24554 .45594 .23464 Mtetra
.45594 .23464 .46519 .24554 .48143 .23965 .47225 .22869 Mtetra
.47225 .22869 .48143 .23965 .49778 .23373 .48865 .2227 Mtetra
.48865 .2227 .49778 .23373 .51422 .22777 .50516 .21667 Mtetra
.50516 .21667 .51422 .22777 .53076 .22177 .52176 .21061 Mtetra
.52176 .21061 .53076 .22177 .5474 .21574 .53847 .20451 Mtetra
.53847 .20451 .5474 .21574 .56414 .20967 .55527 .19837 Mtetra
.55527 .19837 .56414 .20967 .58098 .20357 .57218 .1922 Mtetra
.57218 .1922 .58098 .20357 .59792 .19742 .5892 .18598 Mtetra
.5892 .18598 .59792 .19742 .61497 .19124 .60632 .17973 Mtetra
.60632 .17973 .61497 .19124 .63212 .18502 .62354 .17344 Mtetra
.62354 .17344 .63212 .18502 .64938 .17877 .64087 .16711 Mtetra
.64087 .16711 .64938 .17877 .66675 .17247 .65831 .16075 Mtetra
.65831 .16075 .66675 .17247 .68422 .16614 .67586 .15434 Mtetra
.67586 .15434 .68422 .16614 .7018 .15976 .69351 .14789 Mtetra
.69351 .14789 .7018 .15976 .71949 .15335 .71128 .14141 Mtetra
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Mtetra
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Mtetra
.12424 .34218 .13472 .35194 .14915 .34667 .13872 .33686 Mtetra
.13872 .33686 .14915 .34667 .16366 .34137 .15328 .3315 Mtetra
.15328 .3315 .16366 .34137 .17826 .33604 .16793 .32612 Mtetra
.16793 .32612 .17826 .33604 .19294 .33068 .18265 .3207 Mtetra
.18265 .3207 .19294 .33068 .2077 .32529 .19747 .31525 Mtetra
.19747 .31525 .2077 .32529 .22255 .31986 .21236 .30977 Mtetra
.21236 .30977 .22255 .31986 .23748 .31441 .22735 .30426 Mtetra
.22735 .30426 .23748 .31441 .2525 .30893 .24242 .29872 Mtetra
.24242 .29872 .2525 .30893 .26761 .30341 .25758 .29314 Mtetra
.25758 .29314 .26761 .30341 .2828 .29786 .27282 .28753 Mtetra
.27282 .28753 .2828 .29786 .29809 .29228 .28816 .28189 Mtetra
.28816 .28189 .29809 .29228 .31346 .28667 .30358 .27622 Mtetra
.30358 .27622 .31346 .28667 .32892 .28102 .3191 .27051 Mtetra
.3191 .27051 .32892 .28102 .34447 .27534 .33471 .26477 Mtetra
.33471 .26477 .34447 .27534 .36011 .26963 .35041 .259 Mtetra
.35041 .259 .36011 .26963 .37585 .26389 .3662 .25319 Mtetra
.3662 .25319 .37585 .26389 .39168 .25811 .38209 .24735 Mtetra
.38209 .24735 .39168 .25811 .4076 .25229 .39807 .24147 Mtetra
.39807 .24147 .4076 .25229 .42362 .24644 .41415 .23555 Mtetra
.41415 .23555 .42362 .24644 .43973 .24056 .43032 .22961 Mtetra
.43032 .22961 .43973 .24056 .45594 .23464 .44659 .22362 Mtetra
.44659 .22362 .45594 .23464 .47225 .22869 .46296 .2176 Mtetra
.46296 .2176 .47225 .22869 .48865 .2227 .47943 .21154 Mtetra
.47943 .21154 .48865 .2227 .50516 .21667 .496 .20545 Mtetra
.496 .20545 .50516 .21667 .52176 .21061 .51267 .19932 Mtetra
.51267 .19932 .52176 .21061 .53847 .20451 .52944 .19315 Mtetra
.52944 .19315 .53847 .20451 .55527 .19837 .54631 .18694 Mtetra
.54631 .18694 .55527 .19837 .57218 .1922 .56329 .1807 Mtetra
.56329 .1807 .57218 .1922 .5892 .18598 .58037 .17441 Mtetra
.58037 .17441 .5892 .18598 .60632 .17973 .59756 .16809 Mtetra
.59756 .16809 .60632 .17973 .62354 .17344 .61486 .16173 Mtetra
.61486 .16173 .62354 .17344 .64087 .16711 .63226 .15533 Mtetra
.63226 .15533 .64087 .16711 .65831 .16075 .64977 .14889 Mtetra
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Mtetra
.6674 .14241 .67586 .15434 .69351 .14789 .68513 .13588 Mtetra
.68513 .13588 .69351 .14789 .71128 .14141 .70297 .12932 Mtetra
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.11366 .33233 .12424 .34218 .13872 .33686 .12818 .32695 Mtetra
.12818 .32695 .13872 .33686 .15328 .3315 .14279 .32154 Mtetra
.14279 .32154 .15328 .3315 .16793 .32612 .15748 .31609 Mtetra
.15748 .31609 .16793 .32612 .18265 .3207 .17226 .31062 Mtetra
.17226 .31062 .18265 .3207 .19747 .31525 .18712 .30511 Mtetra
.18712 .30511 .19747 .31525 .21236 .30977 .20207 .29957 Mtetra
.20207 .29957 .21236 .30977 .22735 .30426 .2171 .294 Mtetra
.2171 .294 .22735 .30426 .24242 .29872 .23222 .2884 Mtetra
.23222 .2884 .24242 .29872 .25758 .29314 .24743 .28276 Mtetra
.24743 .28276 .25758 .29314 .27282 .28753 .26273 .2771 Mtetra
.26273 .2771 .27282 .28753 .28816 .28189 .27812 .27139 Mtetra
.27812 .27139 .28816 .28189 .30358 .27622 .2936 .26566 Mtetra
.2936 .26566 .30358 .27622 .3191 .27051 .30917 .25989 Mtetra
.30917 .25989 .3191 .27051 .33471 .26477 .32484 .25409 Mtetra
.32484 .25409 .33471 .26477 .35041 .259 .34059 .24825 Mtetra
.34059 .24825 .35041 .259 .3662 .25319 .35644 .24237 Mtetra
.35644 .24237 .3662 .25319 .38209 .24735 .37239 .23647 Mtetra
.37239 .23647 .38209 .24735 .39807 .24147 .38843 .23052 Mtetra
.38843 .23052 .39807 .24147 .41415 .23555 .40457 .22454 Mtetra
.40457 .22454 .41415 .23555 .43032 .22961 .4208 .21853 Mtetra
.4208 .21853 .43032 .22961 .44659 .22362 .43714 .21248 Mtetra
.43714 .21248 .44659 .22362 .46296 .2176 .45357 .20639 Mtetra
.45357 .20639 .46296 .2176 .47943 .21154 .4701 .20026 Mtetra
.4701 .20026 .47943 .21154 .496 .20545 .48673 .1941 Mtetra
.48673 .1941 .496 .20545 .51267 .19932 .50347 .1879 Mtetra
.50347 .1879 .51267 .19932 .52944 .19315 .52031 .18166 Mtetra
.52031 .18166 .52944 .19315 .54631 .18694 .53725 .17538 Mtetra
.53725 .17538 .54631 .18694 .56329 .1807 .5543 .16907 Mtetra
.5543 .16907 .56329 .1807 .58037 .17441 .57145 .16271 Mtetra
.57145 .16271 .58037 .17441 .59756 .16809 .58871 .15632 Mtetra
.58871 .15632 .59756 .16809 .61486 .16173 .60608 .14988 Mtetra
.60608 .14988 .61486 .16173 .63226 .15533 .62355 .14341 Mtetra
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Mtetra
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Mtetra
.65884 .13033 .6674 .14241 .68513 .13588 .67665 .12373 Mtetra
.67665 .12373 .68513 .13588 .70297 .12932 .69457 .11709 Mtetra
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.10296 .32237 .11366 .33233 .12818 .32695 .11753 .31693 Mtetra
.11753 .31693 .12818 .32695 .14279 .32154 .13219 .31146 Mtetra
.13219 .31146 .14279 .32154 .15748 .31609 .14693 .30596 Mtetra
.14693 .30596 .15748 .31609 .17226 .31062 .16175 .30043 Mtetra
.16175 .30043 .17226 .31062 .18712 .30511 .17666 .29486 Mtetra
.17666 .29486 .18712 .30511 .20207 .29957 .19166 .28926 Mtetra
.19166 .28926 .20207 .29957 .2171 .294 .20674 .28363 Mtetra
.20674 .28363 .2171 .294 .23222 .2884 .22192 .27797 Mtetra
.22192 .27797 .23222 .2884 .24743 .28276 .23718 .27227 Mtetra
.23718 .27227 .24743 .28276 .26273 .2771 .25253 .26654 Mtetra
.25253 .26654 .26273 .2771 .27812 .27139 .26797 .26078 Mtetra
.26797 .26078 .27812 .27139 .2936 .26566 .28351 .25498 Mtetra
.28351 .25498 .2936 .26566 .30917 .25989 .29914 .24915 Mtetra
.29914 .24915 .30917 .25989 .32484 .25409 .31485 .24328 Mtetra
.31485 .24328 .32484 .25409 .34059 .24825 .33067 .23738 Mtetra
.33067 .23738 .34059 .24825 .35644 .24237 .34658 .23144 Mtetra
.34658 .23144 .35644 .24237 .37239 .23647 .36258 .22547 Mtetra
.36258 .22547 .37239 .23647 .38843 .23052 .37868 .21946 Mtetra
.37868 .21946 .38843 .23052 .40457 .22454 .39488 .21341 Mtetra
.39488 .21341 .40457 .22454 .4208 .21853 .41118 .20733 Mtetra
.41118 .20733 .4208 .21853 .43714 .21248 .42757 .20121 Mtetra
.42757 .20121 .43714 .21248 .45357 .20639 .44407 .19505 Mtetra
.44407 .19505 .45357 .20639 .4701 .20026 .46067 .18886 Mtetra
.46067 .18886 .4701 .20026 .48673 .1941 .47737 .18262 Mtetra
.47737 .18262 .48673 .1941 .50347 .1879 .49417 .17635 Mtetra
.49417 .17635 .50347 .1879 .52031 .18166 .51107 .17004 Mtetra
.51107 .17004 .52031 .18166 .53725 .17538 .52808 .16369 Mtetra
.52808 .16369 .53725 .17538 .5543 .16907 .5452 .1573 Mtetra
.5452 .1573 .5543 .16907 .57145 .16271 .56242 .15087 Mtetra
.56242 .15087 .57145 .16271 .58871 .15632 .57976 .1444 Mtetra
.57976 .1444 .58871 .15632 .60608 .14988 .5972 .1379 Mtetra
.5972 .1379 .60608 .14988 .62355 .14341 .61475 .13134 Mtetra
.61475 .13134 .62355 .14341 .64114 .13689 .63241 .12475 Mtetra
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Mtetra
.65018 .11812 .65884 .13033 .67665 .12373 .66806 .11144 Mtetra
.66806 .11144 .67665 .12373 .69457 .11709 .68606 .10472 Mtetra
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Mtetra
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.09215 .3123 .10296 .32237 .11753 .31693 .10677 .30681 Mtetra
.10677 .30681 .11753 .31693 .13219 .31146 .12147 .30128 Mtetra
.12147 .30128 .13219 .31146 .14693 .30596 .13626 .29572 Mtetra
.13626 .29572 .14693 .30596 .16175 .30043 .15113 .29013 Mtetra
.15113 .29013 .16175 .30043 .17666 .29486 .16609 .2845 Mtetra
.16609 .2845 .17666 .29486 .19166 .28926 .18114 .27884 Mtetra
.18114 .27884 .19166 .28926 .20674 .28363 .19627 .27315 Mtetra
.19627 .27315 .20674 .28363 .22192 .27797 .2115 .26743 Mtetra
.2115 .26743 .22192 .27797 .23718 .27227 .22681 .26167 Mtetra
.22681 .26167 .23718 .27227 .25253 .26654 .24222 .25587 Mtetra
.24222 .25587 .25253 .26654 .26797 .26078 .25772 .25005 Mtetra
.25772 .25005 .26797 .26078 .28351 .25498 .27331 .24418 Mtetra
.27331 .24418 .28351 .25498 .29914 .24915 .28899 .23829 Mtetra
.28899 .23829 .29914 .24915 .31485 .24328 .30476 .23236 Mtetra
.30476 .23236 .31485 .24328 .33067 .23738 .32064 .22639 Mtetra
.32064 .22639 .33067 .23738 .34658 .23144 .3366 .22038 Mtetra
.3366 .22038 .34658 .23144 .36258 .22547 .35267 .21434 Mtetra
.35267 .21434 .36258 .22547 .37868 .21946 .36883 .20827 Mtetra
.36883 .20827 .37868 .21946 .39488 .21341 .38509 .20215 Mtetra
.38509 .20215 .39488 .21341 .41118 .20733 .40145 .196 Mtetra
.40145 .196 .41118 .20733 .42757 .20121 .4179 .18981 Mtetra
.4179 .18981 .42757 .20121 .44407 .19505 .43446 .18358 Mtetra
.43446 .18358 .44407 .19505 .46067 .18886 .45113 .17732 Mtetra
.45113 .17732 .46067 .18886 .47737 .18262 .46789 .17101 Mtetra
.46789 .17101 .47737 .18262 .49417 .17635 .48476 .16467 Mtetra
.48476 .16467 .49417 .17635 .51107 .17004 .50173 .15829 Mtetra
.50173 .15829 .51107 .17004 .52808 .16369 .51881 .15187 Mtetra
.51881 .15187 .52808 .16369 .5452 .1573 .536 .1454 Mtetra
.536 .1454 .5452 .1573 .56242 .15087 .55329 .1389 Mtetra
.55329 .1389 .56242 .15087 .57976 .1444 .5707 .13236 Mtetra
.5707 .13236 .57976 .1444 .5972 .1379 .58821 .12577 Mtetra
.58821 .12577 .5972 .1379 .61475 .13134 .60583 .11914 Mtetra
.60583 .11914 .61475 .13134 .63241 .12475 .62357 .11247 Mtetra
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Mtetra
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Mtetra
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Mtetra
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Mtetra
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.08123 .30213 .09215 .3123 .10677 .30681 .09589 .29658 Mtetra
.09589 .29658 .10677 .30681 .12147 .30128 .11064 .29099 Mtetra
.11064 .29099 .12147 .30128 .13626 .29572 .12548 .28537 Mtetra
.12548 .28537 .13626 .29572 .15113 .29013 .1404 .27972 Mtetra
.1404 .27972 .15113 .29013 .16609 .2845 .15541 .27403 Mtetra
.15541 .27403 .16609 .2845 .18114 .27884 .1705 .26831 Mtetra
.1705 .26831 .18114 .27884 .19627 .27315 .18569 .26256 Mtetra
.18569 .26256 .19627 .27315 .2115 .26743 .20097 .25677 Mtetra
.20097 .25677 .2115 .26743 .22681 .26167 .21634 .25095 Mtetra
.21634 .25095 .22681 .26167 .24222 .25587 .23179 .24509 Mtetra
.23179 .24509 .24222 .25587 .25772 .25005 .24735 .2392 Mtetra
.24735 .2392 .25772 .25005 .27331 .24418 .26299 .23327 Mtetra
.26299 .23327 .27331 .24418 .28899 .23829 .27873 .22731 Mtetra
.27873 .22731 .28899 .23829 .30476 .23236 .29456 .22131 Mtetra
.29456 .22131 .30476 .23236 .32064 .22639 .31049 .21527 Mtetra
.31049 .21527 .32064 .22639 .3366 .22038 .32652 .2092 Mtetra
.32652 .2092 .3366 .22038 .35267 .21434 .34264 .20309 Mtetra
.34264 .20309 .35267 .21434 .36883 .20827 .35886 .19695 Mtetra
.35886 .19695 .36883 .20827 .38509 .20215 .37518 .19077 Mtetra
.37518 .19077 .38509 .20215 .40145 .196 .3916 .18454 Mtetra
.3916 .18454 .40145 .196 .4179 .18981 .40812 .17828 Mtetra
.40812 .17828 .4179 .18981 .43446 .18358 .42475 .17199 Mtetra
.42475 .17199 .43446 .18358 .45113 .17732 .44148 .16565 Mtetra
.44148 .16565 .45113 .17732 .46789 .17101 .45831 .15927 Mtetra
.45831 .15927 .46789 .17101 .48476 .16467 .47524 .15286 Mtetra
.47524 .15286 .48476 .16467 .50173 .15829 .49228 .1464 Mtetra
.49228 .1464 .50173 .15829 .51881 .15187 .50943 .1399 Mtetra
.50943 .1399 .51881 .15187 .536 .1454 .52669 .13336 Mtetra
.52669 .13336 .536 .1454 .55329 .1389 .54406 .12679 Mtetra
.54406 .12679 .55329 .1389 .5707 .13236 .56153 .12016 Mtetra
.56153 .12016 .5707 .13236 .58821 .12577 .57912 .1135 Mtetra
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Mtetra
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Mtetra
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Mtetra
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Mtetra
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Mtetra
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Mtetra
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Mtetra
.07019 .29185 .08123 .30213 .09589 .29658 .0849 .28624 Mtetra
.0849 .28624 .09589 .29658 .11064 .29099 .09969 .28059 Mtetra
.09969 .28059 .11064 .29099 .12548 .28537 .11458 .27491 Mtetra
.11458 .27491 .12548 .28537 .1404 .27972 .12955 .26919 Mtetra
.12955 .26919 .1404 .27972 .15541 .27403 .14461 .26344 Mtetra
.14461 .26344 .15541 .27403 .1705 .26831 .15975 .25766 Mtetra
.15975 .25766 .1705 .26831 .18569 .26256 .17499 .25184 Mtetra
.17499 .25184 .18569 .26256 .20097 .25677 .19032 .24599 Mtetra
.19032 .24599 .20097 .25677 .21634 .25095 .20574 .24011 Mtetra
.20574 .24011 .21634 .25095 .23179 .24509 .22125 .23418 Mtetra
.22125 .23418 .23179 .24509 .24735 .2392 .23686 .22823 Mtetra
.23686 .22823 .24735 .2392 .26299 .23327 .25256 .22223 Mtetra
.25256 .22223 .26299 .23327 .27873 .22731 .26835 .2162 Mtetra
.26835 .2162 .27873 .22731 .29456 .22131 .28424 .21014 Mtetra
.28424 .21014 .29456 .22131 .31049 .21527 .30023 .20404 Mtetra
.30023 .20404 .31049 .21527 .32652 .2092 .31632 .1979 Mtetra
.31632 .1979 .32652 .2092 .34264 .20309 .3325 .19172 Mtetra
.3325 .19172 .34264 .20309 .35886 .19695 .34878 .1855 Mtetra
.34878 .1855 .35886 .19695 .37518 .19077 .36516 .17925 Mtetra
.36516 .17925 .37518 .19077 .3916 .18454 .38165 .17296 Mtetra
.38165 .17296 .3916 .18454 .40812 .17828 .39823 .16663 Mtetra
.39823 .16663 .40812 .17828 .42475 .17199 .41492 .16026 Mtetra
.41492 .16026 .42475 .17199 .44148 .16565 .43171 .15385 Mtetra
.43171 .15385 .44148 .16565 .45831 .15927 .44861 .1474 Mtetra
.44861 .1474 .45831 .15927 .47524 .15286 .46562 .1409 Mtetra
.46562 .1409 .47524 .15286 .49228 .1464 .48273 .13437 Mtetra
.48273 .13437 .49228 .1464 .50943 .1399 .49994 .1278 Mtetra
.49994 .1278 .50943 .1399 .52669 .13336 .51727 .12119 Mtetra
.51727 .12119 .52669 .13336 .54406 .12679 .53471 .11453 Mtetra
.53471 .11453 .54406 .12679 .56153 .12016 .55226 .10783 Mtetra
.55226 .10783 .56153 .12016 .57912 .1135 .56992 .10109 Mtetra
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Mtetra
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Mtetra
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Mtetra
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Mtetra
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Mtetra
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Mtetra
.05902 .28146 .07019 .29185 .0849 .28624 .07378 .27578 Mtetra
.07378 .27578 .0849 .28624 .09969 .28059 .08863 .27007 Mtetra
.08863 .27007 .09969 .28059 .11458 .27491 .10356 .26433 Mtetra
.10356 .26433 .11458 .27491 .12955 .26919 .11858 .25855 Mtetra
.11858 .25855 .12955 .26919 .14461 .26344 .13369 .25274 Mtetra
.13369 .25274 .14461 .26344 .15975 .25766 .14889 .24689 Mtetra
.14889 .24689 .15975 .25766 .17499 .25184 .16417 .24101 Mtetra
.16417 .24101 .17499 .25184 .19032 .24599 .17956 .2351 Mtetra
.17956 .2351 .19032 .24599 .20574 .24011 .19503 .22915 Mtetra
.19503 .22915 .20574 .24011 .22125 .23418 .2106 .22316 Mtetra
.2106 .22316 .22125 .23418 .23686 .22823 .22626 .21713 Mtetra
.22626 .21713 .23686 .22823 .25256 .22223 .24201 .21107 Mtetra
.24201 .21107 .25256 .22223 .26835 .2162 .25786 .20498 Mtetra
.25786 .20498 .26835 .2162 .28424 .21014 .27381 .19884 Mtetra
.27381 .19884 .28424 .21014 .30023 .20404 .28986 .19267 Mtetra
.28986 .19267 .30023 .20404 .31632 .1979 .306 .18646 Mtetra
.306 .18646 .31632 .1979 .3325 .19172 .32224 .18021 Mtetra
.32224 .18021 .3325 .19172 .34878 .1855 .33859 .17393 Mtetra
.33859 .17393 .34878 .1855 .36516 .17925 .35503 .1676 Mtetra
.35503 .1676 .36516 .17925 .38165 .17296 .37158 .16124 Mtetra
.37158 .16124 .38165 .17296 .39823 .16663 .38823 .15483 Mtetra
.38823 .15483 .39823 .16663 .41492 .16026 .40498 .14839 Mtetra
.40498 .14839 .41492 .16026 .43171 .15385 .42184 .14191 Mtetra
.42184 .14191 .43171 .15385 .44861 .1474 .4388 .13538 Mtetra
.4388 .13538 .44861 .1474 .46562 .1409 .45588 .12881 Mtetra
.45588 .12881 .46562 .1409 .48273 .13437 .47306 .12221 Mtetra
.47306 .12221 .48273 .13437 .49994 .1278 .49034 .11556 Mtetra
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Mtetra
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Mtetra
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Mtetra
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Mtetra
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Mtetra
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Mtetra
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Mtetra
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Mtetra
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Mtetra
.04774 .27095 .05902 .28146 .07378 .27578 .06255 .26522 Mtetra
.06255 .26522 .07378 .27578 .08863 .27007 .07744 .25944 Mtetra
.07744 .25944 .08863 .27007 .10356 .26433 .09242 .25364 Mtetra
.09242 .25364 .10356 .26433 .11858 .25855 .10749 .2478 Mtetra
.10749 .2478 .11858 .25855 .13369 .25274 .12265 .24192 Mtetra
.12265 .24192 .13369 .25274 .14889 .24689 .1379 .23601 Mtetra
.1379 .23601 .14889 .24689 .16417 .24101 .15324 .23006 Mtetra
.15324 .23006 .16417 .24101 .17956 .2351 .16867 .22408 Mtetra
.16867 .22408 .17956 .2351 .19503 .22915 .1842 .21806 Mtetra
.1842 .21806 .19503 .22915 .2106 .22316 .19982 .21201 Mtetra
.19982 .21201 .2106 .22316 .22626 .21713 .21553 .20592 Mtetra
.21553 .20592 .22626 .21713 .24201 .21107 .23135 .19979 Mtetra
.23135 .19979 .24201 .21107 .25786 .20498 .24725 .19362 Mtetra
.24725 .19362 .25786 .20498 .27381 .19884 .26326 .18742 Mtetra
.26326 .18742 .27381 .19884 .28986 .19267 .27936 .18118 Mtetra
.27936 .18118 .28986 .19267 .306 .18646 .29557 .1749 Mtetra
.29557 .1749 .306 .18646 .32224 .18021 .31187 .16858 Mtetra
.31187 .16858 .32224 .18021 .33859 .17393 .32828 .16222 Mtetra
.32828 .16222 .33859 .17393 .35503 .1676 .34478 .15582 Mtetra
.34478 .15582 .35503 .1676 .37158 .16124 .36139 .14938 Mtetra
.36139 .14938 .37158 .16124 .38823 .15483 .37811 .14291 Mtetra
.37811 .14291 .38823 .15483 .40498 .14839 .39493 .13639 Mtetra
.39493 .13639 .40498 .14839 .42184 .14191 .41185 .12983 Mtetra
.41185 .12983 .42184 .14191 .4388 .13538 .42888 .12323 Mtetra
.42888 .12323 .4388 .13538 .45588 .12881 .44602 .11658 Mtetra
.44602 .11658 .45588 .12881 .47306 .12221 .46327 .1099 Mtetra
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Mtetra
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Mtetra
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Mtetra
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Mtetra
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Mtetra
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Mtetra
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Mtetra
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Mtetra
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Mtetra
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.03634 .26033 .04774 .27095 .06255 .26522 .05119 .25453 Mtetra
.05119 .25453 .06255 .26522 .07744 .25944 .06613 .2487 Mtetra
.06613 .2487 .07744 .25944 .09242 .25364 .08116 .24283 Mtetra
.08116 .24283 .09242 .25364 .10749 .2478 .09628 .23692 Mtetra
.09628 .23692 .10749 .2478 .12265 .24192 .11148 .23098 Mtetra
.11148 .23098 .12265 .24192 .1379 .23601 .12679 .225 Mtetra
.12679 .225 .1379 .23601 .15324 .23006 .14218 .21899 Mtetra
.14218 .21899 .15324 .23006 .16867 .22408 .15767 .21294 Mtetra
.15767 .21294 .16867 .22408 .1842 .21806 .17325 .20686 Mtetra
.17325 .20686 .1842 .21806 .19982 .21201 .18892 .20073 Mtetra
.18892 .20073 .19982 .21201 .21553 .20592 .20469 .19457 Mtetra
.20469 .19457 .21553 .20592 .23135 .19979 .22056 .18838 Mtetra
.22056 .18838 .23135 .19979 .24725 .19362 .23652 .18214 Mtetra
.23652 .18214 .24725 .19362 .26326 .18742 .25259 .17587 Mtetra
.25259 .17587 .26326 .18742 .27936 .18118 .26875 .16955 Mtetra
.26875 .16955 .27936 .18118 .29557 .1749 .28501 .1632 Mtetra
.28501 .1632 .29557 .1749 .31187 .16858 .30138 .15681 Mtetra
.30138 .15681 .31187 .16858 .32828 .16222 .31785 .15038 Mtetra
.31785 .15038 .32828 .16222 .34478 .15582 .33442 .14391 Mtetra
.33442 .14391 .34478 .15582 .36139 .14938 .35109 .13739 Mtetra
.35109 .13739 .36139 .14938 .37811 .14291 .36787 .13084 Mtetra
.36787 .13084 .37811 .14291 .39493 .13639 .38475 .12424 Mtetra
.38475 .12424 .39493 .13639 .41185 .12983 .40174 .11761 Mtetra
.40174 .11761 .41185 .12983 .42888 .12323 .41884 .11093 Mtetra
.41884 .11093 .42888 .12323 .44602 .11658 .43605 .10421 Mtetra
.43605 .10421 .44602 .11658 .46327 .1099 .45337 .09744 Mtetra
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Mtetra
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Mtetra
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Mtetra
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Mtetra
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Mtetra
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Mtetra
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Mtetra
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Mtetra
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Mtetra
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`006_oooonDo`0003?oooooU?l0000Kooooo`006_oo
ool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0T?oo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Iooooo`006_ooool01_l0
003oooooooooo`00003ooooo000000Cooooo0_l00005000008;ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo01Wooooo000Jooooo`04o`000?oooooo
oooo01TI6@800000101<C4`4o`000080000000<06ATI000000000000OOl00003ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`03o`000?oooooooooo00@000000P1<C4`2o`00000407moOol0003o0000o`00008000000P0I
6AT00`00003o0000o`00001jo`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool00_l00003
00000003o`00001VIVKo000000<0Ogmo0_l000030000000301TI6@00003o000007[o00000oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`02o`0000060000000I6AT00000o`00001VIVKo0000101o
Ogl2o`000080<c<c0P00001ko`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool00ol00003
000000;o00000`1oOgl5o`00000403<c<`0000000000000007Wo00000oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0ol0003oooooooooo`05o`00008000000_l0000207moO`03o`00002IVIWo000000?o000000@00000
o`00000I6AT00000N?l00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl0
0003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Co000000@00000
01TI6@00000000000ol0000309VIV@Go000000<0000001TI6@000000Mol00003ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`03o`000?oooooooooo00Go000000@0000001TI6Ol0000000000ol0000209VIV@Ko000000<0
000001TI6Ol00000M_l00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl0
0003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Ko000000@00000
01TI6@00000000000_l0000209VIV@Oo000000<0000001TI6@000000MOl00003ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`03o`000?oooooooooo00Oo000000@0000001TI6@00000000001?l000020<c<c0Ko00000P00
001do`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o
0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool02?l000000`0000006ATI00000004
o`0000<0c<c<1?l000020000000301TI6Ol0003o000007;o00000oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0
003oooooooooo`09o`0000030000000I6AT0000000Co00000P3<c<`6o`0000030000000I6AT00000
07;o00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0
003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0:o`0000<000001?l000000`3<c<co
00000>KViP06o`00000301TI6@00003o0000073o00000oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003ooooo
ooooo`0;o`0000<000001Ol000020>KViPKo000000<06ATI00000?l00000Kol00003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo00_o00000`000005o`0000<0i^KV1?l000020000000301TI6Ol0
003o000006ko00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0<o`0000<000001?l00003
0>KViPGo00000P0000000`0I6AT00000o`00001]o`0000?ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool03Ol00003000000Co00000P3Vi^H6o`00000400000?l000006ATI000006go00000oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`0>o`00000300000?l00000000000Ko000000<0ooooo`00
0?l000001?l00003000006co00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0?o`0000<0
00001_l000000`3ooooo0000o`000004o`0000800000K?l00003ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`00
0?oooooooooo013o000010000005o`000080oooo1Ol000000`00003o00000000001Zo`0000?ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00?o0000ooooooooool04_l000000`00003o000000000005o`000080oooo1Ol0
0003000006Wo00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Bo`0000040000000I6AT0
0000000000Co00000P3oool3o`0000050;>c/ol0003o00000000000I6AT0JOl00003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo01?o000000<0000001TI6@0000001Ol000020?ooo`?o000000H0
/k>co`0000000000000001TI6@00001Wo`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0
5?l000000`0000006ATI00000005o`000080oooo1Ol000001000003o000001TI6@00001Vo`0000?o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00?o0000ooooooooool05ol000000`00003o0000o`00000;o`0000030000
000I6AT0000006Go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go0000
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Fo`0000<000001Ol0
00030>KViP;o000000D0VIVIo`00000c<c<0000001TI6@1Uo`0000?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o
0000ooooooooool05ol00003000000Go00000P3Vi^H5o`00000303<c<`000000000006Co00000ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00ol0003oooooooooo`0Ho`0000<000001Ol000020>KViPCo000000@00000
03<c<ol000000000Hol00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl0
0003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo01Wo000000<00000
o`00000000001ol000000`3<c<co0000o`000002o`0000030000000I6AT0000006;o00000oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`0Jo`0000030000000I6AT0000000Ko000000<0c<c<o`00
0?l000000ol000000`0000006ATIo`00001Qo`0000?ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooooooo
ool06ol00000100000006ATI000000000006o`0000040;>c/ol0003o0000o`000080000000<06ATI
00000?l00000Gol00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo01go000000<06ATIo`00
000000002ol000000`00003o00000000001Oo`0000?ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooooooo
ool07Ol00000100000006ATI000000000005o`000080VIVI0_l000001@1<C4`0000001TI6@0I6AT0
000005ko00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool0
0ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0No`0000040000000I6AT00000
000000?o0000102IVIT2o`00008000000P0I6AT00`00003o0000o`00001Ko`0000?ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00?o0000ooooooooool07ol00000100000006ATI000000000003o`0000<0VIVI0ol00002
0000000301TI6@00003o000005co00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Qo`00
00030000000I6AT0000000Co000000<0VIVIo`000?l000000_l000001000003o000000000000001L
o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000
ooooooooool06Oooool001[ooooo00?o0000ooooooooool08_l0000200000003o`000000003o0000
00;o00000P1oOgl00ol00000IVIVo`0000020000000301TI6@00003o000005[o00000oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Ioooo
o`006_ooool00ol0003oooooooooo`0So`0000@000001?l000000`1oOgoo000006IVIP02o`000003
0000000I6AT0000005[o00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go
00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0To`0000040000
000I6AT06ATI000000;o000000<0IVIVo`000?l000000ol000020000000301TI6@00003o000005So
00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Uo`0000050000000I6AT00000o`000000
00001?l0000204a<C0040000000c<c<00000000005Wo00000oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003o
ooooooooo`0Vo`0000030000000I6AT000000080000000?o000004a<C01<C4`00`1<C4`010000000
<c<c00000000001Ho`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`00
00?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool09ol000000`000000
6ATI01TI6@02000000D0C4a<00D0000003<c<`0000006ATI0000001Go`0000?ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[o
oooo00?o0000ooooooooool0:Ol000001@0000006ATI00000?l00000000000<0C4a<0`00000201TI
6@0300000?l0003o000005Co00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Yo`000008
0000000I6AWo00000000000c<c<0000004a<C000000203<c<`040000000I6AT06ATI000005Ko0000
0oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Zo`0000030000000I6AT06ATI00<00000100c
<c<0100000006ATI01TI6@00001Eo`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0:ol0
0002000000806ATI00<0000003<c<`0c<c<00`0c<c<00`0000006ATI0000001Eo`0000?ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00?o0000ooooooooool0;Ol000001@0000006ATI01TI6Ol00000000000<0<c<c0P00
00000`0I6AT000000000001Co`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0;_l00000
1`0000006ATI01TI6@0I6AT0000003<c<`0000001@0I6AT00`00003o0000o`00001@o`0000?ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00?o0000ooooooooool0;ol000030000000301TI6@0000006ATI00D06ATI00<0
0000o`000?l00000D?l00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl0
0003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo03?o00001`0I6AT0
0`00003o0000o`00001@o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=
o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0<ol000020000
00D06ATI00<00000o`000?l00000D?l00003ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo03Go
000000<0000001TI6@0I6AT00`0I6AT00`00003o0000o`00001?o`0000?ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo
00?o0000ooooooooool0=ol0000401TI6@0300000?l0003o000004oo00000oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00ol0003oooooooooo`0go`0000<0000000<06ATI000000000000D?l00003ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`03o`000?oooooooooo03[o000000<00000o`000?l00000D?l00003ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oo
oooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go
00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o
0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl0
0003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooooooo
ool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003o
ooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?o
oooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo03Wo00002`000019o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000
ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0>?l00000
0`0000006ATI01TI6@0901TI6@@00000AOl00003ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
03Oo000000<0000001TI6@0I6AT03P0I6AT3000004;o00000oooool00ol0003oooooooooo`0Ioooo
o`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0go`0000030000000I6AT06ATI01406ATI0`00000oo`0000?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0=_l000000`0000006ATI01TI6@0401TI6@_o00001P0I6AT00`00003o0000
o`00000lo`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl0
0003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0=ol0000501TI6@03o`00000c
<c<0<c<c00T0<c<c1?l0000301TI6@@00000>_l00003ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo03Ko000000<0000001TI6@0I6AT00`0I6AT00ol00000<c<c03<c<`0403<c<`Go0000100c<c<2
o`0000D06ATI0P00000ho`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0=_l000000`00
00006ATI01TI6@0301TI6@03o`00000c<c<0<c<c0080<c<c0_l0000504a<C0?o00000`0c<c<00ol0
00006ATI01TI6@0401TI6@800000=_l00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Ko
000000<0000001TI6@0I6AT00`0I6AT01Ol00000<c<c03<c<`0c<c?o000000<0C4a<3_l0000501TI
6CKo00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0go`0000030000000I6AT06ATI0080
6ATI00Co000003<c<`0c<c?o00000`1<C4`00ol00000IVIV06IVIP0506IVIPKo000000@0<c<co`00
0?l0003o00000P0I6AT2000003Co00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0
003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0go`00
00030000000I6AT06ATI00806ATI00Co000003<c<`0c<c?o00000`1<C4`01?l00000IVIV06IVIP1V
IVH7o`00000306IVI_l0003o000000;o00000P0c<c<01Ol000006ATI01TI6@0I6AT0000003?o0000
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0ho`0000030000000I6AT06ATI00806ATI00Ko
000003<c<`0c<c?o000004a<C?l0000206IVIP;o00001`1oOgl00ol00000IVIV06IVIP06o`0000<0
6ATI0`00000`o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0
SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0>Ol000001@0000006ATI
01TI6@0I6AWo00000080<c<c00Go000004a<C?l00000IVIVo`00000207moOa?o00000`0I6AT`o`00
00?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0>Ol000001@0000006ATI01TI6@0I6AWo0000
0080<c<c00Go000004a<C?l00000IVIVo`00000207moO`03o`00002IVIT0VIVI0080VIVI1@000000
1Ol00000Ogmoo`000?l00000IVIV00?o000000<0<c<co`000?l000000P0I6AT2000002go00000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0jo`0000040000000I6AT06ATIo`0000<0<c<c0_l0
000206IVIP03o`00001oOgoo000000<0VIVI00<000000;>c/`2c/k<00ol00002000000Oo00000P0c
<c<01Ol000006ATI01TI6@0I6AT0000002co00000oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0jo`0000050000000I6AT06ATI01TI6Ol000000P0c<c<01ol00000C4a<o`00001VIVKo000007mo
Ool000000P2IVIT010000000/k>co`000?l000030<c<c0;o00000P000003o`00000606IVI_l0003o
0000o`00000c<c?o00000`0I6AT00`00003o0000o`00000Yo`0000?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0>ol000004@0000006ATI01TI6@0I6AWo000003<c<ol00000C4a<o`00001VIVKo
000007moOol00000VIVI0000002c/k?o000000<0c<c<0ol000000`3<c<co0000o`000002000000Ko
000000<0<c<co`000?l000000P0I6AT00`00003o0000o`00000Xo`0000?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0>ol000004@0000006ATI01TI6@0I6AWo000003<c<ol00000C4a<o`00001V
IVKo000007moOol00000VIVI0000002c/k?o000000<0c<c<00?o00000>KViP3Vi^H01Ol000001@00
003o000007moOol00000IVIV00;o00000P0c<c<01?l000006ATI01TI6@00000Yo`0000?ooooo00?o
0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0??l00000400000006ATI01TI6@0I6AWo000003<c<ol00000
C4a<o`00001VIVKo000007moOol0000000000;>c/ol000030<c<c003o`00003Vi^H0i^KV00<0i^KV
0ol000001@00003o000007moOol00000IVIV00?o000000D0<c<co`00000I6AT06ATI0000000Xo`00
00?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0?Ol00002000000806ATI00Ko000003<c<ol0
0000C4a<o`00001VIVH2o`00000609VIV@000000/k>co`00003<c<co00000`3Vi^H3o`000080i^KV
0_l000002P00003o000000000?l00000IVIVo`00001<C4co000003<c<ol0000201TI6BSo00000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0oo`0000030000000I6AT06ATI00Go000000<0IVIV
o`000?l000000P0000001?l00000c<c<o`00003Vi^H2o`0000<0oooo1Ol00002000000Ko000000@0
<c<co`00000I6AT06ATI0P00000Uo`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o
0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0@?l0
00001P0000006ATI01TI6@0I6AWo000003<c<`;o000000D0IVIVo`000?l00000VIVI00000002o`00
0080i^KV00?o00000?ooo`3oool00`3oool5o`0000050000002IVIWo0000o`00001VIVH01?l00003
01TI6@0300000?l0003o000002;o00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0
003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`11o`00
00060000000I6AT06ATI01TI6Ol00000<c<c1Ol00000102IVIT00000o`000?l000020>KViP03o`00
003oool0oooo00@0oooo1?l000001`000000VIVIo`000?l00000IVIVo`00001<C4`00ol0000201TI
6BCo00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`13o`0000070000000I6AT06ATIo`00
000c<c?o000004a<C004o`00000500000?l0003o0000o`00003Vi^H00_l000050?ooo`06o`00003V
i^Ko0000o`0000000000VIVI0_l000001P1VIVKo000004a<C?l00000<c<co`0000806ATI00<00000
o`000?l000008?l00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo
08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Co000000<0000001TI
6@0I6AT00ol000001@1<C4co0000o`000?l0000000000080/k>c0_l000020>KViP05o`00003oool0
oooo0?ooool000000P3Vi^H00ol00000c<c<o`00000209VIV@?o000000L0C4a<o`00000c<c<0<c<c
o`00000I6AT0000002;o00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003ooooo
ooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`15o`0000070000
000I6AT06ATIo`00000c<c?o000004a<C003o`000080000000P0/k>co`000?l0003o00000>KVi_l0
0000ooooo`0000<0i^KV00Co00000<c<c?l0000000000P2IVIT01Ol00000IVIVo`00001<C4co0000
0080<c<c00?o000001TI6@0000008Ol00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Go
000000P0000001TI6@0I6AT06ATIo`00000c<c?o000004a<C0Co00000P0000001Ol00000c<c<o`00
003Vi^Ko000000D0i^KV00Go00000<c<c?l00000000009VIV@02o`00000606IVI_l00000C4a<o`00
000c<c?o00000P0I6ATQo`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0A_l000001000
00006ATI01TI6@0I6AT9o`00000300000?l0003o000000Co00000P3Vi^H2o`000080c<c<0_l00000
2@2IVIWo0000o`00001VIVKo000004a<C?l00000<c<co`00000201TI6@0300000?l0003o000001go
00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`17o`0000030000000I6AT06ATI00806ATI
00?o000003<c<ol000000_l00000101VIVKo0000o`000?l00002000000;o000000<0c<c<o`000?l0
0000103<c<`01Ol00000/k>c00000?l00000Ogmo00;o00000P1<C4`2o`0000<06ATI00<00000o`00
0?l000007?l00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go
00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04So00000P00000301TI6@04
o`00000c<c?o000004a<C0?o000000H0Ogmoo`000?l0000000000;>c/ol000050<c<c00=o`00002c
/k<0/k>c00000?l00000Ogmoo`00001VIVKo000004a<C?l00000<c<co`00000301TI6@0300000?l0
003o000001_o00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=
o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1:o`0000070000000I6AT0
6ATI01TI6Ol00000<c<co`00000204a<C0;o00000P1oOgl00ol0000000000;>c/`05o`0000<0/k>c
00@0000009VIVOl00000Ogmo0_l0000204a<C003o`00000c<c?o000000<06ATI7Ol00003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo04_o000000@00000o`00000I6AT06ATI2_l000001000003o
00000000000000030;>c/`<0000000P0VIVIo`00001oOgoo000006IVI_l00000C4a<o`000080<c<c
00Co000001TI6@0I6AT000007?l00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`00
0?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04go0000
00@0000001TI6@0I6AT06ATI0_l0000203<c<`So00000`00000309VIV@08o`00001oOgl0Ogmoo`00
001VIVKo000004a<C?l0000203<c<`05o`00000I6AT06ATI01TI6@0000006ol00003ooooo`03o`00
0?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo04ko000000<0000001TI6@0I6AT00P0I6AT2o`00000403<c<ol0
0000C4a<04a<C0[o00000P1oOgl01ol00000IVIV06IVIP1VIVKo000004a<C?l000000P0c<c<01Ol0
00006ATI01TI6@0I6AT0000001[o00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0
003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1?o`00
000300000?l00000000000<06ATI3?l0000307moO`;o00000P1VIVH2o`00000504a<C?l00000<c<c
03<c<ol00000100I6AT00`00003o0000o`00000Go`0000?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0D_l000000`0000006ATI01TI6@0201TI6@;o000000@0<c<co`000?l00000C4a<1ol00003
06IVIP05o`00001<C4`0C4a<04a<C?l000000P0c<c<00ol000006ATI01TI6@0201TI6@0300000?l0
003o000001Oo00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=
o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Co`0000800000100I6AT0
0ol00000<c<c03<c<`02o`0000<0C4a<1?l000000`1VIVKo000004a<C00304a<C004o`00000c<c<0
<c<co`0000D06ATI00<00000o`000?l000005_l00003ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo05Go000000<0000001TI6@0I6AT00P0I6AT2o`000080<c<c0ol0000404a<C003o`00001<C4`0
C4a<0080C4a<00?o000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@0201TI6@0300000?l0003o
000001Ko00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`00
00?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Fo`00000300000?l000000000
00<06ATI1?l000000`0c<c?o0000o`000008o`0000<0<c<c0_l0000401TI6@0300000?l0003o0000
01Ko00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Io`0000030000000I6AT06ATI00@0
6ATI0_l0000;03<c<`03o`00000I6AT06ATI00@06ATI00<00000o`000?l000005_l00003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo05[o00000`00000501TI6@?o00001P0c<c<2o`0000L06ATI
00<00000o`000?l000005_l00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oo
oooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo05go00000`00
000501TI6@Ko00002@0I6AT00`00003o0000o`00000Fo`0000?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0H?l00002000001806ATI00<00000o`000?l000005_l00003ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo06;o00000`00000>01TI6@8000006?l00003ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo06Go00000`00000901TI6@8000006_l00003ooooo`03o`000?oooooooooo01Wo
oooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo06So0000100000001?l00000000000000000000Mo`0000?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oo
oooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go
00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o
0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl0
0003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooooooo
ool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003o
ooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?o
oooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=
o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000
ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go
00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooo
oooo093ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooo
oooo01Wooooo000JoooooiCo0000<ooooonDo`0001_ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo0025ooooo`;o0000aOooool2o`0004;ooooo0022ooooo`?o
000000?oooooo`000?ooool0`Oooool3o`000003ooooool0003ooooo047ooooo0020ooooo`;o0000
0_ooool20:Vmj0;o0000_oooool2o`0000;ooooo0P2Y_NP2o`00047ooooo001mooooo`?o000000?o
oooo0:Vmj02Y_NP00`2Y_NP00ol0003oooooo`00002kooooo`?o000000?ooooo0:Vmj02Y_NP00`2Y
_NP00ol0003oooooo`000010ooooo`00N_ooool3o`0000?ooooo1P2Y_NP00ol0003oooooo`00002h
ooooo`?o00000oooool60:Vmj003o`000?oooooo0000043ooooo001hooooo`;o00001?ooool80:Vm
j004o`00002Y_NSoooooo`000;Gooooo0_l00003ooooo`T0ZKgX00Co00000:Vmj?oooooo0000?ooo
ool007Gooooo0ol00002ooooo``0ZKgX00Go00000:Vmj02Y_NSoooooo`00002aooooo`?o00000_oo
ool<0:Vmj005o`00002Y_NP0ZKgXooooool00000?_ooool007?ooooo0_l00002ooooo`l0ZKgX00Go
00000:Vmj02Y_NSoooooo`00002_ooooo`;o00000_ooool?0:Vmj005o`00002Y_NP0ZKgXooooool0
0000?_ooool0073ooooo0ol00003oooooa00ZKgX00Ko00000:Vmj02Y_NP0ZKgXooooool0002[oooo
o`?o00000oooool@0:Vmj006o`00002Y_NP0ZKgX0:Vmj?oooooo0000?Oooool006kooooo0_l00004
oooooa80ZKgX00Ko00000:Vmj02Y_NP0ZKgXooooool0002Yooooo`;o00001?oooolB0:Vmj006o`00
002Y_NP0ZKgX0:Vmj?oooooo0000?Oooool006_ooooo0ol00002oooooaH0ZKgX00?o00000:Vmj02Y
_NP00P2Y_NP00ooooooo0000ooooo`2Tooooo`?o00000_oooolF0:Vmj003o`00002Y_NP0ZKgX0080
ZKgX00?oooooo`000?ooool0>oooool006Sooooo0ol00002oooooaT0ZKgX00?o00000:Vmj02Y_NP0
0`2Y_NP00ooooooo0000ooooo`2Pooooo`?o00000_oooolI0:Vmj003o`00002Y_NP0ZKgX00<0ZKgX
00?oooooo`000?ooool0>_ooool006Kooooo0_l00004oooooa/0ZKgX00?o00000:Vmj02Y_NP00`2Y
_NP00ol0003oooooooooo`2Mooooo`;o00001?oooolK0:Vmj003o`00002Y_NP0ZKgX0080ZKgX00?o
ooooo`000?ooool0>_ooool006?ooooo0ol00004oooooad0ZKgX00?o00000:Vmj02Y_NP0102Y_NP0
0ol0003oooooooooo`2Iooooo`?o00001?oooolM0:Vmj003o`00002Y_NP0ZKgX00<0ZKgX00?ooooo
o`000?ooool0>Oooool0067ooooo0_l00004ooooob00ZKgX00?o00000:Vmj02Y_NP0102Y_NP00ooo
oooo0000ooooo`2Gooooo`;o00001?oooolP0:Vmj003o`00002Y_NP0ZKgX00@0ZKgX00?oooooo`00
0?ooool0>?ooool005kooooo0ol00002ooooob@0ZKgX00?o00000:Vmj02Y_NP01@2Y_NP00ol0003o
ooooooooo`2Cooooo`?o00000_oooolT0:Vmj003o`00002Y_NP0ZKgX00D0ZKgX00?o0000oooooooo
ool0=oooool005cooooo0_l00002ooooobL0ZKgX00?o00000:Vmj02Y_NP01@2Y_NP00ooooooo0000
ooooo`2Aooooo`;o00000_oooolW0:Vmj003o`00002Y_NP0ZKgX00D0ZKgX00?oooooo`000?ooool0
=oooool005Wooooo0ol00003ooooobP0ZKgX00?o00000:Vmj02Y_NP01P2Y_NP00ooooooo0000oooo
o`2=ooooo`?o00000ooooolX0:Vmj003o`00002Y_NP0ZKgX00H0ZKgX00?oooooo`000?ooool0=_oo
ool005Oooooo0_l00004ooooobX0ZKgX00?o00000:Vmj02Y_NP01`2Y_NP00ol0003oooooooooo`2:
ooooo`;o00001?oooolZ0:Vmj003o`00002Y_NP0ZKgX00H0ZKgX00?oooooo`000?ooool0=_ooool0
05Cooooo0ol00003ooooobd0ZKgX00?o00000:Vmj02Y_NP01`2Y_NP00ooooooo0000ooooo`27oooo
o`?o00000oooool]0:Vmj003o`00002Y_NP0ZKgX00L0ZKgX00?oooooo`000?ooool0=Oooool0057o
oooo0ol00003oooooc00ZKgX00?o00000:Vmj02Y_NP0202Y_NP00ooooooo0000ooooo`23ooooo`?o
00000oooool`0:Vmj003o`00002Y_NP0ZKgX00P0ZKgX00?oooooo`000?ooool0=?ooool004oooooo
0_l00003oooooc<0ZKgX00?o00000:Vmj02Y_NP0202Y_NP00ooooooo0000ooooo`21ooooo`;o0000
0ooooolc0:Vmj003o`00002Y_NP0ZKgX00P0ZKgX00?oooooo`000?ooool0=?ooool004cooooo0ol0
0002ooooocH0ZKgX00?o00000:Vmj02Y_NP02@2Y_NP00ooooooo0000ooooo`1mooooo`?o00000_oo
oolf0:Vmj003o`00002Y_NP0ZKgX00T0ZKgX00?oooooo`000?ooool0<oooool004[ooooo0_l00004
ooooocL0ZKgX00?o00000:Vmj02Y_NP02P2Y_NP00ol0003oooooooooo`1jooooo`;o00001?oooolg
0:Vmj003o`00002Y_NP0ZKgX00X0ZKgX00?o0000ooooooooool0<_ooool004Oooooo0ol00004oooo
ocT0ZKgX00?o00000:Vmj02Y_NP02`2Y_NP00ol0003oooooooooo`1fooooo`?o00001?ooooli0:Vm
j003o`00002Y_NP0ZKgX00/0ZKgX00?o0000ooooooooool0<Oooool004Gooooo0_l00004oooooc`0
ZKgX00?o00000:Vmj02Y_NP02`2Y_NP00ooooooo0000ooooo`1dooooo`;o00001?ooooll0:Vmj003
o`00002Y_NP0ZKgX00/0ZKgX00?oooooo`000?ooool0<Oooool004;ooooo0ol00003ooooocl0ZKgX
00?o00000:Vmj02Y_NP0302Y_NP00ol0003oooooooooo`1`ooooo`?o00000_oooom00:Vmj003o`00
002Y_NP0ZKgX00`0ZKgX00?o0000ooooooooool0<?ooool003oooooo0ol00003oooood80ZKgX00?o
00000:Vmj02Y_NP0302Y_NP00ooooooo0000ooooo`1]ooooo`?o00000_oooom30:Vmj003o`00002Y
_NP0ZKgX00`0ZKgX00?oooooo`000?ooool0<?ooool003gooooo0_l00003ooooodD0ZKgX00?o0000
0:Vmj02Y_NP03@2Y_NP00ooooooo0000ooooo`1Zooooo`;o00000_oooom60:Vmj003o`00002Y_NP0
ZKgX00d0ZKgX00?oooooo`000?ooool0;oooool003[ooooo0ol00002ooooodP0ZKgX00?o00000:Vm
j02Y_NP03P2Y_NP00ol0003oooooooooo`1Vooooo`?o00000_oooom80:Vmj003o`00002Y_NP0ZKgX
00h0ZKgX00?o0000ooooooooool0;_ooool003Sooooo0_l00004ooooodT0ZKgX00?o00000:Vmj02Y
_NP03P2Y_NP00ooooooo0000ooooo`1Tooooo`;o00001?oooom90:Vmj003o`00002Y_NP0ZKgX00h0
ZKgX00?oooooo`000?ooool0;_ooool003Gooooo0ol00004oooood/0ZKgX00?o00000:Vmj02Y_NP0
3`2Y_NP00ooooooo0000ooooo`1Pooooo`?o00001?oooom;0:Vmj003o`00002Y_NP0ZKgX00l0ZKgX
00?oooooo`000?ooool0;Oooool003?ooooo0_l00004ooooodh0ZKgX00?o00000:Vmj02Y_NP0402Y
_NP00ol0003oooooooooo`1Mooooo`;o00001?oooom>0:Vmj003o`00002Y_NP0ZKgX00l0ZKgX00?o
ooooo`000?ooool0;Oooool0033ooooo0ol00003oooooe40ZKgX00?o00000:Vmj02Y_NP04@2Y_NP0
0ol0003oooooooooo`1Iooooo`?o00000ooooomA0:Vmj003o`00002Y_NP0ZKgX0100ZKgX00?ooooo
o`000?ooool0;?ooool002gooooo0ol00003oooooe@0ZKgX00?o00000:Vmj02Y_NP04@2Y_NP00ol0
003oooooooooo`1Fooooo`?o00000ooooomD0:Vmj003o`00002Y_NP0ZKgX0140ZKgX00?o0000oooo
ooooool0:oooool002_ooooo0_l00003oooooeP0ZKgX00?o00000:Vmj02Y_NP04@2Y_NP00ol0003o
ooooooooo`1Cooooo`;o00000ooooomH0:Vmj003o`00002Y_NP0ZKgX0140ZKgX00?o0000oooooooo
ool0:_ooool002Sooooo0ol00002oooooe/0ZKgX00?o00000:Vmj02Y_NP04@2Y_NP00ooooooo0000
ooooo`1@ooooo`?o00000_oooomK0:Vmj003o`00002Y_NP0ZKgX0140ZKgX00?oooooo`000?ooool0
:_ooool002Kooooo0_l00002oooooeh0ZKgX00?o00000:Vmj02Y_NP04P2Y_NP00ol0003ooooooooo
o`1=ooooo`;o00000_oooomN0:Vmj003o`00002Y_NP0ZKgX0180ZKgX00?o0000ooooooooool0:Ooo
ool002?ooooo0ol00003oooooel0ZKgX00?o00000:Vmj02Y_NP04`2Y_NP00ol0003oooooooooo`19
ooooo`?o00000ooooomO0:Vmj003o`00002Y_NP0ZKgX0180ZKgX00?oooooo`000?ooool0:Oooool0
027ooooo0_l00004ooooof40ZKgX00?o00000:Vmj02Y_NP0502Y_NP00ol0003oooooooooo`16oooo
o`;o00001?oooomQ0:Vmj003o`00002Y_NP0ZKgX01<0ZKgX00?oooooo`000?ooool0:?ooool001ko
oooo0ol00004ooooof<0ZKgX00?o00000:Vmj02Y_NP0502Y_NP00ol0003oooooooooo`13ooooo`?o
00001?oooomS0:Vmj003o`00002Y_NP0ZKgX01@0ZKgX00?o0000ooooooooool09oooool001cooooo
0_l00004ooooo`80ZKcWI02Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003o`000?oooooooooo043ooooo
0_l00004ooooofH0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ol0003oooooooooo`0Vooooo`006Ooo
ool3o`0000?ooooo0P2WYmH40:Vli`80ZKgX0P2Y^nIO0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?o
ooooo`000?ooool0?Oooool3o`0000?oooooJ@2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003ooooool0
003ooooo02Kooooo000Fooooo`?o00000oooool00`2NN:P0YjOF0:NWeP030:NWeP80ZKcW0P2VXm<4
0:VkiP030:Vmj02Y^nH0ZK_V00<0ZKgX0P2Y^nIF0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o0000
ooooooooool0>Oooool3o`0000?oooooK02Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oooooo
oooo02Gooooo000Dooooo`;o00001Oooool309ihZ0<0YjOF00<0WG>S0:JSd`2VXm<00`2VXm<20:Vk
iP80YZ7@0`2Y^nH00`2Y_NP0ZK_V0:VkiP020:VkiP80ZKgX0P2Y^nIA0:Vmj003o`00002Y_NP0ZKgX
01H0ZKgX00?oooooo`000?ooool0=oooool2o`0000?oooooK`2Y_NP00ol00000ZKgX0:Vmj00F0:Vm
j003ooooool0003ooooo02Gooooo000Aooooo`?o00001_ooool509ihZ0040:NWeP2MLj<0WG>S09ec
X`<0YZ?C00<0W72P0:JQd02VXM000`2VXM000`2Y^nH0YYo?0:JOc`030:VkiP80YYo?102Y^nH20:Vm
j0030:VkiP2Y_NP0ZKgX04X0ZKgX0_l0000I0:Vmj003ooooool0003ooooo03?ooooo0ol00003oooo
og00ZKgX0_l0000I0:Vmj003ooooool0003ooooo02Cooooo000@ooooo`;o00002?ooool509ihZ0D0
WG>S00@0YZ?C09a`X02LL:00W72P0`2VXM000`2LKih0YYo?0:JOc`020:JOc`030:VkiP2VWll0YYo?
0080YYo?0P2Y^nH20:JQd0<0ZK_V0P2Y_NP20:Vlid@0ZKgX0ol000000`2Y_NSo00000:Vmj00I0:Vm
j003o`000?oooooooooo037ooooo0_l00002ooooog00ZKgX0ol000000`2Y_NSo00000:Vmj00I0:Vm
j003o`000?oooooooooo02?ooooo000@ooooo`03o`000?oooooo000000Kooooo0P2WLiL409ihZ0D0
WG>S1@2LL:00102VXM00W6nN09a_WP2LKih20:JOc`0309a_WP2VWll0YYo?00<0YYo?1@2VXM000`2Y
^nH0Yj?B0:NSdP040:Vli`80ZKgX0P2Y_>Ll0:Vmj0?o00001@2Y_NP00ol00000ZKgX0:Vmj00H0:Vm
j003o`000?oooooooooo033ooooo00?o00000:Vmj02Y_NP0KP2Y_NP3o`0000D0ZKgX00?o00000:Vm
j02Y_NP0602Y_NP00ol0003oooooooooo`0Rooooo`004?ooool01?l0003oooooooooool00004oooo
o`<0Yg>G0`2NN:P00`2XLI@0WG>S09ecX`0309ecX`D0W72P102LKih0102VWll0W6nN09a_WP2LKih3
0:JOc`80WG2N102VXM040:NSdP80ZKcW0P2XYmD40:Vli`030:Vmj02Y_>L0ZKcW03D0ZKgX0ol00009
0:Vmj003o`00002Y_NP0ZKgX01L0ZKgX00?o0000ooooooooool0<?ooool00ol00000ZKgX0:Vmj01[
0:Vmj0?o00002@2Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`000?oooooooooo02;ooooo000@oooo
o`05o`000?ooooooooooooooool000000oooool30:McU`<0WWRX00<0Z76D09ecX`2MLj<00P2MLj<0
0`2XL980W72P09a`X00309a`X0T0W6nN00@0YYo?09e`WP2ML9h0WG2N0`2VXM0209icX@80Yj?B00<0
X7NT0:RWe@2XYmD00`2XYmD20:Vli`030:R[f@2Y_>L0ZKcW0080ZKcW0P2Y_NP20:Vlibd0ZKgX0ol0
000=0:Vmj003o`00002Y_NP0ZKgX01L0ZKgX00?o0000ooooooooool0;oooool00ol0003ooooo0:Vm
j01X0:Vmj0?o00003@2Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`000?oooooooooo027ooooo000?
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooo`2WLiL0102WLiL0102NN:P0Z76D0:QaU02X
LI@309ecX`030:Q`TP2LL:00W72P0080W72P00<0ZG2A09a_WP2LKih01`2LKih509e`WP050:JQd02N
Lj40WW>Q09icX@2WXm800`2PMj@30:RWe@030:9lZ@2XZmT0Z:_I0080Z:_I0P2Y_>L20:V_g0@0ZKcW
0P2Y_NP00`2Y_NL0ZKgX0:Vmj00T0:Vmj0?o0000402Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003oooo
ool0003ooooo02kooooo00Co0000ooooooooooooooooI@2Y_NP3o`000100ZKgX00?o00000:Vmj02Y
_NP05`2Y_NP00ooooooo0000ooooo`0Qooooo`003oooool00ol0003oooooooooo`020>5j@@;ooooo
00?o00000:McU`2WLiL00`2WLiL0102NN:P0Z76D0:QaU02XLI@209ecX`80Z72B102LL:000`2YL940
W6nN09a_WP0709a_WPD0WG2N102NLj450:1gY0040:RWe@2RO:T0XWbY0:9lZ@<0Z:_I00<0Y8>a0:V_
g02Y[m`00P2Y[m`20:Vli`80ZK?P0`2Y_NLR0:Vmj0?o0000502Y_NP00ol00000ZKgX0:Vmj00G0:Vm
j003o`000?oooooooooo02gooooo00?o0000ooooooooool00_oooomQ0:Vmj0?o0000502Y_NP00ol0
0000ZKgX0:Vmj00G0:Vmj003o`000?oooooooooo023ooooo000?ooooo`03o`000?ooool0dGIQ00@0
hGY100<0biNP0:McU`2WLiL00`2WLiL40:QaU080WG>S0`2XL98209a`X080ZG2A0`2LKih00`2[LI40
W6nN09a_WP0209a_WP030:abT@2ML9h0WG2N00<0WG2N102NLj450:1gY0D0XWbY00@0Z:_I0:B3/@2T
Pk40Y8>a0P2Y[m`20:N<^@@0ZK?P00<0ZKgW0:VfhP2Y]^800`2Y_NP20:Vii1T0ZKgX0ol0000H0:Vm
j003o`00002Y_NP0ZKgX01H0ZKgX00?oooooo`000?ooool0;Oooool00ol0003oooooooooo`03oooo
oed0ZKgX0ol0000H0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?oooooo`000?ooool08?ooool000oo
oooo00?o00000=5fH@3AMV40103QNT400`3;Uj00Yg>G0:McU`030:McU`@0Z76D00<0WG>S0:Q`TP2X
L9800P2XL98209a`X0<0ZG2A0P2LKih00`2[LI40W6nN09a_WP0209a_WP030:abT@2ML9h0WG2N0080
WG2N00@0[GBB09icX@2NLj40WW>Q0P2_MY@40:1gY0D0XWbY102TPk450:N<^@80ZK?P00<0ZIO30:Vf
hP2Y]^800P2Y]^800`2Y_NP0ZKWT0:Vii0020:Vii0030:Vmj02Y^nH0ZK_V0180ZKgX0ol0000L0:Vm
j003o`00002Y_NP0ZKgX01H0ZKgX00?oooooo`000?ooool0;?ooool00ol0003oooooooooo`04oooo
oeT0ZKgX0ol0000L0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?oooooo`000?ooool07oooool000oo
oooo00Co00000=5fH@3AMV40dGIQ0P3QNT420<^GX0@0Yg>G00<0cYNK0:QaU02XLI@00P2XLI@00`2M
Lj<0Z72B0:Q`TP020:Q`TP80W72P0`2YL94209a_WP80Zg6A0`2LKih00`2/LY40WG2N09e`WP0209e`
WP040:edTP2NLj40WW>Q09icX@80[gJD0`2PMj@00`2aNIL0XWbY0:9lZ@030:9lZ@@0Y8>a00<0]8>O
0:N<^@2WS;T00P2WS;T40:VG``80ZKKR0P2[XLd30:Vii0030:^[e`2Y^nH0ZK_V0080ZK_V0P2Y_NP0
0`2Y_>L0ZKgX0:Vmj00:0:Vmj0;o00007`2Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`000?oooooo
oooo02_ooooo00?o0000ooooooooool01OoooomF0:Vmj0;o00007`2Y_NP00ol00000ZKgX0:Vmj00G
0:Vmj003o`000?oooooooooo01kooooo000?ooooo`04o`00003AMV40dGIQ0=5fH@80hGY10P3;Uj04
0:McU`030<jGV`2XLI@0Z76D0080Z76D1@2XL9800`2LL:00ZG2A0:U`T@020:U`T@0409a_WP2[LI40
Zg6A0:]aT@80W6nN0`2/LY4209e`WP<0[GBB0P2NLj420:mfU0<0X7NT0P2aNIL30:9lZ@040;9mVP2T
Pk40Y8>a0:B3/@80]8>O102WS;T40:VG``D0Zj7=00@0ZKWT0:^[e`2[ZmL0Zj_G0P2Y^nH20:^bg@<0
ZKcW0P2Y_NP20:Vli`@0ZKgX0ol0000R0:Vmj003o`00002Y_NP0ZKgX01L0ZKgX00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`06oooooe80ZKgX0ol0000R0:Vmj003o`00002Y_NP0ZKgX01L0
ZKgX00?o0000ooooooooool07Oooool000kooooo00?o00000=5fH@3AMV400P3AMV40103QNT40dGe_
0<^GX03;Uj040:McU`030<jGV`2XLI@0Z76D0080Z76D1@2XL9800`2LL:00ZG2A0:U`T@020:U`T@04
09a_WP2[LI40Zg6A0:]aT@80W6nN0`2/LY4209e`WP<0[GBB00@0WW>Q0:mfU02_MY@0[gJD0`2PMj@2
0;5iU`80XWbY0`2bOIX20:B3/@80]8>O0`2WS;T20;J:Y`80ZIO30P2gT[430:^Qc@050;NM_@2[ZmL0
Zj_G0:^[e`2fYlX01@2[/]d00`2Y_>L0ZkOR0:^ghP040:Vli`?o00009P2Y_NP00ol00000ZKgX0:Vm
j00G0:Vmj003o`000?oooooooooo02Sooooo00?o0000ooooooooool02?oooom>0:Vmj0?o00009P2Y
_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`000?oooooooooo01cooooo000>ooooo`03o`000?ooool0
dGIQ0080dGIQ00@0dGe_0<^GX03;Uj00biNP0`2WLiL20<jGV`@0Z76D1@2XL9850:U`T@0509a_WP2[
LI40Zg6A0:]aT@2LKih0102/LY4209e`WP<0[GBB00@0WW>Q0:mfU02_MY@0[gJD0P2PMj@30;5iU`80
XWbY0`2bOIX00`2TPk40]8>O0;B3W`020;B3W`050:N<^@2fRZL0]XZW0;J:Y`2YUl<0102gT[401@2[
XLd0]ifm0;NM_@2gWKd0Zj_G00<0]ZO:0`2[/]d00`2c/=D0ZkOR0:^ghP020:^ghP?o0000:P2Y_NP0
0ol00000ZKgX0:Vmj00F0:Vmj003o`000?oooooooooo02Sooooo00?o0000ooooooooool02Ooooom:
0:Vmj0?o0000:P2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oooooooooo01cooooo000>oooo
o`06o`000?ooool0dGIQ0=5fH@0E0000dGe_0`3;Uj030:McU`80cYNK0`2XLI@00`3AV9P0Z72B0:Q`
TP030:Q`TPD0ZG2A102[LI400`2LKih0[7:A0:abT@020:abT@0309e`WP2]M980[GBB0080[GBB00<0
WW>Q0:mfU02_MY@00P2_MY@01@2PMj@0/GVG0;5iU`2aNIL0XWbY00@0/WfJ00<0Y8>a0;B3W`2dPil0
0P2dPil40;J:Y`D0]i:a102gWKd50;JWbP040:^bg@2c/=D0/k3E0;>`e@?o000000@0/;KN0:Zji@2Z
^^D0Z[[U0P2Y_NP20:ZliRD0ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00_oooooA@2Y_NP3o`0002d0ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol0
003oooooooooo`0Kooooo`003_ooool01Ol0003ooooo0=5fH@0E003ooooo00@0biNP0P2WLiL30<jG
V`<0Z76D00<0dIRH0:Q`TP2XL9800`2XL9850:U`T@@0Zg6A00<0W6nN0:abT@2/LY400P2/LY400`2M
L9h0[GBB0:edTP020:edTPD0[gJD00@0X7NT0;5iU`2aNIL0/GVG1@2bOIX50;B3W`@0]XZW00<0jKn[
0;NB/@2gT[400P2gT[440;NM_@060=c9a`2fYlX0]ZO:0;JWbP3?b]@0/k3E0ol000000`33amh0/;KN
0;2fgP020;2fgP030:Zji@2]^^<0[K[S00@0Z[cV0P2Y_NP20:Vmib40ZKgX00?o00000:Vmj02Y_NP0
5P2Y_NP00ooooooo0000ooooo`0Wooooo`03o`000?oooooooooo00cooooo@@2Y_NP3o`0000H0ZKgX
0P2Y_NL60:Vmj080ZKgW0P2Y_NP00`2Y_>L0ZKgX0:Vmj0040:Vmj080ZKcW1@2Y_NP20:Vmi`l0ZKgX
00?o00000:Vmj02Y_NP05P2Y_NP00ooooooo0000ooooo`0Kooooo`003_ooool00ol0003ooooooooo
o`02ooooo`@0biNP0P2WLiL30<jGV`<0Z76D00<0dIRH0:Q`TP2XL9800P2XL9800`3EVYH0ZG2A0:U`
T@030:U`T@@0Zg6A1@2/LY450:edTPD0[gJD102aNIL50;9mVP@0]8>O00@0j[VR0;J:Y`2fRZL0]XZW
0P3Y_j/30;NB/@80i<Fh0P2gWKd30=c9a`050;JWb_l0003o0000o`00002c/=D01033amh20;2fgP03
0;S4h`2]^^<0[K[S0080[K[S0P2Z_>H20:^li@80ZKgW0P2Z_NLQ0:Vmj003o`00002Y_NP0ZKgX01H0
ZKgX00?o0000ooooooooool09_ooool00ol0003oooooooooo`0=ooooocd0ZKgX0ol000000`2Y_NL0
ZKgX0:Vmj0040:Vmj0030:Vli`2Y_NL0ZKgW0080ZKgW0P2Y_NP20:Vli`80ZKgW0P2Z^^D30:Vli`80
ZKgX0P2Z^^D40:Vli`80ZKgX00<0ZK_V0:Vmi`2Y_NL00P2Y_NL20:Vmj0030:Vli`2Y_NP0ZKgX00X0
ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Jooooo`003_ooool00ol0003ooooo
ooooo`02ooooo`@0biNP00<0Yg>G0<jGV`3>Ui/00P3>Ui/30:QaU0030=6HV02XL980Z72B0080Z72B
00<0eIZF0:U`T@2YL9400`2YL9440:]aT@D0[7:A1@2]M9850:mfU0@0/GVG1@2bOIX40;B3W`80j[VR
0P2fRZL20>VoZ`80]i:a0`3TaKP00`2gWKd0g<W70=c9a`03o`0000<0cl[D00D0`ng`0<?7gP33amh0
`lON0;WHl0040;S4h`80[K[S0`2a`NH00`2[_>D0[KoW0:foi`040:Zmi`80ZKgX00<0Z[gW0:Vmj02Y
_NP06`2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003ooooool0003ooooo02Kooooo00?o0000oooooooo
ool03Ooooolj0:Vmj0?o000000<0ZKcW0:Vmi`2Y_NL00P2Y_NL20:Vmj0030:VkiP2Y_>L0ZKcW0080
ZKcW0P2Y_NL20:Vji@80ZKcW0P2Z]N440:Zji@030:Vli`2Z]N40Z[GQ00@0Z[[U0P2Y_>L00`2Z]n80
ZK_V0:VkiP020:VkiP80ZKgW00<0Z[WU0:Vli`2Y_>L00P2Y_>L20:Vmj0030:VliP2Y_NP0ZKgX00@0
ZKgX0P2Y_NL01?l00000ZKgX0:Vmj02Y_NLE0:Vmj003ooooool0003ooooo01[ooooo000=ooooo`03
o`000?oooooooooo00?ooooo103;Uj000`2WLiL0cYNK0<jGV`020<jGV`80Z76D0P3AV9P40:Q`TP03
0=FJUP2YL940ZG2A0080ZG2A00<0f9bE0:]aT@2[LI400P2[LI450:abT@D0[GBB1@2_MY@30;5iU`03
0>N^U`2bOIX0/WfJ0080/WfJ00<0jK>K0;B3W`2dPil00P2dPil20>ZiXP030;J:Y`3Y_j/0jKn[0080
jKn[00@0]i:a0>C5^03TaKP0i<Fh0ol000040<?ng0050<o:e033kO00`ng`0<?]l033amh00`2if?02
0;S4h`80//_]0`2a`NH00`2^a>X0[KoW0:foi`020:foi`80Z[gW00<0ZkkX0:Zmi`2Z_NL00P2Z_NLM
0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o0000ooooooooool09?ooool00ol0003oooooooooo`0?
ooooocH0ZKgX0ol000050:Vli`80ZKgW00<0ZK[U0:VkiP2Y^nH00P2Y^nH20:Vli`<0Z[SS00<0ZK[U
0:Z_f`2Z[m/0102Z]N420:Zji@030:Z/f@2Z]N40Z[GQ0080Z[GQ0P2Z^^D00`2Z[]X0Z[OR0:ZghP02
0:ZghP80ZK_V00<0Z[;N0:Zii@2Z^ND00P2Z^ND20:Vli`80Z[OS0`2Y_>H20:Vmj0<0Z[_V0P2Y_NL0
0`2Z^^Go00000:Vmi`020:Vmi`80ZKgX00<0ZKcW0:Vmj02Y_NP0402Y_NP00ol0003oooooooooo`0I
ooooo`003Oooool00ol0003oooooooooo`04ooooo`<0biNP00<0Yg>G0<jGV`3>Ui/00P3>Ui/20:Qa
U080dIRH0`2XL9820=FJUP@0ZG2A00D0f9bE0:]aT@2[LI40Zg6A0=^OU0040:abT@030=jRU02]M980
[GBB0080[GBB00<0hZJD0:mfU02_MY@00P2_MY@01@3UZYD0/GVG0;5iU`2aNIL0ijjG00@0/WfJ0P3Y
/i/20;B3W`<0j[VR00<0]XZW0>VoZ`3Y_j/00P3Y_j/010000000i<Fho`000?l0000209fjk@<0L[Ci
0P1YcO`209:kl`@0U/gk00@0^MS`0:?6lP2Sa_80XlKb0`2bbnd0102a`NH0[/CZ0:k4jP2^a>X20:fo
i`030:_0j@2[_^P0ZkkX0080ZkkX0P2Z_NL00`2Z_^P0ZKgX0:Vmj00L0:Vmj003o`00002Y_NP0ZKgX
01H0ZKgX00?o0000ooooooooool08oooool00ol0003oooooooooo`0@oooooc<0ZKgX0_l000070:Vl
i`80Z[WT0`2Y^^D20:VkiP<0Z[CP0P2Z^><00`2ZZ=D0ZZoK0:Z_f`020:Z_f`80Z[GQ00<0ZZ7>0:Z/
f@2Z[=T00P2Z[=T20:Zeh@030:ZPc02Z[]X0ZZkJ0080ZZkJ0P2Z]n800`2[Y=00Z[;N0:ZbgP020:Zb
gP80Z[WU0P2[[MT40:Zgh`040:VliP2[]N40ZkGQ0:^eh@80Z[_V00<0ZkCO0:Zji@2Z^^D00P2Z^^D0
0ol00000ZKgW0:Zji@040:Vli`80ZKgX00<0ZKgW0:Vmj02Y_NP03@2Y_NP00ol0003oooooooooo`0H
ooooo`003Oooool00ol0003oooooooooo`04ooooo`<0biNP1@3>Ui/20:QaU080dIRH0`2XL9820=FJ
UP@0ZG2A00D0f9bE0:]aT@2[LI40Zg6A0=^OU0040:abT@030=jRU02]M980[GBB0080[GBB00<0hZJD
0:mfU02_MY@00P2_MY@01@3UZYD0/GVG0;5iU`2aNIL0ijjG00@0/WfJ0P3Y/i/20;B3W`<0j[VR00@0
]XZW0>VoZ`3Y_j/0jKn[0ol000000`3TaKP0WK[]09fjk@0209fjk@0407:dn@2S_>/0Xkc[0:>lj`<0
T[_c0P2FcO/209nmkP80XlKb00<0YKg[0:O2k@2W`^d00P2W`^d20:k4jP030:RojP2[`>T0Zl3Y0080
Zl3Y0P2[_^P50:Znj080ZKgX0P2Z_NPJ0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Aooooobl0ZKgX0ol000060:Vli`80Z[ST102Z^N@00`2Y^^D0
Z[7M0:Zag@030:Zdh0030:VSd02ZZ=D0ZZSE0080ZZSE0P2Z[m/00`2YV<@0ZZ7>0:ZQcP020:ZQcP80
ZZcI00<0Z9:n0:ZPc02ZX<`00P2ZX<`20:Z^fP030:VC_`2[Y=00ZjC@0080ZjC@0P2Z/]h20:^Ka`@0
ZjgI0P2Z]n<01@2/Z=<0ZkGQ0:^eh@2[]N40[:G@00@0ZkCO0P2Z^^D00`2//mh0Z[[Uo`0000020:Zj
i@80ZKcW00<0Z[[U0:Vmi`2Y_NL00P2Y_NL20:Vmj0030:Vmi`2Y_NP0ZKgX00X0ZKgX00?o0000oooo
ooooool05oooool000gooooo00?o0000ooooooooool01?ooool20<^GX003ooooo`3>Ui/0cYNK00<0
cYNK00@0Z76D0=6HV03AV9P0dIRH0`2XL9820=FJUP@0ZG2A00D0f9bE0:]aT@2[LI40Zg6A0=^OU004
0:abT@030=jRU02]M980[GBB0080[GBB00<0hZJD0:mfU02_MY@00P2_MY@0103UZYD0/GVG0;5iU`2a
NIL20>N^U`80/WfJ0`3Y/i/00`2dPil0j[VR0>ZiXP020>ZiXP040:Vmj?l0003o0000o`000080ZKgX
0`2X_NP209fjk@80Z;gX0P2S_>/20:Vmj0<0Y[cY0P2O_Nh20:Rmj@<0YKg[0P2W`^d20:Nmj@<0Z;oZ
0P2[`>T20:Vnj@L0Z[kX102Z_NPI0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Booooob/0ZKgX0ol000070:Vli`030:Vii02Z^>@0Z[ST0080Z[ST
0P2Z^N@00`2Z/=`0Z[7M0:Zag@020:Zag@040:Zdh02YXm00ZJ?@0:VSd0<0ZZSE00@0ZZoK0:VHa02Y
V<@0ZIS40`2ZXLh0102Z[=T0Z9:n0:RB_P2XT[h30:ZPc0@0ZI>o0`2[Y=050:^Ka`80ZjgI00<0ZiFo
0:bXd`2/Z=<00P2/Z=<0102[]N40[:G@0:bUd02/YM020:^dg`030:jUc`2//mh0[;?N0080[;?N00?o
00000:Zji@2/]=l0102Z^^D20:Vmi`030:ZkiP2Y_NL0ZKgW0080ZKgW0P2Y_NP30:Vmi`H0ZKgX00?o
0000ooooooooool05oooool000gooooo00?o0000ooooooooool01?ooool0103;Uj3ooooooooooooo
ool40<jGV`040:QaU03AV9P0dIRH0=6HV0<0Z72B0P3EVYH30:U`T@80f9bE0`2[LI400`3KWi@0[7:A
0:abT@020:abT@030=jRU02]M980[GBB0080[GBB00<0hZJD0:mfU02_MY@00P2_MY@00`3UZYD0/GVG
0;5iU`030>N^U`80/WfJ0`3Y/i/00`2dPil0j[VR0>ZiXP03o`0000030:Vmj03Y_j/0ZKgX00H0ZKgX
0P2X_NP60:Vmj0030:Jlj@2Y_NP0ZKgX00@0Z;gY00<0YKg[0:Rmj02X_NP0102W_NT00`2X_nX0Z;gX
0:Rmj0040:Vnj@80Z[kX0P2Y_^P30:Znj080Z[gX6`2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`00
0?oooooooooo027ooooo00?o0000ooooooooool04ooooolW0:Vmj0?o00001`2Y_>L20:Vji@<0ZKWT
0P2Z^>@00`2Y/Md0Z[3L0:Z`g0020:Z`g080Z[7M0P2YXLh30:VSd080ZZSE00<0Z96n0:VHa02YV<@0
0P2YV<@20:ZQcP030:N8/`2XT[h0Z9:n00<0Z9:n00<0ZZ3<0:R6/02XQ[00102YTkl00`2[Y=00ZHZd
0:V:]0030:^Ka`030:Z5[@2[UKl0ZiFo0080ZiFo0P2/Z=<00`2]T[/0[:G@0:bUd0020:bUd0040:^d
g`2^YLl0[ZG?0:jUc`80[;?N00<0[jSA0:bdgol000000P2/]=l20:Zji@80[;OQ0`2Z^nH20:Vmi`<0
Z[cV0P2Y_NL00`2Z_>L0ZKgX0:Vmj0050:Vmj003o`000?oooooooooo01Kooooo000=ooooo`03o`00
0?oooooooooo00Sooooo103>Ui/0102XLI@0dIRH0=6HV03AV9P20:Q`TP<0eIZF0`2YL9420=RLU@<0
Zg6A00<0finD0:abT@2/LY400P2/LY400`3NXY@0[GBB0:edTP020:edTP040>:VU02_MY@0[gJD0:mf
U080iJZE0P2aNIL30>N^U`80/WfJ0`3Y/i/3o`0000030>ZiXP2Y_NP0ZKgX01D0ZKgX0P2X_NT00`2Y
_NP0Z;gX0:Rmj0020:Rmj080YkgY00<0ZKgX0:Rmj02X_NP00P2X_NP20:Vnj@80ZKgX0P2Y_^PR0:Vm
j003o`00002Y_NP0ZKgX01H0ZKgX00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eoooo
ob80ZKgX0ol000030:Vmj0<0ZKcW102Y^nH00`2Y^^D0Z;OS0:Vch0030:Vch0<0ZK7M0P2Z/=`00`2X
Xm40ZJ7>0:VQcP030:VQcP030:VSd02WSk`0Z96n00<0Z96n0`2YV<@40:N8/`@0Z9:n0`2XQ[030:VC
_`030:QoY`2YR[@0ZHZd0080ZHZd00<0Zi_70:Z5[@2ZQJd0102[UKl40:fB^`80[:G@00D0[iBj0:jU
c`2^YLl0[ZG?0;:I_@040:nXd@040:bdgol00000/:gE0;2]e@@0[;OQ00@0Z[_V0:bih`2/^N<0[;WS
0P2Z_>H00`2[^nD0Z[cW0:Zli`020:Zli`80ZKgX00<0Z[gW0:Vmj02Y_NP00P2Y_NP00ol0003ooooo
ooooo`0Eooooo`003?ooool00ol0003oooooooooo`09ooooo`@0cYNK00@0Z76D0=6HV03AV9P0dIRH
0P2XL9830=FJUP<0ZG2A0P3HW9D20:]aT@80finD0`2/LY420=jRU0<0[GBB0P3RYY@30:mfU080iJZE
0P2aNIL30>N^U`030;9mVP3Y/i_o000000;o0000103Z^J8K0:Vmj080Z;gX1@2Y_NP20:Rmj2X0ZKgX
00?o00000:Vmj02Y_NP05@2Y_NP00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Oooooo
7P2Y_NP3o`0000H0ZKgX102Y_>L20:VkiP040:NiiP2X]n<0Z;OS0:Rgh`@0ZK?P00<0ZK7M0:NXe`2X
Xm400`2XXm430:VQcP040:JB`02WSk`0Yhnl0:N?_0@0Z96n00<0ZIS40:N3[P2WPjh00`2WR;<30:RB
_P030:MnY`2XQ[00Z8J`0080Z8J`00<0ZI>o0:QoY`2XOjL0102YR[@40:Z5[@80ZiFo0P2]QJX30:fB
^`@0[iBj00@0[ZG?0;:I_@2bVKd0/YVm0`2_Z=420;2]e@03o`00002`[MD0/:gE0080[;OQ00D0/;;J
0:bih`2/^N<0[;WS0:nhg`040:^ki@80Z[cW00<0ZkcV0:Zmi`2Z_NL00P2Z_NL30:Vmj003o`000?oo
oooooooo01Gooooo000<ooooo`03o`000?oooooooooo00Wooooo103>Ui/40=6HV080Z72B0`3EVYH3
0:U`T@80f9bE0P2[LI420=^OU0<0[7:A0P3NXY@30:edTP80hZJD0`2_MY@20>FZU@80/GVG0P3W[YL3
o`0000<0jK>K00<0ZKgX0>ZiXP3Z^J80C`2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oooooo
oooo01kooooo00?o0000ooooooooool06?oooolJ0:Vmj0?o00002P2Y_NP20:Vli`80Yk_X0`2W^NH3
0:Rgh`80ZK?P00@0YJoN0:NXe`2WZ=L0YjSG102XXm400`2YXLh0YY;00:JB`0030:N?_0<0Z96n00@0
YX:]0:N3[P2WPjh0Yh>^102WR;<00`2XT[h0YgjW0:MnY`040:R6/0@0Z7nW0`2YR[@40:Z5[@040:^E
_`2]QJX0[HFZ0:f5ZP<0[I:k00@0/HRY0:nD^P2_U;X0[iBj1@2bVKd01`2_Z=40]J730;FQ``2`[MGo
00000;2]e@2gZld0102`/]X0102/^N<0[kSO0:nhg`2_^=l20:^ki@030:fki02[_>H0ZkcV0080ZkcV
0`2Z_NL40:Vmj003o`000?oooooooooo01Cooooo000<ooooo`03o`000?oooooooooo00Wooooo103>
Ui/40=6HV080Z72B0`3EVYH20:U`T@<0f9bE0P2[LI420=^OU0<0[7:A0P3NXY@30:edTP80hZJD0`2_
MY@20>FZU@060;5iUol0003o0000o`00003W[YL0/WfJ0`3Y/i/30:Vmj0030>ZiXP2Y_NP0ZKgX04h0
ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Wo
oooo5P2Y_NP3o`0000`0ZKgX0P2X_>P40:Nkj0030:NiiP2T^NP0Y;WX00<0Y;GU0`2U[mh30:NXe`80
Z:?A00<0Y9W:0:JB`02VT/000P2VT/030:N?_0030:RA_P2VPZd0YX:]00<0Yh>^102WR;<40:MnY`<0
Z8J`102XOjL20:V:]080ZgfR0`2ZQJd40:f5ZP80[I:k0P2aR:T30:nD^P030;J>[@2bVKd0/YVm0080
/YVm102eXL<0102`[MGo00000;N[c@2gZld20;2bfP80]kCG0P2_^=l00`2c^ml0[K_T0:fki0020:fk
i080ZkcV00<0[;gV0:Zmi`2Z_NL00P2Z_NL20:Vmj080Z[gX00?o0000ooooooooool04oooool000co
oooo00?o0000ooooooooool02_ooool20<jGV`03ooooo`3AV9P0dIRH0080dIRH00<0Z72B0=FJUP3E
VYH00P3EVYH20:U`T@80f9bE0`2[LI420=^OU0<0[7:A0P3NXY@30:edTP80hZJD0P2_MY@20>FZU@;o
0000103W[YL40>VcVeD0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01[ooooo4`2Y_NP2o`0000d0ZKgX00<0Z;gX0:Rlj02X_>P00P2X_>P20:Nkj003
0:Flj@2T^NP0Y;WX0080Y;WX0`2T]ND00`2U[mh0VZgU09nSf00209nSf0<0Y9W:102VT/020:N?_004
0:B4/@2VPZd0YX:]0:J2[@@0Yh>^0P2WR;<00`2WNj<0YgjW0:MnY`020:MnY`80Z8J`00<0ZGZO0:Qo
Y`2XOjL00P2XOjL0102YR[@0ZgfR0:]mXP2[OJ830:Z5[@D0[HFZ00<0[I:k0;68Z@2aR:T00P2_U;X2
0;J>[@<0/YVm0P2lV;<20;FQ``050<6U_P2gZld0]j_=o`000033]<`00`2g]=L00`2n_]T0/k_O0;>k
g`020;>kg`80[K_T00<0/;kT0:bmiP2/_NH00P2/_NH20:Zmi`80ZkgW0`2Z_NP00ol0003ooooooooo
o`0Cooooo`003?ooool00ol0003oooooooooo`0:ooooo`030<jGVooooooooooo00@0dIRH00<0Z72B
0=FJUP3EVYH00P3EVYH20:U`T@80f9bE0P2[LI430=^OU080[7:A0`3NXY@20:edTP<0hZJD00H0[gJD
o`000?l0003o00000>FZU@2aNIL40>N^U`<0jK>KE`2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003o`00
0?oooooooooo01cooooo00?o0000ooooooooool07?ooool>0:Vmj0?o00003P2Y_NP30:Rmj080Z;cX
00<0YkgY0:Flj@2U_>T00P2U_>T20:Bij00409fjk@2I]^`0VKK/09Vfk0<0VZgU0`2OXmP30:BIbP<0
YY;000<0Yhnl0:B4/@2TQ;40102VPZd30:N3[P030:N8/`2WNj<0Yg^S00@0YgjW00<0Z8J`0:UjW`2Y
NYl0102XOjL40:]mXP80ZXF]0P2_OYl40:f5ZP@0/HRY00D0[iBj0;J>[@2fSZd0]Xj]0;:I_@030;bH
/`090;FQ``31YKh0`JFn0<6U_P2gZld0`kC<o`000033]<`0]kCG00<0_[kI0P2c^ml00`2g`^<0/;kT
0;2ni0020;2ni080[;gV0P2]_^L20:^mi`030:^nj02Z_NP0Z[gX0080Z[gX00?o0000ooooooooool0
4_ooool000cooooo00?o0000ooooooooool03Oooool40=6HV0030:Q`TP3EVYH0eIZF0080eIZF0P2Y
L9420=RLU@80Zg6A0`3KWi@20:abT@<0gZ:D0P2]M9801@3RYYCo0000o`000?l00000[gJD00<0iJZE
00<0/GVG0>N^U`3W[YL00P3W[YL00`2Y_NP0jK>K0>VcV`1G0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`/0ZKgX0ol0000B0:Vmj0@0Z;gX
0P2W_NT20:Flj@<0Xkc[0P2M^^d309Vfk0<0VZgU0P2OXmP30:BIbP80YY;000@0WhZm0:B4/@2TQ;40
Y8Ba102VPZd30:N3[P<0Yg^S102WOZL40:UjW`<0Z7nW1@2[OJ800`2ZQJd0[gjO0:mnW`040:f5ZP@0
/HRY102fSZd40;bH/`@0`JFn0P33]<`00ol00000`kC<0;jnf@020;jnf@030<??h`2g`^<0]l;S0080
]l;S0P2`_^@20;32i`80[KkW00<0[<3X0:^nj02[_^P00P2[_^P20:Zmj0030:Znj?l0003ooooo01?o
oooo000<ooooo`03o`000?oooooooooo00gooooo103AV9P50=FJUP80ZG2A0P3HW9D20:]aT@<0finD
0P2/LY430=jRU0?o00000P3RYY@20:mfU0<0iJZE00@0/GVG0>N^U`3W[YL0ijjG0`2Y_NP00`3Y/i/0
ZKgX0:Vmj01F0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Mooooo`L0ZKgX0ol0000F0:Vmj0<0Z;gX102V_NT20:>lj`030::lk02H^o00V;_`0080
V;_`0`28]_@00`1j[O<0P:7Y082Qj@0309>EdP@0WhZm0`2TQ;430:J2[@80Yh>^00<0YgZS0:MkX`2W
Nj<00P2WNj<30:MnY`@0ZGZO0P2XOjL20:ajW0@0ZgfR00<0ZXF]0:mnW`2_OYl00`2]QJX00`2dPil0
/HRY0;68Z@020;68Z@@0]Xj]102lV;<40<6U_P060=Bl``33]<`0`kC<o`00003@c=H0_[kI0`33cn<2
0;O2h`80]/WX0P2``^L00`2_`nT0[<3X0:c0j0020:c0j0<0ZkkX102Z_^P00ol0003oooooooooo`0A
ooooo`002oooool00ol0003oooooooooo`0?ooooo`<0dIRH1@3EVYH0102YL940f9bE0=RLU@3HW9D2
0:]aT@<0finD0P2/LY43o`000080[GBB0`3RYY@00`2_MY@0iJZE0>FZU@020>FZU@@0ijjGG@2Y_NP0
0ol00000ZKgX0:Vmj00E0:Vmj003o`000?oooooooooo01Wooooo00?o0000ooooooooool07oooool3
0:Vmj0?o00006P2Y_NP30:Rmj080Y[gY0P2W_NT30::lk080V;_`00@0V[c_082gm`20]oL0P;Og0P17
XOH2082Qj@<0TiGB0`2OR[d30:B4/@<0YX:]00@0Yh>^0:MjX`2WNZ<0YgZS0`2WNj<20:MnY`030:Uh
W@2YNYl0ZGZO0080ZGZO00@0Z7nW0:ajW02/NY`0[7ZL102[OJ840:mnW`040:f5ZP2dPil0]8>O0;B3
W`80/HRY00@0_8^R0;J>[@2fSZd0]Xj]0P35UjP20;bH/`80cZRb0P31YKh20=Bl``050<>dc03@c=H0
d<cFo`00003AinH00`33cn<20;gHk@030;K9j02ab^`0/L[/00<0[l?Y0P2/`>P00`2[`>T0ZkkX0:^n
j0020:^nj0@0Z[kX00?o0000ooooooooool04?ooool000_ooooo00?o0000ooooooooool03oooool3
0=6HV0D0eIZF00D0ZG2A0=RLU@3HW9D0f9bE0:]aT@030=^OU0?o00000`3NXY@00`2]M980hZJD0>:V
U0020>:VU0030:mfU03UZYD0iJZE0080iJZE103W[YMN0:Vmj003o`00002Y_NP0ZKgX01@0ZKgX00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Oooooo`?o00007P2Y_NP30:Rmj0@0YkgY00<0
X[c/0:Bmj`2T_N/00`2J_>l3082gm`<0Aj7f00<02W_R09>EdP2CUM800`2OR[d30:B4/@80YX:]00<0
Y7fX0:MjX`2WNZ<00P2WNZ<30:MkX`040:MnY`2YN9d0ZGRM0:UhW@<0ZGZO00@0Z7nW0:ajW02/NY`0
[7ZL102[OJ840:mnW`050:f5ZP2dPil0]8>O0;B3W`2aR:T00`2lRj820;J>[@80aINX00D0_9Rc0<jX
/P3>Z;80cZRb0<6U_P030=Bl``80i^[B00D0d<cF0=7Wi_l00000dNOV0<??h`020;gHk@030;;Bl@2a
b^`0/L[/0080/L[/00@0[l?Y0:c2jP2/`^X0[<;Z0P2[`>T20:^nj0@0Z[kX00<0ZKgXo`000?ooool0
4Oooool000_ooooo00?o0000ooooooooool03oooool20=6HV003ooooo`3EVYH0eIZF00<0eIZF00D0
ZG2A0=RLU@3HW9D0f9bE0:]aT@03o`0000030=^OU02/LY40gZ:D00<0gZ:D00<0[GBB0>:VU03RYY@0
0P3RYY@00`2_MY@0iJZE0>FZU@020>FZU@030:Vmj03W[YL0ijjG05l0ZKgX00?o00000:Vmj02Y_NP0
5@2Y_NP00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo0ol00003oooooal0ZKgX
0`2X_NP20:Nmj@80Z;gY0`2T_N/0102J_>l0X;c]0:2lk@2P_>d308bjm@80AZ?g0P1J0000100UNnH0
WhZm09n:_@2OR[d20:B4/@030:J2[@2TOJP0Y7fX00@0YgZS0`2WNj<0102WOZL0ZGRM0:UhW@2YN9d3
0:UjW`@0[7ZL0`2[OJ800`2bOIX0[gjO0:mnW`020:mnW`@0]8>O00D0/HRY0;b;XP2lRj80_8^R0;J>
[@030<FGZ0050;bH/`3>Z;80cZRb0<jX/P3]e[/00`3D_<<20>KZdP030<;neP3AinKo00000080_N_c
00@0_MS]0;;Bl@2bd_40/];a0P2ab^`20:c5k080[<;Z00<0Z/3Y0:Zoj@2Z_nT00P2Z_nT00`2Z_^P0
ZKkX0:Vmj0030:Vmj003o`000?oooooooooo00oooooo000;ooooo`03o`000?oooooooooo00oooooo
00<0dIRHooooooooool01@3EVYH00`2YL940f9bEo`000002o`0000@0finD00<0[7:A0=jRU03NXY@0
0P3NXY@00`2]M980hZJD0>:VU0020>:VU0040:mfU03UZYD0iJZE0>FZU@80ZKgX0P3W[YMP0:Vmj003
o`00002Y_NP0ZKgX01D0ZKgX00?o0000ooooooooool05oooool00ol0003oooooooooo`0Iooooo`?o
00001ooooolS0:Vmj0030:Rmj@2Y_NP0ZKgX00<0YkgY0P2P_>d20:FmjP<0Vkc_0`1e]?T0100UNnH0
NXKD07Z6e01jQ]@209^1]P@0Y7fX0`2WNZ<30:MkX`@0ZGRM0`2YNYl40:ajW0<0ZgfR00<0/WfJ0:mn
W`2_OYl00P2_OYl40;B3W`@0_8^R00@0]Xj]0<FGZ035UjP0aINX103>Z;820>gF^`040=Bl``3Vj]80
i^[B0<;neP80X_C_00@0_N_co`00002^fOH0[]Wf0P2bd_420:_7kP80[<G/00<0Z/7Z0:[0j@2Z`>T0
0P2Z`>T20:Zoj@@0ZKkX0`2Y_NP2o`00013ooooo000;ooooo`03o`000?oooooooooo00oooooo00<0
dIRHooooooooool0103EVYH3o`000080f9bE00<0Zg6A0=^OU03KWi@00P3KWi@00`2/LY40gZ:D0=jR
U0020=jRU0030:edTP3RYY@0hZJD0080hZJD103UZYD30:Vmj0030>N^U`2Y_NP0ZKgX05l0ZKgX00?o
00000:Vmj02Y_NP0502Y_NP00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo0ol0
000;ooooobH0ZKgX00<0YkgY0:Rmj02X_NP0102U_NX00`2K_>l0Y;g[0:Bmj`0309Jkl@0302EkiP1j
Q]@0NXKD0080Vh6f102TOJP30:MjX`<0Yg^S102YN9d30:UjW`D0[7ZL00<0ZgfR0;9mVP2bOIX00`2_
OYl20;Z4V`<0]8>O102lRj840<FGZ0030>>i[03>Z;80cZRb00<0kMJk00<0_njF0>KZdP1Wfm@00P2R
m>l20:GKnP040:kIm_l00000ZLS_0:W8k`80ZlO^00<0ZL7Z0:[1jP2Z`NX00P2Z`NX20:[0j@H0ZKkX
1@2Y_NP00ol0003oooooooooo`0>ooooo`002oooool00ol0003oooooooooo`0Cooooo`040=FJU_l0
003o00000=FJUP@0f9bE00<0Zg6A0=^OU03KWi@00P3KWi@00`2/LY40gZ:D0=jRU0020=jRU0030:ed
TP3RYY@0hZJD0080hZJD103UZYEV0:Vmj003o`00002Y_NP0ZKgX01<0ZKgX00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Dooooo`;o00003ooooolU0:Vmj0@0Z;gX0P2U_NX20:Rmj@<0Y;g[
00<0U[_a0:Bmj`2T_N/00P1jQ]@309^1]P<0Y7fX102WNZ<00`2WNj<0ZWVN0:UhW@030:UhW@80ZGZO
0P2^NYX40:ajW0040:]mXP2bOIX0/WfJ0;9mVP80[gjO0P2jQ9/30;B3W`050<B?W@2lRj80_8^R0;b;
XP3BX:800P35UjP30>>i[0050<jX/P3]e[/0kMJk0>gF^`2Ic_X00`2Le_`20:GKnP80YlK`00<0ZLS_
o`00002Y`>/0102Y`NX20:[1jP030:Vnj@2Y_^P0ZKkX00@0ZKkX1P2Y_NP00ooooooo0000ooooo`0?
ooooo`002_ooool00ol0003oooooooooo`0Booooo`?o00000`3EVYH40=RLU@D0finD00<0[7:A0=jR
U03NXY@00P3NXY@50>:VU0030:Vmj03UZYD0iJZE06L0ZKgX00?o00000:Vmj02Y_NP03@2Y_NP6oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04_ooool3o`0001;ooooo9@2Y_NP20:Rm
j080ZKgX0P2X_NT00`2Y_NP0Z;gY0:Rmj@020:Rmj@80Y;g[00<0Z;gY07Z6e01jQ]@00P2KPKH30:Am
Z0@0YgZS00<0Yg^S0:YiWP2ZNIh0102YN9d00`2YNYl0[WZJ0:ijVP040:ajW0040:]mXP2bOIX0/WfJ
0;9mVP80[gjO0P2jQ9/20;B3W`80a8nM0`2lRj800`3BX:80aINX0<FGZ0030>>i[0<0kMJk00<0VLkj
0:K1k@2V`Nd00`2U`nl20:O6l0030:RojP2Y`>_o00000080ZL3[0P2Y`NX50:Vnj@80ZKkX102Y_NP6
ooooo`03o`000?oooooooooo00kooooo000:ooooo`03o`000?oooooooooo00oooooo0ol00002oooo
o`<0eIZF00?ooooo0=RLU@3HW9D00P3HW9D50=^OU0D0gZ:D1@3RYY@00`2Y_NP0iJZE0>FZU@1X0:Vm
j003o`00002Y_NP0ZKgX00T0ZKgX2_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00oooooo0ol0000Fooooob`0ZKgX0P2X_NT20:Vmj0<0Z;gY00<0NXKD09^1]P2KPKH00`2TOJP40:Mj
X`<0ZWVN102YN9d00`2YNYl0[WZJ0:ijVP040:ajW0@0/WfJ00@0[gjO0;Z4V`2jQ9/0^XBK0P2dPil2
0<B?W@80_8^R0P3BX:820<FGZ0<0hkV/00<0h^b70>gF^`2W_n/0102V`Nd00`2U`nl0Z;kY0:Rnj@03
0:RojP040:W0jol00000ZKkX0:Vnj080ZKkY1`2Y_NP:ooooo`03o`000?oooooooooo00gooooo000:
ooooo`03o`000?oooooooooo00cooooo0ol00005ooooo`80eIZF0_ooool40=RLU@D0finD1@3NXY@4
0>:VU080ZKgX0P3UZYEY0:Vmj003o`00002Y_NP0ZKgX00D0ZKgX3Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00cooooo0ol0000Joooooc00ZKgX00<0Z;gY0:Vmj02Y_NP00`2KPKH3
0:AmZ080YgZS00@0YgbT0:YiWP2ZNIh0ZWVN102YN9d30:ijVP@0[7ZL102bOIX0102_OYl0^XBK0;Z4
V`2jQ9/20;B3W`80a8nM0P2lRj830=:PXP<0hkV/0P3Rk8L30:Noj`80Y/7]0`2X_^T50:Vmj0030:Vn
j?l00000ZKgX00H0ZKgX3Oooool00ol0003oooooooooo`0=ooooo`002_ooool00ol0003ooooooooo
o`09ooooo`?o00002?ooool20=FJUP;ooooo0`3HW9D00oooool0finD0=^OU0030=^OU0@0gZ:D0_oo
ool30>:VU6d0ZKgX00?o00000:Vmj02Y_NP00P2Y_NP@ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool02Oooool3o`0001kooooo<`2Y_NP201AOeP<0Y7fX00<0YgZS0:MlY02WO:@00`2Z
NIh40:UhW@<0[WZJ0`2/NY`00`2fOiT0/WfJ0;9mVP020;9mVP030:mnW`2jQ9/0^XBK0080^XBK00D0
]8>O0<B?W@34Sid0a8nM0;b;XP030=:PXP<0hkV/00<0h^b70:Vmj02Y_NP00`2Y_NP20:Rnj@P0ZKgX
00?o00000:Vmj02Y_NP00P2Y_NP@ooooo`03o`000?oooooooooo00gooooo000:ooooo`03o`000?oo
oooooooo00Kooooo0ol0000;ooooo`030=FJU_oooooooooo00;ooooo0P3HW9D00oooool0finD0=^O
U0020=^OU003ooooo`3NXY@0gZ:D0080gZ:D0_ooool30>:VU003ooooo`2Y_NP0ZKgX06/0ZKgX00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo0ol0
000Roooooc<0ZKgX00@055oF09Mo]`2GOkL0Ugng0`2WO:@30:YiWP@0ZGRM0`2^NYX30:ajW080]WnI
0`2bOIX50;Z4V`040;B3W`34Sid0a8nM0<B?W@@0dZ2R00<0oMjJ0>>i[03Rk8L04@2Y_NP00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00gooooo000:ooooo`03o`000?oooooooooo00?ooooo
0ol0000Cooooo`80f9bE00?ooooo0=^OU03KWi@00P3KWi@00oooool0gZ:D0=jRU0020=jRU0;ooooo
0P3RYY@3ooooofP0ZKgX1Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool00oooool3o`0002Kooooo<P2Y_NP0100DGmH0Ugng09Mo]`2GOkL30:MlY0<0
ZWVN0`2YN9d0102`OI`0[WZJ0:ijVP2^NYX30:ajW080]WnI0`2bOIX50;Z4V`@0a8nM0`3BX:820?gN
VP030>>i[02Y_NP0ZKgX00`0ZKgX1Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00gooooo0009ooooo`04o`000?ooooooooooooooo`?o00005_ooool0103HW9Goooooooooooooool3
0=^OU0;ooooo0P3NXY@3ooooo`80hZJD1?oooomT0:Vmj0Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Dooooo`04o`000?ooooooooooooooo`?o0000:_oooolb0:Vmj0<0Ugng0`2W
O:@40:YiWP80ZGRM00<0/7fL0:ijVP2^NYX00P2^NYX0102/NY`0]WnI0;IoV@2fOiT30;9mVPD0^XBK
1034Sid30=:PXP80oMjJ302Y_NP9ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3Oooool000Wooooo1?l0000Iooooo`040=RLUOooooooooooooooo`80finD0oooool20=jRU0Cooooo
00<0hZJDooooooooool01?oooomO0:Vmj0cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Dooooo`Co0000;oooool`0:Vmj00301AOeP2GOkL0Ugng00@0YgbT0`2ZNIh0102YN9d0/7fL
0;1mW02`OI`30:ijVP040:ajW02fOiT0]WnI0;IoV@80/WfJ0P31RYX40;Z4V`@0a8nM0`3BX:820?gN
VPT0ZKgX3?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo0009ooooo`;o
00006oooool0103HW9Goooooooooooooool20=^OU0?ooooo00<0gZ:Dooooooooool02_oooomM0:Vm
j0oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`;o0000<Oooool`0:Vm
j00401AOeP2GOkL0Ugng09Mo]`<0YgbT0`2ZNIh0102YN9d0/7fL0;1mW02`OI`30:ijVP040:ajW02f
OiT0]WnI0;IoV@80/WfJ0P31RYX40;Z4V`<0a8nM0P3[^Il00`3BX:80oMjJ0?gNVP080:Vmj0oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`002oooool00ol0003ooooooooo
o`0Looooo`030=^OU?oooooooooo00;ooooo00<0gZ:Dooooooooool02ooooomI0:Vmj1?ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02oooooo<02Y
_NP309Mo]`<0YgbT0`2ZNIh40;1mW0<0[WZJ102fOiT20;9mVP80`HZJ0`2jQ9/0103BVi`0a8nM0<B?
W@34Sid20>^iW`030=:PXP3mgYX0oMjJ00D0ZKgX4oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00cooooo000<ooooo`03o`000?oooooooooo01_ooooo00<0finDooooooooool00_oo
ool00`3NXYCoooooooooo`0=oooooe40ZKgX6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0<?ooool_0:Vmj080Ugng0`2WO:@30:YiWP@0/7fL0`2^
NYX40;IoV@80/WfJ0P31RYX30;Z4V`80dY^L0P34Sid20>^iW`030=:PXP3mgYX0oMjJ01Wooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0J
ooooo`030=^OU?oooooooooo01;oooooC`2Y_NPLooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0_oooooc00ZKgX00@0Ugng0:MlY02WO:@0YgbT0P2Z
NIh00`2_PZ@0/7fL0;1mW0020;1mW0<0[WZJ1@2fOiT00`2bOIX0`HZJ0<6:VP030;Z4V`80dY^L00D0
a8nM0>^iW`3[^Il0jkVO0000400Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool000kooooo0_l0000`oooood/0ZKgX8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01Sooooo0_l0000`oooooc00ZKgX0`2WO:@0102ZNIh0[h:T0:n2Y02_PZ@30;1mW080[WZJ
00<0^hJL0;IoV@2fOiT00`2fOiT30<6:VP80^XBK0`3BVi`01034Sid0jkVO0>^iW`3[^IlMooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0013ooooo00?o0000ooooooooool0
;ooooom60:Vmj2Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo02oooooo;P2Y_NP308j;b`@0[h:T0`2`OI`20:ijVP80^hJL102fOiT40<6:VP050;Z4
V`3BVi`0dY^L0=:KW034Sid00`3[^IlNooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool0017ooooo00?o0000ooooooooool0;ooooom00:Vmj2[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02oooooo;P2Y_NP208j;b`@0[h:T
102`OI`00`2^NYX0^hJL0;^6W0040;IoV@@0`HZJ00@0^XBK0=:KW03BVi`0dY^L0`3[^IlPooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool001;ooooo00?o0000ooooooooool0
;ooooolm0:Vmj2cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo02oooooo;@2Y_NP308j;b`<0[h:T102`OI`00`2^NYX0^hJL0;^6W0040;IoV@@0`HZJ
103BVi`30>^iWb3ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`004ooo
ool2o`00033ooooo>@2Y_NP`ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?oo
ool2o`00033ooooo;@2Y_NP208j;b`<0[h:T102`OI`00`2^NYX0^hJL0;^6W0040;IoV@@0`HZJ103B
Vi`00`3RfF@0jkVO0>^iW`0Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool001Gooooo00?o0000ooooooooool0;ooooolb0:Vmj3Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02oooooo:`2Y_NP208j;b`<0[h:T102`OI`3
0;^6W0<0]WnI0P3>VIh30<6:VP@0dY^L0P3RfF@Sooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02oooool001Kooooo00?o0000ooooooooool0;_ooool_0:Vmj3[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02kooooo;02Y_NP0102>
Rl/0[h:T0:n2Y02_PZ@40;1mW0<0^hJL0`2fOiT20<jIWP<0`HZJ00<0l<6N0=:KW03BVi`00`3RfF@T
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool001Oooooo00?o0000oooo
ooooool0;_ooool/0:Vmj3cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo02kooooo;02Y_NP40:n2Y0<0/7fL0`2kQY`30;IoV@80cYVN0P31RYX20?31
WP80dY^L0P3RfF@Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool001So
oooo0_l0000`ooooobL0ZKgX@?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027o
oooo0_l0000`ooooobL0ZKgX0oooool0102>Rl/0[h:T0:n2Y02_PZ@20;1mW0030<6GZ`2kQY`0^hJL
0080^hJL00@0]WnI0<jIWP3>VIh0cYVN0P31RYX20?31WP80dY^L00<0h]UTooooooooool09Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo
02gooooo8P2Y_NQ6ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0]ooooob80ZKgX2Oooool30:n2Y0030;1mW031Uj/0`IN[00@0^hJL00@0]WnI0<jI
WP3>VIh0cYVN0P31RYX20?31WP80dY^L:Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00[ooooo000Kooooo`03o`000?oooooooooo02gooooo7`2Y_NQ9ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0]oooooal0ZKgX3Oooool0101I
0000`IN[0<6GZ`31Uj/40;^6W0040;IoV@3>VIh0cYVN0<jIWP80`HZJ0`3``Ih00`3BVicooooooooo
o`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool001cooooo00?o0000
ooooooooool0;_oooolH0:Vmj4kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo02kooooo602Y_NPBooooo`0305T00031Uj/0`IN[0080`IN[0`2kQY`5
0<jIWP040<6:VP3``Ih0l<6N0?31WR_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0:ooooo`007Oooool00ol0003oooooooooo`0^oooooa@0ZKgXD_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0;_oooolD0:Vmj1Kooooo1031Uj/3
0;^6W0D0cYVN103``Ih/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0
01kooooo0_l0000_oooooa40ZKgXEOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02Kooooo0_l0000^oooooa80ZKgX6?ooool0101I0000`IN[0<6GZ`31Uj/30;^6W0D0cYVN103``Ih]
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0023ooooo00?o0000oooo
ooooool0;Oooool;0:Vmj5[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo02cooooo302Y_NPMooooo`0405T00031Uj/0`IN[0<6GZ`80^hJL0P3ch;X4
0<jIWP<0l<6N;_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo000Qoooo
o`03o`000?oooooooooo02gooooo202Y_NQMooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0]ooooo`L0ZKgX8Oooool30<6GZ`040;^6W03ch;X0ln2j
0??P^P@0cYVN00?ooooo0?31W_ooool0;oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo000Rooooo`03o`000?oooooooooo02gooooo102Y_NQQooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0]ooooo`@0ZKgX9_ooool0102k
QY`0ln2j0??P^P3ch;X30<jIWSCooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09
ooooo`008oooool2o`0002gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02[ooooo0_l0000]ooooo`03o`000?oooooooooo02Wooooo0`3ch;X00`3>
VIkoooooooooo`0dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02co
oooo00<0cYVNooooooooool0=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo000Vooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0I?ooool01Ol0003ooooo
oooooooooooo000002oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Tooooo`05
o`000?ooooooooooooooool000002oooool002Oooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`1Uooooo`04o`000?ooooooooooo`00033ooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`1Uooooo`04o`000?ooooooooooo`0000_ooooo000Xooooo`;o0000:?ooool00ol0
003oooooooooo`1Vooooo`03o`000?oooooo0000037ooooo0_l0000Xooooo`03o`000?oooooooooo
06Kooooo00?o0000ooooool000002oooool002[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooo000003?ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooo000000_ooooo000[ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0Ioooool00ol0003oooooo`00000cooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0Ioooool00ol0003oooooo`00000:ooooo`00;?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo06Sooooo0_l0000dooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0J?ooool2o`0000[ooooo000]ooooo`;o00008oooool00ol0003oooooooooo`1W
ooooo`?o0000=Oooool2o`0002?ooooo00?o0000ooooooooool0Ioooool3o`0000[ooooo000_oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Hoooool4o`0003[ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`1Sooooo`Co00003Oooool0033ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`1Pooooo`?o0000?oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo063ooooo0ol0000Aooooo`00<Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo05cooooo1?l00013ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
G?ooool4o`0001Cooooo000booooo`;o00007_ooool00ol0003oooooooooo`1Hooooo`Co0000B?oo
ool2o`0001kooooo00?o0000ooooooooool0F?ooool4o`0001Sooooo000dooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0E?ooool4o`0004kooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1Dooooo`Co00007?ooool003Gooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1Aooooo`?o0000Doooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
057ooooo0ol0000Pooooo`00=_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04go
oooo1?l0001Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0COooool4o`0002?o
oooo000gooooo`;o00006Oooool00ol0003oooooooooo`19ooooo`Co0000G?ooool2o`0001Wooooo
00?o0000ooooooooool0BOooool4o`0002Oooooo000iooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0AOooool4o`0006;ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`15ooooo`Co0000:oooool003[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`13
ooooo`?o0000Ioooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04?ooooo0ol0000_
ooooo`00>oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo1?l0001[oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?oooool4o`0003;ooooo000looooo`;o
00004oooool00ol0003oooooooooo`0kooooo`Co0000L?ooool2o`0001?ooooo00?o0000oooooooo
ool0>oooool4o`0003Kooooo000nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
=oooool4o`0007Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0gooooo`Co0000
>_ooool003oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`Co0000Nooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo1?l0000nooooo`00@?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo0ol00020ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0<?ooool3o`0004;ooooo0011ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0;?ooool4o`0008Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0/ooooo`Co0000AOooool004;ooooo0_l0000=ooooo`03o`000?oooooooooo02So
oooo1?l00029ooooo`;o00003Oooool00ol0003oooooooooo`0Xooooo`Co0000BOooool004Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`Co0000Soooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo02Cooooo1?l0001=ooooo`00AOooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo027ooooo0ol0002Dooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08Oooool3o`00057ooooo0016ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool07Oooool4o`0009Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0M
ooooo`Co0000E?ooool004Oooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0002Moooo
o`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000F?ooool004Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Eooooo`Co0000Xoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Gooooo1?l0001Looooo`00B_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01;ooooo0ol0002Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4_ooool3o`00063ooooo001;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_oo
ool4o`000:cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000Hooo
ool004cooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002aooooo`;o00000oooool0
0ol0003oooooooooo`0:ooooo`Co0000Ioooool004kooooo00Co0000oooooooooooo00002?ooool4
o`000;Oooooo00Co0000oooooooooooo00002?ooool4o`0006_ooooo001?ooooo`03o`000?oooooo
000000Gooooo0ol0002looooo`03o`000?oooooo000000Gooooo0ol0001_ooooo`00D?ooool2o`00
0003ooooool0003o000000;o0000`?ooool2o`000003ooooool0003o000000;o0000L_ooool0057o
oooo0_l00035ooooo`;o0000M_ooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-53.3508, \
-19.1129, 1.80794, 1.80794}, {{208.5, 389.375}, {315.688, 169}} -> {-412.962, \
-19.1129, 1.80794, 1.80794}, {{9.625, 190.438}, {154.375, 7.6875}} -> \
{-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, 389.375}, {154.375, \
7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[p1gb, p2gb, {{0, 255}, {0, 255}}, x, y, \ 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .03379 m
.02665 .04389 L
.04389 .06029 L
.04858 .06854 L
.06854 .08747 L
.07166 .0932 L
.0932 .11553 L
.09561 .11785 L
.11785 .14021 L
.12033 .1425 L
.1425 .16421 L
.14579 .16716 L
.16716 .18752 L
.17203 .19181 L
.19181 .21012 L
.19912 .21647 L
.21647 .23195 L
.22715 .24112 L
.24112 .25304 L
.25626 .26578 L
.26578 .27346 L
.28661 .29043 L
.29043 .29335 L
.31509 .31309 L
.31929 .31509 L
.33974 .33218 L
.35469 .33974 L
.3644 .34964 L
.3884 .3644 L
.38905 .3654 L
.41371 .37808 L
.43026 .38905 L
.43836 .3911 L
.46302 .39953 L
.47386 .38905 L
.46399 .3644 L
.46302 .36077 L
.44563 .33974 L
.43836 .32215 L
.428 .31509 L
.41371 .29419 L
.40942 .29043 L
.38919 .26578 L
.38905 .26562 L
.36651 .24112 L
.3644 .23874 L
.34284 .21647 L
.33974 .21314 L
.31829 .19181 L
.31509 .18853 L
.29295 .16716 L
.29043 .16471 L
.26683 .1425 L
.26578 .14153 L
.24112 .11876 L
.24006 .11785 L
.21647 .09649 L
.21256 .0932 L
.19181 .07502 L
.18401 .06854 L
.16716 .05444 L
.15416 .04389 L
.1425 .03213 L
.12273 .01923 L
.01923 .01923 L
F
0 g
.01923 .03379 m
.02665 .04389 L
.04389 .06029 L
.04858 .06854 L
.06854 .08747 L
.07166 .0932 L
.0932 .11553 L
.09561 .11785 L
.11785 .14021 L
.12033 .1425 L
.1425 .16421 L
.14579 .16716 L
.16716 .18752 L
.17203 .19181 L
.19181 .21012 L
.19912 .21647 L
.21647 .23195 L
.22715 .24112 L
.24112 .25304 L
.25626 .26578 L
.26578 .27346 L
.28661 .29043 L
.29043 .29335 L
.31509 .31309 L
.31929 .31509 L
.33974 .33218 L
.35469 .33974 L
.3644 .34964 L
.3884 .3644 L
.38905 .3654 L
.41371 .37808 L
.43026 .38905 L
.43836 .3911 L
.46302 .39953 L
.47386 .38905 L
.46399 .3644 L
.46302 .36077 L
.44563 .33974 L
.43836 .32215 L
.428 .31509 L
.41371 .29419 L
.40942 .29043 L
.38919 .26578 L
.38905 .26562 L
.36651 .24112 L
.3644 .23874 L
.34284 .21647 L
.33974 .21314 L
.31829 .19181 L
.31509 .18853 L
Mistroke
.29295 .16716 L
.29043 .16471 L
.26683 .1425 L
.26578 .14153 L
.24112 .11876 L
.24006 .11785 L
.21647 .09649 L
.21256 .0932 L
.19181 .07502 L
.18401 .06854 L
.16716 .05444 L
.15416 .04389 L
.1425 .03213 L
.12273 .01923 L
Mfstroke
.2 g
.10349 .01923 m
.11785 .02953 L
.13711 .04389 L
.1425 .0491 L
.16716 .06711 L
.16894 .06854 L
.19181 .0872 L
.19882 .0932 L
.21647 .10812 L
.22732 .11785 L
.24112 .12991 L
.25461 .1425 L
.26578 .15259 L
.28084 .16716 L
.29043 .17616 L
.30607 .19181 L
.31509 .20633 L
.3303 .21647 L
.33974 .23099 L
.35343 .24112 L
.3644 .25689 L
.36949 .26578 L
.38905 .28414 L
.3912 .29043 L
.41262 .31509 L
.41371 .31705 L
.42619 .33974 L
.41371 .35687 L
.38905 .34706 L
.37482 .33974 L
.3644 .33351 L
.33974 .31748 L
.33786 .31509 L
.31509 .3005 L
.30547 .29043 L
.29043 .28188 L
.27294 .26578 L
.26578 .25882 L
.24175 .24112 L
.24112 .24052 L
.21647 .21968 L
.21283 .21647 L
.19181 .19795 L
.18518 .19181 L
.16716 .17542 L
.15862 .16716 L
.1425 .15199 L
.13309 .1425 L
.11785 .12756 L
.10861 .11785 L
.0932 .10193 L
.08527 .0932 L
.06854 .07031 L
.06326 .06854 L
.04389 .0444 L
.04306 .04389 L
.02369 .01923 L
F
0 g
.10349 .01923 m
.11785 .02953 L
.13711 .04389 L
.1425 .0491 L
.16716 .06711 L
.16894 .06854 L
.19181 .0872 L
.19882 .0932 L
.21647 .10812 L
.22732 .11785 L
.24112 .12991 L
.25461 .1425 L
.26578 .15259 L
.28084 .16716 L
.29043 .17616 L
.30607 .19181 L
.31509 .20633 L
.3303 .21647 L
.33974 .23099 L
.35343 .24112 L
.3644 .25689 L
.36949 .26578 L
.38905 .28414 L
.3912 .29043 L
.41262 .31509 L
.41371 .31705 L
.42619 .33974 L
.41371 .35687 L
.38905 .34706 L
.37482 .33974 L
.3644 .33351 L
.33974 .31748 L
.33786 .31509 L
.31509 .3005 L
.30547 .29043 L
.29043 .28188 L
.27294 .26578 L
.26578 .25882 L
.24175 .24112 L
.24112 .24052 L
.21647 .21968 L
.21283 .21647 L
.19181 .19795 L
.18518 .19181 L
.16716 .17542 L
.15862 .16716 L
.1425 .15199 L
.13309 .1425 L
.11785 .12756 L
.10861 .11785 L
Mistroke
.0932 .10193 L
.08527 .0932 L
.06854 .07031 L
.06326 .06854 L
.04389 .0444 L
.04306 .04389 L
.02369 .01923 L
Mfstroke
.3 g
.09064 .01923 m
.0932 .02031 L
.11785 .03765 L
.12614 .04389 L
.1425 .05932 L
.15852 .06854 L
.16716 .07682 L
.18921 .0932 L
.19181 .09566 L
.21647 .11623 L
.21829 .11785 L
.24112 .13797 L
.24597 .1425 L
.26578 .16071 L
.27238 .16716 L
.29043 .18453 L
.29755 .19181 L
.31509 .21443 L
.32146 .21647 L
.33974 .23899 L
.34392 .24112 L
.3644 .26566 L
.36442 .26578 L
.38336 .29043 L
.38905 .30028 L
.39749 .31509 L
.38905 .33065 L
.3644 .32339 L
.35196 .31509 L
.33974 .31037 L
.31509 .291 L
.31462 .29043 L
.29043 .27355 L
.28343 .26578 L
.26578 .24853 L
.25252 .24112 L
.24112 .23017 L
.22268 .21647 L
.21647 .21059 L
.19429 .19181 L
.19181 .18952 L
.16737 .16716 L
.16716 .16697 L
.1425 .14314 L
.14189 .1425 L
.11785 .11803 L
.11768 .11785 L
.09483 .0932 L
.0932 .09154 L
.07322 .06854 L
.06854 .06271 L
.05277 .04389 L
.04389 .03164 L
.03767 .01923 L
F
0 g
.09064 .01923 m
.0932 .02031 L
.11785 .03765 L
.12614 .04389 L
.1425 .05932 L
.15852 .06854 L
.16716 .07682 L
.18921 .0932 L
.19181 .09566 L
.21647 .11623 L
.21829 .11785 L
.24112 .13797 L
.24597 .1425 L
.26578 .16071 L
.27238 .16716 L
.29043 .18453 L
.29755 .19181 L
.31509 .21443 L
.32146 .21647 L
.33974 .23899 L
.34392 .24112 L
.3644 .26566 L
.36442 .26578 L
.38336 .29043 L
.38905 .30028 L
.39749 .31509 L
.38905 .33065 L
.3644 .32339 L
.35196 .31509 L
.33974 .31037 L
.31509 .291 L
.31462 .29043 L
.29043 .27355 L
.28343 .26578 L
.26578 .24853 L
.25252 .24112 L
.24112 .23017 L
.22268 .21647 L
.21647 .21059 L
.19429 .19181 L
.19181 .18952 L
.16737 .16716 L
.16716 .16697 L
.1425 .14314 L
.14189 .1425 L
.11785 .11803 L
.11768 .11785 L
.09483 .0932 L
.0932 .09154 L
.07322 .06854 L
Mistroke
.06854 .06271 L
.05277 .04389 L
.04389 .03164 L
.03767 .01923 L
Mfstroke
.4 g
.07138 .01923 m
.0932 .02731 L
.11663 .04389 L
.11785 .04464 L
.1425 .06498 L
.15079 .06854 L
.16716 .0836 L
.18195 .0932 L
.19181 .10245 L
.21133 .11785 L
.21647 .12249 L
.23912 .1425 L
.24112 .14398 L
.26544 .16716 L
.26578 .16749 L
.29043 .1918 L
.29045 .19181 L
.31443 .21647 L
.31509 .21751 L
.33823 .24112 L
.33974 .24544 L
.36372 .26578 L
.3644 .27817 L
.37241 .29043 L
.3644 .30946 L
.33974 .30408 L
.32546 .29043 L
.31509 .28406 L
.29043 .26631 L
.28998 .26578 L
.26578 .24338 L
.25962 .24112 L
.24112 .22357 L
.23007 .21647 L
.21647 .20366 L
.20169 .19181 L
.19181 .18275 L
.17467 .16716 L
.16716 .16074 L
.14906 .1425 L
.1425 .13831 L
.12484 .11785 L
.11785 .11115 L
.10196 .0932 L
.0932 .08316 L
.08057 .06854 L
.06854 .05065 L
.0627 .04389 L
.05976 .01923 L
F
0 g
.07138 .01923 m
.0932 .02731 L
.11663 .04389 L
.11785 .04464 L
.1425 .06498 L
.15079 .06854 L
.16716 .0836 L
.18195 .0932 L
.19181 .10245 L
.21133 .11785 L
.21647 .12249 L
.23912 .1425 L
.24112 .14398 L
.26544 .16716 L
.26578 .16749 L
.29043 .1918 L
.29045 .19181 L
.31443 .21647 L
.31509 .21751 L
.33823 .24112 L
.33974 .24544 L
.36372 .26578 L
.3644 .27817 L
.37241 .29043 L
.3644 .30946 L
.33974 .30408 L
.32546 .29043 L
.31509 .28406 L
.29043 .26631 L
.28998 .26578 L
.26578 .24338 L
.25962 .24112 L
.24112 .22357 L
.23007 .21647 L
.21647 .20366 L
.20169 .19181 L
.19181 .18275 L
.17467 .16716 L
.16716 .16074 L
.14906 .1425 L
.1425 .13831 L
.12484 .11785 L
.11785 .11115 L
.10196 .0932 L
.0932 .08316 L
.08057 .06854 L
.06854 .05065 L
.0627 .04389 L
.05976 .01923 L
s
.5 g
.0932 .03671 m
.10406 .04389 L
.11785 .05145 L
.1425 .06828 L
.14328 .06854 L
.16716 .08827 L
.17587 .0932 L
.19181 .10753 L
.20577 .11785 L
.21647 .12727 L
.23391 .1425 L
.24112 .14753 L
.26058 .16716 L
.26578 .17261 L
.28604 .19181 L
.29043 .19749 L
.31071 .21647 L
.31509 .22429 L
.33521 .24112 L
.33974 .25471 L
.35732 .26578 L
.33974 .29016 L
.31509 .27731 L
.29829 .26578 L
.29043 .26053 L
.26578 .2413 L
.265 .24112 L
.24112 .21954 L
.23558 .21647 L
.21647 .19879 L
.20732 .19181 L
.19181 .17767 L
.18034 .16716 L
.16716 .15591 L
.15474 .1425 L
.1425 .13448 L
.13056 .11785 L
.11785 .10438 L
.108 .0932 L
.0932 .07403 L
.08837 .06854 L
.07696 .04389 L
F
0 g
.0932 .03671 m
.10406 .04389 L
.11785 .05145 L
.1425 .06828 L
.14328 .06854 L
.16716 .08827 L
.17587 .0932 L
.19181 .10753 L
.20577 .11785 L
.21647 .12727 L
.23391 .1425 L
.24112 .14753 L
.26058 .16716 L
.26578 .17261 L
.28604 .19181 L
.29043 .19749 L
.31071 .21647 L
.31509 .22429 L
.33521 .24112 L
.33974 .25471 L
.35732 .26578 L
.33974 .29016 L
.31509 .27731 L
.29829 .26578 L
.29043 .26053 L
.26578 .2413 L
.265 .24112 L
.24112 .21954 L
.23558 .21647 L
.21647 .19879 L
.20732 .19181 L
.19181 .17767 L
.18034 .16716 L
.16716 .15591 L
.15474 .1425 L
.1425 .13448 L
.13056 .11785 L
.11785 .10438 L
.108 .0932 L
.0932 .07403 L
.08837 .06854 L
.07696 .04389 L
.0932 .03671 L
s
.6 g
.11785 .05873 m
.13404 .06854 L
.1425 .07387 L
.16716 .09199 L
.16952 .0932 L
.19181 .11173 L
.20058 .11785 L
.21647 .1314 L
.22927 .1425 L
.24112 .15076 L
.2563 .16716 L
.26578 .17762 L
.28204 .19181 L
.29043 .20319 L
.30668 .21647 L
.31509 .23156 L
.32895 .24112 L
.33771 .26578 L
.31509 .26999 L
.3082 .26578 L
.29043 .25483 L
.27167 .24112 L
.26578 .23683 L
.24112 .21686 L
.24033 .21647 L
.21647 .1951 L
.21202 .19181 L
.19181 .17346 L
.1851 .16716 L
.16716 .15138 L
.15961 .1425 L
.1425 .12914 L
.13577 .11785 L
.11785 .09703 L
.11442 .0932 L
.09835 .06854 L
F
0 g
.11785 .05873 m
.13404 .06854 L
.1425 .07387 L
.16716 .09199 L
.16952 .0932 L
.19181 .11173 L
.20058 .11785 L
.21647 .1314 L
.22927 .1425 L
.24112 .15076 L
.2563 .16716 L
.26578 .17762 L
.28204 .19181 L
.29043 .20319 L
.30668 .21647 L
.31509 .23156 L
.32895 .24112 L
.33771 .26578 L
.31509 .26999 L
.3082 .26578 L
.29043 .25483 L
.27167 .24112 L
.26578 .23683 L
.24112 .21686 L
.24033 .21647 L
.21647 .1951 L
.21202 .19181 L
.19181 .17346 L
.1851 .16716 L
.16716 .15138 L
.15961 .1425 L
.1425 .12914 L
.13577 .11785 L
.11785 .09703 L
.11442 .0932 L
.09835 .06854 L
.11785 .05873 L
s
.7 g
.11785 .06804 m
.11927 .06854 L
.1425 .08012 L
.16198 .0932 L
.16716 .09686 L
.19181 .11588 L
.19476 .11785 L
.21647 .13569 L
.22432 .1425 L
.24112 .15495 L
.2517 .16716 L
.26578 .18277 L
.27729 .19181 L
.29043 .20931 L
.30044 .21647 L
.31509 .24081 L
.31556 .24112 L
.31509 .25828 L
.29043 .24871 L
.27936 .24112 L
.26578 .23169 L
.24617 .21647 L
.24112 .21245 L
.2166 .19181 L
.21647 .1917 L
.19181 .16928 L
.18963 .16716 L
.16716 .14602 L
.16441 .1425 L
.1425 .11995 L
.14143 .11785 L
.12213 .0932 L
.11785 .08514 L
.11492 .06854 L
F
0 g
.11785 .06804 m
.11927 .06854 L
.1425 .08012 L
.16198 .0932 L
.16716 .09686 L
.19181 .11588 L
.19476 .11785 L
.21647 .13569 L
.22432 .1425 L
.24112 .15495 L
.2517 .16716 L
.26578 .18277 L
.27729 .19181 L
.29043 .20931 L
.30044 .21647 L
.31509 .24081 L
.31556 .24112 L
.31509 .25828 L
.29043 .24871 L
.27936 .24112 L
.26578 .23169 L
.24617 .21647 L
.24112 .21245 L
.2166 .19181 L
.21647 .1917 L
.19181 .16928 L
.18963 .16716 L
.16716 .14602 L
.16441 .1425 L
.1425 .11995 L
.14143 .11785 L
.12213 .0932 L
.11785 .08514 L
.11492 .06854 L
.11785 .06804 L
s
.8 g
.1425 .08762 m
.15237 .0932 L
.16716 .10267 L
.18791 .11785 L
.19181 .12093 L
.21647 .14097 L
.21823 .1425 L
.24112 .16135 L
.24588 .16716 L
.26578 .18837 L
.27061 .19181 L
.29021 .21647 L
.29043 .21682 L
.30073 .24112 L
.29043 .24132 L
.29007 .24112 L
.26578 .22615 L
.2528 .21647 L
.24112 .20744 L
.22226 .19181 L
.21647 .18673 L
.19479 .16716 L
.19181 .16422 L
.16989 .1425 L
.16716 .13942 L
.148 .11785 L
.1425 .10996 L
.13189 .0932 L
F
0 g
.1425 .08762 m
.15237 .0932 L
.16716 .10267 L
.18791 .11785 L
.19181 .12093 L
.21647 .14097 L
.21823 .1425 L
.24112 .16135 L
.24588 .16716 L
.26578 .18837 L
.27061 .19181 L
.29021 .21647 L
.29043 .21682 L
.30073 .24112 L
.29043 .24132 L
.29007 .24112 L
.26578 .22615 L
.2528 .21647 L
.24112 .20744 L
.22226 .19181 L
.21647 .18673 L
.19479 .16716 L
.19181 .16422 L
.16989 .1425 L
.16716 .13942 L
.148 .11785 L
.1425 .10996 L
.13189 .0932 L
.1425 .08762 L
s
.9 g
.16716 .10964 m
.17966 .11785 L
.19181 .1269 L
.21141 .1425 L
.21647 .14702 L
.23873 .16716 L
.24112 .16965 L
.26241 .19181 L
.26578 .1962 L
.28004 .21647 L
.26578 .21954 L
.2612 .21647 L
.24112 .2019 L
.22861 .19181 L
.21647 .18129 L
.20072 .16716 L
.19181 .15824 L
.17619 .1425 L
.16716 .13157 L
.15606 .11785 L
F
0 g
.16716 .10964 m
.17966 .11785 L
.19181 .1269 L
.21141 .1425 L
.21647 .14702 L
.23873 .16716 L
.24112 .16965 L
.26241 .19181 L
.26578 .1962 L
.28004 .21647 L
.26578 .21954 L
.2612 .21647 L
.24112 .2019 L
.22861 .19181 L
.21647 .18129 L
.20072 .16716 L
.19181 .15824 L
.17619 .1425 L
.16716 .13157 L
.15606 .11785 L
.16716 .10964 L
s
1 g
.19181 .13464 m
.2027 .1425 L
.21647 .15447 L
.23074 .16716 L
.24112 .17881 L
.25243 .19181 L
.24112 .19494 L
.23693 .19181 L
.21647 .17471 L
.20794 .16716 L
.19181 .15047 L
.18427 .1425 L
F
0 g
.19181 .13464 m
.2027 .1425 L
.21647 .15447 L
.23074 .16716 L
.24112 .17881 L
.25243 .19181 L
.24112 .19494 L
.23693 .19181 L
.21647 .17471 L
.20794 .16716 L
.19181 .15047 L
.18427 .1425 L
.19181 .13464 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.46302 .52566 m
.48767 .52426 L
.51233 .52878 L
.53698 .53229 L
.55121 .53698 L
.56164 .54228 L
.58629 .55147 L
.60661 .56164 L
.61095 .56371 L
.6356 .57759 L
.64878 .58629 L
.66026 .59277 L
.68491 .60981 L
.68571 .61095 L
.70957 .62826 L
.716 .6356 L
.73422 .64854 L
.7445 .66026 L
.75888 .67388 L
.76959 .68491 L
.78353 .69887 L
.79117 .70957 L
.80819 .72887 L
.81039 .73422 L
.82563 .75888 L
.83284 .77456 L
.83489 .78353 L
.8356 .80819 L
.83284 .81532 L
.80819 .83225 L
.80471 .83284 L
.78353 .8334 L
.77294 .83284 L
.75888 .83007 L
.73422 .82142 L
.70957 .81523 L
.69327 .80819 L
.68491 .80457 L
.66026 .79206 L
.64563 .78353 L
.6356 .77824 L
.61095 .76261 L
.60688 .75888 L
.58629 .74572 L
.57269 .73422 L
.56164 .72712 L
.54152 .70957 L
.53698 .70543 L
.51434 .68491 L
.51233 .68298 L
.49108 .66026 L
.48767 .65673 L
.47177 .6356 L
.46302 .62537 L
.45595 .61095 L
.44229 .58629 L
.43836 .57406 L
.43672 .56164 L
.43836 .54753 L
.44334 .53698 L
F
0 g
.46302 .52566 m
.48767 .52426 L
.51233 .52878 L
.53698 .53229 L
.55121 .53698 L
.56164 .54228 L
.58629 .55147 L
.60661 .56164 L
.61095 .56371 L
.6356 .57759 L
.64878 .58629 L
.66026 .59277 L
.68491 .60981 L
.68571 .61095 L
.70957 .62826 L
.716 .6356 L
.73422 .64854 L
.7445 .66026 L
.75888 .67388 L
.76959 .68491 L
.78353 .69887 L
.79117 .70957 L
.80819 .72887 L
.81039 .73422 L
.82563 .75888 L
.83284 .77456 L
.83489 .78353 L
.8356 .80819 L
.83284 .81532 L
.80819 .83225 L
.80471 .83284 L
.78353 .8334 L
.77294 .83284 L
.75888 .83007 L
.73422 .82142 L
.70957 .81523 L
.69327 .80819 L
.68491 .80457 L
.66026 .79206 L
.64563 .78353 L
.6356 .77824 L
.61095 .76261 L
.60688 .75888 L
.58629 .74572 L
.57269 .73422 L
.56164 .72712 L
.54152 .70957 L
.53698 .70543 L
.51434 .68491 L
.51233 .68298 L
Mistroke
.49108 .66026 L
.48767 .65673 L
.47177 .6356 L
.46302 .62537 L
.45595 .61095 L
.44229 .58629 L
.43836 .57406 L
.43672 .56164 L
.43836 .54753 L
.44334 .53698 L
.46302 .52566 L
Mfstroke
.2 g
.48767 .55359 m
.51233 .55092 L
.53698 .55501 L
.56164 .56116 L
.5654 .56164 L
.58629 .57159 L
.61095 .58151 L
.6194 .58629 L
.6356 .59738 L
.66026 .61073 L
.66051 .61095 L
.68491 .63105 L
.69351 .6356 L
.70957 .64957 L
.72293 .66026 L
.73422 .67074 L
.7482 .68491 L
.75888 .69586 L
.76928 .70957 L
.78353 .72733 L
.78667 .73422 L
.79835 .75888 L
.80128 .78353 L
.78353 .80342 L
.75888 .80662 L
.73422 .80254 L
.70957 .79388 L
.68491 .78619 L
.67928 .78353 L
.66026 .7721 L
.6356 .76048 L
.63333 .75888 L
.61095 .7417 L
.59654 .73422 L
.58629 .72586 L
.56433 .70957 L
.56164 .70722 L
.53698 .68502 L
.53686 .68491 L
.51356 .66026 L
.51233 .65902 L
.49484 .6356 L
.48767 .63012 L
.48062 .61095 L
.47228 .58629 L
.4772 .56164 L
F
0 g
.48767 .55359 m
.51233 .55092 L
.53698 .55501 L
.56164 .56116 L
.5654 .56164 L
.58629 .57159 L
.61095 .58151 L
.6194 .58629 L
.6356 .59738 L
.66026 .61073 L
.66051 .61095 L
.68491 .63105 L
.69351 .6356 L
.70957 .64957 L
.72293 .66026 L
.73422 .67074 L
.7482 .68491 L
.75888 .69586 L
.76928 .70957 L
.78353 .72733 L
.78667 .73422 L
.79835 .75888 L
.80128 .78353 L
.78353 .80342 L
.75888 .80662 L
.73422 .80254 L
.70957 .79388 L
.68491 .78619 L
.67928 .78353 L
.66026 .7721 L
.6356 .76048 L
.63333 .75888 L
.61095 .7417 L
.59654 .73422 L
.58629 .72586 L
.56433 .70957 L
.56164 .70722 L
.53698 .68502 L
.53686 .68491 L
.51356 .66026 L
.51233 .65902 L
.49484 .6356 L
.48767 .63012 L
.48062 .61095 L
.47228 .58629 L
.4772 .56164 L
.48767 .55359 L
s
.3 g
.51233 .56961 m
.53698 .56802 L
.56164 .57399 L
.58629 .58308 L
.59735 .58629 L
.61095 .59376 L
.6356 .60813 L
.64284 .61095 L
.66026 .62347 L
.67909 .6356 L
.68491 .64024 L
.70957 .66026 L
.70957 .66026 L
.73422 .68425 L
.7348 .68491 L
.75554 .70957 L
.75888 .71396 L
.77077 .73422 L
.77943 .75888 L
.76967 .78353 L
.75888 .78843 L
.73422 .78814 L
.71059 .78353 L
.70957 .78323 L
.68491 .77339 L
.66026 .76141 L
.65256 .75888 L
.6356 .74797 L
.61202 .73422 L
.61095 .73344 L
.58629 .71394 L
.57968 .70957 L
.56164 .69371 L
.55199 .68491 L
.53698 .67013 L
.52879 .66026 L
.51233 .64024 L
.50996 .6356 L
.49742 .61095 L
.49413 .58629 L
F
0 g
.51233 .56961 m
.53698 .56802 L
.56164 .57399 L
.58629 .58308 L
.59735 .58629 L
.61095 .59376 L
.6356 .60813 L
.64284 .61095 L
.66026 .62347 L
.67909 .6356 L
.68491 .64024 L
.70957 .66026 L
.70957 .66026 L
.73422 .68425 L
.7348 .68491 L
.75554 .70957 L
.75888 .71396 L
.77077 .73422 L
.77943 .75888 L
.76967 .78353 L
.75888 .78843 L
.73422 .78814 L
.71059 .78353 L
.70957 .78323 L
.68491 .77339 L
.66026 .76141 L
.65256 .75888 L
.6356 .74797 L
.61202 .73422 L
.61095 .73344 L
.58629 .71394 L
.57968 .70957 L
.56164 .69371 L
.55199 .68491 L
.53698 .67013 L
.52879 .66026 L
.51233 .64024 L
.50996 .6356 L
.49742 .61095 L
.49413 .58629 L
.51233 .56961 L
s
.4 g
.53698 .58103 m
.56164 .58401 L
.57151 .58629 L
.58629 .5913 L
.61095 .60294 L
.62855 .61095 L
.6356 .6154 L
.66026 .63187 L
.66667 .6356 L
.68491 .64997 L
.6977 .66026 L
.70957 .67077 L
.72325 .68491 L
.73422 .69544 L
.74349 .70957 L
.7579 .73422 L
.75888 .73715 L
.76159 .75888 L
.75888 .76482 L
.73422 .77858 L
.70957 .77271 L
.68491 .76418 L
.66908 .75888 L
.66026 .75381 L
.6356 .73937 L
.6255 .73422 L
.61095 .72389 L
.59085 .70957 L
.58629 .70594 L
.56243 .68491 L
.56164 .68429 L
.53946 .66026 L
.53698 .65728 L
.52217 .6356 L
.51233 .61216 L
.51205 .61095 L
.51233 .59874 L
.52033 .58629 L
F
0 g
.53698 .58103 m
.56164 .58401 L
.57151 .58629 L
.58629 .5913 L
.61095 .60294 L
.62855 .61095 L
.6356 .6154 L
.66026 .63187 L
.66667 .6356 L
.68491 .64997 L
.6977 .66026 L
.70957 .67077 L
.72325 .68491 L
.73422 .69544 L
.74349 .70957 L
.7579 .73422 L
.75888 .73715 L
.76159 .75888 L
.75888 .76482 L
.73422 .77858 L
.70957 .77271 L
.68491 .76418 L
.66908 .75888 L
.66026 .75381 L
.6356 .73937 L
.6255 .73422 L
.61095 .72389 L
.59085 .70957 L
.58629 .70594 L
.56243 .68491 L
.56164 .68429 L
.53946 .66026 L
.53698 .65728 L
.52217 .6356 L
.51233 .61216 L
.51205 .61095 L
.51233 .59874 L
.52033 .58629 L
.53698 .58103 L
s
.5 g
.53698 .59618 m
.56164 .59123 L
.58629 .59967 L
.61095 .60983 L
.6139 .61095 L
.6356 .62317 L
.65605 .6356 L
.66026 .63851 L
.68491 .65778 L
.68797 .66026 L
.70957 .6803 L
.71364 .68491 L
.73354 .70957 L
.73422 .71069 L
.74578 .73422 L
.74021 .75888 L
.73422 .76378 L
.70957 .76318 L
.69165 .75888 L
.68491 .75702 L
.66026 .74593 L
.63737 .73422 L
.6356 .73303 L
.61095 .71624 L
.60129 .70957 L
.58629 .69759 L
.5724 .68491 L
.56164 .67586 L
.54956 .66026 L
.53698 .64264 L
.53312 .6356 L
.52568 .61095 L
F
0 g
.53698 .59618 m
.56164 .59123 L
.58629 .59967 L
.61095 .60983 L
.6139 .61095 L
.6356 .62317 L
.65605 .6356 L
.66026 .63851 L
.68491 .65778 L
.68797 .66026 L
.70957 .6803 L
.71364 .68491 L
.73354 .70957 L
.73422 .71069 L
.74578 .73422 L
.74021 .75888 L
.73422 .76378 L
.70957 .76318 L
.69165 .75888 L
.68491 .75702 L
.66026 .74593 L
.63737 .73422 L
.6356 .73303 L
.61095 .71624 L
.60129 .70957 L
.58629 .69759 L
.5724 .68491 L
.56164 .67586 L
.54956 .66026 L
.53698 .64264 L
.53312 .6356 L
.52568 .61095 L
.53698 .59618 L
s
.6 g
.56164 .60113 m
.58629 .60756 L
.59649 .61095 L
.61095 .61608 L
.6356 .62997 L
.64556 .6356 L
.66026 .64541 L
.67907 .66026 L
.68491 .66331 L
.70497 .68491 L
.70957 .69035 L
.72398 .70957 L
.73296 .73422 L
.70957 .75314 L
.68491 .75009 L
.66026 .73897 L
.64904 .73422 L
.6356 .72635 L
.61095 .70961 L
.61089 .70957 L
.58629 .68967 L
.58133 .68491 L
.56164 .66502 L
.55867 .66026 L
.54298 .6356 L
.54391 .61095 L
F
0 g
.56164 .60113 m
.58629 .60756 L
.59649 .61095 L
.61095 .61608 L
.6356 .62997 L
.64556 .6356 L
.66026 .64541 L
.67907 .66026 L
.68491 .66331 L
.70497 .68491 L
.70957 .69035 L
.72398 .70957 L
.73296 .73422 L
.70957 .75314 L
.68491 .75009 L
.66026 .73897 L
.64904 .73422 L
.6356 .72635 L
.61095 .70961 L
.61089 .70957 L
.58629 .68967 L
.58133 .68491 L
.56164 .66502 L
.55867 .66026 L
.54298 .6356 L
.54391 .61095 L
.56164 .60113 L
s
.7 g
.56164 .61705 m
.58629 .61586 L
.61095 .62259 L
.63412 .6356 L
.6356 .63646 L
.66026 .65233 L
.67017 .66026 L
.68491 .66971 L
.69638 .68491 L
.70957 .70231 L
.71419 .70957 L
.71805 .73422 L
.70957 .74119 L
.68491 .742 L
.66517 .73422 L
.66026 .73217 L
.6356 .71978 L
.61956 .70957 L
.61095 .7056 L
.5895 .68491 L
.58629 .68132 L
.56694 .66026 L
.56164 .65076 L
.55398 .6356 L
F
0 g
.56164 .61705 m
.58629 .61586 L
.61095 .62259 L
.63412 .6356 L
.6356 .63646 L
.66026 .65233 L
.67017 .66026 L
.68491 .66971 L
.69638 .68491 L
.70957 .70231 L
.71419 .70957 L
.71805 .73422 L
.70957 .74119 L
.68491 .742 L
.66517 .73422 L
.66026 .73217 L
.6356 .71978 L
.61956 .70957 L
.61095 .7056 L
.5895 .68491 L
.58629 .68132 L
.56694 .66026 L
.56164 .65076 L
.55398 .6356 L
.56164 .61705 L
s
.8 g
.58629 .62524 m
.61095 .63034 L
.62093 .6356 L
.6356 .64336 L
.66026 .65999 L
.66058 .66026 L
.68491 .68099 L
.68731 .68491 L
.70351 .70957 L
.68491 .73171 L
.66026 .72489 L
.6356 .71265 L
.63035 .70957 L
.61095 .69934 L
.59777 .68491 L
.58629 .6719 L
.57593 .66026 L
.56803 .6356 L
F
0 g
.58629 .62524 m
.61095 .63034 L
.62093 .6356 L
.6356 .64336 L
.66026 .65999 L
.66058 .66026 L
.68491 .68099 L
.68731 .68491 L
.70351 .70957 L
.68491 .73171 L
.66026 .72489 L
.6356 .71265 L
.63035 .70957 L
.61095 .69934 L
.59777 .68491 L
.58629 .6719 L
.57593 .66026 L
.56803 .6356 L
.58629 .62524 L
s
.9 g
.61095 .6396 m
.6356 .65084 L
.65007 .66026 L
.66026 .66834 L
.67745 .68491 L
.68491 .69562 L
.69075 .70957 L
.68491 .71876 L
.66026 .7168 L
.644 .70957 L
.6356 .70477 L
.61095 .68833 L
.60815 .68491 L
.58735 .66026 L
F
0 g
.61095 .6396 m
.6356 .65084 L
.65007 .66026 L
.66026 .66834 L
.67745 .68491 L
.68491 .69562 L
.69075 .70957 L
.68491 .71876 L
.66026 .7168 L
.644 .70957 L
.6356 .70477 L
.61095 .68833 L
.60815 .68491 L
.58735 .66026 L
.61095 .6396 L
s
1 g
.61095 .65132 m
.6356 .65982 L
.63634 .66026 L
.66026 .67919 L
.66556 .68491 L
.66026 .70573 L
.6356 .69546 L
.62065 .68491 L
.61095 .67495 L
.60146 .66026 L
F
0 g
.61095 .65132 m
.6356 .65982 L
.63634 .66026 L
.66026 .67919 L
.66556 .68491 L
.66026 .70573 L
.6356 .69546 L
.62065 .68491 L
.61095 .67495 L
.60146 .66026 L
.61095 .65132 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Mtetra
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Mtetra
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Mtetra
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Mtetra
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Mtetra
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Mtetra
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Mtetra
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Mtetra
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Mtetra
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Mtetra
.57384 .54314 .58111 .55092 .59512 .54671 .5879 .53889 Mtetra
.5879 .53889 .59512 .54671 .60921 .54249 .60203 .53463 Mtetra
.60203 .53463 .60921 .54249 .62337 .53824 .61624 .53034 Mtetra
.61624 .53034 .62337 .53824 .63759 .53397 .63052 .52603 Mtetra
.63052 .52603 .63759 .53397 .6519 .52968 .64487 .5217 Mtetra
.64487 .5217 .6519 .52968 .66627 .52537 .6593 .51735 Mtetra
.6593 .51735 .66627 .52537 .68072 .52103 .67379 .51297 Mtetra
.67379 .51297 .68072 .52103 .69524 .51668 .68837 .50857 Mtetra
.68837 .50857 .69524 .51668 .70984 .5123 .70302 .50415 Mtetra
.70302 .50415 .70984 .5123 .72452 .5079 .71774 .49971 Mtetra
.71774 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Mtetra
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Mtetra
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Mtetra
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Mtetra
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Mtetra
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Mtetra
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Mtetra
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Mtetra
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Mtetra
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Mtetra
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .53529 Mtetra
.5665 .53529 .57384 .54314 .5879 .53889 .58061 .531 Mtetra
.58061 .531 .5879 .53889 .60203 .53463 .59479 .5267 Mtetra
.59479 .5267 .60203 .53463 .61624 .53034 .60905 .52237 Mtetra
.60905 .52237 .61624 .53034 .63052 .52603 .62338 .51802 Mtetra
.62338 .51802 .63052 .52603 .64487 .5217 .63778 .51365 Mtetra
.63778 .51365 .64487 .5217 .6593 .51735 .65225 .50925 Mtetra
.65225 .50925 .6593 .51735 .67379 .51297 .6668 .50483 Mtetra
.6668 .50483 .67379 .51297 .68837 .50857 .68143 .50039 Mtetra
.68143 .50039 .68837 .50857 .70302 .50415 .69613 .49593 Mtetra
.69613 .49593 .70302 .50415 .71774 .49971 .71091 .49144 Mtetra
.71091 .49144 .71774 .49971 .73255 .49524 .72577 .48693 Mtetra
.72577 .48693 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Mtetra
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Mtetra
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Mtetra
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55702 Mtetra
.46198 .55702 .4697 .56468 .48332 .56054 .47564 .55285 Mtetra
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Mtetra
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Mtetra
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .5402 Mtetra
.51705 .5402 .5246 .54801 .5385 .54379 .531 .53594 Mtetra
.531 .53594 .5385 .54379 .55246 .53955 .54501 .53166 Mtetra
.54501 .53166 .55246 .53955 .5665 .53529 .5591 .52736 Mtetra
.5591 .52736 .5665 .53529 .58061 .531 .57325 .52304 Mtetra
.57325 .52304 .58061 .531 .59479 .5267 .58748 .51869 Mtetra
.58748 .51869 .59479 .5267 .60905 .52237 .60179 .51432 Mtetra
.60179 .51432 .60905 .52237 .62338 .51802 .61616 .50993 Mtetra
.61616 .50993 .62338 .51802 .63778 .51365 .63062 .50552 Mtetra
.63062 .50552 .63778 .51365 .65225 .50925 .64514 .50108 Mtetra
.64514 .50108 .65225 .50925 .6668 .50483 .65974 .49662 Mtetra
.65974 .49662 .6668 .50483 .68143 .50039 .67442 .49214 Mtetra
.67442 .49214 .68143 .50039 .69613 .49593 .68918 .48763 Mtetra
.68918 .48763 .69613 .49593 .71091 .49144 .70401 .4831 Mtetra
.70401 .4831 .71091 .49144 .72577 .48693 .71892 .47854 Mtetra
.71892 .47854 .72577 .48693 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46936 Mtetra
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Mtetra
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56181 Mtetra
.41347 .56181 .42139 .56942 .43486 .56531 .42697 .55767 Mtetra
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .55349 Mtetra
.44054 .55349 .44838 .56118 .46198 .55702 .45418 .5493 Mtetra
.45418 .5493 .46198 .55702 .47564 .55285 .46789 .54509 Mtetra
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Mtetra
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Mtetra
.49552 .5366 .50318 .54444 .51705 .5402 .50944 .53232 Mtetra
.50944 .53232 .51705 .5402 .531 .53594 .52343 .52802 Mtetra
.52343 .52802 .531 .53594 .54501 .53166 .53749 .5237 Mtetra
.53749 .5237 .54501 .53166 .5591 .52736 .55162 .51936 Mtetra
.55162 .51936 .5591 .52736 .57325 .52304 .56582 .51499 Mtetra
.56582 .51499 .57325 .52304 .58748 .51869 .5801 .51061 Mtetra
.5801 .51061 .58748 .51869 .60179 .51432 .59446 .5062 Mtetra
.59446 .5062 .60179 .51432 .61616 .50993 .60888 .50176 Mtetra
.60888 .50176 .61616 .50993 .63062 .50552 .62338 .49731 Mtetra
.62338 .49731 .63062 .50552 .64514 .50108 .63796 .49283 Mtetra
.63796 .49283 .64514 .50108 .65974 .49662 .65262 .48832 Mtetra
.65262 .48832 .65974 .49662 .67442 .49214 .66735 .4838 Mtetra
.66735 .4838 .67442 .49214 .68918 .48763 .68215 .47925 Mtetra
.68215 .47925 .68918 .48763 .70401 .4831 .69704 .47467 Mtetra
.69704 .47467 .70401 .4831 .71892 .47854 .712 .47007 Mtetra
.712 .47007 .71892 .47854 .73391 .47397 .72705 .46545 Mtetra
.72705 .46545 .73391 .47397 .74897 .46936 .74217 .4608 Mtetra
.74217 .4608 .74897 .46936 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Mtetra
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Mtetra
.39199 .55831 .40003 .56594 .41347 .56181 .40547 .55414 Mtetra
.40547 .55414 .41347 .56181 .42697 .55767 .41902 .54995 Mtetra
.41902 .54995 .42697 .55767 .44054 .55349 .43263 .54574 Mtetra
.43263 .54574 .44054 .55349 .45418 .5493 .44632 .54151 Mtetra
.44632 .54151 .45418 .5493 .46789 .54509 .46007 .53726 Mtetra
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .53298 Mtetra
.47389 .53298 .48167 .54086 .49552 .5366 .48778 .52869 Mtetra
.48778 .52869 .49552 .5366 .50944 .53232 .50175 .52437 Mtetra
.50175 .52437 .50944 .53232 .52343 .52802 .51578 .52003 Mtetra
.51578 .52003 .52343 .52802 .53749 .5237 .52989 .51567 Mtetra
.52989 .51567 .53749 .5237 .55162 .51936 .54407 .51128 Mtetra
.54407 .51128 .55162 .51936 .56582 .51499 .55833 .50688 Mtetra
.55833 .50688 .56582 .51499 .5801 .51061 .57265 .50245 Mtetra
.57265 .50245 .5801 .51061 .59446 .5062 .58706 .49799 Mtetra
.58706 .49799 .59446 .5062 .60888 .50176 .60153 .49352 Mtetra
.60153 .49352 .60888 .50176 .62338 .49731 .61609 .48902 Mtetra
.61609 .48902 .62338 .49731 .63796 .49283 .63071 .48449 Mtetra
.63071 .48449 .63796 .49283 .65262 .48832 .64542 .47995 Mtetra
.64542 .47995 .65262 .48832 .66735 .4838 .6602 .47538 Mtetra
.6602 .47538 .66735 .4838 .68215 .47925 .67506 .47078 Mtetra
.67506 .47078 .68215 .47925 .69704 .47467 .69 .46616 Mtetra
.69 .46616 .69704 .47467 .712 .47007 .70502 .46152 Mtetra
.70502 .46152 .712 .47007 .72705 .46545 .72012 .45685 Mtetra
.72012 .45685 .72705 .46545 .74217 .4608 .7353 .45216 Mtetra
.7353 .45216 .74217 .4608 .75737 .45613 .75056 .44744 Mtetra
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Mtetra
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Mtetra
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Mtetra
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Mtetra
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Mtetra
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53791 Mtetra
.42465 .53791 .43263 .54574 .44632 .54151 .43837 .53364 Mtetra
.43837 .53364 .44632 .54151 .46007 .53726 .45217 .52935 Mtetra
.45217 .52935 .46007 .53726 .47389 .53298 .46604 .52504 Mtetra
.46604 .52504 .47389 .53298 .48778 .52869 .47998 .5207 Mtetra
.47998 .5207 .48778 .52869 .50175 .52437 .49399 .51634 Mtetra
.49399 .51634 .50175 .52437 .51578 .52003 .50807 .51196 Mtetra
.50807 .51196 .51578 .52003 .52989 .51567 .52222 .50756 Mtetra
.52222 .50756 .52989 .51567 .54407 .51128 .53645 .50313 Mtetra
.53645 .50313 .54407 .51128 .55833 .50688 .55076 .49868 Mtetra
.55076 .49868 .55833 .50688 .57265 .50245 .56513 .49421 Mtetra
.56513 .49421 .57265 .50245 .58706 .49799 .57958 .48971 Mtetra
.57958 .48971 .58706 .49799 .60153 .49352 .59411 .48519 Mtetra
.59411 .48519 .60153 .49352 .61609 .48902 .60871 .48065 Mtetra
.60871 .48065 .61609 .48902 .63071 .48449 .6234 .47608 Mtetra
.6234 .47608 .63071 .48449 .64542 .47995 .63815 .47149 Mtetra
.63815 .47149 .64542 .47995 .6602 .47538 .65299 .46688 Mtetra
.65299 .46688 .6602 .47538 .67506 .47078 .6679 .46224 Mtetra
.6679 .46224 .67506 .47078 .69 .46616 .6829 .45757 Mtetra
.6829 .45757 .69 .46616 .70502 .46152 .69797 .45288 Mtetra
.69797 .45288 .70502 .46152 .72012 .45685 .71312 .44817 Mtetra
.71312 .44817 .72012 .45685 .7353 .45216 .72836 .44343 Mtetra
.72836 .44343 .7353 .45216 .75056 .44744 .74368 .43866 Mtetra
.74368 .43866 .75056 .44744 .7659 .4427 .75908 .43387 Mtetra
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42905 Mtetra
.77456 .42905 .78132 .43793 .79683 .43313 .79013 .42421 Mtetra
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Mtetra
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .5343 Mtetra
.40288 .5343 .41099 .54216 .42465 .53791 .41658 .53001 Mtetra
.41658 .53001 .42465 .53791 .43837 .53364 .43036 .5257 Mtetra
.43036 .5257 .43837 .53364 .45217 .52935 .4442 .52137 Mtetra
.4442 .52137 .45217 .52935 .46604 .52504 .45811 .51701 Mtetra
.45811 .51701 .46604 .52504 .47998 .5207 .4721 .51263 Mtetra
.4721 .51263 .47998 .5207 .49399 .51634 .48615 .50823 Mtetra
.48615 .50823 .49399 .51634 .50807 .51196 .50028 .50381 Mtetra
.50028 .50381 .50807 .51196 .52222 .50756 .51448 .49937 Mtetra
.51448 .49937 .52222 .50756 .53645 .50313 .52876 .4949 Mtetra
.52876 .4949 .53645 .50313 .55076 .49868 .54311 .4904 Mtetra
.54311 .4904 .55076 .49868 .56513 .49421 .55754 .48589 Mtetra
.55754 .48589 .56513 .49421 .57958 .48971 .57204 .48135 Mtetra
.57204 .48135 .57958 .48971 .59411 .48519 .58662 .47679 Mtetra
.58662 .47679 .59411 .48519 .60871 .48065 .60127 .4722 Mtetra
.60127 .4722 .60871 .48065 .6234 .47608 .616 .46759 Mtetra
.616 .46759 .6234 .47608 .63815 .47149 .63082 .46295 Mtetra
.63082 .46295 .63815 .47149 .65299 .46688 .6457 .45829 Mtetra
.6457 .45829 .65299 .46688 .6679 .46224 .66067 .4536 Mtetra
.66067 .4536 .6679 .46224 .6829 .45757 .67572 .44889 Mtetra
.67572 .44889 .6829 .45757 .69797 .45288 .69085 .44416 Mtetra
.69085 .44416 .69797 .45288 .71312 .44817 .70606 .4394 Mtetra
.70606 .4394 .71312 .44817 .72836 .44343 .72135 .43461 Mtetra
.72135 .43461 .72836 .44343 .74368 .43866 .73673 .4298 Mtetra
.73673 .4298 .74368 .43866 .75908 .43387 .75218 .42496 Mtetra
.75218 .42496 .75908 .43387 .77456 .42905 .76773 .42009 Mtetra
.76773 .42009 .77456 .42905 .79013 .42421 .78335 .4152 Mtetra
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Mtetra
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Mtetra
.38103 .53067 .38925 .53857 .40288 .5343 .3947 .52637 Mtetra
.3947 .52637 .40288 .5343 .41658 .53001 .40845 .52204 Mtetra
.40845 .52204 .41658 .53001 .43036 .5257 .42226 .51768 Mtetra
.42226 .51768 .43036 .5257 .4442 .52137 .43615 .51331 Mtetra
.43615 .51331 .4442 .52137 .45811 .51701 .45011 .50891 Mtetra
.45011 .50891 .45811 .51701 .4721 .51263 .46414 .50449 Mtetra
.46414 .50449 .4721 .51263 .48615 .50823 .47824 .50005 Mtetra
.47824 .50005 .48615 .50823 .50028 .50381 .49242 .49559 Mtetra
.49242 .49559 .50028 .50381 .51448 .49937 .50667 .4911 Mtetra
.50667 .4911 .51448 .49937 .52876 .4949 .52099 .48658 Mtetra
.52099 .48658 .52876 .4949 .54311 .4904 .53539 .48205 Mtetra
.53539 .48205 .54311 .4904 .55754 .48589 .54987 .47749 Mtetra
.54987 .47749 .55754 .48589 .57204 .48135 .56442 .47291 Mtetra
.56442 .47291 .57204 .48135 .58662 .47679 .57905 .4683 Mtetra
.57905 .4683 .58662 .47679 .60127 .4722 .59376 .46367 Mtetra
.59376 .46367 .60127 .4722 .616 .46759 .60854 .45901 Mtetra
.60854 .45901 .616 .46759 .63082 .46295 .62341 .45433 Mtetra
.62341 .45433 .63082 .46295 .6457 .45829 .63835 .44962 Mtetra
.63835 .44962 .6457 .45829 .66067 .4536 .65337 .44489 Mtetra
.65337 .44489 .66067 .4536 .67572 .44889 .66847 .44013 Mtetra
.66847 .44013 .67572 .44889 .69085 .44416 .68366 .43535 Mtetra
.68366 .43535 .69085 .44416 .70606 .4394 .69892 .43054 Mtetra
.69892 .43054 .70606 .4394 .72135 .43461 .71427 .4257 Mtetra
.71427 .4257 .72135 .43461 .73673 .4298 .72971 .42084 Mtetra
.72971 .42084 .73673 .4298 .75218 .42496 .74522 .41596 Mtetra
.74522 .41596 .75218 .42496 .76773 .42009 .76082 .41104 Mtetra
.76082 .41104 .76773 .42009 .78335 .4152 .77651 .4061 Mtetra
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Mtetra
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Mtetra
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Mtetra
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51835 Mtetra
.38644 .51835 .3947 .52637 .40845 .52204 .40023 .51398 Mtetra
.40023 .51398 .40845 .52204 .42226 .51768 .41409 .50959 Mtetra
.41409 .50959 .42226 .51768 .43615 .51331 .42802 .50518 Mtetra
.42802 .50518 .43615 .51331 .45011 .50891 .44203 .50074 Mtetra
.44203 .50074 .45011 .50891 .46414 .50449 .45611 .49627 Mtetra
.45611 .49627 .46414 .50449 .47824 .50005 .47026 .49179 Mtetra
.47026 .49179 .47824 .50005 .49242 .49559 .48448 .48728 Mtetra
.48448 .48728 .49242 .49559 .50667 .4911 .49878 .48275 Mtetra
.49878 .48275 .50667 .4911 .52099 .48658 .51315 .47819 Mtetra
.51315 .47819 .52099 .48658 .53539 .48205 .5276 .47361 Mtetra
.5276 .47361 .53539 .48205 .54987 .47749 .54213 .46901 Mtetra
.54213 .46901 .54987 .47749 .56442 .47291 .55673 .46438 Mtetra
.55673 .46438 .56442 .47291 .57905 .4683 .57141 .45973 Mtetra
.57141 .45973 .57905 .4683 .59376 .46367 .58617 .45505 Mtetra
.58617 .45505 .59376 .46367 .60854 .45901 .60101 .45035 Mtetra
.60101 .45035 .60854 .45901 .62341 .45433 .61592 .44562 Mtetra
.61592 .44562 .62341 .45433 .63835 .44962 .63092 .44086 Mtetra
.63092 .44086 .63835 .44962 .65337 .44489 .646 .43609 Mtetra
.646 .43609 .65337 .44489 .66847 .44013 .66115 .43128 Mtetra
.66115 .43128 .66847 .44013 .68366 .43535 .6764 .42645 Mtetra
.6764 .42645 .68366 .43535 .69892 .43054 .69172 .42159 Mtetra
.69172 .42159 .69892 .43054 .71427 .4257 .70712 .41671 Mtetra
.70712 .41671 .71427 .4257 .72971 .42084 .72262 .4118 Mtetra
.72262 .4118 .72971 .42084 .74522 .41596 .73819 .40686 Mtetra
.73819 .40686 .74522 .41596 .76082 .41104 .75385 .4019 Mtetra
.75385 .4019 .76082 .41104 .77651 .4061 .7696 .39691 Mtetra
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Mtetra
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Mtetra
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Mtetra
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Mtetra
.36434 .51466 .37272 .5227 .38644 .51835 .37811 .51027 Mtetra
.37811 .51027 .38644 .51835 .40023 .51398 .39194 .50586 Mtetra
.39194 .50586 .40023 .51398 .41409 .50959 .40584 .50142 Mtetra
.40584 .50142 .41409 .50959 .42802 .50518 .41982 .49696 Mtetra
.41982 .49696 .42802 .50518 .44203 .50074 .43387 .49248 Mtetra
.43387 .49248 .44203 .50074 .45611 .49627 .44799 .48798 Mtetra
.44799 .48798 .45611 .49627 .47026 .49179 .46219 .48345 Mtetra
.46219 .48345 .47026 .49179 .48448 .48728 .47646 .47889 Mtetra
.47646 .47889 .48448 .48728 .49878 .48275 .49081 .47432 Mtetra
.49081 .47432 .49878 .48275 .51315 .47819 .50523 .46972 Mtetra
.50523 .46972 .51315 .47819 .5276 .47361 .51973 .46509 Mtetra
.51973 .46509 .5276 .47361 .54213 .46901 .53431 .46044 Mtetra
.53431 .46044 .54213 .46901 .55673 .46438 .54896 .45577 Mtetra
.54896 .45577 .55673 .46438 .57141 .45973 .56369 .45107 Mtetra
.56369 .45107 .57141 .45973 .58617 .45505 .57851 .44635 Mtetra
.57851 .44635 .58617 .45505 .60101 .45035 .5934 .4416 Mtetra
.5934 .4416 .60101 .45035 .61592 .44562 .60837 .43682 Mtetra
.60837 .43682 .61592 .44562 .63092 .44086 .62342 .43202 Mtetra
.62342 .43202 .63092 .44086 .646 .43609 .63855 .4272 Mtetra
.63855 .4272 .646 .43609 .66115 .43128 .65376 .42234 Mtetra
.65376 .42234 .66115 .43128 .6764 .42645 .66906 .41746 Mtetra
.66906 .41746 .6764 .42645 .69172 .42159 .68444 .41256 Mtetra
.68444 .41256 .69172 .42159 .70712 .41671 .6999 .40762 Mtetra
.6999 .40762 .70712 .41671 .72262 .4118 .71545 .40267 Mtetra
.71545 .40267 .72262 .4118 .73819 .40686 .73109 .39768 Mtetra
.73109 .39768 .73819 .40686 .75385 .4019 .74681 .39266 Mtetra
.74681 .39266 .75385 .4019 .7696 .39691 .76262 .38762 Mtetra
.76262 .38762 .7696 .39691 .78543 .39189 .77851 .38255 Mtetra
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Mtetra
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .5021 Mtetra
.36969 .5021 .37811 .51027 .39194 .50586 .38357 .49765 Mtetra
.38357 .49765 .39194 .50586 .40584 .50142 .39752 .49317 Mtetra
.39752 .49317 .40584 .50142 .41982 .49696 .41154 .48867 Mtetra
.41154 .48867 .41982 .49696 .43387 .49248 .42564 .48415 Mtetra
.42564 .48415 .43387 .49248 .44799 .48798 .43981 .4796 Mtetra
.43981 .4796 .44799 .48798 .46219 .48345 .45405 .47502 Mtetra
.45405 .47502 .46219 .48345 .47646 .47889 .46837 .47043 Mtetra
.46837 .47043 .47646 .47889 .49081 .47432 .48277 .46581 Mtetra
.48277 .46581 .49081 .47432 .50523 .46972 .49724 .46116 Mtetra
.49724 .46116 .50523 .46972 .51973 .46509 .51179 .45649 Mtetra
.51179 .45649 .51973 .46509 .53431 .46044 .52641 .4518 Mtetra
.52641 .4518 .53431 .46044 .54896 .45577 .54112 .44708 Mtetra
.54112 .44708 .54896 .45577 .56369 .45107 .5559 .44233 Mtetra
.5559 .44233 .56369 .45107 .57851 .44635 .57077 .43756 Mtetra
.57077 .43756 .57851 .44635 .5934 .4416 .58571 .43276 Mtetra
.58571 .43276 .5934 .4416 .60837 .43682 .60073 .42794 Mtetra
.60073 .42794 .60837 .43682 .62342 .43202 .61584 .42309 Mtetra
.61584 .42309 .62342 .43202 .63855 .4272 .63103 .41822 Mtetra
.63103 .41822 .63855 .4272 .65376 .42234 .6463 .41331 Mtetra
.6463 .41331 .65376 .42234 .66906 .41746 .66165 .40839 Mtetra
.66165 .40839 .66906 .41746 .68444 .41256 .67709 .40343 Mtetra
.67709 .40343 .68444 .41256 .6999 .40762 .69261 .39845 Mtetra
.69261 .39845 .6999 .40762 .71545 .40267 .70822 .39344 Mtetra
.70822 .39344 .71545 .40267 .73109 .39768 .72391 .3884 Mtetra
.72391 .3884 .73109 .39768 .74681 .39266 .73969 .38333 Mtetra
.73969 .38333 .74681 .39266 .76262 .38762 .75556 .37824 Mtetra
.75556 .37824 .76262 .38762 .77851 .38255 .77152 .37312 Mtetra
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Mtetra
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Mtetra
.34734 .49834 .35588 .50654 .36969 .5021 .36119 .49386 Mtetra
.36119 .49386 .36969 .5021 .38357 .49765 .37511 .48936 Mtetra
.37511 .48936 .38357 .49765 .39752 .49317 .38911 .48484 Mtetra
.38911 .48484 .39752 .49317 .41154 .48867 .40318 .4803 Mtetra
.40318 .4803 .41154 .48867 .42564 .48415 .41732 .47573 Mtetra
.41732 .47573 .42564 .48415 .43981 .4796 .43154 .47114 Mtetra
.43154 .47114 .43981 .4796 .45405 .47502 .44583 .46652 Mtetra
.44583 .46652 .45405 .47502 .46837 .47043 .4602 .46188 Mtetra
.4602 .46188 .46837 .47043 .48277 .46581 .47464 .45721 Mtetra
.47464 .45721 .48277 .46581 .49724 .46116 .48916 .45252 Mtetra
.48916 .45252 .49724 .46116 .51179 .45649 .50376 .4478 Mtetra
.50376 .4478 .51179 .45649 .52641 .4518 .51844 .44306 Mtetra
.51844 .44306 .52641 .4518 .54112 .44708 .5332 .43829 Mtetra
.5332 .43829 .54112 .44708 .5559 .44233 .54803 .4335 Mtetra
.54803 .4335 .5559 .44233 .57077 .43756 .56295 .42868 Mtetra
.56295 .42868 .57077 .43756 .58571 .43276 .57795 .42384 Mtetra
.57795 .42384 .58571 .43276 .60073 .42794 .59302 .41897 Mtetra
.59302 .41897 .60073 .42794 .61584 .42309 .60818 .41407 Mtetra
.60818 .41407 .61584 .42309 .63103 .41822 .62343 .40915 Mtetra
.62343 .40915 .63103 .41822 .6463 .41331 .63875 .40419 Mtetra
.63875 .40419 .6463 .41331 .66165 .40839 .65416 .39922 Mtetra
.65416 .39922 .66165 .40839 .67709 .40343 .66966 .39421 Mtetra
.66966 .39421 .67709 .40343 .69261 .39845 .68524 .38918 Mtetra
.68524 .38918 .69261 .39845 .70822 .39344 .70091 .38411 Mtetra
.70091 .38411 .70822 .39344 .72391 .3884 .71666 .37903 Mtetra
.71666 .37903 .72391 .3884 .73969 .38333 .7325 .37391 Mtetra
.7325 .37391 .73969 .38333 .75556 .37824 .74843 .36876 Mtetra
.74843 .36876 .75556 .37824 .77152 .37312 .76445 .36359 Mtetra
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Mtetra
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Mtetra
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Mtetra
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Mtetra
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Mtetra
.35261 .48554 .36119 .49386 .37511 .48936 .36658 .481 Mtetra
.36658 .481 .37511 .48936 .38911 .48484 .38062 .47643 Mtetra
.38062 .47643 .38911 .48484 .40318 .4803 .39473 .47184 Mtetra
.39473 .47184 .40318 .4803 .41732 .47573 .40892 .46723 Mtetra
.40892 .46723 .41732 .47573 .43154 .47114 .42319 .46259 Mtetra
.42319 .46259 .43154 .47114 .44583 .46652 .43753 .45793 Mtetra
.43753 .45793 .44583 .46652 .4602 .46188 .45194 .45324 Mtetra
.45194 .45324 .4602 .46188 .47464 .45721 .46644 .44853 Mtetra
.46644 .44853 .47464 .45721 .48916 .45252 .48101 .44379 Mtetra
.48101 .44379 .48916 .45252 .50376 .4478 .49566 .43903 Mtetra
.49566 .43903 .50376 .4478 .51844 .44306 .51039 .43424 Mtetra
.51039 .43424 .51844 .44306 .5332 .43829 .5252 .42943 Mtetra
.5252 .42943 .5332 .43829 .54803 .4335 .54008 .42459 Mtetra
.54008 .42459 .54803 .4335 .56295 .42868 .55505 .41972 Mtetra
.55505 .41972 .56295 .42868 .57795 .42384 .5701 .41482 Mtetra
.5701 .41482 .57795 .42384 .59302 .41897 .58524 .4099 Mtetra
.58524 .4099 .59302 .41897 .60818 .41407 .60045 .40496 Mtetra
.60045 .40496 .60818 .41407 .62343 .40915 .61575 .39998 Mtetra
.61575 .39998 .62343 .40915 .63875 .40419 .63113 .39498 Mtetra
.63113 .39498 .63875 .40419 .65416 .39922 .6466 .38995 Mtetra
.6466 .38995 .65416 .39922 .66966 .39421 .66216 .3849 Mtetra
.66216 .3849 .66966 .39421 .68524 .38918 .6778 .37981 Mtetra
.6778 .37981 .68524 .38918 .70091 .38411 .69352 .3747 Mtetra
.69352 .3747 .70091 .38411 .71666 .37903 .70934 .36956 Mtetra
.70934 .36956 .71666 .37903 .7325 .37391 .72524 .36439 Mtetra
.72524 .36439 .7325 .37391 .74843 .36876 .74123 .35919 Mtetra
.74123 .35919 .74843 .36876 .76445 .36359 .75732 .35396 Mtetra
.75732 .35396 .76445 .36359 .78056 .35838 .77349 .3487 Mtetra
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Mtetra
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Mtetra
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Mtetra
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Mtetra
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47255 Mtetra
.35796 .47255 .36658 .481 .38062 .47643 .37205 .46794 Mtetra
.37205 .46794 .38062 .47643 .39473 .47184 .38621 .46331 Mtetra
.38621 .46331 .39473 .47184 .40892 .46723 .40044 .45865 Mtetra
.40044 .45865 .40892 .46723 .42319 .46259 .41476 .45397 Mtetra
.41476 .45397 .42319 .46259 .43753 .45793 .42914 .44926 Mtetra
.42914 .44926 .43753 .45793 .45194 .45324 .44361 .44452 Mtetra
.44361 .44452 .45194 .45324 .46644 .44853 .45815 .43976 Mtetra
.45815 .43976 .46644 .44853 .48101 .44379 .47277 .43498 Mtetra
.47277 .43498 .48101 .44379 .49566 .43903 .48747 .43017 Mtetra
.48747 .43017 .49566 .43903 .51039 .43424 .50225 .42533 Mtetra
.50225 .42533 .51039 .43424 .5252 .42943 .51712 .42047 Mtetra
.51712 .42047 .5252 .42943 .54008 .42459 .53206 .41558 Mtetra
.53206 .41558 .54008 .42459 .55505 .41972 .54708 .41066 Mtetra
.54708 .41066 .55505 .41972 .5701 .41482 .56218 .40572 Mtetra
.56218 .40572 .5701 .41482 .58524 .4099 .57737 .40075 Mtetra
.57737 .40075 .58524 .4099 .60045 .40496 .59264 .39575 Mtetra
.59264 .39575 .60045 .40496 .61575 .39998 .608 .39073 Mtetra
.608 .39073 .61575 .39998 .63113 .39498 .62344 .38568 Mtetra
.62344 .38568 .63113 .39498 .6466 .38995 .63896 .38059 Mtetra
.63896 .38059 .6466 .38995 .66216 .3849 .65458 .37549 Mtetra
.65458 .37549 .66216 .3849 .6778 .37981 .67028 .37035 Mtetra
.663 .741 .908 r
.67028 .37035 .6778 .37981 .69352 .3747 .68606 .36518 Mtetra
.664 .741 .908 r
.68606 .36518 .69352 .3747 .70934 .36956 .70194 .35999 Mtetra
.70194 .35999 .70934 .36956 .72524 .36439 .7179 .35477 Mtetra
.7179 .35477 .72524 .36439 .74123 .35919 .73396 .34951 Mtetra
.73396 .34951 .74123 .35919 .75732 .35396 .75011 .34422 Mtetra
.75011 .34422 .75732 .35396 .77349 .3487 .76634 .33891 Mtetra
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Mtetra
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Mtetra
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Mtetra
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46865 Mtetra
.3352 .46865 .34395 .47714 .35796 .47255 .34926 .46402 Mtetra
.34926 .46402 .35796 .47255 .37205 .46794 .36339 .45937 Mtetra
.36339 .45937 .37205 .46794 .38621 .46331 .3776 .45469 Mtetra
.3776 .45469 .38621 .46331 .40044 .45865 .39188 .44998 Mtetra
.39188 .44998 .40044 .45865 .41476 .45397 .40624 .44525 Mtetra
.40624 .44525 .41476 .45397 .42914 .44926 .42068 .4405 Mtetra
.42068 .4405 .42914 .44926 .44361 .44452 .43519 .43572 Mtetra
.43519 .43572 .44361 .44452 .45815 .43976 .44978 .43091 Mtetra
.44978 .43091 .45815 .43976 .47277 .43498 .46446 .42608 Mtetra
.46446 .42608 .47277 .43498 .48747 .43017 .47921 .42122 Mtetra
.47921 .42122 .48747 .43017 .50225 .42533 .49404 .41633 Mtetra
.49404 .41633 .50225 .42533 .51712 .42047 .50895 .41142 Mtetra
.50895 .41142 .51712 .42047 .53206 .41558 .52395 .40648 Mtetra
.52395 .40648 .53206 .41558 .54708 .41066 .53902 .40152 Mtetra
.53902 .40152 .54708 .41066 .56218 .40572 .55418 .39652 Mtetra
.55418 .39652 .56218 .40572 .57737 .40075 .56943 .3915 Mtetra
.56943 .3915 .57737 .40075 .59264 .39575 .58475 .38645 Mtetra
.58475 .38645 .59264 .39575 .608 .39073 .60016 .38138 Mtetra
.60016 .38138 .608 .39073 .62344 .38568 .61566 .37627 Mtetra
.61566 .37627 .62344 .38568 .63896 .38059 .63125 .37114 Mtetra
.663 .741 .908 r
.63125 .37114 .63896 .38059 .65458 .37549 .64692 .36598 Mtetra
.64692 .36598 .65458 .37549 .67028 .37035 .66268 .3608 Mtetra
.66268 .3608 .67028 .37035 .68606 .36518 .67853 .35558 Mtetra
.664 .742 .908 r
.67853 .35558 .68606 .36518 .70194 .35999 .69446 .35033 Mtetra
.664 .741 .908 r
.69446 .35033 .70194 .35999 .7179 .35477 .71049 .34504 Mtetra
.71049 .34504 .7179 .35477 .73396 .34951 .72661 .33973 Mtetra
.72661 .33973 .73396 .34951 .75011 .34422 .74282 .33439 Mtetra
.74282 .33439 .75011 .34422 .76634 .33891 .75912 .32902 Mtetra
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Mtetra
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46936 Mtetra
.29838 .46936 .3073 .47784 .32121 .47326 .31234 .46474 Mtetra
.31234 .46474 .32121 .47326 .3352 .46865 .32636 .46009 Mtetra
.32636 .46009 .3352 .46865 .34926 .46402 .34047 .45541 Mtetra
.34047 .45541 .34926 .46402 .36339 .45937 .35465 .45071 Mtetra
.35465 .45071 .36339 .45937 .3776 .45469 .3689 .44598 Mtetra
.3689 .44598 .3776 .45469 .39188 .44998 .38323 .44123 Mtetra
.38323 .44123 .39188 .44998 .40624 .44525 .39764 .43645 Mtetra
.39764 .43645 .40624 .44525 .42068 .4405 .41213 .43165 Mtetra
.41213 .43165 .42068 .4405 .43519 .43572 .42669 .42682 Mtetra
.42669 .42682 .43519 .43572 .44978 .43091 .44133 .42197 Mtetra
.44133 .42197 .44978 .43091 .46446 .42608 .45606 .41709 Mtetra
.45606 .41709 .46446 .42608 .47921 .42122 .47086 .41218 Mtetra
.47086 .41218 .47921 .42122 .49404 .41633 .48574 .40724 Mtetra
.48574 .40724 .49404 .41633 .50895 .41142 .50071 .40228 Mtetra
.50071 .40228 .50895 .41142 .52395 .40648 .51576 .39729 Mtetra
.51576 .39729 .52395 .40648 .53902 .40152 .53089 .39228 Mtetra
.53089 .39228 .53902 .40152 .55418 .39652 .5461 .38723 Mtetra
.5461 .38723 .55418 .39652 .56943 .3915 .5614 .38216 Mtetra
.5614 .38216 .56943 .3915 .58475 .38645 .57678 .37706 Mtetra
.57678 .37706 .58475 .38645 .60016 .38138 .59225 .37193 Mtetra
.663 .741 .908 r
.59225 .37193 .60016 .38138 .61566 .37627 .60781 .36678 Mtetra
.60781 .36678 .61566 .37627 .63125 .37114 .62345 .3616 Mtetra
.62345 .3616 .63125 .37114 .64692 .36598 .63918 .3564 Mtetra
.663 .742 .908 r
.63918 .3564 .64692 .36598 .66268 .3608 .655 .35117 Mtetra
.664 .742 .908 r
.655 .35117 .66268 .3608 .67853 .35558 .67091 .34588 Mtetra
.67091 .34588 .67853 .35558 .69446 .35033 .68691 .34056 Mtetra
.664 .741 .908 r
.68691 .34056 .69446 .35033 .71049 .34504 .703 .33522 Mtetra
.703 .33522 .71049 .34504 .72661 .33973 .71918 .32985 Mtetra
.71918 .32985 .72661 .33973 .74282 .33439 .73545 .32445 Mtetra
.73545 .32445 .74282 .33439 .75912 .32902 .75182 .31903 Mtetra
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Mtetra
.27545 .46545 .2845 .47397 .29838 .46936 .28937 .4608 Mtetra
.28937 .4608 .29838 .46936 .31234 .46474 .30337 .45613 Mtetra
.30337 .45613 .31234 .46474 .32636 .46009 .31744 .45143 Mtetra
.31744 .45143 .32636 .46009 .34047 .45541 .33159 .44671 Mtetra
.33159 .44671 .34047 .45541 .35465 .45071 .34582 .44196 Mtetra
.34582 .44196 .35465 .45071 .3689 .44598 .36012 .43719 Mtetra
.36012 .43719 .3689 .44598 .38323 .44123 .3745 .43239 Mtetra
.3745 .43239 .38323 .44123 .39764 .43645 .38896 .42757 Mtetra
.38896 .42757 .39764 .43645 .41213 .43165 .40349 .42272 Mtetra
.40349 .42272 .41213 .43165 .42669 .42682 .4181 .41784 Mtetra
.4181 .41784 .42669 .42682 .44133 .42197 .4328 .41294 Mtetra
.4328 .41294 .44133 .42197 .45606 .41709 .44757 .40801 Mtetra
.44757 .40801 .45606 .41709 .47086 .41218 .46242 .40305 Mtetra
.46242 .40305 .47086 .41218 .48574 .40724 .47736 .39806 Mtetra
.47736 .39806 .48574 .40724 .50071 .40228 .49238 .39305 Mtetra
.49238 .39305 .50071 .40228 .51576 .39729 .50748 .38801 Mtetra
.50748 .38801 .51576 .39729 .53089 .39228 .52267 .38294 Mtetra
.52267 .38294 .53089 .39228 .5461 .38723 .53793 .37785 Mtetra
.53793 .37785 .5461 .38723 .5614 .38216 .55329 .37272 Mtetra
.55329 .37272 .5614 .38216 .57678 .37706 .56873 .36757 Mtetra
.663 .741 .908 r
.56873 .36757 .57678 .37706 .59225 .37193 .58426 .3624 Mtetra
.58426 .3624 .59225 .37193 .60781 .36678 .59987 .35721 Mtetra
.662 .742 .909 r
.59987 .35721 .60781 .36678 .62345 .3616 .61557 .35202 Mtetra
.663 .743 .909 r
.61557 .35202 .62345 .3616 .63918 .3564 .63137 .34677 Mtetra
.664 .743 .909 r
.63137 .34677 .63918 .3564 .655 .35117 .64724 .34144 Mtetra
.665 .742 .908 r
.64724 .34144 .655 .35117 .67091 .34588 .66321 .33606 Mtetra
.664 .741 .908 r
.66321 .33606 .67091 .34588 .68691 .34056 .67927 .33068 Mtetra
.67927 .33068 .68691 .34056 .703 .33522 .69543 .32529 Mtetra
.69543 .32529 .703 .33522 .71918 .32985 .71167 .31986 Mtetra
.71167 .31986 .71918 .32985 .73545 .32445 .72801 .31441 Mtetra
.72801 .31441 .73545 .32445 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Mtetra
.2663 .45685 .27545 .46545 .28937 .4608 .28027 .45216 Mtetra
.28027 .45216 .28937 .4608 .30337 .45613 .29432 .44744 Mtetra
.29432 .44744 .30337 .45613 .31744 .45143 .30844 .4427 Mtetra
.30844 .4427 .31744 .45143 .33159 .44671 .32263 .43793 Mtetra
.32263 .43793 .33159 .44671 .34582 .44196 .3369 .43313 Mtetra
.3369 .43313 .34582 .44196 .36012 .43719 .35125 .42831 Mtetra
.35125 .42831 .36012 .43719 .3745 .43239 .36568 .42346 Mtetra
.36568 .42346 .3745 .43239 .38896 .42757 .38018 .41859 Mtetra
.38018 .41859 .38896 .42757 .40349 .42272 .39477 .41369 Mtetra
.39477 .41369 .40349 .42272 .4181 .41784 .40943 .40877 Mtetra
.40943 .40877 .4181 .41784 .4328 .41294 .42417 .40381 Mtetra
.42417 .40381 .4328 .41294 .44757 .40801 .439 .39883 Mtetra
.439 .39883 .44757 .40801 .46242 .40305 .4539 .39382 Mtetra
.4539 .39382 .46242 .40305 .47736 .39806 .46889 .38879 Mtetra
.46889 .38879 .47736 .39806 .49238 .39305 .48397 .38372 Mtetra
.48397 .38372 .49238 .39305 .50748 .38801 .49912 .37863 Mtetra
.49912 .37863 .50748 .38801 .52267 .38294 .51436 .37351 Mtetra
.51436 .37351 .52267 .38294 .53793 .37785 .52969 .36836 Mtetra
.663 .741 .908 r
.52969 .36836 .53793 .37785 .55329 .37272 .5451 .36319 Mtetra
.5451 .36319 .55329 .37272 .56873 .36757 .56059 .358 Mtetra
.662 .741 .909 r
.56059 .358 .56873 .36757 .58426 .3624 .57618 .35284 Mtetra
.661 .742 .91 r
.57618 .35284 .58426 .3624 .59987 .35721 .59185 .34769 Mtetra
.662 .745 .911 r
.59185 .34769 .59987 .35721 .61557 .35202 .60762 .34245 Mtetra
.666 .746 .91 r
.60762 .34245 .61557 .35202 .63137 .34677 .62347 .33704 Mtetra
.666 .744 .908 r
.62347 .33704 .63137 .34677 .64724 .34144 .63941 .33157 Mtetra
.665 .742 .907 r
.63941 .33157 .64724 .34144 .66321 .33606 .65544 .32613 Mtetra
.664 .741 .908 r
.65544 .32613 .66321 .33606 .67927 .33068 .67156 .3207 Mtetra
.67156 .3207 .67927 .33068 .69543 .32529 .68777 .31525 Mtetra
.68777 .31525 .69543 .32529 .71167 .31986 .70408 .30977 Mtetra
.70408 .30977 .71167 .31986 .72801 .31441 .72049 .30426 Mtetra
.72049 .30426 .72801 .31441 .74444 .30893 .73699 .29872 Mtetra
.73699 .29872 .74444 .30893 .76097 .30341 .75358 .29314 Mtetra
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28753 Mtetra
.77027 .28753 .7776 .29786 .79432 .29228 .78706 .28189 Mtetra
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Mtetra
.25707 .44817 .2663 .45685 .28027 .45216 .27108 .44343 Mtetra
.27108 .44343 .28027 .45216 .29432 .44744 .28517 .43866 Mtetra
.28517 .43866 .29432 .44744 .30844 .4427 .29934 .43387 Mtetra
.29934 .43387 .30844 .4427 .32263 .43793 .31358 .42905 Mtetra
.31358 .42905 .32263 .43793 .3369 .43313 .3279 .42421 Mtetra
.3279 .42421 .3369 .43313 .35125 .42831 .34229 .41934 Mtetra
.34229 .41934 .35125 .42831 .36568 .42346 .35677 .41445 Mtetra
.35677 .41445 .36568 .42346 .38018 .41859 .37132 .40953 Mtetra
.37132 .40953 .38018 .41859 .39477 .41369 .38595 .40458 Mtetra
.38595 .40458 .39477 .41369 .40943 .40877 .40067 .3996 Mtetra
.40067 .3996 .40943 .40877 .42417 .40381 .41546 .3946 Mtetra
.41546 .3946 .42417 .40381 .439 .39883 .43034 .38956 Mtetra
.43034 .38956 .439 .39883 .4539 .39382 .4453 .38451 Mtetra
.4453 .38451 .4539 .39382 .46889 .38879 .46034 .37942 Mtetra
.46034 .37942 .46889 .38879 .48397 .38372 .47546 .3743 Mtetra
.47546 .3743 .48397 .38372 .49912 .37863 .49067 .36916 Mtetra
.49067 .36916 .49912 .37863 .51436 .37351 .50597 .36399 Mtetra
.663 .741 .908 r
.50597 .36399 .51436 .37351 .52969 .36836 .52135 .35879 Mtetra
.662 .741 .909 r
.52135 .35879 .52969 .36836 .5451 .36319 .53682 .35361 Mtetra
.659 .741 .91 r
.53682 .35361 .5451 .36319 .56059 .358 .55237 .34853 Mtetra
.657 .744 .914 r
.55237 .34853 .56059 .358 .57618 .35284 .56802 .34351 Mtetra
.661 .75 .916 r
.56802 .34351 .57618 .35284 .59185 .34769 .58376 .33829 Mtetra
.669 .752 .913 r
.58376 .33829 .59185 .34769 .60762 .34245 .59958 .33273 Mtetra
.67 .747 .908 r
.59958 .33273 .60762 .34245 .62347 .33704 .61548 .32709 Mtetra
.666 .742 .906 r
.61548 .32709 .62347 .33704 .63941 .33157 .63148 .32156 Mtetra
.664 .741 .907 r
.63148 .32156 .63941 .33157 .65544 .32613 .64757 .31609 Mtetra
.664 .741 .908 r
.64757 .31609 .65544 .32613 .67156 .3207 .66376 .31062 Mtetra
.66376 .31062 .67156 .3207 .68777 .31525 .68004 .30511 Mtetra
.68004 .30511 .68777 .31525 .70408 .30977 .69642 .29957 Mtetra
.69642 .29957 .70408 .30977 .72049 .30426 .71289 .294 Mtetra
.71289 .294 .72049 .30426 .73699 .29872 .72945 .2884 Mtetra
.72945 .2884 .73699 .29872 .75358 .29314 .74611 .28276 Mtetra
.74611 .28276 .75358 .29314 .77027 .28753 .76287 .2771 Mtetra
.76287 .2771 .77027 .28753 .78706 .28189 .77973 .27139 Mtetra
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.23376 .44416 .24313 .45288 .25707 .44817 .24775 .4394 Mtetra
.24775 .4394 .25707 .44817 .27108 .44343 .2618 .43461 Mtetra
.2618 .43461 .27108 .44343 .28517 .43866 .27594 .4298 Mtetra
.27594 .4298 .28517 .43866 .29934 .43387 .29015 .42496 Mtetra
.29015 .42496 .29934 .43387 .31358 .42905 .30444 .42009 Mtetra
.30444 .42009 .31358 .42905 .3279 .42421 .3188 .4152 Mtetra
.3188 .4152 .3279 .42421 .34229 .41934 .33325 .41028 Mtetra
.33325 .41028 .34229 .41934 .35677 .41445 .34777 .40534 Mtetra
.34777 .40534 .35677 .41445 .37132 .40953 .36237 .40037 Mtetra
.36237 .40037 .37132 .40953 .38595 .40458 .37705 .39537 Mtetra
.37705 .39537 .38595 .40458 .40067 .3996 .39182 .39034 Mtetra
.39182 .39034 .40067 .3996 .41546 .3946 .40666 .38529 Mtetra
.40666 .38529 .41546 .3946 .43034 .38956 .42159 .3802 Mtetra
.42159 .3802 .43034 .38956 .4453 .38451 .4366 .37509 Mtetra
.4366 .37509 .4453 .38451 .46034 .37942 .4517 .36995 Mtetra
.4517 .36995 .46034 .37942 .47546 .3743 .46688 .36478 Mtetra
.46688 .36478 .47546 .3743 .49067 .36916 .48214 .35959 Mtetra
.663 .741 .908 r
.48214 .35959 .49067 .36916 .50597 .36399 .49749 .35438 Mtetra
.661 .741 .909 r
.49749 .35438 .50597 .36399 .52135 .35879 .51293 .34924 Mtetra
.653 .741 .914 r
.51293 .34924 .52135 .35879 .53682 .35361 .52845 .34436 Mtetra
.647 .747 .922 r
.52845 .34436 .53682 .35361 .55237 .34853 .54407 .33966 Mtetra
.658 .761 .926 r
.54407 .33966 .55237 .34853 .56802 .34351 .55978 .3345 Mtetra
.676 .765 .918 r
.55978 .3345 .56802 .34351 .58376 .33829 .57557 .32864 Mtetra
.677 .751 .907 r
.57557 .32864 .58376 .33829 .59958 .33273 .59144 .32267 Mtetra
.669 .741 .904 r
.59144 .32267 .59958 .33273 .61548 .32709 .60741 .31699 Mtetra
.665 .74 .906 r
.60741 .31699 .61548 .32709 .63148 .32156 .62347 .31147 Mtetra
.664 .741 .907 r
.62347 .31147 .63148 .32156 .64757 .31609 .63963 .30596 Mtetra
.664 .741 .908 r
.63963 .30596 .64757 .31609 .66376 .31062 .65588 .30043 Mtetra
.65588 .30043 .66376 .31062 .68004 .30511 .67223 .29486 Mtetra
.67223 .29486 .68004 .30511 .69642 .29957 .68867 .28926 Mtetra
.68867 .28926 .69642 .29957 .71289 .294 .7052 .28363 Mtetra
.7052 .28363 .71289 .294 .72945 .2884 .72183 .27797 Mtetra
.72183 .27797 .72945 .2884 .74611 .28276 .73856 .27227 Mtetra
.73856 .27227 .74611 .28276 .76287 .2771 .75539 .26654 Mtetra
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.2243 .43535 .23376 .44416 .24775 .4394 .23833 .43054 Mtetra
.23833 .43054 .24775 .4394 .2618 .43461 .25243 .4257 Mtetra
.25243 .4257 .2618 .43461 .27594 .4298 .26661 .42084 Mtetra
.26661 .42084 .27594 .4298 .29015 .42496 .28087 .41596 Mtetra
.28087 .41596 .29015 .42496 .30444 .42009 .2952 .41104 Mtetra
.2952 .41104 .30444 .42009 .3188 .4152 .30961 .4061 Mtetra
.30961 .4061 .3188 .4152 .33325 .41028 .32411 .40113 Mtetra
.32411 .40113 .33325 .41028 .34777 .40534 .33868 .39614 Mtetra
.33868 .39614 .34777 .40534 .36237 .40037 .35333 .39112 Mtetra
.35333 .39112 .36237 .40037 .37705 .39537 .36806 .38606 Mtetra
.36806 .38606 .37705 .39537 .39182 .39034 .38288 .38099 Mtetra
.38288 .38099 .39182 .39034 .40666 .38529 .39777 .37588 Mtetra
.39777 .37588 .40666 .38529 .42159 .3802 .41275 .37074 Mtetra
.41275 .37074 .42159 .3802 .4366 .37509 .42782 .36558 Mtetra
.42782 .36558 .4366 .37509 .4517 .36995 .44297 .36039 Mtetra
.663 .741 .908 r
.44297 .36039 .4517 .36995 .46688 .36478 .4582 .35517 Mtetra
.662 .741 .908 r
.4582 .35517 .46688 .36478 .48214 .35959 .47352 .34996 Mtetra
.657 .74 .911 r
.47352 .34996 .48214 .35959 .49749 .35438 .48892 .34495 Mtetra
.64 .74 .921 r
.48892 .34495 .49749 .35438 .51293 .34924 .50441 .34052 Mtetra
.627 .754 .938 r
.50441 .34052 .51293 .34924 .52845 .34436 .52 .33645 Mtetra
.652 .784 .944 r
.52 .33645 .52845 .34436 .54407 .33966 .53568 .3314 Mtetra
.69 .788 .925 r
.53568 .3314 .54407 .33966 .55978 .3345 .55144 .32493 Mtetra
.691 .759 .904 r
.55144 .32493 .55978 .3345 .57557 .32864 .56729 .31836 Mtetra
.675 .739 .899 r
.56729 .31836 .57557 .32864 .59144 .32267 .58322 .31242 Mtetra
.666 .738 .904 r
.58322 .31242 .59144 .32267 .60741 .31699 .59926 .30682 Mtetra
.664 .74 .907 r
.59926 .30682 .60741 .31699 .62347 .31147 .61538 .30128 Mtetra
.664 .741 .908 r
.61538 .30128 .62347 .31147 .63963 .30596 .6316 .29572 Mtetra
.6316 .29572 .63963 .30596 .65588 .30043 .64792 .29013 Mtetra
.64792 .29013 .65588 .30043 .67223 .29486 .66433 .2845 Mtetra
.66433 .2845 .67223 .29486 .68867 .28926 .68083 .27884 Mtetra
.68083 .27884 .68867 .28926 .7052 .28363 .69743 .27315 Mtetra
.69743 .27315 .7052 .28363 .72183 .27797 .71413 .26743 Mtetra
.71413 .26743 .72183 .27797 .73856 .27227 .73093 .26167 Mtetra
.73093 .26167 .73856 .27227 .75539 .26654 .74783 .25587 Mtetra
.74783 .25587 .75539 .26654 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24418 Mtetra
.78193 .24418 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.21474 .42645 .2243 .43535 .23833 .43054 .22882 .42159 Mtetra
.22882 .42159 .23833 .43054 .25243 .4257 .24296 .41671 Mtetra
.24296 .41671 .25243 .4257 .26661 .42084 .25719 .4118 Mtetra
.25719 .4118 .26661 .42084 .28087 .41596 .27149 .40686 Mtetra
.27149 .40686 .28087 .41596 .2952 .41104 .28587 .4019 Mtetra
.28587 .4019 .2952 .41104 .30961 .4061 .30033 .39691 Mtetra
.30033 .39691 .30961 .4061 .32411 .40113 .31487 .39189 Mtetra
.31487 .39189 .32411 .40113 .33868 .39614 .32949 .38684 Mtetra
.32949 .38684 .33868 .39614 .35333 .39112 .34419 .38177 Mtetra
.34419 .38177 .35333 .39112 .36806 .38606 .35898 .37667 Mtetra
.35898 .37667 .36806 .38606 .38288 .38099 .37384 .37154 Mtetra
.37384 .37154 .38288 .38099 .39777 .37588 .38879 .36638 Mtetra
.38879 .36638 .39777 .37588 .41275 .37074 .40382 .36119 Mtetra
.40382 .36119 .41275 .37074 .42782 .36558 .41894 .35597 Mtetra
.663 .741 .908 r
.41894 .35597 .42782 .36558 .44297 .36039 .43414 .35073 Mtetra
.661 .741 .909 r
.43414 .35073 .44297 .36039 .4582 .35517 .44943 .34555 Mtetra
.649 .739 .915 r
.44943 .34555 .4582 .35517 .47352 .34996 .46479 .34082 Mtetra
.612 .738 .936 r
.46479 .34082 .47352 .34996 .48892 .34495 .48023 .33728 Mtetra
.576 .764 .968 r
.48023 .33728 .48892 .34495 .50441 .34052 .49577 .33439 Mtetra
.634 .828 .975 r
.49577 .33439 .50441 .34052 .52 .33645 .51143 .32948 Mtetra
.718 .828 .933 r
.51143 .32948 .52 .33645 .53568 .3314 .52719 .32189 Mtetra
.714 .768 .895 r
.52719 .32189 .53568 .3314 .55144 .32493 .54301 .31423 Mtetra
.683 .734 .89 r
.54301 .31423 .55144 .32493 .56729 .31836 .55892 .30785 Mtetra
.667 .734 .9 r
.55892 .30785 .56729 .31836 .58322 .31242 .57492 .30215 Mtetra
.664 .739 .906 r
.57492 .30215 .58322 .31242 .59926 .30682 .59101 .29658 Mtetra
.664 .741 .908 r
.59101 .29658 .59926 .30682 .61538 .30128 .6072 .29099 Mtetra
.6072 .29099 .61538 .30128 .6316 .29572 .62349 .28537 Mtetra
.62349 .28537 .6316 .29572 .64792 .29013 .63987 .27972 Mtetra
.63987 .27972 .64792 .29013 .66433 .2845 .65634 .27403 Mtetra
.65634 .27403 .66433 .2845 .68083 .27884 .67291 .26831 Mtetra
.67291 .26831 .68083 .27884 .69743 .27315 .68958 .26256 Mtetra
.68958 .26256 .69743 .27315 .71413 .26743 .70635 .25677 Mtetra
.70635 .25677 .71413 .26743 .73093 .26167 .72322 .25095 Mtetra
.72322 .25095 .73093 .26167 .74783 .25587 .74019 .24509 Mtetra
.74019 .24509 .74783 .25587 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24418 .77443 .23327 Mtetra
.77443 .23327 .78193 .24418 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.20509 .41746 .21474 .42645 .22882 .42159 .21921 .41256 Mtetra
.21921 .41256 .22882 .42159 .24296 .41671 .2334 .40762 Mtetra
.2334 .40762 .24296 .41671 .25719 .4118 .24767 .40267 Mtetra
.24767 .40267 .25719 .4118 .27149 .40686 .26202 .39768 Mtetra
.26202 .39768 .27149 .40686 .28587 .4019 .27645 .39266 Mtetra
.27645 .39266 .28587 .4019 .30033 .39691 .29096 .38762 Mtetra
.29096 .38762 .30033 .39691 .31487 .39189 .30555 .38255 Mtetra
.30555 .38255 .31487 .39189 .32949 .38684 .32021 .37745 Mtetra
.32021 .37745 .32949 .38684 .34419 .38177 .33497 .37233 Mtetra
.33497 .37233 .34419 .38177 .35898 .37667 .3498 .36717 Mtetra
.3498 .36717 .35898 .37667 .37384 .37154 .36472 .36199 Mtetra
.36472 .36199 .37384 .37154 .38879 .36638 .37972 .35677 Mtetra
.37972 .35677 .38879 .36638 .40382 .36119 .3948 .35153 Mtetra
.663 .741 .908 r
.3948 .35153 .40382 .36119 .41894 .35597 .40997 .34628 Mtetra
.659 .74 .91 r
.40997 .34628 .41894 .35597 .43414 .35073 .42522 .34117 Mtetra
.632 .736 .922 r
.42522 .34117 .43414 .35073 .44943 .34555 .44053 .33699 Mtetra
.546 .729 .96 r
.44053 .33699 .44943 .34555 .46479 .34082 .4559 .33509 Mtetra
.425 .756 .995 r
.4559 .33509 .46479 .34082 .48023 .33728 .47136 .33427 Mtetra
.563 .886 .989 r
.47136 .33427 .48023 .33728 .49577 .33439 .48701 .32948 Mtetra
.765 .887 .932 r
.48701 .32948 .49577 .33439 .51143 .32948 .50278 .31986 Mtetra
.746 .774 .875 r
.50278 .31986 .51143 .32948 .52719 .32189 .51861 .31039 Mtetra
.694 .723 .872 r
.51861 .31039 .52719 .32189 .54301 .31423 .53449 .30332 Mtetra
.67 .728 .893 r
.53449 .30332 .54301 .31423 .55892 .30785 .55046 .29747 Mtetra
.664 .738 .905 r
.55046 .29747 .55892 .30785 .57492 .30215 .56653 .29185 Mtetra
.664 .741 .908 r
.56653 .29185 .57492 .30215 .59101 .29658 .58268 .28624 Mtetra
.58268 .28624 .59101 .29658 .6072 .29099 .59894 .28059 Mtetra
.59894 .28059 .6072 .29099 .62349 .28537 .61528 .27491 Mtetra
.61528 .27491 .62349 .28537 .63987 .27972 .63173 .26919 Mtetra
.63173 .26919 .63987 .27972 .65634 .27403 .64827 .26344 Mtetra
.64827 .26344 .65634 .27403 .67291 .26831 .66491 .25766 Mtetra
.66491 .25766 .67291 .26831 .68958 .26256 .68164 .25184 Mtetra
.68164 .25184 .68958 .26256 .70635 .25677 .69848 .24599 Mtetra
.69848 .24599 .70635 .25677 .72322 .25095 .71542 .24011 Mtetra
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23418 Mtetra
.73246 .23418 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Mtetra
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .2162 Mtetra
.78419 .2162 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.19534 .40839 .20509 .41746 .21921 .41256 .2095 .40343 Mtetra
.2095 .40343 .21921 .41256 .2334 .40762 .22374 .39845 Mtetra
.22374 .39845 .2334 .40762 .24767 .40267 .23806 .39344 Mtetra
.23806 .39344 .24767 .40267 .26202 .39768 .25245 .3884 Mtetra
.25245 .3884 .26202 .39768 .27645 .39266 .26693 .38333 Mtetra
.26693 .38333 .27645 .39266 .29096 .38762 .28149 .37824 Mtetra
.28149 .37824 .29096 .38762 .30555 .38255 .29612 .37312 Mtetra
.29612 .37312 .30555 .38255 .32021 .37745 .31084 .36797 Mtetra
.31084 .36797 .32021 .37745 .33497 .37233 .32564 .36279 Mtetra
.32564 .36279 .33497 .37233 .3498 .36717 .34053 .35758 Mtetra
.34053 .35758 .3498 .36717 .36472 .36199 .35549 .35234 Mtetra
.35549 .35234 .36472 .36199 .37972 .35677 .37055 .34707 Mtetra
.663 .741 .908 r
.37055 .34707 .37972 .35677 .3948 .35153 .38568 .34181 Mtetra
.654 .739 .912 r
.38568 .34181 .3948 .35153 .40997 .34628 .40089 .33686 Mtetra
.6 .729 .935 r
.40089 .33686 .40997 .34628 .42522 .34117 .41613 .33366 Mtetra
.376 .682 .978 r
.41613 .33366 .42522 .34117 .44053 .33699 .43136 .33457 Mtetra
0 .522 .773 r
.43136 .33457 .44053 .33699 .4559 .33509 .44669 .33708 Mtetra
.273 .774 .75 r
.44669 .33708 .4559 .33509 .47136 .33427 .46233 .33225 Mtetra
.826 .952 .9 r
.46233 .33225 .47136 .33427 .48701 .32948 .4782 .31924 Mtetra
.783 .769 .841 r
.4782 .31924 .48701 .32948 .50278 .31986 .49407 .30692 Mtetra
.705 .703 .845 r
.49407 .30692 .50278 .31986 .51861 .31039 .50994 .29882 Mtetra
.672 .717 .882 r
.50994 .29882 .51861 .31039 .53449 .30332 .52589 .29276 Mtetra
.664 .736 .903 r
.52589 .29276 .53449 .30332 .55046 .29747 .54192 .2871 Mtetra
.664 .741 .907 r
.54192 .2871 .55046 .29747 .56653 .29185 .55804 .28146 Mtetra
.664 .741 .908 r
.55804 .28146 .56653 .29185 .58268 .28624 .57426 .27578 Mtetra
.57426 .27578 .58268 .28624 .59894 .28059 .59058 .27007 Mtetra
.59058 .27007 .59894 .28059 .61528 .27491 .60699 .26433 Mtetra
.60699 .26433 .61528 .27491 .63173 .26919 .6235 .25855 Mtetra
.6235 .25855 .63173 .26919 .64827 .26344 .64011 .25274 Mtetra
.64011 .25274 .64827 .26344 .66491 .25766 .65681 .24689 Mtetra
.65681 .24689 .66491 .25766 .68164 .25184 .67362 .24101 Mtetra
.67362 .24101 .68164 .25184 .69848 .24599 .69052 .2351 Mtetra
.69052 .2351 .69848 .24599 .71542 .24011 .70753 .22915 Mtetra
.70753 .22915 .71542 .24011 .73246 .23418 .72464 .22316 Mtetra
.72464 .22316 .73246 .23418 .7496 .22823 .74185 .21713 Mtetra
.74185 .21713 .7496 .22823 .76684 .22223 .75917 .21107 Mtetra
.75917 .21107 .76684 .22223 .78419 .2162 .77659 .20498 Mtetra
.77659 .20498 .78419 .2162 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.18549 .39922 .19534 .40839 .2095 .40343 .1997 .39421 Mtetra
.1997 .39421 .2095 .40343 .22374 .39845 .21398 .38918 Mtetra
.21398 .38918 .22374 .39845 .23806 .39344 .22835 .38411 Mtetra
.22835 .38411 .23806 .39344 .25245 .3884 .24279 .37903 Mtetra
.24279 .37903 .25245 .3884 .26693 .38333 .25731 .37391 Mtetra
.25731 .37391 .26693 .38333 .28149 .37824 .27192 .36876 Mtetra
.27192 .36876 .28149 .37824 .29612 .37312 .2866 .36359 Mtetra
.2866 .36359 .29612 .37312 .31084 .36797 .30137 .35838 Mtetra
.30137 .35838 .31084 .36797 .32564 .36279 .31622 .35315 Mtetra
.31622 .35315 .32564 .36279 .34053 .35758 .33116 .34789 Mtetra
.663 .741 .908 r
.33116 .34789 .34053 .35758 .35549 .35234 .34618 .3426 Mtetra
.662 .741 .909 r
.34618 .3426 .35549 .35234 .37055 .34707 .36128 .33734 Mtetra
.646 .737 .916 r
.36128 .33734 .37055 .34707 .38568 .34181 .37644 .33267 Mtetra
.536 .712 .953 r
.37644 .33267 .38568 .34181 .40089 .33686 .39156 .33111 Mtetra
0 .44 .819 r
.39156 .33111 .40089 .33686 .41613 .33366 .40654 .33648 Mtetra
.561 .012 0 r
.40654 .33648 .41613 .33366 .43136 .33457 .42165 .34399 Mtetra
.131 0 0 r
.42165 .34399 .43136 .33457 .44669 .33708 .43732 .33873 Mtetra
.885 .985 .814 r
.43732 .33873 .44669 .33708 .46233 .33225 .45339 .3204 Mtetra
.813 .748 .791 r
.45339 .3204 .46233 .33225 .4782 .31924 .46938 .3039 Mtetra
.714 .673 .808 r
.46938 .3039 .4782 .31924 .49407 .30692 .48527 .29436 Mtetra
.674 .7 .866 r
.48527 .29436 .49407 .30692 .50994 .29882 .50119 .28804 Mtetra
.665 .732 .9 r
.50119 .28804 .50994 .29882 .52589 .29276 .51719 .28233 Mtetra
.664 .74 .907 r
.51719 .28233 .52589 .29276 .54192 .2871 .53328 .27666 Mtetra
.664 .741 .908 r
.53328 .27666 .54192 .2871 .55804 .28146 .54947 .27095 Mtetra
.54947 .27095 .55804 .28146 .57426 .27578 .56575 .26522 Mtetra
.56575 .26522 .57426 .27578 .59058 .27007 .58213 .25944 Mtetra
.58213 .25944 .59058 .27007 .60699 .26433 .59861 .25364 Mtetra
.59861 .25364 .60699 .26433 .6235 .25855 .61518 .2478 Mtetra
.61518 .2478 .6235 .25855 .64011 .25274 .63185 .24192 Mtetra
.63185 .24192 .64011 .25274 .65681 .24689 .64863 .23601 Mtetra
.64863 .23601 .65681 .24689 .67362 .24101 .6655 .23006 Mtetra
.6655 .23006 .67362 .24101 .69052 .2351 .68248 .22408 Mtetra
.68248 .22408 .69052 .2351 .70753 .22915 .69955 .21806 Mtetra
.69955 .21806 .70753 .22915 .72464 .22316 .71674 .21201 Mtetra
.71674 .21201 .72464 .22316 .74185 .21713 .73402 .20592 Mtetra
.73402 .20592 .74185 .21713 .75917 .21107 .75141 .19979 Mtetra
.75141 .19979 .75917 .21107 .77659 .20498 .76891 .19362 Mtetra
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.17555 .38995 .18549 .39922 .1997 .39421 .1898 .3849 Mtetra
.1898 .3849 .1997 .39421 .21398 .38918 .20413 .37981 Mtetra
.20413 .37981 .21398 .38918 .22835 .38411 .21853 .3747 Mtetra
.21853 .3747 .22835 .38411 .24279 .37903 .23302 .36955 Mtetra
.23302 .36955 .24279 .37903 .25731 .37391 .2476 .36438 Mtetra
.2476 .36438 .25731 .37391 .27192 .36876 .26225 .35918 Mtetra
.26225 .35918 .27192 .36876 .2866 .36359 .27698 .35396 Mtetra
.27698 .35396 .2866 .36359 .30137 .35838 .2918 .3487 Mtetra
.2918 .3487 .30137 .35838 .31622 .35315 .3067 .34341 Mtetra
.663 .741 .908 r
.3067 .34341 .31622 .35315 .33116 .34789 .32169 .3381 Mtetra
.661 .741 .909 r
.32169 .3381 .33116 .34789 .34618 .3426 .33675 .33286 Mtetra
.632 .734 .922 r
.33675 .33286 .34618 .3426 .36128 .33734 .35185 .32866 Mtetra
.398 .664 .967 r
.35185 .32866 .36128 .33734 .37644 .33267 .36678 .32964 Mtetra
.628 .064 0 r
.36678 .32964 .37644 .33267 .39156 .33111 .38136 .34162 Mtetra
.695 .265 .224 r
.38136 .34162 .39156 .33111 .40654 .33648 .39609 .35608 Mtetra
.304 0 .128 r
.39609 .35608 .40654 .33648 .42165 .34399 .41185 .34962 Mtetra
.928 .971 .706 r
.41185 .34962 .42165 .34399 .43732 .33873 .4283 .32354 Mtetra
.826 .71 .737 r
.4283 .32354 .43732 .33873 .45339 .3204 .44454 .30134 Mtetra
.715 .634 .766 r
.44454 .30134 .45339 .3204 .46938 .3039 .46047 .28995 Mtetra
.675 .679 .846 r
.46047 .28995 .46938 .3039 .48527 .29436 .47637 .2833 Mtetra
.665 .727 .896 r
.47637 .2833 .48527 .29436 .50119 .28804 .49233 .27754 Mtetra
.664 .74 .907 r
.49233 .27754 .50119 .28804 .51719 .28233 .50839 .27183 Mtetra
.664 .741 .908 r
.50839 .27183 .51719 .28233 .53328 .27666 .52455 .2661 Mtetra
.52455 .2661 .53328 .27666 .54947 .27095 .5408 .26033 Mtetra
.5408 .26033 .54947 .27095 .56575 .26522 .55715 .25453 Mtetra
.55715 .25453 .56575 .26522 .58213 .25944 .57359 .2487 Mtetra
.57359 .2487 .58213 .25944 .59861 .25364 .59013 .24283 Mtetra
.59013 .24283 .59861 .25364 .61518 .2478 .60677 .23692 Mtetra
.60677 .23692 .61518 .2478 .63185 .24192 .62351 .23098 Mtetra
.62351 .23098 .63185 .24192 .64863 .23601 .64035 .225 Mtetra
.64035 .225 .64863 .23601 .6655 .23006 .6573 .21899 Mtetra
.6573 .21899 .6655 .23006 .68248 .22408 .67434 .21294 Mtetra
.67434 .21294 .68248 .22408 .69955 .21806 .69149 .20686 Mtetra
.69149 .20686 .69955 .21806 .71674 .21201 .70874 .20073 Mtetra
.70874 .20073 .71674 .21201 .73402 .20592 .7261 .19457 Mtetra
.7261 .19457 .73402 .20592 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Mtetra
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.1655 .38059 .17555 .38995 .1898 .3849 .17979 .37549 Mtetra
.17979 .37549 .1898 .3849 .20413 .37981 .19417 .37035 Mtetra
.19417 .37035 .20413 .37981 .21853 .3747 .20862 .36518 Mtetra
.20862 .36518 .21853 .3747 .23302 .36955 .22316 .35999 Mtetra
.22316 .35999 .23302 .36955 .2476 .36438 .23778 .35476 Mtetra
.23778 .35476 .2476 .36438 .26225 .35918 .25248 .34951 Mtetra
.25248 .34951 .26225 .35918 .27698 .35396 .26726 .34422 Mtetra
.26726 .34422 .27698 .35396 .2918 .3487 .28213 .33891 Mtetra
.663 .741 .908 r
.28213 .33891 .2918 .3487 .3067 .34341 .29708 .33358 Mtetra
.659 .74 .91 r
.29708 .33358 .3067 .34341 .32169 .3381 .31211 .32839 Mtetra
.609 .728 .93 r
.31211 .32839 .32169 .3381 .33675 .33286 .32711 .3249 Mtetra
.102 .515 .908 r
.32711 .3249 .33675 .33286 .35185 .32866 .34175 .32951 Mtetra
.805 .343 .137 r
.34175 .32951 .35185 .32866 .36678 .32964 .35569 .35056 Mtetra
.724 .359 .358 r
.35569 .35056 .36678 .32964 .38136 .34162 .36986 .37401 Mtetra
.356 .027 .263 r
.36986 .37401 .38136 .34162 .39609 .35608 .38581 .36511 Mtetra
.965 .935 .629 r
.38581 .36511 .39609 .35608 .41185 .34962 .4029 .32852 Mtetra
.822 .665 .688 r
.4029 .32852 .41185 .34962 .4283 .32354 .41952 .29915 Mtetra
.71 .594 .724 r
.41952 .29915 .4283 .32354 .44454 .30134 .43554 .28555 Mtetra
.674 .653 .822 r
.43554 .28555 .44454 .30134 .46047 .28995 .45142 .27853 Mtetra
.665 .722 .891 r
.45142 .27853 .46047 .28995 .47637 .2833 .46736 .27272 Mtetra
.664 .739 .906 r
.46736 .27272 .47637 .2833 .49233 .27754 .48338 .26698 Mtetra
.664 .741 .908 r
.48338 .26698 .49233 .27754 .50839 .27183 .49951 .26122 Mtetra
.49951 .26122 .50839 .27183 .52455 .2661 .51572 .25543 Mtetra
.51572 .25543 .52455 .2661 .5408 .26033 .53204 .2496 Mtetra
.53204 .2496 .5408 .26033 .55715 .25453 .54845 .24373 Mtetra
.54845 .24373 .55715 .25453 .57359 .2487 .56495 .23783 Mtetra
.56495 .23783 .57359 .2487 .59013 .24283 .58156 .2319 Mtetra
.58156 .2319 .59013 .24283 .60677 .23692 .59827 .22593 Mtetra
.59827 .22593 .60677 .23692 .62351 .23098 .61508 .21992 Mtetra
.61508 .21992 .62351 .23098 .64035 .225 .63199 .21388 Mtetra
.63199 .21388 .64035 .225 .6573 .21899 .649 .2078 Mtetra
.649 .2078 .6573 .21899 .67434 .21294 .66611 .20168 Mtetra
.66611 .20168 .67434 .21294 .69149 .20686 .68334 .19552 Mtetra
.68334 .19552 .69149 .20686 .70874 .20073 .70066 .18933 Mtetra
.70066 .18933 .70874 .20073 .7261 .19457 .71809 .1831 Mtetra
.71809 .1831 .7261 .19457 .74357 .18838 .73563 .17683 Mtetra
.73563 .17683 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.15534 .37114 .1655 .38059 .17979 .37549 .16968 .36598 Mtetra
.16968 .36598 .17979 .37549 .19417 .37035 .1841 .36079 Mtetra
.1841 .36079 .19417 .37035 .20862 .36518 .19861 .35557 Mtetra
.19861 .35557 .20862 .36518 .22316 .35999 .21319 .35032 Mtetra
.21319 .35032 .22316 .35999 .23778 .35476 .22786 .34504 Mtetra
.22786 .34504 .23778 .35476 .25248 .34951 .24261 .33973 Mtetra
.24261 .33973 .25248 .34951 .26726 .34422 .25744 .33439 Mtetra
.663 .741 .908 r
.25744 .33439 .26726 .34422 .28213 .33891 .27236 .32904 Mtetra
.656 .739 .911 r
.27236 .32904 .28213 .33891 .29708 .33358 .28734 .32394 Mtetra
.573 .719 .941 r
.28734 .32394 .29708 .33358 .31211 .32839 .30222 .32142 Mtetra
0 .176 .614 r
.30222 .32142 .31211 .32839 .32711 .3249 .31643 .33084 Mtetra
.841 .448 .305 r
.31643 .33084 .32711 .3249 .34175 .32951 .32944 .36345 Mtetra
.73 .399 .42 r
.32944 .36345 .34175 .32951 .35569 .35056 .34283 .39752 Mtetra
.361 .066 .322 r
.34283 .39752 .35569 .35056 .36986 .37401 .35912 .3845 Mtetra
.99 .89 .596 r
.35912 .3845 .36986 .37401 .38581 .36511 .37715 .33477 Mtetra
.807 .621 .651 r
.37715 .33477 .38581 .36511 .4029 .32852 .39433 .29713 Mtetra
.7 .556 .688 r
.39433 .29713 .4029 .32852 .41952 .29915 .41048 .28114 Mtetra
.67 .626 .797 r
.41048 .28114 .41952 .29915 .43554 .28555 .42635 .27375 Mtetra
.665 .715 .886 r
.42635 .27375 .43554 .28555 .45142 .27853 .44226 .26788 Mtetra
.664 .739 .906 r
.44226 .26788 .45142 .27853 .46736 .27272 .45825 .26211 Mtetra
.664 .741 .908 r
.45825 .26211 .46736 .27272 .48338 .26698 .47434 .25632 Mtetra
.47434 .25632 .48338 .26698 .49951 .26122 .49052 .2505 Mtetra
.49052 .2505 .49951 .26122 .51572 .25543 .5068 .24464 Mtetra
.5068 .24464 .51572 .25543 .53204 .2496 .52318 .23874 Mtetra
.52318 .23874 .53204 .2496 .54845 .24373 .53965 .23281 Mtetra
.53965 .23281 .54845 .24373 .56495 .23783 .55622 .22685 Mtetra
.55622 .22685 .56495 .23783 .58156 .2319 .5729 .22085 Mtetra
.5729 .22085 .58156 .2319 .59827 .22593 .58967 .21481 Mtetra
.58967 .21481 .59827 .22593 .61508 .21992 .60655 .20873 Mtetra
.60655 .20873 .61508 .21992 .63199 .21388 .62353 .20262 Mtetra
.62353 .20262 .63199 .21388 .649 .2078 .64061 .19647 Mtetra
.64061 .19647 .649 .2078 .66611 .20168 .6578 .19029 Mtetra
.6578 .19029 .66611 .20168 .68334 .19552 .67509 .18406 Mtetra
.67509 .18406 .68334 .19552 .70066 .18933 .69249 .1778 Mtetra
.69249 .1778 .70066 .18933 .71809 .1831 .70999 .1715 Mtetra
.70999 .1715 .71809 .1831 .73563 .17683 .72761 .16516 Mtetra
.72761 .16516 .73563 .17683 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.14508 .36159 .15534 .37114 .16968 .36598 .15947 .35637 Mtetra
.15947 .35637 .16968 .36598 .1841 .36079 .17394 .35113 Mtetra
.17394 .35113 .1841 .36079 .19861 .35557 .18849 .34585 Mtetra
.18849 .34585 .19861 .35557 .21319 .35032 .20312 .34055 Mtetra
.20312 .34055 .21319 .35032 .22786 .34504 .21783 .33521 Mtetra
.21783 .33521 .22786 .34504 .24261 .33973 .23263 .32985 Mtetra
.663 .741 .908 r
.23263 .32985 .24261 .33973 .25744 .33439 .24751 .32448 Mtetra
.652 .739 .913 r
.24751 .32448 .25744 .33439 .27236 .32904 .26244 .3195 Mtetra
.52 .702 .953 r
.26244 .3195 .27236 .32904 .28734 .32394 .27717 .31823 Mtetra
.704 .171 0 r
.27717 .31823 .28734 .32394 .30222 .32142 .29079 .33353 Mtetra
.847 .494 .384 r
.29079 .33353 .30222 .32142 .31643 .33084 .30256 .37961 Mtetra
.729 .417 .452 r
.30256 .37961 .31643 .33084 .32944 .36345 .31495 .42505 Mtetra
.341 .067 .344 r
.31495 .42505 .32944 .36345 .34283 .39752 .33179 .40593 Mtetra
.992 .838 .587 r
.33179 .40593 .34283 .39752 .35912 .3845 .35109 .34123 Mtetra
.787 .582 .624 r
.35109 .34123 .35912 .3845 .37715 .33477 .36898 .29496 Mtetra
.688 .523 .659 r
.36898 .29496 .37715 .33477 .39433 .29713 .3853 .27666 Mtetra
.664 .6 .773 r
.3853 .27666 .39433 .29713 .41048 .28114 .40116 .26893 Mtetra
.664 .708 .88 r
.40116 .26893 .41048 .28114 .42635 .27375 .41703 .26301 Mtetra
.664 .738 .905 r
.41703 .26301 .42635 .27375 .44226 .26788 .43299 .25721 Mtetra
.664 .741 .908 r
.43299 .25721 .44226 .26788 .45825 .26211 .44904 .25139 Mtetra
.44904 .25139 .45825 .26211 .47434 .25632 .46519 .24554 Mtetra
.46519 .24554 .47434 .25632 .49052 .2505 .48143 .23965 Mtetra
.48143 .23965 .49052 .2505 .5068 .24464 .49778 .23373 Mtetra
.49778 .23373 .5068 .24464 .52318 .23874 .51422 .22777 Mtetra
.51422 .22777 .52318 .23874 .53965 .23281 .53076 .22177 Mtetra
.53076 .22177 .53965 .23281 .55622 .22685 .5474 .21574 Mtetra
.5474 .21574 .55622 .22685 .5729 .22085 .56414 .20967 Mtetra
.56414 .20967 .5729 .22085 .58967 .21481 .58098 .20357 Mtetra
.58098 .20357 .58967 .21481 .60655 .20873 .59792 .19742 Mtetra
.59792 .19742 .60655 .20873 .62353 .20262 .61497 .19124 Mtetra
.61497 .19124 .62353 .20262 .64061 .19647 .63212 .18502 Mtetra
.63212 .18502 .64061 .19647 .6578 .19029 .64938 .17877 Mtetra
.64938 .17877 .6578 .19029 .67509 .18406 .66675 .17247 Mtetra
.66675 .17247 .67509 .18406 .69249 .1778 .68422 .16614 Mtetra
.68422 .16614 .69249 .1778 .70999 .1715 .7018 .15976 Mtetra
.7018 .15976 .70999 .1715 .72761 .16516 .71949 .15335 Mtetra
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Mtetra
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.13472 .35194 .14508 .36159 .15947 .35637 .14915 .34667 Mtetra
.14915 .34667 .15947 .35637 .17394 .35113 .16366 .34137 Mtetra
.16366 .34137 .17394 .35113 .18849 .34585 .17826 .33604 Mtetra
.17826 .33604 .18849 .34585 .20312 .34055 .19294 .33068 Mtetra
.19294 .33068 .20312 .34055 .21783 .33521 .2077 .32529 Mtetra
.663 .741 .908 r
.2077 .32529 .21783 .33521 .23263 .32985 .22255 .3199 Mtetra
.647 .737 .915 r
.22255 .3199 .23263 .32985 .24751 .32448 .23742 .31507 Mtetra
.443 .674 .961 r
.23742 .31507 .24751 .32448 .26244 .3195 .25195 .31526 Mtetra
.829 .357 .061 r
.25195 .31526 .26244 .3195 .27717 .31823 .26484 .3371 Mtetra
.847 .515 .426 r
.26484 .3371 .27717 .31823 .29079 .33353 .27508 .39741 Mtetra
.726 .425 .47 r
.27508 .39741 .29079 .33353 .30256 .37961 .28635 .45352 Mtetra
.298 .04 .343 r
.28635 .45352 .30256 .37961 .31495 .42505 .30395 .42644 Mtetra
.972 .78 .587 r
.30395 .42644 .31495 .42505 .33179 .40593 .32479 .34645 Mtetra
.766 .55 .605 r
.32479 .34645 .33179 .40593 .35109 .34123 .34348 .29229 Mtetra
.675 .497 .637 r
.34348 .29229 .35109 .34123 .36898 .29496 .35998 .27207 Mtetra
.658 .578 .754 r
.35998 .27207 .36898 .29496 .3853 .27666 .37584 .26408 Mtetra
.664 .703 .876 r
.37584 .26408 .3853 .27666 .40116 .26893 .39168 .25812 Mtetra
.664 .738 .905 r
.39168 .25812 .40116 .26893 .41703 .26301 .4076 .25229 Mtetra
.664 .741 .908 r
.4076 .25229 .41703 .26301 .43299 .25721 .42362 .24644 Mtetra
.42362 .24644 .43299 .25721 .44904 .25139 .43973 .24056 Mtetra
.43973 .24056 .44904 .25139 .46519 .24554 .45594 .23464 Mtetra
.45594 .23464 .46519 .24554 .48143 .23965 .47225 .22869 Mtetra
.47225 .22869 .48143 .23965 .49778 .23373 .48865 .2227 Mtetra
.48865 .2227 .49778 .23373 .51422 .22777 .50516 .21667 Mtetra
.50516 .21667 .51422 .22777 .53076 .22177 .52176 .21061 Mtetra
.52176 .21061 .53076 .22177 .5474 .21574 .53847 .20451 Mtetra
.53847 .20451 .5474 .21574 .56414 .20967 .55527 .19837 Mtetra
.55527 .19837 .56414 .20967 .58098 .20357 .57218 .1922 Mtetra
.57218 .1922 .58098 .20357 .59792 .19742 .5892 .18598 Mtetra
.5892 .18598 .59792 .19742 .61497 .19124 .60632 .17973 Mtetra
.60632 .17973 .61497 .19124 .63212 .18502 .62354 .17344 Mtetra
.62354 .17344 .63212 .18502 .64938 .17877 .64087 .16711 Mtetra
.64087 .16711 .64938 .17877 .66675 .17247 .65831 .16075 Mtetra
.65831 .16075 .66675 .17247 .68422 .16614 .67586 .15434 Mtetra
.67586 .15434 .68422 .16614 .7018 .15976 .69351 .14789 Mtetra
.69351 .14789 .7018 .15976 .71949 .15335 .71128 .14141 Mtetra
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Mtetra
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Mtetra
.12424 .34218 .13472 .35194 .14915 .34667 .13872 .33686 Mtetra
.13872 .33686 .14915 .34667 .16366 .34137 .15328 .3315 Mtetra
.15328 .3315 .16366 .34137 .17826 .33604 .16793 .32612 Mtetra
.16793 .32612 .17826 .33604 .19294 .33068 .18265 .3207 Mtetra
.662 .741 .908 r
.18265 .3207 .19294 .33068 .2077 .32529 .19746 .3153 Mtetra
.642 .736 .917 r
.19746 .3153 .2077 .32529 .22255 .3199 .21228 .31064 Mtetra
.341 .63 .959 r
.21228 .31064 .22255 .3199 .23742 .31507 .22657 .31238 Mtetra
.869 .443 .199 r
.22657 .31238 .23742 .31507 .25195 .31526 .23862 .34073 Mtetra
.844 .526 .449 r
.23862 .34073 .25195 .31526 .26484 .3371 .24718 .41426 Mtetra
.721 .427 .479 r
.24718 .41426 .26484 .3371 .27508 .39741 .25734 .4786 Mtetra
.229 0 .32 r
.25734 .4786 .27508 .39741 .28635 .45352 .27592 .44239 Mtetra
.937 .724 .588 r
.27592 .44239 .28635 .45352 .30395 .42644 .29839 .34892 Mtetra
.745 .522 .592 r
.29839 .34892 .30395 .42644 .32479 .34645 .31788 .28877 Mtetra
.663 .476 .622 r
.31788 .28877 .32479 .34645 .34348 .29229 .33455 .26732 Mtetra
.652 .561 .739 r
.33455 .26732 .34348 .29229 .35998 .27207 .3504 .25919 Mtetra
.663 .698 .873 r
.3504 .25919 .35998 .27207 .37584 .26408 .3662 .2532 Mtetra
.664 .737 .905 r
.3662 .2532 .37584 .26408 .39168 .25812 .38209 .24735 Mtetra
.664 .741 .908 r
.38209 .24735 .39168 .25812 .4076 .25229 .39807 .24147 Mtetra
.39807 .24147 .4076 .25229 .42362 .24644 .41415 .23555 Mtetra
.41415 .23555 .42362 .24644 .43973 .24056 .43032 .22961 Mtetra
.43032 .22961 .43973 .24056 .45594 .23464 .44659 .22362 Mtetra
.44659 .22362 .45594 .23464 .47225 .22869 .46296 .2176 Mtetra
.46296 .2176 .47225 .22869 .48865 .2227 .47943 .21154 Mtetra
.47943 .21154 .48865 .2227 .50516 .21667 .496 .20545 Mtetra
.496 .20545 .50516 .21667 .52176 .21061 .51267 .19932 Mtetra
.51267 .19932 .52176 .21061 .53847 .20451 .52944 .19315 Mtetra
.52944 .19315 .53847 .20451 .55527 .19837 .54631 .18694 Mtetra
.54631 .18694 .55527 .19837 .57218 .1922 .56329 .1807 Mtetra
.56329 .1807 .57218 .1922 .5892 .18598 .58037 .17441 Mtetra
.58037 .17441 .5892 .18598 .60632 .17973 .59756 .16809 Mtetra
.59756 .16809 .60632 .17973 .62354 .17344 .61486 .16173 Mtetra
.61486 .16173 .62354 .17344 .64087 .16711 .63226 .15533 Mtetra
.63226 .15533 .64087 .16711 .65831 .16075 .64977 .14889 Mtetra
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Mtetra
.6674 .14241 .67586 .15434 .69351 .14789 .68513 .13588 Mtetra
.68513 .13588 .69351 .14789 .71128 .14141 .70297 .12932 Mtetra
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.11366 .33233 .12424 .34218 .13872 .33686 .12818 .32695 Mtetra
.12818 .32695 .13872 .33686 .15328 .3315 .14279 .32154 Mtetra
.663 .741 .908 r
.14279 .32154 .15328 .3315 .16793 .32612 .15748 .31609 Mtetra
.662 .741 .909 r
.15748 .31609 .16793 .32612 .18265 .3207 .17225 .31068 Mtetra
.636 .735 .92 r
.17225 .31068 .18265 .3207 .19746 .3153 .187 .30619 Mtetra
.223 .572 .94 r
.187 .30619 .19746 .3153 .21228 .31064 .20105 .30936 Mtetra
.882 .485 .273 r
.20105 .30936 .21228 .31064 .22657 .31238 .21223 .34335 Mtetra
.842 .531 .463 r
.21223 .34335 .22657 .31238 .23862 .34073 .21918 .42704 Mtetra
.716 .425 .483 r
.21918 .42704 .23862 .34073 .24718 .41426 .22842 .49554 Mtetra
.116 0 .267 r
.22842 .49554 .24718 .41426 .25734 .4786 .24808 .45028 Mtetra
.899 .673 .587 r
.24808 .45028 .25734 .4786 .27592 .44239 .27206 .3474 Mtetra
.726 .5 .583 r
.27206 .3474 .27592 .44239 .29839 .34892 .29221 .28419 Mtetra
.652 .461 .612 r
.29221 .28419 .29839 .34892 .31788 .28877 .309 .2624 Mtetra
.647 .55 .731 r
.309 .2624 .31788 .28877 .33455 .26732 .32482 .25427 Mtetra
.662 .696 .871 r
.32482 .25427 .33455 .26732 .3504 .25919 .34059 .24825 Mtetra
.663 .737 .905 r
.34059 .24825 .3504 .25919 .3662 .2532 .35644 .24237 Mtetra
.664 .741 .908 r
.35644 .24237 .3662 .2532 .38209 .24735 .37239 .23647 Mtetra
.37239 .23647 .38209 .24735 .39807 .24147 .38843 .23052 Mtetra
.38843 .23052 .39807 .24147 .41415 .23555 .40457 .22454 Mtetra
.40457 .22454 .41415 .23555 .43032 .22961 .4208 .21853 Mtetra
.4208 .21853 .43032 .22961 .44659 .22362 .43714 .21248 Mtetra
.43714 .21248 .44659 .22362 .46296 .2176 .45357 .20639 Mtetra
.45357 .20639 .46296 .2176 .47943 .21154 .4701 .20026 Mtetra
.4701 .20026 .47943 .21154 .496 .20545 .48673 .1941 Mtetra
.48673 .1941 .496 .20545 .51267 .19932 .50347 .1879 Mtetra
.50347 .1879 .51267 .19932 .52944 .19315 .52031 .18166 Mtetra
.52031 .18166 .52944 .19315 .54631 .18694 .53725 .17538 Mtetra
.53725 .17538 .54631 .18694 .56329 .1807 .5543 .16907 Mtetra
.5543 .16907 .56329 .1807 .58037 .17441 .57145 .16271 Mtetra
.57145 .16271 .58037 .17441 .59756 .16809 .58871 .15632 Mtetra
.58871 .15632 .59756 .16809 .61486 .16173 .60608 .14988 Mtetra
.60608 .14988 .61486 .16173 .63226 .15533 .62355 .14341 Mtetra
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Mtetra
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Mtetra
.65884 .13033 .6674 .14241 .68513 .13588 .67665 .12373 Mtetra
.67665 .12373 .68513 .13588 .70297 .12932 .69457 .11709 Mtetra
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.10296 .32237 .11366 .33233 .12818 .32695 .11753 .31693 Mtetra
.663 .741 .908 r
.11753 .31693 .12818 .32695 .14279 .32154 .13219 .31146 Mtetra
.662 .741 .909 r
.13219 .31146 .14279 .32154 .15748 .31609 .14692 .30604 Mtetra
.631 .734 .922 r
.14692 .30604 .15748 .31609 .17225 .31068 .1616 .30169 Mtetra
.114 .511 .909 r
.1616 .30169 .17225 .31068 .187 .30619 .17542 .30599 Mtetra
.885 .504 .311 r
.17542 .30599 .187 .30619 .20105 .30936 .18582 .34382 Mtetra
.839 .532 .47 r
.18582 .34382 .20105 .30936 .21223 .34335 .19146 .43283 Mtetra
.71 .42 .483 r
.19146 .43283 .21223 .34335 .21918 .42704 .20018 .50038 Mtetra
0 0 .16 r
.20018 .50038 .21918 .42704 .22842 .49554 .22086 .44778 Mtetra
.861 .629 .586 r
.22086 .44778 .22842 .49554 .24808 .45028 .24594 .34129 Mtetra
.709 .481 .577 r
.24594 .34129 .24808 .45028 .27206 .3474 .2665 .27849 Mtetra
.643 .45 .606 r
.2665 .27849 .27206 .3474 .29221 .28419 .28333 .25731 Mtetra
.643 .545 .729 r
.28333 .25731 .29221 .28419 .309 .2624 .29912 .24932 Mtetra
.662 .697 .872 r
.29912 .24932 .309 .2624 .32482 .25427 .31485 .24329 Mtetra
.663 .738 .905 r
.31485 .24329 .32482 .25427 .34059 .24825 .33067 .23738 Mtetra
.664 .741 .908 r
.33067 .23738 .34059 .24825 .35644 .24237 .34658 .23144 Mtetra
.34658 .23144 .35644 .24237 .37239 .23647 .36258 .22547 Mtetra
.36258 .22547 .37239 .23647 .38843 .23052 .37868 .21946 Mtetra
.37868 .21946 .38843 .23052 .40457 .22454 .39488 .21341 Mtetra
.39488 .21341 .40457 .22454 .4208 .21853 .41118 .20733 Mtetra
.41118 .20733 .4208 .21853 .43714 .21248 .42757 .20121 Mtetra
.42757 .20121 .43714 .21248 .45357 .20639 .44407 .19505 Mtetra
.44407 .19505 .45357 .20639 .4701 .20026 .46067 .18886 Mtetra
.46067 .18886 .4701 .20026 .48673 .1941 .47737 .18262 Mtetra
.47737 .18262 .48673 .1941 .50347 .1879 .49417 .17635 Mtetra
.49417 .17635 .50347 .1879 .52031 .18166 .51107 .17004 Mtetra
.51107 .17004 .52031 .18166 .53725 .17538 .52808 .16369 Mtetra
.52808 .16369 .53725 .17538 .5543 .16907 .5452 .1573 Mtetra
.5452 .1573 .5543 .16907 .57145 .16271 .56242 .15087 Mtetra
.56242 .15087 .57145 .16271 .58871 .15632 .57976 .1444 Mtetra
.57976 .1444 .58871 .15632 .60608 .14988 .5972 .1379 Mtetra
.5972 .1379 .60608 .14988 .62355 .14341 .61475 .13134 Mtetra
.61475 .13134 .62355 .14341 .64114 .13689 .63241 .12475 Mtetra
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Mtetra
.65018 .11812 .65884 .13033 .67665 .12373 .66806 .11144 Mtetra
.66806 .11144 .67665 .12373 .69457 .11709 .68606 .10472 Mtetra
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Mtetra
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.663 .741 .908 r
.09215 .3123 .10296 .32237 .11753 .31693 .10677 .30681 Mtetra
.661 .741 .909 r
.10677 .30681 .11753 .31693 .13219 .31146 .12146 .30137 Mtetra
.627 .733 .924 r
.12146 .30137 .13219 .31146 .14692 .30604 .13609 .29711 Mtetra
.042 .469 .882 r
.13609 .29711 .14692 .30604 .1616 .30169 .1497 .30204 Mtetra
.885 .511 .327 r
.1497 .30204 .1616 .30169 .17542 .30599 .15953 .34128 Mtetra
.836 .53 .471 r
.15953 .34128 .17542 .30599 .18582 .34382 .16442 .42969 Mtetra
.703 .411 .478 r
.16442 .42969 .18582 .34382 .19146 .43283 .17312 .49124 Mtetra
0 0 0 r
.17312 .49124 .19146 .43283 .20018 .50038 .19456 .43442 Mtetra
.827 .593 .584 r
.19456 .43442 .20018 .50038 .22086 .44778 .22013 .33083 Mtetra
.693 .466 .574 r
.22013 .33083 .22086 .44778 .24594 .34129 .24076 .27181 Mtetra
.635 .443 .605 r
.24076 .27181 .24594 .34129 .2665 .27849 .25754 .25209 Mtetra
.642 .547 .733 r
.25754 .25209 .2665 .27849 .28333 .25731 .27329 .24433 Mtetra
.662 .699 .874 r
.27329 .24433 .28333 .25731 .29912 .24932 .28899 .23829 Mtetra
.663 .738 .905 r
.28899 .23829 .29912 .24932 .31485 .24329 .30476 .23236 Mtetra
.664 .741 .908 r
.30476 .23236 .31485 .24329 .33067 .23738 .32064 .22639 Mtetra
.32064 .22639 .33067 .23738 .34658 .23144 .3366 .22038 Mtetra
.3366 .22038 .34658 .23144 .36258 .22547 .35267 .21434 Mtetra
.35267 .21434 .36258 .22547 .37868 .21946 .36883 .20827 Mtetra
.36883 .20827 .37868 .21946 .39488 .21341 .38509 .20215 Mtetra
.38509 .20215 .39488 .21341 .41118 .20733 .40145 .196 Mtetra
.40145 .196 .41118 .20733 .42757 .20121 .4179 .18981 Mtetra
.4179 .18981 .42757 .20121 .44407 .19505 .43446 .18358 Mtetra
.43446 .18358 .44407 .19505 .46067 .18886 .45113 .17732 Mtetra
.45113 .17732 .46067 .18886 .47737 .18262 .46789 .17101 Mtetra
.46789 .17101 .47737 .18262 .49417 .17635 .48476 .16467 Mtetra
.48476 .16467 .49417 .17635 .51107 .17004 .50173 .15829 Mtetra
.50173 .15829 .51107 .17004 .52808 .16369 .51881 .15187 Mtetra
.51881 .15187 .52808 .16369 .5452 .1573 .536 .1454 Mtetra
.536 .1454 .5452 .1573 .56242 .15087 .55329 .1389 Mtetra
.55329 .1389 .56242 .15087 .57976 .1444 .5707 .13236 Mtetra
.5707 .13236 .57976 .1444 .5972 .1379 .58821 .12577 Mtetra
.58821 .12577 .5972 .1379 .61475 .13134 .60583 .11914 Mtetra
.60583 .11914 .61475 .13134 .63241 .12475 .62357 .11247 Mtetra
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Mtetra
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Mtetra
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Mtetra
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Mtetra
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.661 .741 .909 r
.08123 .30214 .09215 .3123 .10677 .30681 .09588 .29667 Mtetra
.626 .733 .924 r
.09588 .29667 .10677 .30681 .12146 .30137 .11045 .29243 Mtetra
.028 .462 .876 r
.11045 .29243 .12146 .30137 .13609 .29711 .12393 .29738 Mtetra
.882 .506 .325 r
.12393 .29738 .13609 .29711 .1497 .30204 .13351 .33533 Mtetra
.833 .525 .468 r
.13351 .33533 .1497 .30204 .15953 .34128 .13831 .4173 Mtetra
.696 .399 .468 r
.13831 .4173 .15953 .34128 .16442 .42969 .1475 .46899 Mtetra
.795 .834 .366 r
.1475 .46899 .16442 .42969 .17312 .49124 .16928 .41183 Mtetra
.797 .563 .584 r
.16928 .41183 .17312 .49124 .19456 .43442 .19463 .31699 Mtetra
.679 .454 .573 r
.19463 .31699 .19456 .43442 .22013 .33083 .21498 .26446 Mtetra
.629 .441 .609 r
.21498 .26446 .22013 .33083 .24076 .27181 .23163 .24677 Mtetra
.642 .557 .743 r
.23163 .24677 .24076 .27181 .25754 .25209 .24733 .23931 Mtetra
.662 .704 .878 r
.24733 .23931 .25754 .25209 .27329 .24433 .26299 .23327 Mtetra
.663 .738 .906 r
.26299 .23327 .27329 .24433 .28899 .23829 .27873 .22731 Mtetra
.664 .741 .908 r
.27873 .22731 .28899 .23829 .30476 .23236 .29456 .22131 Mtetra
.29456 .22131 .30476 .23236 .32064 .22639 .31049 .21527 Mtetra
.31049 .21527 .32064 .22639 .3366 .22038 .32652 .2092 Mtetra
.32652 .2092 .3366 .22038 .35267 .21434 .34264 .20309 Mtetra
.34264 .20309 .35267 .21434 .36883 .20827 .35886 .19695 Mtetra
.35886 .19695 .36883 .20827 .38509 .20215 .37518 .19077 Mtetra
.37518 .19077 .38509 .20215 .40145 .196 .3916 .18454 Mtetra
.3916 .18454 .40145 .196 .4179 .18981 .40812 .17828 Mtetra
.40812 .17828 .4179 .18981 .43446 .18358 .42475 .17199 Mtetra
.42475 .17199 .43446 .18358 .45113 .17732 .44148 .16565 Mtetra
.44148 .16565 .45113 .17732 .46789 .17101 .45831 .15927 Mtetra
.45831 .15927 .46789 .17101 .48476 .16467 .47524 .15286 Mtetra
.47524 .15286 .48476 .16467 .50173 .15829 .49228 .1464 Mtetra
.49228 .1464 .50173 .15829 .51881 .15187 .50943 .1399 Mtetra
.50943 .1399 .51881 .15187 .536 .1454 .52669 .13336 Mtetra
.52669 .13336 .536 .1454 .55329 .1389 .54406 .12679 Mtetra
.54406 .12679 .55329 .1389 .5707 .13236 .56153 .12016 Mtetra
.56153 .12016 .5707 .13236 .58821 .12577 .57912 .1135 Mtetra
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Mtetra
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Mtetra
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Mtetra
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Mtetra
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Mtetra
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Mtetra
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Mtetra
.626 .733 .924 r
.07017 .29195 .08123 .30214 .09588 .29667 .0847 .28764 Mtetra
.077 .494 .897 r
.0847 .28764 .09588 .29667 .11045 .29243 .09813 .292 Mtetra
.877 .491 .303 r
.09813 .292 .11045 .29243 .12393 .29738 .10779 .32616 Mtetra
.83 .516 .459 r
.10779 .32616 .12393 .29738 .13351 .33533 .11319 .39707 Mtetra
.686 .38 .451 r
.11319 .39707 .13351 .33533 .13831 .4173 .12323 .43687 Mtetra
.981 .908 .596 r
.12323 .43687 .13831 .4173 .1475 .46899 .14488 .38311 Mtetra
.77 .539 .585 r
.14488 .38311 .1475 .46899 .16928 .41183 .16937 .30121 Mtetra
.667 .446 .575 r
.16937 .30121 .16928 .41183 .19463 .31699 .18914 .25678 Mtetra
.626 .444 .617 r
.18914 .25678 .19463 .31699 .21498 .26446 .2056 .24141 Mtetra
.644 .573 .76 r
.2056 .24141 .21498 .26446 .23163 .24677 .22124 .23427 Mtetra
.662 .71 .884 r
.22124 .23427 .23163 .24677 .24733 .23931 .23686 .22823 Mtetra
.663 .739 .906 r
.23686 .22823 .24733 .23931 .26299 .23327 .25256 .22223 Mtetra
.664 .741 .908 r
.25256 .22223 .26299 .23327 .27873 .22731 .26835 .2162 Mtetra
.26835 .2162 .27873 .22731 .29456 .22131 .28424 .21014 Mtetra
.28424 .21014 .29456 .22131 .31049 .21527 .30023 .20404 Mtetra
.30023 .20404 .31049 .21527 .32652 .2092 .31632 .1979 Mtetra
.31632 .1979 .32652 .2092 .34264 .20309 .3325 .19172 Mtetra
.3325 .19172 .34264 .20309 .35886 .19695 .34878 .1855 Mtetra
.34878 .1855 .35886 .19695 .37518 .19077 .36516 .17925 Mtetra
.36516 .17925 .37518 .19077 .3916 .18454 .38165 .17296 Mtetra
.38165 .17296 .3916 .18454 .40812 .17828 .39823 .16663 Mtetra
.39823 .16663 .40812 .17828 .42475 .17199 .41492 .16026 Mtetra
.41492 .16026 .42475 .17199 .44148 .16565 .43171 .15385 Mtetra
.43171 .15385 .44148 .16565 .45831 .15927 .44861 .1474 Mtetra
.44861 .1474 .45831 .15927 .47524 .15286 .46562 .1409 Mtetra
.46562 .1409 .47524 .15286 .49228 .1464 .48273 .13437 Mtetra
.48273 .13437 .49228 .1464 .50943 .1399 .49994 .1278 Mtetra
.49994 .1278 .50943 .1399 .52669 .13336 .51727 .12119 Mtetra
.51727 .12119 .52669 .13336 .54406 .12679 .53471 .11453 Mtetra
.53471 .11453 .54406 .12679 .56153 .12016 .55226 .10783 Mtetra
.55226 .10783 .56153 .12016 .57912 .1135 .56992 .10109 Mtetra
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Mtetra
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Mtetra
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Mtetra
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Mtetra
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Mtetra
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Mtetra
.175 .554 .931 r
.05883 .28276 .07017 .29195 .0847 .28764 .0723 .28599 Mtetra
.866 .458 .255 r
.0723 .28599 .0847 .28764 .09813 .292 .08235 .31455 Mtetra
.826 .502 .44 r
.08235 .31455 .09813 .292 .10779 .32616 .0889 .37168 Mtetra
.673 .349 .418 r
.0889 .37168 .10779 .32616 .11319 .39707 .09999 .3995 Mtetra
.96 .831 .67 r
.09999 .3995 .11319 .39707 .12323 .43687 .12106 .35199 Mtetra
.748 .521 .588 r
.12106 .35199 .12323 .43687 .14488 .38311 .14422 .28502 Mtetra
.657 .442 .58 r
.14422 .28502 .14488 .38311 .16937 .30121 .16322 .24913 Mtetra
.625 .455 .632 r
.16322 .24913 .16937 .30121 .18914 .25678 .17945 .23605 Mtetra
.647 .595 .782 r
.17945 .23605 .18914 .25678 .2056 .24141 .19502 .22921 Mtetra
.662 .717 .889 r
.19502 .22921 .2056 .24141 .22124 .23427 .2106 .22316 Mtetra
.663 .74 .907 r
.2106 .22316 .22124 .23427 .23686 .22823 .22626 .21713 Mtetra
.664 .741 .908 r
.22626 .21713 .23686 .22823 .25256 .22223 .24201 .21107 Mtetra
.24201 .21107 .25256 .22223 .26835 .2162 .25786 .20498 Mtetra
.25786 .20498 .26835 .2162 .28424 .21014 .27381 .19884 Mtetra
.27381 .19884 .28424 .21014 .30023 .20404 .28986 .19267 Mtetra
.28986 .19267 .30023 .20404 .31632 .1979 .306 .18646 Mtetra
.306 .18646 .31632 .1979 .3325 .19172 .32224 .18021 Mtetra
.32224 .18021 .3325 .19172 .34878 .1855 .33859 .17393 Mtetra
.33859 .17393 .34878 .1855 .36516 .17925 .35503 .1676 Mtetra
.35503 .1676 .36516 .17925 .38165 .17296 .37158 .16124 Mtetra
.37158 .16124 .38165 .17296 .39823 .16663 .38823 .15483 Mtetra
.38823 .15483 .39823 .16663 .41492 .16026 .40498 .14839 Mtetra
.40498 .14839 .41492 .16026 .43171 .15385 .42184 .14191 Mtetra
.42184 .14191 .43171 .15385 .44861 .1474 .4388 .13538 Mtetra
.4388 .13538 .44861 .1474 .46562 .1409 .45588 .12881 Mtetra
.45588 .12881 .46562 .1409 .48273 .13437 .47306 .12221 Mtetra
.47306 .12221 .48273 .13437 .49994 .1278 .49034 .11556 Mtetra
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Mtetra
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Mtetra
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Mtetra
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Mtetra
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Mtetra
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Mtetra
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Mtetra
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Mtetra
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Mtetra
.84 .393 .157 r
.04642 .27955 .05883 .28276 .0723 .28599 .05711 .30155 Mtetra
.821 .477 .405 r
.05711 .30155 .0723 .28599 .08235 .31455 .06512 .34429 Mtetra
.649 .294 .356 r
.06512 .34429 .08235 .31455 .0889 .37168 .07725 .36153 Mtetra
.898 .749 .688 r
.07725 .36153 .0889 .37168 .09999 .3995 .09743 .32178 Mtetra
.728 .509 .594 r
.09743 .32178 .09999 .3995 .12106 .35199 .11901 .26966 Mtetra
.649 .443 .59 r
.11901 .26966 .12106 .35199 .14422 .28502 .13717 .24176 Mtetra
.627 .473 .655 r
.13717 .24176 .14422 .28502 .16322 .24913 .15316 .23072 Mtetra
.652 .622 .807 r
.15316 .23072 .16322 .24913 .17945 .23605 .16867 .22412 Mtetra
.663 .723 .894 r
.16867 .22412 .17945 .23605 .19502 .22921 .1842 .21807 Mtetra
.663 .74 .907 r
.1842 .21807 .19502 .22921 .2106 .22316 .19982 .21201 Mtetra
.664 .741 .908 r
.19982 .21201 .2106 .22316 .22626 .21713 .21553 .20592 Mtetra
.21553 .20592 .22626 .21713 .24201 .21107 .23135 .19979 Mtetra
.23135 .19979 .24201 .21107 .25786 .20498 .24725 .19362 Mtetra
.24725 .19362 .25786 .20498 .27381 .19884 .26326 .18742 Mtetra
.26326 .18742 .27381 .19884 .28986 .19267 .27936 .18118 Mtetra
.27936 .18118 .28986 .19267 .306 .18646 .29557 .1749 Mtetra
.29557 .1749 .306 .18646 .32224 .18021 .31187 .16858 Mtetra
.31187 .16858 .32224 .18021 .33859 .17393 .32828 .16222 Mtetra
.32828 .16222 .33859 .17393 .35503 .1676 .34478 .15582 Mtetra
.34478 .15582 .35503 .1676 .37158 .16124 .36139 .14938 Mtetra
.36139 .14938 .37158 .16124 .38823 .15483 .37811 .14291 Mtetra
.37811 .14291 .38823 .15483 .40498 .14839 .39493 .13639 Mtetra
.39493 .13639 .40498 .14839 .42184 .14191 .41185 .12983 Mtetra
.41185 .12983 .42184 .14191 .4388 .13538 .42888 .12323 Mtetra
.42888 .12323 .4388 .13538 .45588 .12881 .44602 .11658 Mtetra
.44602 .11658 .45588 .12881 .47306 .12221 .46327 .1099 Mtetra
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Mtetra
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Mtetra
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Mtetra
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Mtetra
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Mtetra
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Mtetra
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Mtetra
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Mtetra
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Mtetra
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.811 .432 .338 r
.0319 .2883 .04642 .27955 .05711 .30155 .04146 .31772 Mtetra
.594 .174 .214 r
.04146 .31772 .05711 .30155 .06512 .34429 .0545 .32656 Mtetra
.842 .693 .697 r
.0545 .32656 .06512 .34429 .07725 .36153 .07363 .29483 Mtetra
.712 .503 .605 r
.07363 .29483 .07725 .36153 .09743 .32178 .09361 .25595 Mtetra
.645 .452 .607 r
.09361 .25595 .09743 .32178 .11901 .26966 .11096 .23482 Mtetra
.632 .502 .687 r
.11096 .23482 .11901 .26966 .13717 .24176 .12673 .22543 Mtetra
.656 .651 .833 r
.12673 .22543 .13717 .24176 .15316 .23072 .14218 .21902 Mtetra
.663 .729 .898 r
.14218 .21902 .15316 .23072 .16867 .22412 .15767 .21294 Mtetra
.663 .74 .907 r
.15767 .21294 .16867 .22412 .1842 .21807 .17325 .20686 Mtetra
.664 .741 .908 r
.17325 .20686 .1842 .21807 .19982 .21201 .18892 .20073 Mtetra
.18892 .20073 .19982 .21201 .21553 .20592 .20469 .19457 Mtetra
.20469 .19457 .21553 .20592 .23135 .19979 .22056 .18838 Mtetra
.22056 .18838 .23135 .19979 .24725 .19362 .23652 .18214 Mtetra
.23652 .18214 .24725 .19362 .26326 .18742 .25259 .17587 Mtetra
.25259 .17587 .26326 .18742 .27936 .18118 .26875 .16955 Mtetra
.26875 .16955 .27936 .18118 .29557 .1749 .28501 .1632 Mtetra
.28501 .1632 .29557 .1749 .31187 .16858 .30138 .15681 Mtetra
.30138 .15681 .31187 .16858 .32828 .16222 .31785 .15038 Mtetra
.31785 .15038 .32828 .16222 .34478 .15582 .33442 .14391 Mtetra
.33442 .14391 .34478 .15582 .36139 .14938 .35109 .13739 Mtetra
.35109 .13739 .36139 .14938 .37811 .14291 .36787 .13084 Mtetra
.36787 .13084 .37811 .14291 .39493 .13639 .38475 .12424 Mtetra
.38475 .12424 .39493 .13639 .41185 .12983 .40174 .11761 Mtetra
.40174 .11761 .41185 .12983 .42888 .12323 .41884 .11093 Mtetra
.41884 .11093 .42888 .12323 .44602 .11658 .43605 .10421 Mtetra
.43605 .10421 .44602 .11658 .46327 .1099 .45337 .09744 Mtetra
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Mtetra
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Mtetra
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Mtetra
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Mtetra
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Mtetra
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Mtetra
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Mtetra
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Mtetra
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Mtetra
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Mtetra
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Mtetra
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Mtetra
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Mtetra
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Mtetra
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Mtetra
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Mtetra
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Mtetra
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Mtetra
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Mtetra
.57384 .54314 .58111 .55092 .59512 .54671 .5879 .53889 Mtetra
.5879 .53889 .59512 .54671 .60921 .54249 .60203 .53463 Mtetra
.60203 .53463 .60921 .54249 .62337 .53824 .61624 .53034 Mtetra
.61624 .53034 .62337 .53824 .63759 .53397 .63052 .52603 Mtetra
.63052 .52603 .63759 .53397 .6519 .52968 .64487 .5217 Mtetra
.64487 .5217 .6519 .52968 .66627 .52537 .6593 .51735 Mtetra
.6593 .51735 .66627 .52537 .68072 .52103 .67379 .51297 Mtetra
.67379 .51297 .68072 .52103 .69524 .51668 .68837 .50857 Mtetra
.68837 .50857 .69524 .51668 .70984 .5123 .70302 .50415 Mtetra
.70302 .50415 .70984 .5123 .72452 .5079 .71774 .49971 Mtetra
.71774 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.663 .741 .908 r
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45866 Mtetra
.8538 .45866 .86006 .46723 .87552 .46259 .86932 .45398 Mtetra
.663 .742 .908 r
.86932 .45398 .87552 .46259 .89107 .45793 .88492 .44928 Mtetra
.88492 .44928 .89107 .45793 .90669 .45325 .90061 .44456 Mtetra
.663 .742 .909 r
.90061 .44456 .90669 .45325 .9224 .44854 .91638 .43981 Mtetra
.664 .742 .909 r
.91638 .43981 .9224 .44854 .93819 .4438 .93223 .43502 Mtetra
.664 .742 .908 r
.93223 .43502 .93819 .4438 .95407 .43904 .94817 .4302 Mtetra
.94817 .4302 .95407 .43904 .97003 .43425 .9642 .42535 Mtetra
.664 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Mtetra
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Mtetra
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Mtetra
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Mtetra
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Mtetra
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Mtetra
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Mtetra
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Mtetra
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Mtetra
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Mtetra
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .53529 Mtetra
.5665 .53529 .57384 .54314 .5879 .53889 .58061 .531 Mtetra
.58061 .531 .5879 .53889 .60203 .53463 .59479 .5267 Mtetra
.59479 .5267 .60203 .53463 .61624 .53034 .60905 .52237 Mtetra
.60905 .52237 .61624 .53034 .63052 .52603 .62338 .51802 Mtetra
.62338 .51802 .63052 .52603 .64487 .5217 .63778 .51365 Mtetra
.63778 .51365 .64487 .5217 .6593 .51735 .65225 .50925 Mtetra
.65225 .50925 .6593 .51735 .67379 .51297 .6668 .50483 Mtetra
.6668 .50483 .67379 .51297 .68837 .50857 .68143 .50039 Mtetra
.68143 .50039 .68837 .50857 .70302 .50415 .69613 .49593 Mtetra
.69613 .49593 .70302 .50415 .71774 .49971 .71091 .49144 Mtetra
.71091 .49144 .71774 .49971 .73255 .49524 .72577 .48693 Mtetra
.72577 .48693 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.663 .741 .908 r
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46403 Mtetra
.80122 .46403 .80773 .47255 .823 .46794 .81656 .45938 Mtetra
.81656 .45938 .823 .46794 .83836 .46331 .83197 .45472 Mtetra
.663 .742 .909 r
.83197 .45472 .83836 .46331 .8538 .45866 .84747 .45005 Mtetra
.662 .742 .909 r
.84747 .45005 .8538 .45866 .86932 .45398 .86306 .44537 Mtetra
.662 .743 .91 r
.86306 .44537 .86932 .45398 .88492 .44928 .87872 .44065 Mtetra
.663 .744 .911 r
.87872 .44065 .88492 .44928 .90061 .44456 .89447 .43589 Mtetra
.664 .745 .911 r
.89447 .43589 .90061 .44456 .91638 .43981 .91031 .43107 Mtetra
.664 .745 .91 r
.91031 .43107 .91638 .43981 .93223 .43502 .92622 .4262 Mtetra
.665 .744 .909 r
.92622 .4262 .93223 .43502 .94817 .4302 .94222 .4213 Mtetra
.664 .743 .909 r
.94222 .4213 .94817 .4302 .9642 .42535 .9583 .41638 Mtetra
.664 .741 .908 r
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Mtetra
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Mtetra
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Mtetra
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55702 Mtetra
.46198 .55702 .4697 .56468 .48332 .56054 .47564 .55285 Mtetra
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Mtetra
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Mtetra
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .5402 Mtetra
.51705 .5402 .5246 .54801 .5385 .54379 .531 .53594 Mtetra
.531 .53594 .5385 .54379 .55246 .53955 .54501 .53166 Mtetra
.54501 .53166 .55246 .53955 .5665 .53529 .5591 .52736 Mtetra
.5591 .52736 .5665 .53529 .58061 .531 .57325 .52304 Mtetra
.57325 .52304 .58061 .531 .59479 .5267 .58748 .51869 Mtetra
.58748 .51869 .59479 .5267 .60905 .52237 .60179 .51432 Mtetra
.60179 .51432 .60905 .52237 .62338 .51802 .61616 .50993 Mtetra
.61616 .50993 .62338 .51802 .63778 .51365 .63062 .50552 Mtetra
.63062 .50552 .63778 .51365 .65225 .50925 .64514 .50108 Mtetra
.64514 .50108 .65225 .50925 .6668 .50483 .65974 .49662 Mtetra
.65974 .49662 .6668 .50483 .68143 .50039 .67442 .49214 Mtetra
.67442 .49214 .68143 .50039 .69613 .49593 .68918 .48763 Mtetra
.68918 .48763 .69613 .49593 .71091 .49144 .70401 .4831 Mtetra
.70401 .4831 .71091 .49144 .72577 .48693 .71892 .47854 Mtetra
.71892 .47854 .72577 .48693 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46936 Mtetra
.663 .741 .908 r
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .4601 Mtetra
.77935 .4601 .78597 .46865 .80122 .46403 .79466 .45546 Mtetra
.662 .742 .909 r
.79466 .45546 .80122 .46403 .81656 .45938 .81006 .45083 Mtetra
.66 .743 .911 r
.81006 .45083 .81656 .45938 .83197 .45472 .82554 .44623 Mtetra
.659 .745 .913 r
.82554 .44623 .83197 .45472 .84747 .45005 .84111 .44164 Mtetra
.659 .748 .916 r
.84111 .44164 .84747 .45005 .86306 .44537 .85677 .43702 Mtetra
.661 .752 .918 r
.85677 .43702 .86306 .44537 .87872 .44065 .87251 .4323 Mtetra
.664 .754 .917 r
.87251 .4323 .87872 .44065 .89447 .43589 .88831 .42743 Mtetra
.667 .754 .915 r
.88831 .42743 .89447 .43589 .91031 .43107 .90419 .42244 Mtetra
.667 .751 .913 r
.90419 .42244 .91031 .43107 .92622 .4262 .92016 .41739 Mtetra
.667 .747 .91 r
.92016 .41739 .92622 .4262 .94222 .4213 .93621 .41234 Mtetra
.666 .744 .909 r
.93621 .41234 .94222 .4213 .9583 .41638 .95235 .40731 Mtetra
.664 .741 .908 r
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Mtetra
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56181 Mtetra
.41347 .56181 .42139 .56942 .43486 .56531 .42697 .55767 Mtetra
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .55349 Mtetra
.44054 .55349 .44838 .56118 .46198 .55702 .45418 .5493 Mtetra
.45418 .5493 .46198 .55702 .47564 .55285 .46789 .54509 Mtetra
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Mtetra
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Mtetra
.49552 .5366 .50318 .54444 .51705 .5402 .50944 .53232 Mtetra
.50944 .53232 .51705 .5402 .531 .53594 .52343 .52802 Mtetra
.52343 .52802 .531 .53594 .54501 .53166 .53749 .5237 Mtetra
.53749 .5237 .54501 .53166 .5591 .52736 .55162 .51936 Mtetra
.55162 .51936 .5591 .52736 .57325 .52304 .56582 .51499 Mtetra
.56582 .51499 .57325 .52304 .58748 .51869 .5801 .51061 Mtetra
.5801 .51061 .58748 .51869 .60179 .51432 .59446 .5062 Mtetra
.59446 .5062 .60179 .51432 .61616 .50993 .60888 .50176 Mtetra
.60888 .50176 .61616 .50993 .63062 .50552 .62338 .49731 Mtetra
.62338 .49731 .63062 .50552 .64514 .50108 .63796 .49283 Mtetra
.63796 .49283 .64514 .50108 .65974 .49662 .65262 .48832 Mtetra
.65262 .48832 .65974 .49662 .67442 .49214 .66735 .4838 Mtetra
.66735 .4838 .67442 .49214 .68918 .48763 .68215 .47925 Mtetra
.68215 .47925 .68918 .48763 .70401 .4831 .69704 .47467 Mtetra
.69704 .47467 .70401 .4831 .71892 .47854 .712 .47007 Mtetra
.663 .741 .908 r
.712 .47007 .71892 .47854 .73391 .47397 .72705 .46545 Mtetra
.72705 .46545 .73391 .47397 .74897 .46936 .74217 .46082 Mtetra
.74217 .46082 .74897 .46936 .76412 .46474 .75738 .45618 Mtetra
.661 .742 .91 r
.75738 .45618 .76412 .46474 .77935 .4601 .77267 .45159 Mtetra
.658 .743 .913 r
.77267 .45159 .77935 .4601 .79466 .45546 .78805 .4471 Mtetra
.653 .746 .918 r
.78805 .4471 .79466 .45546 .81006 .45083 .80354 .44275 Mtetra
.648 .753 .926 r
.80354 .44275 .81006 .45083 .82554 .44623 .81912 .43852 Mtetra
.647 .764 .934 r
.81912 .43852 .82554 .44623 .84111 .44164 .83479 .43423 Mtetra
.653 .776 .939 r
.83479 .43423 .84111 .44164 .85677 .43702 .85053 .42967 Mtetra
.664 .783 .937 r
.85053 .42967 .85677 .43702 .87251 .4323 .86631 .4247 Mtetra
.673 .78 .93 r
.86631 .4247 .87251 .4323 .88831 .42743 .88214 .41937 Mtetra
.676 .77 .921 r
.88214 .41937 .88831 .42743 .90419 .42244 .89804 .41391 Mtetra
.674 .759 .914 r
.89804 .41391 .90419 .42244 .92016 .41739 .91404 .40852 Mtetra
.67 .749 .91 r
.91404 .40852 .92016 .41739 .93621 .41234 .93013 .40327 Mtetra
.667 .744 .908 r
.93013 .40327 .93621 .41234 .95235 .40731 .94634 .39814 Mtetra
.664 .741 .908 r
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Mtetra
.39199 .55831 .40003 .56594 .41347 .56181 .40547 .55414 Mtetra
.40547 .55414 .41347 .56181 .42697 .55767 .41902 .54995 Mtetra
.41902 .54995 .42697 .55767 .44054 .55349 .43263 .54574 Mtetra
.43263 .54574 .44054 .55349 .45418 .5493 .44632 .54151 Mtetra
.44632 .54151 .45418 .5493 .46789 .54509 .46007 .53726 Mtetra
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .53298 Mtetra
.47389 .53298 .48167 .54086 .49552 .5366 .48778 .52869 Mtetra
.48778 .52869 .49552 .5366 .50944 .53232 .50175 .52437 Mtetra
.50175 .52437 .50944 .53232 .52343 .52802 .51578 .52003 Mtetra
.51578 .52003 .52343 .52802 .53749 .5237 .52989 .51567 Mtetra
.52989 .51567 .53749 .5237 .55162 .51936 .54407 .51128 Mtetra
.54407 .51128 .55162 .51936 .56582 .51499 .55833 .50688 Mtetra
.55833 .50688 .56582 .51499 .5801 .51061 .57265 .50245 Mtetra
.57265 .50245 .5801 .51061 .59446 .5062 .58706 .49799 Mtetra
.58706 .49799 .59446 .5062 .60888 .50176 .60153 .49352 Mtetra
.60153 .49352 .60888 .50176 .62338 .49731 .61609 .48902 Mtetra
.61609 .48902 .62338 .49731 .63796 .49283 .63071 .48449 Mtetra
.63071 .48449 .63796 .49283 .65262 .48832 .64542 .47995 Mtetra
.64542 .47995 .65262 .48832 .66735 .4838 .6602 .47538 Mtetra
.6602 .47538 .66735 .4838 .68215 .47925 .67506 .47078 Mtetra
.67506 .47078 .68215 .47925 .69704 .47467 .69 .46616 Mtetra
.663 .741 .908 r
.69 .46616 .69704 .47467 .712 .47007 .70502 .46153 Mtetra
.70502 .46153 .712 .47007 .72705 .46545 .72012 .45689 Mtetra
.661 .741 .91 r
.72012 .45689 .72705 .46545 .74217 .46082 .73531 .4523 Mtetra
.656 .742 .913 r
.73531 .4523 .74217 .46082 .75738 .45618 .75059 .44787 Mtetra
.646 .745 .921 r
.75059 .44787 .75738 .45618 .77267 .45159 .76598 .44377 Mtetra
.63 .753 .936 r
.76598 .44377 .77267 .45159 .78805 .4471 .7815 .44013 Mtetra
.61 .771 .957 r
.7815 .44013 .78805 .4471 .80354 .44275 .79714 .43686 Mtetra
.597 .801 .978 r
.79714 .43686 .80354 .44275 .81912 .43852 .81288 .43351 Mtetra
.608 .836 .987 r
.81288 .43351 .81912 .43852 .83479 .43423 .82865 .42942 Mtetra
.646 .858 .98 r
.82865 .42942 .83479 .43423 .85053 .42967 .84441 .42421 Mtetra
.685 .851 .962 r
.84441 .42421 .85053 .42967 .86631 .4247 .86016 .41806 Mtetra
.7 .82 .939 r
.86016 .41806 .86631 .4247 .88214 .41937 .87594 .41156 Mtetra
.695 .786 .921 r
.87594 .41156 .88214 .41937 .89804 .41391 .89183 .40528 Mtetra
.683 .762 .911 r
.89183 .40528 .89804 .41391 .91404 .40852 .90784 .39947 Mtetra
.673 .748 .907 r
.90784 .39947 .91404 .40852 .93013 .40327 .92399 .39405 Mtetra
.667 .743 .907 r
.92399 .39405 .93013 .40327 .94634 .39814 .94026 .38885 Mtetra
.664 .741 .908 r
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Mtetra
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Mtetra
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53791 Mtetra
.42465 .53791 .43263 .54574 .44632 .54151 .43837 .53364 Mtetra
.43837 .53364 .44632 .54151 .46007 .53726 .45217 .52935 Mtetra
.45217 .52935 .46007 .53726 .47389 .53298 .46604 .52504 Mtetra
.46604 .52504 .47389 .53298 .48778 .52869 .47998 .5207 Mtetra
.47998 .5207 .48778 .52869 .50175 .52437 .49399 .51634 Mtetra
.49399 .51634 .50175 .52437 .51578 .52003 .50807 .51196 Mtetra
.50807 .51196 .51578 .52003 .52989 .51567 .52222 .50756 Mtetra
.52222 .50756 .52989 .51567 .54407 .51128 .53645 .50313 Mtetra
.53645 .50313 .54407 .51128 .55833 .50688 .55076 .49868 Mtetra
.55076 .49868 .55833 .50688 .57265 .50245 .56513 .49421 Mtetra
.56513 .49421 .57265 .50245 .58706 .49799 .57958 .48971 Mtetra
.57958 .48971 .58706 .49799 .60153 .49352 .59411 .48519 Mtetra
.59411 .48519 .60153 .49352 .61609 .48902 .60871 .48065 Mtetra
.60871 .48065 .61609 .48902 .63071 .48449 .6234 .47608 Mtetra
.6234 .47608 .63071 .48449 .64542 .47995 .63815 .47149 Mtetra
.63815 .47149 .64542 .47995 .6602 .47538 .65299 .46688 Mtetra
.663 .741 .908 r
.65299 .46688 .6602 .47538 .67506 .47078 .6679 .46224 Mtetra
.6679 .46224 .67506 .47078 .69 .46616 .6829 .45759 Mtetra
.662 .741 .909 r
.6829 .45759 .69 .46616 .70502 .46153 .69797 .45298 Mtetra
.657 .741 .912 r
.69797 .45298 .70502 .46153 .72012 .45689 .71314 .44851 Mtetra
.645 .742 .92 r
.71314 .44851 .72012 .45689 .73531 .4523 .72842 .44448 Mtetra
.616 .747 .939 r
.72842 .44448 .73531 .4523 .75059 .44787 .74385 .44129 Mtetra
.557 .761 .973 r
.74385 .44129 .75059 .44787 .76598 .44377 .75947 .43929 Mtetra
.441 .778 .998 r
.75947 .43929 .76598 .44377 .7815 .44013 .77526 .43825 Mtetra
.276 .759 .924 r
.77526 .43825 .7815 .44013 .79714 .43686 .79117 .43706 Mtetra
.218 .741 .795 r
.79117 .43706 .79714 .43686 .81288 .43351 .80706 .43413 Mtetra
.383 .845 .817 r
.80706 .43413 .81288 .43351 .82865 .42942 .82279 .42844 Mtetra
.638 .957 .928 r
.82279 .42844 .82865 .42942 .84441 .42421 .83839 .42042 Mtetra
.748 .921 .949 r
.83839 .42042 .84441 .42421 .86016 .41806 .85395 .41156 Mtetra
.742 .839 .924 r
.85395 .41156 .86016 .41806 .87594 .41156 .86963 .40328 Mtetra
.712 .782 .907 r
.86963 .40328 .87594 .41156 .89183 .40528 .8855 .3962 Mtetra
.687 .754 .902 r
.8855 .3962 .89183 .40528 .90784 .39947 .90156 .39014 Mtetra
.673 .744 .904 r
.90156 .39014 .90784 .39947 .92399 .39405 .91778 .38467 Mtetra
.667 .741 .906 r
.91778 .38467 .92399 .39405 .94026 .38885 .93412 .37946 Mtetra
.664 .741 .908 r
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .5343 Mtetra
.40288 .5343 .41099 .54216 .42465 .53791 .41658 .53001 Mtetra
.41658 .53001 .42465 .53791 .43837 .53364 .43036 .5257 Mtetra
.43036 .5257 .43837 .53364 .45217 .52935 .4442 .52137 Mtetra
.4442 .52137 .45217 .52935 .46604 .52504 .45811 .51701 Mtetra
.45811 .51701 .46604 .52504 .47998 .5207 .4721 .51263 Mtetra
.4721 .51263 .47998 .5207 .49399 .51634 .48615 .50823 Mtetra
.48615 .50823 .49399 .51634 .50807 .51196 .50028 .50381 Mtetra
.50028 .50381 .50807 .51196 .52222 .50756 .51448 .49937 Mtetra
.51448 .49937 .52222 .50756 .53645 .50313 .52876 .4949 Mtetra
.52876 .4949 .53645 .50313 .55076 .49868 .54311 .4904 Mtetra
.54311 .4904 .55076 .49868 .56513 .49421 .55754 .48589 Mtetra
.55754 .48589 .56513 .49421 .57958 .48971 .57204 .48135 Mtetra
.57204 .48135 .57958 .48971 .59411 .48519 .58662 .47679 Mtetra
.58662 .47679 .59411 .48519 .60871 .48065 .60127 .4722 Mtetra
.60127 .4722 .60871 .48065 .6234 .47608 .616 .46759 Mtetra
.616 .46759 .6234 .47608 .63815 .47149 .63082 .46295 Mtetra
.663 .741 .908 r
.63082 .46295 .63815 .47149 .65299 .46688 .6457 .4583 Mtetra
.6457 .4583 .65299 .46688 .6679 .46224 .66067 .45365 Mtetra
.66 .741 .91 r
.66067 .45365 .6679 .46224 .6829 .45759 .67573 .44909 Mtetra
.649 .741 .916 r
.67573 .44909 .6829 .45759 .69797 .45298 .69089 .44489 Mtetra
.62 .742 .934 r
.69089 .44489 .69797 .45298 .71314 .44851 .70618 .44164 Mtetra
.536 .744 .971 r
.70618 .44164 .71314 .44851 .72842 .44448 .72169 .44023 Mtetra
.275 .695 .969 r
.72169 .44023 .72842 .44448 .74385 .44129 .73748 .44144 Mtetra
.265 0 0 r
.73748 .44144 .74385 .44129 .75947 .43929 .75357 .4448 Mtetra
.473 0 0 r
.75357 .4448 .75947 .43929 .77526 .43825 .76981 .44795 Mtetra
.428 0 .082 r
.76981 .44795 .77526 .43825 .79117 .43706 .78592 .44736 Mtetra
.242 0 .018 r
.78592 .44736 .79117 .43706 .80706 .43413 .80165 .4408 Mtetra
0 0 0 r
.80165 .4408 .80706 .43413 .82279 .42844 .817 .42914 Mtetra
.768 .996 .821 r
.817 .42914 .82279 .42844 .83839 .42042 .83219 .41565 Mtetra
.824 .902 .895 r
.83219 .41565 .83839 .42042 .85395 .41156 .84752 .40345 Mtetra
.762 .802 .885 r
.84752 .40345 .85395 .41156 .86963 .40328 .86315 .39386 Mtetra
.712 .756 .887 r
.86315 .39386 .86963 .40328 .8855 .3962 .87906 .38655 Mtetra
.684 .742 .895 r
.87906 .38655 .8855 .3962 .90156 .39014 .8952 .38058 Mtetra
.67 .739 .902 r
.8952 .38058 .90156 .39014 .91778 .38467 .9115 .37518 Mtetra
.665 .74 .906 r
.9115 .37518 .91778 .38467 .93412 .37946 .92791 .36997 Mtetra
.664 .741 .908 r
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Mtetra
.38103 .53067 .38925 .53857 .40288 .5343 .3947 .52637 Mtetra
.3947 .52637 .40288 .5343 .41658 .53001 .40845 .52204 Mtetra
.40845 .52204 .41658 .53001 .43036 .5257 .42226 .51768 Mtetra
.42226 .51768 .43036 .5257 .4442 .52137 .43615 .51331 Mtetra
.43615 .51331 .4442 .52137 .45811 .51701 .45011 .50891 Mtetra
.45011 .50891 .45811 .51701 .4721 .51263 .46414 .50449 Mtetra
.46414 .50449 .4721 .51263 .48615 .50823 .47824 .50005 Mtetra
.47824 .50005 .48615 .50823 .50028 .50381 .49242 .49559 Mtetra
.49242 .49559 .50028 .50381 .51448 .49937 .50667 .4911 Mtetra
.50667 .4911 .51448 .49937 .52876 .4949 .52099 .48658 Mtetra
.52099 .48658 .52876 .4949 .54311 .4904 .53539 .48205 Mtetra
.53539 .48205 .54311 .4904 .55754 .48589 .54987 .47749 Mtetra
.54987 .47749 .55754 .48589 .57204 .48135 .56442 .47291 Mtetra
.56442 .47291 .57204 .48135 .58662 .47679 .57905 .4683 Mtetra
.57905 .4683 .58662 .47679 .60127 .4722 .59376 .46367 Mtetra
.663 .741 .908 r
.59376 .46367 .60127 .4722 .616 .46759 .60854 .45901 Mtetra
.60854 .45901 .616 .46759 .63082 .46295 .62341 .45434 Mtetra
.662 .741 .909 r
.62341 .45434 .63082 .46295 .6457 .4583 .63835 .4497 Mtetra
.656 .741 .912 r
.63835 .4497 .6457 .4583 .66067 .45365 .65339 .44526 Mtetra
.636 .74 .923 r
.65339 .44526 .66067 .45365 .67573 .44909 .66853 .4415 Mtetra
.57 .737 .954 r
.66853 .4415 .67573 .44909 .69089 .44489 .68386 .43953 Mtetra
.316 .683 .978 r
.68386 .43953 .69089 .44489 .70618 .44164 .69949 .44108 Mtetra
.417 0 0 r
.69949 .44108 .70618 .44164 .72169 .44023 .71555 .44761 Mtetra
.664 .201 .144 r
.71555 .44761 .72169 .44023 .73748 .44144 .73208 .45838 Mtetra
.643 .266 .315 r
.73208 .45838 .73748 .44144 .75357 .4448 .74883 .46893 Mtetra
.563 .227 .357 r
.74883 .46893 .75357 .4448 .76981 .44795 .7653 .47246 Mtetra
.416 .101 .32 r
.7653 .47246 .76981 .44795 .78592 .44736 .78106 .46452 Mtetra
.076 0 .116 r
.78106 .46452 .78592 .44736 .80165 .4408 .79607 .44676 Mtetra
.716 .9 .526 r
.79607 .44676 .80165 .4408 .817 .42914 .81072 .42544 Mtetra
.909 .916 .811 r
.81072 .42544 .817 .42914 .83219 .41565 .82553 .40662 Mtetra
.815 .794 .832 r
.82553 .40662 .83219 .41565 .84752 .40345 .84079 .39283 Mtetra
.743 .743 .852 r
.84079 .39283 .84752 .40345 .86315 .39386 .8565 .38342 Mtetra
.698 .731 .876 r
.8565 .38342 .86315 .39386 .87906 .38655 .87254 .3766 Mtetra
.676 .734 .894 r
.87254 .3766 .87906 .38655 .8952 .38058 .88878 .37092 Mtetra
.667 .738 .903 r
.88878 .37092 .8952 .38058 .9115 .37518 .90516 .36562 Mtetra
.664 .74 .907 r
.90516 .36562 .9115 .37518 .92791 .36997 .92164 .36039 Mtetra
.664 .741 .908 r
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Mtetra
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51835 Mtetra
.38644 .51835 .3947 .52637 .40845 .52204 .40023 .51398 Mtetra
.40023 .51398 .40845 .52204 .42226 .51768 .41409 .50959 Mtetra
.41409 .50959 .42226 .51768 .43615 .51331 .42802 .50518 Mtetra
.42802 .50518 .43615 .51331 .45011 .50891 .44203 .50074 Mtetra
.44203 .50074 .45011 .50891 .46414 .50449 .45611 .49627 Mtetra
.45611 .49627 .46414 .50449 .47824 .50005 .47026 .49179 Mtetra
.47026 .49179 .47824 .50005 .49242 .49559 .48448 .48728 Mtetra
.48448 .48728 .49242 .49559 .50667 .4911 .49878 .48275 Mtetra
.49878 .48275 .50667 .4911 .52099 .48658 .51315 .47819 Mtetra
.51315 .47819 .52099 .48658 .53539 .48205 .5276 .47361 Mtetra
.5276 .47361 .53539 .48205 .54987 .47749 .54213 .46901 Mtetra
.54213 .46901 .54987 .47749 .56442 .47291 .55673 .46438 Mtetra
.55673 .46438 .56442 .47291 .57905 .4683 .57141 .45973 Mtetra
.663 .741 .908 r
.57141 .45973 .57905 .4683 .59376 .46367 .58617 .45505 Mtetra
.58617 .45505 .59376 .46367 .60854 .45901 .60101 .45037 Mtetra
.661 .741 .909 r
.60101 .45037 .60854 .45901 .62341 .45434 .61593 .44575 Mtetra
.651 .74 .914 r
.61593 .44575 .62341 .45434 .63835 .4497 .63094 .44146 Mtetra
.616 .738 .933 r
.63094 .44146 .63835 .4497 .65339 .44526 .64608 .43831 Mtetra
.479 .718 .975 r
.64608 .43831 .65339 .44526 .66853 .4415 .66144 .4381 Mtetra
0 .4 .745 r
.66144 .4381 .66853 .4415 .68386 .43953 .6772 .44372 Mtetra
.714 .227 .087 r
.6772 .44372 .68386 .43953 .69949 .44108 .69357 .45769 Mtetra
.733 .36 .344 r
.69357 .45769 .69949 .44108 .71555 .44761 .71063 .47895 Mtetra
.684 .36 .421 r
.71063 .47895 .71555 .44761 .73208 .45838 .72802 .50016 Mtetra
.603 .307 .44 r
.72802 .50016 .73208 .45838 .74883 .46893 .74499 .5098 Mtetra
.461 .186 .409 r
.74499 .5098 .74883 .46893 .7653 .47246 .76082 .50006 Mtetra
.111 0 .242 r
.76082 .50006 .7653 .47246 .78106 .46452 .77543 .47359 Mtetra
.813 .871 .43 r
.77543 .47359 .78106 .46452 .79607 .44676 .78942 .44112 Mtetra
.943 .846 .719 r
.78942 .44112 .79607 .44676 .81072 .42544 .8036 .4129 Mtetra
.836 .739 .757 r
.8036 .4129 .81072 .42544 .82553 .40662 .8184 .39315 Mtetra
.762 .704 .797 r
.8184 .39315 .82553 .40662 .84079 .39283 .83385 .38077 Mtetra
.712 .707 .844 r
.83385 .38077 .84079 .39283 .8565 .38342 .84977 .37276 Mtetra
.682 .722 .88 r
.84977 .37276 .8565 .38342 .87254 .3766 .86596 .36667 Mtetra
.669 .734 .898 r
.86596 .36667 .87254 .3766 .88878 .37092 .8823 .36125 Mtetra
.665 .739 .905 r
.8823 .36125 .88878 .37092 .90516 .36562 .89876 .35598 Mtetra
.664 .741 .907 r
.89876 .35598 .90516 .36562 .92164 .36039 .91531 .35072 Mtetra
.664 .741 .908 r
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Mtetra
.36434 .51466 .37272 .5227 .38644 .51835 .37811 .51027 Mtetra
.37811 .51027 .38644 .51835 .40023 .51398 .39194 .50586 Mtetra
.39194 .50586 .40023 .51398 .41409 .50959 .40584 .50142 Mtetra
.40584 .50142 .41409 .50959 .42802 .50518 .41982 .49696 Mtetra
.41982 .49696 .42802 .50518 .44203 .50074 .43387 .49248 Mtetra
.43387 .49248 .44203 .50074 .45611 .49627 .44799 .48798 Mtetra
.44799 .48798 .45611 .49627 .47026 .49179 .46219 .48345 Mtetra
.46219 .48345 .47026 .49179 .48448 .48728 .47646 .47889 Mtetra
.47646 .47889 .48448 .48728 .49878 .48275 .49081 .47432 Mtetra
.49081 .47432 .49878 .48275 .51315 .47819 .50523 .46972 Mtetra
.50523 .46972 .51315 .47819 .5276 .47361 .51973 .46509 Mtetra
.51973 .46509 .5276 .47361 .54213 .46901 .53431 .46044 Mtetra
.53431 .46044 .54213 .46901 .55673 .46438 .54896 .45577 Mtetra
.663 .741 .908 r
.54896 .45577 .55673 .46438 .57141 .45973 .56369 .45108 Mtetra
.56369 .45108 .57141 .45973 .58617 .45505 .57851 .44638 Mtetra
.66 .741 .91 r
.57851 .44638 .58617 .45505 .60101 .45037 .5934 .44178 Mtetra
.646 .739 .917 r
.5934 .44178 .60101 .45037 .61593 .44575 .60839 .43767 Mtetra
.592 .734 .942 r
.60839 .43767 .61593 .44575 .63094 .44146 .62351 .43518 Mtetra
.34 .67 .976 r
.62351 .43518 .63094 .44146 .64608 .43831 .63889 .43694 Mtetra
.563 0 0 r
.63889 .43694 .64608 .43831 .66144 .4381 .65475 .44711 Mtetra
.778 .365 .269 r
.65475 .44711 .66144 .4381 .6772 .44372 .67138 .46951 Mtetra
.756 .419 .413 r
.67138 .46951 .6772 .44372 .69357 .45769 .68889 .50289 Mtetra
.704 .401 .46 r
.68889 .50289 .69357 .45769 .71063 .47895 .7069 .53673 Mtetra
.624 .342 .47 r
.7069 .53673 .71063 .47895 .72802 .50016 .72438 .55384 Mtetra
.471 .212 .438 r
.72438 .55384 .72802 .50016 .74499 .5098 .74034 .54218 Mtetra
0 0 .222 r
.74034 .54218 .74499 .5098 .76082 .50006 .7546 .50555 Mtetra
.983 .884 .533 r
.7546 .50555 .76082 .50006 .77543 .47359 .76798 .46002 Mtetra
.908 .738 .659 r
.76798 .46002 .77543 .47359 .78942 .44112 .78154 .42086 Mtetra
.817 .663 .692 r
.78154 .42086 .78942 .44112 .8036 .4129 .7959 .3942 Mtetra
.758 .648 .74 r
.7959 .3942 .8036 .4129 .8184 .39315 .81111 .37838 Mtetra
.717 .669 .803 r
.81111 .37838 .8184 .39315 .83385 .38077 .8269 .36897 Mtetra
.687 .703 .859 r
.8269 .36897 .83385 .38077 .84977 .37276 .84303 .36243 Mtetra
.671 .727 .891 r
.84303 .36243 .84977 .37276 .86596 .36667 .85933 .35686 Mtetra
.665 .737 .904 r
.85933 .35686 .86596 .36667 .8823 .36125 .87576 .35155 Mtetra
.664 .74 .907 r
.87576 .35155 .8823 .36125 .89876 .35598 .89229 .34626 Mtetra
.664 .741 .908 r
.89229 .34626 .89876 .35598 .91531 .35072 .90891 .34096 Mtetra
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .5021 Mtetra
.36969 .5021 .37811 .51027 .39194 .50586 .38357 .49765 Mtetra
.38357 .49765 .39194 .50586 .40584 .50142 .39752 .49317 Mtetra
.39752 .49317 .40584 .50142 .41982 .49696 .41154 .48867 Mtetra
.41154 .48867 .41982 .49696 .43387 .49248 .42564 .48415 Mtetra
.42564 .48415 .43387 .49248 .44799 .48798 .43981 .4796 Mtetra
.43981 .4796 .44799 .48798 .46219 .48345 .45405 .47502 Mtetra
.45405 .47502 .46219 .48345 .47646 .47889 .46837 .47043 Mtetra
.46837 .47043 .47646 .47889 .49081 .47432 .48277 .46581 Mtetra
.48277 .46581 .49081 .47432 .50523 .46972 .49724 .46116 Mtetra
.49724 .46116 .50523 .46972 .51973 .46509 .51179 .45649 Mtetra
.51179 .45649 .51973 .46509 .53431 .46044 .52641 .4518 Mtetra
.663 .741 .908 r
.52641 .4518 .53431 .46044 .54896 .45577 .54112 .44708 Mtetra
.54112 .44708 .54896 .45577 .56369 .45108 .5559 .44237 Mtetra
.659 .741 .91 r
.5559 .44237 .56369 .45108 .57851 .44638 .57077 .43779 Mtetra
.641 .739 .919 r
.57077 .43779 .57851 .44638 .5934 .44178 .58573 .43381 Mtetra
.57 .729 .95 r
.58573 .43381 .5934 .44178 .60839 .43767 .60082 .43188 Mtetra
.191 .599 .944 r
.60082 .43188 .60839 .43767 .62351 .43518 .61618 .43525 Mtetra
.704 .172 0 r
.61618 .43525 .62351 .43518 .63889 .43694 .63204 .44927 Mtetra
.799 .418 .333 r
.63204 .44927 .63889 .43694 .65475 .44711 .64876 .47889 Mtetra
.771 .447 .438 r
.64876 .47889 .65475 .44711 .67138 .46951 .6665 .52291 Mtetra
.721 .423 .474 r
.6665 .52291 .67138 .46951 .68889 .50289 .68486 .56814 Mtetra
.641 .361 .479 r
.68486 .56814 .68889 .50289 .7069 .53673 .7027 .59226 Mtetra
.461 .203 .435 r
.7027 .59226 .7069 .53673 .72438 .55384 .71881 .57917 Mtetra
0 0 0 r
.71881 .57917 .72438 .55384 .74034 .54218 .73291 .53354 Mtetra
.96 .767 .6 r
.73291 .53354 .74034 .54218 .7546 .50555 .74593 .47639 Mtetra
.845 .641 .627 r
.74593 .47639 .7546 .50555 .76798 .46002 .75911 .42747 Mtetra
.78 .596 .651 r
.75911 .42747 .76798 .46002 .78154 .42086 .77318 .39467 Mtetra
.74 .595 .695 r
.77318 .39467 .78154 .42086 .7959 .3942 .78821 .37577 Mtetra
.711 .629 .763 r
.78821 .37577 .7959 .3942 .81111 .37838 .8039 .36512 Mtetra
.688 .68 .837 r
.8039 .36512 .81111 .37838 .8269 .36897 .81998 .35815 Mtetra
.672 .718 .883 r
.81998 .35815 .8269 .36897 .84303 .36243 .83626 .35246 Mtetra
.666 .735 .901 r
.83626 .35246 .84303 .36243 .85933 .35686 .85266 .34709 Mtetra
.664 .74 .906 r
.85266 .34709 .85933 .35686 .87576 .35155 .86916 .34178 Mtetra
.664 .741 .908 r
.86916 .34178 .87576 .35155 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Mtetra
.34734 .49834 .35588 .50654 .36969 .5021 .36119 .49386 Mtetra
.36119 .49386 .36969 .5021 .38357 .49765 .37511 .48936 Mtetra
.37511 .48936 .38357 .49765 .39752 .49317 .38911 .48484 Mtetra
.38911 .48484 .39752 .49317 .41154 .48867 .40318 .4803 Mtetra
.40318 .4803 .41154 .48867 .42564 .48415 .41732 .47573 Mtetra
.41732 .47573 .42564 .48415 .43981 .4796 .43154 .47114 Mtetra
.43154 .47114 .43981 .4796 .45405 .47502 .44583 .46652 Mtetra
.44583 .46652 .45405 .47502 .46837 .47043 .4602 .46188 Mtetra
.4602 .46188 .46837 .47043 .48277 .46581 .47464 .45721 Mtetra
.47464 .45721 .48277 .46581 .49724 .46116 .48916 .45252 Mtetra
.48916 .45252 .49724 .46116 .51179 .45649 .50376 .4478 Mtetra
.663 .741 .908 r
.50376 .4478 .51179 .45649 .52641 .4518 .51844 .44307 Mtetra
.51844 .44307 .52641 .4518 .54112 .44708 .5332 .43834 Mtetra
.658 .741 .911 r
.5332 .43834 .54112 .44708 .5559 .44237 .54803 .43375 Mtetra
.639 .738 .92 r
.54803 .43375 .5559 .44237 .57077 .43779 .56296 .42982 Mtetra
.559 .727 .953 r
.56296 .42982 .57077 .43779 .58573 .43381 .57802 .42812 Mtetra
.117 .557 .918 r
.57802 .42812 .58573 .43381 .60082 .43188 .5933 .43224 Mtetra
.741 .228 0 r
.5933 .43224 .60082 .43188 .61618 .43525 .60906 .44808 Mtetra
.811 .437 .347 r
.60906 .44808 .61618 .43525 .63204 .44927 .62563 .48126 Mtetra
.785 .461 .441 r
.62563 .48126 .63204 .44927 .64876 .47889 .64322 .53071 Mtetra
.739 .438 .472 r
.64322 .53071 .64876 .47889 .6665 .52291 .6615 .58202 Mtetra
.661 .373 .472 r
.6615 .58202 .6665 .52291 .68486 .56814 .67938 .6102 Mtetra
.417 .142 .387 r
.67938 .6102 .68486 .56814 .7027 .59226 .6956 .59675 Mtetra
.995 .869 .562 r
.6956 .59675 .7027 .59226 .71881 .57917 .70983 .5466 Mtetra
.859 .642 .607 r
.70983 .5466 .71881 .57917 .73291 .53354 .72291 .48332 Mtetra
.786 .571 .61 r
.72291 .48332 .73291 .53354 .74593 .47639 .73609 .42916 Mtetra
.744 .547 .628 r
.73609 .42916 .74593 .47639 .75911 .42747 .75013 .39299 Mtetra
.717 .554 .667 r
.75013 .39299 .75911 .42747 .77318 .39467 .76512 .37238 Mtetra
.7 .594 .735 r
.76512 .37238 .77318 .39467 .78821 .37577 .78078 .36101 Mtetra
.686 .658 .817 r
.78078 .36101 .78821 .37577 .8039 .36512 .79682 .3538 Mtetra
.673 .709 .875 r
.79682 .3538 .8039 .36512 .81998 .35815 .81307 .34802 Mtetra
.666 .732 .899 r
.81307 .34802 .81998 .35815 .83626 .35246 .82944 .34261 Mtetra
.664 .739 .906 r
.82944 .34261 .83626 .35246 .85266 .34709 .84592 .33727 Mtetra
.664 .741 .908 r
.84592 .33727 .85266 .34709 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Mtetra
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Mtetra
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Mtetra
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Mtetra
.35261 .48554 .36119 .49386 .37511 .48936 .36658 .481 Mtetra
.36658 .481 .37511 .48936 .38911 .48484 .38062 .47643 Mtetra
.38062 .47643 .38911 .48484 .40318 .4803 .39473 .47184 Mtetra
.39473 .47184 .40318 .4803 .41732 .47573 .40892 .46723 Mtetra
.40892 .46723 .41732 .47573 .43154 .47114 .42319 .46259 Mtetra
.42319 .46259 .43154 .47114 .44583 .46652 .43753 .45793 Mtetra
.43753 .45793 .44583 .46652 .4602 .46188 .45194 .45324 Mtetra
.45194 .45324 .4602 .46188 .47464 .45721 .46644 .44853 Mtetra
.46644 .44853 .47464 .45721 .48916 .45252 .48101 .44379 Mtetra
.663 .741 .908 r
.48101 .44379 .48916 .45252 .50376 .4478 .49566 .43904 Mtetra
.49566 .43904 .50376 .4478 .51844 .44307 .51039 .43428 Mtetra
.659 .741 .91 r
.51039 .43428 .51844 .44307 .5332 .43834 .5252 .42966 Mtetra
.641 .738 .92 r
.5252 .42966 .5332 .43834 .54803 .43375 .54009 .42567 Mtetra
.565 .727 .95 r
.54009 .42567 .54803 .43375 .56296 .42982 .55509 .42379 Mtetra
.166 .581 .936 r
.55509 .42379 .56296 .42982 .57802 .42812 .57028 .42749 Mtetra
.721 .193 0 r
.57028 .42749 .57802 .42812 .5933 .43224 .58584 .44244 Mtetra
.819 .433 .324 r
.58584 .44244 .5933 .43224 .60906 .44808 .60207 .47412 Mtetra
.799 .466 .424 r
.60207 .47412 .60906 .44808 .62563 .48126 .61918 .5216 Mtetra
.761 .447 .455 r
.61918 .5216 .62563 .48126 .64322 .53071 .63695 .57114 Mtetra
.69 .377 .441 r
.63695 .57114 .64322 .53071 .6615 .58202 .65451 .59866 Mtetra
.159 0 .082 r
.65451 .59866 .6615 .58202 .67938 .6102 .67077 .58612 Mtetra
.863 .668 .637 r
.67077 .58612 .67938 .6102 .6956 .59675 .68534 .53787 Mtetra
.781 .561 .602 r
.68534 .53787 .6956 .59675 .70983 .5466 .69889 .4765 Mtetra
.741 .525 .602 r
.69889 .4765 .70983 .5466 .72291 .48332 .71247 .42366 Mtetra
.714 .514 .617 r
.71247 .42366 .72291 .48332 .73609 .42916 .72674 .38819 Mtetra
.697 .526 .653 r
.72674 .38819 .73609 .42916 .75013 .39299 .74182 .36785 Mtetra
.688 .572 .719 r
.74182 .36785 .75013 .39299 .76512 .37238 .75751 .35656 Mtetra
.681 .643 .806 r
.75751 .35656 .76512 .37238 .78078 .36101 .77354 .34934 Mtetra
.672 .703 .87 r
.77354 .34934 .78078 .36101 .79682 .3538 .78977 .34354 Mtetra
.666 .73 .898 r
.78977 .34354 .79682 .3538 .81307 .34802 .80611 .33811 Mtetra
.664 .739 .906 r
.80611 .33811 .81307 .34802 .82944 .34261 .82256 .33274 Mtetra
.664 .741 .908 r
.82256 .33274 .82944 .34261 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Mtetra
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Mtetra
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Mtetra
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Mtetra
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47255 Mtetra
.35796 .47255 .36658 .481 .38062 .47643 .37205 .46794 Mtetra
.37205 .46794 .38062 .47643 .39473 .47184 .38621 .46331 Mtetra
.38621 .46331 .39473 .47184 .40892 .46723 .40044 .45865 Mtetra
.40044 .45865 .40892 .46723 .42319 .46259 .41476 .45397 Mtetra
.41476 .45397 .42319 .46259 .43753 .45793 .42914 .44926 Mtetra
.42914 .44926 .43753 .45793 .45194 .45324 .44361 .44452 Mtetra
.44361 .44452 .45194 .45324 .46644 .44853 .45815 .43976 Mtetra
.663 .741 .908 r
.45815 .43976 .46644 .44853 .48101 .44379 .47277 .43498 Mtetra
.47277 .43498 .48101 .44379 .49566 .43904 .48747 .4302 Mtetra
.659 .741 .91 r
.48747 .4302 .49566 .43904 .51039 .43428 .50225 .42553 Mtetra
.645 .739 .918 r
.50225 .42553 .51039 .43428 .5252 .42966 .51711 .42137 Mtetra
.586 .731 .943 r
.51711 .42137 .5252 .42966 .54009 .42567 .53206 .41897 Mtetra
.304 .645 .968 r
.53206 .41897 .54009 .42567 .55509 .42379 .54715 .42123 Mtetra
.602 .032 0 r
.54715 .42123 .55509 .42379 .57028 .42749 .5625 .43291 Mtetra
.817 .395 .244 r
.5625 .43291 .57028 .42749 .58584 .44244 .57831 .45861 Mtetra
.814 .456 .378 r
.57831 .45861 .58584 .44244 .60207 .47412 .59479 .49754 Mtetra
.789 .447 .407 r
.59479 .49754 .60207 .47412 .61918 .5216 .61181 .53822 Mtetra
.737 .358 .335 r
.61181 .53822 .61918 .5216 .63695 .57114 .62881 .56069 Mtetra
.759 .757 .85 r
.62881 .56069 .63695 .57114 .65451 .59866 .64499 .5499 Mtetra
.754 .554 .626 r
.64499 .5499 .65451 .59866 .67077 .58612 .66 .50915 Mtetra
.728 .513 .6 r
.66 .50915 .67077 .58612 .68534 .53787 .67422 .45691 Mtetra
.707 .495 .6 r
.67422 .45691 .68534 .53787 .69889 .4765 .6884 .41143 Mtetra
.69 .493 .615 r
.6884 .41143 .69889 .4765 .71247 .42366 .70308 .38042 Mtetra
.68 .512 .651 r
.70308 .38042 .71247 .42366 .72674 .38819 .71836 .36222 Mtetra
.677 .562 .717 r
.71836 .36222 .72674 .38819 .74182 .36785 .73411 .35176 Mtetra
.676 .638 .805 r
.73411 .35176 .74182 .36785 .75751 .35656 .75015 .34478 Mtetra
.67 .701 .87 r
.75015 .34478 .75751 .35656 .77354 .34934 .76635 .33902 Mtetra
.665 .73 .898 r
.76635 .33902 .77354 .34934 .78977 .34354 .78267 .33359 Mtetra
.664 .739 .906 r
.78267 .33359 .78977 .34354 .80611 .33811 .7991 .32819 Mtetra
.664 .741 .908 r
.7991 .32819 .80611 .33811 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Mtetra
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Mtetra
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Mtetra
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46865 Mtetra
.3352 .46865 .34395 .47714 .35796 .47255 .34926 .46402 Mtetra
.34926 .46402 .35796 .47255 .37205 .46794 .36339 .45937 Mtetra
.36339 .45937 .37205 .46794 .38621 .46331 .3776 .45469 Mtetra
.3776 .45469 .38621 .46331 .40044 .45865 .39188 .44998 Mtetra
.39188 .44998 .40044 .45865 .41476 .45397 .40624 .44525 Mtetra
.40624 .44525 .41476 .45397 .42914 .44926 .42068 .4405 Mtetra
.42068 .4405 .42914 .44926 .44361 .44452 .43519 .43572 Mtetra
.663 .741 .908 r
.43519 .43572 .44361 .44452 .45815 .43976 .44978 .43091 Mtetra
.44978 .43091 .45815 .43976 .47277 .43498 .46446 .4261 Mtetra
.661 .741 .909 r
.46446 .4261 .47277 .43498 .48747 .4302 .47921 .42136 Mtetra
.65 .74 .915 r
.47921 .42136 .48747 .4302 .50225 .42553 .49403 .41698 Mtetra
.61 .735 .934 r
.49403 .41698 .50225 .42553 .51711 .42137 .50894 .41389 Mtetra
.449 .698 .973 r
.50894 .41389 .51711 .42137 .53206 .41897 .52394 .41418 Mtetra
0 .32 .713 r
.52394 .41418 .53206 .41897 .54715 .42123 .53911 .42137 Mtetra
.765 .265 .025 r
.53911 .42137 .54715 .42123 .5625 .43291 .55457 .4388 Mtetra
.82 .404 .255 r
.55457 .4388 .5625 .43291 .57831 .45861 .57046 .46582 Mtetra
.817 .408 .271 r
.57046 .46582 .57831 .45861 .59479 .49754 .58676 .49408 Mtetra
.652 .1 0 r
.58676 .49408 .59479 .49754 .61181 .53822 .60317 .50919 Mtetra
.654 .537 .709 r
.60317 .50919 .61181 .53822 .62881 .56069 .61918 .50035 Mtetra
.697 .503 .621 r
.61918 .50035 .62881 .56069 .64499 .5499 .63453 .46966 Mtetra
.693 .486 .603 r
.63453 .46966 .64499 .5499 .66 .50915 .64938 .43021 Mtetra
.682 .478 .604 r
.64938 .43021 .66 .50915 .67422 .45691 .66417 .39532 Mtetra
.673 .483 .621 r
.66417 .39532 .67422 .45691 .6884 .41143 .67927 .3709 Mtetra
.669 .509 .66 r
.67927 .3709 .6884 .41143 .70308 .38042 .69476 .35594 Mtetra
.67 .566 .729 r
.69476 .35594 .70308 .38042 .71836 .36222 .71059 .34674 Mtetra
.672 .645 .814 r
.71059 .34674 .71836 .36222 .73411 .35176 .72664 .34015 Mtetra
.669 .705 .875 r
.72664 .34015 .73411 .35176 .75015 .34478 .74282 .33448 Mtetra
.665 .731 .899 r
.74282 .33448 .75015 .34478 .76635 .33902 .75912 .32904 Mtetra
.664 .739 .906 r
.75912 .32904 .76635 .33902 .78267 .33359 .77552 .32362 Mtetra
.664 .741 .908 r
.77552 .32362 .78267 .33359 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Mtetra
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46936 Mtetra
.29838 .46936 .3073 .47784 .32121 .47326 .31234 .46474 Mtetra
.31234 .46474 .32121 .47326 .3352 .46865 .32636 .46009 Mtetra
.32636 .46009 .3352 .46865 .34926 .46402 .34047 .45541 Mtetra
.34047 .45541 .34926 .46402 .36339 .45937 .35465 .45071 Mtetra
.35465 .45071 .36339 .45937 .3776 .45469 .3689 .44598 Mtetra
.3689 .44598 .3776 .45469 .39188 .44998 .38323 .44123 Mtetra
.38323 .44123 .39188 .44998 .40624 .44525 .39764 .43645 Mtetra
.39764 .43645 .40624 .44525 .42068 .4405 .41213 .43165 Mtetra
.663 .741 .908 r
.41213 .43165 .42068 .4405 .43519 .43572 .42669 .42683 Mtetra
.42669 .42683 .43519 .43572 .44978 .43091 .44133 .42198 Mtetra
.662 .741 .909 r
.44133 .42198 .44978 .43091 .46446 .4261 .45605 .41718 Mtetra
.655 .74 .912 r
.45605 .41718 .46446 .4261 .47921 .42136 .47085 .41259 Mtetra
.631 .737 .924 r
.47085 .41259 .47921 .42136 .49403 .41698 .48572 .40881 Mtetra
.55 .724 .955 r
.48572 .40881 .49403 .41698 .50894 .41389 .50067 .40719 Mtetra
.255 .621 .959 r
.50067 .40719 .50894 .41389 .52394 .41418 .51572 .40998 Mtetra
.422 0 0 r
.51572 .40998 .52394 .41418 .53911 .42137 .53094 .41929 Mtetra
.713 .178 0 r
.53094 .41929 .53911 .42137 .55457 .4388 .54641 .4347 Mtetra
.683 .143 0 r
.54641 .4347 .55457 .4388 .57046 .46582 .56218 .45085 Mtetra
.286 .445 .845 r
.56218 .45085 .57046 .46582 .58676 .49408 .57811 .4587 Mtetra
.627 .497 .684 r
.57811 .4587 .58676 .49408 .60317 .50919 .59393 .45145 Mtetra
.667 .484 .628 r
.59393 .45145 .60317 .50919 .61918 .50035 .60946 .43028 Mtetra
.67 .475 .613 r
.60946 .43028 .61918 .50035 .63453 .46966 .62474 .40327 Mtetra
.666 .474 .616 r
.62474 .40327 .63453 .46966 .64938 .43021 .63999 .37892 Mtetra
.662 .487 .637 r
.63999 .37892 .64938 .43021 .66417 .39532 .65541 .36119 Mtetra
.662 .521 .682 r
.65541 .36119 .66417 .39532 .67927 .3709 .67108 .34956 Mtetra
.667 .585 .754 r
.67108 .34956 .67927 .3709 .69476 .35594 .68697 .34167 Mtetra
.67 .661 .833 r
.68697 .34167 .69476 .35594 .71059 .34674 .70301 .33549 Mtetra
.667 .712 .882 r
.70301 .33549 .71059 .34674 .72664 .34015 .71918 .32991 Mtetra
.664 .733 .901 r
.71918 .32991 .72664 .34015 .74282 .33448 .73545 .32446 Mtetra
.664 .74 .906 r
.73545 .32446 .74282 .33448 .75912 .32904 .75182 .31903 Mtetra
.664 .741 .908 r
.75182 .31903 .75912 .32904 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Mtetra
.27545 .46545 .2845 .47397 .29838 .46936 .28937 .4608 Mtetra
.28937 .4608 .29838 .46936 .31234 .46474 .30337 .45613 Mtetra
.30337 .45613 .31234 .46474 .32636 .46009 .31744 .45143 Mtetra
.31744 .45143 .32636 .46009 .34047 .45541 .33159 .44671 Mtetra
.33159 .44671 .34047 .45541 .35465 .45071 .34582 .44196 Mtetra
.34582 .44196 .35465 .45071 .3689 .44598 .36012 .43719 Mtetra
.36012 .43719 .3689 .44598 .38323 .44123 .3745 .43239 Mtetra
.3745 .43239 .38323 .44123 .39764 .43645 .38896 .42757 Mtetra
.38896 .42757 .39764 .43645 .41213 .43165 .40349 .42272 Mtetra
.663 .741 .908 r
.40349 .42272 .41213 .43165 .42669 .42683 .4181 .41785 Mtetra
.662 .741 .908 r
.4181 .41785 .42669 .42683 .44133 .42198 .4328 .41299 Mtetra
.659 .741 .91 r
.4328 .41299 .44133 .42198 .45605 .41718 .44756 .40823 Mtetra
.646 .739 .917 r
.44756 .40823 .45605 .41718 .47085 .41259 .46241 .40392 Mtetra
.608 .734 .934 r
.46241 .40392 .47085 .41259 .48572 .40881 .47732 .4008 Mtetra
.503 .711 .965 r
.47732 .4008 .48572 .40881 .50067 .40719 .49231 .40014 Mtetra
.254 .612 .956 r
.49231 .40014 .50067 .40719 .51572 .40998 .5074 .40312 Mtetra
0 .44 .856 r
.5074 .40312 .51572 .40998 .53094 .41929 .52265 .4095 Mtetra
.139 .465 .891 r
.52265 .4095 .53094 .41929 .54641 .4347 .53809 .41628 Mtetra
.504 .523 .809 r
.53809 .41628 .54641 .4347 .56218 .45085 .5537 .41846 Mtetra
.623 .503 .696 r
.5537 .41846 .56218 .45085 .57811 .4587 .56934 .41226 Mtetra
.651 .487 .648 r
.56934 .41226 .57811 .4587 .59393 .45145 .58492 .39826 Mtetra
.657 .481 .635 r
.58492 .39826 .59393 .45145 .60946 .43028 .60043 .38086 Mtetra
.657 .486 .641 r
.60043 .38086 .60946 .43028 .62474 .40327 .61594 .36482 Mtetra
.657 .506 .668 r
.61594 .36482 .62474 .40327 .63999 .37892 .63156 .35244 Mtetra
.661 .551 .719 r
.63156 .35244 .63999 .37892 .65541 .36119 .64732 .3435 Mtetra
.667 .618 .79 r
.64732 .3435 .65541 .36119 .67108 .34956 .66324 .33669 Mtetra
.668 .683 .855 r
.66324 .33669 .67108 .34956 .68697 .34167 .67928 .33084 Mtetra
.666 .721 .89 r
.67928 .33084 .68697 .34167 .70301 .33549 .69543 .32532 Mtetra
.664 .736 .903 r
.69543 .32532 .70301 .33549 .71918 .32991 .71167 .31987 Mtetra
.664 .74 .907 r
.71167 .31987 .71918 .32991 .73545 .32446 .72801 .31441 Mtetra
.664 .741 .908 r
.72801 .31441 .73545 .32446 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Mtetra
.2663 .45685 .27545 .46545 .28937 .4608 .28027 .45216 Mtetra
.28027 .45216 .28937 .4608 .30337 .45613 .29432 .44744 Mtetra
.29432 .44744 .30337 .45613 .31744 .45143 .30844 .4427 Mtetra
.30844 .4427 .31744 .45143 .33159 .44671 .32263 .43793 Mtetra
.32263 .43793 .33159 .44671 .34582 .44196 .3369 .43313 Mtetra
.3369 .43313 .34582 .44196 .36012 .43719 .35125 .42831 Mtetra
.35125 .42831 .36012 .43719 .3745 .43239 .36568 .42346 Mtetra
.36568 .42346 .3745 .43239 .38896 .42757 .38018 .41859 Mtetra
.663 .741 .908 r
.38018 .41859 .38896 .42757 .40349 .42272 .39477 .4137 Mtetra
.39477 .4137 .40349 .42272 .4181 .41785 .40943 .40879 Mtetra
.661 .741 .909 r
.40943 .40879 .4181 .41785 .4328 .41299 .42417 .40392 Mtetra
.655 .74 .912 r
.42417 .40392 .4328 .41299 .44756 .40823 .43899 .39926 Mtetra
.639 .738 .921 r
.43899 .39926 .44756 .40823 .46241 .40392 .45388 .39516 Mtetra
.6 .731 .937 r
.45388 .39516 .46241 .40392 .47732 .4008 .46883 .39225 Mtetra
.529 .71 .954 r
.46883 .39225 .47732 .4008 .49231 .40014 .48387 .39113 Mtetra
.462 .669 .953 r
.48387 .39113 .49231 .40014 .5074 .40312 .49902 .39166 Mtetra
.492 .625 .91 r
.49902 .39166 .5074 .40312 .52265 .4095 .5143 .39238 Mtetra
.58 .578 .815 r
.5143 .39238 .52265 .4095 .53809 .41628 .52972 .39086 Mtetra
.63 .537 .731 r
.52972 .39086 .53809 .41628 .5537 .41846 .54524 .38524 Mtetra
.648 .515 .688 r
.54524 .38524 .5537 .41846 .56934 .41226 .56079 .37576 Mtetra
.653 .509 .674 r
.56079 .37576 .56934 .41226 .58492 .39826 .57637 .36454 Mtetra
.655 .518 .684 r
.57637 .36454 .58492 .39826 .60043 .38086 .59199 .35392 Mtetra
.659 .547 .717 r
.59199 .35392 .60043 .38086 .61594 .36482 .60769 .34508 Mtetra
.664 .597 .77 r
.60769 .34508 .61594 .36482 .63156 .35244 .6235 .33793 Mtetra
.667 .658 .831 r
.6235 .33793 .63156 .35244 .64732 .3435 .63941 .33183 Mtetra
.666 .705 .876 r
.63941 .33183 .64732 .3435 .66324 .33669 .65544 .3262 Mtetra
.665 .729 .898 r
.65544 .3262 .66324 .33669 .67928 .33084 .67156 .32072 Mtetra
.664 .738 .905 r
.67156 .32072 .67928 .33084 .69543 .32532 .68778 .31525 Mtetra
.664 .741 .907 r
.68778 .31525 .69543 .32532 .71167 .31987 .70408 .30977 Mtetra
.664 .741 .908 r
.70408 .30977 .71167 .31987 .72801 .31441 .72049 .30426 Mtetra
.72049 .30426 .72801 .31441 .74444 .30893 .73699 .29872 Mtetra
.73699 .29872 .74444 .30893 .76097 .30341 .75358 .29314 Mtetra
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28753 Mtetra
.77027 .28753 .7776 .29786 .79432 .29228 .78706 .28189 Mtetra
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Mtetra
.25707 .44817 .2663 .45685 .28027 .45216 .27108 .44343 Mtetra
.27108 .44343 .28027 .45216 .29432 .44744 .28517 .43866 Mtetra
.28517 .43866 .29432 .44744 .30844 .4427 .29934 .43387 Mtetra
.29934 .43387 .30844 .4427 .32263 .43793 .31358 .42905 Mtetra
.31358 .42905 .32263 .43793 .3369 .43313 .3279 .42421 Mtetra
.3279 .42421 .3369 .43313 .35125 .42831 .34229 .41934 Mtetra
.34229 .41934 .35125 .42831 .36568 .42346 .35677 .41445 Mtetra
.35677 .41445 .36568 .42346 .38018 .41859 .37132 .40953 Mtetra
.663 .741 .908 r
.37132 .40953 .38018 .41859 .39477 .4137 .38595 .40459 Mtetra
.38595 .40459 .39477 .4137 .40943 .40879 .40067 .39965 Mtetra
.66 .741 .91 r
.40067 .39965 .40943 .40879 .42417 .40392 .41546 .39478 Mtetra
.653 .74 .913 r
.41546 .39478 .42417 .40392 .43899 .39926 .43032 .39014 Mtetra
.639 .737 .92 r
.43032 .39014 .43899 .39926 .45388 .39516 .44526 .38599 Mtetra
.616 .729 .927 r
.44526 .38599 .45388 .39516 .46883 .39225 .46028 .38259 Mtetra
.595 .711 .925 r
.46028 .38259 .46883 .39225 .48387 .39113 .47538 .3799 Mtetra
.598 .679 .898 r
.47538 .3799 .48387 .39113 .49902 .39166 .49059 .37728 Mtetra
.622 .635 .842 r
.49059 .37728 .49902 .39166 .5143 .39238 .50591 .37369 Mtetra
.643 .594 .784 r
.50591 .37369 .5143 .39238 .52972 .39086 .52134 .36833 Mtetra
.654 .569 .747 r
.52134 .36833 .52972 .39086 .54524 .38524 .53685 .36127 Mtetra
.658 .562 .736 r
.53685 .36127 .54524 .38524 .56079 .37576 .55242 .35343 Mtetra
.66 .575 .748 r
.55242 .35343 .56079 .37576 .57637 .36454 .56805 .34582 Mtetra
.664 .606 .781 r
.56805 .34582 .57637 .36454 .59199 .35392 .58377 .33895 Mtetra
.666 .651 .825 r
.58377 .33895 .59199 .35392 .60769 .34508 .59958 .3328 Mtetra
.667 .694 .866 r
.59958 .3328 .60769 .34508 .6235 .33793 .61548 .32709 Mtetra
.665 .722 .891 r
.61548 .32709 .6235 .33793 .63941 .33183 .63148 .32157 Mtetra
.664 .735 .903 r
.63148 .32157 .63941 .33183 .65544 .3262 .64757 .3161 Mtetra
.664 .74 .907 r
.64757 .3161 .65544 .3262 .67156 .32072 .66376 .31062 Mtetra
.664 .741 .908 r
.66376 .31062 .67156 .32072 .68778 .31525 .68004 .30511 Mtetra
.68004 .30511 .68778 .31525 .70408 .30977 .69642 .29957 Mtetra
.69642 .29957 .70408 .30977 .72049 .30426 .71289 .294 Mtetra
.71289 .294 .72049 .30426 .73699 .29872 .72945 .2884 Mtetra
.72945 .2884 .73699 .29872 .75358 .29314 .74611 .28276 Mtetra
.74611 .28276 .75358 .29314 .77027 .28753 .76287 .2771 Mtetra
.76287 .2771 .77027 .28753 .78706 .28189 .77973 .27139 Mtetra
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.23376 .44416 .24313 .45288 .25707 .44817 .24775 .4394 Mtetra
.24775 .4394 .25707 .44817 .27108 .44343 .2618 .43461 Mtetra
.2618 .43461 .27108 .44343 .28517 .43866 .27594 .4298 Mtetra
.27594 .4298 .28517 .43866 .29934 .43387 .29015 .42496 Mtetra
.29015 .42496 .29934 .43387 .31358 .42905 .30444 .42009 Mtetra
.30444 .42009 .31358 .42905 .3279 .42421 .3188 .4152 Mtetra
.3188 .4152 .3279 .42421 .34229 .41934 .33325 .41028 Mtetra
.33325 .41028 .34229 .41934 .35677 .41445 .34777 .40534 Mtetra
.663 .741 .908 r
.34777 .40534 .35677 .41445 .37132 .40953 .36237 .40037 Mtetra
.36237 .40037 .37132 .40953 .38595 .40459 .37705 .39538 Mtetra
.662 .741 .909 r
.37705 .39538 .38595 .40459 .40067 .39965 .39181 .39041 Mtetra
.66 .741 .91 r
.39181 .39041 .40067 .39965 .41546 .39478 .40666 .3855 Mtetra
.655 .739 .912 r
.40666 .3855 .41546 .39478 .43032 .39014 .42157 .38076 Mtetra
.647 .736 .914 r
.42157 .38076 .43032 .39014 .44526 .38599 .43657 .37628 Mtetra
.64 .727 .912 r
.43657 .37628 .44526 .38599 .46028 .38259 .45165 .37206 Mtetra
.639 .71 .898 r
.45165 .37206 .46028 .38259 .47538 .3799 .46682 .36785 Mtetra
.646 .684 .871 r
.46682 .36785 .47538 .3799 .49059 .37728 .48209 .36326 Mtetra
.655 .656 .839 r
.48209 .36326 .49059 .37728 .50591 .37369 .49746 .35798 Mtetra
.661 .636 .815 r
.49746 .35798 .50591 .37369 .52134 .36833 .51292 .35204 Mtetra
.664 .632 .807 r
.51292 .35204 .52134 .36833 .53685 .36127 .52845 .34578 Mtetra
.666 .643 .818 r
.52845 .34578 .53685 .36127 .55242 .35343 .54407 .33958 Mtetra
.666 .667 .841 r
.54407 .33958 .55242 .35343 .56805 .34582 .55977 .33364 Mtetra
.666 .695 .868 r
.55977 .33364 .56805 .34582 .58377 .33895 .57556 .32796 Mtetra
.665 .719 .889 r
.57556 .32796 .58377 .33895 .59958 .3328 .59144 .32243 Mtetra
.664 .732 .9 r
.59144 .32243 .59958 .3328 .61548 .32709 .60741 .31695 Mtetra
.664 .738 .906 r
.60741 .31695 .61548 .32709 .63148 .32157 .62347 .31146 Mtetra
.664 .741 .907 r
.62347 .31146 .63148 .32157 .64757 .3161 .63963 .30596 Mtetra
.664 .741 .908 r
.63963 .30596 .64757 .3161 .66376 .31062 .65588 .30043 Mtetra
.65588 .30043 .66376 .31062 .68004 .30511 .67223 .29486 Mtetra
.67223 .29486 .68004 .30511 .69642 .29957 .68867 .28926 Mtetra
.68867 .28926 .69642 .29957 .71289 .294 .7052 .28363 Mtetra
.7052 .28363 .71289 .294 .72945 .2884 .72183 .27797 Mtetra
.72183 .27797 .72945 .2884 .74611 .28276 .73856 .27227 Mtetra
.73856 .27227 .74611 .28276 .76287 .2771 .75539 .26654 Mtetra
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.2243 .43535 .23376 .44416 .24775 .4394 .23833 .43054 Mtetra
.23833 .43054 .24775 .4394 .2618 .43461 .25243 .4257 Mtetra
.25243 .4257 .2618 .43461 .27594 .4298 .26661 .42084 Mtetra
.26661 .42084 .27594 .4298 .29015 .42496 .28087 .41596 Mtetra
.28087 .41596 .29015 .42496 .30444 .42009 .2952 .41104 Mtetra
.2952 .41104 .30444 .42009 .3188 .4152 .30961 .4061 Mtetra
.30961 .4061 .3188 .4152 .33325 .41028 .32411 .40113 Mtetra
.32411 .40113 .33325 .41028 .34777 .40534 .33868 .39614 Mtetra
.663 .741 .908 r
.33868 .39614 .34777 .40534 .36237 .40037 .35333 .39112 Mtetra
.35333 .39112 .36237 .40037 .37705 .39538 .36806 .38609 Mtetra
.662 .741 .908 r
.36806 .38609 .37705 .39538 .39181 .39041 .38287 .38106 Mtetra
.661 .741 .909 r
.38287 .38106 .39181 .39041 .40666 .3855 .39777 .37606 Mtetra
.658 .739 .909 r
.39777 .37606 .40666 .3855 .42157 .38076 .41274 .37114 Mtetra
.656 .735 .908 r
.41274 .37114 .42157 .38076 .43657 .37628 .4278 .36627 Mtetra
.655 .728 .903 r
.4278 .36627 .43657 .37628 .45165 .37206 .44294 .3614 Mtetra
.658 .716 .891 r
.44294 .3614 .45165 .37206 .46682 .36785 .45817 .35638 Mtetra
.661 .702 .877 r
.45817 .35638 .46682 .36785 .48209 .36326 .4735 .35111 Mtetra
.664 .692 .866 r
.4735 .35111 .48209 .36326 .49746 .35798 .48891 .34561 Mtetra
.666 .69 .863 r
.48891 .34561 .49746 .35798 .51292 .35204 .50441 .33998 Mtetra
.666 .696 .869 r
.50441 .33998 .51292 .35204 .52845 .34578 .52 .33434 Mtetra
.666 .709 .88 r
.52 .33434 .52845 .34578 .54407 .33958 .53567 .32877 Mtetra
.665 .722 .892 r
.53567 .32877 .54407 .33958 .55977 .33364 .55143 .32327 Mtetra
.664 .732 .9 r
.55143 .32327 .55977 .33364 .57556 .32796 .56728 .31779 Mtetra
.664 .738 .905 r
.56728 .31779 .57556 .32796 .59144 .32243 .58322 .31231 Mtetra
.664 .74 .907 r
.58322 .31231 .59144 .32243 .60741 .31695 .59926 .30681 Mtetra
.664 .741 .908 r
.59926 .30681 .60741 .31695 .62347 .31146 .61538 .30128 Mtetra
.61538 .30128 .62347 .31146 .63963 .30596 .6316 .29572 Mtetra
.6316 .29572 .63963 .30596 .65588 .30043 .64792 .29013 Mtetra
.64792 .29013 .65588 .30043 .67223 .29486 .66433 .2845 Mtetra
.66433 .2845 .67223 .29486 .68867 .28926 .68083 .27884 Mtetra
.68083 .27884 .68867 .28926 .7052 .28363 .69743 .27315 Mtetra
.69743 .27315 .7052 .28363 .72183 .27797 .71413 .26743 Mtetra
.71413 .26743 .72183 .27797 .73856 .27227 .73093 .26167 Mtetra
.73093 .26167 .73856 .27227 .75539 .26654 .74783 .25587 Mtetra
.74783 .25587 .75539 .26654 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24418 Mtetra
.78193 .24418 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.21474 .42645 .2243 .43535 .23833 .43054 .22882 .42159 Mtetra
.22882 .42159 .23833 .43054 .25243 .4257 .24296 .41671 Mtetra
.24296 .41671 .25243 .4257 .26661 .42084 .25719 .4118 Mtetra
.25719 .4118 .26661 .42084 .28087 .41596 .27149 .40686 Mtetra
.27149 .40686 .28087 .41596 .2952 .41104 .28587 .4019 Mtetra
.28587 .4019 .2952 .41104 .30961 .4061 .30033 .39691 Mtetra
.30033 .39691 .30961 .4061 .32411 .40113 .31487 .39189 Mtetra
.31487 .39189 .32411 .40113 .33868 .39614 .32949 .38685 Mtetra
.663 .741 .908 r
.32949 .38685 .33868 .39614 .35333 .39112 .34419 .38178 Mtetra
.34419 .38178 .35333 .39112 .36806 .38609 .35898 .37669 Mtetra
.35898 .37669 .36806 .38609 .38287 .38106 .37384 .37159 Mtetra
.662 .74 .908 r
.37384 .37159 .38287 .38106 .39777 .37606 .38879 .36649 Mtetra
.661 .739 .908 r
.38879 .36649 .39777 .37606 .41274 .37114 .40382 .36139 Mtetra
.661 .736 .906 r
.40382 .36139 .41274 .37114 .4278 .36627 .41893 .35626 Mtetra
.662 .732 .902 r
.41893 .35626 .4278 .36627 .44294 .3614 .43413 .35107 Mtetra
.663 .727 .897 r
.43413 .35107 .44294 .3614 .45817 .35638 .44942 .3458 Mtetra
.664 .723 .893 r
.44942 .3458 .45817 .35638 .4735 .35111 .4648 .34042 Mtetra
.665 .722 .892 r
.4648 .34042 .4735 .35111 .48891 .34561 .48027 .33499 Mtetra
.665 .725 .894 r
.48027 .33499 .48891 .34561 .50441 .33998 .49582 .32954 Mtetra
.664 .73 .898 r
.49582 .32954 .50441 .33998 .52 .33434 .51146 .32409 Mtetra
.664 .735 .902 r
.51146 .32409 .52 .33434 .53567 .32877 .52719 .31863 Mtetra
.664 .738 .905 r
.52719 .31863 .53567 .32877 .55143 .32327 .54301 .31315 Mtetra
.664 .74 .907 r
.54301 .31315 .55143 .32327 .56728 .31779 .55892 .30766 Mtetra
.664 .741 .908 r
.55892 .30766 .56728 .31779 .58322 .31231 .57492 .30213 Mtetra
.57492 .30213 .58322 .31231 .59926 .30681 .59101 .29658 Mtetra
.59101 .29658 .59926 .30681 .61538 .30128 .6072 .29099 Mtetra
.6072 .29099 .61538 .30128 .6316 .29572 .62349 .28537 Mtetra
.62349 .28537 .6316 .29572 .64792 .29013 .63987 .27972 Mtetra
.63987 .27972 .64792 .29013 .66433 .2845 .65634 .27403 Mtetra
.65634 .27403 .66433 .2845 .68083 .27884 .67291 .26831 Mtetra
.67291 .26831 .68083 .27884 .69743 .27315 .68958 .26256 Mtetra
.68958 .26256 .69743 .27315 .71413 .26743 .70635 .25677 Mtetra
.70635 .25677 .71413 .26743 .73093 .26167 .72322 .25095 Mtetra
.72322 .25095 .73093 .26167 .74783 .25587 .74019 .24509 Mtetra
.74019 .24509 .74783 .25587 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24418 .77443 .23327 Mtetra
.77443 .23327 .78193 .24418 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.20509 .41746 .21474 .42645 .22882 .42159 .21921 .41256 Mtetra
.21921 .41256 .22882 .42159 .24296 .41671 .2334 .40762 Mtetra
.2334 .40762 .24296 .41671 .25719 .4118 .24767 .40267 Mtetra
.24767 .40267 .25719 .4118 .27149 .40686 .26202 .39768 Mtetra
.26202 .39768 .27149 .40686 .28587 .4019 .27645 .39266 Mtetra
.27645 .39266 .28587 .4019 .30033 .39691 .29096 .38762 Mtetra
.29096 .38762 .30033 .39691 .31487 .39189 .30555 .38255 Mtetra
.30555 .38255 .31487 .39189 .32949 .38685 .32021 .37746 Mtetra
.663 .741 .908 r
.32021 .37746 .32949 .38685 .34419 .38178 .33497 .37233 Mtetra
.33497 .37233 .34419 .38178 .35898 .37669 .3498 .36718 Mtetra
.3498 .36718 .35898 .37669 .37384 .37159 .36472 .36202 Mtetra
.36472 .36202 .37384 .37159 .38879 .36649 .37971 .35682 Mtetra
.663 .74 .907 r
.37971 .35682 .38879 .36649 .40382 .36139 .3948 .35161 Mtetra
.663 .738 .906 r
.3948 .35161 .40382 .36139 .41893 .35626 .40997 .34635 Mtetra
.663 .737 .904 r
.40997 .34635 .41893 .35626 .43413 .35107 .42523 .34105 Mtetra
.664 .736 .903 r
.42523 .34105 .43413 .35107 .44942 .3458 .44057 .3357 Mtetra
.664 .735 .903 r
.44057 .3357 .44942 .3458 .4648 .34042 .456 .33031 Mtetra
.664 .736 .904 r
.456 .33031 .4648 .34042 .48027 .33499 .47152 .3249 Mtetra
.664 .738 .905 r
.47152 .3249 .48027 .33499 .49582 .32954 .48713 .31946 Mtetra
.664 .739 .906 r
.48713 .31946 .49582 .32954 .51146 .32409 .50282 .31399 Mtetra
.664 .74 .907 r
.50282 .31399 .51146 .32409 .52719 .31863 .51861 .3085 Mtetra
.664 .741 .908 r
.51861 .3085 .52719 .31863 .54301 .31315 .53449 .30298 Mtetra
.53449 .30298 .54301 .31315 .55892 .30766 .55046 .29743 Mtetra
.55046 .29743 .55892 .30766 .57492 .30213 .56653 .29185 Mtetra
.56653 .29185 .57492 .30213 .59101 .29658 .58268 .28624 Mtetra
.58268 .28624 .59101 .29658 .6072 .29099 .59894 .28059 Mtetra
.59894 .28059 .6072 .29099 .62349 .28537 .61528 .27491 Mtetra
.61528 .27491 .62349 .28537 .63987 .27972 .63173 .26919 Mtetra
.63173 .26919 .63987 .27972 .65634 .27403 .64827 .26344 Mtetra
.64827 .26344 .65634 .27403 .67291 .26831 .66491 .25766 Mtetra
.66491 .25766 .67291 .26831 .68958 .26256 .68164 .25184 Mtetra
.68164 .25184 .68958 .26256 .70635 .25677 .69848 .24599 Mtetra
.69848 .24599 .70635 .25677 .72322 .25095 .71542 .24011 Mtetra
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23418 Mtetra
.73246 .23418 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Mtetra
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .2162 Mtetra
.78419 .2162 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.19534 .40839 .20509 .41746 .21921 .41256 .2095 .40343 Mtetra
.2095 .40343 .21921 .41256 .2334 .40762 .22374 .39845 Mtetra
.22374 .39845 .2334 .40762 .24767 .40267 .23806 .39344 Mtetra
.23806 .39344 .24767 .40267 .26202 .39768 .25245 .3884 Mtetra
.25245 .3884 .26202 .39768 .27645 .39266 .26693 .38333 Mtetra
.26693 .38333 .27645 .39266 .29096 .38762 .28149 .37824 Mtetra
.28149 .37824 .29096 .38762 .30555 .38255 .29612 .37312 Mtetra
.29612 .37312 .30555 .38255 .32021 .37746 .31084 .36797 Mtetra
.31084 .36797 .32021 .37746 .33497 .37233 .32564 .36279 Mtetra
.663 .741 .908 r
.32564 .36279 .33497 .37233 .3498 .36718 .34053 .35758 Mtetra
.34053 .35758 .3498 .36718 .36472 .36202 .35549 .35235 Mtetra
.35549 .35235 .36472 .36202 .37971 .35682 .37055 .34709 Mtetra
.663 .741 .907 r
.37055 .34709 .37971 .35682 .3948 .35161 .38568 .34179 Mtetra
.664 .74 .907 r
.38568 .34179 .3948 .35161 .40997 .34635 .40091 .33647 Mtetra
.40091 .33647 .40997 .34635 .42523 .34105 .41622 .33111 Mtetra
.41622 .33111 .42523 .34105 .44057 .3357 .43162 .32571 Mtetra
.43162 .32571 .44057 .3357 .456 .33031 .4471 .32029 Mtetra
.4471 .32029 .456 .33031 .47152 .3249 .46268 .31483 Mtetra
.664 .741 .907 r
.46268 .31483 .47152 .3249 .48713 .31946 .47834 .30935 Mtetra
.664 .741 .908 r
.47834 .30935 .48713 .31946 .50282 .31399 .4941 .30384 Mtetra
.4941 .30384 .50282 .31399 .51861 .3085 .50995 .29829 Mtetra
.50995 .29829 .51861 .3085 .53449 .30298 .52589 .29271 Mtetra
.52589 .29271 .53449 .30298 .55046 .29743 .54192 .2871 Mtetra
.54192 .2871 .55046 .29743 .56653 .29185 .55804 .28146 Mtetra
.55804 .28146 .56653 .29185 .58268 .28624 .57426 .27578 Mtetra
.57426 .27578 .58268 .28624 .59894 .28059 .59058 .27007 Mtetra
.59058 .27007 .59894 .28059 .61528 .27491 .60699 .26433 Mtetra
.60699 .26433 .61528 .27491 .63173 .26919 .6235 .25855 Mtetra
.6235 .25855 .63173 .26919 .64827 .26344 .64011 .25274 Mtetra
.64011 .25274 .64827 .26344 .66491 .25766 .65681 .24689 Mtetra
.65681 .24689 .66491 .25766 .68164 .25184 .67362 .24101 Mtetra
.67362 .24101 .68164 .25184 .69848 .24599 .69052 .2351 Mtetra
.69052 .2351 .69848 .24599 .71542 .24011 .70753 .22915 Mtetra
.70753 .22915 .71542 .24011 .73246 .23418 .72464 .22316 Mtetra
.72464 .22316 .73246 .23418 .7496 .22823 .74185 .21713 Mtetra
.74185 .21713 .7496 .22823 .76684 .22223 .75917 .21107 Mtetra
.75917 .21107 .76684 .22223 .78419 .2162 .77659 .20498 Mtetra
.77659 .20498 .78419 .2162 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.18549 .39922 .19534 .40839 .2095 .40343 .1997 .39421 Mtetra
.1997 .39421 .2095 .40343 .22374 .39845 .21398 .38918 Mtetra
.21398 .38918 .22374 .39845 .23806 .39344 .22835 .38411 Mtetra
.22835 .38411 .23806 .39344 .25245 .3884 .24279 .37903 Mtetra
.24279 .37903 .25245 .3884 .26693 .38333 .25731 .37391 Mtetra
.25731 .37391 .26693 .38333 .28149 .37824 .27192 .36876 Mtetra
.27192 .36876 .28149 .37824 .29612 .37312 .2866 .36359 Mtetra
.2866 .36359 .29612 .37312 .31084 .36797 .30137 .35838 Mtetra
.30137 .35838 .31084 .36797 .32564 .36279 .31622 .35315 Mtetra
.31622 .35315 .32564 .36279 .34053 .35758 .33116 .34789 Mtetra
.33116 .34789 .34053 .35758 .35549 .35235 .34618 .3426 Mtetra
.34618 .3426 .35549 .35235 .37055 .34709 .36128 .33727 Mtetra
.36128 .33727 .37055 .34709 .38568 .34179 .37647 .33192 Mtetra
.37647 .33192 .38568 .34179 .40091 .33647 .39175 .32654 Mtetra
.39175 .32654 .40091 .33647 .41622 .33111 .40712 .32112 Mtetra
.40712 .32112 .41622 .33111 .43162 .32571 .42257 .31567 Mtetra
.42257 .31567 .43162 .32571 .4471 .32029 .43811 .3102 Mtetra
.43811 .3102 .4471 .32029 .46268 .31483 .45374 .30469 Mtetra
.45374 .30469 .46268 .31483 .47834 .30935 .46947 .29915 Mtetra
.46947 .29915 .47834 .30935 .4941 .30384 .48528 .29357 Mtetra
.48528 .29357 .4941 .30384 .50995 .29829 .50119 .28797 Mtetra
.50119 .28797 .50995 .29829 .52589 .29271 .51719 .28233 Mtetra
.51719 .28233 .52589 .29271 .54192 .2871 .53328 .27666 Mtetra
.53328 .27666 .54192 .2871 .55804 .28146 .54947 .27095 Mtetra
.54947 .27095 .55804 .28146 .57426 .27578 .56575 .26522 Mtetra
.56575 .26522 .57426 .27578 .59058 .27007 .58213 .25944 Mtetra
.58213 .25944 .59058 .27007 .60699 .26433 .59861 .25364 Mtetra
.59861 .25364 .60699 .26433 .6235 .25855 .61518 .2478 Mtetra
.61518 .2478 .6235 .25855 .64011 .25274 .63185 .24192 Mtetra
.63185 .24192 .64011 .25274 .65681 .24689 .64863 .23601 Mtetra
.64863 .23601 .65681 .24689 .67362 .24101 .6655 .23006 Mtetra
.6655 .23006 .67362 .24101 .69052 .2351 .68248 .22408 Mtetra
.68248 .22408 .69052 .2351 .70753 .22915 .69955 .21806 Mtetra
.69955 .21806 .70753 .22915 .72464 .22316 .71674 .21201 Mtetra
.71674 .21201 .72464 .22316 .74185 .21713 .73402 .20592 Mtetra
.73402 .20592 .74185 .21713 .75917 .21107 .75141 .19979 Mtetra
.75141 .19979 .75917 .21107 .77659 .20498 .76891 .19362 Mtetra
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.17555 .38995 .18549 .39922 .1997 .39421 .1898 .3849 Mtetra
.1898 .3849 .1997 .39421 .21398 .38918 .20413 .37981 Mtetra
.20413 .37981 .21398 .38918 .22835 .38411 .21853 .3747 Mtetra
.21853 .3747 .22835 .38411 .24279 .37903 .23302 .36955 Mtetra
.23302 .36955 .24279 .37903 .25731 .37391 .2476 .36438 Mtetra
.2476 .36438 .25731 .37391 .27192 .36876 .26225 .35918 Mtetra
.26225 .35918 .27192 .36876 .2866 .36359 .27698 .35396 Mtetra
.27698 .35396 .2866 .36359 .30137 .35838 .2918 .3487 Mtetra
.2918 .3487 .30137 .35838 .31622 .35315 .3067 .34341 Mtetra
.3067 .34341 .31622 .35315 .33116 .34789 .32169 .33809 Mtetra
.32169 .33809 .33116 .34789 .34618 .3426 .33676 .33274 Mtetra
.33676 .33274 .34618 .3426 .36128 .33727 .35192 .32736 Mtetra
.35192 .32736 .36128 .33727 .37647 .33192 .36716 .32195 Mtetra
.36716 .32195 .37647 .33192 .39175 .32654 .3825 .31651 Mtetra
.3825 .31651 .39175 .32654 .40712 .32112 .39792 .31104 Mtetra
.39792 .31104 .40712 .32112 .42257 .31567 .41343 .30554 Mtetra
.41343 .30554 .42257 .31567 .43811 .3102 .42902 .3 Mtetra
.42902 .3 .43811 .3102 .45374 .30469 .44471 .29443 Mtetra
.44471 .29443 .45374 .30469 .46947 .29915 .4605 .28883 Mtetra
.4605 .28883 .46947 .29915 .48528 .29357 .47637 .2832 Mtetra
.47637 .2832 .48528 .29357 .50119 .28797 .49233 .27753 Mtetra
.49233 .27753 .50119 .28797 .51719 .28233 .50839 .27183 Mtetra
.50839 .27183 .51719 .28233 .53328 .27666 .52455 .2661 Mtetra
.52455 .2661 .53328 .27666 .54947 .27095 .5408 .26033 Mtetra
.5408 .26033 .54947 .27095 .56575 .26522 .55715 .25453 Mtetra
.55715 .25453 .56575 .26522 .58213 .25944 .57359 .2487 Mtetra
.57359 .2487 .58213 .25944 .59861 .25364 .59013 .24283 Mtetra
.59013 .24283 .59861 .25364 .61518 .2478 .60677 .23692 Mtetra
.60677 .23692 .61518 .2478 .63185 .24192 .62351 .23098 Mtetra
.62351 .23098 .63185 .24192 .64863 .23601 .64035 .225 Mtetra
.64035 .225 .64863 .23601 .6655 .23006 .6573 .21899 Mtetra
.6573 .21899 .6655 .23006 .68248 .22408 .67434 .21294 Mtetra
.67434 .21294 .68248 .22408 .69955 .21806 .69149 .20686 Mtetra
.69149 .20686 .69955 .21806 .71674 .21201 .70874 .20073 Mtetra
.70874 .20073 .71674 .21201 .73402 .20592 .7261 .19457 Mtetra
.7261 .19457 .73402 .20592 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Mtetra
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.1655 .38059 .17555 .38995 .1898 .3849 .17979 .37549 Mtetra
.17979 .37549 .1898 .3849 .20413 .37981 .19417 .37035 Mtetra
.19417 .37035 .20413 .37981 .21853 .3747 .20862 .36518 Mtetra
.20862 .36518 .21853 .3747 .23302 .36955 .22316 .35999 Mtetra
.22316 .35999 .23302 .36955 .2476 .36438 .23778 .35476 Mtetra
.23778 .35476 .2476 .36438 .26225 .35918 .25248 .34951 Mtetra
.25248 .34951 .26225 .35918 .27698 .35396 .26726 .34422 Mtetra
.26726 .34422 .27698 .35396 .2918 .3487 .28213 .33891 Mtetra
.28213 .33891 .2918 .3487 .3067 .34341 .29708 .33357 Mtetra
.29708 .33357 .3067 .34341 .32169 .33809 .31212 .32819 Mtetra
.31212 .32819 .32169 .33809 .33676 .33274 .32725 .32279 Mtetra
.32725 .32279 .33676 .33274 .35192 .32736 .34246 .31735 Mtetra
.34246 .31735 .35192 .32736 .36716 .32195 .35775 .31188 Mtetra
.35775 .31188 .36716 .32195 .3825 .31651 .37314 .30638 Mtetra
.37314 .30638 .3825 .31651 .39792 .31104 .38862 .30085 Mtetra
.38862 .30085 .39792 .31104 .41343 .30554 .40418 .29529 Mtetra
.40418 .29529 .41343 .30554 .42902 .3 .41984 .2897 Mtetra
.41984 .2897 .42902 .3 .44471 .29443 .43559 .28407 Mtetra
.43559 .28407 .44471 .29443 .4605 .28883 .45143 .27841 Mtetra
.45143 .27841 .4605 .28883 .47637 .2832 .46736 .27271 Mtetra
.46736 .27271 .47637 .2832 .49233 .27753 .48338 .26698 Mtetra
.48338 .26698 .49233 .27753 .50839 .27183 .49951 .26122 Mtetra
.49951 .26122 .50839 .27183 .52455 .2661 .51572 .25543 Mtetra
.51572 .25543 .52455 .2661 .5408 .26033 .53204 .2496 Mtetra
.53204 .2496 .5408 .26033 .55715 .25453 .54845 .24373 Mtetra
.54845 .24373 .55715 .25453 .57359 .2487 .56495 .23783 Mtetra
.56495 .23783 .57359 .2487 .59013 .24283 .58156 .2319 Mtetra
.58156 .2319 .59013 .24283 .60677 .23692 .59827 .22593 Mtetra
.59827 .22593 .60677 .23692 .62351 .23098 .61508 .21992 Mtetra
.61508 .21992 .62351 .23098 .64035 .225 .63199 .21388 Mtetra
.63199 .21388 .64035 .225 .6573 .21899 .649 .2078 Mtetra
.649 .2078 .6573 .21899 .67434 .21294 .66611 .20168 Mtetra
.66611 .20168 .67434 .21294 .69149 .20686 .68334 .19552 Mtetra
.68334 .19552 .69149 .20686 .70874 .20073 .70066 .18933 Mtetra
.70066 .18933 .70874 .20073 .7261 .19457 .71809 .1831 Mtetra
.71809 .1831 .7261 .19457 .74357 .18838 .73563 .17683 Mtetra
.73563 .17683 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.15534 .37114 .1655 .38059 .17979 .37549 .16968 .36598 Mtetra
.16968 .36598 .17979 .37549 .19417 .37035 .1841 .36079 Mtetra
.1841 .36079 .19417 .37035 .20862 .36518 .19861 .35557 Mtetra
.19861 .35557 .20862 .36518 .22316 .35999 .21319 .35032 Mtetra
.21319 .35032 .22316 .35999 .23778 .35476 .22786 .34504 Mtetra
.22786 .34504 .23778 .35476 .25248 .34951 .24261 .33973 Mtetra
.24261 .33973 .25248 .34951 .26726 .34422 .25744 .33439 Mtetra
.25744 .33439 .26726 .34422 .28213 .33891 .27236 .32902 Mtetra
.27236 .32902 .28213 .33891 .29708 .33357 .28736 .32362 Mtetra
.28736 .32362 .29708 .33357 .31212 .32819 .30245 .31819 Mtetra
.30245 .31819 .31212 .32819 .32725 .32279 .31763 .31273 Mtetra
.31763 .31273 .32725 .32279 .34246 .31735 .33289 .30723 Mtetra
.33289 .30723 .34246 .31735 .35775 .31188 .34825 .30171 Mtetra
.34825 .30171 .35775 .31188 .37314 .30638 .36369 .29615 Mtetra
.36369 .29615 .37314 .30638 .38862 .30085 .37922 .29056 Mtetra
.37922 .29056 .38862 .30085 .40418 .29529 .39484 .28494 Mtetra
.39484 .28494 .40418 .29529 .41984 .2897 .41055 .27928 Mtetra
.41055 .27928 .41984 .2897 .43559 .28407 .42636 .27359 Mtetra
.42636 .27359 .43559 .28407 .45143 .27841 .44226 .26787 Mtetra
.44226 .26787 .45143 .27841 .46736 .27271 .45825 .26211 Mtetra
.45825 .26211 .46736 .27271 .48338 .26698 .47434 .25632 Mtetra
.47434 .25632 .48338 .26698 .49951 .26122 .49052 .2505 Mtetra
.49052 .2505 .49951 .26122 .51572 .25543 .5068 .24464 Mtetra
.5068 .24464 .51572 .25543 .53204 .2496 .52318 .23874 Mtetra
.52318 .23874 .53204 .2496 .54845 .24373 .53965 .23281 Mtetra
.53965 .23281 .54845 .24373 .56495 .23783 .55622 .22685 Mtetra
.55622 .22685 .56495 .23783 .58156 .2319 .5729 .22085 Mtetra
.5729 .22085 .58156 .2319 .59827 .22593 .58967 .21481 Mtetra
.58967 .21481 .59827 .22593 .61508 .21992 .60655 .20873 Mtetra
.60655 .20873 .61508 .21992 .63199 .21388 .62353 .20262 Mtetra
.62353 .20262 .63199 .21388 .649 .2078 .64061 .19647 Mtetra
.64061 .19647 .649 .2078 .66611 .20168 .6578 .19029 Mtetra
.6578 .19029 .66611 .20168 .68334 .19552 .67509 .18406 Mtetra
.67509 .18406 .68334 .19552 .70066 .18933 .69249 .1778 Mtetra
.69249 .1778 .70066 .18933 .71809 .1831 .70999 .1715 Mtetra
.70999 .1715 .71809 .1831 .73563 .17683 .72761 .16516 Mtetra
.72761 .16516 .73563 .17683 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.14508 .36159 .15534 .37114 .16968 .36598 .15947 .35637 Mtetra
.15947 .35637 .16968 .36598 .1841 .36079 .17394 .35113 Mtetra
.17394 .35113 .1841 .36079 .19861 .35557 .18849 .34585 Mtetra
.18849 .34585 .19861 .35557 .21319 .35032 .20312 .34055 Mtetra
.20312 .34055 .21319 .35032 .22786 .34504 .21783 .33521 Mtetra
.21783 .33521 .22786 .34504 .24261 .33973 .23263 .32985 Mtetra
.23263 .32985 .24261 .33973 .25744 .33439 .24752 .32445 Mtetra
.24752 .32445 .25744 .33439 .27236 .32902 .26248 .31903 Mtetra
.26248 .31903 .27236 .32902 .28736 .32362 .27754 .31357 Mtetra
.27754 .31357 .28736 .32362 .30245 .31819 .29268 .30808 Mtetra
.29268 .30808 .30245 .31819 .31763 .31273 .30791 .30256 Mtetra
.30791 .30256 .31763 .31273 .33289 .30723 .32323 .29701 Mtetra
.32323 .29701 .33289 .30723 .34825 .30171 .33863 .29142 Mtetra
.33863 .29142 .34825 .30171 .36369 .29615 .35413 .2858 Mtetra
.35413 .2858 .36369 .29615 .37922 .29056 .36972 .28015 Mtetra
.36972 .28015 .37922 .29056 .39484 .28494 .3854 .27447 Mtetra
.3854 .27447 .39484 .28494 .41055 .27928 .40117 .26875 Mtetra
.40117 .26875 .41055 .27928 .42636 .27359 .41703 .263 Mtetra
.41703 .263 .42636 .27359 .44226 .26787 .43299 .25721 Mtetra
.43299 .25721 .44226 .26787 .45825 .26211 .44904 .25139 Mtetra
.44904 .25139 .45825 .26211 .47434 .25632 .46519 .24554 Mtetra
.46519 .24554 .47434 .25632 .49052 .2505 .48143 .23965 Mtetra
.48143 .23965 .49052 .2505 .5068 .24464 .49778 .23373 Mtetra
.49778 .23373 .5068 .24464 .52318 .23874 .51422 .22777 Mtetra
.51422 .22777 .52318 .23874 .53965 .23281 .53076 .22177 Mtetra
.53076 .22177 .53965 .23281 .55622 .22685 .5474 .21574 Mtetra
.5474 .21574 .55622 .22685 .5729 .22085 .56414 .20967 Mtetra
.56414 .20967 .5729 .22085 .58967 .21481 .58098 .20357 Mtetra
.58098 .20357 .58967 .21481 .60655 .20873 .59792 .19742 Mtetra
.59792 .19742 .60655 .20873 .62353 .20262 .61497 .19124 Mtetra
.61497 .19124 .62353 .20262 .64061 .19647 .63212 .18502 Mtetra
.63212 .18502 .64061 .19647 .6578 .19029 .64938 .17877 Mtetra
.64938 .17877 .6578 .19029 .67509 .18406 .66675 .17247 Mtetra
.66675 .17247 .67509 .18406 .69249 .1778 .68422 .16614 Mtetra
.68422 .16614 .69249 .1778 .70999 .1715 .7018 .15976 Mtetra
.7018 .15976 .70999 .1715 .72761 .16516 .71949 .15335 Mtetra
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Mtetra
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.13472 .35194 .14508 .36159 .15947 .35637 .14915 .34667 Mtetra
.14915 .34667 .15947 .35637 .17394 .35113 .16366 .34137 Mtetra
.16366 .34137 .17394 .35113 .18849 .34585 .17826 .33604 Mtetra
.17826 .33604 .18849 .34585 .20312 .34055 .19294 .33068 Mtetra
.19294 .33068 .20312 .34055 .21783 .33521 .2077 .32529 Mtetra
.2077 .32529 .21783 .33521 .23263 .32985 .22255 .31986 Mtetra
.22255 .31986 .23263 .32985 .24752 .32445 .23748 .31441 Mtetra
.23748 .31441 .24752 .32445 .26248 .31903 .2525 .30893 Mtetra
.2525 .30893 .26248 .31903 .27754 .31357 .26761 .30341 Mtetra
.26761 .30341 .27754 .31357 .29268 .30808 .2828 .29786 Mtetra
.2828 .29786 .29268 .30808 .30791 .30256 .29809 .29228 Mtetra
.29809 .29228 .30791 .30256 .32323 .29701 .31346 .28667 Mtetra
.31346 .28667 .32323 .29701 .33863 .29142 .32892 .28102 Mtetra
.32892 .28102 .33863 .29142 .35413 .2858 .34447 .27534 Mtetra
.34447 .27534 .35413 .2858 .36972 .28015 .36011 .26963 Mtetra
.36011 .26963 .36972 .28015 .3854 .27447 .37585 .26389 Mtetra
.37585 .26389 .3854 .27447 .40117 .26875 .39168 .25811 Mtetra
.39168 .25811 .40117 .26875 .41703 .263 .4076 .25229 Mtetra
.4076 .25229 .41703 .263 .43299 .25721 .42362 .24644 Mtetra
.42362 .24644 .43299 .25721 .44904 .25139 .43973 .24056 Mtetra
.43973 .24056 .44904 .25139 .46519 .24554 .45594 .23464 Mtetra
.45594 .23464 .46519 .24554 .48143 .23965 .47225 .22869 Mtetra
.47225 .22869 .48143 .23965 .49778 .23373 .48865 .2227 Mtetra
.48865 .2227 .49778 .23373 .51422 .22777 .50516 .21667 Mtetra
.50516 .21667 .51422 .22777 .53076 .22177 .52176 .21061 Mtetra
.52176 .21061 .53076 .22177 .5474 .21574 .53847 .20451 Mtetra
.53847 .20451 .5474 .21574 .56414 .20967 .55527 .19837 Mtetra
.55527 .19837 .56414 .20967 .58098 .20357 .57218 .1922 Mtetra
.57218 .1922 .58098 .20357 .59792 .19742 .5892 .18598 Mtetra
.5892 .18598 .59792 .19742 .61497 .19124 .60632 .17973 Mtetra
.60632 .17973 .61497 .19124 .63212 .18502 .62354 .17344 Mtetra
.62354 .17344 .63212 .18502 .64938 .17877 .64087 .16711 Mtetra
.64087 .16711 .64938 .17877 .66675 .17247 .65831 .16075 Mtetra
.65831 .16075 .66675 .17247 .68422 .16614 .67586 .15434 Mtetra
.67586 .15434 .68422 .16614 .7018 .15976 .69351 .14789 Mtetra
.69351 .14789 .7018 .15976 .71949 .15335 .71128 .14141 Mtetra
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Mtetra
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Mtetra
.12424 .34218 .13472 .35194 .14915 .34667 .13872 .33686 Mtetra
.13872 .33686 .14915 .34667 .16366 .34137 .15328 .3315 Mtetra
.15328 .3315 .16366 .34137 .17826 .33604 .16793 .32612 Mtetra
.16793 .32612 .17826 .33604 .19294 .33068 .18265 .3207 Mtetra
.18265 .3207 .19294 .33068 .2077 .32529 .19747 .31525 Mtetra
.19747 .31525 .2077 .32529 .22255 .31986 .21236 .30977 Mtetra
.21236 .30977 .22255 .31986 .23748 .31441 .22735 .30426 Mtetra
.22735 .30426 .23748 .31441 .2525 .30893 .24242 .29872 Mtetra
.24242 .29872 .2525 .30893 .26761 .30341 .25758 .29314 Mtetra
.25758 .29314 .26761 .30341 .2828 .29786 .27282 .28753 Mtetra
.27282 .28753 .2828 .29786 .29809 .29228 .28816 .28189 Mtetra
.28816 .28189 .29809 .29228 .31346 .28667 .30358 .27622 Mtetra
.30358 .27622 .31346 .28667 .32892 .28102 .3191 .27051 Mtetra
.3191 .27051 .32892 .28102 .34447 .27534 .33471 .26477 Mtetra
.33471 .26477 .34447 .27534 .36011 .26963 .35041 .259 Mtetra
.35041 .259 .36011 .26963 .37585 .26389 .3662 .25319 Mtetra
.3662 .25319 .37585 .26389 .39168 .25811 .38209 .24735 Mtetra
.38209 .24735 .39168 .25811 .4076 .25229 .39807 .24147 Mtetra
.39807 .24147 .4076 .25229 .42362 .24644 .41415 .23555 Mtetra
.41415 .23555 .42362 .24644 .43973 .24056 .43032 .22961 Mtetra
.43032 .22961 .43973 .24056 .45594 .23464 .44659 .22362 Mtetra
.44659 .22362 .45594 .23464 .47225 .22869 .46296 .2176 Mtetra
.46296 .2176 .47225 .22869 .48865 .2227 .47943 .21154 Mtetra
.47943 .21154 .48865 .2227 .50516 .21667 .496 .20545 Mtetra
.496 .20545 .50516 .21667 .52176 .21061 .51267 .19932 Mtetra
.51267 .19932 .52176 .21061 .53847 .20451 .52944 .19315 Mtetra
.52944 .19315 .53847 .20451 .55527 .19837 .54631 .18694 Mtetra
.54631 .18694 .55527 .19837 .57218 .1922 .56329 .1807 Mtetra
.56329 .1807 .57218 .1922 .5892 .18598 .58037 .17441 Mtetra
.58037 .17441 .5892 .18598 .60632 .17973 .59756 .16809 Mtetra
.59756 .16809 .60632 .17973 .62354 .17344 .61486 .16173 Mtetra
.61486 .16173 .62354 .17344 .64087 .16711 .63226 .15533 Mtetra
.63226 .15533 .64087 .16711 .65831 .16075 .64977 .14889 Mtetra
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Mtetra
.6674 .14241 .67586 .15434 .69351 .14789 .68513 .13588 Mtetra
.68513 .13588 .69351 .14789 .71128 .14141 .70297 .12932 Mtetra
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.11366 .33233 .12424 .34218 .13872 .33686 .12818 .32695 Mtetra
.12818 .32695 .13872 .33686 .15328 .3315 .14279 .32154 Mtetra
.14279 .32154 .15328 .3315 .16793 .32612 .15748 .31609 Mtetra
.15748 .31609 .16793 .32612 .18265 .3207 .17226 .31062 Mtetra
.17226 .31062 .18265 .3207 .19747 .31525 .18712 .30511 Mtetra
.18712 .30511 .19747 .31525 .21236 .30977 .20207 .29957 Mtetra
.20207 .29957 .21236 .30977 .22735 .30426 .2171 .294 Mtetra
.2171 .294 .22735 .30426 .24242 .29872 .23222 .2884 Mtetra
.23222 .2884 .24242 .29872 .25758 .29314 .24743 .28276 Mtetra
.24743 .28276 .25758 .29314 .27282 .28753 .26273 .2771 Mtetra
.26273 .2771 .27282 .28753 .28816 .28189 .27812 .27139 Mtetra
.27812 .27139 .28816 .28189 .30358 .27622 .2936 .26566 Mtetra
.2936 .26566 .30358 .27622 .3191 .27051 .30917 .25989 Mtetra
.30917 .25989 .3191 .27051 .33471 .26477 .32484 .25409 Mtetra
.32484 .25409 .33471 .26477 .35041 .259 .34059 .24825 Mtetra
.34059 .24825 .35041 .259 .3662 .25319 .35644 .24237 Mtetra
.35644 .24237 .3662 .25319 .38209 .24735 .37239 .23647 Mtetra
.37239 .23647 .38209 .24735 .39807 .24147 .38843 .23052 Mtetra
.38843 .23052 .39807 .24147 .41415 .23555 .40457 .22454 Mtetra
.40457 .22454 .41415 .23555 .43032 .22961 .4208 .21853 Mtetra
.4208 .21853 .43032 .22961 .44659 .22362 .43714 .21248 Mtetra
.43714 .21248 .44659 .22362 .46296 .2176 .45357 .20639 Mtetra
.45357 .20639 .46296 .2176 .47943 .21154 .4701 .20026 Mtetra
.4701 .20026 .47943 .21154 .496 .20545 .48673 .1941 Mtetra
.48673 .1941 .496 .20545 .51267 .19932 .50347 .1879 Mtetra
.50347 .1879 .51267 .19932 .52944 .19315 .52031 .18166 Mtetra
.52031 .18166 .52944 .19315 .54631 .18694 .53725 .17538 Mtetra
.53725 .17538 .54631 .18694 .56329 .1807 .5543 .16907 Mtetra
.5543 .16907 .56329 .1807 .58037 .17441 .57145 .16271 Mtetra
.57145 .16271 .58037 .17441 .59756 .16809 .58871 .15632 Mtetra
.58871 .15632 .59756 .16809 .61486 .16173 .60608 .14988 Mtetra
.60608 .14988 .61486 .16173 .63226 .15533 .62355 .14341 Mtetra
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Mtetra
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Mtetra
.65884 .13033 .6674 .14241 .68513 .13588 .67665 .12373 Mtetra
.67665 .12373 .68513 .13588 .70297 .12932 .69457 .11709 Mtetra
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.10296 .32237 .11366 .33233 .12818 .32695 .11753 .31693 Mtetra
.11753 .31693 .12818 .32695 .14279 .32154 .13219 .31146 Mtetra
.13219 .31146 .14279 .32154 .15748 .31609 .14693 .30596 Mtetra
.14693 .30596 .15748 .31609 .17226 .31062 .16175 .30043 Mtetra
.16175 .30043 .17226 .31062 .18712 .30511 .17666 .29486 Mtetra
.17666 .29486 .18712 .30511 .20207 .29957 .19166 .28926 Mtetra
.19166 .28926 .20207 .29957 .2171 .294 .20674 .28363 Mtetra
.20674 .28363 .2171 .294 .23222 .2884 .22192 .27797 Mtetra
.22192 .27797 .23222 .2884 .24743 .28276 .23718 .27227 Mtetra
.23718 .27227 .24743 .28276 .26273 .2771 .25253 .26654 Mtetra
.25253 .26654 .26273 .2771 .27812 .27139 .26797 .26078 Mtetra
.26797 .26078 .27812 .27139 .2936 .26566 .28351 .25498 Mtetra
.28351 .25498 .2936 .26566 .30917 .25989 .29914 .24915 Mtetra
.29914 .24915 .30917 .25989 .32484 .25409 .31485 .24328 Mtetra
.31485 .24328 .32484 .25409 .34059 .24825 .33067 .23738 Mtetra
.33067 .23738 .34059 .24825 .35644 .24237 .34658 .23144 Mtetra
.34658 .23144 .35644 .24237 .37239 .23647 .36258 .22547 Mtetra
.36258 .22547 .37239 .23647 .38843 .23052 .37868 .21946 Mtetra
.37868 .21946 .38843 .23052 .40457 .22454 .39488 .21341 Mtetra
.39488 .21341 .40457 .22454 .4208 .21853 .41118 .20733 Mtetra
.41118 .20733 .4208 .21853 .43714 .21248 .42757 .20121 Mtetra
.42757 .20121 .43714 .21248 .45357 .20639 .44407 .19505 Mtetra
.44407 .19505 .45357 .20639 .4701 .20026 .46067 .18886 Mtetra
.46067 .18886 .4701 .20026 .48673 .1941 .47737 .18262 Mtetra
.47737 .18262 .48673 .1941 .50347 .1879 .49417 .17635 Mtetra
.49417 .17635 .50347 .1879 .52031 .18166 .51107 .17004 Mtetra
.51107 .17004 .52031 .18166 .53725 .17538 .52808 .16369 Mtetra
.52808 .16369 .53725 .17538 .5543 .16907 .5452 .1573 Mtetra
.5452 .1573 .5543 .16907 .57145 .16271 .56242 .15087 Mtetra
.56242 .15087 .57145 .16271 .58871 .15632 .57976 .1444 Mtetra
.57976 .1444 .58871 .15632 .60608 .14988 .5972 .1379 Mtetra
.5972 .1379 .60608 .14988 .62355 .14341 .61475 .13134 Mtetra
.61475 .13134 .62355 .14341 .64114 .13689 .63241 .12475 Mtetra
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Mtetra
.65018 .11812 .65884 .13033 .67665 .12373 .66806 .11144 Mtetra
.66806 .11144 .67665 .12373 .69457 .11709 .68606 .10472 Mtetra
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Mtetra
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.09215 .3123 .10296 .32237 .11753 .31693 .10677 .30681 Mtetra
.10677 .30681 .11753 .31693 .13219 .31146 .12147 .30128 Mtetra
.12147 .30128 .13219 .31146 .14693 .30596 .13626 .29572 Mtetra
.13626 .29572 .14693 .30596 .16175 .30043 .15113 .29013 Mtetra
.15113 .29013 .16175 .30043 .17666 .29486 .16609 .2845 Mtetra
.16609 .2845 .17666 .29486 .19166 .28926 .18114 .27884 Mtetra
.18114 .27884 .19166 .28926 .20674 .28363 .19627 .27315 Mtetra
.19627 .27315 .20674 .28363 .22192 .27797 .2115 .26743 Mtetra
.2115 .26743 .22192 .27797 .23718 .27227 .22681 .26167 Mtetra
.22681 .26167 .23718 .27227 .25253 .26654 .24222 .25587 Mtetra
.24222 .25587 .25253 .26654 .26797 .26078 .25772 .25005 Mtetra
.25772 .25005 .26797 .26078 .28351 .25498 .27331 .24418 Mtetra
.27331 .24418 .28351 .25498 .29914 .24915 .28899 .23829 Mtetra
.28899 .23829 .29914 .24915 .31485 .24328 .30476 .23236 Mtetra
.30476 .23236 .31485 .24328 .33067 .23738 .32064 .22639 Mtetra
.32064 .22639 .33067 .23738 .34658 .23144 .3366 .22038 Mtetra
.3366 .22038 .34658 .23144 .36258 .22547 .35267 .21434 Mtetra
.35267 .21434 .36258 .22547 .37868 .21946 .36883 .20827 Mtetra
.36883 .20827 .37868 .21946 .39488 .21341 .38509 .20215 Mtetra
.38509 .20215 .39488 .21341 .41118 .20733 .40145 .196 Mtetra
.40145 .196 .41118 .20733 .42757 .20121 .4179 .18981 Mtetra
.4179 .18981 .42757 .20121 .44407 .19505 .43446 .18358 Mtetra
.43446 .18358 .44407 .19505 .46067 .18886 .45113 .17732 Mtetra
.45113 .17732 .46067 .18886 .47737 .18262 .46789 .17101 Mtetra
.46789 .17101 .47737 .18262 .49417 .17635 .48476 .16467 Mtetra
.48476 .16467 .49417 .17635 .51107 .17004 .50173 .15829 Mtetra
.50173 .15829 .51107 .17004 .52808 .16369 .51881 .15187 Mtetra
.51881 .15187 .52808 .16369 .5452 .1573 .536 .1454 Mtetra
.536 .1454 .5452 .1573 .56242 .15087 .55329 .1389 Mtetra
.55329 .1389 .56242 .15087 .57976 .1444 .5707 .13236 Mtetra
.5707 .13236 .57976 .1444 .5972 .1379 .58821 .12577 Mtetra
.58821 .12577 .5972 .1379 .61475 .13134 .60583 .11914 Mtetra
.60583 .11914 .61475 .13134 .63241 .12475 .62357 .11247 Mtetra
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Mtetra
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Mtetra
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Mtetra
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Mtetra
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.08123 .30213 .09215 .3123 .10677 .30681 .09589 .29658 Mtetra
.09589 .29658 .10677 .30681 .12147 .30128 .11064 .29099 Mtetra
.11064 .29099 .12147 .30128 .13626 .29572 .12548 .28537 Mtetra
.12548 .28537 .13626 .29572 .15113 .29013 .1404 .27972 Mtetra
.1404 .27972 .15113 .29013 .16609 .2845 .15541 .27403 Mtetra
.15541 .27403 .16609 .2845 .18114 .27884 .1705 .26831 Mtetra
.1705 .26831 .18114 .27884 .19627 .27315 .18569 .26256 Mtetra
.18569 .26256 .19627 .27315 .2115 .26743 .20097 .25677 Mtetra
.20097 .25677 .2115 .26743 .22681 .26167 .21634 .25095 Mtetra
.21634 .25095 .22681 .26167 .24222 .25587 .23179 .24509 Mtetra
.23179 .24509 .24222 .25587 .25772 .25005 .24735 .2392 Mtetra
.24735 .2392 .25772 .25005 .27331 .24418 .26299 .23327 Mtetra
.26299 .23327 .27331 .24418 .28899 .23829 .27873 .22731 Mtetra
.27873 .22731 .28899 .23829 .30476 .23236 .29456 .22131 Mtetra
.29456 .22131 .30476 .23236 .32064 .22639 .31049 .21527 Mtetra
.31049 .21527 .32064 .22639 .3366 .22038 .32652 .2092 Mtetra
.32652 .2092 .3366 .22038 .35267 .21434 .34264 .20309 Mtetra
.34264 .20309 .35267 .21434 .36883 .20827 .35886 .19695 Mtetra
.35886 .19695 .36883 .20827 .38509 .20215 .37518 .19077 Mtetra
.37518 .19077 .38509 .20215 .40145 .196 .3916 .18454 Mtetra
.3916 .18454 .40145 .196 .4179 .18981 .40812 .17828 Mtetra
.40812 .17828 .4179 .18981 .43446 .18358 .42475 .17199 Mtetra
.42475 .17199 .43446 .18358 .45113 .17732 .44148 .16565 Mtetra
.44148 .16565 .45113 .17732 .46789 .17101 .45831 .15927 Mtetra
.45831 .15927 .46789 .17101 .48476 .16467 .47524 .15286 Mtetra
.47524 .15286 .48476 .16467 .50173 .15829 .49228 .1464 Mtetra
.49228 .1464 .50173 .15829 .51881 .15187 .50943 .1399 Mtetra
.50943 .1399 .51881 .15187 .536 .1454 .52669 .13336 Mtetra
.52669 .13336 .536 .1454 .55329 .1389 .54406 .12679 Mtetra
.54406 .12679 .55329 .1389 .5707 .13236 .56153 .12016 Mtetra
.56153 .12016 .5707 .13236 .58821 .12577 .57912 .1135 Mtetra
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Mtetra
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Mtetra
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Mtetra
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Mtetra
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Mtetra
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Mtetra
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Mtetra
.07019 .29185 .08123 .30213 .09589 .29658 .0849 .28624 Mtetra
.0849 .28624 .09589 .29658 .11064 .29099 .09969 .28059 Mtetra
.09969 .28059 .11064 .29099 .12548 .28537 .11458 .27491 Mtetra
.11458 .27491 .12548 .28537 .1404 .27972 .12955 .26919 Mtetra
.12955 .26919 .1404 .27972 .15541 .27403 .14461 .26344 Mtetra
.14461 .26344 .15541 .27403 .1705 .26831 .15975 .25766 Mtetra
.15975 .25766 .1705 .26831 .18569 .26256 .17499 .25184 Mtetra
.17499 .25184 .18569 .26256 .20097 .25677 .19032 .24599 Mtetra
.19032 .24599 .20097 .25677 .21634 .25095 .20574 .24011 Mtetra
.20574 .24011 .21634 .25095 .23179 .24509 .22125 .23418 Mtetra
.22125 .23418 .23179 .24509 .24735 .2392 .23686 .22823 Mtetra
.23686 .22823 .24735 .2392 .26299 .23327 .25256 .22223 Mtetra
.25256 .22223 .26299 .23327 .27873 .22731 .26835 .2162 Mtetra
.26835 .2162 .27873 .22731 .29456 .22131 .28424 .21014 Mtetra
.28424 .21014 .29456 .22131 .31049 .21527 .30023 .20404 Mtetra
.30023 .20404 .31049 .21527 .32652 .2092 .31632 .1979 Mtetra
.31632 .1979 .32652 .2092 .34264 .20309 .3325 .19172 Mtetra
.3325 .19172 .34264 .20309 .35886 .19695 .34878 .1855 Mtetra
.34878 .1855 .35886 .19695 .37518 .19077 .36516 .17925 Mtetra
.36516 .17925 .37518 .19077 .3916 .18454 .38165 .17296 Mtetra
.38165 .17296 .3916 .18454 .40812 .17828 .39823 .16663 Mtetra
.39823 .16663 .40812 .17828 .42475 .17199 .41492 .16026 Mtetra
.41492 .16026 .42475 .17199 .44148 .16565 .43171 .15385 Mtetra
.43171 .15385 .44148 .16565 .45831 .15927 .44861 .1474 Mtetra
.44861 .1474 .45831 .15927 .47524 .15286 .46562 .1409 Mtetra
.46562 .1409 .47524 .15286 .49228 .1464 .48273 .13437 Mtetra
.48273 .13437 .49228 .1464 .50943 .1399 .49994 .1278 Mtetra
.49994 .1278 .50943 .1399 .52669 .13336 .51727 .12119 Mtetra
.51727 .12119 .52669 .13336 .54406 .12679 .53471 .11453 Mtetra
.53471 .11453 .54406 .12679 .56153 .12016 .55226 .10783 Mtetra
.55226 .10783 .56153 .12016 .57912 .1135 .56992 .10109 Mtetra
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Mtetra
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Mtetra
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Mtetra
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Mtetra
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Mtetra
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Mtetra
.05902 .28146 .07019 .29185 .0849 .28624 .07378 .27578 Mtetra
.07378 .27578 .0849 .28624 .09969 .28059 .08863 .27007 Mtetra
.08863 .27007 .09969 .28059 .11458 .27491 .10356 .26433 Mtetra
.10356 .26433 .11458 .27491 .12955 .26919 .11858 .25855 Mtetra
.11858 .25855 .12955 .26919 .14461 .26344 .13369 .25274 Mtetra
.13369 .25274 .14461 .26344 .15975 .25766 .14889 .24689 Mtetra
.14889 .24689 .15975 .25766 .17499 .25184 .16417 .24101 Mtetra
.16417 .24101 .17499 .25184 .19032 .24599 .17956 .2351 Mtetra
.17956 .2351 .19032 .24599 .20574 .24011 .19503 .22915 Mtetra
.19503 .22915 .20574 .24011 .22125 .23418 .2106 .22316 Mtetra
.2106 .22316 .22125 .23418 .23686 .22823 .22626 .21713 Mtetra
.22626 .21713 .23686 .22823 .25256 .22223 .24201 .21107 Mtetra
.24201 .21107 .25256 .22223 .26835 .2162 .25786 .20498 Mtetra
.25786 .20498 .26835 .2162 .28424 .21014 .27381 .19884 Mtetra
.27381 .19884 .28424 .21014 .30023 .20404 .28986 .19267 Mtetra
.28986 .19267 .30023 .20404 .31632 .1979 .306 .18646 Mtetra
.306 .18646 .31632 .1979 .3325 .19172 .32224 .18021 Mtetra
.32224 .18021 .3325 .19172 .34878 .1855 .33859 .17393 Mtetra
.33859 .17393 .34878 .1855 .36516 .17925 .35503 .1676 Mtetra
.35503 .1676 .36516 .17925 .38165 .17296 .37158 .16124 Mtetra
.37158 .16124 .38165 .17296 .39823 .16663 .38823 .15483 Mtetra
.38823 .15483 .39823 .16663 .41492 .16026 .40498 .14839 Mtetra
.40498 .14839 .41492 .16026 .43171 .15385 .42184 .14191 Mtetra
.42184 .14191 .43171 .15385 .44861 .1474 .4388 .13538 Mtetra
.4388 .13538 .44861 .1474 .46562 .1409 .45588 .12881 Mtetra
.45588 .12881 .46562 .1409 .48273 .13437 .47306 .12221 Mtetra
.47306 .12221 .48273 .13437 .49994 .1278 .49034 .11556 Mtetra
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Mtetra
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Mtetra
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Mtetra
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Mtetra
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Mtetra
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Mtetra
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Mtetra
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Mtetra
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Mtetra
.04774 .27095 .05902 .28146 .07378 .27578 .06255 .26522 Mtetra
.06255 .26522 .07378 .27578 .08863 .27007 .07744 .25944 Mtetra
.07744 .25944 .08863 .27007 .10356 .26433 .09242 .25364 Mtetra
.09242 .25364 .10356 .26433 .11858 .25855 .10749 .2478 Mtetra
.10749 .2478 .11858 .25855 .13369 .25274 .12265 .24192 Mtetra
.12265 .24192 .13369 .25274 .14889 .24689 .1379 .23601 Mtetra
.1379 .23601 .14889 .24689 .16417 .24101 .15324 .23006 Mtetra
.15324 .23006 .16417 .24101 .17956 .2351 .16867 .22408 Mtetra
.16867 .22408 .17956 .2351 .19503 .22915 .1842 .21806 Mtetra
.1842 .21806 .19503 .22915 .2106 .22316 .19982 .21201 Mtetra
.19982 .21201 .2106 .22316 .22626 .21713 .21553 .20592 Mtetra
.21553 .20592 .22626 .21713 .24201 .21107 .23135 .19979 Mtetra
.23135 .19979 .24201 .21107 .25786 .20498 .24725 .19362 Mtetra
.24725 .19362 .25786 .20498 .27381 .19884 .26326 .18742 Mtetra
.26326 .18742 .27381 .19884 .28986 .19267 .27936 .18118 Mtetra
.27936 .18118 .28986 .19267 .306 .18646 .29557 .1749 Mtetra
.29557 .1749 .306 .18646 .32224 .18021 .31187 .16858 Mtetra
.31187 .16858 .32224 .18021 .33859 .17393 .32828 .16222 Mtetra
.32828 .16222 .33859 .17393 .35503 .1676 .34478 .15582 Mtetra
.34478 .15582 .35503 .1676 .37158 .16124 .36139 .14938 Mtetra
.36139 .14938 .37158 .16124 .38823 .15483 .37811 .14291 Mtetra
.37811 .14291 .38823 .15483 .40498 .14839 .39493 .13639 Mtetra
.39493 .13639 .40498 .14839 .42184 .14191 .41185 .12983 Mtetra
.41185 .12983 .42184 .14191 .4388 .13538 .42888 .12323 Mtetra
.42888 .12323 .4388 .13538 .45588 .12881 .44602 .11658 Mtetra
.44602 .11658 .45588 .12881 .47306 .12221 .46327 .1099 Mtetra
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Mtetra
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Mtetra
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Mtetra
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Mtetra
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Mtetra
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Mtetra
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Mtetra
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Mtetra
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Mtetra
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.03634 .26033 .04774 .27095 .06255 .26522 .05119 .25453 Mtetra
.05119 .25453 .06255 .26522 .07744 .25944 .06613 .2487 Mtetra
.06613 .2487 .07744 .25944 .09242 .25364 .08116 .24283 Mtetra
.08116 .24283 .09242 .25364 .10749 .2478 .09628 .23692 Mtetra
.09628 .23692 .10749 .2478 .12265 .24192 .11148 .23098 Mtetra
.11148 .23098 .12265 .24192 .1379 .23601 .12679 .225 Mtetra
.12679 .225 .1379 .23601 .15324 .23006 .14218 .21899 Mtetra
.14218 .21899 .15324 .23006 .16867 .22408 .15767 .21294 Mtetra
.15767 .21294 .16867 .22408 .1842 .21806 .17325 .20686 Mtetra
.17325 .20686 .1842 .21806 .19982 .21201 .18892 .20073 Mtetra
.18892 .20073 .19982 .21201 .21553 .20592 .20469 .19457 Mtetra
.20469 .19457 .21553 .20592 .23135 .19979 .22056 .18838 Mtetra
.22056 .18838 .23135 .19979 .24725 .19362 .23652 .18214 Mtetra
.23652 .18214 .24725 .19362 .26326 .18742 .25259 .17587 Mtetra
.25259 .17587 .26326 .18742 .27936 .18118 .26875 .16955 Mtetra
.26875 .16955 .27936 .18118 .29557 .1749 .28501 .1632 Mtetra
.28501 .1632 .29557 .1749 .31187 .16858 .30138 .15681 Mtetra
.30138 .15681 .31187 .16858 .32828 .16222 .31785 .15038 Mtetra
.31785 .15038 .32828 .16222 .34478 .15582 .33442 .14391 Mtetra
.33442 .14391 .34478 .15582 .36139 .14938 .35109 .13739 Mtetra
.35109 .13739 .36139 .14938 .37811 .14291 .36787 .13084 Mtetra
.36787 .13084 .37811 .14291 .39493 .13639 .38475 .12424 Mtetra
.38475 .12424 .39493 .13639 .41185 .12983 .40174 .11761 Mtetra
.40174 .11761 .41185 .12983 .42888 .12323 .41884 .11093 Mtetra
.41884 .11093 .42888 .12323 .44602 .11658 .43605 .10421 Mtetra
.43605 .10421 .44602 .11658 .46327 .1099 .45337 .09744 Mtetra
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Mtetra
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Mtetra
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Mtetra
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Mtetra
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Mtetra
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Mtetra
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Mtetra
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Mtetra
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Mtetra
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`006P3ooonDo`0003<0ooooU?l0000K0?ooo`006P3o
ool00ol00000oooo0?ooo`2@0?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0T03o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2@0?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool0T03oool00ol00000oooo0?ooo`0I0?ooo`006P3oool01ol0
0000oooo0?ooo`3oool000000?ooool000000P3oool00`000000oooo00000005000000030?ooo`00
0000000007l0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2@0?ooo`03o`00003o
ool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo00806ATI00D0000003<c<ol00000C4a<0000
000406IVIPD0000000<06ATI00000?l00000N_l000030?ooo`03o`00003oool0oooo0340oooo00?o
00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`04o`00003oool0
ooooo`0000806ATI0P0000000`1<C4`0000006IVIP0206IVIP;o000000<0IVIV0000000000000P00
00000`0I6AT000000000001io`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?oo
o`2=o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00Go00000?ooo`3ooooo00000000
000201TI6@<0000000<0IVIVo`000?l000000P1oOgl2o`0000<0000000Co000001TI6@0I6AT00000
N?l000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00
003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo00;o000000D0000001TI6@0000000000
04a<C002o`0000D0Ogmo0_l000001P000000<c<c0000000000006ATI000007Oo00000`3oool00ol0
0000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00ol00000oooo0?ooo`03o`0000030000000I6AT000000080000000<0IVIVo`00001o
Ogl00`1oOgl3o`0000060000000c<c<0<c<c0000000I6AT00000M_l000030?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?oo
o`03o`00003oool0oooo00Go000000D0000003<c<`0000000000o`00000307moO`03o`00002IVIT0
VIVI00?o000000D0000003<c<`0000006ATI0000001eo`0000<0oooo00?o00000?ooo`3oool0<@3o
ool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o0000
0?ooo`3oool01?l000000`0000006ATI00000002o`00000500000?l00000Ogmoo`00002IVIT01_l0
00030000000301TI6@00003o000007?o00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003o
ool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`05
o`0000030000000I6AT06ATI00<000000_l00000102IVIWo00000;>c/`2c/k<4o`0000<0000000<0
6ATIo`0000000000L_l000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl0
00030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo00Ko000000<00000
01TI6@0I6AT00`000003o`0000<0/k>c1?l00003000000806ATI00<00000o`000?l00000Kol00003
0?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0
oooo01T0oooo000J0?ooo`03o`00003oool0oooo00So000000@0000001TI6@00000000001?l00000
0`2c/k?o0000o`000002000000?o000000D00000o`00000000006ATI0000001`o`0000<0oooo00?o
00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00?o00000?ooo`3oool02?l000000`0000006ATI00000002000000?o000000<0/k>c
0000003<c<`00P3<c<`00`00003o0000o`0000040000000301TI6Ol0003o000006ko00000`3oool0
0ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00ol00000oooo0?ooo`09o`0000030000000I6AT00000008000000ol000000`2c
/k<000000<c<c0020<c<c080000000?o00000000000000000P0000000`0I6AT00000o`00001]o`00
00<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool02_l000000`0000006ATI00000002000000?o
000000<000000<c<c03<c<`00ol000000`00003o0000o`000005000006go00000`3oool00ol00000
oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`00
6P3oool00ol00000oooo0?ooo`0;o`0000040000000I6AT00000000000Ko00000`3Vi^H5o`0000@0
0000K?l000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03
o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo00co00000P0000000`0c<c<00000
o`000002o`0000030;>c/`00003o000000<0i^KV00?o000000000?l000000_l00000101<C4`00000
00000000001[o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0
oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool03Ol00004000000?o0000
00<0/k>c00000?l000000`3Vi^H00ol00000000000000002o`00000404a<C00000000000000006[o
00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000
oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0?o`00000301TI6@000000000000?o0000
00@0/k>co`00003Vi^H0i^KV0ol000001P3<c<co0000o`000?l00000C4a<o`0000800000JOl00003
0?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0
oooo01T0oooo000J0?ooo`03o`00003oool0oooo00oo000000@0000001TI6@00000000001_l00002
0?ooo`?o000000H00000o`000?l0003o000000000?l00002000006Oo00000`3oool00ol00000oooo
0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3o
ool00ol00000oooo0?ooo`0@o`0000050000000I6AWo000003<c<`0000000_l000001000003o0000
o`000?l000020?ooo`;o00000P0000001_l0000000000000000000006ATI000006Ko00000`3oool0
0ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00ol00000oooo0?ooo`0Ao`0000050000000I6AT0000003<c<`0000000_l00000
1000003o0000o`000?l000020?ooo`;o000000P0c<c<o`000?l000000000o`00000000006ATI0000
06Go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol0
0000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Co`000080000000D0<c<c00000?l0
003o000000000003o`000080oooo0_l000000`00003o0000o`0000030000000301TI6@00003o0000
06?o00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol0
0000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Do`0000@000000ol000000`00003o
0000o`0000020?ooo`;o000000<00000o`000?l000000`0000000`0I6AT00000o`00001Ro`0000<0
oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3o
ool06@3oool001X0oooo00?o00000?ooo`3oool05Ol00004000000?o000000<00000o`000?l00000
0P3oool2o`00000300000?l0003o000000<0000000<06ATI00000?l00000HOl000030?ooo`03o`00
003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo
000J0?ooo`03o`00003oool0oooo01Oo000010000002o`00000600000?l0003o00000?ooool00000
i^KV1?l000001@00003o00000000000I6AT00000067o00000`3oool00ol00000oooo0?ooo`0a0?oo
o`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000
oooo0?ooo`0Fo`0000060000000I6AT0000000000?l0000000001ol000000`3Vi^Ko000000000002
o`0000<0000000<06ATIo`000?l00000Gol000030?ooo`03o`00003oool0oooo0340oooo00?o0000
0?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo
01Oo000000@0000001TI6Ol00000<c<c0P0000001Ol00000VIVIo`000000003o00000080i^KV00?o
000000000?l000000_l00002000000806ATI00<00000o`000?l00000GOl000030?ooo`03o`00003o
ool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J
0?ooo`03o`00003oool0oooo01So000000@0000001TI6@000000<c<c0P0000002Ol00000VIVIo`00
0000003o00000>KVi_l00000c<c<00000003o`0000<0000000<06ATI00000?l00000GOl000030?oo
o`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo
01T0oooo000J0?ooo`03o`00003oool0oooo01[o000000<06ATI0000000c<c<00P0000002?l00000
VIVI0000003<c<co00000>KVi_l00000c<c<0P000003o`00000403<c<`0000006ATI000005go0000
0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo
0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Jo`0000<000000_l000000`00003o0000o`00
0002000000?o000000<0c<c<00000?l000000_l000001@000000<c<c00000?l00000000005co0000
0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo
0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Lo`0000030000000I6AT06ATI00<000000_l0
000200000080c<c<00<00000o`000?l000000_l00002000000806ATI00<00000o`000?l00000FOl0
00030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003o
ool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01go00000P000000100I6AT0000000000000
0003o`000080000000<0c<c<00000?l000000ol000030000000301TI6@00003o000005Wo00000`3o
ool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Oo`0000050000000I6AT00000o`00000000001?l0
00001@00003o00000;>c/ol00000VIVI00?o00000P0000000`0I6AT00000o`00001Ho`0000<0oooo
00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00?o00000?ooo`3oool08?l000001P0000006ATI0000000c<c?o0000000000Co
000000<0/k>co`00002IVIT00_l000020000000303<c<`000000000005Wo00000`3oool00ol00000
oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`00
6P3oool00ol00000oooo0?ooo`0Qo`0000040000000I6AT0000003<c<`8000000_l000000`2IVIWo
0000o`00000209VIV@?o000000@0000003<c<`0000000000F?l000030?ooo`03o`00003oool0oooo
0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
o`00003oool0oooo02;o000000@0000001TI6@000000<c<c0P000002o`00000509VIVOl00000VIVI
09VIVOl000000P1oOgl01Ol0000000000000000I6AT0000005Oo00000`3oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0ol00000oooo0?ooo`0To`00000301TI6Ol000000000008000001ol0000207moO`05o`0000000000
000001TI6@000000E_l000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl0
00030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02Co00000P000000
0`0I6AT00000o`000002000000;o0000101oOgl01ol00000IVIV0000000c<c<0000001TI6@000000
EOl000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00
003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02Ko000000<0000001TI6@0000001000
0002o`00000:07moOol00000IVIV06IVI_l00000000003<c<ol000006ATI000005Co00000`3oool0
0ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00ol00000oooo0?ooo`0Xo`0000806ATI100000000`1VIVKo000006IVIP0306IV
IP80000000@0<c<c0000000I6AT00000Dol000030?ooo`03o`00003oool0oooo0340oooo00?o0000
0?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo
02So000000<0000001TI6@0000000P0c<c<2000000D0IVIV0P000000100c<c<0000001TI6@0I6AUC
o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o0000
0?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0:Ol000001@0000006ATI000000000000
<c<c00@0000000T0IVIV0000001<C4`0C4a<0000000c<c<0000001TI6@000000D_l000030?ooo`03
o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0
oooo000J0?ooo`03o`00003oool0oooo02[o000000<0000001TI6@0I6AT0100000000`1<C4`00000
0000000204a<C0060000000c<c<0<c<c0000000I6AT00000DOl000030?ooo`03o`00003oool0oooo
0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
o`00003oool0oooo02co000000<0000001TI6@0I6AT01000000404a<C0060000000c<c<0<c<c0000
000I6AT00000D?l000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl00003
0?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02go000000H0000001TI
6@0I6AT06ATI0000000c<c<30000000504a<C0000000<c<c03<c<`0000000P0I6AU@o`0000<0oooo
00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00?o00000?ooo`3oool0;_l000001@0000006ATI01TI6@0I6AT0000000<0<c<c
00<0000003<c<`0c<c<00P0c<c<00`0000006ATI0000001?o`0000<0oooo00?o00000?ooo`3oool0
<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o
00000?ooo`3oool0;ol00002000000806ATI00<0000003<c<`0c<c<01@0c<c<0100000006ATI01TI
6@00001>o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0<Ol000020000000301TI6Ol0
0000000000H0<c<c00@0000001TI6@0I6AT00000COl000030?ooo`03o`00003oool0oooo0340oooo
00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003o
ool0oooo03?o00000P000000100I6AT0000000000000000203<c<`050000000I6AT06ATI01TI6@00
0000COl000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03
o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo03Go000000@0000001TI6@0I6AT0
6ATI0P00000501TI6@0300000?l0003o000004[o00000`3oool00ol00000oooo0?ooo`0a0?ooo`03
o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`0fo`00008000002@0I6AT00`00003o0000o`000019o`0000<0oooo00?o00000?ooo`3oool0
<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o
00000?ooo`3oool0>?l00002000000L06ATI00<00000o`000?l00000BOl000030?ooo`03o`00003o
ool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J
0?ooo`03o`00003oool0oooo03[o000000<0000001TI6@0I6AT01@0I6AT00`00003o0000o`000018
o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o0000
0?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0>ol000000`0000006ATI01TI6@0401TI
6@0300000?l0003o000004So00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo
08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0mo`0000<0
00000P0I6AT2000004Wo00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go
00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`10o`0000800000
Bol000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00
003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=
o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?oo
o`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo
01T0oooo000J0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03
o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003o
ool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J
0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0
oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`00
00<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340
oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00
003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go0000
0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o
00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo00?o0000
0?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo
08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol0
0000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3o
ool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo
00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0
SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo08go00000`3o
ool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3oool0
0ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?oo
o`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000
oooo0?ooo`0a0?ooo`03o`00003oool0oooo043o00002`000012o`0000<0oooo00?o00000?ooo`3o
ool06@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo
00?o00000?ooo`3oool0?ol000000`0000006ATI01TI6@0901TI6@<00000?ol000030?ooo`03o`00
003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo03ko000000<0000001TI6@0I6AT03@0I6AT00ol0000000000000
000lo`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0SOl00003
0?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0?_l0000C01TI6@800000>_l00003
0?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo08go00000`3oool00ol0
0000oooo0?ooo`0a0?ooo`03o`00003oool0oooo03go000000<0000001TI6@0I6AT0100I6AT;0000
00@06ATI0`00000go`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3o
ool0SOl000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0?Ol000000`000000
6ATI01TI6@0301TI6@030000000c<c<0<c<c00T0<c<c00?o0000000000000000100I6AT00ol00000
0000o`00000do`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0
SOl000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0?Ol000000`0000006ATI
01TI6@0301TI6@030000000c<c<0<c<c0080<c<c1`00000303<c<`030000000I6AT06ATI00<06ATI
00<00000o`000?l00000<_l000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003o
ool0oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo03go000000<0
000001TI6@0I6AT00`0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<00@0C4a<0`00
0000100c<c<0000000000000000301TI6@0300000?l0003o0000037o00000`3oool00ol00000oooo
0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3o
ool00ol00000oooo0?ooo`0mo`0000030000000I6AT06ATI00806ATI00<0000003<c<`0c<c<00P0c
<c<010000000C4a<04a<C01<C4`6o`00000704a<C000000000000000000c<c<00000o`00000201TI
6@800000<Ol000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo08go
00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo03ko000000D0000001TI6@0I
6AT06ATI0000000303<c<`030000001<C4`0C4a<00;o00001P1VIVH2o`000080C4a<0P0000000`0c
<c<000000000000201TI6@800000;ol000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo03ko
000000D0000001TI6@0I6AT06ATI0000000303<c<`040000001<C4`0C4a<o`000080IVIV1_l00000
1@1VIVKo0000o`000?l00000C4a<0080000000<0<c<c0000000000000P0I6AT2000002go00000`3o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o0000
0?ooo`3oool0<@3oool00ol00000oooo0?ooo`0oo`0000050000000I6AT06ATI01TI6@0000000P0c
<c<00`000000C4a<o`00000206IVIP03o`00001oOgl0Ogmo00@000001ol000000`000000<c<c03<c
<`02000000806ATI0P00000[o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o0000
0?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0@?l00000
2`0000006ATI01TI6@0I6AT0000003<c<`000000C4a<o`00001VIVKo00000080Ogmo00<0000009VI
V@2IVIT00P2IVIT5000000Co00000P0000000`0c<c<000000000000201TI6@0300000?l0003o0000
02So00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0
oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`10o`00000;0000000I6AT06ATI01TI
6@000000<c<c0000001<C4co000006IVI_l000000P1oOgl00`000000VIVIo`000006o`00000309VI
V@000000000000?o000000D0C4a<0000000c<c<0<c<c0000000201TI6@0300000?l0003o000002Oo
00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo
00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`11o`00000:0000000I6AT06ATI01TI6@00
0000<c<c00000?l00000IVIVo`000080Ogmo00<0000009VIVOl000001P2c/k<3o`00000300000?l0
003o000000;o00000P0000001@0c<c<0000001TI6@0I6AT0000002So00000`3oool00ol00000oooo
0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3o
ool00ol00000oooo0?ooo`11o`00000>0000000I6AT06ATI01TI6@000000<c<c0000001<C4co0000
06IVI_l00000Ogmo00000?l000030;>c/`Ko000000/0/k>co`00000000000000o`00001VIVKo0000
04a<C0000000<c<co`00000201TI6BSo00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`13
o`0000<06ATI00Co000003<c<`000000C4a<0_l00000101oOgl00000o`00002c/k<2o`0000H0c<c<
1?l00002000000Co000000@0<c<c0000000I6AT06ATI0P00000Uo`0000<0oooo00?o00000?ooo`3o
ool06@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo
00?o00000?ooo`3oool0@ol000003P0000006ATI01TI6@000000<c<co`00001<C4co000006IVI_l0
00000000o`00002c/k?o00001@3<c<`8o`0000070000001oOgoo0000o`0000000000<c<c00000003
01TI6@0300000?l0003o000002;o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol0
0000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`14o`00
00070000000I6AT06ATI0000000c<c<0000004a<C002o`00000507moO`00003o00000;>c/ol00000
0`3<c<`03?l00000i^KVo`000?l00000i^KVo`00003<c<co00000;>c/ol00000000007moO`;o0000
00<0000003<c<`0000000`0I6AT00`00003o0000o`00000Qo`0000<0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo00?o
00000?ooo`3oool0AOl000001`0000006ATI01TI6@000000<c<c0000001<C4`00_l000001000003o
00000;>c/ol000020<c<c003o`00003Vi^Ko00000080oooo00Co00000>KVi_l00000c<c<0_l00000
1@2IVIT0000007moOol00000C4a<00<000000P0I6AT00`00003o0000o`00000Qo`0000<0oooo00?o
00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool0A_l0000201TI6@0:o`0000000000<c<c00000?l00000IVIV
o`000000003o00000;>c/`;o000000<0i^KVo`00003oool00`3oool8o`00000300000?l0003o0000
00@0000000<06ATI00000?l000008Ol000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo04Ko
000000H0000001TI6@0I6AT06ATI0000000c<c<3o`00000407moO`00003o00000;>c/`;o000000<0
i^KVo`00003oool0103oool3o`00000=0<c<c?l00000/k>co`0000000000IVIVo`00001<C4`00000
03<c<`0000006ATI0000000Qo`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o0000
0?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0Aol00000
1`0000006ATI01TI6@0I6AT0000003<c<`0000000ol000000`00003o00000;>c/`02o`0000030>KV
i_l00000oooo00D0oooo0_l00000303<c<co0000o`00002IVIT0000006IVI_l00000C4a<0000000c
<c<0000001TI6@8000007ol000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003o
ool0oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo04So000000L0
0000o`00000I6AT06ATI0000000c<c<0000000?o000000<00000o`000?l000000_l000000`3Vi^Ko
00000?ooo`050?ooo`;o000000@0c<c<o`000?l00000VIVI0ol00000101<C4`0000003<c<`000002
01TI6@0300000?l0003o000001co00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol0
0000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1:o`00
00050000000I6AT0000003<c<`0000000P1<C4`3o`00000300000?l0003o000000?o00001@3oool0
0ol00000i^KVo`000002o`00000809VIV@00003o000006IVI_l00000000003<c<`00000301TI6@03
00000?l0003o000001_o00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1;o`0000040000
000I6AT0000003<c<`80000000D0C4a<o`000?l00000Ogmo00000007o`0000030?ooool00000i^KV
0080i^KV0ol0000020000000Ogmoo`00001VIVKo00000000000c<c<000000`0I6AT00`00003o0000
o`00000Jo`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0SOl0
00030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0C?l000000`0000006ATI0000
000203<c<`080000001<C4co0000o`00001oOgl00000o`00002c/k<3o`0000030>KVi_l0003o0000
00<0i^KV0_l00000102c/k?o00000000001oOgl2o`00000404a<C0000000<c<c000000806ATI00<0
0000o`000?l000006_l000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0
oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo04ko000000<06ATI
00000?l000000P0000001@1<C4co0000o`000?l00000000000Ko0000103Vi^H01ol00000c<c<o`00
002c/k?o00000000001oOgl00_l00000101<C4co000003<c<`00000201TI6@0300000?l0003o0000
01Wo00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0
oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1>o`0000080000000I6AT06ATI01TI
6@00003o00000000001<C4`3o`00000300000?l0003o000000Oo000000H0c<c<o`00002c/k?o0000
0000001oOgl2o`00000404a<C0000000<c<c000000<06ATI00<00000o`000?l000006?l000030?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000
oooo0?ooo`0a0?ooo`03o`00003oool0oooo04oo000000H0000001TI6@0I6AT06ATI0000000c<c<2
00000005o`00001VIVKo00000000002IVIT01Ol000020<c<c00:o`00002c/k<0/k>co`00002IVIT0
0000o`00001VIVKo000000000080<c<c00D0000001TI6@0I6AT06ATI0000000Io`0000<0oooo00?o
00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool0D?l000001@0000006ATI01TI6@0I6AT000000080<c<c00D0
0000o`00001VIVKo00000000000209VIV@03o`00002c/k<0/k>c00;o00000`2c/k<01?l00000VIVI
0000001oOgl2o`00000504a<C0000000<c<c03<c<ol000000`0I6ATIo`0000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340
oooo00?o00000?ooo`3oool0DOl00002000000806ATI0P0000000ol000000000o`000002o`0000<0
00000ol000040;>c/`0;o`00002IVIT0000000000?l00000IVIVo`00001<C4`0000003<c<`000000
0`0I6AT00`00003o0000o`00000Fo`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o
00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0Dol0
0002000000806ATI0`00000204a<C0Co00000P000004o`00008000000P1oOgl01ol00000IVIVo`00
001<C4`0000003<c<`0000000`0I6AT00`00003o0000o`00000Fo`0000<0oooo00?o00000?ooo`3o
ool06@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo
00?o00000?ooo`3oool0EOl00000100000006ATI01TI6@0I6AT40000000304a<C?l00000IVIV00;o
00001000000407moO`08o`00001VIVH0IVIVo`00001<C4`0000003<c<`00000301TI6@0300000?l0
003o000001Go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=
o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1Fo`0000040000000I6AT0
6ATI01TI6@80000000<0<c<c00000?l000001_l0000507moO`06o`00001VIVH0IVIVo`00001<C4`0
00000P0c<c<01@0000006ATI01TI6@0I6AT0000001Ko00000`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000
oooo0?ooo`1Ho`0000040000000I6AT06ATI01TI6@8000000P0c<c<2000000So000000<0IVIVo`00
0?l000000P1<C4`010000000<c<c03<c<`00000301TI6@0300000?l0003o000001Co00000`3oool0
0ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?oo
o`3oool0<@3oool00ol00000oooo0?ooo`1Io`0000030000000I6AT06ATI00806ATI0P00000203<c
<`80000000@0C4a<o`000?l0003o00000P1VIVH00ol00000C4a<04a<C00204a<C0040000000c<c<0
<c<c000000@06ATI00<00000o`000?l000004ol000030?ooo`03o`00003oool0oooo01T0oooo000J
0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0
oooo05[o00000P00000401TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`2o`0000@0C4a<00<0
000003<c<`0c<c<00P0c<c<01@0000006ATI01TI6@0I6AT0000001Go00000`3oool00ol00000oooo
0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3o
ool00ol00000oooo0?ooo`1Lo`00008000000`0I6AT00`00003o00000000000;000000@0<c<c00<0
000001TI6@0I6AT00P0I6AT00`00003o0000o`00000Bo`0000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo00?o0000
0?ooo`3oool0G_l00002000000D06ATI0P00000;03<c<`030000000I6AT06ATI00<06ATI00<00000
o`000?l000004_l000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo
08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo063o00000P00000501TI
6@800000200c<c<00`0000006ATI01TI6@0401TI6@0300000?l0003o000001;o00000`3oool00ol0
0000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3o
ool0<@3oool00ol00000oooo0?ooo`1Ro`00000300000?l00000000000@06ATI2000000701TI6AGo
00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo
00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1Uo`0000<000003`0I6AT00`00003o0000
o`00000Co`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0SOl0
00030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0J?l00003000000/06ATI00<0
0000o`000?l000005?l000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0
oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo06_o000000<00000
01TI6@0I6AT01`0I6AT00`00003o0000o`00000Eo`0000<0oooo00?o00000?ooo`3oool06@3oool0
01X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo00?o00000?oo
o`3oool0K?l00008000001Wo00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000
oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0
oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00
003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo
000J0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003o
ool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=
o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o0000
0?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo
0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go
00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo
00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo00?o
00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0
oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool0
0ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?oo
o`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0
oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3o
ool0SOl000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo08go0000
0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo
0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3o
ool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o0000
0?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl00003
0?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo08go00000`3oool00ol0
0000oooo0?ooo`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000
oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0
SOl000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00
003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0ol00000oooo0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=
o`0000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0SOl000030?oo
o`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0SOl000030?ooo`03o`00003oool0oooo
01T0oooo000J0?ooo`03o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0a0?ooo`03
o`00003oool0oooo08go00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`2=o`0000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2=o`0000<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0T03oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo0900oooo00?o00000?ooo`3oool06@3oool001X0ooooU?l0000c
0?oooiCo00006`3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool008D0oooo0_l000350?ooo`;o0000@P3oool00880oooo0ol000000`3ooooo00000?ooo`310?oo
o`?o000000<0ooooo`00003oool0@@3oool00800oooo0_l000020?ooo`80ZKgX0_l0002o0?ooo`;o
00000P3oool20:Vmj0;o0000@@3oool007d0oooo0ol000000`3oool0ZKgX0:Vmj0030:Vmj003o`00
003ooooo00000;/0oooo0ol000000`3oool0ZKgX0:Vmj0030:Vmj003o`00003ooooo00000400oooo
001j0?ooo`?o00000`3oool60:Vmj003o`00003ooooo00000;P0oooo0ol000030?ooo`H0ZKgX00?o
00000?ooool00000@03oool007P0oooo0_l000040?ooo`P0ZKgX00Co00000:Vmj03ooooo0000]@3o
ool2o`0000<0oooo2@2Y_NP01?l00000ZKgX0?ooool0000o0?ooo`00M@3oool3o`000080oooo302Y
_NP01Ol00000ZKgX0:Vmj03ooooo00000;40oooo0ol000020?ooo``0ZKgX00Go00000:Vmj02Y_NP0
ooooo`00000n0?ooo`00L`3oool2o`000080oooo3`2Y_NP01Ol00000ZKgX0:Vmj03ooooo00000:l0
oooo0_l000020?ooo`l0ZKgX00Go00000:Vmj02Y_NP0ooooo`00000n0?ooo`00L03oool3o`0000<0
oooo402Y_NP01_l00000ZKgX0:Vmj02Y_NP0ooooo`000:/0oooo0ol000030?oooa00ZKgX00Ko0000
0:Vmj02Y_NP0ZKgX0?ooool0000m0?ooo`00KP3oool2o`0000@0oooo4P2Y_NP01_l00000ZKgX0:Vm
j02Y_NP0ooooo`000:T0oooo0_l000040?oooa80ZKgX00Ko00000:Vmj02Y_NP0ZKgX0?ooool0000m
0?ooo`00J`3oool3o`000080oooo5P2Y_NP00ol00000ZKgX0:Vmj0020:Vmj0030?ooool00000oooo
0:@0oooo0ol000020?oooaH0ZKgX00?o00000:Vmj02Y_NP00P2Y_NP00`3ooooo00000?ooo`0k0?oo
o`00J03oool3o`000080oooo6@2Y_NP00ol00000ZKgX0:Vmj0030:Vmj0030?ooool00000oooo0:00
oooo0ol000020?oooaT0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00`3ooooo00000?ooo`0j0?ooo`00
IP3oool2o`0000@0oooo6`2Y_NP00ol00000ZKgX0:Vmj0030:Vmj003o`00003oool0oooo09d0oooo
0_l000040?oooa/0ZKgX00?o00000:Vmj02Y_NP00P2Y_NP00`3ooooo00000?ooo`0j0?ooo`00H`3o
ool3o`0000@0oooo7@2Y_NP00ol00000ZKgX0:Vmj0040:Vmj003o`00003oool0oooo09T0oooo0ol0
00040?oooad0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00`3ooooo00000?ooo`0i0?ooo`00H@3oool2
o`0000@0oooo802Y_NP00ol00000ZKgX0:Vmj0040:Vmj0030?ooool00000oooo09L0oooo0_l00004
0?ooob00ZKgX00?o00000:Vmj02Y_NP0102Y_NP00`3ooooo00000?ooo`0h0?ooo`00GP3oool3o`00
0080oooo902Y_NP00ol00000ZKgX0:Vmj0050:Vmj003o`00003oool0oooo09<0oooo0ol000020?oo
ob@0ZKgX00?o00000:Vmj02Y_NP01@2Y_NP00ol00000oooo0?ooo`0g0?ooo`00G03oool2o`000080
oooo9`2Y_NP00ol00000ZKgX0:Vmj0050:Vmj0030?ooool00000oooo0940oooo0_l000020?ooobL0
ZKgX00?o00000:Vmj02Y_NP01@2Y_NP00`3ooooo00000?ooo`0g0?ooo`00F@3oool3o`0000<0oooo
:02Y_NP00ol00000ZKgX0:Vmj0060:Vmj0030?ooool00000oooo08d0oooo0ol000030?ooobP0ZKgX
00?o00000:Vmj02Y_NP01P2Y_NP00`3ooooo00000?ooo`0f0?ooo`00E`3oool2o`0000@0oooo:P2Y
_NP00ol00000ZKgX0:Vmj0070:Vmj003o`00003oool0oooo08X0oooo0_l000040?ooobX0ZKgX00?o
00000:Vmj02Y_NP01P2Y_NP00`3ooooo00000?ooo`0f0?ooo`00E03oool3o`0000<0oooo;@2Y_NP0
0ol00000ZKgX0:Vmj0070:Vmj0030?ooool00000oooo08L0oooo0ol000030?ooobd0ZKgX00?o0000
0:Vmj02Y_NP01`2Y_NP00`3ooooo00000?ooo`0e0?ooo`00D@3oool3o`0000<0oooo<02Y_NP00ol0
0000ZKgX0:Vmj0080:Vmj0030?ooool00000oooo08<0oooo0ol000030?oooc00ZKgX00?o00000:Vm
j02Y_NP0202Y_NP00`3ooooo00000?ooo`0d0?ooo`00C`3oool2o`0000<0oooo<`2Y_NP00ol00000
ZKgX0:Vmj0080:Vmj0030?ooool00000oooo0840oooo0_l000030?oooc<0ZKgX00?o00000:Vmj02Y
_NP0202Y_NP00`3ooooo00000?ooo`0d0?ooo`00C03oool3o`000080oooo=P2Y_NP00ol00000ZKgX
0:Vmj0090:Vmj0030?ooool00000oooo07d0oooo0ol000020?ooocH0ZKgX00?o00000:Vmj02Y_NP0
2@2Y_NP00`3ooooo00000?ooo`0c0?ooo`00BP3oool2o`0000@0oooo=`2Y_NP00ol00000ZKgX0:Vm
j00:0:Vmj003o`00003oool0oooo07X0oooo0_l000040?ooocL0ZKgX00?o00000:Vmj02Y_NP02P2Y
_NP00ol00000oooo0?ooo`0b0?ooo`00A`3oool3o`0000@0oooo>@2Y_NP00ol00000ZKgX0:Vmj00;
0:Vmj003o`00003oool0oooo07H0oooo0ol000040?ooocT0ZKgX00?o00000:Vmj02Y_NP02`2Y_NP0
0ol00000oooo0?ooo`0a0?ooo`00A@3oool2o`0000@0oooo?02Y_NP00ol00000ZKgX0:Vmj00;0:Vm
j0030?ooool00000oooo07@0oooo0_l000040?oooc`0ZKgX00?o00000:Vmj02Y_NP02`2Y_NP00`3o
oooo00000?ooo`0a0?ooo`00@P3oool3o`0000<0oooo?`2Y_NP00ol00000ZKgX0:Vmj00<0:Vmj003
o`00003oool0oooo0700oooo0ol000020?oood00ZKgX00?o00000:Vmj02Y_NP0302Y_NP00ol00000
oooo0?ooo`0`0?ooo`00?`3oool3o`0000<0oooo@P2Y_NP00ol00000ZKgX0:Vmj00<0:Vmj0030?oo
ool00000oooo06d0oooo0ol000020?oood<0ZKgX00?o00000:Vmj02Y_NP0302Y_NP00`3ooooo0000
0?ooo`0`0?ooo`00?@3oool2o`0000<0ooooA@2Y_NP00ol00000ZKgX0:Vmj00=0:Vmj0030?ooool0
0000oooo06X0oooo0_l000020?ooodH0ZKgX00?o00000:Vmj02Y_NP03@2Y_NP00`3ooooo00000?oo
o`0_0?ooo`00>P3oool3o`000080ooooB02Y_NP00ol00000ZKgX0:Vmj00>0:Vmj003o`00003oool0
oooo06H0oooo0ol000020?ooodP0ZKgX00?o00000:Vmj02Y_NP03P2Y_NP00ol00000oooo0?ooo`0^
0?ooo`00>03oool2o`0000@0ooooB@2Y_NP00ol00000ZKgX0:Vmj00>0:Vmj0030?ooool00000oooo
06@0oooo0_l000040?ooodT0ZKgX00?o00000:Vmj02Y_NP03P2Y_NP00`3ooooo00000?ooo`0^0?oo
o`00=@3oool3o`0000@0ooooB`2Y_NP00ol00000ZKgX0:Vmj00?0:Vmj0030?ooool00000oooo0600
oooo0ol000040?oood/0ZKgX00?o00000:Vmj02Y_NP03`2Y_NP00`3ooooo00000?ooo`0]0?ooo`00
<`3oool2o`0000@0ooooCP2Y_NP00ol00000ZKgX0:Vmj00@0:Vmj003o`00003oool0oooo05d0oooo
0_l000040?ooodh0ZKgX00?o00000:Vmj02Y_NP03`2Y_NP00`3ooooo00000?ooo`0]0?ooo`00<03o
ool3o`0000<0ooooD@2Y_NP00ol00000ZKgX0:Vmj00A0:Vmj003o`00003oool0oooo05T0oooo0ol0
00030?oooe40ZKgX00?o00000:Vmj02Y_NP0402Y_NP00`3ooooo00000?ooo`0/0?ooo`00;@3oool3
o`0000<0ooooE02Y_NP00ol00000ZKgX0:Vmj00A0:Vmj003o`00003oool0oooo05H0oooo0ol00003
0?oooe@0ZKgX00?o00000:Vmj02Y_NP04@2Y_NP00ol00000oooo0?ooo`0[0?ooo`00:`3oool2o`00
00<0ooooF02Y_NP00ol00000ZKgX0:Vmj00A0:Vmj003o`00003oool0oooo05<0oooo0_l000030?oo
oeP0ZKgX00?o00000:Vmj02Y_NP04@2Y_NP00ol00000oooo0?ooo`0Z0?ooo`00:03oool3o`000080
ooooF`2Y_NP00ol00000ZKgX0:Vmj00A0:Vmj0030?ooool00000oooo0500oooo0ol000020?oooe/0
ZKgX00?o00000:Vmj02Y_NP04@2Y_NP00`3ooooo00000?ooo`0Z0?ooo`009P3oool2o`000080oooo
GP2Y_NP00ol00000ZKgX0:Vmj00B0:Vmj003o`00003oool0oooo04d0oooo0_l000020?oooeh0ZKgX
00?o00000:Vmj02Y_NP04P2Y_NP00ol00000oooo0?ooo`0Y0?ooo`008`3oool3o`0000<0ooooG`2Y
_NP00ol00000ZKgX0:Vmj00C0:Vmj003o`00003oool0oooo04T0oooo0ol000030?oooel0ZKgX00?o
00000:Vmj02Y_NP04P2Y_NP00`3ooooo00000?ooo`0Y0?ooo`008@3oool2o`0000@0ooooH@2Y_NP0
0ol00000ZKgX0:Vmj00D0:Vmj003o`00003oool0oooo04H0oooo0_l000040?ooof40ZKgX00?o0000
0:Vmj02Y_NP04`2Y_NP00`3ooooo00000?ooo`0X0?ooo`007P3oool3o`0000@0oooo0P2Y^^EQ0:Vm
j003o`00002Y_NP0ZKgX01@0ZKgX00?o00000?ooo`3oool0@`3oool3o`0000@0ooooH`2Y_NP00ol0
0000ZKgX0:Vmj00D0:Vmj003o`00003oool0oooo02L0oooo000L0?ooo`;o0000103oool20:NVe@@0
ZK[U00<0ZKgX0:Vii02Y^N@00`2Y_NP20:Vgh`H0ZKgX0P2Y_NM@0:Vmj003o`00002Y_NP0ZKgX01D0
ZKgX00?o00000?ooo`3oool0@03oool2o`0000@0ooooIP2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003
o`00003oool0oooo02H0oooo000I0?ooo`?o00000`3oool00`2QP:l0YjKE0:NVe@030:NVe@80ZK[U
0P2VWlh30:Vii0030:Vmj02Y]n<0ZKOS0080ZKOS0P2Y_NP20:VehP@0ZKgW0P2Y_NP00`2Y_>L0ZKgX
0:Vmj01:0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00<0ooooo`00003oool0?@3oool3o`0000<0oooo
J@2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj0030?ooool00000oooo02H0oooo000F0?ooo`?o00001@3o
ool30:60[`<0YjKE00<0X7VW0:JOcP2VWlh00`2VWlh00`2Y^N@0YIS80:FHb0030:Vgh`030:BB`P2Y
]N80ZKGR00<0ZKGR0P2Y_NL20:Vdh0<0ZKcW0P2Y_NP20:VlidL0ZKgX00?o00000:Vmj02Y_NP05P2Y
_NP00ol00000oooo0?ooo`0i0?ooo`?o00000`3ooom/0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o
00000?ooo`3oool09@3oool001@0oooo0_l000070?ooo`D0XH2_00@0YjKE0:1iY`2PNJL0X7VW0`2V
Wlh00`2OM:40YIS80:FHb0020:FHb0040:Vgh`2TT/80Y9;20:BB`P<0ZKGR00<0Y8jn0:Vdh02Y]>00
0`2Y]>000`2Y_>L0ZK;O0:Vbg`040:Vli`80ZKgX0P2Y_>M20:Vmj003o`00002Y_NP0ZKgX01H0ZKgX
00<0ooooo`00003oool0=`3oool2o`0000<0ooooK`2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj0030?oo
ool00000oooo02D0oooo000A0?ooo`?o0000203oool20:EcV`@0XH2_1@2PNJL00`2VWlh0WgBQ09md
X@040:FHb0D0Y9;200@0ZKGR0:B>_P2TS[h0Y8jn0`2Y]>000`2TS;/0ZK;O0:Vbg`020:Vbg`80ZKcW
0P2Y/]l40:Vli`80ZKgX00<0ZKcW0:Vmj02Y_NP0>`2Y_NP2o`0001T0ZKgX00<0ooooo`00003oool0
<`3oool3o`0000<0ooooL02Y_NP2o`0001T0ZKgX00<0ooooo`00003oool0903oool00100oooo0_l0
00090?ooo`<0YG>K102QP:l50:1iY`@0WgBQ0P2UV<P20:1aW@@0Y9;21@2TS[h0102Y]>00Y8bk0:B<
^`2TS;/20:Vbg`030:B;^P2Y/]l0ZK;O00<0ZK;O0P2Y_>L00`2Y/]h0ZKcW0:Vli`020:Vli`80ZKgX
0P2Y_>Le0:Vmj0?o000000<0ZKgXo`00002Y_NP06@2Y_NP00ol00000oooo0?ooo`0a0?ooo`;o0000
0P3ooom`0:Vmj0?o000000<0ZKgXo`00002Y_NP06@2Y_NP00ol00000oooo0?ooo`0S0?ooo`00403o
ool00ol00000ooooo`0000070?ooo`@0YG>K0`2QP:l00`2VLIL0X7VW0:1iY`030:1iY`@0WgBQ00@0
YIS80:1aW@2PLId0X76M0`2TT/820:5`V`@0Y8jn102TS;/0102Y/]l0Y8^j0:B;^P2TRkX30:Vbg`80
YHbk0`2Y/]h20:Vli`80ZK;O102Y_>L20:Vmj080ZKcW;@2Y_NP3o`0000D0ZKgX00?o00000:Vmj02Y
_NP0602Y_NP00ol00000oooo0?ooo`0`0?ooo`03o`00002Y_NP0ZKgX06h0ZKgX0ol000050:Vmj003
o`00002Y_NP0ZKgX01P0ZKgX00?o00000?ooo`3oool08P3oool00100oooo00Co00000?ooo`3ooooo
00001P3oool50:EcV`030:60[`2VLIL0YW6G00@0X7VW00<0Z76D09mdX@2OM:400P2OM:450:1aW@04
0:BB`P2QL9/0XG2K0:5`V`<0Y8jn00<0XW6J0:B<^`2TS;/00P2TS;/50:B;^P030:Vbg`2US;/0YHbk
0080YHbk00<0ZK;N0:J?_@2VSkd0102Y/]l20:Vli`80ZK?P102Y_>L00`2Y_NP0ZKcW0:Vli`0V0:Vm
j0?o00002@2Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`00003oool0oooo0300oooo00?o00000:Vm
j02Y_NP0J`2Y_NP3o`0000T0ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol00000oooo0?ooo`0R0?oo
o`00403oool01Ol00000oooo0?ooo`3ooooo000000@0oooo00<0]X2J0:EcV`2ULi/00`2ULi/0102Q
P:l0YW6G0:IaU`2VLIL30:1iY`030:QaU02OM:40WgBQ0080WgBQ1@2PLId50:5`V`040:B>_P2RLIX0
XW6J0:9aVP80Y8bk0P2TLi/40:B;^PD0YHbk102VSkd20:Vbg`80Z9?1102Y/n020:Vli`030:Veh@2Y
_>L0ZKcW0080ZKcW0P2Y_NP30:Vmi`80ZKgX00<0ZKgW0:Vmj02Y_NP0602Y_NP3o`0000d0ZKgX00?o
00000:Vmj02Y_NP05`2Y_NP00ol00000oooo0?ooo`0_0?ooo`03o`00003oool0ZKgX06P0ZKgX0ol0
000=0:Vmj003o`00002Y_NP0ZKgX01L0ZKgX00?o00000?ooo`3oool08@3oool000l0oooo00?o0000
0?ooo`3oool00`3oool01Ol00000oooo0?ooo`3oool0]X2J00D0YG>K102VLIL20:1iY`80Z76D0`2O
M:400`2ZLY<0X76M0:1aW@030:1aW@D0XG2K102RLIX0102TS;/0Y7>K0:AcV`2TLi/40:B;^P030:If
W02US;/0YHbk0080YHbk102VSkd50:RC`@80ZK?P00<0ZIW50:Veh@2Y]N400P2Y]N420:Vli`<0Z[OR
0P2Y_NL00`2Z^>@0ZKgW0:Vmi`020:VmiaH0ZKgX0ol0000@0:Vmj003o`00002Y_NP0ZKgX01L0ZKgX
00<0ooooo`00003oool0;P3oool01?l00000oooo0?ooo`3ooomU0:Vmj0?o0000402Y_NP00ol00000
ZKgX0:Vmj00G0:Vmj0030?ooool00000oooo0240oooo000?0?ooo`03o`00003oool0oooo00@0oooo
00Co00000?ooo`2fP9X0]X2J1@2ULi/40:IaU`030:1iY`2XLI@0Z76D0080Z76D0P2OM:400`2ZLY<0
X76M0:1aW@020:1aW@030:edTP2QL9/0XG2K00<0XG2K102RLIX40:AcV`<0Y8^j0P2VMY`30:F<^`80
ZGVO0`2VSkd00`2/Oj<0Z9?10:RC`@020:RC`@@0ZIW50P2Y]N420:^Pc0<0Z[OR00<0[:OB0:Zhi02Z
^>@00P2Z^>@20:Vmi`80Z[[U4P2Y_NP3o`0001@0ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol00000
oooo0?ooo`0]0?ooo`03o`00003oool0oooo0080ooooH@2Y_NP3o`0001@0ZKgX00?o00000:Vmj02Y
_NP05`2Y_NP00ol00000oooo0?ooo`0P0?ooo`003`3oool00ol00000oooo0<m^EP040=MT:0040?oo
o`2fP9X0]X2J0;J0VP@0YG>K00<0^X:H0:IaU`2VLIL00P2VLIL00`2PNJL0Z76D0:QaU0020:QaU080
WgBQ00<0ZW:C0:1aW@2PLId00P2PLId00`2]M980XG2K0:5`V`020:5`V`030;5gTP2RLIX0XW6J0080
XW6J1@2TLi/00`2TRkX0YWJL0:IfW0020:IfW0040:F<^`2YNIl0ZGVO0:UiW`80YXnm0P2/Oj<30:RC
`@030;25Z02YVLD0ZIW50080ZIW51@2[X<`0102Z]n80[:OB0:bWdP2/Ym820:Zhi080[:gH102Z^^D2
0:Vmj0030:ZkiP2Y_NP0ZKgX00T0ZKgX0ol0000H0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00<0oooo
o`00003oool0;@3oool00ol00000oooo0?ooo`030?oooed0ZKgX0ol0000H0:Vmj003o`00002Y_NP0
ZKgX01H0ZKgX00<0ooooo`00003oool0803oool000l0oooo00?o00000<m^EP3?KUH0103GI2P00`3M
MD40]X2J0;J0VP020;J0VP<0YG>K00<0^X:H0:IaU`2VLIL00P2VLIL50:QaU00409mdX@2ZLY<0ZW:C
0:YbT`80X76M0P2]M9840:5`V`030;5gTP2RLIX0XW6J0080XW6J1@2TLi/50:IfW0@0ZGVO00<0YXnm
0:aoX`2/Oj<00P2/Oj<0102XTl40/8FX0;25Z02`QJP20:VIa@80/hj`0`2[X<`00`2eV;T0[:OB0:bW
dP020:bWdP030:Zhi02/[MP0[:gH0080[:gH0P2Z^^D00`2//md0Z[_V0:ZkiP020:ZkiP80ZKgX0P2Y
_>L30:Vmj0?o0000702Y_NP00ol00000ZKgX0:Vmj00F0:Vmj0030?ooool00000oooo02`0oooo00?o
00000?ooo`3oool0103ooomI0:Vmj0?o0000702Y_NP00ol00000ZKgX0:Vmj00F0:Vmj0030?ooool0
0000oooo01l0oooo000?0?ooo`04o`00003?KUH0cfiF0<m^EP80ef@X00<0dWYW0;J0VP2fP9X00`2f
P9X20:EcV`80^X:H102VLIL50:QaU00409mdX@2ZLY<0ZW:C0:YbT`80X76M0P2]M9840:5`V`050;5g
TP2RLIX0XW6J0:9aVP2eNi<01@2TLi/50:IfW0@0ZGVO1@2/Oj<40;25Z0030:VIa@2cS[00/hj`0080
/hj`00@0Zj3<0;FH^@2eV;T0]IRi0`2/Ym801@2gX/@0[:gH0:b]f02/[MP0]Zc>00@0[;?M0P2Z^nH2
0:bgh@@0ZKcW0_l000000`2Y_>L0ZKgX0:Vmj00L0:Vmj003o`00002Y_NP0ZKgX01L0ZKgX00?o0000
0?ooo`3oool0:`3oool00ol00000oooo0?ooo`050?oooeH0ZKgX0_l0000O0:Vmj003o`00002Y_NP0
ZKgX01L0ZKgX00?o00000?ooo`3oool07P3oool000l0oooo00Go00000<m^EP3?KUH0cfiF0=MT:002
0=9jI`D0]X2J0P2ULi/20;Z2V0<0YW6G00<0_hFF0:QaU02XLI@00`2XLI@0102OM:40ZW:C0:YbT`2Z
LY<20:1aW@<0[GBB0P2QL9/20;5gTP<0XW6J00<0]G^C0:AcV`2TLi/00P2TLi/00`2iOiD0YWJL0:If
W0020:IfW0030;j5U`2YNIl0ZGVO0080ZGVO1@2/Oj<40;25Z0D0/hj`1@2eV;T01@2/Ym80]j;40;NR
a02gX/@0[:gH00<0]Zc>0P2//md20;Bcf0@0[;OQ0ol000040:Vli`80ZKgX00<0ZKgW0:Vmj02Y_NP0
6@2Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`00003oool0oooo02X0oooo00?o00000?ooo`3oool0
1P3ooomB0:Vmj0?o00008P2Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`00003oool0oooo01d0oooo
000>0?ooo`03o`00003oool0cfiF0080cfiF0P3BNVL00`3G/K80]X2J0;J0VP030;J0VP80YG>K0P2j
PYP30:IaU`030;n5UP2XLI@0Z76D00<0Z76D102ZLY<00`2PLId0[GBB0:edTP020:edTP80XG2K0`2a
Mi820:9aVP030;EkT`2TLi/0Y7>K0080Y7>K00<0^GnE0:IfW02VMY`00P2VMY`00`2nQIL0ZGVO0:Ui
W`020:UiW`050<B<VP2/Oj<0[7nS0:aoX`39U9l0102`QJP00`3>WZH0/hj`0;>>/0020;>>/0030=:Z
/02eV;T0]IRi0080]IRi102gX/@40;J/cP030:bcg@2d/mP0];?H0080];?H0ol000040:^ji080ZKcW
0P2Z^nH30:Vmia/0ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol00000oooo0?ooo`0X0?ooo`03o`00
003oool0oooo00P0ooooCP2Y_NP3o`0002H0ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol00000oooo
0?ooo`0L0?ooo`003P3oool00ol00000oooo0?ooo`020<m^EP80dWYW00<0ek6b0;J0VP2fP9X00`2f
P9X0102ULi/0^X:H0;Z2V02jPYP30:IaU`030;n5UP2XLI@0Z76D00<0Z76D102ZLY<00`2PLId0[GBB
0:edTP020:edTP80XG2K0`2aMi820:9aVP80]G^C0`2TLi/00`2iOiD0YWJL0:IfW0020:IfW0040;j5
U`2YNIl0ZGVO0:UiW`80a8bJ0`2/Oj<01039U9l0/8FX0;25Z02`QJP20<jNYP<0/hj`0P3BZ[040;FH
^@030=>e_02gX/@0]j;40080d;o:0`2f[<h00`38a=L0];?Ho`000002o`0000@0/KWO0P2[^^@20:jk
h`@0Z[_V00@0ZKgW0:Zli`2Z_>L0Z[cW0P2Y_NP00`2Z_NL0ZKgX0:Vmj00E0:Vmj003o`00002Y_NP0
ZKgX01H0ZKgX00?o00000?ooo`3oool0:03oool00ol00000oooo0?ooo`090?ooodX0ZKgX0ol0000B
0:Vmj0030:Vli`2Y_NP0ZKgX01D0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol00000oooo0?ooo`0L
0?ooo`003P3oool01?l00000oooo0?ooo`3?KUH209P/=P80ek6b1@2fP9X0102ULi/0^X:H0;Z2V02j
PYP20:IaU`80_hFF102XLI@00`35RID0ZW:C0:YbT`020:YbT`D0[GBB00<0XG2K0;5gTP2aMi800P2a
Mi80102RLIX0]G^C0;EkT`2eNi<20:AcV`<0^GnE0P2VMY`30;j5U`80ZGVO0P34S9X30:aoX`80bIBO
0P2`QJP20<jNYP<0/hj`0P3BZ[030;FH^@80dkFl00<0]j;40=2obP3@_lX00P3@_lX01@2f[<ko0000
o`000?l00000];?H00<0_/KO0P2a^Ml20;K4i@@0[[_S0P2Z^nH20:bmiP80Z[cW00<0ZkgW0:Zmi`2Z
_NL00P2Z_NLF0:Vmj003o`00002Y_NP0ZKgX01L0ZKgX00?o00000?ooo`3oool09`3oool00ol00000
oooo0?ooo`0;0?ooodD0ZKgX0ol000000`2Y_NL0ZKgX0:Vmj0030:Vmj080ZKcW1@2Y_NP30:Vli`80
ZKgX00<0ZK_V0:Vli`2Y_>L00P2Y_>L20:Vmj080ZKcW1@2Y_NP20:Vli`/0ZKgX00?o00000:Vmj02Y
_NP05`2Y_NP00ol00000oooo0?ooo`0K0?ooo`003P3oool00ol00000oooo0?ooo`020?ooo`0309P/
=P3G/K80ek6b00D0]X2J102jPYP20:IaU`80_hFF102XLI@00`35RID0ZW:C0:YbT`020:YbT`D0[GBB
00<0XG2K0;5gTP2aMi800P2aMi80102RLIX0]G^C0;EkT`2eNi<20:AcV`<0^GnE0P2VMY`30;j5U`80
ZGVO0P34S9X20:aoX`<0bIBO00<0/8FX0<jNYP3>WZH00P3>WZH00`2cS[00dZZ`0=:Z/0020=:Z/005
0;FH^@3C]K`0dkFl0=>e_03Ro=000P3@_lX3o`000080b<CG0P33hnh30;k6g`030;OCkP2fa>D0]/CU
0080]/CU0P2^^n<0102``^L0[;gV0:bmiP2/_NH20:g0j0<0ZkgW102Z_NLF0:Vmj003o`00002Y_NP0
ZKgX01H0ZKgX00<0ooooo`00003oool09`3oool00ol00000oooo0?ooo`0<0?oood40ZKgX0ol00000
0`2Y_>L0ZKgW0:Vmi`020:Vmi`030:Vmj02Y_>H0ZKcV00@0ZKcW0P2Y_NP20:VkiP80ZKcW00<0Z[SS
0:VkiP2Y^nH00P2Y^nH20:Vli`80Z[ST102Y_>L00`2Y_NP0Z[[U0:Zji@040:Vli`80ZKgX00<0ZKcW
0:Vmj02Y_NP0102Y_NP00`2Y_NL0ZKgXo`00000H0:Vmj0030?ooool00000oooo01/0oooo000>0?oo
o`03o`00003oool0oooo0080oooo103G/K840;J0VP@0^X:H0P2VLIL20;n5UP@0Z76D00<0aHVE0:Yb
T`2ZLY<00P2ZLY<50:edTP030:5`V`2aMi80/GNB0080/GNB00@0XW6J0;EkT`2eNi<0]G^C0P2TLi/3
0;UoU@80YWJL0`2nQIL0102YNIl0a8bJ0<B<VP34S9X20:aoX`<0bIBO00<0/8FX0<jNYP3>WZH00P3>
WZH00`2cS[00dZZ`0=:Z/0020=:Z/0<0dkFl00@0h_c@o`000?l0003o00000`3ClnH00`38a=L0`n?^
0<?SkP020<?SkP040;k6g`2gdnh0]m?^0;OCkP80]/CU00<0/<W/0;32i`2``^L00P2``^L00`2/_NH0
[L3X0:g0j0020:g0j0030:^mi`2[_nP0ZkoX00@0Z[gW0P2Y_NP00`2Z_NP0ZKgX0:Vmj00A0:Vmj003
o`00002Y_NP0ZKgX01H0ZKgX00?o00000?ooo`3oool09P3oool00ol00000oooo0?ooo`0=0?ooocd0
ZKgX0ol000050:Vli`80ZKgW00<0ZK[U0:VliP2Y_>H00P2Y_>H20:Vli`80Z[ST0P2Y^nH20:ZagP<0
Z[SS0P2Y^nH20:Zag@@0Z[ST0P2Y_>L00`2Z]>00Z[[U0:Zji@020:Zji@80ZKcW00<0Z[SS0:Vli`2Y
_>L00P2Y_>L20:Vmj0030:VkiP2Y_NL0ZKgW0080ZKgW00<0ZKgXo`00002Y_NL00P2Y_NL20:Vmj003
0:Vmi`2Y_NP0ZKgX0100ZKgX00?o00000?ooo`3oool06P3oool000h0oooo00?o00000?ooo`3oool0
0`3oool30=Na/P<0]X2J00<0iKn`0;Z2V02jPYP00P2jPYP0102VLIL0_hFF0;n5UP2oQIH30:QaU080
aHVE0`2ZLY<00`3<T9D0[GBB0:edTP030:edTPD0/GNB00D0XW6J0;EkT`2eNi<0]G^C0:AcV`040;Uo
U@030:IfW02nQIL0_XFG0080_XFG00<0ZGVO0<B<VP34S9X00P34S9X01@2/Oj<0bIBO0<VDW`39U9l0
/8FX00@0cYjV1@3BZ[001@3]n;Co0000o`000?l00000h_c@0080ALJo0P3ClnH3093Ro@80`n?^0P2R
doT20;OCkP80Y/Sa0`2`bN`20;32i`<0[L?[0P2]`>P00`2[`>T0ZkoX0:^oj0020:^oj080Z[gW00<0
Z[kX0:Zmj02Z_NP00P2Z_NPB0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00<0ooooo`00003oool09P3o
ool00ol00000oooo0?ooo`0=0?ooocX0ZKgX0ol000070:Vli`030:Zii02Y^^D0ZK[U0080ZK[U0P2Y
_>H01@2Z]N40Z[ST0:Zhi02Z^>@0ZZ[G00D0Z[7N00<0Z[SS0:ZVd`2Z/Md0102Z/Md20:Zhi0030:ZX
e02Z]>00Z[CP0080Z[CP0P2Z^^D00`2[[]X0Z[SS0:Zhh`020:Zhh`80ZKcW00<0Z[KQ0:VkiP2Y^nH0
0P2Y^nH20:Vmi`80Z[_V00Co00000:Vmi`2Y_NL0Z[[U102Y_NL20:Vmj0030:Vmi`2Y_NP0ZKgX00`0
ZKgX00<0ooooo`00003oool06P3oool000d0oooo00?o00000?ooo`3oool01@3oool20=Na/P<0]X2J
00<0iKn`0;Z2V02jPYP00P2jPYP0102VLIL0_hFF0;n5UP2oQIH30:QaU080aHVE0`2ZLY<00`3<T9D0
[GBB0:edTP030:edTPD0/GNB102eNi<00`2TLi/0^GnE0;UoU@020;UoU@030:IfW02nQIL0_XFG0080
_XFG00<0ZGVO0<B<VP34S9X00P34S9X40<VDW`D0cYjV00<0mnnQ0=:Z/03BZ[000ol000000`2Q_>`0
Rk[e08^jm@0208^jm@80K<7n0P2L_>l309?3m`80X]?i0`2P`O030:K8l@040;39k02X`^d0Z<;]0:S2
k@80[L?[00<0ZKoZ0:_0j@2[`>T00P2[`>T20:^oj0D0Z[kX0`2Z_NPC0:Vmj003o`00002Y_NP0ZKgX
01H0ZKgX00?o00000?ooo`3oool0903oool00ol00000oooo0?ooo`0?0?ooocH0ZKgX0ol000070:Vl
i`030:Zhi02Z^N@0Z[WT0080Z[WT0P2Y^^D20:ZbgP<0Z[GQ00@0Z[ST0:ZZe`2ZZ]L0ZZ[G0`2Z/Mh0
102YVlL0ZZKC0:ZVd`2ZY]<30:Zag@030:VHa@2ZZ=@0ZZSD0080ZZSD0P2Z]>000`2ZW/X0ZjkJ0:^^
fP020:^^fP80Z[SS0P2[ZMD30:Zfh@80ZK_V0`2[]=l20:ZkiP030:^cg_l00000Z[[U0080Z[[U0P2Y
_NL00`2Z^^D0ZKgW0:Vmi`020:Vmi`80ZKgX00<0ZKgW0:Vmj02Y_NP02@2Y_NP00ol00000oooo0?oo
o`0I0?ooo`003@3oool00ol00000oooo0?ooo`050?ooo`80ek6b0P2fP9X20>Fo/0@0^X:H00@0YW6G
0;n5UP2oQIH0_hFF0`2XLI@20<F9U@<0ZW:C00<0c92E0:edTP2]M9800`2]M9850;5gTP@0]G^C00<0
Y7>K0;UoU@2iOiD00P2iOiD00`2VMY`0_XFG0;j5U`020;j5U`D0a8bJ1039U9l0103mhiP0cYjV0<jN
YP3>WZH20?O_X@;o00000P2X_NP30:6lk080Rk[e0`2V_NX309blk`0409?3m`2S_N/0Xkg[0:>mj`80
X<7`00<0YkgY0:Fok02U_n`00P2U_n`20:S2k@030:Rnj@2Y_nX0ZKoZ0080ZKoZ0P2[`>T00`2Y_^T0
Z[kX0:Znj0040:Znj080ZKkX0`2Z_NPC0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o00000?ooo`3o
ool08`3oool00ol00000oooo0?ooo`0@0?oooc<0ZKgX0_l000070:Vli`80ZKWT0`2Z^>@20:Zii080
Z[3L102Z/]h00`2Z]N40ZZCA0:ZTd@040:ZZe`040:ZagP2YVlL0ZI_70:VKa`<0ZZKC00@0Z[7M0:VH
a@2YV<D0ZIS50P2ZZ=@00`2YSKP0ZYk:0:ZNbP020:ZNbP80ZjkJ0P2ZUL440:^Ye@030:Zfh@2/YM00
[:G@00<0ZkCO00<0[J?>0:^cgP2[/mh00P2[/mh00ol00000Z[[U0:bcgP040:Zji@80ZKgW00<0Z[_V
0:Vmi`2Y_NL00P2Y_NL20:Vmj0030:Vmi`2Y_NP0ZKgX00H0ZKgX00?o00000?ooo`3oool0603oool0
00d0oooo00?o00000?ooo`3oool01P3oool00`3G/K80]X2J0;J0VP020>Fo/0@0^X:H102oQIH20:Qa
U0<0aHVE0`2ZLY<00`3<T9D0[GBB0:edTP020:edTP030=>GU@2aMi80/GNB00<0/GNB102eNi<50;Uo
U@D0_XFG1@34S9X30<VDW`80oN>H0P3>WZH3o`000080ZKgX0`2X_NP0102Q_>`0ZKgX0:Vmj02Y_NP2
0:JmjP030:Vmj02X_NT0Z;gY0080Z;gY0P2S_N/00`2Y_NP0YkgY0:Nmj@020:Nmj@80YKo/00<0Z;gX
0:Rnj@2X_^T00P2X_^T20:VojP80ZKgX0`2Y_^T20:Znj0H0ZKkX00<0Z[gX0:Vmj02Y_NP04`2Y_NP0
0ol00000ZKgX0:Vmj00F0:Vmj003o`00003oool0oooo0280oooo00?o00000?ooo`3oool04@3oool_
0:Vmj0?o00001P2Y_>L20:Vji@@0ZKWT00<0Z[ST0:Vag@2Y/Md0102Z/=`20:ZbgP030:VQcP2ZY=40
ZZCA0080ZZCA0P2ZZ]L00`2XTkl0ZI_70:VKa`020:VKa`80ZZKC00<0Z8bg0:VHa@2YV<D00P2YV<D0
102ZZ=@0ZHfh0:V=^02YSKP30:ZNbPD0ZYG10P2[ZMD00`2[T;X0[:G@0:bUd0020:bUd0040:^dg`2]
Xlh0[J?>0:fScP80Zk?N00<0[ZC>0:bcg_l000000P2//mh20:Zji@030:beg`2Z^nH0Z[_V0080Z[_V
0P2Y_NL00`2Z_>H0ZKgW0:Vmi`020:Vmi`P0ZKgX00?o00000?ooo`3oool05`3oool000d0oooo00?o
00000?ooo`3oool01P3oool00`3G/K80]X2J0>Fo/0020>Fo/0@0^X:H102oQIH20:QaU0<0aHVE0`2Z
LY<00`3<T9D0[GBB0:edTP020:edTP030=>GU@2aMi80/GNB00<0/GNB102eNi<50;UoU@D0_XFG1034
S9X01@3meYH0bIBO0<VDW`39U9l0oN>H00?o00000P3gkj4>0:Vmj080Z;gY1@2Y_NP20:Nmj@80ZKgX
0`2X_NP20:Rnj@H0ZKgX00<0ZKkY0:Vmj02Y_NP01P2Y_^PG0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX
00?o00000?ooo`3oool08P3oool00ol00000oooo0?ooo`0B0?ooob/0ZKgX0ol000020:Vmj0D0ZKcW
0P2Y^nH30:Vji@80ZKWT00<0ZK?P0:Vag@2Y/Md00P2Y/Md20:Z`g0030:VRd02YXLh0ZJ7>0080ZJ7>
0P2ZY=400`2XSk`0Z9>o0:RC_`020:RC_`80ZI_700<0YhB_0:R<]`2XS;L00P2XS;L20:VHa@030:R1
Z`2YSKP0ZHfh00<0ZHfh00<0ZYk:0:V5[P2YQJh0102ZUL440:^@^P80[:G@00<0[Hng0:fScP2]Xlh0
0P2]Xlh01`2[/mh0[ZC>0:jTcP2^Y<ko00000:bcgP2_Z=40102/]Ml20:ZkiP030:bghP2Z_>H0Z[cV
0080Z[cV0P2Y_NL30:Zli`80ZKgX00D0Z[gW0:Vmj02Y_NP0ZKgXo`00000I0?ooo`003@3oool00ol0
0000oooo0?ooo`070?ooo`040;J0VP3U_k00iKn`0>Fo/0@0^X:H102oQIH20:QaU0<0aHVE0P2ZLY<2
0<b@U@@0[GBB00<0diNE0;5gTP2aMi800P2aMi800`3LXIH0]G^C0;EkT`020;EkT`D0^GnE1@2nQIL4
0<B<VP030?gFUP39U9oo000000;o00000P3mhiP00`3>WZH0ZKgX0:Vmj00J0:Vmj0030:Rmj02Y_NP0
ZKgX00/0ZKgX0P2Y_^PK0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o00000?ooo`3oool08@3oool0
0ol00000oooo0?ooo`0C0?ooobL0ZKgX0ol000060:Vmj0<0ZKcW0P2Y^nH20:Nji`80Z;OT102Y/n02
0:Vag@030:NWeP2YX]00ZJ;@0080ZJ;@0P2YXLh0102WTKl0Z8nl0:R?_02XSk`40:RC_`040:VKa`2W
Q:l0YhB_0:N4[`<0Z8bg00@0ZIS50:R1Z`2XPJ/0Z86[102YSKP30:V5[P<0ZYG100<0Zh:X0:^@^P2[
T;X00P2[T;X0102/YM00[Hng0:f?]`2]SkL20:fScP070;2B^02^Y<h0[ZC>0:jTcP2cV;`0[jSAo`00
00020:nXd@80[;GO0P2`[]H30:bghP80Z[cV0`2[^^@20:Zli`030:^ki@2Z_NL0Z[gW0080Z[gW0`2Y
_NP00ol00000oooo0?ooo`0F0?ooo`003@3oool00ol00000oooo0?ooo`090?ooo`80iKn`0`2jPYP0
0`3ee:/0_hFF0;n5UP020;n5UP030:QaU035RID0aHVE0080aHVE0P2ZLY<20<b@U@@0[GBB00<0diNE
0;5gTP2aMi800P2aMi801@3LXIH0]G^C0;EkT`2eNi<0iZbF00@0^GnE00<0kkVF0;j5U`2nQIL00P2n
QIL0103haiH0a8bJ0<B<VP34S9X3o`0000040<VDW`3mhiP0oN>H0?gSV4X0ZKgX00?o00000:Vmj02Y
_NP05P2Y_NP00ol00000oooo0?ooo`0P0?ooo`03o`00003oool0oooo01D0oooo8P2Y_NP3o`0000X0
ZKgX00<0ZKcW0:Nlj02W_>P0102W^^L20:Rgi080ZK?P0P2U[mh30:NWeP<0ZJ;@00@0ZJ7>0:NA_`2W
TKl0Yi6o0`2XSk`20:RC_`030:N2[02WQ:l0YhB_0080YhB_0`2XS;L40:R1Z`@0ZHfh102YQJh0102Z
UL40Zh:X0:^2Z02[PZP30:^@^P@0[Hng00D0[J?>0;2B^02`T[P0/9:h0:jTcP030;>H_0030:nXdOl0
0000[jSA00D0/:kF00<0[;OR0:ncf`2_/m/00`2[^^@00`2^^>40Zk_U0:^ki@020:^ki@80Z[gW00<0
Z[cW0:Vmj02Y_NP00P2Y_NP00ol00000oooo0?ooo`0E0?ooo`00303oool00ol00000oooo0?ooo`0:
0?ooo`80iKn`0`2jPYP00`3ee:/0_hFF0;n5UP020;n5UP030:QaU035RID0aHVE0080aHVE0P2ZLY<2
0<b@U@<0[GBB0P3CUiD40;5gTP050=bQUP2eNi<0]G^C0;EkT`3V[9H0102iOiD00`3_^IH0_XFG0;j5
U`020;j5U`040?S7U_l0003o0000o`0000<0oMJF00<0bIBO0?gSV03mhiP0C02Y_NP00ol00000ZKgX
0:Vmj00E0:Vmj003o`00003oool0oooo01l0oooo00?o00000?ooo`3oool05`3ooolN0:Vmj0?o0000
302Y_NP00`2X_NP0YkcX0:Nlj0020:Nlj080Yk[W00@0Xk[Y0:>ei@2S]ND0XkGU102U[mh30:NWeP03
0:VRd02TV<P0Yi6o00<0Yi6o0`2XSk`0102XTkl0Yh:/0:N2[02WPZ`30:N4[`<0Z8bg102XPJ/30:V=
^0030:UlX`2YQJh0ZHF^0080ZHF^102[PZP20:^@^P030:j3YP2]SkL0[Hng0080[Hng102`T[P50;>H
_0030:nXdOl00000]Z7300<0/:kF00<0]j_=0:ncf`2_/m/00P2_/m/0102[^^@0[[SQ0:jhh@2^^>42
0:^ki@030:fki02Z_>L0Z[cW0080Z[cW0P2Y_NP00`2Z_NOo00000?ooo`0F0?ooo`00303oool00ol0
0000oooo0?ooo`0;0?ooo`030>Fo/02jPYP0^X:H0080mMB[102oQIH00`2XLI@0aHVE0<F9U@020<F9
U@80ZW:C0P3<T9D30:edTP80diNE102aMi801@3LXIH0]G^C0;EkT`2eNi<0iZbF00@0^GnE00<0kkVF
0;j5U`2nQIL00ol000000`3haiH0a8bJ0<B<VP030?gFUP030<VDW`3mhiP0ZKgX04`0ZKgX00?o0000
0:Vmj02Y_NP05P2Y_NP00ol00000oooo0?ooo`0N0?ooo`03o`00003oool0oooo01P0oooo6P2Y_NP3
o`0000h0ZKgX0`2X_NP20:Nlj080YKcY0`2S^^T30:>ei@80YJoN00@0VJgU09nRe`2OX]L0Wj;G0`2T
V<P30:NA_`<0Z8nl102WPZ`40:N4[`030:R<]`2XO:@0Z7bT00@0Z86[00@0ZHfh0:UlX`2YO:<0ZGbS
0`2YQJh40:^2Z0040:^@^P2^PjH0[X>V0:j3YP80[Hng0P2bQZL30;2B^0030;N=ZP2cV;`0/iRl0080
/iRl00D0]Z73o`00002fXL<0]Z730;2^eP030;N[c@80[k?K0P2f]=P20:jhh@030;:kh02]^n@0[K_T
0080[K_T0P2Z_>L00`2[_NH0Z[gW0:Zmi`020:Zmi`03o`00003oool0oooo01@0oooo000<0?ooo`03
o`00003oool0oooo00/0oooo00<0iKn`0;Z2V02jPYP00P3ee:/40;n5UPD0aHVE00@0ZW:C0<b@U@3<
T9D0c92E0`2]M9820=>GU@<0/GNB0P3LXIH30;EkT`030>J/UP2iOiD0^GnE0080^GnE0ol00000102n
QIL0n<NF0?S7UP3haiH20<B<VP<0oMJF00<0oN>H0:Vmj02Y_NP0C@2Y_NP00ol00000ZKgX0:Vmj00F
0:Vmj003o`00003oool0oooo01d0oooo00?o00000?ooo`3oool06@3ooolF0:Vmj0?o00004P2Y_NP0
0`2X_NP0YkgY0:Nmj@040:Flj@030:>jj@2M^^d0WK[]00<0V;K/0`2I[ND309nRe`80Y9S8102WTKl0
0`2XSk`0YH>`0:N2[0030:N2[0@0YhB_0`2XO:@40:R1Z`@0ZGbS0P2YQJh20:akWP<0Zh:X102^PjH0
102]SkL0/XJW0;:6Y`2bQZL20;2B^080]hfZ0`2cV;`20;fH/@030;JQ`ol00000`ZFm00<0]j_=00D0
`kC<0;Jdf02f]=P0][CH0;jnfP040;:kh080[K_T00<0[kgU0:^miP2[_NH00P2[_NH40:Zmi`03o`00
003oool0oooo01<0oooo000<0?ooo`03o`00003oool0oooo00/0oooo00<0iKn`0;Z2V03ee:/00P3e
e:/40;n5UPD0aHVE00@0ZW:C0<b@U@3<T9D0c92E0P2]M9830=>GU@<0/GNB0P3LXIH30;EkT`030>J/
UP2iOiD0^GnE00;o00000P3_^IH20;j5U`<0n<NF00@0a8bJ0?gFUP3meYH0oMJFDP2Y_NP00ol00000
ZKgX0:Vmj00E0:Vmj003o`00003oool0oooo01d0oooo00?o00000?ooo`3oool06P3ooolC0:Vmj0;o
0000502Y_NP00`2X_NP0YkgY0:Nmj@020:Nmj@80YKcY00<0Xkc[09fjk@2M^^d00P2M^^d309Rfk080
VJgU0`2OX]L30:BHb080Yi6o00@0XHVk0:F3/02UPk00YH>`102WPZ`20:N4[`040:QkXP2XO:@0Z7bT
0:QlY0@0Z86[102YO:<0102YQJh0[7^N0:akWP2/Nih30:^2Z0@0[X>V1@2bQZL01@2`T[P0]hfZ0;N=
ZP2gSJX0/iRl00<0_IRa00D0]Z730<:U_Ol00000`ZFm0;N[c@030<>dc0040;Jdf02n_]X0_[kJ0;jn
fP80/[_P00<0]/7S0:nmi@2__ND00P2__ND20:^miP80[;kW0P2Z_NL00`2Z_^So00000?ooo`0D0?oo
o`00303oool00ol00000oooo0?ooo`0<0?ooo`040;Z2V03ee:/0mMB[0?GDZ`<0_hFF00<0nnRH0<F9
U@35RID00`35RID0102ZLY<0c92E0<b@U@3<T9D20:edTP<0diNE0`2aMi820=bQUP80]G^C00D0iZbF
o`000?l0003o00000;UoU@030>niUP80_XFG0`3haiH00`34S9X0oMJF0?gFUP1D0:Vmj003o`00002Y
_NP0ZKgX01D0ZKgX00?o00000?ooo`3oool0703oool00ol00000oooo0?ooo`0L0?ooo`h0ZKgX0ol0
000E0:Vmj0<0Z;gX102W_NT30:>lj`80WK[]00<0VK__08Nem027]O@00P27]O@207J[l`80OIoX0`2D
Tm030:69^`<0YH>`102WPZ`00`2WQ:l0Z7^R0:QkXP040:QlY080Z86[00<0ZWVM0:UlX`2YO:<00P2Y
O:<0102YQJh0[7^N0:akWP2/Nih20:^2Z080/7jM0`2^PjH50;:6Y`@0]hfZ102mV;430<:U_@03o`00
0033]<`0`kC<0080`kC<0`2n_]X00`33cN80]/7S0;K1h`020;K1h`80[kgU0P2_`NH20:bni`030:bo
j02Z_^P0Z[kX0080Z[kX00?o00000?ooo`3oool04P3oool000`0oooo00?o00000?ooo`3oool03`3o
ool01@3ee:/0_hFF0;n5UP2oQIH0nnRH00D0aHVE00@0ZW:C0<b@U@3<T9D0c92E0P2]M9830=>GU@80
/GNB0`3LXIH3o`000080iZbF0P2iOiD30>niUP80_XFG0`3haiH00`34S9X0oMJF0:Vmj01D0:Vmj003
o`00002Y_NP0ZKgX01D0ZKgX00?o00000?ooo`3oool0703oool00ol00000oooo0?ooo`0L0?ooo`/0
ZKgX0ol0000I0:Vmj0@0Z;gX0`2W_NT40:>lj`80VK__0P27]O@2082fm`80@Icd0P1mWnP209BCd0<0
XHVk0`2UPk040:N2[0<0Z7^R102XO:@00`2XPJ/0ZWVM0:YiW@040:UlX`@0[7^N0P2[PZP20;1nW@<0
[X>V00<0]X>M0;:6Y`2bQZL00P2bQZL40;N=ZP@0_IRa0`32YKd01?l00000e[g10<>dc033]<`20=3;
e0040;jnfP33cN80`lgR0<?=hP80]/7S0P2fb>P20:o1iP030:k3j@2/_nP0[;oX0080[;oX0`2Z_^P0
0ol00000oooo0?ooo`0B0?ooo`00303oool00ol00000oooo0?ooo`0?0?ooo`050?GDZ`2oQIH0_hFF
0;n5UP3kj9P01@35RID0102ZLY<0c92E0<b@U@3<T9D20:edTP<0diNE0P2aMi83o`000080]G^C0`3V
[9H20;UoU@<0kkVF00<0_XFG0?S7UP3haiH00P3haiH00`3meYH0ZKgX0:Vmj01E0:Vmj003o`00002Y
_NP0ZKgX01D0ZKgX00?o00000?ooo`3oool06`3oool00ol00000oooo0?ooo`0M0?ooo`L0ZKgX0ol0
000M0:Vmj080Z;gX00<0ZKgX0:Nmj@2W_NT00P2W_NT20:>lj`030:FmjP2K^nl0Vk__0080Vk__0`20
]_L2046Lm080073K0P2DTm030:69^`<0YH>`0P2WPZ`00`2VO:D0Z7^R0:QkXP020:QkXP<0Z7bT102Z
NId30:UlX`D0[7^N00<0Zh:X0;1nW@2`OYd00P2^PjH20;J3W@<0/XJW00@0_XbP0;N=ZP2gSJX0]hfZ
0P37V:H20;fH/@80dJVa0P32YKd00`3F_L7o00000<>dc0030=3;e0<0`lgR00D0_MK/0;K8j02fb>P0
]/SX0;79j`040:k3j@80[;oX00<0ZkoX0:Znj02Z_^P00P2Z_^P00ol00000oooo0?ooo`0A0?ooo`00
2`3oool00ol00000oooo0?ooo`0@0?ooo`030?GDZ`2oQIH0_hFF0080nnRH1@35RID40<b@U@040:ed
TP3CUiD0diNE0=>GU@?o00000`3LXIH20;EkT`<0iZbF0P2iOiD30>niUP030;j5U`3haiH0n<NF0080
n<NFF@2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003o`00003oool0oooo01T0oooo00?o00000?ooo`3o
ool07`3oool30:Vmj0?o0000902Y_NP20:Nmj@030:Rmj02U_NX0YKgZ0080YKgZ0P2K^nl00`2Q_>`0
S;Wd08bim00208bim0<0@Ike0P0SMn@30:69^`<0YH>`00<0Yh:/0:IlY@2VO:D0102XNj830:QlY0@0
ZWVM0P2YO:<00`2^NYX0[7^N0:akWP030:akWP<0/7jM0P2^PjH20;J3W@<0/XJW0P2nS:020;N=ZP80
aiRV00D0_IRa0=6Y/@3AZK40dJVa0<:U_@030=Jm`@03o`00003Xj/l0d<_D0080d^KU00D0`lgR0;gF
k02me^`0_MK/0;K8j0030;79j`80[/?Y00<0[<;Y0:^oj02[_nP00P2[_nP40:Znj003o`00003oool0
oooo0100oooo000;0?ooo`03o`00003oool0oooo0140oooo0P2oQIH20?_XV0D0aHVE103<T9D01@2]
M9;o0000o`000?l00000diNE0080/GNB0`3LXIH20;EkT`<0iZbF00<0^GnE0>niUP3_^IH00P3_^IH0
102nQIL0n<NF0?S7UP3haiIK0:Vmj003o`00002Y_NP0ZKgX01@0ZKgX00?o00000?ooo`3oool06@3o
ool00ol00000oooo0?ooo`0O0?ooo`?o0000:@2Y_NP20:Rmj080YKgZ0`2W_NT20:6lk080S;Wd0`2L
_>l207:bn@0402=gi021QLl0PHG?0865c`80YH>`00@0Wh2b0:IlY@2VO:D0YWbU102XNj820:QlY003
0:]iW02ZNId0ZWVM0080ZWVM0P2YO:<20:ijVP@0[7^N102`OYd00`2^PjH0]X>M0;J3W@020;:6Y`<0
_XbP00D0]hfZ0<NHYP37V:H0aiRV0;fH/@030=6Y/@080?7H^03F_L40e[g10=Jm`@3Xj/oo00000<Cn
dP3Bi^D30;o[lP050;gFk02cdO00/m7`0;?Al02abN/00P2]aN/30:c2j@80ZkoX0P2Z_nP20:Znj003
0:Vnj?l00000oooo0140oooo000;0?ooo`03o`00003oool0oooo0140oooo00@0_hFF0?_XV03kj9P0
nnRH1@35RID20<b@U@?o0000103CUiD00`2aMi80g:6F0=bQUP020=bQUP030;EkT`3V[9H0iZbF0080
iZbF00<0^GnE0>niUP3_^IH00P3_^IH30?S7UU`0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ol00000
oooo0?ooo`0H0?ooo`03o`00003oool0oooo01`0oooo0ol000030?ooobd0ZKgX0P2W_NT00`2Y_NP0
Y[gZ0:JmjP020:JmjP80W;c_00D0YKg[09Jkl@2F^o40U[_a02=gi0020865c`<0Wh2b0`2VO:D40:Qk
XP040:QlY02[NI`0ZgVL0:]iW0<0ZWVM00@0ZGbS0:ijVP2^NYX0[WZJ102/Nih40;1nW@@0]X>M00D0
/XJW0;j<X02nS:00_XbP0;N=ZP030<NHYP@0dJVa0P3af;P0103F_L40j>[?0>SZcol000020:?dk@80
_n_b0P2_fOH20;?Al080[<O^0`2]aN/01P2/`^T0Z/3Y0:[0j@2Z`>T0Z[oX0:Znj0@0ZKkX00?o0000
0?ooo`3oool03`3oool000/0oooo00?o00000?ooo`3oool04@3oool00`2oQIH0nnRH0?ooo`020?_X
V0<0aHVE0ol000020<b@U@030:edTP3CUiD0diNE0080diNE00<0/GNB0=bQUP3LXIH00P3LXIH00`2e
Ni<0iZbF0>J/UP020>J/UP030;UoU@3_^IH0kkVF0080kkVFH02Y_NP00ol00000ZKgX0:Vmj00E0:Vm
j003o`00003oool0oooo01L0oooo00?o00000?ooo`3oool06@3oool3o`0000L0oooo<02Y_NP20:Jm
jP030:Rmj02U_N/0YKg[0080YKg[0P2F^o40102T_>/0PHG?0865c`21QLl309n0/P<0YWbU0`2XNj80
102XO:@0ZgVL0:]iW02[NI`30:YiW@040:UlX`2^NYX0[WZJ0:ijVP<0[7^N00<0]7jI0;1nW@2`OYd0
0P2`OYd40;J3W@040;:6Y`2nS:00_XbP0;j<X0@0aiRV00<0j;bX0=6Y/@3AZK400`3af;P01@2giXH0
j>[?0<CndP2Sm>go00000080YM_j0P2_fOH20:W8k`80[<O^00<0ZL7Z0:[1jP2Z`NX00P2Z`NX20:[0
j@040:Vnj02Z_^P0Z[kX0:Znj080ZKkX00<0ZKgXo`000?l00000403oool000/0oooo00?o00000?oo
o`3oool04@3oool01@2oQIH0oooo0?ooo`3oool0nnRH00?o000000<0bmEM0<b@U@3<T9D00P3<T9D5
0=>GU@030;5gTP3LXIH0g:6F0080g:6F00<0]G^C0>J/UP3V[9H00P3V[9H00`2iOiD0kkVF0>niUP02
0>niUV40ZKgX00?o00000:Vmj02Y_NP0502Y_NP00ol00000oooo0?ooo`0G0?ooo`03o`00003oool0
oooo01H0oooo0ol0000;0?oooc00ZKgX0`2X_NP20:Fmj`80Z;gX0`2T_>/20865c`<0Wh2b0`2VO:D3
0:QkXP@0ZgVL0`2ZNId40:ijVP<0[7^N00<0]7jI0;1nW@2`OYd00P2`OYd40;J3W@@0_XbP00D0f:BP
0<NHYP37V:H0aiRV0>RlZ0020=6Y/@<0lMRh00H0000006;Hd@2Ke_`0VmKl0:GKn_l000020:O6l080
ZLS_00<0ZL3[0:W1jP2Y`NX00P2Y`NX20:[1jP030:Vnj@2Y_^P0ZKkX0080ZKkX00<0Z[kX0:Vmj02Y
_NP00`2Y_NP00ol00000oooo0?ooo`0>0?ooo`002`3oool00ol00000oooo0?ooo`0D0?ooo`;o0000
0`35RID00`3;eEd0c92E0<b@U@020<b@U@D0diNE00<0/GNB0=bQUP3LXIH00P3LXIH00`2eNi<0iZbF
0>J/UP020>J/UP@0kkVFH`2Y_NP00ol00000ZKgX0:Vmj00C0:Vmj003o`00003oool0oooo01L0oooo
00?o00000?ooo`3oool0503oool2o`0000l0oooo<02Y_NP01@2X_NP0ZKgX0:Vmj02Y_NP0Z;gX0080
ZKgX0`2X_NT01021QLl0Wh2b09n0/P2OP;830:IlY@<0Z7^R102[NI`30:YiW@@0[WZJ0`2/Nih01@2d
OYT0/7jM0;1nW@2`OYd0_HJJ00@0]X>M102nS:000`3HY:00aiRV0<NHYP030>RlZ0050=6Y/@3af;P0
lMRh09S=nP2U`>d0102U`nl00`2Wa_3o00000:RojP040:W0j`80ZL7Z1@2Y_^T20:Vnj0H0ZKgX00<0
ooooo`00003oool03`3oool000X0oooo00?o00000?ooo`3oool04P3oool3o`0000060?ooo`3kj9P0
aHVE0<F9U@3oool0bmEM103<T9D50=>GU@D0g:6F00<0]G^C0>J/UP3V[9H00P3V[9H00`2Y_NP0kkVF
0>niUP1T0:Vmj003o`00002Y_NP0ZKgX00d0ZKgX1P3oool00ol00000oooo0?ooo`0F0?ooo`03o`00
003oool0oooo0180oooo0ol0000B0?ooocL0ZKgX0P2X_NT0102Y_NP0PHG?09n0/P2OP;830:IlY@80
Z7^R00<0ZW^P0:]iW02[NI`00P2[NI`30:YiW@D0[WZJ00@0[7^N0;AnV@2dOYT0]7jI0P2`OYd20;f6
VP<0]X>M00<0bI:L0;j<X02nS:000P3HY:020<NHYP<0j;bX00<0d=i^0?7H^02W_^/00`2U`>d20:G3
k`030:Rnj@2X_n[o00000080Z;oZ0P2Y`>/20:Vnj0D0ZKkY102Y_NP60?ooo`03o`00003oool0oooo
00h0oooo000:0?ooo`03o`00003oool0oooo00l0oooo0ol000040?ooo`050?_XV035RID0aHVE0?oo
o`3;eEd00`3<T9D00`3oool0diNE0=>GU@030=>GU@D0g:6F1@3V[9H20:Vmj0030>niUP2Y_NP0ZKgX
06<0ZKgX00?o00000:Vmj02Y_NP02@2Y_NP:0?ooo`03o`00003oool0oooo01D0oooo00?o00000?oo
o`3oool03`3oool3o`0001H0oooo>P2Y_NP309n0/P80YWbU00@0Z7^R0:YkX02ZNj00ZW^P0`2[NI`2
0:YiW@80/GbJ102^NYX0102/Nih0]7jI0;AnV@2dOYT20;1nW@80_HJJ0P2fPid20<VBW080_XbP0`3H
Y:001@37V:H0j;bX0>RlZ03X_:P0d=i^00<0Ykk[00<0YL3]0:Rnj@2X_^T00`2X_^T0102X_n[o0000
0:Vmj02Y_NP20:Vnj0L0ZKgX2P3oool00ol00000oooo0?ooo`0=0?ooo`002P3oool00ol00000oooo
0?ooo`0<0?ooo`?o00001`3oool01@3kj9P0aHVE0?ooo`3oool0bmEM00<0c92E00<0oooo0=>GU@3C
UiD00`3CUiD50=bQUP@0iZbFJP2Y_NP00ol00000ZKgX0:Vmj0050:Vmj0d0oooo00?o00000?ooo`3o
ool05@3oool00ol00000oooo0?ooo`0<0?ooo`?o00006P3oooli0:Vmj0<0BG7H00<0YWbU0:1o[`2Z
Nj000`2ZNj040:]iW0030:YiW@2aO9X0/GbJ00@0[WZJ00D0[7^N0;AnV@2dOYT0]7jI0;1nW@030;f6
VP80]X>M0P39TY`20;j<X0<0f:BP0`3X_:P00`3@gVh0ZKgX0:Vmj0030:Vmj0030:Rnj@2Y_NP0ZKgX
00@0ZKgX00?o00000:Vmj02Y_NP01@2Y_NP=0?ooo`03o`00003oool0oooo00d0oooo000:0?ooo`03
o`00003oool0oooo00T0oooo0ol0000;0?ooo`040<F9U@3oool0oooo0?ooo`<0c92E00<0oooo0=>G
U@3CUiD00P3CUiD00`3oool0g:6F0=bQUP030=bQUP040?ooo`3V[9H0iZbF0>J/UVX0ZKgX00?o0000
0:Vmj02Y_NP00P2Y_NP@0?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool02@3oool3
o`0001h0oooo>@2Y_NP204Uaf080X7n_102ZNj040:]iW0030:YiW@2aO9X0/GbJ00@0[WZJ102dOYT0
102`OYd0_HJJ0;f6VP2mQYX20;J3W@80bI:L0P2nS:030=RTX0<0j;bX3@2Y_NP00ol00000ZKgX0:Vm
j0020:Vmj100oooo00?o00000?ooo`3oool03@3oool000X0oooo00?o00000?ooo`3oool01P3oool3
o`0000h0oooo00@0aHVE0?ooo`3oool0oooo0P3<T9D20?ooo`@0diNE00<0oooo0=bQUP3LXIH00P3L
XIH20?ooo`80iZbFK02Y_NP00ol00000oooo0?ooo`0A0?ooo`03o`00003oool0oooo01D0oooo00?o
00000?ooo`3oool01P3oool3o`000280oooo>02Y_NP204Uaf0<0X7n_0`2ZNj040:]iW0<0/GbJ102^
NYX40;AnV@040;1nW@2mQYX0_HJJ0;f6VP80]X>M0`39TY`01P2nS:00f:BP0=RTX03HY:00nn:80>Rl
Z0l0ZKgX00?o00000?ooo`3oool04@3oool00ol00000oooo0?ooo`0=0?ooo`002P3oool00ol00000
oooo0?ooo`030?ooo`?o00005@3oool20<b@U@<0oooo0`3CUiD20?ooo`<0g:6F0P3oool20>J/UVP0
ZKgX1@3oool00ol00000oooo0?ooo`0@0?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3o
ool00`3oool3o`0002H0oooo>02Y_NP01019LMP0X7n_0:1o[`2POjl30:YkX0@0ZgVL0`2aO9X30:ij
VP030;Z3V@2dOYT0]7jI0080]7jI1@2mQYX0102fPid0bI:L0<VBW039TY`30=RTX080nn:800<0j;bX
0:Vmj02Y_NP02@2Y_NP50?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3oool03@3oool0
00T0oooo00Co00000?ooo`3oool0oooo0ol0000H0?ooo`030<b@U@3oool0oooo0080oooo0P3CUiD3
0?ooo`80g:6F103oool00`3V[9H0oooo0:Vmj01S0:Vmj0T0oooo00?o00000?ooo`3oool03`3oool0
0ol00000oooo0?ooo`0D0?ooo`04o`00003oool0oooo0?ooo`?o0000:P3ooolh0:Vmj00304Uaf02P
Ojl0X7n_00<0ZW^P102[NI`30;5lVP<0[WZJ0P2jPiT30;AnV@D0_HJJ1039TY`30=RTX080nn:82@2Y
_NP90?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool03@3oool000T0oooo1?l0000K
0?ooo`030<b@U@3oool0oooo0080oooo0P3CUiD30?ooo`80g:6F203ooomO0:Vmj0`0oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`0D0?ooo`Co0000;`3ooolf0:Vmj00304Uaf02POjl0
X7n_00<0ZW^P0`2[NI`0102bP9h0/GbJ0;5lVP2aO9X30:ijVP80^X>I0`2dOYT50;f6VP@0bI:L0`3H
Y:020?_RR0H0ZKgX303oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00d0oooo0009
0?ooo`;o00007@3oool00`3<T9D0oooo0?ooo`020?ooo`030=>GU@3oool0oooo0080oooo00<0g:6F
0?ooo`3oool01`3ooomM0:Vmj0l0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0C
0?ooo`;o0000<@3ooolg0:Vmj080X7n_102ZNj020:]iW0030;:0WP2aO9X0/GbJ0080/GbJ00@0[WZJ
0;Z3V@2jPiT0^X>I0`2dOYT50;f6VP@0bI:L0P3HY:020?_RR0D0ZKgX3`3oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo00`0oooo000;0?ooo`03o`00003oool0oooo01l0oooo00<0diNE
0?ooo`3oool00P3oool00`3LXIH0oooo0?ooo`080?oooeT0ZKgX4`3oool00ol00000oooo0?ooo`0>
0?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool0;`3ooolg0:Vmj080X7n_0`2ZNj00
102[NI`0/X2N0;:0WP2bP9h30;5lVP040:ijVP2jPiT0^X>I0;Z3V@<0]7jI00<0ahnJ0;f6VP2mQYX0
0P2mQYX40<VBW0040?G4V@3HY:00nn:80?_RR080ZKgX4`3oool00ol00000oooo0?ooo`0>0?ooo`03
o`00003oool0oooo00`0oooo000<0?ooo`03o`00003oool0oooo01h0oooo00<0diNE0?ooo`3oool0
3`3ooomA0:Vmj1X0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?ooo`0F0?ooo`03o`00
003oool0oooo0300oooo=P2Y_NP01@2POjl0ZW^P0:YkX02ZNj00ZgVL00<0/X2N0`2aO9X0102^NYX0
^X>I0;Z3V@2jPiT20;AnV@80ahnJ102mQYX00`3KY9/0bI:L0<VBW0020?G4V@030=RTX03khXP0nn:8
01H0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?ooo`0<0?ooo`003@3oool00ol00000
oooo0?ooo`0_0?ooodl0ZKgX703oool00ol00000oooo0?ooo`0=0?ooo`03o`00003oool0oooo01L0
oooo00?o00000?ooo`3oool0;`3ooolg0:Vmj080ZW^P00<0YhVe0;:0WP2bP9h00P2bP9h30;5lVP@0
^X>I0P2dOYT20<N?VP<0_HJJ0P3KY9/20<VBW080mLBI00<0nn:80?ooo`3oool05P3oool00ol00000
oooo0?ooo`0=0?ooo`03o`00003oool0oooo00`0oooo000>0?ooo`;o0000<03ooom;0:Vmj200oooo
00?o00000?ooo`3oool0303oool00ol00000oooo0?ooo`0H0?ooo`;o0000<03ooolf0:Vmj0<0YhVe
102bP9h30;5lVP@0^X>I0P2dOYT20<N?VP<0_HJJ0P3KY9/20<VBW080mLBI6P3oool00ol00000oooo
0?ooo`0<0?ooo`03o`00003oool0oooo00`0oooo000@0?ooo`03o`00003oool0oooo02l0ooooAP2Y
_NPT0?ooo`03o`00003oool0oooo00/0oooo00?o00000?ooo`3oool06P3oool00ol00000oooo0?oo
o`0_0?ooocD0ZKgX0P2WRKD40;:0WP<0/GbJ1@2jPiT00`2dOYT0ahnJ0<N?VP030;f6VP80fjBK0P39
TY`20?G4VA/0oooo00?o00000?ooo`3oool02`3oool00ol00000oooo0?ooo`0<0?ooo`004@3oool0
0ol00000oooo0?ooo`0_0?oood00ZKgX:P3oool00ol00000oooo0?ooo`0:0?ooo`03o`00003oool0
oooo01/0oooo00?o00000?ooo`3oool0;`3ooold0:Vmj0<0YhVe0`2bP9h30;5lVPD0^X>I00<0]7jI
0<N?VP37SiX00P2mQYX30=^TV`80bI:L00<0mLBI0?ooo`3oool06`3oool00ol00000oooo0?ooo`0:
0?ooo`03o`00003oool0oooo00`0oooo000B0?ooo`03o`00003oool0oooo02l0oooo?@2Y_NP/0?oo
o`03o`00003oool0oooo00/0oooo00?o00000?ooo`3oool06`3oool00ol00000oooo0?ooo`0_0?oo
oc<0ZKgX0`2WRKD30;:0WP80/GbJ0P31SJ040;Z3V@<0ahnJ0P2mQYX40=^TV`80mLBI7@3oool00ol0
0000oooo0?ooo`0;0?ooo`03o`00003oool0oooo00/0oooo000C0?ooo`;o0000<03oooli0:Vmj300
oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0L0?ooo`;o0000<03ooolc0:Vmj080
YhVe102bP9h00`2aO9X0`HfP0<6=X0040;Z3V@@0ahnJ00<0_HJJ0=^TV`3KY9/00P3KY9/20?G4VAh0
oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0;0?ooo`005@3oool00ol00000oooo
0?ooo`0_0?oooc80ZKgX=P3oool00ol00000oooo0?ooo`090?ooo`03o`00003oool0oooo01h0oooo
00?o00000?ooo`3oool0;`3ooola0:Vmj080YhVe102bP9h00`2aO9X0`HfP0<6=X0040;Z3V@@0ahnJ
00<0_HJJ0=^TV`3KY9/00P3KY9/00`000000oooo0?ooo`0N0?ooo`03o`00003oool0oooo00T0oooo
00?o00000?ooo`3oool02`3oool001H0oooo00?o00000?ooo`3oool0;P3oool_0:Vmj3X0oooo00?o
00000?ooo`3oool0203oool00ol00000oooo0?ooo`0O0?ooo`03o`00003oool0oooo02h0oooo;`2Y
_NP30?ooo`030:N9]@2bP9h0/X2N0080/X2N00<0/GbJ0<6=X031SJ00102jPiT40<N?VPD0fjBK8P3o
ool00ol00000oooo0?ooo`080?ooo`03o`00003oool0oooo00/0oooo000G0?ooo`03o`00003oool0
oooo02h0oooo;02Y_NPl0?ooo`03o`00003oool0oooo00P0oooo00?o00000?ooo`3oool0803oool0
0ol00000oooo0?ooo`0^0?ooob`0ZKgX1P3oool0102WRKD0/X2N0;:0WP2bP9h30<6=X0<0^X>I00<0
g:^S0<N?VP37SiX00P37SiX40=^TVb<0oooo00?o00000?ooo`3oool0203oool00ol00000oooo0?oo
o`0;0?ooo`00603oool2o`000300oooo9`2Y_NQ00?ooo`03o`00003oool0oooo00L0oooo00?o0000
0?ooo`3oool08@3oool2o`000300oooo9`2Y_NP90?ooo`040:N9]@2bP9h0/X2N0<;1f@<0`HfP0`2j
PiT20=b[X`<0ahnJ00@0o]j?0=^TV`3KY9/0fjBK903oool00ol00000oooo0?ooo`070?ooo`03o`00
003oool0oooo00/0oooo000J0?ooo`03o`00003oool0oooo02d0oooo8P2Y_NQ60?ooo`03o`00003o
ool0oooo00L0oooo00?o00000?ooo`3oool08P3oool00ol00000oooo0?ooo`0]0?ooob80ZKgX3`3o
ool00`2bP9h0`/7I0<;1f@030<6=X0<0^X>I0P3LZj<30<N?VP040?kNS`3KY9/0fjBK0=^TVbD0oooo
00?o00000?ooo`3oool01`3oool00ol00000oooo0?ooo`0:0?ooo`006`3oool00ol00000oooo0?oo
o`0]0?oooal0ZKgXB@3oool00ol00000oooo0?ooo`060?ooo`03o`00003oool0oooo02<0oooo00?o
00000?ooo`3oool0;@3ooolO0:Vmj180oooo0P32`MT40<6=X0040;Z3V@3LZj<0g:^S0=b[X`80ahnJ
0P3ngXl20=^TVbL0oooo00?o00000?ooo`3oool01P3oool00ol00000oooo0?ooo`0:0?ooo`00703o
ool00ol00000oooo0?ooo`0^0?oooaP0ZKgXCP3oool00ol00000oooo0?ooo`060?ooo`03o`00003o
ool0oooo02@0oooo00?o00000?ooo`3oool0;P3ooolH0:Vmj1L0oooo0P32`MT40<6=X0040;Z3V@3L
Zj<0g:^S0=b[X`80ahnJ0`3ngXl00`3KY9/0oooo0?ooo`0U0?ooo`03o`00003oool0oooo00H0oooo
00?o00000?ooo`3oool02P3oool001d0oooo00?o00000?ooo`3oool0;P3ooolD0:Vmj580oooo00?o
00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0U0?ooo`03o`00003oool0oooo02h0oooo502Y
_NPK0?ooo`80`/7I0`31SJ00102jPiT0g:^S0=b[X`3LZj<20<N?VP<0o]j?00<0fjBK0?ooo`3oool0
9P3oool00ol00000oooo0?ooo`050?ooo`03o`00003oool0oooo00X0oooo000N0?ooo`;o0000;`3o
oolA0:Vmj5D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`0V0?ooo`;o0000;P3o
oolB0:Vmj1h0oooo00@0`/7I0<6=X031SJ00`HfP1@3LZj<00`37SiX0o]j?0?kNS`0[0?ooo`03o`00
003oool0oooo00@0oooo00?o00000?ooo`3oool02P3oool00200oooo00?o00000?ooo`3oool0;@3o
ool;0:Vmj5X0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`0X0?ooo`03o`00003o
ool0oooo02`0oooo302Y_NPS0?ooo`040<;1f@31SJ00`HfP0?ooo`D0g:^S00<0ahnJ0?kNS`3oool0
:`3oool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo00X0oooo000Q0?ooo`03o`00003o
ool0oooo02d0oooo202Y_NQM0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool0:@3o
ool00ol00000oooo0?ooo`0]0?ooo`L0ZKgX9`3oool01031SJ00oooo0?ooo`3oool40=b[X`030?kN
S`3oool0oooo02`0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0:0?ooo`008P3o
ool00ol00000oooo0?ooo`0]0?ooo`@0ZKgXH@3oool00ol00000oooo0?ooo`030?ooo`03o`00003o
ool0oooo02T0oooo00?o00000?ooo`3oool0;@3oool40:Vmj2d0oooo0`3LZj<a0?ooo`03o`00003o
ool0oooo00<0oooo00?o00000?ooo`3oool02@3oool002<0oooo0_l0000]0?ooo`03o`00003oool0
oooo06<0oooo00?o00000?ooo`3oool00P3oool00ol00000oooo0?ooo`0Z0?ooo`;o0000;@3oool0
0ol00000oooo0?ooo`0_0?ooo`030=b[X`3oool0oooo0340oooo00?o00000?ooo`3oool00P3oool0
0ol00000oooo0?ooo`090?ooo`009@3oool00ol00000oooo0?ooo`0Z0?ooo`03o`00003oool0oooo
06<0oooo00?o00000?ooo`3oool00P3oool00ol00000oooo0?ooo`0/0?ooo`03o`00003oool0oooo
02X0oooo00?o00000?ooo`3oool0H`3oool00ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo
00T0oooo000V0?ooo`03o`00003oool0oooo02T0oooo00?o00000?ooo`3oool0I03oool01Ol00000
oooo0?ooo`3ooooo000002l0oooo00?o00000?ooo`3oool0:@3oool00ol00000oooo0?ooo`1T0?oo
o`05o`00003oool0oooo0?ooool000002`3oool002L0oooo00?o00000?ooo`3oool0:03oool00ol0
0000oooo0?ooo`1U0?ooo`04o`00003oool0ooooo`000300oooo00?o00000?ooo`3oool0:03oool0
0ol00000oooo0?ooo`1U0?ooo`04o`00003oool0ooooo`0000/0oooo000X0?ooo`;o0000:03oool0
0ol00000oooo0?ooo`1V0?ooo`03o`00003ooooo00000340oooo0_l0000X0?ooo`03o`00003oool0
oooo06H0oooo00?o00000?ooool000002`3oool002X0oooo00?o00000?ooo`3oool09@3oool00ol0
0000oooo0?ooo`1V0?ooo`03o`00003ooooo000003<0oooo00?o00000?ooo`3oool09@3oool00ol0
0000oooo0?ooo`1V0?ooo`03o`00003ooooo000000/0oooo000[0?ooo`03o`00003oool0oooo02@0
oooo00?o00000?ooo`3oool0I`3oool00ol00000ooooo`00000c0?ooo`03o`00003oool0oooo02@0
oooo00?o00000?ooo`3oool0I`3oool00ol00000ooooo`00000:0?ooo`00;03oool00ol00000oooo
0?ooo`0S0?ooo`03o`00003oool0oooo06P0oooo0_l0000d0?ooo`03o`00003oool0oooo02<0oooo
00?o00000?ooo`3oool0J03oool2o`0000X0oooo000]0?ooo`;o00008`3oool00ol00000oooo0?oo
o`1W0?ooo`?o0000=@3oool2o`0002<0oooo00?o00000?ooo`3oool0I`3oool3o`0000X0oooo000_
0?ooo`03o`00003oool0oooo0200oooo00?o00000?ooo`3oool0H`3oool4o`0003X0oooo00?o0000
0?ooo`3oool0803oool00ol00000oooo0?ooo`1S0?ooo`Co00003@3oool00300oooo00?o00000?oo
o`3oool07`3oool00ol00000oooo0?ooo`1P0?ooo`?o0000?`3oool00ol00000oooo0?ooo`0O0?oo
o`03o`00003oool0oooo0600oooo0ol0000A0?ooo`00<@3oool00ol00000oooo0?ooo`0N0?ooo`03
o`00003oool0oooo05`0oooo1?l000130?ooo`03o`00003oool0oooo01h0oooo00?o00000?ooo`3o
ool0G03oool4o`0001@0oooo000b0?ooo`;o00007P3oool00ol00000oooo0?ooo`1H0?ooo`Co0000
B03oool2o`0001h0oooo00?o00000?ooo`3oool0F03oool4o`0001P0oooo000d0?ooo`03o`00003o
ool0oooo01/0oooo00?o00000?ooo`3oool0E03oool4o`0004h0oooo00?o00000?ooo`3oool06`3o
ool00ol00000oooo0?ooo`1D0?ooo`Co0000703oool003D0oooo00?o00000?ooo`3oool06P3oool0
0ol00000oooo0?ooo`1A0?ooo`?o0000D`3oool00ol00000oooo0?ooo`0J0?ooo`03o`00003oool0
oooo0540oooo0ol0000P0?ooo`00=P3oool00ol00000oooo0?ooo`0I0?ooo`03o`00003oool0oooo
04d0oooo1?l0001G0?ooo`03o`00003oool0oooo01T0oooo00?o00000?ooo`3oool0C@3oool4o`00
02<0oooo000g0?ooo`;o00006@3oool00ol00000oooo0?ooo`190?ooo`Co0000G03oool2o`0001T0
oooo00?o00000?ooo`3oool0B@3oool4o`0002L0oooo000i0?ooo`03o`00003oool0oooo01H0oooo
00?o00000?ooo`3oool0A@3oool4o`000680oooo00?o00000?ooo`3oool05P3oool00ol00000oooo
0?ooo`150?ooo`Co0000:`3oool003X0oooo00?o00000?ooo`3oool0503oool00ol00000oooo0?oo
o`130?ooo`?o0000I`3oool00ol00000oooo0?ooo`0D0?ooo`03o`00003oool0oooo04<0oooo0ol0
000_0?ooo`00>`3oool00ol00000oooo0?ooo`0C0?ooo`03o`00003oool0oooo03l0oooo1?l0001[
0?ooo`03o`00003oool0oooo01<0oooo00?o00000?ooo`3oool0?`3oool4o`000380oooo000l0?oo
o`;o00004`3oool00ol00000oooo0?ooo`0k0?ooo`Co0000L03oool2o`0001<0oooo00?o00000?oo
o`3oool0>`3oool4o`0003H0oooo000n0?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3o
ool0=`3oool4o`0007H0oooo00?o00000?ooo`3oool0403oool00ol00000oooo0?ooo`0g0?ooo`Co
0000>P3oool003l0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0c0?ooo`Co0000
N`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03<0oooo1?l0000n0?ooo`00@03o
ool00ol00000oooo0?ooo`0>0?ooo`03o`00003oool0oooo0300oooo0ol000200?ooo`03o`00003o
ool0oooo00h0oooo00?o00000?ooo`3oool0<03oool3o`000480oooo00110?ooo`03o`00003oool0
oooo00d0oooo00?o00000?ooo`3oool0;03oool4o`0008@0oooo00?o00000?ooo`3oool03@3oool0
0ol00000oooo0?ooo`0/0?ooo`Co0000A@3oool00480oooo0_l0000=0?ooo`03o`00003oool0oooo
02P0oooo1?l000290?ooo`;o00003@3oool00ol00000oooo0?ooo`0X0?ooo`Co0000B@3oool004@0
oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0T0?ooo`Co0000S`3oool00ol00000
oooo0?ooo`0:0?ooo`03o`00003oool0oooo02@0oooo1?l0001=0?ooo`00A@3oool00ol00000oooo
0?ooo`090?ooo`03o`00003oool0oooo0240oooo0ol0002D0?ooo`03o`00003oool0oooo00T0oooo
00?o00000?ooo`3oool08@3oool3o`000540oooo00160?ooo`03o`00003oool0oooo00P0oooo00?o
00000?ooo`3oool07@3oool4o`0009P0oooo00?o00000?ooo`3oool0203oool00ol00000oooo0?oo
o`0M0?ooo`Co0000E03oool004L0oooo0_l000080?ooo`03o`00003oool0oooo01T0oooo1?l0002M
0?ooo`;o0000203oool00ol00000oooo0?ooo`0I0?ooo`Co0000F03oool004T0oooo00?o00000?oo
o`3oool01@3oool00ol00000oooo0?ooo`0E0?ooo`Co0000X`3oool00ol00000oooo0?ooo`050?oo
o`03o`00003oool0oooo01D0oooo1?l0001L0?ooo`00BP3oool00ol00000oooo0?ooo`040?ooo`03
o`00003oool0oooo0180oooo0ol0002X0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3o
ool04P3oool3o`000600oooo001;0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool0
3P3oool4o`000:`0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0>0?ooo`Co0000
H`3oool004`0oooo0_l000030?ooo`03o`00003oool0oooo00X0oooo1?l0002a0?ooo`;o00000`3o
ool00ol00000oooo0?ooo`0:0?ooo`Co0000I`3oool004h0oooo00Co00000?ooo`3ooooo0000203o
ool4o`000;L0oooo00Co00000?ooo`3ooooo0000203oool4o`0006/0oooo001?0?ooo`03o`00003o
oooo000000D0oooo0ol0002l0?ooo`03o`00003ooooo000000D0oooo0ol0001_0?ooo`00D03oool2
o`0000030?ooool0003o000000;o0000`03oool2o`0000030?ooool0003o000000;o0000LP3oool0
0540oooo0_l000350?ooo`;o0000MP3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-53.3508, \
-19.1129, 1.80794, 1.80794}, {{208.5, 389.375}, {315.688, 169}} -> {-412.962, \
-19.1129, 1.80794, 1.80794}, {{9.625, 190.438}, {154.375, 7.6875}} -> \
{-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, 389.375}, {154.375, \
7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show decision regions", "Subsection"],

Cell[CellGroupData[{

Cell["RG plane", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(decRG = 
        ShowTwoClassificationRegions[p1rg, p2rg, pr, x, y, classColors, 
          False, Axes \[Rule] False, Frame \[Rule] True, \ 
          FrameTicks \[Rule] None, nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{decRG, distRG}}], 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
4e-05 4e-05 m
.00731 4e-05 L
.01524 4e-05 L
.02269 4e-05 L
.02985 4e-05 L
.03747 4e-05 L
.04481 4e-05 L
.05261 4e-05 L
.06012 4e-05 L
.06735 4e-05 L
.07504 4e-05 L
.08245 4e-05 L
.08957 4e-05 L
.09715 4e-05 L
.10445 4e-05 L
.11221 4e-05 L
.11968 4e-05 L
.12687 4e-05 L
.13452 4e-05 L
.14188 4e-05 L
.14971 4e-05 L
.15725 4e-05 L
.1645 4e-05 L
.17222 4e-05 L
.17927 4e-05 L
s
4e-05 .09206 m
.00731 .09914 L
.01524 .10685 L
.02269 .11409 L
.02985 .12105 L
.03747 .12845 L
.04481 .13557 L
.05261 .14313 L
.06012 .15041 L
.06735 .1574 L
.07504 .16484 L
.08245 .17199 L
.08957 .17886 L
.09715 .18616 L
.10445 .19319 L
.11221 .20065 L
.11968 .20782 L
.12687 .21471 L
.13452 .22204 L
.14188 .22908 L
.14971 .23655 L
.15725 .24374 L
.1645 .25064 L
.17222 .25797 L
.17927 .26465 L
s
1 1 .5 r
4e-05 4e-05 m
.00731 4e-05 L
.01524 4e-05 L
.02269 4e-05 L
.02985 4e-05 L
.03747 4e-05 L
.04481 4e-05 L
.05261 4e-05 L
.06012 4e-05 L
.06735 4e-05 L
.07504 4e-05 L
.08245 4e-05 L
.08957 4e-05 L
.09715 4e-05 L
.10445 4e-05 L
.11221 4e-05 L
.11968 4e-05 L
.12687 4e-05 L
.13452 4e-05 L
.14188 4e-05 L
.14971 4e-05 L
.15725 4e-05 L
.1645 4e-05 L
.17222 4e-05 L
.17927 4e-05 L
.17927 .26465 L
.17222 .25797 L
.1645 .25064 L
.15725 .24374 L
.14971 .23655 L
.14188 .22908 L
.13452 .22204 L
.12687 .21471 L
.11968 .20782 L
.11221 .20065 L
.10445 .19319 L
.09715 .18616 L
.08957 .17886 L
.08245 .17199 L
.07504 .16484 L
.06735 .1574 L
.06012 .15041 L
.05261 .14313 L
.04481 .13557 L
.03747 .12845 L
.02985 .12105 L
.02269 .11409 L
.01524 .10685 L
.00731 .09914 L
4e-05 .09206 L
F
0 g
4e-05 4e-05 m
.00731 4e-05 L
.01524 4e-05 L
.02269 4e-05 L
.02985 4e-05 L
.03747 4e-05 L
.04481 4e-05 L
.05261 4e-05 L
.06012 4e-05 L
.06735 4e-05 L
.07504 4e-05 L
.08245 4e-05 L
.08957 4e-05 L
.09715 4e-05 L
.10445 4e-05 L
.11221 4e-05 L
.11968 4e-05 L
.12687 4e-05 L
.13452 4e-05 L
.14188 4e-05 L
.14971 4e-05 L
.15725 4e-05 L
.1645 4e-05 L
.17222 4e-05 L
.17927 4e-05 L
s
4e-05 .09206 m
.00731 .09914 L
.01524 .10685 L
.02269 .11409 L
.02985 .12105 L
.03747 .12845 L
.04481 .13557 L
.05261 .14313 L
.06012 .15041 L
.06735 .1574 L
.07504 .16484 L
.08245 .17199 L
.08957 .17886 L
.09715 .18616 L
.10445 .19319 L
.11221 .20065 L
.11968 .20782 L
.12687 .21471 L
.13452 .22204 L
.14188 .22908 L
.14971 .23655 L
.15725 .24374 L
.1645 .25064 L
.17222 .25797 L
.17927 .26465 L
s
.17927 4e-05 m
.18895 .01631 L
.1995 .03409 L
.20942 .05081 L
.21895 .06693 L
.2291 .08413 L
.23887 .10072 L
.24925 .11841 L
.25925 .1355 L
.26887 .152 L
.27911 .16962 L
.28897 .18666 L
.29845 .20312 L
.30854 .22075 L
.31825 .23782 L
.32858 .25612 L
.33853 .27391 L
.3481 .2912 L
.35828 .30986 L
.36808 .32815 L
.3785 .34805 L
.38853 .36789 L
.39819 .38798 L
.40309 .3988 L
.40846 .41154 L
.41081 .41758 L
.41332 .42465 L
.41454 .42845 L
.41569 .43245 L
.41673 .43671 L
.41701 .4381 L
.41731 .43978 L
.41757 .44155 L
.41785 .44566 L
s
.17927 .26465 m
.18895 .2738 L
.1995 .28375 L
.20942 .29306 L
.21895 .30199 L
.2291 .31145 L
.23887 .32051 L
.24925 .3301 L
.25925 .33928 L
.26887 .34806 L
.27911 .35733 L
.28897 .36618 L
.29845 .37462 L
.30854 .3835 L
.31825 .39194 L
.32858 .40077 L
.33853 .40911 L
.3481 .41694 L
.35828 .42503 L
.36808 .43249 L
.3785 .43995 L
.38853 .44648 L
.39819 .45175 L
.40319 .45383 L
.4057 .45461 L
.40713 .45495 L
.40782 .45508 L
.40846 .45517 L
.40905 .45524 L
.40935 .45526 L
.40967 .45528 L
.41 .4553 L
.41018 .4553 L
.41035 .4553 L
.41066 .45529 L
.41099 .45528 L
.41127 .45526 L
.41158 .45523 L
.41187 .45519 L
.41213 .45514 L
.41277 .455 L
.41337 .4548 L
.41392 .45457 L
.41449 .45425 L
.41498 .4539 L
.41552 .45342 L
.4161 .45274 L
.41642 .45226 L
.41673 .4517 L
.41701 .45107 L
Mistroke
.41731 .45016 L
.41759 .44894 L
.41785 .44571 L
Mfstroke
1 1 .5 r
.17927 4e-05 m
.18895 .01631 L
.1995 .03409 L
.20942 .05081 L
.21895 .06693 L
.2291 .08413 L
.23887 .10072 L
.24925 .11841 L
.25925 .1355 L
.26887 .152 L
.27911 .16962 L
.28897 .18666 L
.29845 .20312 L
.30854 .22075 L
.31825 .23782 L
.32858 .25612 L
.33853 .27391 L
.3481 .2912 L
.35828 .30986 L
.36808 .32815 L
.3785 .34805 L
.38853 .36789 L
.39819 .38798 L
.40309 .3988 L
.40846 .41154 L
.41081 .41758 L
.41332 .42465 L
.41454 .42845 L
.41569 .43245 L
.41673 .43671 L
.41701 .4381 L
.41731 .43978 L
.41757 .44155 L
.41785 .44566 L
.41785 .44571 L
.41759 .44894 L
.41731 .45016 L
.41701 .45107 L
.41673 .4517 L
.41642 .45226 L
.4161 .45274 L
.41552 .45342 L
.41498 .4539 L
.41449 .45425 L
.41392 .45457 L
.41337 .4548 L
.41277 .455 L
.41213 .45514 L
.41187 .45519 L
.41158 .45523 L
.41127 .45526 L
.41099 .45528 L
.41066 .45529 L
.41035 .4553 L
.41018 .4553 L
.41 .4553 L
.40967 .45528 L
.40935 .45526 L
.40905 .45524 L
.40846 .45517 L
.40782 .45508 L
.40713 .45495 L
.4057 .45461 L
.40319 .45383 L
.39819 .45175 L
.38853 .44648 L
.3785 .43995 L
.36808 .43249 L
.35828 .42503 L
.3481 .41694 L
.33853 .40911 L
.32858 .40077 L
.31825 .39194 L
.30854 .3835 L
.29845 .37462 L
.28897 .36618 L
.27911 .35733 L
.26887 .34806 L
.25925 .33928 L
.24925 .3301 L
.23887 .32051 L
.2291 .31145 L
.21895 .30199 L
.20942 .29306 L
.1995 .28375 L
.18895 .2738 L
.17927 .26465 L
F
0 g
.17927 4e-05 m
.18895 .01631 L
.1995 .03409 L
.20942 .05081 L
.21895 .06693 L
.2291 .08413 L
.23887 .10072 L
.24925 .11841 L
.25925 .1355 L
.26887 .152 L
.27911 .16962 L
.28897 .18666 L
.29845 .20312 L
.30854 .22075 L
.31825 .23782 L
.32858 .25612 L
.33853 .27391 L
.3481 .2912 L
.35828 .30986 L
.36808 .32815 L
.3785 .34805 L
.38853 .36789 L
.39819 .38798 L
.40309 .3988 L
.40846 .41154 L
.41081 .41758 L
.41332 .42465 L
.41454 .42845 L
.41569 .43245 L
.41673 .43671 L
.41701 .4381 L
.41731 .43978 L
.41757 .44155 L
.41785 .44566 L
s
.17927 .26465 m
.18895 .2738 L
.1995 .28375 L
.20942 .29306 L
.21895 .30199 L
.2291 .31145 L
.23887 .32051 L
.24925 .3301 L
.25925 .33928 L
.26887 .34806 L
.27911 .35733 L
.28897 .36618 L
.29845 .37462 L
.30854 .3835 L
.31825 .39194 L
.32858 .40077 L
.33853 .40911 L
.3481 .41694 L
.35828 .42503 L
.36808 .43249 L
.3785 .43995 L
.38853 .44648 L
.39819 .45175 L
.40319 .45383 L
.4057 .45461 L
.40713 .45495 L
.40782 .45508 L
.40846 .45517 L
.40905 .45524 L
.40935 .45526 L
.40967 .45528 L
.41 .4553 L
.41018 .4553 L
.41035 .4553 L
.41066 .45529 L
.41099 .45528 L
.41127 .45526 L
.41158 .45523 L
.41187 .45519 L
.41213 .45514 L
.41277 .455 L
.41337 .4548 L
.41392 .45457 L
.41449 .45425 L
.41498 .4539 L
.41552 .45342 L
.4161 .45274 L
.41642 .45226 L
.41673 .4517 L
.41701 .45107 L
Mistroke
.41731 .45016 L
.41759 .44894 L
.41785 .44571 L
Mfstroke
4e-05 .09206 m
.00731 .09914 L
.01524 .10685 L
.02269 .11409 L
.02985 .12105 L
.03747 .12845 L
.04481 .13557 L
.05261 .14313 L
.06012 .15041 L
.06735 .1574 L
.07504 .16484 L
.08245 .17199 L
.08957 .17886 L
.09715 .18616 L
.10445 .19319 L
.11221 .20065 L
.11968 .20782 L
.12687 .21471 L
.13452 .22204 L
.14188 .22908 L
.14971 .23655 L
.15725 .24374 L
.1645 .25064 L
.17222 .25797 L
.17927 .26465 L
s
4e-05 .99996 m
.00731 .99996 L
.01524 .99996 L
.02269 .99996 L
.02985 .99996 L
.03747 .99996 L
.04481 .99996 L
.05261 .99996 L
.06012 .99996 L
.06735 .99996 L
.07504 .99996 L
.08245 .99996 L
.08957 .99996 L
.09715 .99996 L
.10445 .99996 L
.11221 .99996 L
.11968 .99996 L
.12687 .99996 L
.13452 .99996 L
.14188 .99996 L
.14971 .99996 L
.15725 .99996 L
.1645 .99996 L
.17222 .99996 L
.17927 .99996 L
s
.5 1 1 r
4e-05 .09206 m
.00731 .09914 L
.01524 .10685 L
.02269 .11409 L
.02985 .12105 L
.03747 .12845 L
.04481 .13557 L
.05261 .14313 L
.06012 .15041 L
.06735 .1574 L
.07504 .16484 L
.08245 .17199 L
.08957 .17886 L
.09715 .18616 L
.10445 .19319 L
.11221 .20065 L
.11968 .20782 L
.12687 .21471 L
.13452 .22204 L
.14188 .22908 L
.14971 .23655 L
.15725 .24374 L
.1645 .25064 L
.17222 .25797 L
.17927 .26465 L
.17927 .99996 L
.17222 .99996 L
.1645 .99996 L
.15725 .99996 L
.14971 .99996 L
.14188 .99996 L
.13452 .99996 L
.12687 .99996 L
.11968 .99996 L
.11221 .99996 L
.10445 .99996 L
.09715 .99996 L
.08957 .99996 L
.08245 .99996 L
.07504 .99996 L
.06735 .99996 L
.06012 .99996 L
.05261 .99996 L
.04481 .99996 L
.03747 .99996 L
.02985 .99996 L
.02269 .99996 L
.01524 .99996 L
.00731 .99996 L
4e-05 .99996 L
F
0 g
4e-05 .09206 m
.00731 .09914 L
.01524 .10685 L
.02269 .11409 L
.02985 .12105 L
.03747 .12845 L
.04481 .13557 L
.05261 .14313 L
.06012 .15041 L
.06735 .1574 L
.07504 .16484 L
.08245 .17199 L
.08957 .17886 L
.09715 .18616 L
.10445 .19319 L
.11221 .20065 L
.11968 .20782 L
.12687 .21471 L
.13452 .22204 L
.14188 .22908 L
.14971 .23655 L
.15725 .24374 L
.1645 .25064 L
.17222 .25797 L
.17927 .26465 L
s
4e-05 .99996 m
.00731 .99996 L
.01524 .99996 L
.02269 .99996 L
.02985 .99996 L
.03747 .99996 L
.04481 .99996 L
.05261 .99996 L
.06012 .99996 L
.06735 .99996 L
.07504 .99996 L
.08245 .99996 L
.08957 .99996 L
.09715 .99996 L
.10445 .99996 L
.11221 .99996 L
.11968 .99996 L
.12687 .99996 L
.13452 .99996 L
.14188 .99996 L
.14971 .99996 L
.15725 .99996 L
.1645 .99996 L
.17222 .99996 L
.17927 .99996 L
s
.17927 4e-05 m
.18895 4e-05 L
.1995 4e-05 L
.20942 4e-05 L
.21895 4e-05 L
.2291 4e-05 L
.23887 4e-05 L
.24925 4e-05 L
.25925 4e-05 L
.26887 4e-05 L
.27911 4e-05 L
.28897 4e-05 L
.29845 4e-05 L
.30854 4e-05 L
.31825 4e-05 L
.32858 4e-05 L
.33853 4e-05 L
.3481 4e-05 L
.35828 4e-05 L
.36808 4e-05 L
.3785 4e-05 L
.38853 4e-05 L
.39819 4e-05 L
.40846 4e-05 L
.41785 4e-05 L
s
.17927 4e-05 m
.18895 .01631 L
.1995 .03409 L
.20942 .05081 L
.21895 .06693 L
.2291 .08413 L
.23887 .10072 L
.24925 .11841 L
.25925 .1355 L
.26887 .152 L
.27911 .16962 L
.28897 .18666 L
.29845 .20312 L
.30854 .22075 L
.31825 .23782 L
.32858 .25612 L
.33853 .27391 L
.3481 .2912 L
.35828 .30986 L
.36808 .32815 L
.3785 .34805 L
.38853 .36789 L
.39819 .38798 L
.40309 .3988 L
.40846 .41154 L
.41081 .41758 L
.41332 .42465 L
.41454 .42845 L
.41569 .43245 L
.41673 .43671 L
.41701 .4381 L
.41731 .43978 L
.41757 .44155 L
.41785 .44566 L
s
.5 1 1 r
.17927 4e-05 m
.18895 4e-05 L
.1995 4e-05 L
.20942 4e-05 L
.21895 4e-05 L
.2291 4e-05 L
.23887 4e-05 L
.24925 4e-05 L
.25925 4e-05 L
.26887 4e-05 L
.27911 4e-05 L
.28897 4e-05 L
.29845 4e-05 L
.30854 4e-05 L
.31825 4e-05 L
.32858 4e-05 L
.33853 4e-05 L
.3481 4e-05 L
.35828 4e-05 L
.36808 4e-05 L
.3785 4e-05 L
.38853 4e-05 L
.39819 4e-05 L
.40846 4e-05 L
.41785 4e-05 L
.41785 .44566 L
.41757 .44155 L
.41731 .43978 L
.41701 .4381 L
.41673 .43671 L
.41569 .43245 L
.41454 .42845 L
.41332 .42465 L
.41081 .41758 L
.40846 .41154 L
.40309 .3988 L
.39819 .38798 L
.38853 .36789 L
.3785 .34805 L
.36808 .32815 L
.35828 .30986 L
.3481 .2912 L
.33853 .27391 L
.32858 .25612 L
.31825 .23782 L
.30854 .22075 L
.29845 .20312 L
.28897 .18666 L
.27911 .16962 L
.26887 .152 L
.25925 .1355 L
.24925 .11841 L
.23887 .10072 L
.2291 .08413 L
.21895 .06693 L
.20942 .05081 L
.1995 .03409 L
.18895 .01631 L
.17927 4e-05 L
F
0 g
.17927 4e-05 m
.18895 4e-05 L
.1995 4e-05 L
.20942 4e-05 L
.21895 4e-05 L
.2291 4e-05 L
.23887 4e-05 L
.24925 4e-05 L
.25925 4e-05 L
.26887 4e-05 L
.27911 4e-05 L
.28897 4e-05 L
.29845 4e-05 L
.30854 4e-05 L
.31825 4e-05 L
.32858 4e-05 L
.33853 4e-05 L
.3481 4e-05 L
.35828 4e-05 L
.36808 4e-05 L
.3785 4e-05 L
.38853 4e-05 L
.39819 4e-05 L
.40846 4e-05 L
.41785 4e-05 L
s
.17927 4e-05 m
.18895 .01631 L
.1995 .03409 L
.20942 .05081 L
.21895 .06693 L
.2291 .08413 L
.23887 .10072 L
.24925 .11841 L
.25925 .1355 L
.26887 .152 L
.27911 .16962 L
.28897 .18666 L
.29845 .20312 L
.30854 .22075 L
.31825 .23782 L
.32858 .25612 L
.33853 .27391 L
.3481 .2912 L
.35828 .30986 L
.36808 .32815 L
.3785 .34805 L
.38853 .36789 L
.39819 .38798 L
.40309 .3988 L
.40846 .41154 L
.41081 .41758 L
.41332 .42465 L
.41454 .42845 L
.41569 .43245 L
.41673 .43671 L
.41701 .4381 L
.41731 .43978 L
.41757 .44155 L
.41785 .44566 L
s
.41785 4e-05 m
.44147 4e-05 L
.46722 4e-05 L
.49141 4e-05 L
.51467 4e-05 L
.53943 4e-05 L
.56326 4e-05 L
.58859 4e-05 L
.613 4e-05 L
.63648 4e-05 L
.66146 4e-05 L
.68551 4e-05 L
.70863 4e-05 L
.73326 4e-05 L
.75695 4e-05 L
.78215 4e-05 L
.80642 4e-05 L
.82977 4e-05 L
.85461 4e-05 L
.87853 4e-05 L
.90394 4e-05 L
.92843 4e-05 L
.95199 4e-05 L
.97706 4e-05 L
.99996 4e-05 L
s
.41785 .99996 m
.44147 .99996 L
.46722 .99996 L
.49141 .99996 L
.51467 .99996 L
.53943 .99996 L
.56326 .99996 L
.58859 .99996 L
.613 .99996 L
.63648 .99996 L
.66146 .99996 L
.68551 .99996 L
.70863 .99996 L
.73326 .99996 L
.75695 .99996 L
.78215 .99996 L
.80642 .99996 L
.82977 .99996 L
.85461 .99996 L
.87853 .99996 L
.90394 .99996 L
.92843 .99996 L
.95199 .99996 L
.97706 .99996 L
.99996 .99996 L
s
.5 1 1 r
.41785 4e-05 m
.44147 4e-05 L
.46722 4e-05 L
.49141 4e-05 L
.51467 4e-05 L
.53943 4e-05 L
.56326 4e-05 L
.58859 4e-05 L
.613 4e-05 L
.63648 4e-05 L
.66146 4e-05 L
.68551 4e-05 L
.70863 4e-05 L
.73326 4e-05 L
.75695 4e-05 L
.78215 4e-05 L
.80642 4e-05 L
.82977 4e-05 L
.85461 4e-05 L
.87853 4e-05 L
.90394 4e-05 L
.92843 4e-05 L
.95199 4e-05 L
.97706 4e-05 L
.99996 4e-05 L
.99996 .99996 L
.97706 .99996 L
.95199 .99996 L
.92843 .99996 L
.90394 .99996 L
.87853 .99996 L
.85461 .99996 L
.82977 .99996 L
.80642 .99996 L
.78215 .99996 L
.75695 .99996 L
.73326 .99996 L
.70863 .99996 L
.68551 .99996 L
.66146 .99996 L
.63648 .99996 L
.613 .99996 L
.58859 .99996 L
.56326 .99996 L
.53943 .99996 L
.51467 .99996 L
.49141 .99996 L
.46722 .99996 L
.44147 .99996 L
.41785 .99996 L
F
0 g
.41785 4e-05 m
.44147 4e-05 L
.46722 4e-05 L
.49141 4e-05 L
.51467 4e-05 L
.53943 4e-05 L
.56326 4e-05 L
.58859 4e-05 L
.613 4e-05 L
.63648 4e-05 L
.66146 4e-05 L
.68551 4e-05 L
.70863 4e-05 L
.73326 4e-05 L
.75695 4e-05 L
.78215 4e-05 L
.80642 4e-05 L
.82977 4e-05 L
.85461 4e-05 L
.87853 4e-05 L
.90394 4e-05 L
.92843 4e-05 L
.95199 4e-05 L
.97706 4e-05 L
.99996 4e-05 L
s
.41785 .99996 m
.44147 .99996 L
.46722 .99996 L
.49141 .99996 L
.51467 .99996 L
.53943 .99996 L
.56326 .99996 L
.58859 .99996 L
.613 .99996 L
.63648 .99996 L
.66146 .99996 L
.68551 .99996 L
.70863 .99996 L
.73326 .99996 L
.75695 .99996 L
.78215 .99996 L
.80642 .99996 L
.82977 .99996 L
.85461 .99996 L
.87853 .99996 L
.90394 .99996 L
.92843 .99996 L
.95199 .99996 L
.97706 .99996 L
.99996 .99996 L
s
.17927 .26465 m
.18895 .2738 L
.1995 .28375 L
.20942 .29306 L
.21895 .30199 L
.2291 .31145 L
.23887 .32051 L
.24925 .3301 L
.25925 .33928 L
.26887 .34806 L
.27911 .35733 L
.28897 .36618 L
.29845 .37462 L
.30854 .3835 L
.31825 .39194 L
.32858 .40077 L
.33853 .40911 L
.3481 .41694 L
.35828 .42503 L
.36808 .43249 L
.3785 .43995 L
.38853 .44648 L
.39819 .45175 L
.40319 .45383 L
.4057 .45461 L
.40713 .45495 L
.40782 .45508 L
.40846 .45517 L
.40905 .45524 L
.40935 .45526 L
.40967 .45528 L
.41 .4553 L
.41018 .4553 L
.41035 .4553 L
.41066 .45529 L
.41099 .45528 L
.41127 .45526 L
.41158 .45523 L
.41187 .45519 L
.41213 .45514 L
.41277 .455 L
.41337 .4548 L
.41392 .45457 L
.41449 .45425 L
.41498 .4539 L
.41552 .45342 L
.4161 .45274 L
.41642 .45226 L
.41673 .4517 L
.41701 .45107 L
Mistroke
.41731 .45016 L
.41759 .44894 L
.41785 .44571 L
Mfstroke
.17927 .99996 m
.18895 .99996 L
.1995 .99996 L
.20942 .99996 L
.21895 .99996 L
.2291 .99996 L
.23887 .99996 L
.24925 .99996 L
.25925 .99996 L
.26887 .99996 L
.27911 .99996 L
.28897 .99996 L
.29845 .99996 L
.30854 .99996 L
.31825 .99996 L
.32858 .99996 L
.33853 .99996 L
.3481 .99996 L
.35828 .99996 L
.36808 .99996 L
.3785 .99996 L
.38853 .99996 L
.39819 .99996 L
.40846 .99996 L
.41785 .99996 L
s
.5 1 1 r
.17927 .26465 m
.18895 .2738 L
.1995 .28375 L
.20942 .29306 L
.21895 .30199 L
.2291 .31145 L
.23887 .32051 L
.24925 .3301 L
.25925 .33928 L
.26887 .34806 L
.27911 .35733 L
.28897 .36618 L
.29845 .37462 L
.30854 .3835 L
.31825 .39194 L
.32858 .40077 L
.33853 .40911 L
.3481 .41694 L
.35828 .42503 L
.36808 .43249 L
.3785 .43995 L
.38853 .44648 L
.39819 .45175 L
.40319 .45383 L
.4057 .45461 L
.40713 .45495 L
.40782 .45508 L
.40846 .45517 L
.40905 .45524 L
.40935 .45526 L
.40967 .45528 L
.41 .4553 L
.41018 .4553 L
.41035 .4553 L
.41066 .45529 L
.41099 .45528 L
.41127 .45526 L
.41158 .45523 L
.41187 .45519 L
.41213 .45514 L
.41277 .455 L
.41337 .4548 L
.41392 .45457 L
.41449 .45425 L
.41498 .4539 L
.41552 .45342 L
.4161 .45274 L
.41642 .45226 L
.41673 .4517 L
.41701 .45107 L
.41731 .45016 L
.41759 .44894 L
.41785 .44571 L
.41785 .99996 L
.40846 .99996 L
.39819 .99996 L
.38853 .99996 L
.3785 .99996 L
.36808 .99996 L
.35828 .99996 L
.3481 .99996 L
.33853 .99996 L
.32858 .99996 L
.31825 .99996 L
.30854 .99996 L
.29845 .99996 L
.28897 .99996 L
.27911 .99996 L
.26887 .99996 L
.25925 .99996 L
.24925 .99996 L
.23887 .99996 L
.2291 .99996 L
.21895 .99996 L
.20942 .99996 L
.1995 .99996 L
.18895 .99996 L
.17927 .99996 L
F
0 g
.17927 .26465 m
.18895 .2738 L
.1995 .28375 L
.20942 .29306 L
.21895 .30199 L
.2291 .31145 L
.23887 .32051 L
.24925 .3301 L
.25925 .33928 L
.26887 .34806 L
.27911 .35733 L
.28897 .36618 L
.29845 .37462 L
.30854 .3835 L
.31825 .39194 L
.32858 .40077 L
.33853 .40911 L
.3481 .41694 L
.35828 .42503 L
.36808 .43249 L
.3785 .43995 L
.38853 .44648 L
.39819 .45175 L
.40319 .45383 L
.4057 .45461 L
.40713 .45495 L
.40782 .45508 L
.40846 .45517 L
.40905 .45524 L
.40935 .45526 L
.40967 .45528 L
.41 .4553 L
.41018 .4553 L
.41035 .4553 L
.41066 .45529 L
.41099 .45528 L
.41127 .45526 L
.41158 .45523 L
.41187 .45519 L
.41213 .45514 L
.41277 .455 L
.41337 .4548 L
.41392 .45457 L
.41449 .45425 L
.41498 .4539 L
.41552 .45342 L
.4161 .45274 L
.41642 .45226 L
.41673 .4517 L
.41701 .45107 L
Mistroke
.41731 .45016 L
.41759 .44894 L
.41785 .44571 L
Mfstroke
.17927 .99996 m
.18895 .99996 L
.1995 .99996 L
.20942 .99996 L
.21895 .99996 L
.2291 .99996 L
.23887 .99996 L
.24925 .99996 L
.25925 .99996 L
.26887 .99996 L
.27911 .99996 L
.28897 .99996 L
.29845 .99996 L
.30854 .99996 L
.31825 .99996 L
.32858 .99996 L
.33853 .99996 L
.3481 .99996 L
.35828 .99996 L
.36808 .99996 L
.3785 .99996 L
.38853 .99996 L
.39819 .99996 L
.40846 .99996 L
.41785 .99996 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 0 r
.02 w
.06278 .06278 Mdot
.06278 .05886 Mdot
.06278 .05886 Mdot
.0667 .06278 Mdot
.0667 .06278 Mdot
.07062 .0667 Mdot
.07062 .0667 Mdot
.08239 .07454 Mdot
.07846 .07454 Mdot
.08239 .07846 Mdot
.08631 .07454 Mdot
.07454 .07062 Mdot
.07846 .07454 Mdot
.07454 .07846 Mdot
.0667 .07062 Mdot
.0667 .07062 Mdot
.0667 .07454 Mdot
.07454 .07846 Mdot
.07846 .08239 Mdot
.0667 .07062 Mdot
.0667 .07062 Mdot
.06278 .07062 Mdot
.05494 .06278 Mdot
.05494 .06278 Mdot
.06278 .07454 Mdot
.06278 .07846 Mdot
.0667 .07454 Mdot
.06278 .07062 Mdot
.07062 .07846 Mdot
.07454 .07846 Mdot
.08239 .07846 Mdot
.07846 .07846 Mdot
.07846 .07846 Mdot
.07454 .07454 Mdot
.08239 .08631 Mdot
.08631 .09023 Mdot
.08631 .09023 Mdot
.07846 .08631 Mdot
.07846 .08631 Mdot
.08239 .09415 Mdot
.07846 .08631 Mdot
.07846 .08239 Mdot
.07062 .07846 Mdot
.07454 .08631 Mdot
.07846 .09023 Mdot
.07454 .08631 Mdot
.07454 .08239 Mdot
.07454 .07846 Mdot
.07846 .08239 Mdot
.08239 .08239 Mdot
.09023 .09023 Mdot
.09023 .09023 Mdot
.09023 .08631 Mdot
.09415 .09415 Mdot
.08631 .09023 Mdot
.09023 .09807 Mdot
.09023 .09807 Mdot
.08631 .09023 Mdot
.07846 .08239 Mdot
.07846 .08631 Mdot
.07846 .08631 Mdot
.07062 .07846 Mdot
.0667 .07846 Mdot
.07062 .08239 Mdot
.07062 .08239 Mdot
.07062 .07454 Mdot
.07846 .08239 Mdot
.07846 .08631 Mdot
.08239 .09023 Mdot
.08239 .09023 Mdot
.08239 .09023 Mdot
.09023 .09807 Mdot
.09023 .09807 Mdot
.07846 .08239 Mdot
.07846 .08239 Mdot
.07454 .07454 Mdot
.07846 .07846 Mdot
.08631 .09023 Mdot
.09023 .09807 Mdot
.09023 .09807 Mdot
.08239 .09023 Mdot
.08631 .09415 Mdot
.08239 .09415 Mdot
.08239 .09415 Mdot
.08239 .09415 Mdot
.08239 .09415 Mdot
.09023 .09807 Mdot
.08631 .08239 Mdot
.08631 .08631 Mdot
.08631 .08631 Mdot
.08631 .08239 Mdot
.09023 .08631 Mdot
.08631 .08631 Mdot
.08631 .08631 Mdot
.08239 .08631 Mdot
.08631 .09023 Mdot
.07846 .08239 Mdot
.07846 .08239 Mdot
.07454 .07846 Mdot
.07454 .07062 Mdot
.08631 .08239 Mdot
.07846 .07846 Mdot
.07454 .07454 Mdot
.07454 .07454 Mdot
.07062 .07062 Mdot
.07454 .07454 Mdot
.06278 .0667 Mdot
.0667 .07062 Mdot
.07062 .07454 Mdot
.0667 .07062 Mdot
.07846 .07454 Mdot
.07454 .07454 Mdot
.07062 .07062 Mdot
.0667 .0667 Mdot
.07062 .07062 Mdot
.0667 .0667 Mdot
.0667 .05886 Mdot
.05494 .04709 Mdot
.05886 .05494 Mdot
.05494 .05494 Mdot
.05494 .05886 Mdot
.05886 .0667 Mdot
.06278 .07454 Mdot
.05494 .07062 Mdot
.05102 .06278 Mdot
.04709 .05886 Mdot
.04317 .05102 Mdot
.03925 .05102 Mdot
.04709 .05494 Mdot
.04317 .05102 Mdot
.04317 .04317 Mdot
.04317 .03925 Mdot
.05494 .05886 Mdot
.04709 .05494 Mdot
.04317 .05494 Mdot
.04317 .04709 Mdot
.05102 .04317 Mdot
.04709 .03533 Mdot
.04709 .03925 Mdot
.04317 .05102 Mdot
.03533 .03925 Mdot
.03533 .04317 Mdot
.03533 .04709 Mdot
.04709 .05886 Mdot
.00396 .00788 Mdot
.00396 .00788 Mdot
.00788 .00788 Mdot
.00396 .00788 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.0118 .00788 Mdot
.0118 .00788 Mdot
.0118 .00788 Mdot
.00788 .00396 Mdot
.00396 .00396 Mdot
.00788 .00396 Mdot
.01572 .00788 Mdot
.01572 .00788 Mdot
.01965 .00788 Mdot
.08631 .09807 Mdot
.10591 .1216 Mdot
.11768 .12944 Mdot
.11768 .12944 Mdot
.11376 .1216 Mdot
.11768 .13336 Mdot
.1216 .1412 Mdot
.11768 .13728 Mdot
.10591 .12552 Mdot
.10199 .1216 Mdot
.10983 .12944 Mdot
.11768 .1412 Mdot
.12552 .14513 Mdot
.1216 .1412 Mdot
.1216 .13728 Mdot
.11768 .12944 Mdot
.1216 .13336 Mdot
.11768 .12552 Mdot
.11768 .13336 Mdot
.1216 .1412 Mdot
.1216 .1412 Mdot
.11768 .1412 Mdot
.10199 .1216 Mdot
.10983 .12944 Mdot
.10591 .12944 Mdot
.10199 .12944 Mdot
.10591 .12944 Mdot
.11376 .13728 Mdot
.12552 .1412 Mdot
.12944 .1412 Mdot
.12552 .13728 Mdot
.12944 .14513 Mdot
.13336 .14905 Mdot
.13336 .15297 Mdot
.12944 .14905 Mdot
.11768 .1412 Mdot
.12552 .14905 Mdot
.13336 .16473 Mdot
.13728 .17257 Mdot
.14513 .1765 Mdot
.13728 .16865 Mdot
.14513 .16473 Mdot
.13728 .14905 Mdot
.13728 .15297 Mdot
.14905 .16473 Mdot
.1412 .16473 Mdot
.13728 .15689 Mdot
.1412 .16865 Mdot
.14905 .17257 Mdot
.15297 .1765 Mdot
.16473 .18434 Mdot
.15689 .17257 Mdot
.15689 .16865 Mdot
.1412 .15297 Mdot
.14513 .16081 Mdot
.14905 .17257 Mdot
.13728 .16865 Mdot
.14905 .18434 Mdot
.14905 .18042 Mdot
.15297 .1765 Mdot
.15689 .18434 Mdot
.14905 .16865 Mdot
.15689 .17257 Mdot
.15297 .16865 Mdot
.14905 .16865 Mdot
.14513 .16865 Mdot
.14905 .1765 Mdot
.14905 .17257 Mdot
.15297 .1765 Mdot
.14905 .18042 Mdot
.13336 .16473 Mdot
.1412 .16865 Mdot
.14905 .1765 Mdot
.14513 .17257 Mdot
.15297 .18434 Mdot
.14905 .17257 Mdot
.14513 .16865 Mdot
.16865 .1961 Mdot
.14905 .17257 Mdot
.14905 .1765 Mdot
.15689 .18434 Mdot
.17257 .19218 Mdot
.1412 .16081 Mdot
.16081 .18042 Mdot
.14905 .16473 Mdot
.15689 .17257 Mdot
.16081 .18042 Mdot
.1765 .19218 Mdot
.1765 .19218 Mdot
.17257 .18434 Mdot
.17257 .18434 Mdot
.17257 .18434 Mdot
.1765 .19218 Mdot
.16081 .1765 Mdot
.15297 .16865 Mdot
.14513 .16473 Mdot
.14905 .17257 Mdot
.14513 .17257 Mdot
.15689 .1765 Mdot
.16473 .18434 Mdot
.16473 .18434 Mdot
.16473 .18042 Mdot
.16473 .16865 Mdot
.15689 .16473 Mdot
.16081 .1765 Mdot
.16473 .1765 Mdot
.13728 .14513 Mdot
.13336 .1412 Mdot
.12944 .13728 Mdot
.1216 .12944 Mdot
.12944 .13336 Mdot
.13336 .1412 Mdot
.12552 .12944 Mdot
.12552 .13336 Mdot
.13336 .13728 Mdot
.12552 .13728 Mdot
.1216 .12552 Mdot
.10591 .11376 Mdot
.1412 .15297 Mdot
.12944 .13728 Mdot
.13336 .1412 Mdot
.13336 .14513 Mdot
.12944 .1412 Mdot
.10983 .12552 Mdot
.10591 .12552 Mdot
.11376 .12552 Mdot
.11376 .12552 Mdot
.10591 .11768 Mdot
.10199 .11376 Mdot
.10591 .11768 Mdot
.09807 .10983 Mdot
.10591 .11768 Mdot
.09807 .1216 Mdot
.09023 .11768 Mdot
.09023 .1216 Mdot
.11768 .15297 Mdot
.04709 .05494 Mdot
.05102 .04709 Mdot
.05102 .05102 Mdot
.03533 .04317 Mdot
.03533 .04317 Mdot
.07846 .10199 Mdot
.05102 .0667 Mdot
.00396 .00788 Mdot
.00788 .00788 Mdot
.00788 .01572 Mdot
.00396 .00788 Mdot
.00396 .00788 Mdot
.00788 .00788 Mdot
.00788 .00788 Mdot
.00396 .00788 Mdot
.00396 .01572 Mdot
.00396 .01572 Mdot
.00396 .0118 Mdot
.00396 .0118 Mdot
.00396 .0118 Mdot
.00396 .01572 Mdot
.00788 .01572 Mdot
.01572 .0118 Mdot
.01965 .0118 Mdot
.59215 .68234 Mdot
.61176 .70587 Mdot
.62352 .72547 Mdot
.62352 .72939 Mdot
.4902 .56862 Mdot
.12552 .1412 Mdot
.09807 .10591 Mdot
.09807 .11376 Mdot
.0667 .07846 Mdot
.05886 .07062 Mdot
.05886 .07062 Mdot
.07454 .09415 Mdot
.09415 .10983 Mdot
.09807 .11376 Mdot
.10199 .11768 Mdot
.10591 .11376 Mdot
.10983 .1216 Mdot
.10591 .1216 Mdot
.10983 .12552 Mdot
.11376 .12552 Mdot
.10199 .11376 Mdot
.10983 .12552 Mdot
.10983 .12552 Mdot
.1216 .13336 Mdot
.11768 .13728 Mdot
.11376 .13728 Mdot
.1216 .14513 Mdot
.11768 .13728 Mdot
.11768 .13728 Mdot
.1216 .1412 Mdot
.12552 .1412 Mdot
.12944 .14513 Mdot
.12944 .14513 Mdot
.12944 .15297 Mdot
.12552 .14513 Mdot
.11768 .13336 Mdot
.1216 .14513 Mdot
.10983 .1412 Mdot
.11768 .14905 Mdot
.13336 .15297 Mdot
.13728 .15297 Mdot
.1412 .15297 Mdot
.13336 .1412 Mdot
.13728 .14905 Mdot
.1412 .14905 Mdot
.1216 .12944 Mdot
.12552 .13336 Mdot
.12944 .1412 Mdot
.13336 .15689 Mdot
.13336 .15297 Mdot
.14513 .16473 Mdot
.14905 .16473 Mdot
.14905 .16081 Mdot
.1412 .14905 Mdot
.14905 .16081 Mdot
.1412 .16473 Mdot
.14513 .16865 Mdot
.15297 .1765 Mdot
.15689 .18042 Mdot
.16081 .18042 Mdot
.16081 .1765 Mdot
.16473 .18042 Mdot
.16081 .16473 Mdot
.16081 .17257 Mdot
.16081 .1765 Mdot
.16081 .18042 Mdot
.15297 .17257 Mdot
.16473 .18826 Mdot
.16081 .18434 Mdot
.15297 .1765 Mdot
.15297 .1765 Mdot
.16081 .18042 Mdot
.16473 .18434 Mdot
.16081 .18434 Mdot
.16081 .18826 Mdot
.14513 .16865 Mdot
.15689 .1765 Mdot
.16081 .18042 Mdot
.16865 .18826 Mdot
.16473 .18434 Mdot
.16081 .18042 Mdot
.15297 .17257 Mdot
.14513 .16473 Mdot
.14905 .16865 Mdot
.14905 .16865 Mdot
.14513 .15689 Mdot
.15297 .16081 Mdot
.15689 .16473 Mdot
.16865 .18042 Mdot
.17257 .18434 Mdot
.18042 .19218 Mdot
.18434 .1961 Mdot
.1765 .19218 Mdot
.16473 .18434 Mdot
.16865 .18826 Mdot
.17257 .1961 Mdot
.16473 .1961 Mdot
.18434 .21179 Mdot
.18826 .21179 Mdot
.18826 .20787 Mdot
.18042 .1961 Mdot
.19218 .21179 Mdot
.19218 .20787 Mdot
.18042 .1961 Mdot
.18434 .20394 Mdot
.18434 .1961 Mdot
.1765 .18434 Mdot
.16865 .18042 Mdot
.15689 .16865 Mdot
.16473 .18434 Mdot
.16865 .18042 Mdot
.18042 .18826 Mdot
.1765 .18434 Mdot
.15297 .16865 Mdot
.15297 .16473 Mdot
.14905 .15689 Mdot
.1412 .14905 Mdot
.14905 .16081 Mdot
.14513 .16081 Mdot
.1412 .15297 Mdot
.14513 .15297 Mdot
.15297 .16081 Mdot
.14513 .15689 Mdot
.14513 .16473 Mdot
.14513 .15689 Mdot
.13728 .14905 Mdot
.14513 .16081 Mdot
.1412 .15689 Mdot
.13336 .14905 Mdot
.13728 .15689 Mdot
.1216 .13728 Mdot
.12552 .1412 Mdot
.12552 .1412 Mdot
.12944 .1412 Mdot
.10591 .1216 Mdot
.10983 .13336 Mdot
.10591 .12552 Mdot
.09023 .10591 Mdot
.09023 .10983 Mdot
.09023 .10591 Mdot
.08239 .09807 Mdot
.09415 .11768 Mdot
.10199 .1216 Mdot
.08631 .10591 Mdot
.08239 .09807 Mdot
.08239 .09807 Mdot
.07454 .08631 Mdot
.07062 .08239 Mdot
.09023 .10199 Mdot
.09415 .10591 Mdot
.09023 .10591 Mdot
.07846 .09023 Mdot
.07846 .09807 Mdot
.07454 .09023 Mdot
.07846 .09415 Mdot
.07846 .09415 Mdot
.08239 .10199 Mdot
.08631 .10983 Mdot
.08239 .10199 Mdot
.08631 .10199 Mdot
.59215 .68234 Mdot
.61568 .71763 Mdot
.63136 .73332 Mdot
.62352 .72547 Mdot
.59999 .69802 Mdot
.25492 .29413 Mdot
.07062 .07846 Mdot
.09807 .11768 Mdot
.08631 .10199 Mdot
.07454 .09023 Mdot
.08239 .10199 Mdot
.08631 .10983 Mdot
.10199 .12552 Mdot
.10199 .12944 Mdot
.09415 .1216 Mdot
.09807 .11768 Mdot
.10591 .12944 Mdot
.11768 .1412 Mdot
.1216 .13728 Mdot
.1216 .13336 Mdot
.1216 .12944 Mdot
.1216 .1216 Mdot
.1216 .12944 Mdot
.12552 .13336 Mdot
.12944 .13728 Mdot
.12944 .1412 Mdot
.12552 .1412 Mdot
.10591 .12552 Mdot
.11376 .1412 Mdot
.11768 .14513 Mdot
.1216 .14905 Mdot
.1216 .15297 Mdot
.1216 .14905 Mdot
.1216 .15297 Mdot
.1216 .14513 Mdot
.12944 .14905 Mdot
.1412 .16473 Mdot
.1412 .16865 Mdot
.12944 .16081 Mdot
.13336 .16081 Mdot
.14513 .16473 Mdot
.14513 .16473 Mdot
.14513 .16081 Mdot
.1412 .14905 Mdot
.14513 .15297 Mdot
.1412 .14905 Mdot
.13336 .1412 Mdot
.1412 .15297 Mdot
.13728 .14905 Mdot
.13336 .15689 Mdot
.1412 .16473 Mdot
.15689 .1765 Mdot
.14905 .16865 Mdot
.1412 .15689 Mdot
.13728 .15689 Mdot
.14905 .17257 Mdot
.15297 .18042 Mdot
.16081 .18042 Mdot
.16865 .18826 Mdot
.16473 .1765 Mdot
.17257 .18826 Mdot
.1961 .20394 Mdot
.18826 .18826 Mdot
.1765 .18042 Mdot
.1961 .1961 Mdot
.18434 .19218 Mdot
.18042 .18826 Mdot
.18042 .18826 Mdot
.15689 .16473 Mdot
.14513 .15297 Mdot
.14513 .16081 Mdot
.14905 .16865 Mdot
.18826 .22355 Mdot
.16473 .20002 Mdot
.14513 .18434 Mdot
.14905 .1765 Mdot
.15297 .18042 Mdot
.16081 .18434 Mdot
.15297 .1765 Mdot
.15297 .1765 Mdot
.15689 .1765 Mdot
.16081 .18042 Mdot
.14905 .16865 Mdot
.14513 .15689 Mdot
.14905 .16081 Mdot
.14905 .16081 Mdot
.15297 .15689 Mdot
.16081 .16081 Mdot
.16081 .16081 Mdot
.16865 .18042 Mdot
.1765 .18826 Mdot
.18042 .1961 Mdot
.17257 .1961 Mdot
.17257 .1961 Mdot
.15297 .18042 Mdot
.15689 .19218 Mdot
.16865 .20002 Mdot
.1765 .20002 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.16865 .19218 Mdot
.18042 .20394 Mdot
.18434 .20394 Mdot
.18042 .1961 Mdot
.18042 .1961 Mdot
.20002 .20787 Mdot
.19218 .20394 Mdot
.17257 .18826 Mdot
.17257 .18434 Mdot
.16865 .18434 Mdot
.16865 .18434 Mdot
.18042 .19218 Mdot
.1765 .19218 Mdot
.16473 .18042 Mdot
.15689 .17257 Mdot
.15297 .16865 Mdot
.15297 .16081 Mdot
.14905 .16081 Mdot
.15297 .16865 Mdot
.15297 .17257 Mdot
.15689 .16865 Mdot
.15297 .16473 Mdot
.15297 .16081 Mdot
.14513 .14905 Mdot
.14513 .15297 Mdot
.15297 .16081 Mdot
.14905 .15297 Mdot
.13728 .1412 Mdot
.13336 .1412 Mdot
.13336 .14513 Mdot
.12552 .1412 Mdot
.1216 .1412 Mdot
.12552 .1412 Mdot
.12552 .14905 Mdot
.1216 .14905 Mdot
.1216 .14513 Mdot
.12944 .14905 Mdot
.11376 .13336 Mdot
.09415 .11376 Mdot
.09415 .1216 Mdot
.09023 .10983 Mdot
.08631 .10591 Mdot
.08239 .09807 Mdot
.09023 .10591 Mdot
.09415 .10983 Mdot
.09807 .10591 Mdot
.09023 .09415 Mdot
.09415 .10199 Mdot
.10199 .10199 Mdot
.09807 .10199 Mdot
.09807 .09807 Mdot
.08239 .09023 Mdot
.08239 .09023 Mdot
.08239 .09415 Mdot
.09023 .10199 Mdot
.08631 .09807 Mdot
.09023 .10591 Mdot
.09415 .11376 Mdot
.09023 .10983 Mdot
.08239 .09807 Mdot
.58039 .67842 Mdot
.62352 .73332 Mdot
.63528 .75292 Mdot
.62352 .72939 Mdot
.61568 .72547 Mdot
.42746 .50588 Mdot
.1216 .1412 Mdot
.10983 .12944 Mdot
.09023 .10591 Mdot
.07454 .09415 Mdot
.07846 .09807 Mdot
.08239 .10591 Mdot
.09023 .11376 Mdot
.10199 .12944 Mdot
.11376 .1412 Mdot
.11768 .1412 Mdot
.11768 .12944 Mdot
.12944 .1412 Mdot
.13336 .14513 Mdot
.13728 .13728 Mdot
.13728 .13728 Mdot
.13336 .13728 Mdot
.12944 .13336 Mdot
.1216 .12552 Mdot
.11768 .12552 Mdot
.10983 .12552 Mdot
.1216 .14513 Mdot
.10983 .13728 Mdot
.11376 .14513 Mdot
.11376 .14513 Mdot
.11768 .14905 Mdot
.1216 .15689 Mdot
.1216 .15297 Mdot
.1216 .15297 Mdot
.1216 .14905 Mdot
.13336 .16081 Mdot
.14513 .16473 Mdot
.13728 .15297 Mdot
.1412 .16081 Mdot
.14905 .16865 Mdot
.14905 .16081 Mdot
.14513 .15689 Mdot
.1412 .15689 Mdot
.14905 .16473 Mdot
.15297 .17257 Mdot
.14905 .17257 Mdot
.14905 .16473 Mdot
.14905 .16473 Mdot
.1412 .16081 Mdot
.14513 .16081 Mdot
.14513 .16081 Mdot
.15297 .16865 Mdot
.14513 .16473 Mdot
.13336 .15689 Mdot
.12944 .15297 Mdot
.14905 .18042 Mdot
.16081 .20002 Mdot
.1765 .20394 Mdot
.17257 .19218 Mdot
.18042 .18826 Mdot
.18042 .18434 Mdot
.18042 .18042 Mdot
.1961 .19218 Mdot
.18434 .18434 Mdot
.18826 .19218 Mdot
.18826 .19218 Mdot
.18826 .19218 Mdot
.19218 .20002 Mdot
.17257 .18434 Mdot
.16081 .17257 Mdot
.16473 .1765 Mdot
.15689 .17257 Mdot
.14905 .17257 Mdot
.14905 .18434 Mdot
.14905 .18434 Mdot
.1412 .17257 Mdot
.15297 .18826 Mdot
.15689 .18042 Mdot
.16473 .18434 Mdot
.16865 .19218 Mdot
.16865 .18434 Mdot
.16865 .18042 Mdot
.16081 .16865 Mdot
.15689 .17257 Mdot
.14513 .16081 Mdot
.14905 .15689 Mdot
.14905 .15297 Mdot
.16473 .1765 Mdot
.15689 .16865 Mdot
.16473 .1765 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.16865 .19218 Mdot
.16473 .1961 Mdot
.16865 .20002 Mdot
.1765 .20394 Mdot
.18042 .20787 Mdot
.19218 .21571 Mdot
.18434 .20394 Mdot
.16865 .18434 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.18434 .20002 Mdot
.18434 .20394 Mdot
.18434 .20002 Mdot
.18434 .20002 Mdot
.19218 .20787 Mdot
.19218 .20787 Mdot
.18826 .20394 Mdot
.18434 .20787 Mdot
.18042 .20394 Mdot
.18042 .20002 Mdot
.1765 .1961 Mdot
.18042 .20394 Mdot
.18042 .20002 Mdot
.1765 .19218 Mdot
.16865 .18042 Mdot
.16081 .17257 Mdot
.16081 .18042 Mdot
.16473 .18434 Mdot
.16473 .18042 Mdot
.15689 .17257 Mdot
.14905 .16081 Mdot
.15689 .16865 Mdot
.14905 .16081 Mdot
.14513 .15297 Mdot
.14513 .14905 Mdot
.13728 .1412 Mdot
.13728 .14513 Mdot
.1412 .15297 Mdot
.12552 .15297 Mdot
.12552 .15297 Mdot
.12552 .15297 Mdot
.1412 .16473 Mdot
.13336 .15689 Mdot
.13336 .15689 Mdot
.12552 .14513 Mdot
.11768 .13728 Mdot
.10591 .13336 Mdot
.09807 .1216 Mdot
.09023 .11376 Mdot
.09023 .11376 Mdot
.09415 .1216 Mdot
.09807 .12552 Mdot
.10591 .1216 Mdot
.10591 .11376 Mdot
.10591 .10199 Mdot
.10591 .10591 Mdot
.11376 .1216 Mdot
.10983 .11768 Mdot
.10983 .11376 Mdot
.10199 .11376 Mdot
.09023 .10591 Mdot
.09415 .10591 Mdot
.09807 .11376 Mdot
.09023 .10591 Mdot
.09415 .11376 Mdot
.10199 .12552 Mdot
.09023 .10591 Mdot
.09415 .10199 Mdot
.45491 .5098 Mdot
.59215 .68234 Mdot
.60391 .70979 Mdot
.6196 .73332 Mdot
.6196 .73724 Mdot
.5647 .6745 Mdot
.26276 .31766 Mdot
.0667 .08631 Mdot
.09807 .11768 Mdot
.06278 .07846 Mdot
.05886 .07454 Mdot
.07062 .08631 Mdot
.08239 .09807 Mdot
.09415 .11768 Mdot
.10199 .12944 Mdot
.10983 .13336 Mdot
.11768 .13336 Mdot
.12944 .14513 Mdot
.13336 .14905 Mdot
.14513 .16473 Mdot
.13728 .15297 Mdot
.13728 .14513 Mdot
.12944 .1412 Mdot
.12944 .1412 Mdot
.12944 .1412 Mdot
.1216 .13728 Mdot
.11376 .13336 Mdot
.11768 .13728 Mdot
.1216 .14513 Mdot
.11376 .13728 Mdot
.1216 .14905 Mdot
.1216 .15297 Mdot
.13728 .16081 Mdot
.14905 .16865 Mdot
.14513 .16473 Mdot
.12552 .15297 Mdot
.14513 .17257 Mdot
.14513 .16473 Mdot
.1412 .16473 Mdot
.15689 .1765 Mdot
.15689 .17257 Mdot
.15689 .17257 Mdot
.15689 .17257 Mdot
.15689 .17257 Mdot
.14513 .16081 Mdot
.15689 .17257 Mdot
.15689 .17257 Mdot
.15297 .16473 Mdot
.13728 .14905 Mdot
.13336 .14905 Mdot
.1216 .14513 Mdot
.12552 .14905 Mdot
.12944 .15297 Mdot
.12944 .16081 Mdot
.14513 .16865 Mdot
.16081 .18434 Mdot
.15297 .18434 Mdot
.16081 .18826 Mdot
.1765 .20002 Mdot
.18042 .20394 Mdot
.18042 .20002 Mdot
.18042 .18826 Mdot
.18826 .20002 Mdot
.1765 .18826 Mdot
.18434 .20394 Mdot
.18434 .20394 Mdot
.18434 .20002 Mdot
.19218 .20002 Mdot
.18826 .19218 Mdot
.18434 .18826 Mdot
.18434 .18826 Mdot
.16081 .17257 Mdot
.15689 .18042 Mdot
.15689 .18434 Mdot
.14905 .1765 Mdot
.14905 .17257 Mdot
.15689 .1765 Mdot
.16865 .18826 Mdot
.16865 .19218 Mdot
.17257 .20002 Mdot
.16081 .18826 Mdot
.16081 .18042 Mdot
.15689 .1765 Mdot
.15297 .1765 Mdot
.14513 .16865 Mdot
.14513 .16865 Mdot
.14513 .16081 Mdot
.16081 .1765 Mdot
.16865 .18434 Mdot
.17257 .18042 Mdot
.17257 .18826 Mdot
.17257 .18826 Mdot
.16865 .18826 Mdot
.18042 .20787 Mdot
.1765 .20394 Mdot
.18826 .21571 Mdot
.20002 .22747 Mdot
.1961 .21571 Mdot
.19218 .20787 Mdot
.18434 .1961 Mdot
.18826 .20394 Mdot
.1765 .19218 Mdot
.1765 .20002 Mdot
.1765 .20002 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.1765 .20394 Mdot
.18042 .20394 Mdot
.18042 .20394 Mdot
.18042 .20394 Mdot
.1765 .20002 Mdot
.18434 .21179 Mdot
.18826 .21179 Mdot
.19218 .20787 Mdot
.1961 .20002 Mdot
.19218 .1961 Mdot
.18826 .1961 Mdot
.1765 .18826 Mdot
.16473 .18042 Mdot
.15297 .1765 Mdot
.16473 .18826 Mdot
.14905 .1765 Mdot
.14905 .18042 Mdot
.15297 .18042 Mdot
.15689 .1765 Mdot
.15297 .16865 Mdot
.1412 .15297 Mdot
.1412 .14905 Mdot
.13728 .14905 Mdot
.13728 .14905 Mdot
.13336 .14513 Mdot
.13728 .15689 Mdot
.13728 .15689 Mdot
.13728 .15689 Mdot
.12944 .14513 Mdot
.11768 .12944 Mdot
.1216 .13336 Mdot
.11376 .12552 Mdot
.10199 .1216 Mdot
.10199 .12552 Mdot
.09807 .1216 Mdot
.09023 .11376 Mdot
.09023 .11376 Mdot
.09415 .11768 Mdot
.09023 .11376 Mdot
.09415 .11376 Mdot
.09415 .10983 Mdot
.09415 .10983 Mdot
.10591 .12552 Mdot
.10983 .12552 Mdot
.09807 .1216 Mdot
.10591 .12944 Mdot
.10591 .12944 Mdot
.10199 .12552 Mdot
.09807 .1216 Mdot
.09415 .11768 Mdot
.09023 .11768 Mdot
.09415 .11768 Mdot
.09415 .11376 Mdot
.08239 .09415 Mdot
.15689 .1765 Mdot
.25884 .29806 Mdot
.34119 .39217 Mdot
.47451 .55686 Mdot
.52157 .62352 Mdot
.58431 .70587 Mdot
.38824 .47451 Mdot
.05886 .07062 Mdot
.07062 .08631 Mdot
.05886 .07846 Mdot
.05102 .06278 Mdot
.05494 .06278 Mdot
.07454 .09023 Mdot
.08631 .10983 Mdot
.09415 .11768 Mdot
.10199 .12944 Mdot
.10983 .13336 Mdot
.12552 .14905 Mdot
.12552 .15297 Mdot
.13728 .15297 Mdot
.13336 .14905 Mdot
.12944 .14513 Mdot
.13728 .14513 Mdot
.14513 .16081 Mdot
.1412 .15689 Mdot
.14513 .16081 Mdot
.13336 .14513 Mdot
.13728 .14905 Mdot
.1412 .15689 Mdot
.13728 .15297 Mdot
.13728 .15689 Mdot
.13336 .15689 Mdot
.14513 .16081 Mdot
.13728 .14905 Mdot
.13336 .15297 Mdot
.13336 .16081 Mdot
.13336 .16081 Mdot
.13336 .16081 Mdot
.1412 .16865 Mdot
.13728 .16473 Mdot
.14513 .16473 Mdot
.14905 .17257 Mdot
.16473 .18434 Mdot
.16865 .18826 Mdot
.15689 .1765 Mdot
.14513 .16081 Mdot
.15297 .16473 Mdot
.14905 .16081 Mdot
.1412 .15689 Mdot
.13728 .16081 Mdot
.13728 .16081 Mdot
.13336 .16081 Mdot
.14905 .18042 Mdot
.13728 .16473 Mdot
.1412 .17257 Mdot
.14513 .17257 Mdot
.15689 .18826 Mdot
.15689 .1961 Mdot
.15297 .18826 Mdot
.17257 .20002 Mdot
.1765 .20002 Mdot
.17257 .19218 Mdot
.1765 .20002 Mdot
.1765 .1961 Mdot
.18042 .20787 Mdot
.18042 .20002 Mdot
.1961 .21571 Mdot
.20002 .21179 Mdot
.20002 .20394 Mdot
.20002 .20002 Mdot
.18042 .18042 Mdot
.18826 .1961 Mdot
.17257 .19218 Mdot
.16081 .18434 Mdot
.14905 .17257 Mdot
.1412 .1765 Mdot
.14905 .18042 Mdot
.1412 .17257 Mdot
.14905 .18434 Mdot
.14513 .18042 Mdot
.15689 .19218 Mdot
.15297 .18042 Mdot
.15689 .18042 Mdot
.15689 .1765 Mdot
.15689 .18042 Mdot
.15297 .17257 Mdot
.14905 .15689 Mdot
.16865 .17257 Mdot
.18042 .18434 Mdot
.17257 .1765 Mdot
.1765 .18042 Mdot
.18042 .18826 Mdot
.16865 .18434 Mdot
.17257 .1961 Mdot
.17257 .20002 Mdot
.18042 .20394 Mdot
.19218 .21571 Mdot
.19218 .21179 Mdot
.20394 .21571 Mdot
.1961 .20787 Mdot
.19218 .21179 Mdot
.18434 .20394 Mdot
.1765 .19218 Mdot
.17257 .19218 Mdot
.18042 .20002 Mdot
.17257 .1961 Mdot
.1765 .20002 Mdot
.19218 .21963 Mdot
.19218 .21571 Mdot
.18434 .20787 Mdot
.17257 .19218 Mdot
.18826 .21179 Mdot
.1961 .21179 Mdot
.20394 .20787 Mdot
.20002 .20394 Mdot
.18826 .19218 Mdot
.16473 .18042 Mdot
.1765 .1961 Mdot
.15297 .17257 Mdot
.15689 .1765 Mdot
.15689 .18042 Mdot
.14513 .17257 Mdot
.14513 .1765 Mdot
.13728 .16865 Mdot
.14513 .16865 Mdot
.15689 .1765 Mdot
.15297 .16865 Mdot
.14513 .15297 Mdot
.1412 .14905 Mdot
.14513 .15689 Mdot
.13728 .14905 Mdot
.1412 .15689 Mdot
.13336 .14905 Mdot
.12944 .14513 Mdot
.10983 .13336 Mdot
.11376 .13728 Mdot
.11768 .13728 Mdot
.10591 .12552 Mdot
.10199 .12552 Mdot
.09807 .12552 Mdot
.09415 .11376 Mdot
.09415 .10983 Mdot
.07454 .09023 Mdot
.09023 .11376 Mdot
.07846 .09807 Mdot
.07454 .09415 Mdot
.07454 .08631 Mdot
.09023 .10591 Mdot
.09415 .11376 Mdot
.09807 .11768 Mdot
.09807 .1216 Mdot
.11376 .1412 Mdot
.10591 .13336 Mdot
.10199 .12944 Mdot
.09807 .1216 Mdot
.09807 .11768 Mdot
.08631 .10591 Mdot
.08631 .09807 Mdot
.09023 .09807 Mdot
.07846 .08631 Mdot
.09807 .1216 Mdot
.12552 .14905 Mdot
.1216 .1412 Mdot
.13336 .16081 Mdot
.21963 .26276 Mdot
.32943 .39609 Mdot
.30198 .36472 Mdot
.13336 .14905 Mdot
.13728 .15689 Mdot
.11376 .13336 Mdot
.09023 .10983 Mdot
.07846 .09415 Mdot
.09415 .11768 Mdot
.09415 .11768 Mdot
.09415 .1216 Mdot
.10983 .13728 Mdot
.1216 .15297 Mdot
.12552 .14905 Mdot
.13728 .15689 Mdot
.13728 .15689 Mdot
.13728 .15689 Mdot
.13728 .14905 Mdot
.1412 .14513 Mdot
.15297 .15297 Mdot
.15297 .16081 Mdot
.15297 .16473 Mdot
.14513 .16081 Mdot
.14513 .14905 Mdot
.1412 .14513 Mdot
.12552 .1412 Mdot
.13728 .15297 Mdot
.13728 .14905 Mdot
.13728 .14905 Mdot
.1412 .16081 Mdot
.1412 .15689 Mdot
.14905 .16473 Mdot
.14513 .16865 Mdot
.13728 .16081 Mdot
.14513 .17257 Mdot
.15297 .18042 Mdot
.15689 .18042 Mdot
.15297 .18042 Mdot
.14905 .18042 Mdot
.16081 .18826 Mdot
.16473 .18434 Mdot
.15297 .16865 Mdot
.15689 .16865 Mdot
.16865 .18434 Mdot
.16081 .1765 Mdot
.16865 .18042 Mdot
.16473 .18434 Mdot
.16473 .18826 Mdot
.15689 .18042 Mdot
.15689 .18042 Mdot
.16081 .18434 Mdot
.14905 .18434 Mdot
.15297 .18826 Mdot
.1412 .17257 Mdot
.16081 .18826 Mdot
.17257 .1961 Mdot
.17257 .18826 Mdot
.18042 .18826 Mdot
.18434 .1961 Mdot
.18434 .20002 Mdot
.1765 .1961 Mdot
.18042 .20394 Mdot
.19218 .21179 Mdot
.19218 .1961 Mdot
.1961 .20002 Mdot
.18826 .19218 Mdot
.18434 .19218 Mdot
.18042 .19218 Mdot
.16473 .18042 Mdot
.16473 .18826 Mdot
.16081 .19218 Mdot
.15297 .18434 Mdot
.14513 .1765 Mdot
.12552 .15689 Mdot
.12552 .15689 Mdot
.1412 .17257 Mdot
.14513 .17257 Mdot
.16081 .18434 Mdot
.16081 .1765 Mdot
.16081 .1765 Mdot
.15689 .17257 Mdot
.15297 .16865 Mdot
.14905 .16473 Mdot
.16865 .18042 Mdot
.1765 .19218 Mdot
.17257 .18826 Mdot
.16865 .18042 Mdot
.1765 .18826 Mdot
.17257 .18826 Mdot
.1765 .1961 Mdot
.1765 .20002 Mdot
.18042 .20002 Mdot
.18042 .20002 Mdot
.1961 .21571 Mdot
.20394 .22747 Mdot
.1961 .21179 Mdot
.19218 .21179 Mdot
.19218 .21571 Mdot
.18434 .21179 Mdot
.1765 .20394 Mdot
.1765 .20394 Mdot
.18434 .21179 Mdot
.19218 .22355 Mdot
.18434 .21963 Mdot
.18434 .21571 Mdot
.19218 .22355 Mdot
.18434 .20787 Mdot
.18434 .20002 Mdot
.20002 .21179 Mdot
.20787 .21571 Mdot
.20002 .20394 Mdot
.19218 .1961 Mdot
.18042 .18826 Mdot
.1765 .18826 Mdot
.16865 .18434 Mdot
.17257 .19218 Mdot
.17257 .19218 Mdot
.16081 .18042 Mdot
.16473 .18434 Mdot
.16473 .18434 Mdot
.15689 .1765 Mdot
.16081 .18042 Mdot
.17257 .19218 Mdot
.16081 .18042 Mdot
.16081 .18434 Mdot
.1412 .16473 Mdot
.1412 .15689 Mdot
.1412 .16081 Mdot
.12944 .14513 Mdot
.1216 .12944 Mdot
.12944 .1412 Mdot
.12552 .14513 Mdot
.11768 .13336 Mdot
.11768 .13336 Mdot
.10983 .12944 Mdot
.10199 .12552 Mdot
.09807 .1216 Mdot
.09807 .1216 Mdot
.09807 .10591 Mdot
.09807 .10591 Mdot
.10199 .10591 Mdot
.09415 .10199 Mdot
.09023 .09807 Mdot
.09807 .10591 Mdot
.10983 .1216 Mdot
.10591 .1216 Mdot
.08631 .10591 Mdot
.10199 .1216 Mdot
.10591 .12552 Mdot
.10199 .1216 Mdot
.09415 .10591 Mdot
.08239 .09807 Mdot
.08239 .09807 Mdot
.07846 .09415 Mdot
.07454 .08239 Mdot
.05886 .06278 Mdot
.05886 .07454 Mdot
.07454 .09415 Mdot
.08239 .09807 Mdot
.08631 .09807 Mdot
.11376 .12944 Mdot
.12944 .15297 Mdot
.12944 .16081 Mdot
.11768 .13728 Mdot
.11376 .13728 Mdot
.10591 .12944 Mdot
.09807 .12552 Mdot
.09023 .11768 Mdot
.08631 .11376 Mdot
.09415 .1216 Mdot
.10199 .12552 Mdot
.09023 .11376 Mdot
.10591 .13336 Mdot
.11768 .14513 Mdot
.13728 .15297 Mdot
.14513 .16473 Mdot
.1412 .16081 Mdot
.13336 .14905 Mdot
.13728 .14905 Mdot
.14905 .16473 Mdot
.15297 .16865 Mdot
.15297 .16473 Mdot
.14905 .16473 Mdot
.14905 .15689 Mdot
.15297 .16865 Mdot
.14905 .16865 Mdot
.13728 .15689 Mdot
.13728 .14905 Mdot
.1412 .15689 Mdot
.14905 .16865 Mdot
.1412 .15689 Mdot
.14905 .16473 Mdot
.15297 .17257 Mdot
.15297 .17257 Mdot
.15297 .1765 Mdot
.15689 .17257 Mdot
.14513 .16473 Mdot
.13728 .15689 Mdot
.15689 .1765 Mdot
.16473 .18434 Mdot
.16865 .19218 Mdot
.16081 .18042 Mdot
.16473 .18042 Mdot
.16473 .17257 Mdot
.17257 .18434 Mdot
.16473 .1765 Mdot
.16473 .1765 Mdot
.16865 .18826 Mdot
.17257 .18826 Mdot
.16865 .18826 Mdot
.16081 .18042 Mdot
.14905 .16865 Mdot
.15297 .18042 Mdot
.16473 .18826 Mdot
.16473 .19218 Mdot
.18434 .20787 Mdot
.18434 .20394 Mdot
.18826 .20394 Mdot
.1961 .20002 Mdot
.18434 .18826 Mdot
.18826 .19218 Mdot
.1961 .20787 Mdot
.20394 .21571 Mdot
.1961 .20394 Mdot
.20787 .21571 Mdot
.18434 .19218 Mdot
.1765 .18434 Mdot
.18434 .20002 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.16865 .1961 Mdot
.16473 .1961 Mdot
.16081 .1961 Mdot
.14905 .18042 Mdot
.13728 .17257 Mdot
.1412 .17257 Mdot
.15297 .18042 Mdot
.14905 .16865 Mdot
.15297 .17257 Mdot
.16081 .18042 Mdot
.16473 .18434 Mdot
.14905 .17257 Mdot
.13728 .16081 Mdot
.14905 .1765 Mdot
.16473 .1961 Mdot
.16473 .18434 Mdot
.17257 .19218 Mdot
.1765 .1961 Mdot
.18042 .1961 Mdot
.1765 .20002 Mdot
.1765 .19218 Mdot
.18042 .20002 Mdot
.18434 .20394 Mdot
.18826 .21571 Mdot
.1961 .21571 Mdot
.20394 .21963 Mdot
.20787 .22747 Mdot
.1961 .22355 Mdot
.18042 .20394 Mdot
.17257 .1961 Mdot
.1765 .20394 Mdot
.18434 .21179 Mdot
.18434 .21179 Mdot
.18826 .21571 Mdot
.19218 .21963 Mdot
.19218 .21571 Mdot
.1961 .20787 Mdot
.19218 .1961 Mdot
.1961 .1961 Mdot
.1961 .20394 Mdot
.19218 .1961 Mdot
.1961 .20002 Mdot
.20394 .20787 Mdot
.18042 .18826 Mdot
.17257 .18434 Mdot
.17257 .18826 Mdot
.16865 .18826 Mdot
.17257 .18826 Mdot
.16473 .18042 Mdot
.15689 .1765 Mdot
.1765 .19218 Mdot
.16473 .18826 Mdot
.16473 .18434 Mdot
.16865 .18826 Mdot
.16865 .1961 Mdot
.15297 .18042 Mdot
.13728 .16865 Mdot
.1412 .15689 Mdot
.14513 .16081 Mdot
.13336 .14513 Mdot
.13336 .1412 Mdot
.12944 .13728 Mdot
.13336 .1412 Mdot
.12944 .13728 Mdot
.12552 .13728 Mdot
.11768 .12944 Mdot
.11768 .12944 Mdot
.11376 .12552 Mdot
.11376 .13336 Mdot
.10199 .10983 Mdot
.09415 .10199 Mdot
.09807 .10199 Mdot
.09415 .09807 Mdot
.09415 .10199 Mdot
.10591 .11376 Mdot
.10591 .11376 Mdot
.10199 .10983 Mdot
.10983 .1216 Mdot
.09807 .10983 Mdot
.09415 .10591 Mdot
.09415 .10199 Mdot
.09415 .10199 Mdot
.08239 .09415 Mdot
.07062 .08631 Mdot
.06278 .0667 Mdot
.0667 .07454 Mdot
.05494 .07062 Mdot
.0667 .07846 Mdot
.0667 .07062 Mdot
.08631 .09415 Mdot
.09023 .09807 Mdot
.10591 .12552 Mdot
.10983 .13336 Mdot
.10591 .13336 Mdot
.10199 .12944 Mdot
.10591 .12944 Mdot
.10591 .13336 Mdot
.10199 .12944 Mdot
.10199 .12552 Mdot
.10199 .12944 Mdot
.09807 .1216 Mdot
.09023 .11768 Mdot
.10983 .13728 Mdot
.11768 .1412 Mdot
.1216 .14513 Mdot
.13336 .14905 Mdot
.12552 .1412 Mdot
.13728 .14905 Mdot
.13728 .14905 Mdot
.13728 .14905 Mdot
.14513 .15297 Mdot
.14513 .15689 Mdot
.14905 .16473 Mdot
.14513 .16081 Mdot
.15297 .1765 Mdot
.14905 .17257 Mdot
.14513 .17257 Mdot
.14513 .16865 Mdot
.13728 .16081 Mdot
.13336 .15689 Mdot
.14905 .16865 Mdot
.14905 .16081 Mdot
.15689 .1765 Mdot
.15297 .16865 Mdot
.14905 .16473 Mdot
.15689 .1765 Mdot
.15297 .17257 Mdot
.15297 .16473 Mdot
.16865 .18042 Mdot
.16473 .18042 Mdot
.17257 .19218 Mdot
.16865 .18826 Mdot
.17257 .19218 Mdot
.16473 .18434 Mdot
.16473 .18434 Mdot
.16865 .18826 Mdot
.17257 .1961 Mdot
.16081 .18042 Mdot
.16081 .18042 Mdot
.16865 .18826 Mdot
.16081 .18042 Mdot
.15297 .18042 Mdot
.16865 .18826 Mdot
.17257 .1961 Mdot
.17257 .19218 Mdot
.1765 .20002 Mdot
.18434 .20002 Mdot
.19218 .20787 Mdot
.1765 .18434 Mdot
.18434 .19218 Mdot
.19218 .20002 Mdot
.20002 .21571 Mdot
.20002 .21571 Mdot
.20002 .21571 Mdot
.20787 .22355 Mdot
.20394 .22355 Mdot
.19218 .21179 Mdot
.18434 .20787 Mdot
.18434 .20787 Mdot
.18042 .20394 Mdot
.18042 .21179 Mdot
.17257 .20787 Mdot
.1765 .20394 Mdot
.16473 .1961 Mdot
.16865 .20394 Mdot
.18042 .20787 Mdot
.17257 .1961 Mdot
.16473 .18434 Mdot
.15689 .1765 Mdot
.16865 .18826 Mdot
.16865 .18826 Mdot
.16473 .18826 Mdot
.16473 .19218 Mdot
.16081 .20002 Mdot
.16081 .20394 Mdot
.15297 .18826 Mdot
.15689 .19218 Mdot
.16865 .20394 Mdot
.18042 .20394 Mdot
.18042 .20394 Mdot
.18434 .20002 Mdot
.18826 .20787 Mdot
.18434 .20394 Mdot
.18042 .20394 Mdot
.18042 .19218 Mdot
.20394 .21179 Mdot
.20787 .21963 Mdot
.21179 .23139 Mdot
.20394 .22747 Mdot
.1961 .22355 Mdot
.18826 .21571 Mdot
.18434 .21179 Mdot
.18826 .21571 Mdot
.19218 .21963 Mdot
.20394 .23139 Mdot
.20394 .22747 Mdot
.19218 .21571 Mdot
.1961 .21179 Mdot
.20787 .21571 Mdot
.19218 .1961 Mdot
.18434 .18434 Mdot
.18042 .18042 Mdot
.18826 .1961 Mdot
.18826 .19218 Mdot
.18434 .18826 Mdot
.1765 .19218 Mdot
.1765 .19218 Mdot
.18042 .20002 Mdot
.1765 .20002 Mdot
.1765 .20002 Mdot
.17257 .18826 Mdot
.16473 .18434 Mdot
.17257 .19218 Mdot
.1765 .19218 Mdot
.16473 .18434 Mdot
.16473 .1961 Mdot
.15689 .18826 Mdot
.13728 .16473 Mdot
.13336 .16473 Mdot
.12944 .15297 Mdot
.13336 .15297 Mdot
.1412 .15297 Mdot
.14513 .16081 Mdot
.13336 .1412 Mdot
.13336 .14513 Mdot
.12944 .13728 Mdot
.1216 .12944 Mdot
.12552 .13336 Mdot
.12944 .1412 Mdot
.11768 .12944 Mdot
.11768 .11376 Mdot
.11768 .11768 Mdot
.10983 .11768 Mdot
.10983 .11768 Mdot
.10199 .10983 Mdot
.10591 .11376 Mdot
.10983 .1216 Mdot
.10591 .11768 Mdot
.09023 .10983 Mdot
.09023 .10591 Mdot
.09023 .10591 Mdot
.09807 .11768 Mdot
.0667 .08239 Mdot
.0667 .08239 Mdot
.06278 .07846 Mdot
.07062 .08631 Mdot
.03141 .03925 Mdot
.04317 .05494 Mdot
.04709 .05886 Mdot
.07846 .08239 Mdot
.09415 .10199 Mdot
.09415 .10983 Mdot
.09415 .11376 Mdot
.09415 .11376 Mdot
.10983 .12944 Mdot
.1216 .13728 Mdot
.10983 .12944 Mdot
.1216 .13728 Mdot
.11376 .12944 Mdot
.09807 .1216 Mdot
.09415 .11376 Mdot
.10199 .12552 Mdot
.10983 .13728 Mdot
.11768 .14905 Mdot
.11768 .15297 Mdot
.12944 .16081 Mdot
.12944 .15297 Mdot
.13336 .15689 Mdot
.14905 .16473 Mdot
.14513 .15689 Mdot
.15297 .16473 Mdot
.15297 .16081 Mdot
.15689 .17257 Mdot
.15689 .1765 Mdot
.15297 .1765 Mdot
.14513 .17257 Mdot
.14905 .1765 Mdot
.14905 .18434 Mdot
.14905 .18042 Mdot
.14513 .16865 Mdot
.14905 .1765 Mdot
.14905 .1765 Mdot
.16473 .18434 Mdot
.15689 .17257 Mdot
.14905 .16081 Mdot
.15689 .16865 Mdot
.15297 .16865 Mdot
.15689 .16473 Mdot
.1765 .18042 Mdot
.17257 .18042 Mdot
.16865 .18826 Mdot
.17257 .18826 Mdot
.18042 .20394 Mdot
.18826 .21179 Mdot
.18434 .20787 Mdot
.16865 .18826 Mdot
.15689 .18826 Mdot
.16081 .18826 Mdot
.16865 .18826 Mdot
.16865 .19218 Mdot
.17257 .1961 Mdot
.16473 .1961 Mdot
.16473 .19218 Mdot
.16473 .19218 Mdot
.15689 .18434 Mdot
.17257 .1961 Mdot
.17257 .19218 Mdot
.17257 .19218 Mdot
.1765 .1961 Mdot
.17257 .18826 Mdot
.1765 .19218 Mdot
.18826 .20787 Mdot
.1961 .22355 Mdot
.20002 .22355 Mdot
.20002 .22355 Mdot
.1961 .21963 Mdot
.18826 .21179 Mdot
.1961 .21963 Mdot
.1765 .20002 Mdot
.17257 .1961 Mdot
.16473 .1961 Mdot
.16865 .20394 Mdot
.16865 .20394 Mdot
.16865 .20394 Mdot
.16865 .20394 Mdot
.18434 .21963 Mdot
.18434 .21179 Mdot
.19218 .21179 Mdot
.18434 .20002 Mdot
.18042 .18434 Mdot
.17257 .18434 Mdot
.17257 .18826 Mdot
.16865 .19218 Mdot
.16473 .1961 Mdot
.16081 .20002 Mdot
.16081 .20002 Mdot
.16081 .20002 Mdot
.17257 .20394 Mdot
.18042 .20002 Mdot
.18826 .20787 Mdot
.19218 .21179 Mdot
.20002 .22355 Mdot
.20002 .21963 Mdot
.19218 .21179 Mdot
.19218 .21179 Mdot
.18826 .20787 Mdot
.19218 .20787 Mdot
.20394 .22355 Mdot
.18826 .21179 Mdot
.18826 .20394 Mdot
.1961 .21571 Mdot
.19218 .21179 Mdot
.19218 .21963 Mdot
.18434 .21179 Mdot
.19218 .21963 Mdot
.18434 .21179 Mdot
.18826 .21179 Mdot
.19218 .21571 Mdot
.1961 .21571 Mdot
.1961 .20787 Mdot
.18826 .19218 Mdot
.18434 .18434 Mdot
.1765 .1765 Mdot
.1765 .18042 Mdot
.16473 .17257 Mdot
.16473 .18042 Mdot
.16473 .18434 Mdot
.16081 .18042 Mdot
.17257 .19218 Mdot
.1765 .1961 Mdot
.17257 .18434 Mdot
.16865 .18042 Mdot
.16081 .17257 Mdot
.17257 .18826 Mdot
.17257 .18826 Mdot
.16081 .18042 Mdot
.16081 .18826 Mdot
.1216 .14905 Mdot
.12552 .15689 Mdot
.1216 .15297 Mdot
.11768 .14905 Mdot
.12552 .15297 Mdot
.13728 .15689 Mdot
.14513 .16473 Mdot
.13336 .15297 Mdot
.11768 .13336 Mdot
.10591 .1216 Mdot
.10983 .12552 Mdot
.12944 .1412 Mdot
.11768 .12552 Mdot
.11376 .1216 Mdot
.11768 .12944 Mdot
.11376 .1216 Mdot
.11376 .1216 Mdot
.11376 .12552 Mdot
.11768 .12552 Mdot
.10983 .1216 Mdot
.10591 .11376 Mdot
.10983 .1216 Mdot
.10199 .10983 Mdot
.10199 .11376 Mdot
.10199 .11768 Mdot
.09807 .10983 Mdot
.07846 .10199 Mdot
.07846 .09807 Mdot
.07454 .09023 Mdot
.02749 .03925 Mdot
.03925 .05102 Mdot
.0667 .08631 Mdot
.09023 .10983 Mdot
.11376 .13728 Mdot
.10591 .1216 Mdot
.08239 .08631 Mdot
.08239 .08239 Mdot
.09807 .10591 Mdot
.08631 .09415 Mdot
.09023 .10199 Mdot
.09415 .11768 Mdot
.10199 .12552 Mdot
.10983 .13728 Mdot
.10983 .13728 Mdot
.10983 .1412 Mdot
.10591 .13728 Mdot
.11768 .15297 Mdot
.11768 .15689 Mdot
.1216 .15689 Mdot
.1216 .15297 Mdot
.12552 .15297 Mdot
.14513 .16473 Mdot
.14905 .16473 Mdot
.14513 .16081 Mdot
.15297 .17257 Mdot
.16865 .18434 Mdot
.16473 .18042 Mdot
.16081 .18434 Mdot
.14905 .17257 Mdot
.14905 .18042 Mdot
.15297 .18434 Mdot
.15689 .18826 Mdot
.16081 .18826 Mdot
.15689 .18434 Mdot
.14513 .17257 Mdot
.15689 .18434 Mdot
.15689 .1765 Mdot
.15689 .1765 Mdot
.16473 .18434 Mdot
.16473 .18434 Mdot
.15689 .17257 Mdot
.16473 .18042 Mdot
.1765 .19218 Mdot
.18434 .20394 Mdot
.18042 .1961 Mdot
.17257 .19218 Mdot
.18042 .20002 Mdot
.1765 .19218 Mdot
.1765 .19218 Mdot
.16865 .18826 Mdot
.17257 .19218 Mdot
.1765 .1961 Mdot
.17257 .19218 Mdot
.16473 .18434 Mdot
.16865 .19218 Mdot
.17257 .20002 Mdot
.1765 .21179 Mdot
.16865 .20394 Mdot
.16473 .20002 Mdot
.15689 .18826 Mdot
.16473 .1961 Mdot
.1765 .20394 Mdot
.17257 .20002 Mdot
.1765 .20002 Mdot
.18042 .20394 Mdot
.19218 .21963 Mdot
.19218 .21963 Mdot
.1961 .22747 Mdot
.18826 .22355 Mdot
.20394 .23139 Mdot
.20394 .22747 Mdot
.1961 .22747 Mdot
.18042 .21963 Mdot
.1765 .21571 Mdot
.1765 .21179 Mdot
.17257 .20787 Mdot
.16865 .20787 Mdot
.18042 .21571 Mdot
.1765 .21179 Mdot
.18434 .20787 Mdot
.18434 .21179 Mdot
.18434 .20787 Mdot
.18434 .20002 Mdot
.1765 .19218 Mdot
.18042 .1961 Mdot
.18434 .20394 Mdot
.1765 .20002 Mdot
.1765 .20394 Mdot
.17257 .20394 Mdot
.16473 .1961 Mdot
.17257 .1961 Mdot
.18826 .21179 Mdot
.18826 .21179 Mdot
.19218 .21571 Mdot
.18826 .21179 Mdot
.1961 .21963 Mdot
.1961 .21571 Mdot
.1961 .21179 Mdot
.20394 .21963 Mdot
.1961 .21179 Mdot
.20002 .21963 Mdot
.20394 .22355 Mdot
.20002 .21963 Mdot
.20002 .22355 Mdot
.1961 .21571 Mdot
.19218 .20787 Mdot
.18826 .20787 Mdot
.19218 .21571 Mdot
.19218 .21179 Mdot
.1961 .21963 Mdot
.20002 .22355 Mdot
.1961 .22355 Mdot
.18826 .21179 Mdot
.18434 .20394 Mdot
.17257 .18826 Mdot
.16473 .17257 Mdot
.16865 .1765 Mdot
.17257 .1765 Mdot
.1765 .18434 Mdot
.16473 .18042 Mdot
.17257 .18826 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.16865 .18434 Mdot
.1765 .18826 Mdot
.17257 .18826 Mdot
.16081 .1765 Mdot
.16473 .18826 Mdot
.16081 .18826 Mdot
.16081 .18434 Mdot
.14513 .1765 Mdot
.14905 .18434 Mdot
.13336 .16865 Mdot
.12944 .16081 Mdot
.12552 .15297 Mdot
.14513 .16473 Mdot
.14513 .16473 Mdot
.1412 .15689 Mdot
.1412 .15689 Mdot
.12944 .14905 Mdot
.11768 .1412 Mdot
.11768 .1412 Mdot
.10983 .12552 Mdot
.10591 .1216 Mdot
.10199 .11376 Mdot
.09807 .10983 Mdot
.09415 .10199 Mdot
.10199 .11376 Mdot
.12552 .1412 Mdot
.11376 .1216 Mdot
.09807 .10199 Mdot
.09807 .09807 Mdot
.10983 .10983 Mdot
.10983 .10983 Mdot
.10591 .10983 Mdot
.10591 .11768 Mdot
.08631 .09807 Mdot
.08239 .09807 Mdot
.0667 .08631 Mdot
.03533 .04317 Mdot
.05102 .06278 Mdot
.05494 .0667 Mdot
.05494 .07062 Mdot
.07062 .09023 Mdot
.08239 .09807 Mdot
.08631 .09415 Mdot
.0667 .07846 Mdot
.05494 .0667 Mdot
.03533 .04317 Mdot
.05102 .0667 Mdot
.07454 .09023 Mdot
.09023 .11768 Mdot
.09415 .11376 Mdot
.09807 .12552 Mdot
.11376 .1412 Mdot
.11376 .14513 Mdot
.11376 .14513 Mdot
.1216 .15297 Mdot
.11768 .14905 Mdot
.12552 .15689 Mdot
.12944 .15689 Mdot
.1412 .16473 Mdot
.14513 .16865 Mdot
.1412 .16473 Mdot
.16081 .18826 Mdot
.16865 .20002 Mdot
.16865 .1961 Mdot
.16865 .19218 Mdot
.16081 .18826 Mdot
.14513 .17257 Mdot
.15297 .18434 Mdot
.15297 .18042 Mdot
.14905 .1765 Mdot
.15689 .18826 Mdot
.15689 .18826 Mdot
.16081 .1961 Mdot
.16473 .19218 Mdot
.1765 .20394 Mdot
.17257 .18826 Mdot
.16865 .18434 Mdot
.16081 .18042 Mdot
.16473 .18042 Mdot
.16865 .18826 Mdot
.18042 .20002 Mdot
.18042 .1961 Mdot
.18826 .20787 Mdot
.18826 .20394 Mdot
.18826 .1961 Mdot
.18826 .20002 Mdot
.17257 .18434 Mdot
.16081 .17257 Mdot
.16865 .18434 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.16865 .18826 Mdot
.1765 .20002 Mdot
.18042 .20787 Mdot
.1765 .20394 Mdot
.16081 .19218 Mdot
.15297 .18434 Mdot
.16081 .19218 Mdot
.16865 .20002 Mdot
.18042 .21571 Mdot
.18434 .21179 Mdot
.1961 .22355 Mdot
.20002 .22747 Mdot
.19218 .22747 Mdot
.18042 .21963 Mdot
.20002 .23139 Mdot
.20002 .23531 Mdot
.19218 .23531 Mdot
.18826 .23139 Mdot
.19218 .23531 Mdot
.1961 .23924 Mdot
.18434 .22355 Mdot
.18434 .22747 Mdot
.19218 .23531 Mdot
.19218 .22355 Mdot
.20002 .22747 Mdot
.18826 .21179 Mdot
.19218 .21571 Mdot
.19218 .20787 Mdot
.20002 .20787 Mdot
.1961 .20787 Mdot
.18826 .20394 Mdot
.18434 .20394 Mdot
.19218 .21571 Mdot
.18042 .20787 Mdot
.1765 .20394 Mdot
.1765 .20787 Mdot
.18042 .20002 Mdot
.18434 .20002 Mdot
.1961 .21571 Mdot
.1961 .22355 Mdot
.19218 .21571 Mdot
.20002 .21963 Mdot
.1961 .20394 Mdot
.20787 .21963 Mdot
.20394 .22355 Mdot
.1961 .21963 Mdot
.19218 .21963 Mdot
.18826 .21571 Mdot
.1961 .22355 Mdot
.1961 .21963 Mdot
.18826 .21571 Mdot
.18042 .20394 Mdot
.1961 .21963 Mdot
.20002 .21963 Mdot
.20394 .22355 Mdot
.20002 .22355 Mdot
.1961 .22355 Mdot
.19218 .21571 Mdot
.18826 .21179 Mdot
.18042 .20002 Mdot
.16473 .18042 Mdot
.16081 .1765 Mdot
.16473 .16865 Mdot
.16865 .18042 Mdot
.17257 .18826 Mdot
.17257 .18826 Mdot
.17257 .18826 Mdot
.16473 .18434 Mdot
.17257 .19218 Mdot
.17257 .19218 Mdot
.17257 .1961 Mdot
.16473 .18434 Mdot
.14905 .1765 Mdot
.15297 .18434 Mdot
.14905 .1765 Mdot
.14905 .18042 Mdot
.14513 .18042 Mdot
.14905 .18042 Mdot
.1412 .16865 Mdot
.12944 .15297 Mdot
.13728 .15689 Mdot
.1412 .15689 Mdot
.13728 .15297 Mdot
.13728 .16081 Mdot
.13336 .16473 Mdot
.12552 .15689 Mdot
.12552 .14905 Mdot
.11376 .13336 Mdot
.10591 .12552 Mdot
.09807 .11376 Mdot
.10591 .1216 Mdot
.10199 .11768 Mdot
.11768 .12944 Mdot
.12552 .13336 Mdot
.11768 .12552 Mdot
.10591 .10983 Mdot
.10591 .10591 Mdot
.10591 .10983 Mdot
.10983 .11376 Mdot
.10199 .10983 Mdot
.10199 .10983 Mdot
.09807 .10591 Mdot
.08631 .09807 Mdot
.07454 .08239 Mdot
.02357 .03141 Mdot
.02749 .03533 Mdot
.02357 .03533 Mdot
.03533 .05102 Mdot
.04317 .05886 Mdot
.05886 .07454 Mdot
.08239 .10591 Mdot
.07454 .09415 Mdot
.06278 .07454 Mdot
.03925 .04709 Mdot
.04709 .05886 Mdot
.05886 .07846 Mdot
.05102 .06278 Mdot
.04709 .06278 Mdot
.07062 .09415 Mdot
.09807 .1216 Mdot
.11376 .1412 Mdot
.11768 .1412 Mdot
.13336 .16473 Mdot
.12944 .16081 Mdot
.12944 .16081 Mdot
.13728 .16865 Mdot
.13336 .16865 Mdot
.13728 .16865 Mdot
.12944 .16473 Mdot
.1412 .1765 Mdot
.14905 .18826 Mdot
.14905 .18434 Mdot
.15689 .19218 Mdot
.16081 .1961 Mdot
.15689 .18826 Mdot
.14905 .1765 Mdot
.16081 .18434 Mdot
.16473 .18042 Mdot
.18042 .20394 Mdot
.17257 .19218 Mdot
.18042 .20002 Mdot
.18434 .20002 Mdot
.1765 .1961 Mdot
.18042 .1961 Mdot
.18042 .20002 Mdot
.18434 .20787 Mdot
.18042 .20002 Mdot
.1765 .1961 Mdot
.18042 .20787 Mdot
.19218 .21179 Mdot
.1961 .21571 Mdot
.19218 .21179 Mdot
.18826 .20787 Mdot
.18434 .20787 Mdot
.18042 .19218 Mdot
.17257 .18042 Mdot
.16865 .1765 Mdot
.16865 .18434 Mdot
.16865 .18434 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.18042 .20002 Mdot
.18042 .20394 Mdot
.18042 .20787 Mdot
.1765 .21179 Mdot
.18042 .21571 Mdot
.17257 .20787 Mdot
.16865 .20394 Mdot
.16081 .19218 Mdot
.16865 .20394 Mdot
.1765 .20787 Mdot
.18042 .21571 Mdot
.18434 .21963 Mdot
.18826 .22747 Mdot
.1961 .23531 Mdot
.1961 .23531 Mdot
.20394 .23531 Mdot
.20787 .23924 Mdot
.20787 .24316 Mdot
.20394 .23531 Mdot
.20787 .23924 Mdot
.1961 .22747 Mdot
.20394 .23139 Mdot
.20002 .22747 Mdot
.1961 .21571 Mdot
.1961 .21963 Mdot
.20002 .22747 Mdot
.1961 .21571 Mdot
.20002 .21179 Mdot
.20394 .21179 Mdot
.20002 .20787 Mdot
.18826 .20394 Mdot
.18826 .21179 Mdot
.18826 .21179 Mdot
.18042 .20787 Mdot
.1765 .20002 Mdot
.18042 .20002 Mdot
.18434 .20394 Mdot
.1961 .21963 Mdot
.19218 .21571 Mdot
.19218 .21571 Mdot
.20002 .21571 Mdot
.20002 .21963 Mdot
.21179 .23139 Mdot
.22747 .24316 Mdot
.21571 .23139 Mdot
.19218 .20787 Mdot
.18042 .20787 Mdot
.18826 .21571 Mdot
.18826 .21571 Mdot
.19218 .21963 Mdot
.19218 .22355 Mdot
.19218 .22355 Mdot
.20002 .23139 Mdot
.1961 .21963 Mdot
.18826 .21179 Mdot
.1765 .20002 Mdot
.18434 .20787 Mdot
.18042 .20394 Mdot
.18826 .21179 Mdot
.1765 .1961 Mdot
.17257 .18042 Mdot
.17257 .18434 Mdot
.18042 .19218 Mdot
.1765 .19218 Mdot
.18042 .1961 Mdot
.1765 .19218 Mdot
.17257 .18826 Mdot
.16865 .18826 Mdot
.17257 .18826 Mdot
.17257 .19218 Mdot
.17257 .19218 Mdot
.16865 .19218 Mdot
.16865 .19218 Mdot
.15297 .17257 Mdot
.15689 .1765 Mdot
.15689 .1765 Mdot
.16081 .18042 Mdot
.16473 .18042 Mdot
.13336 .14905 Mdot
.13336 .15297 Mdot
.13728 .15297 Mdot
.13336 .15297 Mdot
.12944 .15297 Mdot
.12944 .15689 Mdot
.12944 .16473 Mdot
.12552 .14905 Mdot
.12944 .14513 Mdot
.12552 .13336 Mdot
.12944 .13728 Mdot
.13728 .14905 Mdot
.11376 .12552 Mdot
.11768 .13336 Mdot
.12944 .14513 Mdot
.1216 .12944 Mdot
.11376 .12944 Mdot
.11376 .12944 Mdot
.10591 .11376 Mdot
.10591 .11376 Mdot
.10983 .11376 Mdot
.10983 .11768 Mdot
.10983 .11768 Mdot
.09415 .09807 Mdot
.07846 .08631 Mdot
.01572 .02357 Mdot
.02357 .03141 Mdot
.01965 .02749 Mdot
.02357 .03533 Mdot
.02357 .03533 Mdot
.04709 .06278 Mdot
.05494 .07454 Mdot
.05886 .07846 Mdot
.06278 .08239 Mdot
.05886 .0667 Mdot
.06278 .0667 Mdot
.06278 .07062 Mdot
.06278 .07062 Mdot
.05102 .05494 Mdot
.05102 .05494 Mdot
.05102 .05886 Mdot
.07846 .09415 Mdot
.10199 .11768 Mdot
.11768 .13728 Mdot
.13336 .15297 Mdot
.13728 .16473 Mdot
.1412 .1765 Mdot
.14513 .18042 Mdot
.13728 .17257 Mdot
.13336 .16865 Mdot
.13728 .17257 Mdot
.13728 .17257 Mdot
.14905 .18434 Mdot
.15297 .18826 Mdot
.15689 .19218 Mdot
.15689 .18826 Mdot
.16081 .19218 Mdot
.17257 .20002 Mdot
.1765 .1961 Mdot
.18434 .20002 Mdot
.18434 .20002 Mdot
.18434 .20002 Mdot
.18826 .20394 Mdot
.1961 .20787 Mdot
.20002 .21571 Mdot
.1961 .21179 Mdot
.19218 .21179 Mdot
.19218 .21179 Mdot
.18042 .20394 Mdot
.1765 .20787 Mdot
.18042 .21571 Mdot
.18042 .21571 Mdot
.18434 .20787 Mdot
.18826 .21179 Mdot
.19218 .21571 Mdot
.19218 .20394 Mdot
.19218 .1961 Mdot
.1765 .18042 Mdot
.1765 .18826 Mdot
.17257 .1765 Mdot
.1765 .18826 Mdot
.1765 .19218 Mdot
.18826 .20394 Mdot
.18434 .21179 Mdot
.18434 .21571 Mdot
.1765 .20787 Mdot
.17257 .20787 Mdot
.17257 .20787 Mdot
.1765 .21179 Mdot
.16081 .20002 Mdot
.17257 .21571 Mdot
.16865 .21179 Mdot
.17257 .21571 Mdot
.18042 .21963 Mdot
.19218 .22747 Mdot
.1961 .23531 Mdot
.1961 .23531 Mdot
.20787 .24316 Mdot
.21179 .24316 Mdot
.21571 .24316 Mdot
.20394 .23139 Mdot
.20002 .22747 Mdot
.20787 .23139 Mdot
.20787 .22747 Mdot
.21179 .22747 Mdot
.21179 .23531 Mdot
.20787 .23139 Mdot
.21179 .23531 Mdot
.20002 .21963 Mdot
.20394 .21571 Mdot
.20787 .21179 Mdot
.20002 .20787 Mdot
.1961 .20787 Mdot
.18826 .20787 Mdot
.18434 .20787 Mdot
.1765 .1961 Mdot
.17257 .20002 Mdot
.17257 .20002 Mdot
.1765 .20002 Mdot
.18826 .21963 Mdot
.18434 .21571 Mdot
.1961 .22355 Mdot
.20002 .22355 Mdot
.20394 .23139 Mdot
.20394 .23531 Mdot
.21179 .24316 Mdot
.21571 .23924 Mdot
.21571 .24316 Mdot
.1961 .22355 Mdot
.18434 .20787 Mdot
.1961 .21571 Mdot
.20787 .23531 Mdot
.20787 .23924 Mdot
.20394 .23139 Mdot
.20394 .23139 Mdot
.18434 .21179 Mdot
.18434 .21571 Mdot
.18042 .21179 Mdot
.17257 .20002 Mdot
.18042 .20787 Mdot
.18826 .21571 Mdot
.18042 .20002 Mdot
.1765 .20002 Mdot
.1765 .19218 Mdot
.18042 .1961 Mdot
.18042 .1961 Mdot
.18826 .20002 Mdot
.18826 .1961 Mdot
.1765 .18826 Mdot
.1765 .18434 Mdot
.18042 .19218 Mdot
.1765 .1961 Mdot
.17257 .1961 Mdot
.16473 .18826 Mdot
.15297 .1765 Mdot
.1412 .16865 Mdot
.14905 .1765 Mdot
.1412 .16081 Mdot
.15297 .16473 Mdot
.16865 .18042 Mdot
.16081 .17257 Mdot
.1412 .15689 Mdot
.14513 .15689 Mdot
.13728 .15297 Mdot
.12552 .14513 Mdot
.1216 .14905 Mdot
.12552 .15689 Mdot
.1216 .15297 Mdot
.10983 .13336 Mdot
.11768 .13336 Mdot
.11768 .13336 Mdot
.12552 .14513 Mdot
.11376 .13336 Mdot
.10591 .12552 Mdot
.12552 .13728 Mdot
.1216 .13728 Mdot
.12552 .13728 Mdot
.11376 .12552 Mdot
.09807 .10591 Mdot
.08631 .09807 Mdot
.10591 .11768 Mdot
.09415 .10983 Mdot
.09807 .11376 Mdot
.08631 .09415 Mdot
.07846 .09023 Mdot
.01572 .03533 Mdot
.02357 .04317 Mdot
.02749 .03925 Mdot
.02357 .03925 Mdot
.01572 .02749 Mdot
.01965 .03141 Mdot
.02749 .03533 Mdot
.01965 .03141 Mdot
.03533 .03533 Mdot
.06278 .0667 Mdot
.08239 .08239 Mdot
.10199 .10591 Mdot
.08631 .09023 Mdot
.0667 .07062 Mdot
.05102 .05886 Mdot
.03925 .04709 Mdot
.03141 .04709 Mdot
.05494 .07454 Mdot
.07454 .09415 Mdot
.10591 .12944 Mdot
.1216 .14905 Mdot
.13728 .17257 Mdot
.15297 .19218 Mdot
.14905 .18826 Mdot
.15297 .19218 Mdot
.14905 .18434 Mdot
.15689 .19218 Mdot
.15689 .1961 Mdot
.14905 .18434 Mdot
.14513 .18042 Mdot
.15297 .19218 Mdot
.16081 .20002 Mdot
.16081 .19218 Mdot
.17257 .1961 Mdot
.18826 .21179 Mdot
.18042 .19218 Mdot
.18434 .20002 Mdot
.18434 .20002 Mdot
.19218 .20787 Mdot
.20002 .22355 Mdot
.1961 .21963 Mdot
.20002 .22355 Mdot
.19218 .21571 Mdot
.18042 .20787 Mdot
.18042 .21179 Mdot
.18434 .21963 Mdot
.18826 .21963 Mdot
.20002 .22747 Mdot
.20002 .22747 Mdot
.1961 .21963 Mdot
.20002 .21963 Mdot
.19218 .20002 Mdot
.18042 .18042 Mdot
.18042 .18434 Mdot
.19218 .1961 Mdot
.18826 .1961 Mdot
.18826 .20787 Mdot
.19218 .21179 Mdot
.1961 .21963 Mdot
.1961 .22355 Mdot
.18042 .21963 Mdot
.1765 .21179 Mdot
.18042 .21963 Mdot
.18434 .22355 Mdot
.18826 .22747 Mdot
.18434 .21963 Mdot
.1961 .23139 Mdot
.18042 .21179 Mdot
.1765 .20787 Mdot
.18042 .20787 Mdot
.18826 .21179 Mdot
.19218 .21963 Mdot
.20394 .23531 Mdot
.20787 .23924 Mdot
.20394 .23139 Mdot
.1961 .22355 Mdot
.1961 .21963 Mdot
.20787 .22747 Mdot
.20002 .21963 Mdot
.21179 .23139 Mdot
.21963 .23531 Mdot
.21963 .23924 Mdot
.21571 .23531 Mdot
.20394 .22747 Mdot
.20787 .22747 Mdot
.21571 .22747 Mdot
.20787 .21571 Mdot
.20002 .20787 Mdot
.1961 .21571 Mdot
.18042 .20394 Mdot
.17257 .1961 Mdot
.17257 .20002 Mdot
.17257 .20002 Mdot
.17257 .20787 Mdot
.1765 .21179 Mdot
.19218 .23139 Mdot
.1961 .22747 Mdot
.18434 .21571 Mdot
.20002 .22747 Mdot
.20002 .23139 Mdot
.1961 .22355 Mdot
.21179 .23531 Mdot
.21571 .23924 Mdot
.20002 .22355 Mdot
.19218 .21179 Mdot
.18042 .1961 Mdot
.18434 .20394 Mdot
.20002 .22355 Mdot
.21179 .24316 Mdot
.20002 .22747 Mdot
.20787 .23531 Mdot
.20002 .23531 Mdot
.19218 .22747 Mdot
.19218 .22355 Mdot
.1961 .22747 Mdot
.20002 .23139 Mdot
.1765 .20787 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.18826 .20394 Mdot
.19218 .21179 Mdot
.18826 .21179 Mdot
.18826 .20394 Mdot
.18434 .20002 Mdot
.18042 .19218 Mdot
.1765 .18826 Mdot
.16865 .18434 Mdot
.17257 .18826 Mdot
.16473 .18434 Mdot
.15689 .18826 Mdot
.15297 .18434 Mdot
.1412 .17257 Mdot
.14905 .16865 Mdot
.14905 .16865 Mdot
.16473 .18042 Mdot
.16081 .1765 Mdot
.16081 .18042 Mdot
.15297 .16865 Mdot
.1412 .15689 Mdot
.1412 .16081 Mdot
.1216 .13728 Mdot
.11768 .12944 Mdot
.11376 .12944 Mdot
.1216 .14513 Mdot
.1216 .14905 Mdot
.1216 .14513 Mdot
.11768 .14905 Mdot
.11376 .1412 Mdot
.11376 .13336 Mdot
.10199 .1216 Mdot
.10199 .12552 Mdot
.11376 .13336 Mdot
.11768 .12944 Mdot
.11768 .12944 Mdot
.10591 .1216 Mdot
.09807 .11768 Mdot
.09807 .11376 Mdot
.09807 .11768 Mdot
.08239 .10199 Mdot
.0667 .08631 Mdot
.01965 .03925 Mdot
.01965 .03533 Mdot
.02749 .04317 Mdot
.03141 .04709 Mdot
.02749 .04317 Mdot
.0118 .02749 Mdot
.00788 .01965 Mdot
.01572 .02749 Mdot
.03533 .03533 Mdot
.03925 .02749 Mdot
.08239 .07846 Mdot
.09807 .10199 Mdot
.09415 .09807 Mdot
.07454 .08239 Mdot
.04709 .05494 Mdot
.04709 .05102 Mdot
.04317 .04709 Mdot
.03141 .03533 Mdot
.03533 .04709 Mdot
.0667 .08239 Mdot
.10983 .12552 Mdot
.13336 .15297 Mdot
.14905 .17257 Mdot
.16081 .18826 Mdot
.16865 .20787 Mdot
.16865 .20787 Mdot
.17257 .21571 Mdot
.16081 .20002 Mdot
.15689 .20002 Mdot
.14905 .19218 Mdot
.1412 .18434 Mdot
.14905 .19218 Mdot
.16473 .20394 Mdot
.17257 .20394 Mdot
.18434 .20394 Mdot
.20002 .20787 Mdot
.20002 .20787 Mdot
.20394 .21179 Mdot
.1961 .20394 Mdot
.19218 .20787 Mdot
.18826 .20787 Mdot
.19218 .21571 Mdot
.18434 .21571 Mdot
.18042 .21571 Mdot
.18826 .22355 Mdot
.19218 .23139 Mdot
.20002 .23531 Mdot
.20394 .22747 Mdot
.21571 .23531 Mdot
.21179 .22355 Mdot
.20787 .21963 Mdot
.20394 .21179 Mdot
.20787 .21179 Mdot
.21571 .22355 Mdot
.21179 .21963 Mdot
.20394 .21179 Mdot
.20002 .21179 Mdot
.20394 .22355 Mdot
.18826 .21179 Mdot
.1961 .22355 Mdot
.18826 .22747 Mdot
.1765 .21179 Mdot
.17257 .21179 Mdot
.18042 .21571 Mdot
.19218 .22747 Mdot
.20394 .23531 Mdot
.1961 .22747 Mdot
.20002 .22355 Mdot
.20002 .22355 Mdot
.20002 .21571 Mdot
.20002 .21571 Mdot
.1961 .21571 Mdot
.1961 .21963 Mdot
.20002 .22355 Mdot
.1961 .21963 Mdot
.20787 .23531 Mdot
.21963 .24316 Mdot
.20787 .23139 Mdot
.21963 .24708 Mdot
.21179 .23924 Mdot
.22355 .25492 Mdot
.21963 .24316 Mdot
.23139 .26276 Mdot
.22747 .24708 Mdot
.21571 .22747 Mdot
.21571 .22355 Mdot
.21571 .21963 Mdot
.20394 .21571 Mdot
.19218 .20787 Mdot
.18434 .21179 Mdot
.17257 .20002 Mdot
.16473 .20394 Mdot
.16473 .20002 Mdot
.16865 .20787 Mdot
.16865 .20787 Mdot
.18826 .23531 Mdot
.18826 .23531 Mdot
.18826 .23139 Mdot
.18434 .21571 Mdot
.19218 .22747 Mdot
.1961 .22747 Mdot
.20787 .23531 Mdot
.21571 .24708 Mdot
.20787 .23531 Mdot
.1961 .21963 Mdot
.20787 .22747 Mdot
.19218 .21179 Mdot
.18826 .21179 Mdot
.20002 .22747 Mdot
.20787 .23924 Mdot
.21179 .24316 Mdot
.20787 .24316 Mdot
.20394 .24316 Mdot
.1961 .23924 Mdot
.1961 .23139 Mdot
.1961 .22355 Mdot
.19218 .21963 Mdot
.18434 .21179 Mdot
.19218 .21571 Mdot
.1961 .21179 Mdot
.18826 .20787 Mdot
.19218 .20787 Mdot
.19218 .21179 Mdot
.18826 .20787 Mdot
.18042 .20002 Mdot
.1765 .18826 Mdot
.18042 .1961 Mdot
.15689 .1765 Mdot
.16473 .18826 Mdot
.16081 .19218 Mdot
.15689 .19218 Mdot
.16473 .18826 Mdot
.16473 .18434 Mdot
.16865 .18826 Mdot
.1765 .19218 Mdot
.18042 .18826 Mdot
.17257 .1765 Mdot
.16865 .17257 Mdot
.17257 .18042 Mdot
.16081 .16473 Mdot
.13728 .1412 Mdot
.12944 .13336 Mdot
.12552 .13336 Mdot
.12552 .13728 Mdot
.12552 .14513 Mdot
.12552 .14905 Mdot
.12944 .15297 Mdot
.13728 .15689 Mdot
.13728 .15689 Mdot
.12552 .15297 Mdot
.11376 .1412 Mdot
.11768 .14513 Mdot
.11768 .13336 Mdot
.11768 .13336 Mdot
.11768 .13336 Mdot
.10591 .1216 Mdot
.10591 .12552 Mdot
.09807 .10983 Mdot
.09415 .09807 Mdot
.07454 .08631 Mdot
.02749 .04709 Mdot
.03533 .04709 Mdot
.04317 .05494 Mdot
.05102 .06278 Mdot
.04317 .05102 Mdot
.03925 .04709 Mdot
.03141 .03925 Mdot
.03925 .05102 Mdot
.04317 .04317 Mdot
.03925 .03533 Mdot
.05102 .05102 Mdot
.05494 .05102 Mdot
.06278 .06278 Mdot
.05886 .05886 Mdot
.0667 .06278 Mdot
.05494 .05494 Mdot
.05102 .04317 Mdot
.04709 .03141 Mdot
.03533 .01965 Mdot
.03925 .02749 Mdot
.06278 .05494 Mdot
.10983 .11376 Mdot
.15297 .16081 Mdot
.16865 .18826 Mdot
.17257 .20394 Mdot
.16473 .20787 Mdot
.17257 .21963 Mdot
.16473 .21963 Mdot
.16081 .21571 Mdot
.16081 .20394 Mdot
.16473 .21179 Mdot
.16473 .20787 Mdot
.16865 .21571 Mdot
.18042 .20787 Mdot
.1765 .19218 Mdot
.18826 .1961 Mdot
.20394 .21179 Mdot
.20394 .20787 Mdot
.20394 .21179 Mdot
.18826 .20394 Mdot
.18826 .20787 Mdot
.1765 .20787 Mdot
.18042 .21571 Mdot
.18042 .21571 Mdot
.19218 .23139 Mdot
.20394 .23924 Mdot
.21179 .23924 Mdot
.21179 .23139 Mdot
.21571 .23139 Mdot
.21963 .22747 Mdot
.23924 .24316 Mdot
.22747 .23531 Mdot
.23139 .23531 Mdot
.22747 .23531 Mdot
.21963 .22747 Mdot
.20787 .21179 Mdot
.20394 .21179 Mdot
.20394 .22355 Mdot
.20394 .23139 Mdot
.20002 .23924 Mdot
.19218 .23924 Mdot
.18434 .23139 Mdot
.18042 .21571 Mdot
.19218 .22747 Mdot
.20394 .23531 Mdot
.21963 .24316 Mdot
.21963 .23924 Mdot
.23531 .24708 Mdot
.23531 .24316 Mdot
.22747 .23139 Mdot
.22747 .23139 Mdot
.21571 .22355 Mdot
.20787 .21963 Mdot
.22747 .24708 Mdot
.21571 .24316 Mdot
.21179 .24708 Mdot
.22355 .25492 Mdot
.21963 .25492 Mdot
.21179 .24708 Mdot
.20394 .23531 Mdot
.21571 .24316 Mdot
.22747 .251 Mdot
.23139 .25492 Mdot
.23531 .25492 Mdot
.22747 .23531 Mdot
.22747 .23531 Mdot
.21179 .21571 Mdot
.20002 .20787 Mdot
.1961 .20787 Mdot
.18826 .21571 Mdot
.16865 .20394 Mdot
.17257 .21179 Mdot
.17257 .21179 Mdot
.16865 .20787 Mdot
.16473 .21179 Mdot
.1765 .22355 Mdot
.18434 .23531 Mdot
.19218 .24316 Mdot
.1961 .23924 Mdot
.20002 .23531 Mdot
.21571 .24708 Mdot
.21179 .23531 Mdot
.21571 .24708 Mdot
.22355 .25492 Mdot
.22355 .24708 Mdot
.21963 .24316 Mdot
.20394 .23531 Mdot
.1961 .22355 Mdot
.1765 .20787 Mdot
.18434 .21963 Mdot
.1961 .23139 Mdot
.20394 .24316 Mdot
.20787 .251 Mdot
.20394 .24316 Mdot
.20002 .23531 Mdot
.1961 .22355 Mdot
.20787 .23139 Mdot
.20787 .22355 Mdot
.20787 .22747 Mdot
.20787 .21179 Mdot
.21179 .21963 Mdot
.20002 .21571 Mdot
.19218 .20787 Mdot
.1961 .21571 Mdot
.18826 .20787 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.16865 .1961 Mdot
.16473 .20002 Mdot
.16473 .20002 Mdot
.16081 .1961 Mdot
.16865 .20394 Mdot
.17257 .1961 Mdot
.17257 .18434 Mdot
.1765 .18434 Mdot
.18434 .18826 Mdot
.18042 .17257 Mdot
.18826 .18042 Mdot
.18434 .18042 Mdot
.17257 .16865 Mdot
.16081 .15689 Mdot
.1412 .14513 Mdot
.13728 .1412 Mdot
.12944 .1412 Mdot
.13336 .15297 Mdot
.12944 .14905 Mdot
.12944 .15689 Mdot
.13336 .16081 Mdot
.13336 .16081 Mdot
.12552 .15297 Mdot
.1216 .15297 Mdot
.1216 .14905 Mdot
.12552 .15297 Mdot
.11376 .1412 Mdot
.11768 .14905 Mdot
.1216 .15297 Mdot
.1216 .14905 Mdot
.11768 .14513 Mdot
.11768 .13336 Mdot
.09023 .09415 Mdot
.03925 .04709 Mdot
.05102 .05494 Mdot
.07062 .07062 Mdot
.06278 .0667 Mdot
.05102 .05494 Mdot
.03925 .03925 Mdot
.03141 .03533 Mdot
.04317 .04709 Mdot
.03925 .04317 Mdot
.04709 .05102 Mdot
.03925 .04709 Mdot
.02749 .03141 Mdot
.04317 .03925 Mdot
.05494 .05494 Mdot
.05886 .05494 Mdot
.05886 .05102 Mdot
.05886 .05494 Mdot
.05494 .03925 Mdot
.04317 .02357 Mdot
.03925 .01965 Mdot
.03141 .01572 Mdot
.07846 .07454 Mdot
.10591 .10983 Mdot
.13728 .15689 Mdot
.15689 .18826 Mdot
.16473 .20787 Mdot
.16081 .21179 Mdot
.16473 .22355 Mdot
.16081 .22355 Mdot
.15689 .21571 Mdot
.16473 .21179 Mdot
.17257 .21963 Mdot
.18826 .22747 Mdot
.18826 .21963 Mdot
.19218 .21179 Mdot
.20002 .21571 Mdot
.20394 .21963 Mdot
.20787 .21963 Mdot
.20002 .21963 Mdot
.1961 .21571 Mdot
.1961 .21963 Mdot
.1961 .23139 Mdot
.1961 .23531 Mdot
.19218 .23139 Mdot
.20002 .24708 Mdot
.1961 .23531 Mdot
.21571 .24316 Mdot
.23924 .26276 Mdot
.23531 .25492 Mdot
.24316 .24708 Mdot
.24708 .24316 Mdot
.24708 .24316 Mdot
.24316 .24316 Mdot
.22747 .22747 Mdot
.22747 .23531 Mdot
.21963 .23531 Mdot
.21963 .23924 Mdot
.21571 .24316 Mdot
.20787 .24316 Mdot
.20002 .23924 Mdot
.20787 .24708 Mdot
.20394 .24708 Mdot
.20394 .23531 Mdot
.21571 .24316 Mdot
.21963 .24708 Mdot
.23924 .251 Mdot
.23924 .24316 Mdot
.251 .24708 Mdot
.24316 .24316 Mdot
.23139 .22747 Mdot
.22355 .22747 Mdot
.22747 .23531 Mdot
.21963 .23924 Mdot
.20787 .23139 Mdot
.21963 .24708 Mdot
.21179 .24708 Mdot
.22355 .26668 Mdot
.22747 .26668 Mdot
.22747 .25884 Mdot
.22355 .251 Mdot
.22747 .24708 Mdot
.22747 .23924 Mdot
.23924 .25492 Mdot
.23531 .24708 Mdot
.23924 .24708 Mdot
.23531 .24708 Mdot
.21963 .23924 Mdot
.20394 .22747 Mdot
.20787 .23924 Mdot
.19218 .23139 Mdot
.18042 .21963 Mdot
.18434 .22747 Mdot
.1765 .21571 Mdot
.18042 .21963 Mdot
.16865 .20787 Mdot
.16473 .20002 Mdot
.16865 .20787 Mdot
.18042 .21571 Mdot
.19218 .22747 Mdot
.20394 .23924 Mdot
.21179 .22747 Mdot
.21179 .23139 Mdot
.21571 .24316 Mdot
.21571 .251 Mdot
.21179 .25492 Mdot
.20787 .25492 Mdot
.21179 .25492 Mdot
.20002 .24708 Mdot
.1961 .23531 Mdot
.18826 .22747 Mdot
.18434 .21963 Mdot
.19218 .22747 Mdot
.20002 .23139 Mdot
.1961 .23139 Mdot
.20394 .23139 Mdot
.21571 .22747 Mdot
.22355 .22747 Mdot
.21963 .21571 Mdot
.20787 .20394 Mdot
.20002 .20002 Mdot
.19218 .1961 Mdot
.18826 .20787 Mdot
.19218 .22355 Mdot
.17257 .20394 Mdot
.17257 .20787 Mdot
.16081 .19218 Mdot
.16473 .20002 Mdot
.16473 .19218 Mdot
.17257 .20394 Mdot
.18042 .21571 Mdot
.17257 .20394 Mdot
.1765 .20394 Mdot
.18042 .20002 Mdot
.18434 .18826 Mdot
.19218 .19218 Mdot
.1961 .19218 Mdot
.20002 .19218 Mdot
.19218 .18434 Mdot
.1765 .16473 Mdot
.17257 .17257 Mdot
.15689 .16865 Mdot
.15297 .16865 Mdot
.13336 .15297 Mdot
.11376 .13728 Mdot
.1216 .14905 Mdot
.11768 .14905 Mdot
.12552 .16081 Mdot
.12944 .16473 Mdot
.13728 .16865 Mdot
.13336 .16473 Mdot
.1216 .15689 Mdot
.12552 .16081 Mdot
.12552 .16081 Mdot
.1216 .15689 Mdot
.11768 .14513 Mdot
.12552 .14905 Mdot
.1216 .1412 Mdot
.12552 .1412 Mdot
.1216 .12944 Mdot
.11376 .10983 Mdot
.05886 .07062 Mdot
.05494 .06278 Mdot
.05494 .0667 Mdot
.04709 .05494 Mdot
.02749 .03533 Mdot
.01965 .02749 Mdot
.02357 .03141 Mdot
.04709 .05494 Mdot
.05494 .0667 Mdot
.04709 .05886 Mdot
.04317 .05886 Mdot
.03533 .04317 Mdot
.04317 .04709 Mdot
.04709 .05494 Mdot
.06278 .0667 Mdot
.05886 .05494 Mdot
.04317 .03925 Mdot
.03141 .02357 Mdot
.02749 .01572 Mdot
.03925 .02749 Mdot
.04709 .03533 Mdot
.04317 .03141 Mdot
.06278 .05886 Mdot
.09415 .10591 Mdot
.13336 .16081 Mdot
.14905 .18434 Mdot
.15689 .20002 Mdot
.15297 .20787 Mdot
.15689 .20787 Mdot
.17257 .21963 Mdot
.1765 .22355 Mdot
.1765 .21963 Mdot
.18826 .21963 Mdot
.18434 .21179 Mdot
.18826 .21571 Mdot
.18826 .20394 Mdot
.20787 .21963 Mdot
.21571 .22747 Mdot
.20002 .21571 Mdot
.20394 .22355 Mdot
.21571 .23531 Mdot
.20394 .23139 Mdot
.1961 .23531 Mdot
.18826 .23139 Mdot
.19218 .23924 Mdot
.19218 .23531 Mdot
.21179 .251 Mdot
.21963 .251 Mdot
.22355 .251 Mdot
.22747 .24708 Mdot
.22747 .23924 Mdot
.22747 .23139 Mdot
.23924 .24708 Mdot
.22747 .23531 Mdot
.23139 .24316 Mdot
.22355 .23924 Mdot
.21963 .23924 Mdot
.21179 .23531 Mdot
.20787 .23139 Mdot
.21571 .24316 Mdot
.21963 .251 Mdot
.21571 .251 Mdot
.21179 .24316 Mdot
.21963 .23924 Mdot
.22355 .23531 Mdot
.23139 .23924 Mdot
.23924 .23924 Mdot
.24316 .23924 Mdot
.23531 .22355 Mdot
.23139 .22355 Mdot
.23139 .23924 Mdot
.21571 .22355 Mdot
.20787 .22355 Mdot
.21963 .24708 Mdot
.21179 .251 Mdot
.21571 .25884 Mdot
.22355 .26668 Mdot
.23139 .27061 Mdot
.22747 .25884 Mdot
.21963 .24708 Mdot
.21963 .24316 Mdot
.22355 .23531 Mdot
.23924 .251 Mdot
.23924 .24708 Mdot
.24708 .25492 Mdot
.24316 .25884 Mdot
.22747 .25492 Mdot
.21179 .24316 Mdot
.20787 .24316 Mdot
.20394 .23924 Mdot
.20002 .24316 Mdot
.18826 .23139 Mdot
.18042 .21963 Mdot
.18434 .21963 Mdot
.1765 .20787 Mdot
.16865 .1961 Mdot
.16473 .1961 Mdot
.16865 .1961 Mdot
.17257 .20394 Mdot
.18434 .21571 Mdot
.18826 .21179 Mdot
.18826 .21179 Mdot
.20002 .22747 Mdot
.20002 .22747 Mdot
.1961 .22355 Mdot
.20002 .23139 Mdot
.20394 .24316 Mdot
.20002 .23531 Mdot
.1961 .23139 Mdot
.18826 .22747 Mdot
.18042 .21571 Mdot
.19218 .21963 Mdot
.20002 .22747 Mdot
.20394 .21963 Mdot
.21179 .22747 Mdot
.21571 .22747 Mdot
.21963 .22355 Mdot
.21963 .22355 Mdot
.21571 .21571 Mdot
.1961 .1961 Mdot
.18042 .19218 Mdot
.16865 .19218 Mdot
.15689 .18434 Mdot
.16473 .1961 Mdot
.16865 .20002 Mdot
.17257 .20394 Mdot
.18042 .21179 Mdot
.18042 .20787 Mdot
.17257 .19218 Mdot
.18042 .20394 Mdot
.18826 .20394 Mdot
.18434 .20002 Mdot
.19218 .20002 Mdot
.18826 .19218 Mdot
.1961 .19218 Mdot
.19218 .18434 Mdot
.18826 .1765 Mdot
.20002 .1961 Mdot
.18042 .18042 Mdot
.18042 .18826 Mdot
.16865 .18042 Mdot
.14905 .16865 Mdot
.13336 .15689 Mdot
.12552 .14905 Mdot
.1216 .15297 Mdot
.11768 .14513 Mdot
.12552 .15689 Mdot
.12552 .16081 Mdot
.1216 .15689 Mdot
.12944 .16473 Mdot
.12552 .16081 Mdot
.12944 .15297 Mdot
.12552 .15297 Mdot
.11768 .14513 Mdot
.10199 .12552 Mdot
.1216 .1412 Mdot
.12552 .1412 Mdot
.12552 .13336 Mdot
.1216 .12944 Mdot
.11376 .1216 Mdot
.06278 .08239 Mdot
.05102 .06278 Mdot
.04317 .05102 Mdot
.03925 .04709 Mdot
.04317 .05102 Mdot
.02749 .03925 Mdot
.02357 .03141 Mdot
.02749 .03533 Mdot
.03925 .05102 Mdot
.03141 .03533 Mdot
.02749 .03533 Mdot
.03533 .03925 Mdot
.03533 .04317 Mdot
.04317 .05102 Mdot
.03925 .03925 Mdot
.03925 .03533 Mdot
.03533 .03141 Mdot
.02357 .01965 Mdot
.01965 .00788 Mdot
.05886 .05494 Mdot
.09023 .08631 Mdot
.09415 .09023 Mdot
.09023 .08631 Mdot
.09807 .09807 Mdot
.10983 .11768 Mdot
.13336 .14905 Mdot
.14513 .18042 Mdot
.15297 .1961 Mdot
.14905 .20002 Mdot
.16473 .20787 Mdot
.17257 .20787 Mdot
.18042 .21963 Mdot
.18826 .21963 Mdot
.18826 .21571 Mdot
.19218 .21963 Mdot
.20002 .21963 Mdot
.20787 .22355 Mdot
.22747 .23139 Mdot
.22747 .23139 Mdot
.21571 .22355 Mdot
.21963 .22747 Mdot
.20787 .22355 Mdot
.20787 .23139 Mdot
.20787 .24316 Mdot
.1961 .23924 Mdot
.20002 .24316 Mdot
.20787 .25492 Mdot
.21179 .25492 Mdot
.22747 .26276 Mdot
.22355 .25884 Mdot
.22355 .25492 Mdot
.22355 .24708 Mdot
.23531 .251 Mdot
.23139 .24708 Mdot
.23531 .251 Mdot
.23531 .25492 Mdot
.22747 .24316 Mdot
.22355 .24708 Mdot
.22355 .24316 Mdot
.21571 .24316 Mdot
.20787 .23924 Mdot
.21179 .25492 Mdot
.21179 .25492 Mdot
.20394 .24316 Mdot
.20787 .23531 Mdot
.21963 .24316 Mdot
.22747 .24316 Mdot
.22747 .23531 Mdot
.23531 .23924 Mdot
.23924 .23531 Mdot
.23531 .23531 Mdot
.22355 .23531 Mdot
.21179 .22355 Mdot
.20787 .22747 Mdot
.21179 .23924 Mdot
.21963 .26276 Mdot
.22355 .26668 Mdot
.23139 .27845 Mdot
.24708 .28629 Mdot
.24316 .28237 Mdot
.23924 .27453 Mdot
.23924 .26276 Mdot
.24316 .25884 Mdot
.251 .26668 Mdot
.24708 .25884 Mdot
.251 .25884 Mdot
.24708 .26276 Mdot
.23139 .251 Mdot
.23531 .26276 Mdot
.21963 .25492 Mdot
.20787 .251 Mdot
.20002 .23924 Mdot
.18434 .21963 Mdot
.18042 .20787 Mdot
.1765 .1961 Mdot
.16081 .18434 Mdot
.16865 .1961 Mdot
.17257 .20002 Mdot
.16865 .19218 Mdot
.1765 .20394 Mdot
.1765 .20002 Mdot
.18434 .20787 Mdot
.19218 .21179 Mdot
.20787 .22747 Mdot
.21571 .23531 Mdot
.21179 .23139 Mdot
.21963 .23924 Mdot
.20394 .22747 Mdot
.20394 .22747 Mdot
.1961 .22355 Mdot
.20002 .23531 Mdot
.20002 .23531 Mdot
.19218 .22355 Mdot
.19218 .22355 Mdot
.20002 .22747 Mdot
.20787 .23139 Mdot
.21571 .23139 Mdot
.22355 .23531 Mdot
.22747 .23531 Mdot
.20787 .21179 Mdot
.19218 .20002 Mdot
.18434 .20002 Mdot
.1765 .18826 Mdot
.17257 .18434 Mdot
.1765 .19218 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.18434 .20787 Mdot
.18042 .20394 Mdot
.18826 .21179 Mdot
.18434 .20787 Mdot
.18826 .21179 Mdot
.18042 .20002 Mdot
.18434 .1961 Mdot
.18826 .1961 Mdot
.1961 .20002 Mdot
.18826 .18042 Mdot
.18826 .1765 Mdot
.19218 .18434 Mdot
.18042 .1765 Mdot
.1765 .18042 Mdot
.17257 .18434 Mdot
.16081 .17257 Mdot
.14513 .15689 Mdot
.13728 .16081 Mdot
.12552 .14513 Mdot
.12552 .14513 Mdot
.12552 .15297 Mdot
.11768 .14513 Mdot
.1216 .14905 Mdot
.12944 .16081 Mdot
.13336 .15297 Mdot
.13336 .15297 Mdot
.13336 .14905 Mdot
.1216 .1412 Mdot
.11768 .13728 Mdot
.1216 .13728 Mdot
.1216 .13336 Mdot
.11768 .12944 Mdot
.11376 .1216 Mdot
.04709 .0667 Mdot
.04709 .05886 Mdot
.03533 .04709 Mdot
.03925 .05102 Mdot
.04317 .05494 Mdot
.03141 .03925 Mdot
.02357 .03533 Mdot
.02749 .03925 Mdot
.02749 .02749 Mdot
.03141 .03533 Mdot
.03533 .04317 Mdot
.03141 .03925 Mdot
.03141 .03925 Mdot
.03533 .04317 Mdot
.02749 .03533 Mdot
.02357 .03141 Mdot
.01965 .02749 Mdot
.01965 .01965 Mdot
.01572 .0118 Mdot
.01965 .01965 Mdot
.0667 .07454 Mdot
.1216 .13336 Mdot
.18042 .1961 Mdot
.20002 .21571 Mdot
.18826 .20002 Mdot
.17257 .18826 Mdot
.16865 .19218 Mdot
.17257 .20394 Mdot
.18042 .21963 Mdot
.16473 .20002 Mdot
.16081 .1961 Mdot
.15297 .19218 Mdot
.15689 .19218 Mdot
.15689 .18826 Mdot
.16865 .19218 Mdot
.16865 .19218 Mdot
.18434 .20394 Mdot
.19218 .21571 Mdot
.20787 .21963 Mdot
.20394 .21571 Mdot
.20787 .21963 Mdot
.21179 .22747 Mdot
.20002 .21963 Mdot
.21179 .23924 Mdot
.18434 .21963 Mdot
.19218 .22747 Mdot
.19218 .23139 Mdot
.20787 .24708 Mdot
.20394 .23531 Mdot
.20787 .24316 Mdot
.20787 .23924 Mdot
.20394 .23531 Mdot
.21571 .24316 Mdot
.21571 .24316 Mdot
.22355 .251 Mdot
.22747 .25884 Mdot
.21963 .24316 Mdot
.21179 .23531 Mdot
.21963 .24708 Mdot
.21571 .23924 Mdot
.22355 .25492 Mdot
.21179 .251 Mdot
.21179 .25492 Mdot
.20787 .251 Mdot
.21571 .251 Mdot
.21571 .24708 Mdot
.21571 .24708 Mdot
.20787 .23531 Mdot
.21963 .23924 Mdot
.21571 .23531 Mdot
.22747 .24316 Mdot
.23139 .24708 Mdot
.23139 .24316 Mdot
.22747 .23924 Mdot
.21571 .23924 Mdot
.21571 .24708 Mdot
.23531 .27453 Mdot
.23924 .28237 Mdot
.23924 .27845 Mdot
.23531 .27061 Mdot
.23924 .27453 Mdot
.23139 .26276 Mdot
.23924 .26276 Mdot
.22355 .24316 Mdot
.23139 .251 Mdot
.23924 .25492 Mdot
.23924 .25884 Mdot
.23924 .26276 Mdot
.23531 .26276 Mdot
.23139 .25884 Mdot
.22747 .25884 Mdot
.21179 .24316 Mdot
.18434 .21179 Mdot
.1765 .20394 Mdot
.16865 .19218 Mdot
.16473 .19218 Mdot
.16473 .19218 Mdot
.16865 .19218 Mdot
.17257 .19218 Mdot
.1765 .20394 Mdot
.16865 .18826 Mdot
.16473 .18434 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.19218 .20394 Mdot
.1961 .21571 Mdot
.19218 .21571 Mdot
.20002 .22355 Mdot
.20394 .22747 Mdot
.20787 .23531 Mdot
.20787 .24316 Mdot
.21571 .25884 Mdot
.21179 .251 Mdot
.20002 .24316 Mdot
.20002 .23531 Mdot
.1961 .22747 Mdot
.18434 .20787 Mdot
.20394 .21963 Mdot
.22355 .24316 Mdot
.22747 .23531 Mdot
.21571 .21963 Mdot
.20394 .21179 Mdot
.19218 .20002 Mdot
.18042 .18434 Mdot
.18042 .18826 Mdot
.18042 .1961 Mdot
.18826 .20787 Mdot
.18434 .20787 Mdot
.16865 .20002 Mdot
.16865 .20002 Mdot
.16473 .20002 Mdot
.16865 .20002 Mdot
.17257 .19218 Mdot
.1765 .1961 Mdot
.18434 .20394 Mdot
.1961 .20002 Mdot
.18826 .18434 Mdot
.18042 .16865 Mdot
.18434 .1765 Mdot
.18434 .18042 Mdot
.18826 .18434 Mdot
.16865 .15689 Mdot
.18042 .1765 Mdot
.16865 .17257 Mdot
.15297 .16081 Mdot
.14513 .15297 Mdot
.13336 .14513 Mdot
.13336 .14905 Mdot
.12552 .14513 Mdot
.1216 .1412 Mdot
.1216 .1412 Mdot
.11768 .14513 Mdot
.1216 .14513 Mdot
.10983 .13336 Mdot
.11376 .13336 Mdot
.1216 .1412 Mdot
.13336 .14905 Mdot
.12552 .1412 Mdot
.1216 .12944 Mdot
.10983 .11768 Mdot
.03141 .04709 Mdot
.03533 .04709 Mdot
.03925 .05102 Mdot
.03925 .03925 Mdot
.03141 .03533 Mdot
.03533 .03533 Mdot
.04709 .05102 Mdot
.05886 .0667 Mdot
.06278 .0667 Mdot
.05494 .05494 Mdot
.06278 .0667 Mdot
.05102 .05886 Mdot
.04317 .05494 Mdot
.03533 .04709 Mdot
.02749 .03925 Mdot
.01965 .02749 Mdot
.01965 .02749 Mdot
.0118 .01965 Mdot
.0118 .01965 Mdot
.0118 .01965 Mdot
.00788 .0118 Mdot
.07062 .08631 Mdot
.22355 .27061 Mdot
.22355 .25884 Mdot
.20394 .22747 Mdot
.20394 .23139 Mdot
.20002 .22747 Mdot
.20002 .22355 Mdot
.21571 .25492 Mdot
.20002 .23924 Mdot
.15297 .18434 Mdot
.12944 .15689 Mdot
.1216 .15297 Mdot
.1216 .14513 Mdot
.12552 .14513 Mdot
.13728 .15689 Mdot
.1412 .16473 Mdot
.14513 .16473 Mdot
.16473 .18434 Mdot
.18042 .20394 Mdot
.19218 .21179 Mdot
.20394 .22355 Mdot
.21571 .23924 Mdot
.22747 .25884 Mdot
.22747 .25884 Mdot
.21179 .24708 Mdot
.21571 .251 Mdot
.22355 .251 Mdot
.21179 .23924 Mdot
.22355 .251 Mdot
.21963 .24316 Mdot
.22355 .251 Mdot
.21963 .24708 Mdot
.21963 .24708 Mdot
.21963 .24708 Mdot
.22355 .25492 Mdot
.22355 .25492 Mdot
.21963 .24708 Mdot
.21963 .251 Mdot
.21963 .24708 Mdot
.22355 .24708 Mdot
.23139 .25884 Mdot
.22747 .24708 Mdot
.22355 .251 Mdot
.22355 .25492 Mdot
.22747 .25492 Mdot
.22747 .25492 Mdot
.20787 .23924 Mdot
.21571 .24316 Mdot
.21571 .24708 Mdot
.21571 .251 Mdot
.22355 .25492 Mdot
.21963 .24708 Mdot
.22355 .251 Mdot
.21963 .24708 Mdot
.21571 .24708 Mdot
.23139 .26276 Mdot
.22747 .26276 Mdot
.23531 .26276 Mdot
.23924 .26276 Mdot
.23531 .25884 Mdot
.23531 .26276 Mdot
.22355 .24708 Mdot
.21571 .24316 Mdot
.21571 .24316 Mdot
.22355 .24708 Mdot
.22747 .25492 Mdot
.23139 .25884 Mdot
.23139 .25492 Mdot
.23531 .26276 Mdot
.23924 .27061 Mdot
.21571 .24316 Mdot
.20002 .22355 Mdot
.18042 .20787 Mdot
.17257 .20002 Mdot
.17257 .1961 Mdot
.16865 .19218 Mdot
.1765 .20394 Mdot
.1765 .20002 Mdot
.17257 .1961 Mdot
.16081 .18434 Mdot
.16473 .18042 Mdot
.16865 .18826 Mdot
.16865 .19218 Mdot
.1765 .1961 Mdot
.1765 .20002 Mdot
.1765 .20394 Mdot
.1961 .22355 Mdot
.21179 .23531 Mdot
.21571 .24316 Mdot
.21571 .23924 Mdot
.21963 .251 Mdot
.21963 .25492 Mdot
.21571 .251 Mdot
.20787 .24316 Mdot
.1961 .22355 Mdot
.18434 .20787 Mdot
.1961 .22355 Mdot
.20394 .23139 Mdot
.19218 .21963 Mdot
.20002 .21963 Mdot
.20002 .22355 Mdot
.18434 .20394 Mdot
.18042 .20002 Mdot
.18434 .1961 Mdot
.17257 .18826 Mdot
.16081 .1765 Mdot
.1765 .18826 Mdot
.18042 .20394 Mdot
.1765 .20394 Mdot
.17257 .1961 Mdot
.1765 .20002 Mdot
.1765 .1961 Mdot
.17257 .19218 Mdot
.18042 .20394 Mdot
.18826 .20787 Mdot
.18042 .18826 Mdot
.18042 .18434 Mdot
.16865 .16473 Mdot
.16473 .16081 Mdot
.17257 .1765 Mdot
.16081 .16081 Mdot
.15297 .15689 Mdot
.14513 .15297 Mdot
.15297 .16081 Mdot
.14905 .15297 Mdot
.12944 .13728 Mdot
.13728 .14513 Mdot
.12944 .13728 Mdot
.13336 .14905 Mdot
.12944 .15297 Mdot
.12552 .15297 Mdot
.11376 .13728 Mdot
.10983 .13336 Mdot
.1216 .14513 Mdot
.10983 .13336 Mdot
.11376 .13728 Mdot
.12944 .1412 Mdot
.12944 .13336 Mdot
.11376 .11768 Mdot
.02357 .04317 Mdot
.02357 .03925 Mdot
.04317 .05494 Mdot
.05494 .05494 Mdot
.04317 .03925 Mdot
.04709 .04709 Mdot
.0667 .07454 Mdot
.07846 .09415 Mdot
.09023 .10199 Mdot
.07846 .09023 Mdot
.08631 .10199 Mdot
.07846 .09415 Mdot
.07062 .08631 Mdot
.04709 .05886 Mdot
.03141 .04317 Mdot
.01965 .02749 Mdot
.02749 .03141 Mdot
.02749 .03141 Mdot
.01572 .02357 Mdot
.0118 .01572 Mdot
.01965 .03141 Mdot
.01572 .02749 Mdot
.08631 .10983 Mdot
.11376 .13728 Mdot
.18042 .20394 Mdot
.27845 .32158 Mdot
.1961 .22355 Mdot
.19218 .21571 Mdot
.21963 .25884 Mdot
.20002 .23924 Mdot
.09807 .11768 Mdot
.08631 .10199 Mdot
.0667 .08239 Mdot
.07062 .08631 Mdot
.07454 .09807 Mdot
.10199 .11768 Mdot
.11768 .12944 Mdot
.1216 .12552 Mdot
.1412 .15297 Mdot
.17257 .18826 Mdot
.1961 .21963 Mdot
.21179 .23531 Mdot
.21963 .251 Mdot
.23139 .26276 Mdot
.22355 .25492 Mdot
.22747 .26276 Mdot
.23139 .26276 Mdot
.23924 .27453 Mdot
.24316 .27061 Mdot
.25492 .27453 Mdot
.25492 .27453 Mdot
.251 .26668 Mdot
.24708 .26276 Mdot
.23531 .25884 Mdot
.23139 .25492 Mdot
.23531 .26276 Mdot
.23531 .26276 Mdot
.23924 .26276 Mdot
.24708 .27453 Mdot
.22355 .25492 Mdot
.23139 .26276 Mdot
.23139 .25884 Mdot
.24316 .25884 Mdot
.23924 .25884 Mdot
.23924 .25884 Mdot
.24708 .26668 Mdot
.24316 .26668 Mdot
.23139 .251 Mdot
.22747 .251 Mdot
.23139 .25884 Mdot
.24316 .27845 Mdot
.23531 .27061 Mdot
.23531 .27453 Mdot
.22747 .26276 Mdot
.23139 .26668 Mdot
.23531 .27061 Mdot
.23139 .27061 Mdot
.23531 .27061 Mdot
.251 .28237 Mdot
.25884 .28237 Mdot
.26668 .28629 Mdot
.25884 .27845 Mdot
.24316 .26668 Mdot
.23139 .25492 Mdot
.22355 .24316 Mdot
.21571 .23924 Mdot
.22355 .251 Mdot
.22747 .26276 Mdot
.22355 .251 Mdot
.23531 .26668 Mdot
.23139 .26276 Mdot
.23139 .26276 Mdot
.22355 .251 Mdot
.20787 .23531 Mdot
.18042 .20787 Mdot
.18042 .20002 Mdot
.18042 .20394 Mdot
.1765 .20002 Mdot
.18434 .20787 Mdot
.19218 .21963 Mdot
.18434 .20787 Mdot
.1765 .1961 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.1765 .20002 Mdot
.1765 .20002 Mdot
.17257 .1961 Mdot
.18042 .21179 Mdot
.18434 .21179 Mdot
.19218 .21963 Mdot
.20002 .23139 Mdot
.20787 .23924 Mdot
.20787 .23531 Mdot
.21963 .25492 Mdot
.21963 .26276 Mdot
.21963 .25492 Mdot
.20394 .23139 Mdot
.20394 .23531 Mdot
.19218 .21963 Mdot
.1961 .21963 Mdot
.18826 .21571 Mdot
.20002 .23139 Mdot
.20002 .22747 Mdot
.1961 .22747 Mdot
.18042 .20787 Mdot
.18434 .21179 Mdot
.18434 .21571 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.20002 .22355 Mdot
.20002 .22747 Mdot
.18826 .21179 Mdot
.18434 .20787 Mdot
.16865 .18434 Mdot
.18434 .20787 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.18434 .20787 Mdot
.1765 .1961 Mdot
.17257 .18434 Mdot
.17257 .19218 Mdot
.16081 .18042 Mdot
.15689 .1765 Mdot
.15297 .16865 Mdot
.15689 .17257 Mdot
.14905 .16865 Mdot
.14905 .16473 Mdot
.1412 .15297 Mdot
.14513 .16081 Mdot
.14513 .16473 Mdot
.13728 .16081 Mdot
.12552 .14905 Mdot
.1216 .15297 Mdot
.11768 .14513 Mdot
.11768 .1412 Mdot
.11768 .14513 Mdot
.1216 .14905 Mdot
.1216 .1412 Mdot
.12944 .1412 Mdot
.11768 .12552 Mdot
.02749 .03925 Mdot
.03925 .05494 Mdot
.03533 .04709 Mdot
.03141 .03925 Mdot
.03533 .04317 Mdot
.03141 .03925 Mdot
.04317 .05886 Mdot
.05494 .0667 Mdot
.07846 .09807 Mdot
.09023 .11376 Mdot
.09415 .11376 Mdot
.09807 .12552 Mdot
.08631 .10983 Mdot
.05494 .07454 Mdot
.03925 .05494 Mdot
.02357 .03925 Mdot
.02749 .03925 Mdot
.01572 .02357 Mdot
.01965 .03141 Mdot
.00788 .01965 Mdot
.0118 .02357 Mdot
.02749 .04317 Mdot
.04317 .06278 Mdot
.04709 .06278 Mdot
.05886 .07454 Mdot
.15297 .17257 Mdot
.15689 .1765 Mdot
.16473 .18042 Mdot
.24316 .27845 Mdot
.23924 .27845 Mdot
.15297 .18042 Mdot
.10983 .13336 Mdot
.0667 .07846 Mdot
.05886 .06278 Mdot
.06278 .06278 Mdot
.07062 .07062 Mdot
.08239 .08631 Mdot
.09807 .09807 Mdot
.1412 .15297 Mdot
.17257 .18826 Mdot
.20394 .23139 Mdot
.21179 .23924 Mdot
.23139 .26276 Mdot
.23139 .26668 Mdot
.22747 .26668 Mdot
.22355 .25884 Mdot
.23531 .26668 Mdot
.23531 .27061 Mdot
.24708 .27453 Mdot
.25492 .27453 Mdot
.26276 .28237 Mdot
.25492 .27845 Mdot
.24316 .26276 Mdot
.24316 .26668 Mdot
.23924 .25884 Mdot
.24316 .26276 Mdot
.25492 .27845 Mdot
.25492 .27845 Mdot
.251 .27845 Mdot
.24316 .27453 Mdot
.23924 .27061 Mdot
.23924 .27061 Mdot
.24316 .27061 Mdot
.25492 .27453 Mdot
.251 .26668 Mdot
.251 .27061 Mdot
.23924 .25884 Mdot
.23924 .26276 Mdot
.23139 .25492 Mdot
.24316 .27453 Mdot
.23924 .27453 Mdot
.24316 .28237 Mdot
.23531 .27453 Mdot
.24316 .27845 Mdot
.23924 .27845 Mdot
.23924 .27453 Mdot
.24708 .28629 Mdot
.24708 .27845 Mdot
.26276 .29806 Mdot
.26668 .28629 Mdot
.26276 .28237 Mdot
.26668 .29021 Mdot
.26276 .29021 Mdot
.26276 .29021 Mdot
.24316 .26668 Mdot
.22747 .251 Mdot
.22355 .251 Mdot
.21571 .24708 Mdot
.21571 .24708 Mdot
.22747 .25884 Mdot
.23139 .25884 Mdot
.23924 .26668 Mdot
.24708 .27845 Mdot
.22747 .25884 Mdot
.20002 .23139 Mdot
.19218 .22355 Mdot
.18434 .21571 Mdot
.18042 .21571 Mdot
.18826 .22355 Mdot
.19218 .22355 Mdot
.19218 .22355 Mdot
.18434 .21571 Mdot
.18042 .20394 Mdot
.18042 .20394 Mdot
.18042 .20787 Mdot
.1765 .20002 Mdot
.1765 .19218 Mdot
.1765 .19218 Mdot
.1765 .1961 Mdot
.16865 .18826 Mdot
.17257 .20394 Mdot
.1765 .21571 Mdot
.1961 .23139 Mdot
.19218 .23531 Mdot
.1961 .251 Mdot
.21179 .25884 Mdot
.20394 .24316 Mdot
.20394 .24316 Mdot
.20394 .24316 Mdot
.20002 .23924 Mdot
.1961 .22355 Mdot
.18826 .21571 Mdot
.18826 .21571 Mdot
.20002 .23139 Mdot
.19218 .22355 Mdot
.18434 .21571 Mdot
.18826 .21179 Mdot
.1765 .20002 Mdot
.18042 .20002 Mdot
.18826 .21179 Mdot
.18826 .21571 Mdot
.16865 .1961 Mdot
.1765 .1961 Mdot
.18434 .20787 Mdot
.1765 .19218 Mdot
.17257 .18826 Mdot
.16865 .18826 Mdot
.17257 .1961 Mdot
.18042 .20787 Mdot
.1765 .20394 Mdot
.17257 .1961 Mdot
.16473 .18434 Mdot
.16473 .18434 Mdot
.15689 .1765 Mdot
.15689 .1765 Mdot
.15297 .17257 Mdot
.15297 .17257 Mdot
.13728 .15297 Mdot
.1412 .16081 Mdot
.13728 .15689 Mdot
.13728 .16473 Mdot
.12944 .16081 Mdot
.12944 .15689 Mdot
.1216 .14905 Mdot
.1216 .15297 Mdot
.1216 .15297 Mdot
.12944 .16081 Mdot
.13728 .16473 Mdot
.1412 .16081 Mdot
.12944 .1412 Mdot
.03533 .04709 Mdot
.03141 .04317 Mdot
.04709 .05886 Mdot
.03141 .04317 Mdot
.01965 .02749 Mdot
.01572 .01965 Mdot
.01965 .02749 Mdot
.03533 .04709 Mdot
.04317 .05494 Mdot
.06278 .07454 Mdot
.07846 .09415 Mdot
.08239 .10199 Mdot
.07846 .09807 Mdot
.05886 .07454 Mdot
.04317 .05494 Mdot
.03141 .04317 Mdot
.02357 .03141 Mdot
.01965 .02357 Mdot
.01572 .01965 Mdot
.01572 .02357 Mdot
.01572 .02357 Mdot
.03533 .04709 Mdot
.03141 .04709 Mdot
.03141 .04709 Mdot
.03141 .03925 Mdot
.03141 .04317 Mdot
.05102 .06278 Mdot
.0667 .07454 Mdot
.1412 .16865 Mdot
.18826 .22747 Mdot
.14905 .18434 Mdot
.13336 .16081 Mdot
.1216 .13728 Mdot
.11376 .1216 Mdot
.09807 .10199 Mdot
.08239 .08239 Mdot
.08239 .08631 Mdot
.08631 .08631 Mdot
.12552 .13728 Mdot
.15297 .16865 Mdot
.18434 .20787 Mdot
.20002 .22355 Mdot
.22355 .25492 Mdot
.22747 .26276 Mdot
.22355 .25884 Mdot
.21963 .25492 Mdot
.22355 .251 Mdot
.22747 .25884 Mdot
.23531 .26276 Mdot
.24316 .27453 Mdot
.24316 .27061 Mdot
.251 .28629 Mdot
.24316 .27453 Mdot
.23924 .26276 Mdot
.251 .27453 Mdot
.25492 .28237 Mdot
.25492 .28629 Mdot
.26276 .29413 Mdot
.251 .28237 Mdot
.25884 .29021 Mdot
.26276 .29806 Mdot
.25492 .29021 Mdot
.25492 .29021 Mdot
.251 .27845 Mdot
.25492 .27453 Mdot
.26276 .28237 Mdot
.24708 .26276 Mdot
.24708 .27061 Mdot
.24316 .26668 Mdot
.24316 .27061 Mdot
.23924 .27061 Mdot
.251 .28629 Mdot
.25492 .29413 Mdot
.251 .29021 Mdot
.24316 .28237 Mdot
.24708 .29413 Mdot
.251 .29413 Mdot
.24316 .28237 Mdot
.24316 .27845 Mdot
.25492 .28237 Mdot
.25884 .29021 Mdot
.26276 .28237 Mdot
.27845 .29806 Mdot
.26668 .28629 Mdot
.26668 .29413 Mdot
.25492 .28237 Mdot
.25884 .28629 Mdot
.23139 .26276 Mdot
.21963 .251 Mdot
.21963 .251 Mdot
.21963 .251 Mdot
.23531 .26276 Mdot
.24708 .27845 Mdot
.24708 .27845 Mdot
.23139 .26276 Mdot
.21571 .24316 Mdot
.21571 .24316 Mdot
.21571 .24316 Mdot
.21179 .24316 Mdot
.1961 .23139 Mdot
.1961 .23139 Mdot
.18826 .22747 Mdot
.18826 .21963 Mdot
.18826 .21571 Mdot
.18826 .21571 Mdot
.1765 .20394 Mdot
.18042 .20394 Mdot
.18434 .20787 Mdot
.18826 .20787 Mdot
.18042 .19218 Mdot
.18042 .20002 Mdot
.1765 .20394 Mdot
.18434 .21571 Mdot
.20002 .24316 Mdot
.19218 .23924 Mdot
.20002 .24708 Mdot
.20787 .25884 Mdot
.20002 .251 Mdot
.20002 .24708 Mdot
.1961 .23531 Mdot
.18042 .21963 Mdot
.1765 .21571 Mdot
.18042 .21571 Mdot
.19218 .22747 Mdot
.1961 .23139 Mdot
.19218 .22355 Mdot
.1961 .21963 Mdot
.18042 .20002 Mdot
.18434 .20002 Mdot
.19218 .20002 Mdot
.18826 .1961 Mdot
.19218 .20394 Mdot
.18826 .20394 Mdot
.18434 .20002 Mdot
.18826 .20787 Mdot
.1765 .19218 Mdot
.17257 .1961 Mdot
.16473 .1961 Mdot
.16473 .19218 Mdot
.16865 .20002 Mdot
.1765 .20394 Mdot
.1765 .20002 Mdot
.16865 .1961 Mdot
.16081 .18434 Mdot
.16865 .18826 Mdot
.16081 .18042 Mdot
.15689 .17257 Mdot
.14905 .16473 Mdot
.15297 .17257 Mdot
.1412 .16081 Mdot
.13728 .16081 Mdot
.13728 .16865 Mdot
.14905 .17257 Mdot
.13728 .15689 Mdot
.12944 .14905 Mdot
.1216 .14513 Mdot
.1216 .14905 Mdot
.1216 .14905 Mdot
.12552 .15297 Mdot
.11768 .13728 Mdot
.07846 .09807 Mdot
.05886 .07454 Mdot
.04709 .05494 Mdot
.03141 .03925 Mdot
.01965 .03141 Mdot
.01965 .02749 Mdot
.0118 .01965 Mdot
.03141 .04317 Mdot
.06278 .07846 Mdot
.0667 .08631 Mdot
.05886 .07846 Mdot
.0667 .07846 Mdot
.0667 .07846 Mdot
.05494 .0667 Mdot
.04317 .05494 Mdot
.04317 .05494 Mdot
.02749 .03533 Mdot
.02749 .03533 Mdot
.01965 .02357 Mdot
.02357 .02357 Mdot
.03141 .03533 Mdot
.04317 .04317 Mdot
.03141 .03925 Mdot
.01572 .01965 Mdot
.02357 .02357 Mdot
.02749 .03141 Mdot
.02749 .03141 Mdot
.03925 .04317 Mdot
.04317 .05886 Mdot
.07062 .09023 Mdot
.07454 .09415 Mdot
.07846 .09415 Mdot
.09023 .10199 Mdot
.09023 .10591 Mdot
.10199 .11768 Mdot
.13336 .14905 Mdot
.13728 .14905 Mdot
.1216 .13728 Mdot
.1216 .1412 Mdot
.13728 .16081 Mdot
.16473 .18826 Mdot
.18434 .21571 Mdot
.20394 .23924 Mdot
.21963 .25492 Mdot
.21963 .25884 Mdot
.21571 .251 Mdot
.22747 .26276 Mdot
.22355 .25884 Mdot
.21963 .24708 Mdot
.22355 .251 Mdot
.23924 .27453 Mdot
.24316 .29021 Mdot
.24708 .29413 Mdot
.251 .28629 Mdot
.26668 .30198 Mdot
.25492 .29021 Mdot
.25492 .28629 Mdot
.25884 .29413 Mdot
.26668 .29806 Mdot
.27845 .3059 Mdot
.26668 .29806 Mdot
.251 .28629 Mdot
.25492 .28629 Mdot
.251 .28629 Mdot
.25884 .29021 Mdot
.26276 .29021 Mdot
.251 .27061 Mdot
.251 .27453 Mdot
.24708 .27453 Mdot
.24708 .27845 Mdot
.25492 .28629 Mdot
.25492 .29021 Mdot
.25884 .29413 Mdot
.26276 .30198 Mdot
.25492 .29806 Mdot
.251 .29413 Mdot
.251 .29806 Mdot
.26276 .30198 Mdot
.25884 .29806 Mdot
.25492 .29413 Mdot
.25492 .29413 Mdot
.26276 .29413 Mdot
.27453 .29413 Mdot
.27453 .29413 Mdot
.27453 .29413 Mdot
.26668 .29021 Mdot
.25492 .27453 Mdot
.26276 .28629 Mdot
.24316 .26668 Mdot
.23924 .26668 Mdot
.22747 .25884 Mdot
.22747 .251 Mdot
.24708 .26668 Mdot
.24316 .26276 Mdot
.251 .27061 Mdot
.251 .27453 Mdot
.25884 .27845 Mdot
.23924 .26276 Mdot
.22355 .24316 Mdot
.20787 .23139 Mdot
.19218 .22355 Mdot
.20787 .24316 Mdot
.20787 .23924 Mdot
.1961 .22747 Mdot
.19218 .21963 Mdot
.18826 .21571 Mdot
.1961 .22355 Mdot
.18826 .21571 Mdot
.19218 .20787 Mdot
.18826 .20394 Mdot
.18826 .21179 Mdot
.1765 .1961 Mdot
.18434 .21179 Mdot
.18042 .20787 Mdot
.18042 .21571 Mdot
.18042 .21963 Mdot
.18434 .22747 Mdot
.18434 .23139 Mdot
.18826 .23139 Mdot
.20394 .24708 Mdot
.20002 .23924 Mdot
.20002 .23531 Mdot
.19218 .22355 Mdot
.18434 .21571 Mdot
.18042 .21571 Mdot
.20002 .23139 Mdot
.19218 .21571 Mdot
.18042 .20002 Mdot
.16865 .18434 Mdot
.18826 .20394 Mdot
.18042 .1961 Mdot
.18826 .1961 Mdot
.18434 .19218 Mdot
.1765 .18826 Mdot
.1765 .19218 Mdot
.18434 .20002 Mdot
.1765 .1961 Mdot
.1765 .19218 Mdot
.16865 .18042 Mdot
.1765 .1961 Mdot
.16865 .1961 Mdot
.17257 .1961 Mdot
.16865 .19218 Mdot
.16473 .18826 Mdot
.16081 .18434 Mdot
.16473 .18826 Mdot
.16473 .18042 Mdot
.15297 .16865 Mdot
.14905 .16473 Mdot
.14513 .16081 Mdot
.1412 .15689 Mdot
.13728 .14905 Mdot
.1412 .15689 Mdot
.13728 .15297 Mdot
.12552 .1412 Mdot
.1216 .14905 Mdot
.1216 .14513 Mdot
.11768 .14513 Mdot
.11768 .1412 Mdot
.10591 .13336 Mdot
.09023 .11376 Mdot
.08631 .11376 Mdot
.08239 .10591 Mdot
.0667 .07846 Mdot
.04709 .05886 Mdot
.04317 .05886 Mdot
.03533 .04317 Mdot
.05494 .07062 Mdot
.0667 .08239 Mdot
.05494 .0667 Mdot
.04317 .05494 Mdot
.05102 .06278 Mdot
.06278 .07846 Mdot
.0667 .07846 Mdot
.06278 .07062 Mdot
.05886 .06278 Mdot
.04709 .05102 Mdot
.04317 .03925 Mdot
.04709 .04317 Mdot
.03925 .03533 Mdot
.03925 .03533 Mdot
.03533 .03141 Mdot
.02357 .01965 Mdot
.01572 .01572 Mdot
.0118 .00788 Mdot
.01572 .01572 Mdot
.02749 .03533 Mdot
.04709 .05886 Mdot
.05494 .0667 Mdot
.04709 .05886 Mdot
.03925 .05494 Mdot
.05102 .06278 Mdot
.05102 .06278 Mdot
.03925 .05102 Mdot
.05494 .07062 Mdot
.09023 .11376 Mdot
.1412 .1765 Mdot
.15689 .1961 Mdot
.16865 .21179 Mdot
.17257 .21179 Mdot
.18434 .22355 Mdot
.18826 .23139 Mdot
.19218 .23531 Mdot
.19218 .23139 Mdot
.20394 .24316 Mdot
.20394 .24316 Mdot
.20002 .23531 Mdot
.20787 .23924 Mdot
.21179 .24316 Mdot
.21571 .25492 Mdot
.22355 .26276 Mdot
.22355 .27453 Mdot
.22355 .27453 Mdot
.23531 .28629 Mdot
.251 .29806 Mdot
.25884 .29413 Mdot
.26668 .30198 Mdot
.27061 .30198 Mdot
.27453 .30198 Mdot
.27845 .30198 Mdot
.27061 .29806 Mdot
.27061 .30198 Mdot
.27061 .3059 Mdot
.27453 .30982 Mdot
.27453 .30982 Mdot
.27845 .3059 Mdot
.27453 .30198 Mdot
.27061 .29806 Mdot
.25492 .28629 Mdot
.24708 .28237 Mdot
.24708 .28237 Mdot
.25884 .30198 Mdot
.25884 .30198 Mdot
.26668 .31374 Mdot
.25884 .3059 Mdot
.24708 .29413 Mdot
.24708 .29806 Mdot
.24708 .29413 Mdot
.251 .29413 Mdot
.25884 .3059 Mdot
.251 .30198 Mdot
.25492 .29806 Mdot
.25492 .29021 Mdot
.26668 .29021 Mdot
.25884 .27845 Mdot
.27061 .29021 Mdot
.26668 .28629 Mdot
.26668 .27453 Mdot
.26668 .28237 Mdot
.26276 .28237 Mdot
.24708 .27453 Mdot
.24316 .27453 Mdot
.24708 .27061 Mdot
.24708 .26276 Mdot
.24708 .26668 Mdot
.27061 .28629 Mdot
.27061 .29021 Mdot
.26276 .28237 Mdot
.25492 .27061 Mdot
.24316 .26668 Mdot
.22747 .25884 Mdot
.22747 .25492 Mdot
.21571 .251 Mdot
.20787 .23531 Mdot
.20394 .23531 Mdot
.1961 .22355 Mdot
.19218 .21179 Mdot
.20002 .21963 Mdot
.19218 .21179 Mdot
.18434 .20787 Mdot
.18042 .20787 Mdot
.1765 .20002 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.18826 .21571 Mdot
.18042 .21963 Mdot
.18434 .21963 Mdot
.18826 .22747 Mdot
.18042 .22747 Mdot
.1961 .24316 Mdot
.21179 .25492 Mdot
.21571 .251 Mdot
.21571 .251 Mdot
.20394 .23531 Mdot
.19218 .21963 Mdot
.19218 .21571 Mdot
.1961 .21963 Mdot
.19218 .21571 Mdot
.18434 .20394 Mdot
.1765 .1961 Mdot
.1765 .19218 Mdot
.18042 .20002 Mdot
.18042 .1961 Mdot
.18042 .19218 Mdot
.1765 .18042 Mdot
.18042 .19218 Mdot
.18042 .20002 Mdot
.18042 .19218 Mdot
.1765 .18826 Mdot
.18826 .21179 Mdot
.16865 .1961 Mdot
.15689 .18434 Mdot
.16865 .1961 Mdot
.16473 .18434 Mdot
.16865 .18042 Mdot
.16865 .18434 Mdot
.15297 .16865 Mdot
.15297 .16865 Mdot
.14905 .16473 Mdot
.14905 .16081 Mdot
.1412 .15297 Mdot
.12552 .14513 Mdot
.12552 .1412 Mdot
.12552 .14905 Mdot
.11768 .14513 Mdot
.11768 .1412 Mdot
.11768 .14513 Mdot
.10199 .12552 Mdot
.10983 .13728 Mdot
.10591 .12552 Mdot
.1412 .17257 Mdot
.13728 .16473 Mdot
.12944 .15297 Mdot
.11768 .1412 Mdot
.10591 .12944 Mdot
.08239 .10199 Mdot
.0667 .07846 Mdot
.07454 .08631 Mdot
.0667 .07454 Mdot
.04317 .04317 Mdot
.04317 .05102 Mdot
.05494 .0667 Mdot
.05886 .07846 Mdot
.06278 .07846 Mdot
.0667 .07454 Mdot
.05494 .06278 Mdot
.04317 .05494 Mdot
.05102 .05102 Mdot
.05102 .04709 Mdot
.05102 .05102 Mdot
.06278 .05886 Mdot
.05886 .05886 Mdot
.03925 .04317 Mdot
.01965 .01965 Mdot
.01572 .01572 Mdot
.01965 .02749 Mdot
.05494 .0667 Mdot
.07062 .08631 Mdot
.0667 .07846 Mdot
.05494 .07062 Mdot
.05102 .0667 Mdot
.04709 .05886 Mdot
.04709 .05886 Mdot
.03141 .04317 Mdot
.03141 .04317 Mdot
.03925 .05102 Mdot
.05886 .07846 Mdot
.10199 .12944 Mdot
.1765 .21179 Mdot
.20787 .24708 Mdot
.23139 .27061 Mdot
.22747 .27061 Mdot
.21571 .24708 Mdot
.21179 .24316 Mdot
.20787 .23924 Mdot
.20002 .23139 Mdot
.20002 .22747 Mdot
.18434 .21571 Mdot
.18434 .21571 Mdot
.18042 .21179 Mdot
.19218 .22747 Mdot
.20002 .24316 Mdot
.21179 .25884 Mdot
.22747 .27453 Mdot
.23531 .28237 Mdot
.24708 .28629 Mdot
.26276 .29806 Mdot
.27061 .29806 Mdot
.26668 .29806 Mdot
.27061 .30198 Mdot
.27845 .30982 Mdot
.28237 .32158 Mdot
.27845 .31766 Mdot
.28237 .32943 Mdot
.27453 .31374 Mdot
.27061 .30982 Mdot
.27061 .30982 Mdot
.27453 .30982 Mdot
.26276 .29806 Mdot
.26276 .30198 Mdot
.25492 .29021 Mdot
.25884 .30198 Mdot
.25884 .29806 Mdot
.27061 .30982 Mdot
.25492 .29806 Mdot
.24708 .29021 Mdot
.251 .29806 Mdot
.24316 .29021 Mdot
.24316 .30198 Mdot
.24708 .30198 Mdot
.251 .3059 Mdot
.251 .29806 Mdot
.251 .29021 Mdot
.25884 .29413 Mdot
.26276 .28237 Mdot
.27061 .29021 Mdot
.26668 .27845 Mdot
.26668 .27845 Mdot
.25884 .27845 Mdot
.25884 .27845 Mdot
.251 .27845 Mdot
.25492 .27845 Mdot
.251 .27845 Mdot
.23924 .26276 Mdot
.25884 .27845 Mdot
.26276 .28237 Mdot
.25884 .27453 Mdot
.26276 .28237 Mdot
.26276 .27845 Mdot
.251 .26668 Mdot
.26276 .27845 Mdot
.25884 .28629 Mdot
.23531 .27061 Mdot
.22747 .25884 Mdot
.21963 .24708 Mdot
.21179 .23531 Mdot
.20394 .22355 Mdot
.18826 .21179 Mdot
.18042 .20002 Mdot
.19218 .21179 Mdot
.19218 .20787 Mdot
.18042 .1961 Mdot
.18434 .20002 Mdot
.18042 .20002 Mdot
.19218 .21963 Mdot
.18826 .21963 Mdot
.18826 .22747 Mdot
.19218 .23531 Mdot
.18434 .22747 Mdot
.18826 .23139 Mdot
.19218 .23924 Mdot
.20394 .251 Mdot
.21571 .251 Mdot
.20787 .23924 Mdot
.19218 .21963 Mdot
.18042 .20394 Mdot
.18042 .20394 Mdot
.19218 .21571 Mdot
.18434 .20787 Mdot
.18434 .20394 Mdot
.18042 .20787 Mdot
.1765 .20002 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.17257 .18042 Mdot
.1765 .18434 Mdot
.17257 .18042 Mdot
.18042 .19218 Mdot
.18042 .1961 Mdot
.1765 .20002 Mdot
.17257 .1961 Mdot
.16473 .18434 Mdot
.16865 .18826 Mdot
.17257 .1961 Mdot
.16865 .18434 Mdot
.16865 .18042 Mdot
.16081 .1765 Mdot
.15297 .17257 Mdot
.1412 .15297 Mdot
.13336 .14513 Mdot
.13336 .15297 Mdot
.12552 .14905 Mdot
.12944 .15689 Mdot
.1216 .14513 Mdot
.1216 .14905 Mdot
.10983 .13728 Mdot
.10591 .13336 Mdot
.10591 .13728 Mdot
.11376 .13728 Mdot
.10591 .1216 Mdot
.13728 .15689 Mdot
.14905 .1765 Mdot
.1412 .16865 Mdot
.13728 .16473 Mdot
.1412 .16473 Mdot
.13728 .16081 Mdot
.12552 .14905 Mdot
.12552 .14513 Mdot
.08239 .09415 Mdot
.06278 .07062 Mdot
.05494 .06278 Mdot
.05886 .07062 Mdot
.0667 .08631 Mdot
.0667 .08631 Mdot
.0667 .08239 Mdot
.05494 .07062 Mdot
.04317 .05494 Mdot
.03925 .04709 Mdot
.05494 .0667 Mdot
.05494 .0667 Mdot
.0667 .07454 Mdot
.05886 .0667 Mdot
.05886 .0667 Mdot
.05102 .05886 Mdot
.02357 .02749 Mdot
.02749 .03141 Mdot
.06278 .07846 Mdot
.08239 .09807 Mdot
.07062 .08631 Mdot
.04709 .05494 Mdot
.03141 .03925 Mdot
.02749 .03925 Mdot
.03141 .03925 Mdot
.03533 .04317 Mdot
.03533 .04709 Mdot
.03533 .04317 Mdot
.03141 .03925 Mdot
.05886 .07846 Mdot
.10199 .11768 Mdot
.13728 .15297 Mdot
.15689 .17257 Mdot
.19218 .21571 Mdot
.22747 .25492 Mdot
.23531 .26668 Mdot
.22747 .26276 Mdot
.21963 .25492 Mdot
.20787 .24316 Mdot
.18826 .21963 Mdot
.17257 .20002 Mdot
.15297 .18434 Mdot
.1412 .16865 Mdot
.13728 .16865 Mdot
.1765 .21571 Mdot
.20394 .24708 Mdot
.22355 .27061 Mdot
.24316 .28629 Mdot
.26276 .30198 Mdot
.27061 .30198 Mdot
.26668 .29806 Mdot
.26276 .29806 Mdot
.26276 .29413 Mdot
.25492 .29021 Mdot
.26668 .30198 Mdot
.27453 .31374 Mdot
.27845 .31766 Mdot
.27453 .31374 Mdot
.29021 .33335 Mdot
.28629 .32943 Mdot
.27845 .31374 Mdot
.27061 .30198 Mdot
.27061 .30198 Mdot
.26668 .29413 Mdot
.26668 .29413 Mdot
.27453 .31374 Mdot
.26668 .30198 Mdot
.27061 .30982 Mdot
.27061 .30982 Mdot
.25884 .3059 Mdot
.251 .30198 Mdot
.26276 .3059 Mdot
.26668 .30982 Mdot
.27061 .30982 Mdot
.25884 .29021 Mdot
.27061 .29021 Mdot
.26276 .27845 Mdot
.26668 .28237 Mdot
.27061 .28237 Mdot
.26276 .27845 Mdot
.26276 .28237 Mdot
.25492 .28237 Mdot
.25492 .28629 Mdot
.26276 .3059 Mdot
.27061 .30982 Mdot
.26668 .29806 Mdot
.27061 .29806 Mdot
.27061 .29413 Mdot
.27453 .29021 Mdot
.251 .26668 Mdot
.24708 .26276 Mdot
.24316 .26276 Mdot
.25492 .28237 Mdot
.24316 .27453 Mdot
.23924 .27453 Mdot
.24316 .27845 Mdot
.23924 .27453 Mdot
.22355 .24708 Mdot
.20787 .23139 Mdot
.18434 .20787 Mdot
.18826 .20787 Mdot
.18042 .1961 Mdot
.18042 .20002 Mdot
.18826 .20002 Mdot
.18826 .20002 Mdot
.18434 .20002 Mdot
.18826 .21571 Mdot
.1961 .22747 Mdot
.18042 .21571 Mdot
.18434 .22747 Mdot
.18826 .23139 Mdot
.18826 .23139 Mdot
.18042 .22355 Mdot
.18434 .22747 Mdot
.20787 .24708 Mdot
.21179 .24708 Mdot
.20787 .23924 Mdot
.20002 .22355 Mdot
.19218 .21571 Mdot
.19218 .21571 Mdot
.19218 .21571 Mdot
.20002 .22355 Mdot
.1961 .21963 Mdot
.18826 .21179 Mdot
.17257 .19218 Mdot
.16473 .18434 Mdot
.16473 .18042 Mdot
.15689 .17257 Mdot
.16473 .18434 Mdot
.1765 .1961 Mdot
.1765 .20002 Mdot
.17257 .20002 Mdot
.17257 .18826 Mdot
.16865 .18826 Mdot
.17257 .20002 Mdot
.17257 .20394 Mdot
.1765 .20394 Mdot
.15689 .16865 Mdot
.16081 .16473 Mdot
.15689 .16081 Mdot
.1412 .14905 Mdot
.14513 .15689 Mdot
.13336 .14905 Mdot
.1216 .1412 Mdot
.13728 .16081 Mdot
.12944 .15297 Mdot
.12552 .14905 Mdot
.11768 .14513 Mdot
.1216 .1412 Mdot
.11768 .13728 Mdot
.11768 .12944 Mdot
.10591 .1216 Mdot
.16081 .18434 Mdot
.16865 .18826 Mdot
.15297 .17257 Mdot
.1412 .16473 Mdot
.14513 .16473 Mdot
.15689 .18042 Mdot
.15297 .18042 Mdot
.1412 .16473 Mdot
.13728 .15689 Mdot
.11768 .13336 Mdot
.09415 .10983 Mdot
.07846 .09807 Mdot
.08631 .10199 Mdot
.07062 .09023 Mdot
.05102 .07062 Mdot
.04709 .06278 Mdot
.04317 .05886 Mdot
.04709 .06278 Mdot
.05886 .07846 Mdot
.06278 .08239 Mdot
.05886 .07062 Mdot
.05494 .06278 Mdot
.05102 .05494 Mdot
.05886 .06278 Mdot
.05102 .05494 Mdot
.06278 .0667 Mdot
.08239 .09415 Mdot
.08631 .10199 Mdot
.07062 .08631 Mdot
.06278 .07846 Mdot
.04709 .05886 Mdot
.02357 .03533 Mdot
.02749 .03925 Mdot
.03141 .03925 Mdot
.03533 .03925 Mdot
.03533 .04709 Mdot
.03533 .04317 Mdot
.03925 .04709 Mdot
.06278 .07846 Mdot
.07846 .09023 Mdot
.09807 .10983 Mdot
.09807 .10591 Mdot
.18434 .21179 Mdot
.24708 .28629 Mdot
.26276 .3059 Mdot
.25884 .30198 Mdot
.251 .29021 Mdot
.20787 .24316 Mdot
.1765 .20787 Mdot
.1412 .16865 Mdot
.10983 .12944 Mdot
.09023 .10199 Mdot
.10199 .1216 Mdot
.14513 .1765 Mdot
.18042 .21179 Mdot
.21179 .25492 Mdot
.24316 .29021 Mdot
.26668 .3059 Mdot
.26276 .29806 Mdot
.251 .28629 Mdot
.25492 .28629 Mdot
.251 .28629 Mdot
.25884 .29021 Mdot
.26668 .29021 Mdot
.27453 .30198 Mdot
.28237 .31374 Mdot
.28237 .32158 Mdot
.27845 .32158 Mdot
.27453 .31766 Mdot
.26668 .30982 Mdot
.27453 .31766 Mdot
.27453 .31374 Mdot
.28237 .31374 Mdot
.27453 .3059 Mdot
.28237 .31374 Mdot
.27845 .30982 Mdot
.27061 .30198 Mdot
.26668 .3059 Mdot
.26668 .3059 Mdot
.26276 .3059 Mdot
.25884 .29806 Mdot
.25884 .29806 Mdot
.26276 .29413 Mdot
.27845 .30198 Mdot
.27453 .29806 Mdot
.27453 .29413 Mdot
.27453 .29021 Mdot
.27845 .29413 Mdot
.28237 .30198 Mdot
.28237 .3059 Mdot
.27845 .30982 Mdot
.27061 .3059 Mdot
.27061 .3059 Mdot
.27453 .30982 Mdot
.27453 .30982 Mdot
.26668 .30198 Mdot
.27061 .29806 Mdot
.25492 .27453 Mdot
.24316 .25884 Mdot
.23924 .26276 Mdot
.23139 .25884 Mdot
.23924 .26668 Mdot
.23924 .26668 Mdot
.24708 .28237 Mdot
.23531 .26668 Mdot
.22747 .25492 Mdot
.23531 .26668 Mdot
.21963 .251 Mdot
.20787 .22747 Mdot
.18826 .20394 Mdot
.18434 .20394 Mdot
.1961 .21963 Mdot
.19218 .21571 Mdot
.18826 .21179 Mdot
.18826 .21179 Mdot
.20394 .23139 Mdot
.18434 .21963 Mdot
.18826 .22747 Mdot
.1961 .23924 Mdot
.1961 .24316 Mdot
.19218 .23924 Mdot
.18042 .21963 Mdot
.18826 .22747 Mdot
.1961 .23531 Mdot
.20787 .23531 Mdot
.21179 .23531 Mdot
.20787 .23139 Mdot
.18434 .20787 Mdot
.18042 .20002 Mdot
.18042 .20394 Mdot
.1961 .21963 Mdot
.1961 .21963 Mdot
.20002 .22355 Mdot
.18434 .20394 Mdot
.18042 .20394 Mdot
.1765 .1961 Mdot
.16865 .18826 Mdot
.17257 .20002 Mdot
.18042 .20394 Mdot
.18042 .20787 Mdot
.17257 .19218 Mdot
.16473 .18434 Mdot
.18042 .20394 Mdot
.17257 .1961 Mdot
.16865 .18434 Mdot
.17257 .18434 Mdot
.1765 .18434 Mdot
.16473 .17257 Mdot
.15297 .16473 Mdot
.14513 .15689 Mdot
.13728 .14905 Mdot
.12944 .14513 Mdot
.13336 .15297 Mdot
.12944 .1412 Mdot
.12552 .1412 Mdot
.11768 .13728 Mdot
.12552 .1412 Mdot
.12552 .1412 Mdot
.12944 .1412 Mdot
.11768 .12944 Mdot
.16473 .18042 Mdot
.16865 .18434 Mdot
.16473 .17257 Mdot
.15689 .16865 Mdot
.14905 .16081 Mdot
.14905 .16865 Mdot
.15297 .17257 Mdot
.15689 .18042 Mdot
.15297 .17257 Mdot
.14905 .1765 Mdot
.14513 .17257 Mdot
.13336 .16081 Mdot
.11768 .1412 Mdot
.08239 .10199 Mdot
.05886 .07454 Mdot
.05102 .06278 Mdot
.0667 .07454 Mdot
.05494 .05886 Mdot
.05494 .05102 Mdot
.06278 .05886 Mdot
.06278 .06278 Mdot
.02749 .01965 Mdot
.01965 .02357 Mdot
.02357 .02749 Mdot
.02749 .03141 Mdot
.05886 .0667 Mdot
.08239 .09415 Mdot
.09807 .1216 Mdot
.09023 .11376 Mdot
.0667 .09023 Mdot
.05102 .0667 Mdot
.03925 .05102 Mdot
.04317 .05102 Mdot
.03141 .03925 Mdot
.05102 .05886 Mdot
.05102 .06278 Mdot
.04709 .05494 Mdot
.03925 .04317 Mdot
.03925 .03925 Mdot
.05886 .05494 Mdot
.07062 .07062 Mdot
.07846 .07846 Mdot
.09807 .09807 Mdot
.1412 .15689 Mdot
.20002 .22355 Mdot
.23531 .26668 Mdot
.27453 .30982 Mdot
.20394 .23139 Mdot
.16081 .18434 Mdot
.12944 .15297 Mdot
.10591 .1216 Mdot
.09807 .10591 Mdot
.09023 .09807 Mdot
.09415 .11376 Mdot
.13728 .16081 Mdot
.1765 .21179 Mdot
.20394 .24708 Mdot
.23139 .27453 Mdot
.23531 .28237 Mdot
.24316 .28629 Mdot
.25492 .29021 Mdot
.251 .28629 Mdot
.251 .28237 Mdot
.25492 .28629 Mdot
.25884 .28237 Mdot
.26276 .29413 Mdot
.26276 .30198 Mdot
.25492 .30198 Mdot
.25884 .30982 Mdot
.25884 .31374 Mdot
.26668 .30982 Mdot
.26668 .31374 Mdot
.26668 .3059 Mdot
.27453 .30982 Mdot
.27845 .31374 Mdot
.27453 .3059 Mdot
.27061 .3059 Mdot
.25492 .29021 Mdot
.25492 .29021 Mdot
.25492 .29413 Mdot
.25492 .29806 Mdot
.251 .29413 Mdot
.25884 .29806 Mdot
.26668 .30198 Mdot
.27453 .29806 Mdot
.27453 .29413 Mdot
.27061 .28629 Mdot
.27845 .29413 Mdot
.27453 .29021 Mdot
.28237 .29413 Mdot
.27453 .29806 Mdot
.25492 .28629 Mdot
.26276 .29806 Mdot
.25884 .29806 Mdot
.26668 .3059 Mdot
.25884 .29413 Mdot
.25884 .28629 Mdot
.25884 .28629 Mdot
.24316 .25884 Mdot
.23139 .24708 Mdot
.22747 .24316 Mdot
.22355 .24316 Mdot
.23139 .25884 Mdot
.23531 .26276 Mdot
.22747 .25884 Mdot
.22747 .25884 Mdot
.22355 .25492 Mdot
.21963 .25492 Mdot
.21571 .24708 Mdot
.20002 .22355 Mdot
.1961 .22355 Mdot
.20394 .22747 Mdot
.18434 .21179 Mdot
.18042 .20787 Mdot
.1765 .20787 Mdot
.18434 .21963 Mdot
.18826 .21963 Mdot
.18826 .23139 Mdot
.18826 .23531 Mdot
.18434 .23139 Mdot
.18826 .23531 Mdot
.18826 .23531 Mdot
.18042 .22355 Mdot
.18826 .22747 Mdot
.19218 .23531 Mdot
.20394 .23924 Mdot
.19218 .21571 Mdot
.19218 .21571 Mdot
.18826 .21179 Mdot
.18434 .21179 Mdot
.18434 .21179 Mdot
.1961 .22355 Mdot
.21179 .23531 Mdot
.20002 .22747 Mdot
.19218 .21571 Mdot
.18434 .20787 Mdot
.17257 .1961 Mdot
.16081 .18826 Mdot
.15689 .18042 Mdot
.16865 .19218 Mdot
.16473 .18826 Mdot
.16865 .19218 Mdot
.16473 .1765 Mdot
.17257 .18434 Mdot
.1765 .18434 Mdot
.17257 .18434 Mdot
.16865 .18042 Mdot
.16081 .16473 Mdot
.14905 .15297 Mdot
.1412 .14905 Mdot
.13336 .14513 Mdot
.12944 .13728 Mdot
.12552 .13336 Mdot
.1216 .13336 Mdot
.12552 .13728 Mdot
.11376 .12552 Mdot
.1216 .13728 Mdot
.13336 .14513 Mdot
.12552 .13728 Mdot
.10983 .12944 Mdot
.1412 .17257 Mdot
.16473 .19218 Mdot
.18042 .1961 Mdot
.18434 .1961 Mdot
.18434 .18826 Mdot
.17257 .18042 Mdot
.18434 .19218 Mdot
.17257 .18042 Mdot
.16473 .16865 Mdot
.18042 .18826 Mdot
.18434 .1961 Mdot
.18826 .20394 Mdot
.15297 .17257 Mdot
.09807 .11376 Mdot
.09023 .09415 Mdot
.07846 .07062 Mdot
.07454 .0667 Mdot
.07062 .05886 Mdot
.05886 .04709 Mdot
.05102 .04317 Mdot
.03925 .03533 Mdot
.02357 .02357 Mdot
.01965 .01965 Mdot
.02357 .02749 Mdot
.01572 .01965 Mdot
.03925 .04709 Mdot
.09023 .11376 Mdot
.10983 .13336 Mdot
.09023 .10983 Mdot
.0667 .07846 Mdot
.05102 .05886 Mdot
.03925 .04709 Mdot
.04317 .05102 Mdot
.04317 .05102 Mdot
.05886 .07062 Mdot
.07062 .08239 Mdot
.05886 .06278 Mdot
.06278 .05886 Mdot
.05102 .04709 Mdot
.05886 .05102 Mdot
.09023 .08239 Mdot
.10199 .09415 Mdot
.08631 .08239 Mdot
.09415 .09415 Mdot
.10591 .10591 Mdot
.13336 .13728 Mdot
.16865 .18042 Mdot
.15689 .17257 Mdot
.1216 .13728 Mdot
.09415 .10983 Mdot
.05886 .06278 Mdot
.09807 .11376 Mdot
.1216 .14513 Mdot
.13728 .16473 Mdot
.14513 .1765 Mdot
.14905 .18434 Mdot
.16473 .20394 Mdot
.1765 .22355 Mdot
.1961 .24316 Mdot
.21179 .26276 Mdot
.23924 .28237 Mdot
.25884 .29806 Mdot
.26668 .3059 Mdot
.25884 .29413 Mdot
.25884 .29806 Mdot
.26668 .30982 Mdot
.26668 .31374 Mdot
.26668 .31766 Mdot
.27453 .32943 Mdot
.28629 .33727 Mdot
.28237 .32943 Mdot
.28237 .3255 Mdot
.28237 .3255 Mdot
.28237 .3255 Mdot
.27453 .31766 Mdot
.26668 .3059 Mdot
.26276 .3059 Mdot
.27061 .31374 Mdot
.26668 .31374 Mdot
.26668 .31374 Mdot
.25884 .3059 Mdot
.25884 .3059 Mdot
.25492 .29413 Mdot
.26276 .30198 Mdot
.27453 .30982 Mdot
.27845 .30982 Mdot
.28629 .3059 Mdot
.28629 .3059 Mdot
.29021 .3059 Mdot
.29806 .31374 Mdot
.29806 .32158 Mdot
.29021 .31374 Mdot
.27453 .3059 Mdot
.27845 .30982 Mdot
.26668 .30198 Mdot
.26276 .29806 Mdot
.27061 .3059 Mdot
.27061 .3059 Mdot
.25884 .28629 Mdot
.25884 .27845 Mdot
.251 .26668 Mdot
.23924 .26276 Mdot
.24708 .27453 Mdot
.251 .28629 Mdot
.251 .28629 Mdot
.24316 .27845 Mdot
.23531 .27453 Mdot
.22355 .26668 Mdot
.23924 .29021 Mdot
.21571 .25884 Mdot
.21963 .25884 Mdot
.20787 .24708 Mdot
.1961 .22747 Mdot
.1961 .22747 Mdot
.18826 .21963 Mdot
.18434 .21963 Mdot
.20002 .23139 Mdot
.19218 .23139 Mdot
.1961 .24316 Mdot
.1961 .23924 Mdot
.1961 .23531 Mdot
.1961 .23924 Mdot
.20002 .23531 Mdot
.21179 .24708 Mdot
.21571 .251 Mdot
.21963 .251 Mdot
.21179 .23924 Mdot
.20787 .23139 Mdot
.18826 .21179 Mdot
.19218 .21571 Mdot
.19218 .21963 Mdot
.20394 .22747 Mdot
.22355 .24316 Mdot
.21963 .24708 Mdot
.21571 .24316 Mdot
.20002 .22747 Mdot
.18042 .21179 Mdot
.16865 .20002 Mdot
.16865 .20002 Mdot
.16865 .20002 Mdot
.17257 .1961 Mdot
.18042 .20002 Mdot
.16865 .18826 Mdot
.17257 .18826 Mdot
.17257 .19218 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.15689 .1765 Mdot
.14513 .16081 Mdot
.15689 .17257 Mdot
.15689 .16865 Mdot
.14513 .15689 Mdot
.1412 .15689 Mdot
.1412 .16081 Mdot
.13336 .15297 Mdot
.13336 .15297 Mdot
.13336 .15689 Mdot
.12552 .15297 Mdot
.12552 .14905 Mdot
.12944 .14905 Mdot
.09415 .12552 Mdot
.11768 .14513 Mdot
.1412 .16473 Mdot
.16081 .16865 Mdot
.16865 .1765 Mdot
.1765 .18434 Mdot
.18434 .1961 Mdot
.18434 .19218 Mdot
.18826 .1961 Mdot
.18434 .1961 Mdot
.19218 .21963 Mdot
.21571 .251 Mdot
.18826 .21963 Mdot
.13336 .15297 Mdot
.1216 .13336 Mdot
.11768 .11768 Mdot
.09023 .08239 Mdot
.0667 .0667 Mdot
.05494 .05886 Mdot
.05102 .05494 Mdot
.02357 .02357 Mdot
.01965 .01572 Mdot
.01572 .01572 Mdot
.00788 .01572 Mdot
.0118 .01965 Mdot
.02357 .03141 Mdot
.07062 .09023 Mdot
.10199 .12552 Mdot
.09807 .11376 Mdot
.08631 .08631 Mdot
.0667 .0667 Mdot
.05102 .05102 Mdot
.04709 .05102 Mdot
.05886 .07062 Mdot
.08239 .09023 Mdot
.09415 .10199 Mdot
.08631 .09415 Mdot
.06278 .07062 Mdot
.05102 .05102 Mdot
.06278 .07062 Mdot
.07846 .07454 Mdot
.09415 .09023 Mdot
.07846 .0667 Mdot
.07454 .07062 Mdot
.08239 .07846 Mdot
.08239 .07846 Mdot
.09807 .10199 Mdot
.10983 .1216 Mdot
.08631 .09807 Mdot
.07062 .08239 Mdot
.06278 .06278 Mdot
.05102 .04709 Mdot
.10983 .1216 Mdot
.14513 .16865 Mdot
.14513 .16865 Mdot
.11376 .13728 Mdot
.10591 .13728 Mdot
.10199 .12944 Mdot
.11768 .14905 Mdot
.14513 .18042 Mdot
.18042 .22355 Mdot
.21179 .25884 Mdot
.23139 .28237 Mdot
.24708 .29413 Mdot
.25492 .3059 Mdot
.25884 .3059 Mdot
.26668 .32158 Mdot
.27061 .33335 Mdot
.27061 .32158 Mdot
.28629 .32943 Mdot
.28237 .32158 Mdot
.27845 .31374 Mdot
.28629 .3255 Mdot
.28629 .3255 Mdot
.28237 .3255 Mdot
.27845 .32158 Mdot
.27061 .31374 Mdot
.26668 .30982 Mdot
.26668 .30982 Mdot
.27845 .31766 Mdot
.26668 .3059 Mdot
.27061 .30982 Mdot
.25884 .29413 Mdot
.25884 .29806 Mdot
.26668 .30198 Mdot
.27453 .30198 Mdot
.28237 .3059 Mdot
.28629 .3059 Mdot
.29413 .30982 Mdot
.29413 .30982 Mdot
.30198 .31766 Mdot
.32943 .34511 Mdot
.32158 .33727 Mdot
.30198 .32158 Mdot
.29021 .31374 Mdot
.28629 .30982 Mdot
.27845 .30198 Mdot
.27061 .29806 Mdot
.27061 .29806 Mdot
.27061 .29806 Mdot
.27061 .30198 Mdot
.26276 .28629 Mdot
.26276 .29021 Mdot
.26276 .29806 Mdot
.25884 .29413 Mdot
.25492 .28629 Mdot
.24708 .28237 Mdot
.23924 .27845 Mdot
.23924 .28629 Mdot
.23139 .27845 Mdot
.22355 .27453 Mdot
.21571 .26276 Mdot
.20787 .25492 Mdot
.1961 .24316 Mdot
.19218 .22747 Mdot
.1961 .22747 Mdot
.20002 .24316 Mdot
.20394 .24316 Mdot
.21571 .24708 Mdot
.21179 .24316 Mdot
.20787 .24708 Mdot
.20002 .23924 Mdot
.20394 .23139 Mdot
.21179 .23531 Mdot
.20787 .23139 Mdot
.21963 .24708 Mdot
.21571 .24708 Mdot
.21571 .251 Mdot
.20787 .24316 Mdot
.20394 .23924 Mdot
.20002 .23531 Mdot
.18042 .21179 Mdot
.18826 .20787 Mdot
.20002 .22355 Mdot
.20002 .22747 Mdot
.20394 .23531 Mdot
.19218 .22747 Mdot
.1765 .21179 Mdot
.17257 .20002 Mdot
.16473 .1961 Mdot
.15689 .1765 Mdot
.16081 .18042 Mdot
.16081 .1765 Mdot
.16865 .18434 Mdot
.18042 .1961 Mdot
.17257 .1961 Mdot
.16473 .18434 Mdot
.17257 .19218 Mdot
.15689 .17257 Mdot
.13728 .15689 Mdot
.14905 .16473 Mdot
.14513 .15689 Mdot
.14513 .16081 Mdot
.1412 .15297 Mdot
.13336 .16081 Mdot
.12944 .16081 Mdot
.13336 .16865 Mdot
.1412 .17257 Mdot
.12944 .15689 Mdot
.13728 .15689 Mdot
.10591 .12552 Mdot
.10591 .12552 Mdot
.09415 .11376 Mdot
.10591 .11768 Mdot
.1216 .13336 Mdot
.14905 .15689 Mdot
.18042 .1961 Mdot
.18826 .20002 Mdot
.1961 .21571 Mdot
.19218 .21571 Mdot
.18042 .20787 Mdot
.18434 .21571 Mdot
.19218 .22355 Mdot
.18042 .21179 Mdot
.15689 .18042 Mdot
.15297 .17257 Mdot
.13336 .14905 Mdot
.12944 .1412 Mdot
.12552 .13336 Mdot
.10591 .11768 Mdot
.08239 .09023 Mdot
.05494 .05886 Mdot
.03533 .03925 Mdot
.02357 .02749 Mdot
.01965 .02749 Mdot
.01965 .02357 Mdot
.0667 .08631 Mdot
.09415 .11376 Mdot
.09023 .10983 Mdot
.08239 .08631 Mdot
.07454 .07454 Mdot
.07846 .07454 Mdot
.07454 .07454 Mdot
.08239 .07846 Mdot
.09807 .10591 Mdot
.11768 .13336 Mdot
.12552 .14905 Mdot
.1216 .14513 Mdot
.09415 .10983 Mdot
.09023 .10591 Mdot
.09807 .11376 Mdot
.07846 .09023 Mdot
.0667 .0667 Mdot
.05886 .05886 Mdot
.05886 .06278 Mdot
.05494 .06278 Mdot
.05886 .0667 Mdot
.07846 .09023 Mdot
.0667 .07846 Mdot
.05886 .07454 Mdot
.05102 .06278 Mdot
.04317 .04709 Mdot
.14513 .17257 Mdot
.18434 .21571 Mdot
.1765 .21179 Mdot
.10591 .13336 Mdot
.09415 .1216 Mdot
.07454 .09023 Mdot
.07454 .09415 Mdot
.07846 .09807 Mdot
.09807 .11768 Mdot
.11768 .14513 Mdot
.14905 .18042 Mdot
.18042 .21571 Mdot
.20394 .24708 Mdot
.23139 .27453 Mdot
.25492 .3059 Mdot
.26668 .30982 Mdot
.27845 .3255 Mdot
.28237 .32158 Mdot
.28629 .32158 Mdot
.28629 .32943 Mdot
.29021 .33335 Mdot
.27845 .3255 Mdot
.27453 .32943 Mdot
.27845 .32943 Mdot
.28237 .33335 Mdot
.27453 .32158 Mdot
.27453 .32158 Mdot
.27061 .30982 Mdot
.27453 .31374 Mdot
.27845 .31374 Mdot
.28237 .30982 Mdot
.28629 .31374 Mdot
.28629 .30982 Mdot
.28629 .3059 Mdot
.28629 .30982 Mdot
.27845 .29806 Mdot
.28629 .3059 Mdot
.29413 .30982 Mdot
.30198 .31766 Mdot
.31374 .3255 Mdot
.31766 .32943 Mdot
.30982 .32158 Mdot
.29806 .31766 Mdot
.29806 .31766 Mdot
.28629 .30982 Mdot
.27061 .3059 Mdot
.27453 .31374 Mdot
.25884 .29806 Mdot
.26276 .30198 Mdot
.251 .28237 Mdot
.25492 .27845 Mdot
.26276 .28629 Mdot
.26276 .28237 Mdot
.26668 .28629 Mdot
.26276 .28629 Mdot
.251 .28237 Mdot
.24708 .28237 Mdot
.23531 .27061 Mdot
.21963 .25884 Mdot
.21571 .25884 Mdot
.20787 .251 Mdot
.20002 .23924 Mdot
.20002 .23531 Mdot
.19218 .22747 Mdot
.1961 .23139 Mdot
.20394 .251 Mdot
.21963 .26276 Mdot
.20002 .24316 Mdot
.20394 .24708 Mdot
.1961 .23531 Mdot
.21179 .24316 Mdot
.21179 .23531 Mdot
.21963 .23924 Mdot
.21963 .24316 Mdot
.21963 .251 Mdot
.20787 .23531 Mdot
.21571 .24708 Mdot
.21571 .251 Mdot
.21179 .24316 Mdot
.19218 .21963 Mdot
.1765 .20787 Mdot
.17257 .20787 Mdot
.1765 .21179 Mdot
.1765 .20787 Mdot
.19218 .22355 Mdot
.18042 .21179 Mdot
.16865 .1961 Mdot
.16473 .18434 Mdot
.17257 .19218 Mdot
.1765 .20002 Mdot
.16473 .18042 Mdot
.16865 .18826 Mdot
.16473 .18826 Mdot
.16081 .18434 Mdot
.16865 .18826 Mdot
.16473 .19218 Mdot
.16081 .19218 Mdot
.14905 .18042 Mdot
.13728 .16865 Mdot
.12944 .15689 Mdot
.12552 .15297 Mdot
.1412 .16081 Mdot
.1412 .16473 Mdot
.12552 .15689 Mdot
.1216 .14513 Mdot
.13336 .15689 Mdot
.12552 .14513 Mdot
.12552 .14513 Mdot
.12552 .1412 Mdot
.10983 .1216 Mdot
.09807 .11376 Mdot
.09023 .10591 Mdot
.09023 .10983 Mdot
.11376 .12552 Mdot
.12944 .13728 Mdot
.1412 .15297 Mdot
.16473 .1765 Mdot
.1765 .19218 Mdot
.18434 .20787 Mdot
.18826 .21963 Mdot
.21179 .24708 Mdot
.18042 .21571 Mdot
.16865 .20002 Mdot
.17257 .20394 Mdot
.18042 .20394 Mdot
.18826 .20787 Mdot
.18826 .20394 Mdot
.18826 .20002 Mdot
.17257 .18042 Mdot
.14513 .15689 Mdot
.11768 .12944 Mdot
.0667 .07454 Mdot
.04317 .05494 Mdot
.03141 .03533 Mdot
.05102 .06278 Mdot
.07846 .09023 Mdot
.08631 .10591 Mdot
.07846 .09415 Mdot
.07846 .07846 Mdot
.07454 .07454 Mdot
.07846 .07846 Mdot
.09415 .09807 Mdot
.11768 .12944 Mdot
.11376 .12552 Mdot
.13336 .15297 Mdot
.13728 .16473 Mdot
.14513 .17257 Mdot
.1412 .16865 Mdot
.15297 .1765 Mdot
.10199 .11768 Mdot
.07454 .08239 Mdot
.05494 .05886 Mdot
.05494 .05494 Mdot
.05494 .05886 Mdot
.06278 .0667 Mdot
.07062 .07846 Mdot
.0667 .08239 Mdot
.05886 .07062 Mdot
.05494 .0667 Mdot
.04709 .05886 Mdot
.09807 .1216 Mdot
.11376 .14513 Mdot
.12552 .15689 Mdot
.11768 .14905 Mdot
.10983 .13728 Mdot
.09023 .10983 Mdot
.07846 .08631 Mdot
.07846 .08239 Mdot
.08239 .09023 Mdot
.07846 .09023 Mdot
.07846 .09023 Mdot
.09807 .11768 Mdot
.13336 .16081 Mdot
.16865 .20394 Mdot
.21179 .251 Mdot
.251 .29021 Mdot
.26276 .30198 Mdot
.27453 .31766 Mdot
.27845 .31766 Mdot
.28629 .32158 Mdot
.28629 .32943 Mdot
.28629 .33335 Mdot
.28237 .32943 Mdot
.28629 .33335 Mdot
.29413 .34119 Mdot
.28629 .32943 Mdot
.28629 .32943 Mdot
.28237 .32943 Mdot
.27453 .32158 Mdot
.27061 .3059 Mdot
.27453 .3059 Mdot
.29806 .32158 Mdot
.29413 .32158 Mdot
.29021 .32158 Mdot
.28629 .3059 Mdot
.28629 .3059 Mdot
.28629 .30982 Mdot
.29021 .31374 Mdot
.29021 .30982 Mdot
.30982 .32943 Mdot
.30198 .31766 Mdot
.3059 .32158 Mdot
.30982 .32943 Mdot
.30198 .33335 Mdot
.29806 .3255 Mdot
.27845 .31766 Mdot
.27453 .31766 Mdot
.26668 .30982 Mdot
.27845 .32158 Mdot
.28237 .3255 Mdot
.27061 .30982 Mdot
.26668 .29806 Mdot
.26668 .29806 Mdot
.26668 .29413 Mdot
.26668 .28629 Mdot
.25492 .27845 Mdot
.25492 .28629 Mdot
.23531 .26668 Mdot
.23139 .26276 Mdot
.23531 .27061 Mdot
.21963 .25884 Mdot
.20394 .23924 Mdot
.20394 .23924 Mdot
.20787 .24708 Mdot
.20394 .23924 Mdot
.20787 .24316 Mdot
.21571 .251 Mdot
.21179 .24708 Mdot
.20787 .24316 Mdot
.21179 .24316 Mdot
.20787 .23531 Mdot
.20394 .23139 Mdot
.21571 .24316 Mdot
.21571 .23924 Mdot
.21571 .24708 Mdot
.21179 .23924 Mdot
.21179 .23924 Mdot
.21571 .24316 Mdot
.20787 .23531 Mdot
.1961 .23139 Mdot
.19218 .23531 Mdot
.18434 .22747 Mdot
.18042 .22355 Mdot
.16865 .21179 Mdot
.1765 .21179 Mdot
.18826 .21963 Mdot
.1765 .20002 Mdot
.16865 .19218 Mdot
.16473 .18042 Mdot
.1765 .1961 Mdot
.17257 .19218 Mdot
.16081 .18826 Mdot
.16081 .19218 Mdot
.16473 .19218 Mdot
.15689 .18434 Mdot
.16081 .19218 Mdot
.15689 .19218 Mdot
.13728 .17257 Mdot
.14513 .18042 Mdot
.14513 .18042 Mdot
.13728 .17257 Mdot
.1412 .17257 Mdot
.1412 .17257 Mdot
.12552 .16081 Mdot
.12552 .15689 Mdot
.1412 .16865 Mdot
.13728 .16081 Mdot
.1216 .14513 Mdot
.11376 .13728 Mdot
.1216 .13336 Mdot
.10983 .11376 Mdot
.09415 .10199 Mdot
.09807 .10983 Mdot
.10591 .10983 Mdot
.10591 .10591 Mdot
.10983 .11376 Mdot
.10983 .10983 Mdot
.1216 .1216 Mdot
.13728 .14513 Mdot
.15297 .1765 Mdot
.18434 .21571 Mdot
.19218 .22747 Mdot
.18826 .22355 Mdot
.18434 .21963 Mdot
.1765 .20394 Mdot
.18042 .20002 Mdot
.1961 .20787 Mdot
.1961 .20787 Mdot
.20394 .21571 Mdot
.1961 .21571 Mdot
.18042 .20394 Mdot
.15297 .1765 Mdot
.11376 .13728 Mdot
.09415 .11376 Mdot
.07846 .09807 Mdot
.08631 .10591 Mdot
.09807 .11768 Mdot
.08631 .10591 Mdot
.07846 .09415 Mdot
.07846 .09415 Mdot
.09023 .09807 Mdot
.10199 .11376 Mdot
.09023 .09807 Mdot
.07846 .09023 Mdot
.09415 .10591 Mdot
.11768 .13728 Mdot
.15689 .18042 Mdot
.17257 .1961 Mdot
.18434 .21179 Mdot
.17257 .20394 Mdot
.10983 .12552 Mdot
.09415 .10199 Mdot
.08239 .07454 Mdot
.0667 .05886 Mdot
.05886 .05102 Mdot
.06278 .06278 Mdot
.0667 .07062 Mdot
.07454 .08631 Mdot
.06278 .07846 Mdot
.06278 .09023 Mdot
.07062 .09807 Mdot
.09023 .1216 Mdot
.09415 .12552 Mdot
.09415 .1216 Mdot
.09415 .1216 Mdot
.08631 .10591 Mdot
.07846 .09415 Mdot
.07846 .09415 Mdot
.07454 .08631 Mdot
.0667 .08239 Mdot
.0667 .08239 Mdot
.07062 .08631 Mdot
.09807 .11768 Mdot
.09807 .10591 Mdot
.13728 .15297 Mdot
.20394 .23139 Mdot
.23924 .27061 Mdot
.26668 .3059 Mdot
.28237 .32158 Mdot
.29413 .32943 Mdot
.29021 .33335 Mdot
.28237 .32943 Mdot
.28237 .3255 Mdot
.27845 .3255 Mdot
.29021 .33727 Mdot
.29021 .33727 Mdot
.29021 .33727 Mdot
.28629 .33335 Mdot
.28237 .33335 Mdot
.27453 .31766 Mdot
.27845 .31374 Mdot
.27845 .31374 Mdot
.28629 .3255 Mdot
.28629 .32943 Mdot
.27845 .31766 Mdot
.27845 .30982 Mdot
.28237 .31374 Mdot
.29021 .30982 Mdot
.29413 .31766 Mdot
.29806 .30982 Mdot
.30198 .31766 Mdot
.29806 .31766 Mdot
.29413 .31766 Mdot
.29413 .32158 Mdot
.29021 .3255 Mdot
.27845 .31766 Mdot
.26668 .30982 Mdot
.26668 .30982 Mdot
.27061 .30982 Mdot
.27061 .30982 Mdot
.26668 .30982 Mdot
.26668 .3059 Mdot
.27453 .31374 Mdot
.27845 .31374 Mdot
.27061 .29413 Mdot
.27061 .29413 Mdot
.26668 .29413 Mdot
.24708 .27453 Mdot
.23924 .26668 Mdot
.23139 .26276 Mdot
.23139 .26668 Mdot
.21179 .24708 Mdot
.22355 .26276 Mdot
.22355 .26668 Mdot
.21963 .25884 Mdot
.21571 .24708 Mdot
.21963 .25492 Mdot
.22747 .25884 Mdot
.22747 .25884 Mdot
.22355 .251 Mdot
.21571 .24316 Mdot
.20002 .22747 Mdot
.20002 .22355 Mdot
.18826 .21179 Mdot
.20002 .22355 Mdot
.21179 .23924 Mdot
.21179 .23924 Mdot
.20787 .23924 Mdot
.1961 .22747 Mdot
.20787 .23924 Mdot
.20787 .23531 Mdot
.20787 .23924 Mdot
.20394 .23924 Mdot
.20787 .23924 Mdot
.18434 .21571 Mdot
.18826 .21179 Mdot
.18434 .20787 Mdot
.18434 .20787 Mdot
.18042 .20002 Mdot
.18042 .20002 Mdot
.18042 .20002 Mdot
.1765 .20002 Mdot
.17257 .1961 Mdot
.16865 .19218 Mdot
.15297 .17257 Mdot
.15297 .1765 Mdot
.16473 .19218 Mdot
.15297 .18434 Mdot
.14905 .18826 Mdot
.14905 .18434 Mdot
.14513 .1765 Mdot
.14905 .18042 Mdot
.13728 .16865 Mdot
.13336 .16473 Mdot
.12944 .16081 Mdot
.1216 .15689 Mdot
.13336 .16081 Mdot
.12944 .14905 Mdot
.07454 .08631 Mdot
.15689 .16865 Mdot
.12944 .12552 Mdot
.11376 .10591 Mdot
.09807 .09023 Mdot
.09415 .09023 Mdot
.09415 .09023 Mdot
.09807 .09415 Mdot
.08631 .08239 Mdot
.07846 .07846 Mdot
.07454 .08631 Mdot
.09023 .10983 Mdot
.12552 .15297 Mdot
.14905 .18042 Mdot
.16865 .20787 Mdot
.20002 .23531 Mdot
.19218 .21963 Mdot
.19218 .21179 Mdot
.18434 .1961 Mdot
.18826 .20002 Mdot
.1961 .20394 Mdot
.20394 .21963 Mdot
.20394 .22747 Mdot
.1961 .22747 Mdot
.18434 .21571 Mdot
.15689 .19218 Mdot
.13336 .16865 Mdot
.12552 .15297 Mdot
.10983 .13728 Mdot
.08631 .10199 Mdot
.09023 .10591 Mdot
.09023 .10591 Mdot
.09023 .10591 Mdot
.09807 .11376 Mdot
.08239 .09415 Mdot
.05886 .07062 Mdot
.05886 .0667 Mdot
.07062 .08631 Mdot
.1216 .1412 Mdot
.15297 .16865 Mdot
.1765 .1961 Mdot
.18826 .20787 Mdot
.18826 .20787 Mdot
.17257 .18826 Mdot
.14905 .16473 Mdot
.11768 .12552 Mdot
.09023 .09807 Mdot
.08239 .08631 Mdot
.0667 .07846 Mdot
.0667 .07846 Mdot
.09023 .10983 Mdot
.10591 .13336 Mdot
.10199 .12944 Mdot
.10199 .13336 Mdot
.09415 .12552 Mdot
.10199 .12944 Mdot
.09023 .11768 Mdot
.07846 .10199 Mdot
.07454 .09807 Mdot
.05886 .08239 Mdot
.05886 .08239 Mdot
.0667 .07846 Mdot
.07062 .08631 Mdot
.07846 .09023 Mdot
.08631 .09807 Mdot
.07062 .07846 Mdot
.08631 .08631 Mdot
.11376 .11768 Mdot
.18042 .18434 Mdot
.21963 .23531 Mdot
.26276 .29021 Mdot
.28237 .32158 Mdot
.28629 .32943 Mdot
.29413 .34119 Mdot
.29413 .34119 Mdot
.29021 .34511 Mdot
.28629 .34511 Mdot
.28629 .33727 Mdot
.28629 .32943 Mdot
.29021 .33727 Mdot
.28629 .33335 Mdot
.27845 .31766 Mdot
.27453 .31374 Mdot
.27453 .31374 Mdot
.28629 .3255 Mdot
.29021 .32943 Mdot
.29021 .33335 Mdot
.27453 .31374 Mdot
.27453 .31374 Mdot
.27845 .30982 Mdot
.27845 .30198 Mdot
.28237 .30198 Mdot
.28629 .29806 Mdot
.27845 .29413 Mdot
.28629 .30982 Mdot
.28237 .30982 Mdot
.27453 .30982 Mdot
.27453 .31374 Mdot
.27453 .31374 Mdot
.27061 .31374 Mdot
.26668 .3059 Mdot
.26668 .30198 Mdot
.26668 .30198 Mdot
.26276 .29806 Mdot
.26276 .29806 Mdot
.27845 .3059 Mdot
.26668 .28629 Mdot
.27061 .28629 Mdot
.27845 .30198 Mdot
.26668 .29413 Mdot
.24316 .27061 Mdot
.23531 .26276 Mdot
.22355 .25884 Mdot
.21179 .24708 Mdot
.21179 .25492 Mdot
.21179 .25884 Mdot
.20787 .251 Mdot
.21179 .251 Mdot
.21963 .25492 Mdot
.22747 .26276 Mdot
.21179 .23924 Mdot
.20787 .23531 Mdot
.21571 .23531 Mdot
.20002 .22355 Mdot
.20002 .22355 Mdot
.18826 .20787 Mdot
.18042 .20394 Mdot
.19218 .21963 Mdot
.1961 .22747 Mdot
.1961 .22355 Mdot
.19218 .22355 Mdot
.19218 .22747 Mdot
.19218 .21963 Mdot
.1961 .22355 Mdot
.19218 .21963 Mdot
.19218 .21963 Mdot
.18042 .20787 Mdot
.18042 .1961 Mdot
.18042 .20002 Mdot
.18042 .1961 Mdot
.18042 .1961 Mdot
.1765 .18826 Mdot
.18042 .20002 Mdot
.1765 .20002 Mdot
.18434 .20394 Mdot
.18042 .20002 Mdot
.16473 .18042 Mdot
.14905 .17257 Mdot
.15689 .1765 Mdot
.14905 .17257 Mdot
.14513 .17257 Mdot
.14513 .17257 Mdot
.15689 .17257 Mdot
.15689 .18434 Mdot
.15689 .18434 Mdot
.1412 .16865 Mdot
.12552 .15297 Mdot
.11768 .14513 Mdot
.11768 .14513 Mdot
.1216 .13728 Mdot
.43922 .47059 Mdot
.22355 .25492 Mdot
.18826 .20394 Mdot
.16473 .16865 Mdot
.15297 .15689 Mdot
.13728 .13728 Mdot
.11768 .10983 Mdot
.10983 .10199 Mdot
.09807 .09415 Mdot
.09023 .09415 Mdot
.07454 .08631 Mdot
.07454 .09023 Mdot
.07454 .09415 Mdot
.08239 .10199 Mdot
.13336 .15297 Mdot
.16081 .1765 Mdot
.18434 .20002 Mdot
.20787 .21963 Mdot
.20002 .21571 Mdot
.20002 .21179 Mdot
.20787 .21571 Mdot
.22355 .23531 Mdot
.21963 .23531 Mdot
.20787 .23531 Mdot
.1961 .22355 Mdot
.19218 .22747 Mdot
.1765 .20787 Mdot
.14905 .18042 Mdot
.12552 .14905 Mdot
.11768 .13728 Mdot
.11768 .12552 Mdot
.11768 .1216 Mdot
.10983 .11768 Mdot
.09023 .09807 Mdot
.07454 .08239 Mdot
.05886 .06278 Mdot
.05102 .05102 Mdot
.08631 .09807 Mdot
.1216 .13728 Mdot
.11768 .13336 Mdot
.11376 .1216 Mdot
.11768 .12944 Mdot
.15689 .17257 Mdot
.17257 .19218 Mdot
.18042 .20002 Mdot
.1765 .20002 Mdot
.16081 .18434 Mdot
.11768 .13728 Mdot
.09807 .11768 Mdot
.09023 .10983 Mdot
.10591 .12944 Mdot
.10983 .13728 Mdot
.11376 .14513 Mdot
.10591 .12944 Mdot
.10199 .1216 Mdot
.10591 .12944 Mdot
.10591 .1216 Mdot
.08239 .09415 Mdot
.07454 .08239 Mdot
.0667 .07454 Mdot
.06278 .07062 Mdot
.06278 .07062 Mdot
.07062 .07846 Mdot
.09023 .09415 Mdot
.09023 .09415 Mdot
.08239 .08239 Mdot
.08631 .08239 Mdot
.09023 .08239 Mdot
.11376 .10591 Mdot
.11768 .11376 Mdot
.21179 .23139 Mdot
.24708 .27845 Mdot
.27845 .31374 Mdot
.29413 .3255 Mdot
.3059 .34119 Mdot
.30198 .34511 Mdot
.29413 .34511 Mdot
.29413 .34119 Mdot
.29021 .33335 Mdot
.29021 .33727 Mdot
.29021 .33727 Mdot
.29806 .34511 Mdot
.29021 .33335 Mdot
.27845 .32158 Mdot
.27845 .31766 Mdot
.29021 .3255 Mdot
.28629 .3255 Mdot
.27453 .30982 Mdot
.27845 .31766 Mdot
.27453 .31374 Mdot
.27453 .30982 Mdot
.27845 .3059 Mdot
.27453 .29806 Mdot
.27845 .30198 Mdot
.28629 .3059 Mdot
.28629 .31374 Mdot
.27061 .29806 Mdot
.27061 .29806 Mdot
.27061 .3059 Mdot
.26668 .30198 Mdot
.26668 .29806 Mdot
.26668 .30198 Mdot
.27061 .29806 Mdot
.26668 .29413 Mdot
.27453 .29806 Mdot
.27845 .3059 Mdot
.28237 .30982 Mdot
.27845 .30198 Mdot
.27453 .29413 Mdot
.27061 .29021 Mdot
.25884 .28629 Mdot
.24708 .27453 Mdot
.23531 .26276 Mdot
.22747 .25884 Mdot
.21179 .24316 Mdot
.1961 .23924 Mdot
.20002 .24708 Mdot
.1961 .24316 Mdot
.20787 .24708 Mdot
.20787 .24708 Mdot
.20787 .24316 Mdot
.20002 .23531 Mdot
.20787 .23531 Mdot
.20002 .22355 Mdot
.18434 .20787 Mdot
.18434 .20787 Mdot
.18826 .21179 Mdot
.17257 .19218 Mdot
.18434 .21179 Mdot
.20002 .22355 Mdot
.20002 .23139 Mdot
.19218 .22355 Mdot
.1961 .22747 Mdot
.19218 .22355 Mdot
.18826 .21963 Mdot
.18434 .21571 Mdot
.17257 .20394 Mdot
.17257 .20394 Mdot
.18042 .20394 Mdot
.17257 .19218 Mdot
.16865 .18434 Mdot
.16865 .18434 Mdot
.18042 .1961 Mdot
.17257 .19218 Mdot
.16865 .18826 Mdot
.17257 .19218 Mdot
.16865 .1961 Mdot
.15689 .18434 Mdot
.14513 .1765 Mdot
.13728 .16865 Mdot
.13336 .16081 Mdot
.14513 .16473 Mdot
.16081 .18042 Mdot
.14905 .17257 Mdot
.14905 .1765 Mdot
.14513 .16865 Mdot
.13728 .16081 Mdot
.13728 .16473 Mdot
.12944 .15689 Mdot
.1216 .13728 Mdot
.63528 .65489 Mdot
.3059 .35295 Mdot
.27845 .30982 Mdot
.24708 .26668 Mdot
.21179 .22355 Mdot
.1765 .18826 Mdot
.1412 .15297 Mdot
.1216 .13336 Mdot
.11376 .12944 Mdot
.10983 .12552 Mdot
.11768 .12944 Mdot
.12944 .13728 Mdot
.1216 .12552 Mdot
.12552 .11768 Mdot
.15297 .14513 Mdot
.1765 .1765 Mdot
.18042 .18042 Mdot
.18434 .18434 Mdot
.21179 .22355 Mdot
.22355 .23924 Mdot
.22747 .24708 Mdot
.23139 .26668 Mdot
.21963 .25492 Mdot
.20394 .24316 Mdot
.18434 .21963 Mdot
.18434 .21963 Mdot
.16865 .19218 Mdot
.17257 .20394 Mdot
.18826 .21963 Mdot
.16081 .17257 Mdot
.14513 .15297 Mdot
.1216 .11768 Mdot
.08239 .07454 Mdot
.06278 .05102 Mdot
.05494 .04709 Mdot
.09023 .09023 Mdot
.10983 .12552 Mdot
.09415 .10591 Mdot
.07062 .07846 Mdot
.05494 .06278 Mdot
.07454 .09023 Mdot
.09415 .10983 Mdot
.13336 .15689 Mdot
.15689 .18434 Mdot
.16865 .20002 Mdot
.13336 .16081 Mdot
.11768 .14905 Mdot
.1412 .17257 Mdot
.13336 .16865 Mdot
.1216 .15689 Mdot
.11376 .14513 Mdot
.09415 .11768 Mdot
.09023 .11376 Mdot
.10983 .12944 Mdot
.10591 .1216 Mdot
.09807 .10199 Mdot
.07846 .08239 Mdot
.08239 .08239 Mdot
.07454 .07454 Mdot
.06278 .06278 Mdot
.0667 .06278 Mdot
.07062 .07062 Mdot
.07454 .07454 Mdot
.09023 .09023 Mdot
.09415 .09415 Mdot
.12552 .12944 Mdot
.13728 .1412 Mdot
.1412 .15297 Mdot
.16081 .18434 Mdot
.20787 .23139 Mdot
.24708 .27061 Mdot
.27453 .29806 Mdot
.29413 .32158 Mdot
.30982 .33727 Mdot
.30982 .34511 Mdot
.3059 .34903 Mdot
.29413 .33727 Mdot
.29413 .34119 Mdot
.29021 .33727 Mdot
.29021 .33335 Mdot
.29021 .32943 Mdot
.30198 .34119 Mdot
.3059 .33335 Mdot
.29413 .31766 Mdot
.30198 .32158 Mdot
.28629 .3059 Mdot
.28629 .3059 Mdot
.28629 .31374 Mdot
.27845 .30982 Mdot
.28629 .31766 Mdot
.28237 .31374 Mdot
.28629 .31766 Mdot
.27845 .30198 Mdot
.27453 .29413 Mdot
.27061 .29021 Mdot
.27845 .29806 Mdot
.28237 .30982 Mdot
.28237 .30982 Mdot
.28629 .30982 Mdot
.28237 .3059 Mdot
.27845 .29413 Mdot
.27845 .29413 Mdot
.26668 .29413 Mdot
.26276 .29413 Mdot
.27061 .30982 Mdot
.27061 .30198 Mdot
.27845 .30982 Mdot
.26668 .29021 Mdot
.27061 .28629 Mdot
.26276 .27845 Mdot
.24316 .26276 Mdot
.24316 .26668 Mdot
.22355 .24316 Mdot
.20787 .23531 Mdot
.1961 .23139 Mdot
.20002 .24708 Mdot
.1961 .24708 Mdot
.1961 .24316 Mdot
.19218 .23924 Mdot
.20002 .23531 Mdot
.21179 .24708 Mdot
.20394 .23139 Mdot
.1961 .22355 Mdot
.19218 .21963 Mdot
.20787 .23924 Mdot
.20002 .22355 Mdot
.19218 .21179 Mdot
.19218 .21179 Mdot
.1961 .21963 Mdot
.1961 .21963 Mdot
.20002 .22355 Mdot
.19218 .22355 Mdot
.18826 .22747 Mdot
.18042 .21963 Mdot
.18042 .21571 Mdot
.18042 .21963 Mdot
.1765 .21571 Mdot
.17257 .21179 Mdot
.17257 .1961 Mdot
.1765 .19218 Mdot
.17257 .18042 Mdot
.18042 .19218 Mdot
.18042 .19218 Mdot
.18042 .1961 Mdot
.1765 .1961 Mdot
.17257 .1961 Mdot
.15297 .18042 Mdot
.13728 .16865 Mdot
.1412 .17257 Mdot
.1412 .16865 Mdot
.15297 .1765 Mdot
.14513 .17257 Mdot
.13336 .16473 Mdot
.12944 .16081 Mdot
.13336 .16081 Mdot
.13728 .16473 Mdot
.13336 .16081 Mdot
.1216 .14905 Mdot
.86272 .87448 Mdot
.69802 .72155 Mdot
.43922 .50196 Mdot
.37256 .43138 Mdot
.26668 .30982 Mdot
.251 .29021 Mdot
.28237 .31766 Mdot
.29806 .33335 Mdot
.29021 .31766 Mdot
.21571 .22355 Mdot
.1765 .1765 Mdot
.1765 .17257 Mdot
.1765 .17257 Mdot
.16865 .16473 Mdot
.1412 .13336 Mdot
.13728 .12552 Mdot
.16865 .16473 Mdot
.18042 .18826 Mdot
.20787 .22355 Mdot
.21963 .23924 Mdot
.22355 .25492 Mdot
.21179 .24708 Mdot
.18434 .21571 Mdot
.17257 .20394 Mdot
.18042 .21571 Mdot
.1961 .22747 Mdot
.21179 .24708 Mdot
.21179 .24316 Mdot
.22355 .24708 Mdot
.20394 .21571 Mdot
.16081 .16081 Mdot
.1216 .11768 Mdot
.10591 .10199 Mdot
.11768 .1216 Mdot
.11768 .12944 Mdot
.07454 .08239 Mdot
.06278 .07062 Mdot
.05886 .05886 Mdot
.05494 .05494 Mdot
.0667 .07062 Mdot
.07846 .08239 Mdot
.09023 .10199 Mdot
.11376 .13336 Mdot
.1216 .15297 Mdot
.15689 .19218 Mdot
.16081 .20394 Mdot
.16081 .20394 Mdot
.14905 .19218 Mdot
.12552 .15689 Mdot
.10983 .1412 Mdot
.10591 .13336 Mdot
.10591 .12944 Mdot
.11376 .12944 Mdot
.10199 .10983 Mdot
.09023 .09023 Mdot
.09023 .09415 Mdot
.08631 .09023 Mdot
.07454 .07454 Mdot
.07454 .07062 Mdot
.07062 .07062 Mdot
.07846 .07846 Mdot
.05886 .05886 Mdot
.07062 .07062 Mdot
.23531 .27453 Mdot
.26668 .32158 Mdot
.28629 .34903 Mdot
.26276 .32158 Mdot
.25492 .30198 Mdot
.24708 .28237 Mdot
.24316 .27453 Mdot
.26276 .28629 Mdot
.27453 .29806 Mdot
.29021 .31766 Mdot
.29413 .3255 Mdot
.29413 .33335 Mdot
.29413 .34119 Mdot
.29021 .34119 Mdot
.29413 .33335 Mdot
.29021 .32158 Mdot
.3059 .33335 Mdot
.31374 .33727 Mdot
.32158 .35295 Mdot
.31374 .33727 Mdot
.31374 .32943 Mdot
.29806 .31374 Mdot
.29021 .31374 Mdot
.29806 .32158 Mdot
.29413 .32158 Mdot
.29413 .32158 Mdot
.29021 .31766 Mdot
.27845 .3059 Mdot
.27845 .30198 Mdot
.28237 .30198 Mdot
.29021 .3059 Mdot
.29413 .30982 Mdot
.28237 .30198 Mdot
.29806 .31766 Mdot
.29021 .31374 Mdot
.27453 .29806 Mdot
.26668 .29021 Mdot
.26668 .3059 Mdot
.26668 .3059 Mdot
.26668 .3059 Mdot
.26276 .30198 Mdot
.27061 .30982 Mdot
.27061 .30198 Mdot
.27453 .30198 Mdot
.27453 .29413 Mdot
.27453 .29021 Mdot
.27061 .29021 Mdot
.25492 .27453 Mdot
.23531 .251 Mdot
.22355 .24708 Mdot
.21179 .251 Mdot
.20394 .24316 Mdot
.20394 .24316 Mdot
.20787 .24316 Mdot
.21179 .24316 Mdot
.21179 .24316 Mdot
.21179 .24316 Mdot
.21179 .24316 Mdot
.21179 .23924 Mdot
.20787 .23531 Mdot
.20394 .22747 Mdot
.20787 .23531 Mdot
.1961 .21963 Mdot
.18434 .21179 Mdot
.18434 .21179 Mdot
.18042 .21571 Mdot
.1765 .21571 Mdot
.18434 .22355 Mdot
.18434 .22355 Mdot
.18434 .22355 Mdot
.18042 .21963 Mdot
.18434 .22747 Mdot
.18042 .21963 Mdot
.18042 .21179 Mdot
.17257 .19218 Mdot
.16865 .18434 Mdot
.17257 .19218 Mdot
.18042 .1961 Mdot
.1765 .18826 Mdot
.16865 .18434 Mdot
.16473 .18042 Mdot
.15689 .18042 Mdot
.14513 .17257 Mdot
.14905 .1765 Mdot
.1412 .16865 Mdot
.14905 .1765 Mdot
.1412 .16865 Mdot
.13728 .15689 Mdot
.13336 .15297 Mdot
.12944 .15689 Mdot
.12944 .16081 Mdot
.12552 .15297 Mdot
.1216 .14905 Mdot
.8784 .89801 Mdot
.6196 .67057 Mdot
.47843 .54509 Mdot
.4902 .5647 Mdot
.50588 .58431 Mdot
.49804 .57646 Mdot
.42354 .47451 Mdot
.37256 .41569 Mdot
.39609 .44706 Mdot
.28237 .30982 Mdot
.15297 .15297 Mdot
.1216 .11768 Mdot
.10199 .09415 Mdot
.09415 .08631 Mdot
.10983 .10983 Mdot
.14905 .15297 Mdot
.1765 .19218 Mdot
.20787 .22747 Mdot
.21571 .24316 Mdot
.21179 .24708 Mdot
.19218 .22355 Mdot
.22355 .26276 Mdot
.23531 .27845 Mdot
.24316 .28237 Mdot
.23924 .27453 Mdot
.24316 .27061 Mdot
.23139 .251 Mdot
.22355 .24316 Mdot
.20002 .22747 Mdot
.18434 .20787 Mdot
.17257 .19218 Mdot
.11376 .12944 Mdot
.08239 .09023 Mdot
.07062 .07454 Mdot
.0667 .06278 Mdot
.07454 .07454 Mdot
.07454 .07454 Mdot
.06278 .05886 Mdot
.06278 .06278 Mdot
.06278 .07062 Mdot
.07846 .09023 Mdot
.15689 .19218 Mdot
.15689 .19218 Mdot
.1765 .21571 Mdot
.15689 .19218 Mdot
.1412 .17257 Mdot
.12552 .15689 Mdot
.11768 .14905 Mdot
.11376 .13728 Mdot
.10983 .12944 Mdot
.09807 .11768 Mdot
.09023 .10591 Mdot
.09023 .10591 Mdot
.08239 .09415 Mdot
.08631 .09023 Mdot
.08239 .08631 Mdot
.09807 .09807 Mdot
.08239 .07846 Mdot
.09415 .09415 Mdot
.11376 .11768 Mdot
.20394 .22355 Mdot
.32158 .37256 Mdot
.34119 .40393 Mdot
.34119 .41177 Mdot
.33335 .40001 Mdot
.29806 .35687 Mdot
.27061 .3255 Mdot
.26668 .30982 Mdot
.26276 .29806 Mdot
.27061 .30982 Mdot
.27845 .31374 Mdot
.29021 .3255 Mdot
.30982 .34119 Mdot
.29806 .33335 Mdot
.30198 .33727 Mdot
.31374 .34903 Mdot
.30982 .34511 Mdot
.30198 .33727 Mdot
.30982 .34511 Mdot
.31374 .34119 Mdot
.31374 .34511 Mdot
.3059 .33727 Mdot
.3059 .33335 Mdot
.3059 .32943 Mdot
.3059 .32943 Mdot
.30198 .3255 Mdot
.29413 .32158 Mdot
.30198 .3255 Mdot
.29413 .31766 Mdot
.29021 .30982 Mdot
.28629 .3059 Mdot
.28629 .3059 Mdot
.28629 .3059 Mdot
.28237 .3059 Mdot
.28629 .30982 Mdot
.28237 .3059 Mdot
.27845 .30198 Mdot
.28237 .31374 Mdot
.27845 .30982 Mdot
.27453 .30982 Mdot
.27061 .31374 Mdot
.27845 .32158 Mdot
.27845 .31374 Mdot
.27453 .30198 Mdot
.27453 .30198 Mdot
.27453 .29806 Mdot
.27453 .29413 Mdot
.25884 .27845 Mdot
.25492 .28237 Mdot
.24316 .27061 Mdot
.23139 .25884 Mdot
.22747 .25492 Mdot
.20787 .23139 Mdot
.20394 .23139 Mdot
.20002 .23139 Mdot
.21179 .251 Mdot
.21179 .24708 Mdot
.20394 .24708 Mdot
.1961 .23924 Mdot
.20002 .24316 Mdot
.1961 .23139 Mdot
.20002 .23531 Mdot
.1961 .23924 Mdot
.19218 .23531 Mdot
.19218 .23139 Mdot
.18826 .22355 Mdot
.19218 .23139 Mdot
.18826 .22747 Mdot
.18434 .21963 Mdot
.18434 .21963 Mdot
.20394 .23924 Mdot
.20002 .23531 Mdot
.18826 .22355 Mdot
.1961 .23139 Mdot
.18434 .20787 Mdot
.1765 .1961 Mdot
.17257 .19218 Mdot
.1765 .19218 Mdot
.16865 .18826 Mdot
.16865 .19218 Mdot
.16081 .18826 Mdot
.16081 .18042 Mdot
.16865 .18826 Mdot
.16473 .18434 Mdot
.15689 .17257 Mdot
.15689 .17257 Mdot
.14513 .16081 Mdot
.13336 .14513 Mdot
.13336 .14905 Mdot
.12944 .14905 Mdot
.14513 .16081 Mdot
.1412 .16081 Mdot
.12944 .1412 Mdot
.76861 .81174 Mdot
.65881 .72547 Mdot
.54117 .63528 Mdot
.54509 .63528 Mdot
.54117 .6196 Mdot
.54902 .62744 Mdot
.43138 .48628 Mdot
.12552 .1216 Mdot
.1216 .11768 Mdot
.10591 .09807 Mdot
.09023 .08239 Mdot
.07846 .07062 Mdot
.08239 .07846 Mdot
.1216 .12552 Mdot
.1412 .15297 Mdot
.16473 .18434 Mdot
.20394 .23924 Mdot
.21179 .24708 Mdot
.26276 .30982 Mdot
.27061 .32158 Mdot
.251 .29413 Mdot
.251 .29021 Mdot
.23531 .26668 Mdot
.23531 .26668 Mdot
.22355 .25492 Mdot
.22355 .25492 Mdot
.22747 .26276 Mdot
.21963 .25884 Mdot
.21179 .24316 Mdot
.14905 .16865 Mdot
.10591 .11768 Mdot
.08631 .09807 Mdot
.07454 .07454 Mdot
.07454 .07062 Mdot
.05494 .05102 Mdot
.0667 .05886 Mdot
.07062 .06278 Mdot
.09807 .10983 Mdot
.16473 .1961 Mdot
.1412 .17257 Mdot
.14513 .17257 Mdot
.15689 .18434 Mdot
.15689 .18434 Mdot
.13728 .16865 Mdot
.13728 .16081 Mdot
.11768 .13728 Mdot
.11768 .13728 Mdot
.1216 .1412 Mdot
.1216 .14905 Mdot
.10983 .12944 Mdot
.10199 .11768 Mdot
.10199 .11768 Mdot
.09807 .11376 Mdot
.11376 .1216 Mdot
.10199 .09807 Mdot
.11376 .11376 Mdot
.16473 .16473 Mdot
.14905 .1412 Mdot
.28629 .3059 Mdot
.33335 .3804 Mdot
.30198 .3608 Mdot
.28629 .34119 Mdot
.3059 .36864 Mdot
.31766 .38432 Mdot
.3059 .37256 Mdot
.27845 .34511 Mdot
.27453 .32943 Mdot
.27845 .32158 Mdot
.28237 .31766 Mdot
.29021 .32158 Mdot
.29413 .32158 Mdot
.29021 .31766 Mdot
.29806 .32943 Mdot
.30198 .35295 Mdot
.29021 .33727 Mdot
.30198 .35295 Mdot
.30982 .3608 Mdot
.29413 .34119 Mdot
.30198 .33727 Mdot
.3059 .33335 Mdot
.3059 .33335 Mdot
.3059 .32158 Mdot
.30982 .3255 Mdot
.3059 .3255 Mdot
.30198 .31766 Mdot
.28629 .30982 Mdot
.28629 .31374 Mdot
.28237 .31766 Mdot
.28237 .31766 Mdot
.28237 .31374 Mdot
.27845 .30982 Mdot
.28237 .31374 Mdot
.27845 .30982 Mdot
.28629 .30982 Mdot
.28237 .29806 Mdot
.28237 .29806 Mdot
.27845 .29806 Mdot
.26668 .29806 Mdot
.27453 .31374 Mdot
.26276 .29806 Mdot
.26668 .30198 Mdot
.26276 .29806 Mdot
.25884 .29021 Mdot
.25884 .28629 Mdot
.25492 .29021 Mdot
.25884 .29021 Mdot
.27061 .29021 Mdot
.25884 .27845 Mdot
.24316 .27061 Mdot
.23139 .25884 Mdot
.21963 .24316 Mdot
.20394 .22747 Mdot
.20002 .23531 Mdot
.19218 .22747 Mdot
.18826 .22747 Mdot
.18826 .23531 Mdot
.18434 .23531 Mdot
.19218 .24316 Mdot
.1961 .24708 Mdot
.20394 .251 Mdot
.1961 .23924 Mdot
.1961 .23139 Mdot
.20394 .23139 Mdot
.1961 .22355 Mdot
.1961 .22355 Mdot
.18826 .21179 Mdot
.18826 .21571 Mdot
.18434 .20787 Mdot
.18434 .21571 Mdot
.19218 .22747 Mdot
.18434 .22747 Mdot
.18042 .21963 Mdot
.1765 .21179 Mdot
.16473 .1961 Mdot
.16081 .19218 Mdot
.16081 .19218 Mdot
.16473 .20002 Mdot
.17257 .20787 Mdot
.1765 .20002 Mdot
.16865 .18042 Mdot
.18434 .19218 Mdot
.17257 .18434 Mdot
.16081 .1765 Mdot
.14905 .16081 Mdot
.13336 .14513 Mdot
.13336 .14513 Mdot
.12944 .13728 Mdot
.14513 .15689 Mdot
.13728 .14513 Mdot
.12944 .13728 Mdot
.78037 .8235 Mdot
.56862 .65489 Mdot
.57254 .65881 Mdot
.53725 .6196 Mdot
.31766 .3608 Mdot
.12552 .12944 Mdot
.12944 .13336 Mdot
.10983 .10983 Mdot
.08631 .08239 Mdot
.08631 .07846 Mdot
.08239 .07454 Mdot
.09023 .08631 Mdot
.10983 .11376 Mdot
.13336 .14513 Mdot
.15297 .17257 Mdot
.1961 .22747 Mdot
.22355 .25884 Mdot
.23924 .26276 Mdot
.24316 .27061 Mdot
.24708 .27061 Mdot
.24316 .27061 Mdot
.24316 .27061 Mdot
.24316 .27845 Mdot
.251 .27845 Mdot
.24708 .27453 Mdot
.24316 .27453 Mdot
.24708 .28237 Mdot
.22747 .25884 Mdot
.19218 .21963 Mdot
.13728 .14513 Mdot
.11376 .11376 Mdot
.10199 .09807 Mdot
.08631 .07846 Mdot
.0667 .05494 Mdot
.13336 .14513 Mdot
.13336 .15297 Mdot
.11376 .13336 Mdot
.10591 .12552 Mdot
.13336 .16081 Mdot
.15297 .18434 Mdot
.14513 .16865 Mdot
.13336 .14905 Mdot
.13728 .16081 Mdot
.13336 .15689 Mdot
.1412 .16865 Mdot
.13336 .15689 Mdot
.13728 .16473 Mdot
.12552 .15297 Mdot
.12552 .15297 Mdot
.12552 .14513 Mdot
.10591 .11768 Mdot
.10199 .10199 Mdot
.08631 .08631 Mdot
.10591 .10591 Mdot
.10983 .10983 Mdot
.36472 .41961 Mdot
.36864 .4353 Mdot
.26668 .31766 Mdot
.18434 .21963 Mdot
.19218 .22747 Mdot
.20787 .251 Mdot
.30982 .38432 Mdot
.30982 .38432 Mdot
.31766 .38432 Mdot
.30982 .37256 Mdot
.28237 .33335 Mdot
.27845 .31766 Mdot
.29021 .32158 Mdot
.29021 .32158 Mdot
.28237 .32158 Mdot
.27453 .31766 Mdot
.27453 .32943 Mdot
.28629 .34119 Mdot
.3059 .35687 Mdot
.29413 .34119 Mdot
.30198 .34119 Mdot
.29806 .33727 Mdot
.30198 .32943 Mdot
.29806 .32158 Mdot
.28629 .30982 Mdot
.29021 .31766 Mdot
.29413 .32158 Mdot
.29021 .32158 Mdot
.28629 .31766 Mdot
.27845 .31374 Mdot
.27845 .31374 Mdot
.27453 .31374 Mdot
.27845 .31766 Mdot
.29021 .3255 Mdot
.28237 .31374 Mdot
.27845 .3059 Mdot
.28629 .30982 Mdot
.28237 .30198 Mdot
.27845 .3059 Mdot
.27845 .30982 Mdot
.27453 .30198 Mdot
.27061 .30198 Mdot
.27453 .30982 Mdot
.26668 .29806 Mdot
.25884 .29413 Mdot
.25884 .29021 Mdot
.26276 .29413 Mdot
.27453 .3059 Mdot
.27061 .29413 Mdot
.26276 .28237 Mdot
.26668 .28237 Mdot
.25884 .28629 Mdot
.24316 .27061 Mdot
.21963 .24708 Mdot
.20002 .23924 Mdot
.18042 .21963 Mdot
.19218 .23139 Mdot
.18826 .22747 Mdot
.19218 .23924 Mdot
.1961 .24316 Mdot
.19218 .23139 Mdot
.1961 .23139 Mdot
.20394 .23139 Mdot
.20002 .22747 Mdot
.20002 .22747 Mdot
.18826 .21571 Mdot
.1961 .22355 Mdot
.1961 .22355 Mdot
.19218 .21963 Mdot
.17257 .20394 Mdot
.1765 .21571 Mdot
.19218 .22355 Mdot
.18826 .22355 Mdot
.18826 .21963 Mdot
.19218 .21963 Mdot
.17257 .1961 Mdot
.1765 .20002 Mdot
.16081 .18042 Mdot
.16081 .18434 Mdot
.15689 .18826 Mdot
.15689 .18826 Mdot
.16473 .19218 Mdot
.1765 .19218 Mdot
.1765 .19218 Mdot
.16473 .18042 Mdot
.14513 .16081 Mdot
.12944 .14513 Mdot
.11768 .12944 Mdot
.13728 .14513 Mdot
.1412 .15689 Mdot
.12944 .1412 Mdot
.12552 .13728 Mdot
.89409 .91761 Mdot
.79213 .83919 Mdot
.48628 .56078 Mdot
.25492 .29021 Mdot
.18042 .1961 Mdot
.15297 .16081 Mdot
.11376 .10983 Mdot
.10199 .09415 Mdot
.09023 .08631 Mdot
.08631 .08239 Mdot
.09023 .09415 Mdot
.09807 .10199 Mdot
.09023 .10199 Mdot
.11376 .12552 Mdot
.13728 .14905 Mdot
.18826 .20394 Mdot
.23531 .251 Mdot
.251 .27061 Mdot
.26276 .28237 Mdot
.27061 .30198 Mdot
.27061 .30198 Mdot
.27845 .30982 Mdot
.26668 .3059 Mdot
.25884 .29806 Mdot
.25492 .30198 Mdot
.251 .29021 Mdot
.25492 .28237 Mdot
.24316 .26276 Mdot
.22355 .23531 Mdot
.20787 .21571 Mdot
.15689 .15297 Mdot
.12944 .11768 Mdot
.16865 .17257 Mdot
.12944 .13336 Mdot
.07846 .08239 Mdot
.07454 .08239 Mdot
.09415 .10591 Mdot
.09415 .11376 Mdot
.10983 .12944 Mdot
.1216 .1412 Mdot
.12552 .14513 Mdot
.12944 .15689 Mdot
.1216 .15297 Mdot
.12552 .14905 Mdot
.13336 .16081 Mdot
.13728 .16473 Mdot
.1412 .16473 Mdot
.13336 .14513 Mdot
.1216 .12944 Mdot
.10983 .11376 Mdot
.10199 .10199 Mdot
.1216 .12552 Mdot
.10591 .11768 Mdot
.21179 .251 Mdot
.23531 .27845 Mdot
.15297 .1765 Mdot
.17257 .1961 Mdot
.14513 .16081 Mdot
.11376 .12552 Mdot
.14513 .1765 Mdot
.23924 .29413 Mdot
.33335 .40785 Mdot
.34903 .42746 Mdot
.33727 .40785 Mdot
.31374 .37256 Mdot
.29021 .33727 Mdot
.28629 .32943 Mdot
.27453 .31374 Mdot
.251 .29413 Mdot
.24708 .29806 Mdot
.25884 .30982 Mdot
.27845 .32943 Mdot
.29021 .34511 Mdot
.29806 .34511 Mdot
.29806 .34119 Mdot
.29413 .33727 Mdot
.28629 .33335 Mdot
.29021 .33335 Mdot
.30198 .33727 Mdot
.29021 .33335 Mdot
.28629 .32158 Mdot
.29413 .3255 Mdot
.28237 .31374 Mdot
.27845 .30982 Mdot
.28629 .32158 Mdot
.28629 .32943 Mdot
.28629 .32943 Mdot
.27453 .31374 Mdot
.27845 .31766 Mdot
.27845 .31374 Mdot
.28237 .31374 Mdot
.27453 .30198 Mdot
.27845 .30982 Mdot
.28629 .31374 Mdot
.27453 .30198 Mdot
.27453 .30198 Mdot
.27061 .30198 Mdot
.27061 .3059 Mdot
.27061 .3059 Mdot
.25884 .29021 Mdot
.26276 .29806 Mdot
.26276 .30198 Mdot
.26276 .29806 Mdot
.25492 .28237 Mdot
.25884 .29021 Mdot
.251 .28237 Mdot
.23924 .27453 Mdot
.23139 .26276 Mdot
.22355 .251 Mdot
.20394 .23139 Mdot
.20394 .22747 Mdot
.1961 .22747 Mdot
.19218 .22747 Mdot
.20002 .23531 Mdot
.20002 .23531 Mdot
.1961 .22747 Mdot
.18042 .21179 Mdot
.17257 .20787 Mdot
.1765 .21571 Mdot
.1765 .21571 Mdot
.19218 .22747 Mdot
.18042 .21179 Mdot
.18826 .21963 Mdot
.18042 .20787 Mdot
.18042 .20787 Mdot
.18434 .21179 Mdot
.18434 .21179 Mdot
.1961 .21963 Mdot
.1961 .22355 Mdot
.18826 .21571 Mdot
.1765 .20394 Mdot
.16865 .1961 Mdot
.15689 .18826 Mdot
.15689 .19218 Mdot
.16473 .1961 Mdot
.16865 .19218 Mdot
.16473 .1961 Mdot
.15689 .18826 Mdot
.14513 .17257 Mdot
.13336 .15689 Mdot
.13336 .15689 Mdot
.1412 .16473 Mdot
.13728 .15297 Mdot
.13336 .14905 Mdot
.12552 .1412 Mdot
.73332 .76861 Mdot
.51765 .56078 Mdot
.24708 .27061 Mdot
.18434 .1961 Mdot
.14905 .14513 Mdot
.13336 .12552 Mdot
.12552 .1216 Mdot
.10983 .10591 Mdot
.10591 .10591 Mdot
.09807 .09415 Mdot
.09415 .09415 Mdot
.09415 .09415 Mdot
.09023 .08239 Mdot
.15689 .15689 Mdot
.18434 .18434 Mdot
.22355 .23531 Mdot
.24708 .27061 Mdot
.25884 .28629 Mdot
.27061 .3059 Mdot
.27453 .32158 Mdot
.251 .29413 Mdot
.24316 .28237 Mdot
.25492 .29806 Mdot
.25884 .29021 Mdot
.26668 .29021 Mdot
.27453 .29806 Mdot
.26668 .28237 Mdot
.25492 .26668 Mdot
.23531 .24316 Mdot
.21571 .22747 Mdot
.13728 .1412 Mdot
.09023 .08631 Mdot
.0667 .0667 Mdot
.06278 .07062 Mdot
.05494 .06278 Mdot
.05886 .0667 Mdot
.07062 .08239 Mdot
.10199 .1216 Mdot
.11376 .13728 Mdot
.1216 .14513 Mdot
.11768 .13728 Mdot
.12552 .15297 Mdot
.13728 .16473 Mdot
.14905 .17257 Mdot
.1412 .15297 Mdot
.14513 .15297 Mdot
.14905 .15689 Mdot
.15297 .16081 Mdot
.14905 .15689 Mdot
.12552 .14513 Mdot
.09807 .10983 Mdot
.09807 .11376 Mdot
.10199 .11376 Mdot
.12944 .13728 Mdot
.1216 .12552 Mdot
.10983 .11768 Mdot
.09807 .10983 Mdot
.09807 .11376 Mdot
.19218 .23139 Mdot
.25492 .30982 Mdot
.30982 .37648 Mdot
.34511 .41961 Mdot
.34903 .42354 Mdot
.29413 .34511 Mdot
.21179 .251 Mdot
.18434 .21963 Mdot
.18042 .21963 Mdot
.1961 .23531 Mdot
.21179 .25492 Mdot
.25492 .30198 Mdot
.26668 .31766 Mdot
.29021 .34119 Mdot
.28237 .33727 Mdot
.28629 .34119 Mdot
.29413 .34511 Mdot
.3059 .3608 Mdot
.29021 .33727 Mdot
.29806 .33727 Mdot
.29413 .32943 Mdot
.28629 .31766 Mdot
.28629 .32158 Mdot
.28237 .31374 Mdot
.27453 .31766 Mdot
.28237 .32943 Mdot
.27845 .32158 Mdot
.27453 .31766 Mdot
.27845 .31766 Mdot
.27453 .31766 Mdot
.27845 .31766 Mdot
.27845 .30982 Mdot
.27845 .30198 Mdot
.27453 .29021 Mdot
.27453 .29413 Mdot
.28629 .30982 Mdot
.27845 .3059 Mdot
.28237 .31374 Mdot
.27845 .31374 Mdot
.27061 .30198 Mdot
.27061 .30198 Mdot
.26668 .30198 Mdot
.24708 .28237 Mdot
.251 .28237 Mdot
.24708 .27845 Mdot
.25884 .29021 Mdot
.25884 .29021 Mdot
.23924 .27061 Mdot
.22747 .25492 Mdot
.21963 .23924 Mdot
.20394 .22747 Mdot
.20002 .22355 Mdot
.20394 .22747 Mdot
.21179 .23924 Mdot
.21179 .24316 Mdot
.20394 .24316 Mdot
.1765 .21571 Mdot
.16473 .20002 Mdot
.1765 .20394 Mdot
.18042 .20002 Mdot
.18042 .20002 Mdot
.18434 .20787 Mdot
.18042 .20394 Mdot
.18042 .20394 Mdot
.18826 .21963 Mdot
.1961 .22355 Mdot
.19218 .21963 Mdot
.18826 .21963 Mdot
.18434 .21571 Mdot
.18042 .21571 Mdot
.1765 .20394 Mdot
.16473 .19218 Mdot
.15689 .18434 Mdot
.14905 .18434 Mdot
.16081 .20002 Mdot
.14905 .18434 Mdot
.1412 .17257 Mdot
.15297 .18434 Mdot
.13336 .16081 Mdot
.11376 .13728 Mdot
.1216 .14905 Mdot
.13336 .14905 Mdot
.13728 .15297 Mdot
.12944 .13728 Mdot
.64705 .65881 Mdot
.41177 .41961 Mdot
.19218 .20002 Mdot
.17257 .18042 Mdot
.1412 .14513 Mdot
.11768 .1216 Mdot
.10983 .10591 Mdot
.10199 .09807 Mdot
.09023 .08239 Mdot
.09023 .07062 Mdot
.09023 .07062 Mdot
.09415 .07846 Mdot
.13336 .1216 Mdot
.20002 .1961 Mdot
.24708 .26276 Mdot
.24708 .27453 Mdot
.26276 .30198 Mdot
.26276 .3059 Mdot
.26668 .3059 Mdot
.25492 .29806 Mdot
.26276 .30198 Mdot
.27061 .30198 Mdot
.26668 .29021 Mdot
.26668 .28629 Mdot
.28629 .29806 Mdot
.28629 .29413 Mdot
.27453 .28237 Mdot
.23531 .24316 Mdot
.19218 .20394 Mdot
.1216 .13336 Mdot
.07454 .07454 Mdot
.07454 .07454 Mdot
.0667 .0667 Mdot
.0667 .07062 Mdot
.07846 .08239 Mdot
.10199 .11768 Mdot
.11768 .13728 Mdot
.1216 .1412 Mdot
.12552 .14905 Mdot
.13728 .16473 Mdot
.14905 .16865 Mdot
.14905 .16081 Mdot
.14513 .15297 Mdot
.20394 .21571 Mdot
.20394 .21571 Mdot
.19218 .20394 Mdot
.13728 .1412 Mdot
.11768 .11768 Mdot
.09023 .09023 Mdot
.09023 .09023 Mdot
.10591 .11376 Mdot
.10983 .12552 Mdot
.10199 .11376 Mdot
.10591 .12944 Mdot
.10591 .12944 Mdot
.09415 .1216 Mdot
.1216 .15297 Mdot
.1412 .1765 Mdot
.19218 .23924 Mdot
.32943 .40393 Mdot
.31374 .38432 Mdot
.16865 .20787 Mdot
.13728 .16865 Mdot
.10983 .13336 Mdot
.10199 .12944 Mdot
.10199 .12552 Mdot
.18434 .22355 Mdot
.22355 .26276 Mdot
.26668 .3059 Mdot
.28629 .32943 Mdot
.29021 .33727 Mdot
.29021 .33335 Mdot
.29806 .34511 Mdot
.29413 .34119 Mdot
.29413 .34119 Mdot
.28629 .33335 Mdot
.28237 .3255 Mdot
.29413 .33335 Mdot
.29413 .32158 Mdot
.28237 .30982 Mdot
.27453 .3059 Mdot
.28629 .32158 Mdot
.27061 .30982 Mdot
.26668 .3059 Mdot
.26668 .3059 Mdot
.27061 .31374 Mdot
.26668 .30198 Mdot
.26668 .29806 Mdot
.25884 .28629 Mdot
.27061 .29413 Mdot
.27453 .29806 Mdot
.27453 .29413 Mdot
.28237 .30198 Mdot
.27845 .30198 Mdot
.28237 .30198 Mdot
.27845 .29806 Mdot
.26668 .28629 Mdot
.25492 .28237 Mdot
.24708 .27453 Mdot
.23924 .27061 Mdot
.24316 .27453 Mdot
.24708 .28237 Mdot
.24708 .28237 Mdot
.24708 .27845 Mdot
.24708 .27453 Mdot
.23531 .25884 Mdot
.23139 .24316 Mdot
.21963 .22355 Mdot
.21179 .22355 Mdot
.20394 .22355 Mdot
.1961 .22355 Mdot
.18042 .21179 Mdot
.1765 .20787 Mdot
.1765 .20394 Mdot
.17257 .20394 Mdot
.1765 .20394 Mdot
.1765 .20787 Mdot
.16473 .20394 Mdot
.15689 .19218 Mdot
.17257 .20394 Mdot
.18434 .21571 Mdot
.1765 .21179 Mdot
.18826 .21571 Mdot
.18042 .20394 Mdot
.1765 .20394 Mdot
.17257 .20002 Mdot
.14513 .16865 Mdot
.13728 .16473 Mdot
.13728 .16865 Mdot
.14513 .1765 Mdot
.14905 .18042 Mdot
.15297 .18434 Mdot
.14513 .18042 Mdot
.13728 .16865 Mdot
.12552 .15689 Mdot
.13336 .16081 Mdot
.13336 .14905 Mdot
.12944 .1412 Mdot
.12552 .13728 Mdot
.80782 .81174 Mdot
.62352 .63528 Mdot
.22747 .251 Mdot
.15297 .17257 Mdot
.13336 .15297 Mdot
.10591 .11376 Mdot
.09807 .09807 Mdot
.09415 .07846 Mdot
.10199 .07846 Mdot
.09415 .07062 Mdot
.10199 .07846 Mdot
.11768 .09807 Mdot
.14513 .13728 Mdot
.18042 .18826 Mdot
.21179 .23139 Mdot
.23924 .27061 Mdot
.251 .28629 Mdot
.26668 .3059 Mdot
.27845 .31766 Mdot
.28629 .31766 Mdot
.27845 .30982 Mdot
.27845 .29806 Mdot
.27845 .28629 Mdot
.27061 .27453 Mdot
.27061 .27453 Mdot
.27061 .28237 Mdot
.27061 .29021 Mdot
.251 .27061 Mdot
.19218 .21571 Mdot
.11376 .1216 Mdot
.10591 .11376 Mdot
.08631 .09807 Mdot
.0667 .07062 Mdot
.08239 .09415 Mdot
.11376 .13336 Mdot
.12552 .14905 Mdot
.12944 .15689 Mdot
.13728 .16473 Mdot
.1412 .16865 Mdot
.1412 .16081 Mdot
.13336 .14513 Mdot
.20394 .21571 Mdot
.24708 .27061 Mdot
.25884 .28237 Mdot
.21179 .23139 Mdot
.16865 .18042 Mdot
.13336 .13728 Mdot
.10591 .10199 Mdot
.10983 .11376 Mdot
.10199 .11376 Mdot
.10199 .11376 Mdot
.10199 .11768 Mdot
.08631 .10591 Mdot
.07454 .09023 Mdot
.09415 .11768 Mdot
.11376 .1412 Mdot
.09415 .1216 Mdot
.14513 .18042 Mdot
.16473 .20394 Mdot
.12944 .16081 Mdot
.10591 .13336 Mdot
.10591 .12944 Mdot
.10591 .12944 Mdot
.09023 .11376 Mdot
.13728 .16473 Mdot
.16865 .1961 Mdot
.23531 .27453 Mdot
.251 .29021 Mdot
.26668 .3059 Mdot
.26668 .3059 Mdot
.29806 .34119 Mdot
.29806 .34903 Mdot
.30198 .34903 Mdot
.29806 .34511 Mdot
.28629 .32943 Mdot
.3059 .34119 Mdot
.29413 .31766 Mdot
.28629 .30982 Mdot
.29021 .31766 Mdot
.28237 .30982 Mdot
.27453 .30982 Mdot
.27061 .3059 Mdot
.27061 .30982 Mdot
.27453 .31374 Mdot
.27453 .31374 Mdot
.27061 .30198 Mdot
.25884 .29021 Mdot
.23924 .26668 Mdot
.24316 .26276 Mdot
.24708 .26276 Mdot
.25884 .27453 Mdot
.27061 .29413 Mdot
.27061 .29021 Mdot
.27845 .29806 Mdot
.27845 .30198 Mdot
.26668 .29021 Mdot
.251 .27845 Mdot
.251 .27453 Mdot
.24316 .27453 Mdot
.23924 .27061 Mdot
.23531 .26668 Mdot
.23924 .26668 Mdot
.23924 .26276 Mdot
.25492 .27061 Mdot
.23924 .251 Mdot
.23139 .23924 Mdot
.23531 .24708 Mdot
.21571 .23139 Mdot
.20002 .21963 Mdot
.19218 .21571 Mdot
.1961 .21571 Mdot
.18042 .20787 Mdot
.17257 .20394 Mdot
.18042 .21571 Mdot
.18434 .22355 Mdot
.18434 .21963 Mdot
.17257 .20787 Mdot
.17257 .1961 Mdot
.1765 .20394 Mdot
.16865 .1961 Mdot
.18434 .20787 Mdot
.1765 .20394 Mdot
.1765 .20787 Mdot
.1765 .21179 Mdot
.16473 .19218 Mdot
.14513 .1765 Mdot
.14905 .18434 Mdot
.13728 .16473 Mdot
.1412 .1765 Mdot
.14905 .18434 Mdot
.14905 .18434 Mdot
.1412 .1765 Mdot
.14513 .18042 Mdot
.15297 .18042 Mdot
.15297 .1765 Mdot
.13336 .14905 Mdot
.12552 .1412 Mdot
.80782 .81566 Mdot
.59215 .60391 Mdot
.16081 .16473 Mdot
.13728 .13728 Mdot
.1216 .11376 Mdot
.10983 .09807 Mdot
.11376 .10199 Mdot
.11376 .10591 Mdot
.11376 .10591 Mdot
.1216 .11768 Mdot
.1216 .11376 Mdot
.12944 .12944 Mdot
.14905 .15689 Mdot
.18826 .20002 Mdot
.24708 .27061 Mdot
.27845 .30982 Mdot
.29806 .32943 Mdot
.30198 .33335 Mdot
.29806 .32158 Mdot
.28629 .29806 Mdot
.27453 .28629 Mdot
.27061 .28237 Mdot
.25492 .27453 Mdot
.29413 .33727 Mdot
.25884 .29806 Mdot
.28237 .3255 Mdot
.23924 .27453 Mdot
.22747 .25492 Mdot
.19218 .20394 Mdot
.1216 .12552 Mdot
.10199 .10591 Mdot
.16081 .1765 Mdot
.15297 .1765 Mdot
.12944 .15689 Mdot
.1216 .15297 Mdot
.12552 .16081 Mdot
.1216 .15297 Mdot
.12552 .14905 Mdot
.12552 .12944 Mdot
.1765 .18826 Mdot
.21963 .24316 Mdot
.23924 .27061 Mdot
.23531 .26276 Mdot
.22355 .25492 Mdot
.19218 .20787 Mdot
.14905 .16865 Mdot
.12552 .14513 Mdot
.10983 .1216 Mdot
.09023 .10591 Mdot
.07062 .08239 Mdot
.05494 .0667 Mdot
.09023 .10983 Mdot
.10199 .12552 Mdot
.10199 .1216 Mdot
.11376 .13336 Mdot
.13728 .16473 Mdot
.14905 .1765 Mdot
.11376 .1412 Mdot
.10591 .13336 Mdot
.10983 .13728 Mdot
.11768 .14513 Mdot
.16081 .20002 Mdot
.20002 .24316 Mdot
.21963 .27061 Mdot
.24316 .28629 Mdot
.25884 .29806 Mdot
.26276 .29806 Mdot
.28629 .32158 Mdot
.28629 .31766 Mdot
.29021 .3255 Mdot
.30198 .33335 Mdot
.30198 .32943 Mdot
.30982 .34119 Mdot
.29413 .3255 Mdot
.29413 .3255 Mdot
.29021 .32943 Mdot
.28629 .3255 Mdot
.29021 .33335 Mdot
.28629 .32943 Mdot
.29021 .3255 Mdot
.29413 .32943 Mdot
.30198 .32943 Mdot
.3059 .32158 Mdot
.29021 .30982 Mdot
.27453 .29021 Mdot
.26276 .28237 Mdot
.25492 .27453 Mdot
.251 .27845 Mdot
.251 .27845 Mdot
.251 .27845 Mdot
.25492 .27845 Mdot
.26668 .29806 Mdot
.25884 .29413 Mdot
.25884 .28629 Mdot
.25884 .28629 Mdot
.251 .27845 Mdot
.23531 .26668 Mdot
.24708 .27845 Mdot
.24708 .27845 Mdot
.23531 .27061 Mdot
.24316 .27453 Mdot
.23531 .26668 Mdot
.23139 .25884 Mdot
.23531 .25884 Mdot
.22747 .251 Mdot
.22355 .251 Mdot
.22355 .25492 Mdot
.22747 .25884 Mdot
.21179 .24708 Mdot
.20394 .23531 Mdot
.21179 .23924 Mdot
.21179 .23531 Mdot
.20002 .22747 Mdot
.1961 .22747 Mdot
.18826 .21963 Mdot
.17257 .20787 Mdot
.16473 .1961 Mdot
.16081 .1961 Mdot
.16473 .20002 Mdot
.16473 .20394 Mdot
.16865 .20787 Mdot
.18042 .21963 Mdot
.16865 .20394 Mdot
.16081 .20002 Mdot
.16865 .20394 Mdot
.16081 .18434 Mdot
.16865 .18826 Mdot
.16473 .18826 Mdot
.17257 .1961 Mdot
.16865 .19218 Mdot
.16865 .18826 Mdot
.15689 .18042 Mdot
.15689 .17257 Mdot
.14905 .16081 Mdot
.62352 .63528 Mdot
.38432 .38432 Mdot
.16473 .16865 Mdot
.1765 .18434 Mdot
.1961 .20787 Mdot
.16865 .17257 Mdot
.15297 .15689 Mdot
.14513 .14905 Mdot
.13336 .1412 Mdot
.1412 .14905 Mdot
.14905 .15689 Mdot
.18826 .20394 Mdot
.20394 .21963 Mdot
.25492 .27453 Mdot
.28629 .30198 Mdot
.30982 .31766 Mdot
.30982 .32158 Mdot
.3059 .3255 Mdot
.29021 .31766 Mdot
.26276 .29413 Mdot
.25492 .29806 Mdot
.25884 .3059 Mdot
.27453 .32158 Mdot
.29413 .34119 Mdot
.29021 .32158 Mdot
.28629 .31374 Mdot
.26668 .28237 Mdot
.21963 .23531 Mdot
.20787 .23531 Mdot
.12944 .14513 Mdot
.10591 .12552 Mdot
.08631 .11376 Mdot
.07846 .10591 Mdot
.08631 .10591 Mdot
.09023 .10591 Mdot
.07846 .07846 Mdot
.09023 .08239 Mdot
.12944 .12552 Mdot
.20394 .21571 Mdot
.23531 .25884 Mdot
.251 .27845 Mdot
.25492 .28629 Mdot
.24316 .28237 Mdot
.18042 .21179 Mdot
.14513 .17257 Mdot
.11768 .13728 Mdot
.09023 .10983 Mdot
.06278 .07846 Mdot
.06278 .07846 Mdot
.07846 .08631 Mdot
.08239 .09807 Mdot
.12944 .15689 Mdot
.14513 .1765 Mdot
.16473 .1961 Mdot
.14513 .1765 Mdot
.1412 .17257 Mdot
.13336 .16473 Mdot
.11768 .1412 Mdot
.14905 .1765 Mdot
.16865 .19218 Mdot
.1961 .22355 Mdot
.20787 .23531 Mdot
.23531 .26276 Mdot
.23924 .26668 Mdot
.26668 .29021 Mdot
.28237 .30198 Mdot
.28237 .30198 Mdot
.28629 .30982 Mdot
.29806 .31766 Mdot
.29806 .32158 Mdot
.30198 .32943 Mdot
.29413 .3255 Mdot
.28629 .3255 Mdot
.28629 .32943 Mdot
.29413 .33727 Mdot
.28629 .3255 Mdot
.28629 .31766 Mdot
.29021 .31374 Mdot
.29806 .31766 Mdot
.3059 .3255 Mdot
.30198 .31766 Mdot
.29021 .30982 Mdot
.27453 .29413 Mdot
.26276 .29021 Mdot
.25884 .29021 Mdot
.26276 .30198 Mdot
.24708 .28629 Mdot
.24708 .29021 Mdot
.24316 .28237 Mdot
.23924 .27453 Mdot
.24316 .28237 Mdot
.24708 .27845 Mdot
.24316 .27453 Mdot
.22747 .25884 Mdot
.23531 .27061 Mdot
.23531 .27061 Mdot
.22355 .25884 Mdot
.21571 .25492 Mdot
.21179 .251 Mdot
.21571 .25884 Mdot
.21179 .251 Mdot
.21963 .25492 Mdot
.20787 .251 Mdot
.22355 .25884 Mdot
.21963 .25492 Mdot
.21571 .25492 Mdot
.21179 .24708 Mdot
.21963 .251 Mdot
.21963 .25492 Mdot
.21963 .24708 Mdot
.21179 .23531 Mdot
.1961 .23139 Mdot
.18826 .22355 Mdot
.18434 .22355 Mdot
.16865 .20787 Mdot
.16473 .20002 Mdot
.15689 .19218 Mdot
.15297 .18826 Mdot
.15689 .1961 Mdot
.16081 .20002 Mdot
.16865 .20394 Mdot
.17257 .21179 Mdot
.16865 .20002 Mdot
.16473 .18434 Mdot
.16473 .18434 Mdot
.14905 .16473 Mdot
.15689 .17257 Mdot
.15297 .17257 Mdot
.14513 .16473 Mdot
.15689 .16473 Mdot
.15297 .16081 Mdot
.67842 .69802 Mdot
.53333 .56078 Mdot
.30982 .32943 Mdot
.29806 .32943 Mdot
.26668 .29413 Mdot
.21963 .23924 Mdot
.20394 .21571 Mdot
.19218 .19218 Mdot
.18826 .18434 Mdot
.18826 .18042 Mdot
.20787 .20002 Mdot
.21963 .21179 Mdot
.26276 .26276 Mdot
.28237 .28629 Mdot
.30198 .32158 Mdot
.30982 .34119 Mdot
.29806 .34511 Mdot
.28629 .33727 Mdot
.27845 .32158 Mdot
.27845 .32158 Mdot
.3059 .34511 Mdot
.3059 .33335 Mdot
.3059 .3255 Mdot
.30198 .33335 Mdot
.29806 .33335 Mdot
.27845 .3255 Mdot
.20394 .24316 Mdot
.17257 .20787 Mdot
.10199 .13728 Mdot
.10983 .13728 Mdot
.09023 .10199 Mdot
.07454 .07454 Mdot
.0667 .05494 Mdot
.10199 .08239 Mdot
.10199 .07846 Mdot
.23531 .23531 Mdot
.23139 .22747 Mdot
.22355 .21963 Mdot
.21571 .22355 Mdot
.22747 .24316 Mdot
.24708 .27061 Mdot
.24316 .27845 Mdot
.22355 .26668 Mdot
.15297 .18826 Mdot
.07062 .09415 Mdot
.07062 .09023 Mdot
.06278 .07846 Mdot
.07062 .08239 Mdot
.14905 .18042 Mdot
.14905 .1765 Mdot
.16081 .18434 Mdot
.16473 .18826 Mdot
.16081 .18826 Mdot
.16081 .1961 Mdot
.16865 .19218 Mdot
.15297 .17257 Mdot
.13728 .14905 Mdot
.13336 .13728 Mdot
.1216 .12552 Mdot
.14905 .16081 Mdot
.18434 .19218 Mdot
.24708 .26276 Mdot
.27845 .3059 Mdot
.27845 .31374 Mdot
.29021 .3255 Mdot
.28629 .32158 Mdot
.28629 .31766 Mdot
.28237 .3059 Mdot
.27845 .30198 Mdot
.27845 .3059 Mdot
.28629 .31766 Mdot
.28237 .32158 Mdot
.27845 .31766 Mdot
.27845 .32158 Mdot
.28629 .3255 Mdot
.28629 .3255 Mdot
.30198 .34119 Mdot
.28629 .32158 Mdot
.27453 .31374 Mdot
.27061 .30982 Mdot
.26668 .3059 Mdot
.26668 .3059 Mdot
.26276 .3059 Mdot
.26276 .30982 Mdot
.25492 .29806 Mdot
.24708 .29413 Mdot
.23924 .28629 Mdot
.23531 .29021 Mdot
.23924 .28237 Mdot
.23924 .27453 Mdot
.23924 .27453 Mdot
.23139 .27061 Mdot
.22747 .26276 Mdot
.23139 .26668 Mdot
.22355 .26276 Mdot
.21571 .25492 Mdot
.22355 .26668 Mdot
.22747 .27061 Mdot
.21571 .25884 Mdot
.20394 .251 Mdot
.20394 .251 Mdot
.20787 .251 Mdot
.20787 .24708 Mdot
.20394 .24708 Mdot
.21963 .25884 Mdot
.21963 .25492 Mdot
.22355 .25492 Mdot
.21571 .24708 Mdot
.20787 .23139 Mdot
.20394 .23531 Mdot
.20002 .23531 Mdot
.19218 .22747 Mdot
.18434 .21963 Mdot
.17257 .21179 Mdot
.15689 .19218 Mdot
.16081 .20002 Mdot
.16865 .20787 Mdot
.17257 .21179 Mdot
.17257 .20394 Mdot
.16865 .20002 Mdot
.16865 .19218 Mdot
.17257 .20002 Mdot
.16473 .18434 Mdot
.16081 .18434 Mdot
.15689 .18042 Mdot
.14905 .16865 Mdot
.15689 .17257 Mdot
.15689 .1765 Mdot
.89017 .90585 Mdot
.77253 .8039 Mdot
.54509 .61568 Mdot
.32943 .37256 Mdot
.29413 .3255 Mdot
.27845 .30198 Mdot
.26668 .26668 Mdot
.26276 .25884 Mdot
.24708 .24708 Mdot
.21179 .20787 Mdot
.20394 .20002 Mdot
.21571 .21179 Mdot
.25492 .25492 Mdot
.29021 .30198 Mdot
.29021 .32158 Mdot
.3059 .34511 Mdot
.30982 .35295 Mdot
.3255 .37256 Mdot
.3255 .36472 Mdot
.30982 .34119 Mdot
.29413 .32158 Mdot
.30198 .3255 Mdot
.31374 .34511 Mdot
.30982 .35295 Mdot
.29806 .34511 Mdot
.28629 .33335 Mdot
.23924 .28237 Mdot
.21179 .251 Mdot
.14513 .16473 Mdot
.13728 .13728 Mdot
.11376 .09023 Mdot
.11768 .08631 Mdot
.15297 .13336 Mdot
.27453 .27061 Mdot
.17257 .15297 Mdot
.15689 .14513 Mdot
.13728 .1216 Mdot
.13728 .12552 Mdot
.18434 .1961 Mdot
.21571 .24708 Mdot
.23531 .27845 Mdot
.23924 .29806 Mdot
.13728 .18042 Mdot
.08239 .11376 Mdot
.0667 .09023 Mdot
.05102 .06278 Mdot
.07846 .09415 Mdot
.08631 .10591 Mdot
.09807 .11376 Mdot
.12944 .14513 Mdot
.1412 .16081 Mdot
.15689 .18434 Mdot
.15297 .1765 Mdot
.1412 .16081 Mdot
.12944 .14513 Mdot
.15689 .1765 Mdot
.12944 .14513 Mdot
.1216 .12944 Mdot
.11768 .1216 Mdot
.23924 .27061 Mdot
.3608 .41569 Mdot
.34511 .39609 Mdot
.34511 .39609 Mdot
.3255 .3608 Mdot
.3059 .33335 Mdot
.28629 .31374 Mdot
.27845 .30198 Mdot
.27061 .29806 Mdot
.27061 .29806 Mdot
.25884 .29413 Mdot
.25884 .29413 Mdot
.26668 .30198 Mdot
.27061 .30982 Mdot
.27845 .32158 Mdot
.28237 .32158 Mdot
.28629 .33335 Mdot
.28237 .32158 Mdot
.27061 .30982 Mdot
.26276 .30198 Mdot
.25492 .29806 Mdot
.25884 .3059 Mdot
.26276 .31766 Mdot
.25492 .30982 Mdot
.26668 .31374 Mdot
.251 .30198 Mdot
.24708 .29021 Mdot
.24316 .28237 Mdot
.251 .28237 Mdot
.25492 .28237 Mdot
.23924 .26668 Mdot
.23924 .26276 Mdot
.23139 .26276 Mdot
.22355 .25884 Mdot
.22747 .26276 Mdot
.23139 .27845 Mdot
.21571 .25884 Mdot
.21571 .26668 Mdot
.21571 .26668 Mdot
.21571 .26276 Mdot
.21571 .25884 Mdot
.21963 .25492 Mdot
.21179 .24316 Mdot
.21179 .23924 Mdot
.21179 .23531 Mdot
.21571 .24316 Mdot
.21179 .23924 Mdot
.20787 .23924 Mdot
.20394 .23924 Mdot
.20002 .23531 Mdot
.18042 .21571 Mdot
.18042 .21571 Mdot
.1765 .21179 Mdot
.16473 .20394 Mdot
.16473 .20394 Mdot
.16081 .20002 Mdot
.16865 .20002 Mdot
.17257 .1961 Mdot
.17257 .18826 Mdot
.16865 .18434 Mdot
.16865 .18434 Mdot
.16081 .18042 Mdot
.14513 .16473 Mdot
.13728 .15297 Mdot
.15297 .16865 Mdot
.14905 .16473 Mdot
.14905 .17257 Mdot
.87056 .88232 Mdot
.73724 .76469 Mdot
.44706 .47843 Mdot
.4902 .53333 Mdot
.52549 .57646 Mdot
.27453 .28237 Mdot
.27061 .27845 Mdot
.25492 .25492 Mdot
.23924 .22747 Mdot
.24316 .22747 Mdot
.23531 .22355 Mdot
.24316 .23924 Mdot
.25884 .26668 Mdot
.29413 .31766 Mdot
.31374 .34903 Mdot
.3255 .36864 Mdot
.3255 .36472 Mdot
.3059 .34119 Mdot
.3059 .32943 Mdot
.32943 .34119 Mdot
.32158 .34119 Mdot
.30198 .3255 Mdot
.3059 .33727 Mdot
.30198 .34511 Mdot
.30198 .35687 Mdot
.28237 .32943 Mdot
.251 .29021 Mdot
.20002 .20787 Mdot
.15689 .1412 Mdot
.22355 .21571 Mdot
.24708 .24708 Mdot
.14513 .12552 Mdot
.13728 .12552 Mdot
.10591 .09023 Mdot
.08631 .07062 Mdot
.08631 .08239 Mdot
.10591 .11376 Mdot
.13728 .15689 Mdot
.16081 .19218 Mdot
.15297 .19218 Mdot
.10199 .13728 Mdot
.09023 .11376 Mdot
.09023 .11768 Mdot
.07062 .09415 Mdot
.07846 .09807 Mdot
.07846 .09415 Mdot
.07846 .09023 Mdot
.09415 .10983 Mdot
.10199 .1216 Mdot
.10983 .12552 Mdot
.09023 .10983 Mdot
.07454 .08631 Mdot
.12944 .15689 Mdot
.14513 .17257 Mdot
.15689 .1765 Mdot
.15689 .17257 Mdot
.19218 .21179 Mdot
.30198 .34511 Mdot
.37256 .41961 Mdot
.38432 .43922 Mdot
.38824 .44314 Mdot
.3608 .41177 Mdot
.31374 .35295 Mdot
.28629 .30982 Mdot
.25884 .27453 Mdot
.23924 .25492 Mdot
.22747 .24708 Mdot
.23139 .25492 Mdot
.24316 .25884 Mdot
.25492 .27845 Mdot
.26668 .29806 Mdot
.27845 .31766 Mdot
.28237 .31766 Mdot
.27061 .30982 Mdot
.26668 .30982 Mdot
.24708 .29413 Mdot
.25492 .3059 Mdot
.251 .30982 Mdot
.25492 .31374 Mdot
.25492 .30982 Mdot
.25884 .30198 Mdot
.25884 .30198 Mdot
.25884 .29806 Mdot
.26668 .29806 Mdot
.25492 .27845 Mdot
.25884 .28237 Mdot
.24316 .26668 Mdot
.23924 .27061 Mdot
.23531 .27453 Mdot
.21963 .26276 Mdot
.21571 .25884 Mdot
.22355 .27453 Mdot
.21571 .26668 Mdot
.21963 .26668 Mdot
.21571 .26276 Mdot
.23139 .27061 Mdot
.22747 .25884 Mdot
.21963 .24316 Mdot
.21571 .24316 Mdot
.1961 .22355 Mdot
.18826 .21963 Mdot
.18826 .22355 Mdot
.1961 .23139 Mdot
.19218 .23531 Mdot
.19218 .23531 Mdot
.19218 .23531 Mdot
.18826 .23139 Mdot
.18434 .22355 Mdot
.18042 .21571 Mdot
.17257 .20787 Mdot
.16865 .20394 Mdot
.16081 .18826 Mdot
.16865 .18826 Mdot
.1765 .18826 Mdot
.17257 .1765 Mdot
.1765 .18434 Mdot
.1765 .18434 Mdot
.16865 .17257 Mdot
.15689 .16473 Mdot
.15297 .16473 Mdot
.15689 .16865 Mdot
.15689 .17257 Mdot
.14513 .16081 Mdot
.81566 .83527 Mdot
.72547 .76861 Mdot
.5098 .56078 Mdot
.45883 .50588 Mdot
.3255 .34511 Mdot
.33727 .34903 Mdot
.31766 .32158 Mdot
.29413 .29413 Mdot
.27061 .26668 Mdot
.251 .251 Mdot
.24316 .24708 Mdot
.25492 .26276 Mdot
.28237 .30198 Mdot
.30198 .3255 Mdot
.32158 .34903 Mdot
.32943 .3608 Mdot
.34511 .36472 Mdot
.33727 .35687 Mdot
.32158 .34119 Mdot
.31374 .34119 Mdot
.3059 .33727 Mdot
.29413 .34511 Mdot
.3059 .3608 Mdot
.32158 .37256 Mdot
.32158 .3608 Mdot
.29806 .31374 Mdot
.28629 .29021 Mdot
.23139 .22747 Mdot
.13336 .11768 Mdot
.11768 .11376 Mdot
.10199 .09807 Mdot
.07846 .07062 Mdot
.07846 .07846 Mdot
.07062 .07846 Mdot
.0667 .08239 Mdot
.07454 .09415 Mdot
.07846 .10591 Mdot
.07454 .10983 Mdot
.07846 .10983 Mdot
.09807 .12944 Mdot
.10983 .13728 Mdot
.10199 .1216 Mdot
.09415 .10983 Mdot
.09807 .10591 Mdot
.08631 .09415 Mdot
.09807 .10983 Mdot
.08239 .08239 Mdot
.0667 .07062 Mdot
.06278 .06278 Mdot
.0667 .0667 Mdot
.08631 .09023 Mdot
.09807 .10199 Mdot
.10591 .10983 Mdot
.16473 .18042 Mdot
.1961 .21179 Mdot
.28237 .31766 Mdot
.32158 .36864 Mdot
.36472 .42746 Mdot
.38432 .45491 Mdot
.40001 .47059 Mdot
.34511 .39609 Mdot
.24316 .26668 Mdot
.18042 .18434 Mdot
.15297 .14905 Mdot
.15297 .14513 Mdot
.18826 .18042 Mdot
.20787 .20787 Mdot
.22355 .22355 Mdot
.251 .26668 Mdot
.26668 .29021 Mdot
.26276 .30198 Mdot
.26276 .30982 Mdot
.24708 .29806 Mdot
.24708 .30198 Mdot
.251 .31374 Mdot
.25492 .31374 Mdot
.25492 .30982 Mdot
.26276 .30982 Mdot
.251 .29021 Mdot
.25492 .27845 Mdot
.25884 .28237 Mdot
.26276 .28237 Mdot
.24708 .27061 Mdot
.24708 .27453 Mdot
.23139 .25884 Mdot
.23139 .26668 Mdot
.21963 .26276 Mdot
.21179 .251 Mdot
.20787 .25492 Mdot
.20787 .25884 Mdot
.20787 .25492 Mdot
.22747 .26668 Mdot
.22355 .251 Mdot
.23139 .25492 Mdot
.21963 .23531 Mdot
.22747 .24316 Mdot
.21963 .23531 Mdot
.21179 .23531 Mdot
.1961 .22747 Mdot
.19218 .23139 Mdot
.1765 .21179 Mdot
.16865 .20787 Mdot
.17257 .21571 Mdot
.18042 .22747 Mdot
.18434 .22747 Mdot
.18434 .22747 Mdot
.18042 .22355 Mdot
.17257 .21179 Mdot
.1765 .21179 Mdot
.1765 .20002 Mdot
.18434 .20002 Mdot
.18434 .18826 Mdot
.19218 .1961 Mdot
.18434 .18434 Mdot
.18042 .1765 Mdot
.17257 .17257 Mdot
.16865 .1765 Mdot
.16865 .18042 Mdot
.14513 .16081 Mdot
.13336 .14513 Mdot
.81566 .83919 Mdot
.67057 .6941 Mdot
.56862 .60391 Mdot
.52157 .55294 Mdot
.48235 .5098 Mdot
.40001 .42746 Mdot
.3059 .3255 Mdot
.27453 .28629 Mdot
.251 .25884 Mdot
.22747 .22747 Mdot
.23924 .24316 Mdot
.24316 .251 Mdot
.27453 .28629 Mdot
.3059 .32158 Mdot
.32943 .35687 Mdot
.32943 .36472 Mdot
.32158 .36472 Mdot
.3059 .35295 Mdot
.29806 .34511 Mdot
.29413 .34119 Mdot
.32158 .36472 Mdot
.34511 .38432 Mdot
.3608 .38432 Mdot
.34903 .36472 Mdot
.33335 .35295 Mdot
.21963 .22355 Mdot
.1765 .18826 Mdot
.13336 .14513 Mdot
.09415 .10591 Mdot
.08239 .09415 Mdot
.07454 .09023 Mdot
.06278 .08631 Mdot
.05102 .07454 Mdot
.04317 .06278 Mdot
.07062 .09807 Mdot
.10199 .13336 Mdot
.1216 .15689 Mdot
.13728 .17257 Mdot
.13728 .16865 Mdot
.12944 .14905 Mdot
.1216 .13728 Mdot
.11768 .13336 Mdot
.10199 .10983 Mdot
.08631 .09415 Mdot
.0667 .05886 Mdot
.0667 .05494 Mdot
.07846 .0667 Mdot
.08631 .07846 Mdot
.09807 .09023 Mdot
.08631 .07454 Mdot
.07846 .07454 Mdot
.09415 .08631 Mdot
.14905 .15689 Mdot
.19218 .21179 Mdot
.25492 .29806 Mdot
.30982 .37256 Mdot
.35295 .42354 Mdot
.31374 .3804 Mdot
.35295 .41961 Mdot
.25492 .28237 Mdot
.21571 .21963 Mdot
.18434 .16865 Mdot
.18042 .15689 Mdot
.15297 .12944 Mdot
.16865 .15689 Mdot
.20002 .20002 Mdot
.22355 .24316 Mdot
.23924 .27061 Mdot
.24708 .28629 Mdot
.23531 .27845 Mdot
.23531 .28237 Mdot
.23139 .28237 Mdot
.251 .29413 Mdot
.24316 .28237 Mdot
.23924 .27061 Mdot
.23531 .25884 Mdot
.23531 .25884 Mdot
.23531 .26276 Mdot
.23139 .25884 Mdot
.22355 .251 Mdot
.22355 .25492 Mdot
.21571 .251 Mdot
.20394 .24316 Mdot
.21179 .24708 Mdot
.21963 .251 Mdot
.21963 .25492 Mdot
.21571 .25492 Mdot
.22747 .25884 Mdot
.24316 .27061 Mdot
.23924 .26668 Mdot
.23924 .26276 Mdot
.23924 .25884 Mdot
.22355 .23924 Mdot
.21571 .23531 Mdot
.21179 .24316 Mdot
.20394 .23531 Mdot
.19218 .22747 Mdot
.17257 .20787 Mdot
.17257 .20787 Mdot
.16865 .20394 Mdot
.16865 .20787 Mdot
.17257 .21571 Mdot
.18042 .21963 Mdot
.18434 .22747 Mdot
.18042 .22747 Mdot
.17257 .21571 Mdot
.17257 .20787 Mdot
.18434 .21179 Mdot
.1765 .19218 Mdot
.16865 .18042 Mdot
.16473 .1765 Mdot
.16865 .18042 Mdot
.16473 .1765 Mdot
.15689 .17257 Mdot
.15689 .17257 Mdot
.14513 .16081 Mdot
.13336 .14905 Mdot
.92154 .9333 Mdot
.83135 .85095 Mdot
.64705 .6941 Mdot
.5647 .60783 Mdot
.52549 .57646 Mdot
.31766 .33727 Mdot
.23924 .25492 Mdot
.21179 .22747 Mdot
.18434 .19218 Mdot
.17257 .1765 Mdot
.17257 .16865 Mdot
.21179 .21179 Mdot
.29413 .30982 Mdot
.3059 .33335 Mdot
.3255 .3608 Mdot
.33727 .37648 Mdot
.32943 .37256 Mdot
.31374 .35687 Mdot
.31374 .35687 Mdot
.32943 .36472 Mdot
.34903 .3804 Mdot
.35295 .3804 Mdot
.36472 .38824 Mdot
.3608 .38432 Mdot
.33335 .3608 Mdot
.24316 .26668 Mdot
.20002 .22747 Mdot
.14513 .16865 Mdot
.09807 .11768 Mdot
.0667 .08631 Mdot
.04709 .07062 Mdot
.03925 .06278 Mdot
.07062 .10199 Mdot
.10591 .13728 Mdot
.14513 .18434 Mdot
.1765 .21571 Mdot
.18434 .22747 Mdot
.16865 .20394 Mdot
.12944 .16081 Mdot
.11376 .13336 Mdot
.09807 .10591 Mdot
.07846 .08631 Mdot
.07454 .07846 Mdot
.07062 .0667 Mdot
.08631 .07454 Mdot
.10591 .09415 Mdot
.1216 .10983 Mdot
.12552 .11376 Mdot
.12944 .1216 Mdot
.13336 .11768 Mdot
.11768 .10983 Mdot
.13728 .13336 Mdot
.20002 .21179 Mdot
.251 .28237 Mdot
.31766 .36864 Mdot
.13728 .15689 Mdot
.15297 .18434 Mdot
.16473 .20002 Mdot
.26668 .31766 Mdot
.34903 .40001 Mdot
.34119 .36864 Mdot
.32158 .33727 Mdot
.28629 .29413 Mdot
.24708 .251 Mdot
.23139 .24316 Mdot
.23924 .25884 Mdot
.24708 .27061 Mdot
.24708 .27061 Mdot
.23531 .26276 Mdot
.23531 .26668 Mdot
.23531 .26276 Mdot
.23531 .27061 Mdot
.22355 .251 Mdot
.21963 .24708 Mdot
.21963 .24708 Mdot
.21571 .23924 Mdot
.20787 .23531 Mdot
.21179 .23924 Mdot
.21963 .24708 Mdot
.21963 .24708 Mdot
.20787 .23531 Mdot
.20394 .22747 Mdot
.20394 .22747 Mdot
.22355 .24316 Mdot
.23139 .25492 Mdot
.22355 .251 Mdot
.21963 .24708 Mdot
.22355 .25492 Mdot
.22355 .24708 Mdot
.21963 .251 Mdot
.21963 .251 Mdot
.21179 .23924 Mdot
.21179 .24316 Mdot
.21179 .23924 Mdot
.19218 .22355 Mdot
.1765 .20787 Mdot
.1765 .20394 Mdot
.17257 .20002 Mdot
.17257 .20002 Mdot
.16865 .20002 Mdot
.16865 .20394 Mdot
.16865 .20394 Mdot
.16865 .20787 Mdot
.17257 .21179 Mdot
.17257 .20787 Mdot
.17257 .20394 Mdot
.16081 .19218 Mdot
.16473 .18826 Mdot
.16473 .18434 Mdot
.16473 .18826 Mdot
.15297 .17257 Mdot
.16473 .18434 Mdot
.16865 .18434 Mdot
.16473 .18042 Mdot
.15297 .17257 Mdot
.91761 .92938 Mdot
.81566 .84703 Mdot
.48235 .52941 Mdot
.27845 .3059 Mdot
.24316 .26668 Mdot
.21571 .23531 Mdot
.18826 .20002 Mdot
.17257 .1765 Mdot
.16473 .15689 Mdot
.17257 .15689 Mdot
.23139 .23139 Mdot
.26276 .27061 Mdot
.29021 .30982 Mdot
.31374 .34511 Mdot
.32943 .36864 Mdot
.34511 .39217 Mdot
.36472 .41177 Mdot
.34903 .38824 Mdot
.33727 .36864 Mdot
.35295 .3804 Mdot
.34511 .37256 Mdot
.34903 .38432 Mdot
.34119 .3804 Mdot
.3255 .37256 Mdot
.29021 .34119 Mdot
.21571 .25884 Mdot
.11768 .1412 Mdot
.07846 .09415 Mdot
.05886 .07454 Mdot
.09023 .11376 Mdot
.11376 .14905 Mdot
.13336 .16865 Mdot
.15689 .1961 Mdot
.18042 .21963 Mdot
.16865 .20394 Mdot
.1412 .16865 Mdot
.11376 .12552 Mdot
.08631 .08631 Mdot
.06278 .06278 Mdot
.05494 .05494 Mdot
.0667 .07062 Mdot
.07454 .07454 Mdot
.15689 .16865 Mdot
.12944 .13336 Mdot
.11376 .10983 Mdot
.31374 .34903 Mdot
.27845 .30198 Mdot
.15689 .15297 Mdot
.26668 .29413 Mdot
.23924 .25884 Mdot
.21179 .23139 Mdot
.18434 .20394 Mdot
.14905 .16081 Mdot
.09415 .09807 Mdot
.07454 .07454 Mdot
.05886 .05886 Mdot
.22747 .26276 Mdot
.49804 .58039 Mdot
.50588 .58039 Mdot
.4902 .5647 Mdot
.33727 .37256 Mdot
.31766 .35295 Mdot
.30198 .32943 Mdot
.28629 .30982 Mdot
.27845 .29413 Mdot
.25884 .27845 Mdot
.25492 .27845 Mdot
.23924 .27453 Mdot
.24316 .28629 Mdot
.23924 .27845 Mdot
.23531 .26668 Mdot
.22747 .26276 Mdot
.21571 .24708 Mdot
.21571 .24708 Mdot
.20787 .23531 Mdot
.21179 .23139 Mdot
.22355 .24316 Mdot
.21571 .23531 Mdot
.1961 .21571 Mdot
.20394 .21963 Mdot
.20787 .22355 Mdot
.20394 .21963 Mdot
.20394 .22747 Mdot
.20394 .23139 Mdot
.20787 .23924 Mdot
.20002 .23531 Mdot
.1961 .23531 Mdot
.20002 .23924 Mdot
.20002 .24708 Mdot
.1961 .24316 Mdot
.19218 .23531 Mdot
.18042 .21963 Mdot
.18042 .21179 Mdot
.18042 .20787 Mdot
.1765 .20002 Mdot
.1765 .20002 Mdot
.16473 .1961 Mdot
.16081 .19218 Mdot
.15689 .19218 Mdot
.16473 .20394 Mdot
.16473 .20787 Mdot
.16473 .20787 Mdot
.16865 .21179 Mdot
.16865 .21179 Mdot
.16081 .20002 Mdot
.16081 .1961 Mdot
.16473 .19218 Mdot
.16081 .18826 Mdot
.16081 .18042 Mdot
.15689 .1765 Mdot
.16081 .17257 Mdot
.15689 .16865 Mdot
.73724 .76076 Mdot
.54117 .57254 Mdot
.27845 .3059 Mdot
.21963 .23924 Mdot
.21179 .23139 Mdot
.19218 .20002 Mdot
.20787 .20787 Mdot
.1961 .19218 Mdot
.1961 .18826 Mdot
.1961 .18826 Mdot
.20394 .20002 Mdot
.26276 .28237 Mdot
.30982 .34119 Mdot
.34119 .3804 Mdot
.34903 .38824 Mdot
.35687 .39609 Mdot
.34511 .38432 Mdot
.32943 .36472 Mdot
.33335 .37256 Mdot
.34511 .39609 Mdot
.33727 .38824 Mdot
.32158 .3804 Mdot
.33335 .39609 Mdot
.22747 .27061 Mdot
.10199 .1216 Mdot
.10199 .1216 Mdot
.09415 .11376 Mdot
.09415 .11768 Mdot
.10199 .12552 Mdot
.10983 .13336 Mdot
.11768 .1412 Mdot
.12944 .14513 Mdot
.1412 .16081 Mdot
.11768 .13336 Mdot
.07846 .08239 Mdot
.07454 .0667 Mdot
.0667 .06278 Mdot
.05886 .05494 Mdot
.07062 .06278 Mdot
.13728 .1412 Mdot
.08239 .07454 Mdot
.18434 .20002 Mdot
.67057 .78429 Mdot
.65881 .77253 Mdot
.41569 .48628 Mdot
.27845 .32158 Mdot
.27453 .31374 Mdot
.12944 .13728 Mdot
.11768 .1216 Mdot
.08631 .08631 Mdot
.09415 .09415 Mdot
.07454 .07062 Mdot
.07062 .06278 Mdot
.07846 .07062 Mdot
.47059 .54902 Mdot
.58431 .67842 Mdot
.54509 .62744 Mdot
.51765 .59607 Mdot
.41961 .47843 Mdot
.40393 .46275 Mdot
.39217 .44706 Mdot
.38432 .43922 Mdot
.3608 .40393 Mdot
.33335 .3804 Mdot
.31766 .36864 Mdot
.30198 .34511 Mdot
.27845 .32158 Mdot
.27061 .30982 Mdot
.26276 .29413 Mdot
.24708 .27845 Mdot
.23924 .26276 Mdot
.22747 .24708 Mdot
.22355 .23531 Mdot
.22355 .23139 Mdot
.21571 .22747 Mdot
.20394 .21571 Mdot
.20002 .21179 Mdot
.1961 .20787 Mdot
.20002 .21571 Mdot
.19218 .20787 Mdot
.18434 .20394 Mdot
.18434 .21179 Mdot
.17257 .20787 Mdot
.16081 .20002 Mdot
.1765 .21571 Mdot
.16865 .20787 Mdot
.17257 .20787 Mdot
.1765 .21963 Mdot
.1765 .21963 Mdot
.17257 .21571 Mdot
.16865 .20394 Mdot
.16865 .20002 Mdot
.16473 .1961 Mdot
.16473 .1961 Mdot
.16081 .19218 Mdot
.16473 .20394 Mdot
.16865 .20394 Mdot
.16865 .20787 Mdot
.16081 .1961 Mdot
.16865 .20394 Mdot
.16473 .1961 Mdot
.16081 .1961 Mdot
.16081 .1961 Mdot
.16865 .1961 Mdot
.15297 .18042 Mdot
.15297 .16865 Mdot
.14905 .17257 Mdot
.14905 .17257 Mdot
.1412 .16473 Mdot
.63528 .6392 Mdot
.51765 .53333 Mdot
.36472 .38824 Mdot
.29413 .3059 Mdot
.251 .251 Mdot
.23924 .23139 Mdot
.21179 .20002 Mdot
.18042 .16865 Mdot
.16081 .14905 Mdot
.17257 .16473 Mdot
.251 .26668 Mdot
.28629 .3059 Mdot
.34903 .37648 Mdot
.35295 .38824 Mdot
.35295 .39609 Mdot
.29806 .33727 Mdot
.33727 .38432 Mdot
.3059 .34903 Mdot
.29021 .34119 Mdot
.28237 .34119 Mdot
.30198 .36472 Mdot
.21963 .26668 Mdot
.14513 .17257 Mdot
.1216 .14905 Mdot
.11376 .12944 Mdot
.09415 .10983 Mdot
.09807 .10591 Mdot
.09807 .10199 Mdot
.11376 .11376 Mdot
.12552 .12944 Mdot
.1216 .12552 Mdot
.09415 .09807 Mdot
.07846 .07454 Mdot
.07846 .07454 Mdot
.07846 .07454 Mdot
.07062 .06278 Mdot
.08631 .08239 Mdot
.10983 .10983 Mdot
.11376 .11376 Mdot
.38824 .44314 Mdot
.48235 .56078 Mdot
.6941 .82743 Mdot
.41177 .4902 Mdot
.20002 .22355 Mdot
.14905 .16473 Mdot
.11768 .1216 Mdot
.08631 .08239 Mdot
.07062 .05494 Mdot
.07846 .06278 Mdot
.07846 .06278 Mdot
.06278 .05494 Mdot
.21179 .23924 Mdot
.58431 .6941 Mdot
.53333 .62352 Mdot
.52549 .61176 Mdot
.47843 .55294 Mdot
.32943 .37256 Mdot
.35295 .40001 Mdot
.37648 .42746 Mdot
.42746 .48235 Mdot
.4902 .56078 Mdot
.50196 .58039 Mdot
.4902 .56078 Mdot
.46667 .52941 Mdot
.40785 .45491 Mdot
.37648 .40393 Mdot
.35687 .37648 Mdot
.33727 .35687 Mdot
.30982 .32943 Mdot
.27845 .3059 Mdot
.24316 .26668 Mdot
.22747 .251 Mdot
.22355 .23531 Mdot
.21179 .22355 Mdot
.20787 .22355 Mdot
.21571 .23139 Mdot
.20002 .21963 Mdot
.1961 .21963 Mdot
.19218 .21963 Mdot
.18434 .21571 Mdot
.1765 .20787 Mdot
.17257 .20002 Mdot
.18042 .20787 Mdot
.17257 .20002 Mdot
.16473 .20002 Mdot
.1765 .21179 Mdot
.1765 .21179 Mdot
.16473 .19218 Mdot
.18042 .20394 Mdot
.16865 .19218 Mdot
.16473 .18826 Mdot
.16081 .18826 Mdot
.15689 .18826 Mdot
.15689 .19218 Mdot
.14905 .18042 Mdot
.15689 .18826 Mdot
.14905 .17257 Mdot
.15689 .18042 Mdot
.14905 .16865 Mdot
.15297 .17257 Mdot
.14905 .16473 Mdot
.1412 .16081 Mdot
.12944 .15297 Mdot
.1412 .17257 Mdot
.13728 .16865 Mdot
.12944 .16081 Mdot
.90977 .92154 Mdot
.73724 .749 Mdot
.40393 .41177 Mdot
.34903 .35295 Mdot
.21571 .18826 Mdot
.20787 .18434 Mdot
.18042 .16081 Mdot
.15689 .1412 Mdot
.16473 .15689 Mdot
.18826 .18826 Mdot
.22355 .23531 Mdot
.27845 .29806 Mdot
.27453 .30198 Mdot
.20787 .22747 Mdot
.21963 .24708 Mdot
.1961 .22747 Mdot
.17257 .20787 Mdot
.18826 .22355 Mdot
.23139 .27453 Mdot
.25884 .30198 Mdot
.16865 .19218 Mdot
.1765 .19218 Mdot
.1412 .15689 Mdot
.1216 .12944 Mdot
.09807 .10199 Mdot
.09415 .09415 Mdot
.11376 .11376 Mdot
.13336 .13728 Mdot
.12552 .13336 Mdot
.08631 .08631 Mdot
.07454 .08239 Mdot
.07454 .08631 Mdot
.07454 .08631 Mdot
.07846 .07846 Mdot
.11768 .1216 Mdot
.12552 .13336 Mdot
.13728 .14905 Mdot
.13336 .14905 Mdot
.19218 .21963 Mdot
.40393 .47059 Mdot
.39609 .46275 Mdot
.24316 .27845 Mdot
.11768 .1216 Mdot
.14513 .14513 Mdot
.07454 .05494 Mdot
.0667 .04709 Mdot
.05886 .03141 Mdot
.05494 .02357 Mdot
.05886 .04317 Mdot
.27845 .31374 Mdot
.50588 .59607 Mdot
.53333 .62744 Mdot
.49804 .58823 Mdot
.52549 .61176 Mdot
.47451 .54509 Mdot
.41961 .46667 Mdot
.35687 .38432 Mdot
.36472 .40001 Mdot
.54117 .61176 Mdot
.52549 .59607 Mdot
.54117 .61176 Mdot
.57254 .6392 Mdot
.52157 .58431 Mdot
.36864 .39609 Mdot
.39217 .41569 Mdot
.42354 .45491 Mdot
.42746 .46667 Mdot
.40785 .45098 Mdot
.38432 .42746 Mdot
.35687 .39609 Mdot
.3255 .36472 Mdot
.28629 .32158 Mdot
.27061 .29806 Mdot
.251 .27845 Mdot
.24316 .27453 Mdot
.23924 .26668 Mdot
.23139 .26276 Mdot
.21963 .251 Mdot
.1961 .22747 Mdot
.18434 .20002 Mdot
.18042 .20002 Mdot
.1765 .1961 Mdot
.17257 .18826 Mdot
.17257 .18826 Mdot
.1765 .1961 Mdot
.18042 .18826 Mdot
.19218 .1961 Mdot
.19218 .20394 Mdot
.18042 .20002 Mdot
.15297 .17257 Mdot
.1216 .15297 Mdot
.10199 .12552 Mdot
.09023 .11376 Mdot
.09807 .1216 Mdot
.10591 .12944 Mdot
.11768 .13728 Mdot
.1412 .16081 Mdot
.15689 .17257 Mdot
.15297 .16473 Mdot
.1412 .15297 Mdot
.14513 .15689 Mdot
.13336 .15689 Mdot
.12552 .15297 Mdot
.12944 .16081 Mdot
.85095 .85095 Mdot
.6196 .60391 Mdot
.22747 .20394 Mdot
.23139 .21571 Mdot
.21571 .20394 Mdot
.20394 .1961 Mdot
.20787 .20394 Mdot
.20394 .20787 Mdot
.18826 .18826 Mdot
.18042 .18042 Mdot
.16865 .16081 Mdot
.14513 .14513 Mdot
.12552 .13336 Mdot
.13336 .14905 Mdot
.14513 .16081 Mdot
.18826 .20787 Mdot
.21571 .23531 Mdot
.19218 .20787 Mdot
.17257 .18434 Mdot
.1412 .14905 Mdot
.11768 .1216 Mdot
.10591 .10983 Mdot
.10199 .10983 Mdot
.1216 .12552 Mdot
.1412 .14513 Mdot
.11768 .12944 Mdot
.10591 .11768 Mdot
.09023 .09807 Mdot
.09415 .10591 Mdot
.09415 .10591 Mdot
.07846 .09023 Mdot
.07846 .08239 Mdot
.13336 .1412 Mdot
.17257 .19218 Mdot
.20394 .22747 Mdot
.21571 .24708 Mdot
.26276 .29806 Mdot
.28237 .32158 Mdot
.26276 .29413 Mdot
.11376 .11768 Mdot
.12944 .13728 Mdot
.10591 .09807 Mdot
.09023 .07062 Mdot
.07846 .05494 Mdot
.0667 .04317 Mdot
.05886 .04317 Mdot
.21963 .22355 Mdot
.42746 .48235 Mdot
.44314 .51765 Mdot
.48628 .57254 Mdot
.5098 .59215 Mdot
.53725 .61176 Mdot
.54117 .61176 Mdot
.50196 .56862 Mdot
.48628 .54509 Mdot
.4902 .56078 Mdot
.5098 .58431 Mdot
.52157 .58823 Mdot
.51765 .58039 Mdot
.57646 .64705 Mdot
.51765 .57646 Mdot
.33335 .3608 Mdot
.34511 .37256 Mdot
.31766 .33727 Mdot
.45491 .50196 Mdot
.52157 .58431 Mdot
.36864 .40393 Mdot
.34903 .38432 Mdot
.35295 .39609 Mdot
.3804 .42746 Mdot
.38824 .43922 Mdot
.39217 .44314 Mdot
.3804 .4353 Mdot
.36864 .41177 Mdot
.34903 .38432 Mdot
.30982 .33727 Mdot
.27061 .29021 Mdot
.22355 .22747 Mdot
.20394 .20787 Mdot
.20394 .21179 Mdot
.19218 .20394 Mdot
.1765 .18434 Mdot
.18826 .19218 Mdot
.1961 .1961 Mdot
.18434 .18826 Mdot
.17257 .18434 Mdot
.13336 .14513 Mdot
.09807 .10983 Mdot
.05886 .07454 Mdot
.03533 .04709 Mdot
.02357 .03141 Mdot
.03533 .04317 Mdot
.03533 .04709 Mdot
.09023 .10983 Mdot
.11376 .13728 Mdot
.13336 .15297 Mdot
.1412 .15297 Mdot
.1412 .14905 Mdot
.1412 .15297 Mdot
.12552 .1412 Mdot
.11768 .13728 Mdot
.65097 .65097 Mdot
.54902 .56862 Mdot
.30198 .31374 Mdot
.28629 .30198 Mdot
.26668 .27845 Mdot
.24708 .24708 Mdot
.1961 .18826 Mdot
.18434 .1765 Mdot
.16473 .16081 Mdot
.15689 .15297 Mdot
.14905 .15689 Mdot
.15297 .16473 Mdot
.18434 .19218 Mdot
.23139 .23924 Mdot
.22355 .23139 Mdot
.19218 .19218 Mdot
.15689 .15689 Mdot
.13336 .13728 Mdot
.11376 .11768 Mdot
.11768 .12552 Mdot
.14513 .15297 Mdot
.15689 .16865 Mdot
.14513 .15297 Mdot
.13336 .14905 Mdot
.11768 .12944 Mdot
.10591 .11376 Mdot
.10591 .11768 Mdot
.07062 .07846 Mdot
.0667 .0667 Mdot
.07846 .07454 Mdot
.09807 .10591 Mdot
.15297 .1765 Mdot
.20394 .23139 Mdot
.27845 .32158 Mdot
.27061 .30982 Mdot
.21571 .24316 Mdot
.17257 .1961 Mdot
.14513 .15689 Mdot
.12552 .12944 Mdot
.11376 .11376 Mdot
.10983 .10591 Mdot
.09807 .09415 Mdot
.10199 .10199 Mdot
.09415 .09807 Mdot
.16081 .1765 Mdot
.251 .28237 Mdot
.29806 .33335 Mdot
.36472 .40001 Mdot
.60391 .67842 Mdot
.57646 .64313 Mdot
.57646 .64705 Mdot
.57254 .64313 Mdot
.56078 .62744 Mdot
.55294 .62352 Mdot
.54902 .6196 Mdot
.53725 .59999 Mdot
.53333 .59999 Mdot
.53725 .60783 Mdot
.47451 .53725 Mdot
.43138 .47843 Mdot
.39609 .43138 Mdot
.38824 .42746 Mdot
.62744 .71371 Mdot
.55686 .6392 Mdot
.35687 .40001 Mdot
.35687 .40393 Mdot
.32943 .36864 Mdot
.3255 .3608 Mdot
.43138 .49412 Mdot
.47059 .54117 Mdot
.48628 .56078 Mdot
.4902 .5647 Mdot
.47451 .54509 Mdot
.42354 .47843 Mdot
.38824 .43138 Mdot
.36864 .40393 Mdot
.33335 .3608 Mdot
.30198 .32158 Mdot
.28237 .30198 Mdot
.26668 .27845 Mdot
.23924 .24708 Mdot
.20787 .21963 Mdot
.18826 .20787 Mdot
.15689 .17257 Mdot
.09415 .10591 Mdot
.05102 .0667 Mdot
.03533 .04709 Mdot
.01965 .02749 Mdot
.01965 .02749 Mdot
.0118 .01965 Mdot
.00788 .01572 Mdot
.03533 .04317 Mdot
.05494 .0667 Mdot
.08631 .09807 Mdot
.11768 .12944 Mdot
.13728 .15297 Mdot
.13728 .16081 Mdot
.14513 .1765 Mdot
.749 .76861 Mdot
.59607 .6196 Mdot
.34903 .3608 Mdot
.26276 .26276 Mdot
.25884 .26668 Mdot
.23139 .24316 Mdot
.23531 .24708 Mdot
.21571 .22747 Mdot
.21179 .22355 Mdot
.20787 .21571 Mdot
.23531 .23139 Mdot
.24316 .23531 Mdot
.21963 .21571 Mdot
.1765 .1765 Mdot
.14905 .14905 Mdot
.1216 .1216 Mdot
.1216 .1216 Mdot
.13728 .1412 Mdot
.15689 .16081 Mdot
.16865 .18042 Mdot
.18042 .19218 Mdot
.16865 .18434 Mdot
.12552 .13728 Mdot
.10591 .11376 Mdot
.0667 .07062 Mdot
.05886 .07062 Mdot
.05494 .0667 Mdot
.07062 .08239 Mdot
.08631 .10199 Mdot
.14513 .16473 Mdot
.15689 .18434 Mdot
.16473 .18826 Mdot
.1765 .1961 Mdot
.14905 .16473 Mdot
.12944 .13336 Mdot
.11768 .11768 Mdot
.10591 .09807 Mdot
.1216 .1216 Mdot
.10591 .10591 Mdot
.23139 .26276 Mdot
.21963 .24316 Mdot
.24708 .28237 Mdot
.27061 .30982 Mdot
.28629 .32158 Mdot
.251 .26276 Mdot
.38432 .40785 Mdot
.60391 .67057 Mdot
.53333 .59215 Mdot
.57254 .6392 Mdot
.53725 .59999 Mdot
.5647 .63136 Mdot
.55686 .63136 Mdot
.54902 .62352 Mdot
.55294 .63136 Mdot
.54902 .62744 Mdot
.52549 .60783 Mdot
.52157 .59607 Mdot
.50196 .57646 Mdot
.48628 .56078 Mdot
.47843 .55294 Mdot
.49804 .57646 Mdot
.48235 .55686 Mdot
.47843 .55294 Mdot
.43922 .5098 Mdot
.42746 .4902 Mdot
.42354 .48628 Mdot
.45098 .52157 Mdot
.46667 .53333 Mdot
.47843 .54902 Mdot
.48235 .55686 Mdot
.48628 .55294 Mdot
.48235 .55294 Mdot
.49412 .56078 Mdot
.4902 .54902 Mdot
.46667 .51372 Mdot
.44314 .4902 Mdot
.42746 .47843 Mdot
.39609 .44706 Mdot
.35687 .40393 Mdot
.29413 .33727 Mdot
.15297 .1765 Mdot
.11768 .13728 Mdot
.09023 .10199 Mdot
.04317 .04709 Mdot
.02749 .03141 Mdot
.01572 .01965 Mdot
.00788 .0118 Mdot
.00788 .0118 Mdot
.00396 .0118 Mdot
.00396 .0118 Mdot
.01572 .01572 Mdot
.08631 .09415 Mdot
.12944 .14513 Mdot
.1412 .16081 Mdot
.14513 .16473 Mdot
.88232 .89017 Mdot
.62744 .62352 Mdot
.37256 .3804 Mdot
.4353 .46667 Mdot
.43922 .47451 Mdot
.35687 .3804 Mdot
.31766 .33727 Mdot
.27845 .29413 Mdot
.27061 .27845 Mdot
.26276 .26276 Mdot
.21571 .20394 Mdot
.19218 .18434 Mdot
.16865 .16473 Mdot
.14905 .14513 Mdot
.12552 .12552 Mdot
.12552 .12552 Mdot
.1412 .14513 Mdot
.15297 .15297 Mdot
.16865 .1765 Mdot
.17257 .18434 Mdot
.13728 .14513 Mdot
.11768 .11768 Mdot
.09023 .09023 Mdot
.07846 .07846 Mdot
.07062 .08239 Mdot
.07062 .08631 Mdot
.09023 .10983 Mdot
.10983 .13336 Mdot
.13728 .16865 Mdot
.15689 .18434 Mdot
.16081 .19218 Mdot
.12944 .14905 Mdot
.11768 .12552 Mdot
.10983 .10199 Mdot
.10199 .09415 Mdot
.09415 .08631 Mdot
.12552 .12552 Mdot
.24316 .26668 Mdot
.40393 .46667 Mdot
.39217 .46667 Mdot
.39609 .47059 Mdot
.41177 .47843 Mdot
.36472 .41177 Mdot
.27061 .27845 Mdot
.75292 .85095 Mdot
.46667 .52549 Mdot
.46667 .53333 Mdot
.35687 .40393 Mdot
.37256 .41569 Mdot
.48628 .56078 Mdot
.52157 .59215 Mdot
.53725 .61176 Mdot
.54902 .63136 Mdot
.53333 .61568 Mdot
.54902 .6392 Mdot
.33335 .38824 Mdot
.39609 .46275 Mdot
.5098 .58431 Mdot
.47059 .54509 Mdot
.47059 .54117 Mdot
.48628 .56862 Mdot
.50196 .58823 Mdot
.50196 .59215 Mdot
.49804 .58823 Mdot
.46667 .54509 Mdot
.46667 .53333 Mdot
.45883 .51765 Mdot
.46275 .51372 Mdot
.45098 .5098 Mdot
.45491 .51765 Mdot
.45883 .52549 Mdot
.47059 .52549 Mdot
.46667 .51765 Mdot
.47059 .52157 Mdot
.46667 .52157 Mdot
.46667 .52157 Mdot
.46667 .52549 Mdot
.48235 .55686 Mdot
.22747 .25492 Mdot
.07454 .08239 Mdot
.05102 .05494 Mdot
.00788 .00788 Mdot
.00396 .00788 Mdot
.00396 .00788 Mdot
.00396 .00788 Mdot
.00396 .00788 Mdot
.00396 .0118 Mdot
.0118 .02357 Mdot
.04317 .05102 Mdot
.06278 .07454 Mdot
.09415 .10983 Mdot
.1412 .16081 Mdot
.15297 .16865 Mdot
.90585 .91369 Mdot
.75292 .78037 Mdot
.6196 .65097 Mdot
.54117 .56862 Mdot
.46667 .48628 Mdot
.34119 .34119 Mdot
.32158 .31374 Mdot
.27453 .25884 Mdot
.22355 .21179 Mdot
.20002 .20002 Mdot
.16473 .16865 Mdot
.14905 .15297 Mdot
.15689 .15689 Mdot
.16473 .17257 Mdot
.16473 .17257 Mdot
.15689 .16473 Mdot
.13336 .13728 Mdot
.11768 .1216 Mdot
.10199 .09807 Mdot
.10199 .09807 Mdot
.07846 .08239 Mdot
.09023 .10199 Mdot
.11376 .13336 Mdot
.13728 .16473 Mdot
.14513 .17257 Mdot
.16865 .19218 Mdot
.17257 .1961 Mdot
.18042 .21179 Mdot
.16865 .19218 Mdot
.14513 .16081 Mdot
.1412 .14513 Mdot
.12552 .12944 Mdot
.11768 .11376 Mdot
.10199 .09807 Mdot
.31766 .36864 Mdot
.65489 .78037 Mdot
.46275 .55294 Mdot
.33335 .40001 Mdot
.33335 .38824 Mdot
.251 .27845 Mdot
.27453 .29806 Mdot
.53333 .60783 Mdot
.44314 .51372 Mdot
.45883 .54509 Mdot
.37648 .44314 Mdot
.35687 .41569 Mdot
.44706 .51765 Mdot
.49804 .57646 Mdot
.51372 .59607 Mdot
.52549 .60783 Mdot
.53333 .61176 Mdot
.55294 .64313 Mdot
.251 .27845 Mdot
.29806 .32943 Mdot
.64313 .74116 Mdot
.23924 .251 Mdot
.3608 .40393 Mdot
.59607 .68626 Mdot
.43922 .5098 Mdot
.42354 .50196 Mdot
.45098 .53725 Mdot
.47451 .54902 Mdot
.45883 .52157 Mdot
.44706 .50196 Mdot
.45491 .50588 Mdot
.44706 .49412 Mdot
.45491 .5098 Mdot
.45491 .51372 Mdot
.45491 .51765 Mdot
.45491 .5098 Mdot
.45491 .5098 Mdot
.4353 .48628 Mdot
.4353 .48235 Mdot
.43138 .48235 Mdot
.42354 .47843 Mdot
.20002 .21179 Mdot
.05886 .04709 Mdot
.02749 .0118 Mdot
.01965 .0118 Mdot
.0118 .00788 Mdot
.00788 .00788 Mdot
.00396 .00396 Mdot
.00396 .00788 Mdot
.00788 .01572 Mdot
.03533 .04317 Mdot
.10199 .10983 Mdot
.11768 .12944 Mdot
.13336 .15297 Mdot
.13728 .16473 Mdot
.1412 .16473 Mdot
.8588 .8784 Mdot
.75292 .77253 Mdot
.56862 .58431 Mdot
.51765 .53333 Mdot
.33335 .32943 Mdot
.27453 .27845 Mdot
.24708 .25884 Mdot
.21571 .23924 Mdot
.18826 .20394 Mdot
.18826 .19218 Mdot
.18434 .18042 Mdot
.17257 .1765 Mdot
.15689 .16081 Mdot
.13336 .13336 Mdot
.1216 .12552 Mdot
.10983 .11768 Mdot
.10199 .10591 Mdot
.09807 .10591 Mdot
.11376 .1216 Mdot
.13728 .14905 Mdot
.1765 .1961 Mdot
.18042 .20002 Mdot
.18826 .21179 Mdot
.18826 .20394 Mdot
.18826 .20394 Mdot
.18826 .20787 Mdot
.18042 .1961 Mdot
.1765 .19218 Mdot
.15297 .16081 Mdot
.10591 .10983 Mdot
.09807 .10199 Mdot
.08631 .09415 Mdot
.24316 .28629 Mdot
.33335 .39609 Mdot
.21963 .24708 Mdot
.22355 .24708 Mdot
.18042 .20002 Mdot
.17257 .19218 Mdot
.16865 .18826 Mdot
.14513 .16473 Mdot
.44706 .53725 Mdot
.39217 .46667 Mdot
.39217 .45883 Mdot
.43138 .49804 Mdot
.45883 .52549 Mdot
.46667 .54117 Mdot
.47451 .55294 Mdot
.48628 .5647 Mdot
.50196 .58823 Mdot
.41961 .48235 Mdot
.44706 .5098 Mdot
.58431 .67057 Mdot
.23531 .251 Mdot
.29021 .31766 Mdot
.62744 .72939 Mdot
.54509 .62744 Mdot
.40785 .46667 Mdot
.51765 .59607 Mdot
.46667 .52549 Mdot
.26668 .27453 Mdot
.34119 .36472 Mdot
.47843 .51765 Mdot
.44314 .48628 Mdot
.42354 .47451 Mdot
.4353 .49412 Mdot
.44314 .50588 Mdot
.44706 .50196 Mdot
.45883 .52157 Mdot
.4353 .50196 Mdot
.42746 .48628 Mdot
.39217 .43922 Mdot
.3059 .34511 Mdot
.18434 .20394 Mdot
.07454 .07062 Mdot
.05494 .04709 Mdot
.04317 .03141 Mdot
.02749 .01572 Mdot
.02749 .01965 Mdot
.0118 .00788 Mdot
.0118 .01572 Mdot
.03533 .04317 Mdot
.06278 .07454 Mdot
.13336 .14905 Mdot
.15689 .18042 Mdot
.16081 .18826 Mdot
.16473 .1961 Mdot
.16473 .20002 Mdot
.83527 .8588 Mdot
.58039 .6196 Mdot
.31766 .31374 Mdot
.34119 .34903 Mdot
.30982 .31766 Mdot
.28629 .29413 Mdot
.27453 .27453 Mdot
.251 .24708 Mdot
.22355 .21571 Mdot
.18826 .18042 Mdot
.15297 .15297 Mdot
.13728 .14513 Mdot
.12944 .13728 Mdot
.11768 .12944 Mdot
.11768 .12552 Mdot
.13336 .13728 Mdot
.15689 .17257 Mdot
.19218 .20787 Mdot
.21571 .22355 Mdot
.22355 .23139 Mdot
.21179 .21963 Mdot
.21571 .21963 Mdot
.20002 .20394 Mdot
.18434 .18826 Mdot
.17257 .1765 Mdot
.18434 .1961 Mdot
.15297 .16081 Mdot
.11768 .12552 Mdot
.10591 .11376 Mdot
.09023 .09415 Mdot
.09023 .09807 Mdot
.11376 .11768 Mdot
.10983 .10983 Mdot
.10591 .10983 Mdot
.12552 .13728 Mdot
.13336 .14905 Mdot
.10199 .11768 Mdot
.23139 .27453 Mdot
.3608 .42354 Mdot
.39609 .45883 Mdot
.52549 .61568 Mdot
.41961 .4902 Mdot
.33335 .38432 Mdot
.27453 .31374 Mdot
.33727 .38824 Mdot
.38824 .45883 Mdot
.44314 .52941 Mdot
.44706 .52941 Mdot
.47059 .55686 Mdot
.41569 .4902 Mdot
.41177 .48628 Mdot
.47843 .56862 Mdot
.58039 .68234 Mdot
.53725 .62744 Mdot
.53725 .61176 Mdot
.40001 .4353 Mdot
.15689 .13728 Mdot
.18042 .1765 Mdot
.56862 .65097 Mdot
.3255 .3608 Mdot
.25492 .27061 Mdot
.38824 .44314 Mdot
.45883 .53725 Mdot
.34119 .38824 Mdot
.31374 .34903 Mdot
.3804 .4353 Mdot
.40393 .46667 Mdot
.39217 .45491 Mdot
.29806 .35295 Mdot
.15297 .1765 Mdot
.09807 .10983 Mdot
.0667 .06278 Mdot
.03925 .03141 Mdot
.03141 .02357 Mdot
.02749 .01965 Mdot
.01965 .01572 Mdot
.0118 .00788 Mdot
.11376 .13728 Mdot
.16081 .18826 Mdot
.16865 .1961 Mdot
.17257 .20002 Mdot
.16865 .19218 Mdot
.15689 .17257 Mdot
.15297 .17257 Mdot
.87448 .8784 Mdot
.72939 .72547 Mdot
.5647 .57646 Mdot
.58039 .61176 Mdot
.49804 .51765 Mdot
.36472 .3608 Mdot
.26668 .251 Mdot
.23531 .23139 Mdot
.18042 .18434 Mdot
.16473 .18042 Mdot
.15689 .17257 Mdot
.15297 .16473 Mdot
.15689 .16081 Mdot
.16081 .15689 Mdot
.16865 .17257 Mdot
.20787 .21571 Mdot
.24316 .25492 Mdot
.25492 .26668 Mdot
.23924 .251 Mdot
.21571 .22747 Mdot
.18826 .20002 Mdot
.17257 .18042 Mdot
.15689 .16473 Mdot
.1412 .14905 Mdot
.14905 .16473 Mdot
.13336 .14905 Mdot
.1216 .13728 Mdot
.09807 .11376 Mdot
.11768 .12552 Mdot
.10199 .10591 Mdot
.08631 .08631 Mdot
.10591 .10983 Mdot
.1216 .12944 Mdot
.13336 .14513 Mdot
.1216 .13336 Mdot
.09415 .10983 Mdot
.1412 .16473 Mdot
.16865 .20002 Mdot
.26276 .31766 Mdot
.26668 .32158 Mdot
.26668 .31766 Mdot
.18826 .20787 Mdot
.1765 .20002 Mdot
.1765 .1961 Mdot
.27845 .32943 Mdot
.34119 .40785 Mdot
.39217 .46667 Mdot
.3255 .38824 Mdot
.29021 .34511 Mdot
.44314 .52941 Mdot
.45098 .53725 Mdot
.47059 .55686 Mdot
.48628 .56862 Mdot
.45098 .5098 Mdot
.18042 .1765 Mdot
.20394 .22355 Mdot
.45883 .54509 Mdot
.48628 .57646 Mdot
.25884 .29806 Mdot
.41569 .47843 Mdot
.44706 .51765 Mdot
.24708 .27453 Mdot
.08631 .07454 Mdot
.19218 .20394 Mdot
.43138 .49804 Mdot
.3059 .35295 Mdot
.20787 .24316 Mdot
.18826 .22355 Mdot
.10983 .12552 Mdot
.09415 .10983 Mdot
.05102 .05886 Mdot
.02749 .03533 Mdot
.02749 .03533 Mdot
.01965 .03141 Mdot
.02357 .03141 Mdot
.16473 .20787 Mdot
.251 .31374 Mdot
.24708 .29806 Mdot
.1961 .23531 Mdot
.17257 .20787 Mdot
.15689 .18042 Mdot
.14905 .16081 Mdot
.93722 .94898 Mdot
.78429 .81958 Mdot
.60783 .63528 Mdot
.27061 .24708 Mdot
.30982 .30982 Mdot
.25884 .26668 Mdot
.23924 .251 Mdot
.22747 .24708 Mdot
.23139 .251 Mdot
.23531 .24316 Mdot
.23531 .24316 Mdot
.22355 .22747 Mdot
.23531 .251 Mdot
.28629 .30982 Mdot
.30198 .32943 Mdot
.23924 .25884 Mdot
.22747 .24316 Mdot
.21571 .23531 Mdot
.18042 .1961 Mdot
.16473 .1765 Mdot
.15689 .16865 Mdot
.16473 .18042 Mdot
.16081 .1765 Mdot
.14513 .16081 Mdot
.13336 .15297 Mdot
.1412 .15297 Mdot
.1216 .12944 Mdot
.09415 .09415 Mdot
.12944 .1412 Mdot
.1412 .15689 Mdot
.15297 .16473 Mdot
.13336 .1412 Mdot
.11768 .12944 Mdot
.10199 .11376 Mdot
.09415 .10591 Mdot
.12944 .15297 Mdot
.15297 .16865 Mdot
.15689 .16473 Mdot
.14905 .16081 Mdot
.1412 .15297 Mdot
.13336 .14905 Mdot
.14513 .16081 Mdot
.16081 .18826 Mdot
.41177 .49804 Mdot
.29806 .35295 Mdot
.20787 .23139 Mdot
.16473 .18042 Mdot
.31374 .35687 Mdot
.3255 .36864 Mdot
.3608 .41177 Mdot
.45883 .52941 Mdot
.47451 .56078 Mdot
.34903 .41177 Mdot
.36864 .44314 Mdot
.41177 .48628 Mdot
.42746 .50588 Mdot
.43922 .5098 Mdot
.43138 .49804 Mdot
.31766 .35295 Mdot
.17257 .1765 Mdot
.30982 .33727 Mdot
.34119 .37648 Mdot
.34511 .38824 Mdot
.25492 .28629 Mdot
.10591 .1216 Mdot
.10983 .12944 Mdot
.08239 .10199 Mdot
.05494 .0667 Mdot
.03925 .04709 Mdot
.02749 .03533 Mdot
.03533 .04709 Mdot
.05494 .07062 Mdot
.07454 .09807 Mdot
.251 .31374 Mdot
.28629 .35687 Mdot
.23531 .28237 Mdot
.20787 .251 Mdot
.16865 .20002 Mdot
.13336 .16081 Mdot
.8039 .81566 Mdot
.59999 .60391 Mdot
.54902 .57646 Mdot
.47059 .4902 Mdot
.41177 .4353 Mdot
.39609 .41177 Mdot
.37256 .38432 Mdot
.35295 .36472 Mdot
.3059 .31766 Mdot
.27845 .30198 Mdot
.27453 .28237 Mdot
.26668 .27845 Mdot
.251 .26276 Mdot
.23531 .23924 Mdot
.21963 .22355 Mdot
.21179 .21963 Mdot
.20787 .21963 Mdot
.21179 .21963 Mdot
.19218 .20394 Mdot
.18042 .1961 Mdot
.18434 .20002 Mdot
.1765 .1961 Mdot
.16865 .18826 Mdot
.13336 .14513 Mdot
.10591 .10591 Mdot
.10983 .10983 Mdot
.12552 .13336 Mdot
.13728 .14905 Mdot
.12552 .13336 Mdot
.10983 .11768 Mdot
.08631 .09415 Mdot
.12944 .13728 Mdot
.18826 .20787 Mdot
.18042 .1961 Mdot
.16081 .1765 Mdot
.12552 .12552 Mdot
.11768 .11768 Mdot
.10983 .11768 Mdot
.11768 .1412 Mdot
.10983 .12944 Mdot
.15689 .18434 Mdot
.1961 .23139 Mdot
.20787 .23924 Mdot
.18826 .21179 Mdot
.15689 .1765 Mdot
.13728 .14513 Mdot
.13336 .1412 Mdot
.18826 .20394 Mdot
.38432 .44706 Mdot
.27453 .31766 Mdot
.24316 .28237 Mdot
.28237 .32158 Mdot
.36472 .42354 Mdot
.40001 .47059 Mdot
.41177 .48628 Mdot
.41569 .48628 Mdot
.38824 .44314 Mdot
.41569 .47059 Mdot
.33335 .3608 Mdot
.27453 .30198 Mdot
.30982 .3608 Mdot
.10591 .12552 Mdot
.09415 .11376 Mdot
.05494 .07062 Mdot
.04317 .05494 Mdot
.03533 .04317 Mdot
.03925 .03925 Mdot
.07062 .07454 Mdot
.0667 .07062 Mdot
.05494 .05886 Mdot
.07846 .09023 Mdot
.09415 .11376 Mdot
.1216 .14513 Mdot
.21571 .25884 Mdot
.20002 .23924 Mdot
.15689 .18434 Mdot
.81958 .83919 Mdot
.65097 .69018 Mdot
.53333 .55686 Mdot
.4902 .5098 Mdot
.39609 .40785 Mdot
.34511 .35687 Mdot
.3255 .33335 Mdot
.29413 .29413 Mdot
.28237 .28237 Mdot
.25884 .25884 Mdot
.251 .251 Mdot
.23924 .23531 Mdot
.30198 .31766 Mdot
.30198 .3255 Mdot
.28237 .3059 Mdot
.25492 .27061 Mdot
.21571 .22747 Mdot
.1961 .21179 Mdot
.1765 .19218 Mdot
.17257 .18826 Mdot
.15297 .16473 Mdot
.12552 .13728 Mdot
.10983 .11376 Mdot
.12944 .1412 Mdot
.1412 .15689 Mdot
.13728 .14905 Mdot
.11768 .12944 Mdot
.10199 .10591 Mdot
.14905 .15689 Mdot
.16865 .18042 Mdot
.16865 .18434 Mdot
.16473 .17257 Mdot
.15297 .15689 Mdot
.12944 .13336 Mdot
.12552 .13336 Mdot
.10591 .11768 Mdot
.10591 .11376 Mdot
.07846 .07846 Mdot
.09415 .09415 Mdot
.10983 .11768 Mdot
.13728 .14513 Mdot
.12552 .13336 Mdot
.09807 .10199 Mdot
.08631 .09415 Mdot
.08239 .08239 Mdot
.22355 .25492 Mdot
.3255 .3804 Mdot
.12552 .1412 Mdot
.14513 .17257 Mdot
.14513 .16865 Mdot
.18434 .22355 Mdot
.32158 .38432 Mdot
.3804 .45098 Mdot
.39217 .45883 Mdot
.38824 .44706 Mdot
.37256 .43922 Mdot
.20394 .24316 Mdot
.22355 .27453 Mdot
.21571 .26668 Mdot
.10199 .12552 Mdot
.0667 .08239 Mdot
.07062 .08631 Mdot
.07062 .07454 Mdot
.07062 .06278 Mdot
.07062 .06278 Mdot
.0667 .05494 Mdot
.05102 .03925 Mdot
.04709 .03533 Mdot
.04317 .03533 Mdot
.04317 .03533 Mdot
.09023 .09023 Mdot
.11376 .11768 Mdot
.14905 .16473 Mdot
.91761 .92938 Mdot
.80782 .83135 Mdot
.58431 .62744 Mdot
.45098 .46667 Mdot
.4353 .45098 Mdot
.38824 .38824 Mdot
.34119 .33335 Mdot
.3059 .30198 Mdot
.29021 .29021 Mdot
.25884 .25884 Mdot
.35295 .39217 Mdot
.40785 .47059 Mdot
.41177 .47843 Mdot
.39217 .44706 Mdot
.20002 .20787 Mdot
.17257 .17257 Mdot
.15297 .14905 Mdot
.13336 .13336 Mdot
.13728 .13728 Mdot
.13728 .13728 Mdot
.13336 .13728 Mdot
.14905 .15689 Mdot
.14905 .16081 Mdot
.13336 .15297 Mdot
.11768 .13336 Mdot
.12552 .13728 Mdot
.21571 .24708 Mdot
.21963 .24708 Mdot
.18434 .20002 Mdot
.17257 .18042 Mdot
.15297 .16081 Mdot
.15689 .15689 Mdot
.16473 .1765 Mdot
.14513 .15297 Mdot
.10591 .10983 Mdot
.08239 .08239 Mdot
.0667 .06278 Mdot
.10199 .10591 Mdot
.12552 .12552 Mdot
.10199 .09807 Mdot
.07062 .06278 Mdot
.05494 .05102 Mdot
.05102 .04709 Mdot
.10199 .10983 Mdot
.33335 .39217 Mdot
.16081 .18826 Mdot
.15689 .18826 Mdot
.1216 .14513 Mdot
.10199 .12552 Mdot
.09023 .10591 Mdot
.17257 .21571 Mdot
.21179 .25492 Mdot
.1765 .20002 Mdot
.21179 .24316 Mdot
.251 .29806 Mdot
.31374 .37648 Mdot
.27845 .32943 Mdot
.05102 .05494 Mdot
.08631 .09415 Mdot
.10591 .11768 Mdot
.09415 .10591 Mdot
.10591 .10983 Mdot
.09023 .08631 Mdot
.0667 .05494 Mdot
.04317 .02357 Mdot
.04709 .02749 Mdot
.04317 .01965 Mdot
.05102 .02357 Mdot
.05102 .03141 Mdot
.05494 .03925 Mdot
.10591 .10983 Mdot
.91761 .92546 Mdot
.70979 .73332 Mdot
.62352 .65489 Mdot
.42354 .41961 Mdot
.37256 .37256 Mdot
.34511 .34511 Mdot
.3255 .32943 Mdot
.27061 .27453 Mdot
.27453 .29413 Mdot
.32158 .3608 Mdot
.27061 .3059 Mdot
.20394 .22355 Mdot
.18042 .20394 Mdot
.16473 .18042 Mdot
.13728 .1412 Mdot
.12944 .13336 Mdot
.13728 .13728 Mdot
.16473 .1765 Mdot
.16865 .18826 Mdot
.16865 .18826 Mdot
.16865 .18826 Mdot
.13728 .15297 Mdot
.14513 .16081 Mdot
.29413 .34119 Mdot
.25884 .3059 Mdot
.21179 .251 Mdot
.1961 .22747 Mdot
.19218 .21571 Mdot
.18434 .20394 Mdot
.18434 .20394 Mdot
.1412 .14905 Mdot
.10199 .10199 Mdot
.0667 .05886 Mdot
.07062 .07062 Mdot
.09807 .10199 Mdot
.11768 .1216 Mdot
.11376 .1216 Mdot
.08631 .09023 Mdot
.0667 .06278 Mdot
.04709 .04317 Mdot
.04317 .03925 Mdot
.09023 .09415 Mdot
.09807 .10983 Mdot
.09415 .10591 Mdot
.07846 .09415 Mdot
.07454 .09415 Mdot
.07846 .10199 Mdot
.10983 .13728 Mdot
.10983 .13728 Mdot
.10199 .12944 Mdot
.09807 .11768 Mdot
.08631 .10199 Mdot
.14513 .16081 Mdot
.16081 .1765 Mdot
.11768 .12552 Mdot
.1412 .15689 Mdot
.13336 .14905 Mdot
.12944 .1412 Mdot
.21179 .23531 Mdot
.16865 .18434 Mdot
.14905 .15689 Mdot
.12552 .1216 Mdot
.12552 .10983 Mdot
.10983 .09023 Mdot
.09415 .07062 Mdot
.07454 .04709 Mdot
.06278 .03925 Mdot
.07454 .05886 Mdot
.83527 .85487 Mdot
.63528 .64705 Mdot
.40393 .40393 Mdot
.40393 .41177 Mdot
.32158 .32158 Mdot
.30198 .3059 Mdot
.28237 .28629 Mdot
.24708 .25884 Mdot
.21963 .23924 Mdot
.18434 .1961 Mdot
.16081 .16865 Mdot
.15297 .16081 Mdot
.13336 .1412 Mdot
.15297 .16865 Mdot
.1765 .1961 Mdot
.19218 .21571 Mdot
.18434 .20394 Mdot
.18042 .1961 Mdot
.1765 .18042 Mdot
.1765 .1765 Mdot
.20394 .21571 Mdot
.20394 .22355 Mdot
.20002 .22355 Mdot
.1961 .22355 Mdot
.19218 .22355 Mdot
.20002 .23531 Mdot
.18434 .21571 Mdot
.14513 .16865 Mdot
.13336 .1412 Mdot
.10983 .10983 Mdot
.09807 .10199 Mdot
.10983 .1216 Mdot
.1216 .1412 Mdot
.10591 .1216 Mdot
.09023 .10983 Mdot
.06278 .07454 Mdot
.0667 .08239 Mdot
.05886 .0667 Mdot
.07454 .07846 Mdot
.09023 .10199 Mdot
.09807 .11376 Mdot
.08239 .09807 Mdot
.0667 .08239 Mdot
.07062 .08631 Mdot
.09023 .11376 Mdot
.09023 .10983 Mdot
.08239 .10199 Mdot
.08631 .09807 Mdot
.08631 .09807 Mdot
.07454 .08239 Mdot
.09807 .10591 Mdot
.09807 .11376 Mdot
.10983 .12944 Mdot
.09807 .11376 Mdot
.10199 .11376 Mdot
.14513 .16865 Mdot
.20394 .23139 Mdot
.20394 .23139 Mdot
.16081 .17257 Mdot
.20394 .20787 Mdot
.23139 .22747 Mdot
.18434 .16865 Mdot
.17257 .16081 Mdot
.15297 .14513 Mdot
.11768 .11376 Mdot
.79998 .81958 Mdot
.51372 .54117 Mdot
.41569 .42746 Mdot
.3804 .38824 Mdot
.31374 .31766 Mdot
.28629 .29021 Mdot
.22355 .22355 Mdot
.20394 .20002 Mdot
.18826 .18042 Mdot
.16473 .16865 Mdot
.16081 .16081 Mdot
.16473 .1765 Mdot
.18434 .20002 Mdot
.18826 .20394 Mdot
.18434 .20002 Mdot
.19218 .20394 Mdot
.1961 .20394 Mdot
.16865 .16865 Mdot
.16081 .16081 Mdot
.14513 .15689 Mdot
.15297 .16473 Mdot
.1765 .19218 Mdot
.19218 .21963 Mdot
.17257 .19218 Mdot
.16865 .18826 Mdot
.16081 .18042 Mdot
.13728 .14905 Mdot
.15297 .17257 Mdot
.17257 .20394 Mdot
.13728 .16865 Mdot
.10983 .13336 Mdot
.08239 .09807 Mdot
.0667 .07846 Mdot
.05102 .06278 Mdot
.04709 .05886 Mdot
.07846 .09415 Mdot
.08631 .10591 Mdot
.10199 .1216 Mdot
.08631 .10591 Mdot
.07062 .08631 Mdot
.0667 .08631 Mdot
.08631 .10983 Mdot
.08239 .09807 Mdot
.07062 .08631 Mdot
.06278 .07454 Mdot
.05494 .07062 Mdot
.05494 .07062 Mdot
.05102 .06278 Mdot
.06278 .07454 Mdot
.08239 .08631 Mdot
.07454 .07846 Mdot
.10983 .12552 Mdot
.13336 .15297 Mdot
.15689 .18042 Mdot
.17257 .18826 Mdot
.11376 .11376 Mdot
.21179 .21571 Mdot
.12944 .10591 Mdot
.20787 .1961 Mdot
.16081 .14513 Mdot
.18434 .20002 Mdot
.1961 .22747 Mdot
.91761 .9333 Mdot
.74116 .749 Mdot
.49804 .52549 Mdot
.41569 .42746 Mdot
.29021 .27845 Mdot
.29021 .28237 Mdot
.23139 .21571 Mdot
.20787 .19218 Mdot
.20002 .18434 Mdot
.19218 .1765 Mdot
.18434 .16865 Mdot
.18826 .18042 Mdot
.1765 .16865 Mdot
.17257 .16865 Mdot
.18434 .18826 Mdot
.17257 .1765 Mdot
.15297 .15689 Mdot
.14513 .14905 Mdot
.13336 .14513 Mdot
.13728 .14905 Mdot
.13336 .14513 Mdot
.1412 .14905 Mdot
.1412 .16473 Mdot
.15689 .18434 Mdot
.14513 .17257 Mdot
.15297 .18826 Mdot
.21963 .27061 Mdot
.14513 .18042 Mdot
.10591 .13336 Mdot
.07454 .09023 Mdot
.0667 .07062 Mdot
.06278 .07062 Mdot
.06278 .07454 Mdot
.07846 .09023 Mdot
.10199 .11768 Mdot
.10591 .1216 Mdot
.10199 .12552 Mdot
.09415 .11768 Mdot
.09807 .12552 Mdot
.11376 .1412 Mdot
.09807 .1216 Mdot
.09415 .11376 Mdot
.0667 .08631 Mdot
.05886 .07454 Mdot
.05886 .08239 Mdot
.05102 .07062 Mdot
.03141 .04317 Mdot
.04317 .05102 Mdot
.04317 .04709 Mdot
.05102 .05102 Mdot
.05886 .05886 Mdot
.08239 .08239 Mdot
.11376 .11768 Mdot
.10199 .09415 Mdot
.29806 .3255 Mdot
.0667 .05102 Mdot
.40393 .44314 Mdot
.36472 .41569 Mdot
.06278 .07062 Mdot
.11768 .1412 Mdot
.90585 .91761 Mdot
.61568 .62744 Mdot
.48235 .50588 Mdot
.34119 .34511 Mdot
.32158 .32158 Mdot
.29413 .28629 Mdot
.26668 .24708 Mdot
.24708 .22355 Mdot
.24708 .22747 Mdot
.18042 .16081 Mdot
.18042 .16473 Mdot
.1765 .15689 Mdot
.16865 .15297 Mdot
.14905 .13728 Mdot
.14905 .14513 Mdot
.15689 .17257 Mdot
.14513 .16865 Mdot
.12552 .14905 Mdot
.1216 .14905 Mdot
.13728 .16473 Mdot
.12944 .16081 Mdot
.13336 .16865 Mdot
.1412 .18042 Mdot
.13728 .18434 Mdot
.1412 .18042 Mdot
.11768 .14513 Mdot
.09415 .1216 Mdot
.09023 .10983 Mdot
.08239 .09807 Mdot
.08239 .09415 Mdot
.09807 .10983 Mdot
.09415 .10983 Mdot
.10591 .1216 Mdot
.10983 .12944 Mdot
.09807 .1216 Mdot
.10591 .12944 Mdot
.11376 .1412 Mdot
.11376 .13728 Mdot
.10983 .13728 Mdot
.07062 .10591 Mdot
.05102 .07454 Mdot
.05886 .08239 Mdot
.04709 .07062 Mdot
.03925 .05494 Mdot
.03533 .04709 Mdot
.03533 .03925 Mdot
.03141 .03141 Mdot
.03925 .03141 Mdot
.03533 .02749 Mdot
.03925 .03925 Mdot
.03533 .04317 Mdot
.05102 .06278 Mdot
.08631 .10199 Mdot
.10591 .12552 Mdot
.13728 .16081 Mdot
.12944 .15297 Mdot
.09807 .10983 Mdot
.76861 .78429 Mdot
.59607 .60391 Mdot
.41569 .41961 Mdot
.34119 .33335 Mdot
.32158 .30982 Mdot
.29413 .28237 Mdot
.26668 .25884 Mdot
.23139 .22355 Mdot
.20002 .1961 Mdot
.16473 .15689 Mdot
.1412 .13336 Mdot
.13728 .13728 Mdot
.12944 .13728 Mdot
.13336 .15297 Mdot
.12944 .15689 Mdot
.11376 .1412 Mdot
.09807 .1216 Mdot
.09807 .1216 Mdot
.12944 .16081 Mdot
.10199 .12944 Mdot
.10983 .13336 Mdot
.1216 .15297 Mdot
.1216 .14513 Mdot
.1216 .1412 Mdot
.11768 .13728 Mdot
.10983 .13336 Mdot
.10199 .12552 Mdot
.09807 .11768 Mdot
.08631 .09807 Mdot
.09807 .10983 Mdot
.10591 .1216 Mdot
.11376 .13728 Mdot
.1216 .14905 Mdot
.11768 .14905 Mdot
.10983 .14905 Mdot
.10199 .14513 Mdot
.09415 .13336 Mdot
.08239 .1216 Mdot
.0667 .10199 Mdot
.05886 .08239 Mdot
.05102 .07454 Mdot
.04709 .06278 Mdot
.05102 .06278 Mdot
.04709 .05102 Mdot
.04317 .03925 Mdot
.03141 .03141 Mdot
.02749 .03533 Mdot
.02749 .03925 Mdot
.02749 .03925 Mdot
.04709 .05886 Mdot
.0667 .07846 Mdot
.09415 .10591 Mdot
.07062 .07454 Mdot
.05102 .05102 Mdot
.73724 .74508 Mdot
.42354 .42746 Mdot
.35687 .36472 Mdot
.31766 .32943 Mdot
.29021 .29413 Mdot
.24316 .24708 Mdot
.21571 .21571 Mdot
.20787 .20787 Mdot
.1961 .19218 Mdot
.17257 .17257 Mdot
.14905 .15689 Mdot
.13728 .14905 Mdot
.1216 .13728 Mdot
.10983 .12944 Mdot
.09807 .11768 Mdot
.11376 .13728 Mdot
.10199 .12552 Mdot
.10199 .12552 Mdot
.12552 .14905 Mdot
.13728 .16473 Mdot
.13336 .15689 Mdot
.12552 .15297 Mdot
.12552 .15297 Mdot
.13336 .16081 Mdot
.1216 .14905 Mdot
.10983 .13728 Mdot
.1216 .15297 Mdot
.13336 .16865 Mdot
.13728 .17257 Mdot
.15297 .18826 Mdot
.12944 .16865 Mdot
.13336 .17257 Mdot
.1216 .16081 Mdot
.1216 .15297 Mdot
.10983 .13728 Mdot
.10983 .13728 Mdot
.10591 .13336 Mdot
.08631 .10983 Mdot
.09415 .10983 Mdot
.07846 .08631 Mdot
.07454 .07454 Mdot
.07846 .08631 Mdot
.0667 .07062 Mdot
.05102 .05886 Mdot
.04709 .05886 Mdot
.04709 .0667 Mdot
.04709 .06278 Mdot
.04709 .06278 Mdot
.07062 .08239 Mdot
.06278 .0667 Mdot
.04709 .03925 Mdot
.87056 .87448 Mdot
.71763 .72939 Mdot
.40001 .40393 Mdot
.30982 .3059 Mdot
.28237 .28629 Mdot
.25884 .26668 Mdot
.23139 .23531 Mdot
.1961 .19218 Mdot
.16865 .16081 Mdot
.14513 .13728 Mdot
.12944 .12552 Mdot
.10983 .11376 Mdot
.11768 .12944 Mdot
.10983 .12944 Mdot
.09023 .10199 Mdot
.07454 .08239 Mdot
.07062 .08631 Mdot
.07846 .09415 Mdot
.08631 .10591 Mdot
.08239 .10591 Mdot
.09023 .10983 Mdot
.09807 .11768 Mdot
.09807 .1216 Mdot
.10591 .13336 Mdot
.09415 .12552 Mdot
.09023 .11768 Mdot
.10199 .12944 Mdot
.10983 .1412 Mdot
.10591 .13728 Mdot
.10591 .13336 Mdot
.09807 .1216 Mdot
.09807 .12552 Mdot
.09807 .12552 Mdot
.09415 .11768 Mdot
.09023 .11768 Mdot
.10199 .12944 Mdot
.10199 .1216 Mdot
.09807 .10591 Mdot
.08631 .08631 Mdot
.08239 .08631 Mdot
.06278 .07062 Mdot
.05494 .06278 Mdot
.04317 .05494 Mdot
.04709 .05886 Mdot
.05102 .0667 Mdot
.04709 .06278 Mdot
.05102 .05886 Mdot
.05494 .05494 Mdot
.04317 .03925 Mdot
.8784 .88232 Mdot
.59607 .61176 Mdot
.44314 .47451 Mdot
.24316 .23531 Mdot
.23531 .22355 Mdot
.1961 .17257 Mdot
.15297 .1216 Mdot
.12944 .10591 Mdot
.1216 .10591 Mdot
.12552 .12552 Mdot
.12552 .12552 Mdot
.11376 .11768 Mdot
.07846 .08239 Mdot
.05886 .0667 Mdot
.05886 .0667 Mdot
.05102 .05886 Mdot
.04317 .05102 Mdot
.06278 .07846 Mdot
.06278 .08239 Mdot
.05102 .07454 Mdot
.05494 .08239 Mdot
.05494 .07846 Mdot
.07062 .10199 Mdot
.07846 .10591 Mdot
.08239 .11768 Mdot
.07454 .10199 Mdot
.07062 .09807 Mdot
.09023 .11768 Mdot
.10199 .12552 Mdot
.08631 .10199 Mdot
.07454 .08631 Mdot
.06278 .07454 Mdot
.07062 .08239 Mdot
.07454 .07846 Mdot
.07062 .07846 Mdot
.0667 .07062 Mdot
.0667 .07846 Mdot
.05102 .05886 Mdot
.03925 .04709 Mdot
.02749 .03141 Mdot
.04317 .05102 Mdot
.05494 .0667 Mdot
.04709 .05494 Mdot
.04709 .05886 Mdot
.05494 .06278 Mdot
.04709 .04317 Mdot
.69018 .69018 Mdot
.45098 .42746 Mdot
.28629 .25884 Mdot
.18434 .15297 Mdot
.15689 .12552 Mdot
.13336 .10591 Mdot
.12552 .10199 Mdot
.10983 .09023 Mdot
.09023 .07846 Mdot
.09023 .07846 Mdot
.07846 .08239 Mdot
.06278 .07454 Mdot
.05886 .07454 Mdot
.0667 .08239 Mdot
.0667 .08631 Mdot
.06278 .08239 Mdot
.05102 .07454 Mdot
.03925 .06278 Mdot
.02749 .05102 Mdot
.0667 .10199 Mdot
.09023 .12944 Mdot
.07454 .11376 Mdot
.08239 .11376 Mdot
.07846 .11376 Mdot
.08631 .1216 Mdot
.09415 .1216 Mdot
.07846 .09415 Mdot
.08239 .09023 Mdot
.07062 .07454 Mdot
.07454 .08239 Mdot
.06278 .05886 Mdot
.06278 .06278 Mdot
.07454 .07454 Mdot
.07454 .07846 Mdot
.06278 .07062 Mdot
.04709 .05886 Mdot
.04317 .05494 Mdot
.03925 .05494 Mdot
.0667 .08239 Mdot
.04709 .05494 Mdot
.04709 .05494 Mdot
.05886 .06278 Mdot
.05886 .05886 Mdot
.57646 .55686 Mdot
.21179 .19218 Mdot
.21179 .19218 Mdot
.17257 .1412 Mdot
.13728 .10199 Mdot
.11768 .09023 Mdot
.11376 .09807 Mdot
.09807 .09023 Mdot
.09415 .09807 Mdot
.09415 .09807 Mdot
.08631 .09807 Mdot
.0667 .07846 Mdot
.07846 .09415 Mdot
.05494 .06278 Mdot
.04317 .05102 Mdot
.04317 .05102 Mdot
.05102 .0667 Mdot
.07454 .09807 Mdot
.07846 .10591 Mdot
.08239 .11768 Mdot
.0667 .10591 Mdot
.06278 .09807 Mdot
.07454 .10199 Mdot
.08631 .11768 Mdot
.08239 .10591 Mdot
.08631 .10983 Mdot
.09415 .10199 Mdot
.08631 .08631 Mdot
.07846 .07846 Mdot
.07454 .07454 Mdot
.07454 .07454 Mdot
.07846 .08239 Mdot
.05886 .07062 Mdot
.05494 .0667 Mdot
.05494 .06278 Mdot
.05886 .07062 Mdot
.0667 .07454 Mdot
.07062 .07454 Mdot
.07062 .07454 Mdot
.0667 .07062 Mdot
.81174 .8039 Mdot
.60783 .58823 Mdot
.19218 .15297 Mdot
.16473 .12552 Mdot
.1412 .10591 Mdot
.11768 .09023 Mdot
.10983 .08631 Mdot
.10983 .09415 Mdot
.10591 .09415 Mdot
.09415 .07846 Mdot
.07846 .06278 Mdot
.08239 .07062 Mdot
.07454 .06278 Mdot
.05102 .03925 Mdot
.07062 .07454 Mdot
.09415 .10983 Mdot
.09807 .11768 Mdot
.08631 .10983 Mdot
.08631 .11768 Mdot
.08239 .10983 Mdot
.09023 .11768 Mdot
.08239 .10983 Mdot
.08239 .10591 Mdot
.08239 .10591 Mdot
.08239 .10199 Mdot
.07846 .09807 Mdot
.07846 .08631 Mdot
.07062 .07846 Mdot
.0667 .07454 Mdot
.07454 .08631 Mdot
.07846 .09023 Mdot
.05886 .07454 Mdot
.04317 .05102 Mdot
.04709 .04709 Mdot
.05886 .05886 Mdot
.05494 .05102 Mdot
.05102 .05102 Mdot
.05494 .05494 Mdot
.59215 .57254 Mdot
.37256 .34511 Mdot
.14513 .10983 Mdot
.1412 .11376 Mdot
.12552 .10591 Mdot
.11376 .09415 Mdot
.10199 .07846 Mdot
.09415 .07062 Mdot
.09023 .07846 Mdot
.08631 .07846 Mdot
.06278 .05886 Mdot
.05494 .05886 Mdot
.07454 .08631 Mdot
.09023 .10983 Mdot
.10199 .12944 Mdot
.10983 .1412 Mdot
.10983 .14513 Mdot
.10983 .13728 Mdot
.09023 .11768 Mdot
.08631 .10591 Mdot
.08239 .10591 Mdot
.08239 .10591 Mdot
.07846 .09807 Mdot
.0667 .08239 Mdot
.05494 .0667 Mdot
.06278 .07846 Mdot
.07062 .08631 Mdot
.0667 .08631 Mdot
.06278 .07846 Mdot
.05886 .07454 Mdot
.06278 .0667 Mdot
.05494 .06278 Mdot
.05494 .05494 Mdot
.07062 .07846 Mdot
.06278 .07846 Mdot
.58431 .56862 Mdot
.35687 .33335 Mdot
.1216 .09807 Mdot
.13336 .11376 Mdot
.13728 .1216 Mdot
.10591 .09807 Mdot
.08239 .08239 Mdot
.06278 .07062 Mdot
.04709 .05494 Mdot
.05494 .0667 Mdot
.07062 .08631 Mdot
.09023 .11376 Mdot
.10199 .12944 Mdot
.11768 .1412 Mdot
.10983 .12944 Mdot
.09023 .10983 Mdot
.09023 .10983 Mdot
.08239 .10591 Mdot
.06278 .08239 Mdot
.05886 .07062 Mdot
.06278 .07846 Mdot
.0667 .08239 Mdot
.07846 .09415 Mdot
.0667 .08631 Mdot
.05494 .07454 Mdot
.05494 .07062 Mdot
.05494 .0667 Mdot
.05886 .07062 Mdot
.05886 .07454 Mdot
.0667 .07846 Mdot
.05494 .05886 Mdot
.03141 .03533 Mdot
.77645 .77253 Mdot
.62352 .63528 Mdot
.15689 .16473 Mdot
.1216 .12944 Mdot
.10199 .11376 Mdot
.07846 .09023 Mdot
.06278 .07062 Mdot
.05494 .07062 Mdot
.0667 .08239 Mdot
.08239 .09807 Mdot
.10199 .1216 Mdot
.1216 .13728 Mdot
.10983 .11768 Mdot
.09807 .09807 Mdot
.09807 .10199 Mdot
.10199 .11376 Mdot
.07846 .09023 Mdot
.07846 .09023 Mdot
.07846 .09023 Mdot
.08239 .10199 Mdot
.08239 .09807 Mdot
.08631 .10199 Mdot
.07062 .08239 Mdot
.05886 .0667 Mdot
.05886 .07062 Mdot
.05886 .07454 Mdot
.07062 .08631 Mdot
.05494 .0667 Mdot
.03141 .04317 Mdot
.02357 .02749 Mdot
.78037 .78429 Mdot
.56078 .5647 Mdot
.11768 .12944 Mdot
.13336 .15297 Mdot
.10591 .1216 Mdot
.10199 .10591 Mdot
.09023 .09415 Mdot
.10199 .10591 Mdot
.11376 .10983 Mdot
.11768 .10983 Mdot
.11376 .10591 Mdot
.12552 .12552 Mdot
.1216 .12552 Mdot
.10983 .11768 Mdot
.10591 .10983 Mdot
.09807 .10983 Mdot
.07454 .08631 Mdot
.09415 .10983 Mdot
.09023 .10591 Mdot
.07846 .09415 Mdot
.06278 .07454 Mdot
.04709 .05886 Mdot
.0667 .07846 Mdot
.07062 .09023 Mdot
.05494 .0667 Mdot
.03141 .03925 Mdot
.00788 .0118 Mdot
.59215 .60391 Mdot
.34903 .35687 Mdot
.12944 .13728 Mdot
.1216 .12944 Mdot
.10983 .10591 Mdot
.10983 .09415 Mdot
.11768 .10199 Mdot
.12552 .11768 Mdot
.12552 .12552 Mdot
.12552 .13336 Mdot
.11376 .12552 Mdot
.11376 .12552 Mdot
.10591 .1216 Mdot
.09415 .10591 Mdot
.09807 .11768 Mdot
.09807 .1216 Mdot
.08239 .09807 Mdot
.07846 .09415 Mdot
.06278 .07846 Mdot
.04709 .05886 Mdot
.04709 .05886 Mdot
.03925 .04709 Mdot
.02357 .02749 Mdot
.00788 .0118 Mdot
.57254 .57646 Mdot
.34903 .34511 Mdot
.10591 .08631 Mdot
.11376 .09807 Mdot
.12552 .12552 Mdot
.13728 .1412 Mdot
.13336 .15297 Mdot
.1216 .14513 Mdot
.11768 .1412 Mdot
.09807 .1216 Mdot
.09415 .11376 Mdot
.09807 .11768 Mdot
.10199 .1216 Mdot
.09807 .1216 Mdot
.07454 .09415 Mdot
.05494 .06278 Mdot
.03141 .03925 Mdot
.03141 .03925 Mdot
.02357 .02357 Mdot
.01965 .0118 Mdot
.01572 .0118 Mdot
.77253 .76861 Mdot
.54117 .53333 Mdot
.08239 .07454 Mdot
.08239 .07846 Mdot
.09807 .10199 Mdot
.09415 .10983 Mdot
.07846 .09023 Mdot
.08239 .09807 Mdot
.08239 .09023 Mdot
.09023 .09807 Mdot
.08239 .09023 Mdot
.07454 .08631 Mdot
.05494 .06278 Mdot
.03141 .02749 Mdot
.04317 .03925 Mdot
.05494 .05102 Mdot
.03533 .02749 Mdot
.03141 .01965 Mdot
.03141 .01965 Mdot
.76469 .76469 Mdot
.53333 .52941 Mdot
.08239 .07846 Mdot
.09807 .09023 Mdot
.08631 .08239 Mdot
.07846 .07846 Mdot
.08239 .08631 Mdot
.08631 .09023 Mdot
.07454 .07454 Mdot
.04709 .04709 Mdot
.04317 .03925 Mdot
.04709 .04317 Mdot
.05886 .05494 Mdot
.04709 .03925 Mdot
.03533 .02749 Mdot
.03533 .02749 Mdot
.58039 .58431 Mdot
.34903 .34511 Mdot
.11768 .11768 Mdot
.08631 .08631 Mdot
.08239 .07846 Mdot
.08239 .07846 Mdot
.07454 .07062 Mdot
.05494 .05494 Mdot
.05494 .05886 Mdot
.05886 .0667 Mdot
.05886 .0667 Mdot
.03141 .02749 Mdot
.03141 .02357 Mdot
.55686 .55686 Mdot
.33335 .33335 Mdot
.12944 .13728 Mdot
.10591 .10591 Mdot
.08239 .08631 Mdot
.05886 .06278 Mdot
.04317 .05102 Mdot
.03533 .04317 Mdot
.02749 .03533 Mdot
.02357 .02357 Mdot
.76469 .76076 Mdot
.54509 .54117 Mdot
.0667 .06278 Mdot
.03141 .03141 Mdot
.01572 .01572 Mdot
.0118 .0118 Mdot
.00788 .0118 Mdot
.01572 .01572 Mdot
.76469 .76469 Mdot
.51372 .51765 Mdot
.01965 .02749 Mdot
.01572 .01965 Mdot
.0118 .0118 Mdot
.50588 .51372 Mdot
.25492 .25492 Mdot
0 0 1 r
.83919 .8588 Mdot
.43138 .5098 Mdot
.40785 .48628 Mdot
.69802 .73724 Mdot
.4902 .56862 Mdot
.51372 .58823 Mdot
.51765 .59607 Mdot
.50196 .57254 Mdot
.63528 .68626 Mdot
.749 .78429 Mdot
.51372 .58823 Mdot
.52941 .59607 Mdot
.54509 .61176 Mdot
.54509 .60783 Mdot
.53725 .59999 Mdot
.52549 .58823 Mdot
.52549 .59215 Mdot
.65097 .70194 Mdot
.88232 .89801 Mdot
.5098 .59215 Mdot
.54117 .61176 Mdot
.54902 .61568 Mdot
.55294 .61568 Mdot
.55686 .61568 Mdot
.54902 .61176 Mdot
.54117 .59999 Mdot
.54509 .60783 Mdot
.54509 .61176 Mdot
.54902 .6196 Mdot
.77253 .81566 Mdot
.89017 .91369 Mdot
.49804 .58039 Mdot
.53725 .6196 Mdot
.54117 .6196 Mdot
.55294 .62744 Mdot
.5647 .63528 Mdot
.55686 .62744 Mdot
.55294 .62744 Mdot
.55686 .62744 Mdot
.55294 .62352 Mdot
.55686 .63136 Mdot
.55686 .6392 Mdot
.55294 .64313 Mdot
.55686 .65097 Mdot
.78429 .83135 Mdot
.52157 .61176 Mdot
.54117 .63136 Mdot
.55294 .6392 Mdot
.55294 .6392 Mdot
.55294 .63528 Mdot
.55294 .63528 Mdot
.55294 .63528 Mdot
.55686 .63528 Mdot
.54902 .62744 Mdot
.55294 .63136 Mdot
.55686 .63528 Mdot
.56078 .64313 Mdot
.5647 .65489 Mdot
.5647 .65489 Mdot
.58039 .67057 Mdot
.68626 .749 Mdot
.79213 .83527 Mdot
.5098 .59215 Mdot
.53725 .63136 Mdot
.54117 .6392 Mdot
.54117 .63136 Mdot
.54117 .63136 Mdot
.54509 .63528 Mdot
.53725 .62352 Mdot
.54117 .61568 Mdot
.55294 .63136 Mdot
.56862 .64705 Mdot
.57254 .65097 Mdot
.57646 .65489 Mdot
.57646 .65489 Mdot
.57646 .65097 Mdot
.58431 .65489 Mdot
.58039 .65097 Mdot
.59215 .66273 Mdot
.5647 .63528 Mdot
.77253 .80782 Mdot
.88232 .89801 Mdot
.52157 .60783 Mdot
.52941 .62352 Mdot
.52941 .62744 Mdot
.52549 .62744 Mdot
.52941 .62352 Mdot
.54117 .63136 Mdot
.54509 .62744 Mdot
.55294 .63136 Mdot
.55294 .63136 Mdot
.56078 .63528 Mdot
.5647 .64313 Mdot
.57254 .64705 Mdot
.58039 .65489 Mdot
.58431 .65489 Mdot
.58823 .65097 Mdot
.59999 .66273 Mdot
.59215 .65881 Mdot
.58823 .65489 Mdot
.58039 .64705 Mdot
.58039 .65097 Mdot
.46275 .52157 Mdot
.72155 .749 Mdot
.81958 .82743 Mdot
.50588 .58039 Mdot
.53725 .6196 Mdot
.54509 .63528 Mdot
.54509 .63528 Mdot
.53725 .62352 Mdot
.52549 .61176 Mdot
.53725 .6196 Mdot
.54902 .62744 Mdot
.55686 .63136 Mdot
.55686 .63136 Mdot
.5647 .64313 Mdot
.5647 .6392 Mdot
.57254 .64705 Mdot
.58823 .65489 Mdot
.58431 .64313 Mdot
.59999 .66273 Mdot
.59215 .65097 Mdot
.59999 .66273 Mdot
.59215 .65881 Mdot
.58431 .65489 Mdot
.59215 .67057 Mdot
.55686 .63136 Mdot
.44706 .50588 Mdot
.51372 .54117 Mdot
.66665 .68626 Mdot
.5098 .58039 Mdot
.54509 .62744 Mdot
.54902 .64313 Mdot
.53333 .6196 Mdot
.53333 .62352 Mdot
.52941 .61568 Mdot
.53333 .61568 Mdot
.53725 .62352 Mdot
.55294 .63136 Mdot
.56078 .63528 Mdot
.56862 .6392 Mdot
.57646 .65097 Mdot
.58039 .65489 Mdot
.59215 .65881 Mdot
.59215 .66273 Mdot
.59607 .66665 Mdot
.59607 .65881 Mdot
.59607 .65881 Mdot
.60783 .6745 Mdot
.60391 .6745 Mdot
.59607 .6745 Mdot
.58823 .67057 Mdot
.58431 .66665 Mdot
.54902 .63136 Mdot
.49412 .5647 Mdot
.41569 .48235 Mdot
.47059 .50588 Mdot
.63528 .64705 Mdot
.52941 .60783 Mdot
.55686 .6392 Mdot
.55686 .64705 Mdot
.54509 .64313 Mdot
.54117 .63528 Mdot
.54509 .63136 Mdot
.53725 .62352 Mdot
.53333 .6196 Mdot
.54509 .62744 Mdot
.55294 .63528 Mdot
.57254 .65097 Mdot
.57646 .65097 Mdot
.57646 .65097 Mdot
.58039 .65489 Mdot
.58823 .66273 Mdot
.58823 .66665 Mdot
.59999 .67057 Mdot
.60783 .6745 Mdot
.60391 .66665 Mdot
.59999 .68234 Mdot
.59999 .67842 Mdot
.59607 .6745 Mdot
.59607 .67842 Mdot
.59999 .68234 Mdot
.59215 .67842 Mdot
.58431 .66665 Mdot
.54902 .62744 Mdot
.38824 .43922 Mdot
.3608 .40393 Mdot
.72155 .75292 Mdot
.81174 .81958 Mdot
.53333 .6196 Mdot
.55294 .64313 Mdot
.55686 .64705 Mdot
.55294 .64313 Mdot
.55294 .6392 Mdot
.54902 .63528 Mdot
.54509 .62744 Mdot
.54117 .62352 Mdot
.54902 .63136 Mdot
.55686 .6392 Mdot
.5647 .64705 Mdot
.56862 .65097 Mdot
.57646 .65881 Mdot
.58431 .66665 Mdot
.58823 .66665 Mdot
.58039 .65489 Mdot
.59607 .66665 Mdot
.60783 .6745 Mdot
.60783 .67842 Mdot
.60391 .68234 Mdot
.59999 .67842 Mdot
.60783 .68626 Mdot
.59999 .67842 Mdot
.59999 .67842 Mdot
.60391 .68626 Mdot
.60391 .68626 Mdot
.61176 .6941 Mdot
.59607 .6745 Mdot
.52941 .59215 Mdot
.47059 .52941 Mdot
.36472 .39609 Mdot
.32158 .34119 Mdot
.75292 .77645 Mdot
.8784 .89017 Mdot
.51765 .60391 Mdot
.54509 .63136 Mdot
.54509 .63528 Mdot
.54902 .63136 Mdot
.53725 .6196 Mdot
.54117 .62352 Mdot
.54902 .63136 Mdot
.54509 .62744 Mdot
.54902 .63136 Mdot
.55294 .6392 Mdot
.56078 .65097 Mdot
.56862 .66273 Mdot
.57254 .66665 Mdot
.58431 .6745 Mdot
.58823 .6745 Mdot
.58431 .66273 Mdot
.59607 .67057 Mdot
.59215 .66665 Mdot
.59607 .67057 Mdot
.60391 .6745 Mdot
.60391 .67842 Mdot
.60391 .68234 Mdot
.60783 .68234 Mdot
.61176 .69018 Mdot
.62744 .70194 Mdot
.62744 .70587 Mdot
.62352 .69018 Mdot
.62744 .70194 Mdot
.48628 .54509 Mdot
.38432 .41961 Mdot
.40001 .4353 Mdot
.44706 .48235 Mdot
.59999 .65881 Mdot
.58039 .6392 Mdot
.6941 .74116 Mdot
.81174 .84703 Mdot
.52549 .59607 Mdot
.54902 .62352 Mdot
.55686 .63528 Mdot
.54509 .62352 Mdot
.53333 .61568 Mdot
.53333 .61568 Mdot
.54509 .62744 Mdot
.54902 .63136 Mdot
.54902 .63136 Mdot
.5647 .64313 Mdot
.5647 .64313 Mdot
.5647 .64705 Mdot
.57646 .66273 Mdot
.57254 .65881 Mdot
.57646 .66273 Mdot
.59215 .67057 Mdot
.60391 .68234 Mdot
.59607 .6745 Mdot
.59999 .6745 Mdot
.60783 .67842 Mdot
.61176 .67842 Mdot
.61176 .67842 Mdot
.62744 .6941 Mdot
.63528 .69802 Mdot
.63136 .69802 Mdot
.62744 .6941 Mdot
.63136 .6941 Mdot
.63528 .70979 Mdot
.53725 .59999 Mdot
.39609 .42746 Mdot
.40001 .42746 Mdot
.56078 .61568 Mdot
.60783 .66665 Mdot
.62352 .6745 Mdot
.64313 .70194 Mdot
.65097 .70979 Mdot
.65489 .71371 Mdot
.72155 .76076 Mdot
.79998 .81958 Mdot
.53333 .59999 Mdot
.55294 .62352 Mdot
.56078 .63136 Mdot
.54902 .6196 Mdot
.54509 .6196 Mdot
.55294 .62744 Mdot
.56078 .63528 Mdot
.56078 .63136 Mdot
.5647 .6392 Mdot
.56862 .6392 Mdot
.5647 .6392 Mdot
.56862 .64705 Mdot
.56862 .65097 Mdot
.56862 .65881 Mdot
.56862 .65489 Mdot
.58039 .65881 Mdot
.59607 .6745 Mdot
.58823 .67057 Mdot
.59215 .6745 Mdot
.60783 .68626 Mdot
.6196 .69018 Mdot
.6196 .67842 Mdot
.62352 .68234 Mdot
.63136 .69018 Mdot
.6392 .70194 Mdot
.6392 .70587 Mdot
.64705 .70979 Mdot
.64705 .70979 Mdot
.61176 .6745 Mdot
.58431 .6392 Mdot
.56078 .60783 Mdot
.59215 .65097 Mdot
.6392 .69802 Mdot
.64705 .69802 Mdot
.65489 .70979 Mdot
.66665 .71371 Mdot
.66665 .70979 Mdot
.67057 .70979 Mdot
.65881 .69802 Mdot
.66273 .70194 Mdot
.83135 .85487 Mdot
.91761 .9333 Mdot
.51765 .58823 Mdot
.53725 .60783 Mdot
.55294 .62744 Mdot
.55294 .62352 Mdot
.54509 .61568 Mdot
.54902 .61176 Mdot
.55294 .61568 Mdot
.55686 .62352 Mdot
.56862 .63528 Mdot
.57254 .6392 Mdot
.56078 .63136 Mdot
.57646 .65097 Mdot
.57646 .65881 Mdot
.57254 .65489 Mdot
.57254 .65489 Mdot
.58039 .65881 Mdot
.60391 .68234 Mdot
.61176 .69018 Mdot
.60391 .68234 Mdot
.60391 .67842 Mdot
.60391 .68234 Mdot
.61176 .68234 Mdot
.6196 .68234 Mdot
.62744 .68626 Mdot
.63136 .6941 Mdot
.63528 .70194 Mdot
.63136 .69802 Mdot
.64705 .70979 Mdot
.64705 .70979 Mdot
.64313 .70194 Mdot
.63136 .68626 Mdot
.6392 .69802 Mdot
.65097 .70979 Mdot
.65881 .70587 Mdot
.65881 .70979 Mdot
.6745 .72155 Mdot
.67842 .71763 Mdot
.68626 .72939 Mdot
.68234 .72155 Mdot
.67842 .72547 Mdot
.66665 .70587 Mdot
.6745 .72547 Mdot
.67057 .72547 Mdot
.83527 .8588 Mdot
.91761 .92546 Mdot
.50588 .59607 Mdot
.53333 .6196 Mdot
.54509 .62744 Mdot
.54902 .62352 Mdot
.54509 .61568 Mdot
.54509 .61176 Mdot
.54902 .61568 Mdot
.54902 .61176 Mdot
.55686 .62352 Mdot
.5647 .63528 Mdot
.5647 .6392 Mdot
.57254 .64313 Mdot
.57254 .64705 Mdot
.57646 .65097 Mdot
.57254 .65489 Mdot
.57646 .65489 Mdot
.59215 .67057 Mdot
.59607 .6745 Mdot
.61176 .68626 Mdot
.60391 .67842 Mdot
.61568 .69018 Mdot
.60391 .67842 Mdot
.6196 .69018 Mdot
.62744 .6941 Mdot
.63528 .6941 Mdot
.63528 .69802 Mdot
.63136 .6941 Mdot
.64313 .70979 Mdot
.65097 .70979 Mdot
.65097 .70194 Mdot
.65097 .70587 Mdot
.64705 .70194 Mdot
.64705 .70194 Mdot
.65881 .70979 Mdot
.66665 .71763 Mdot
.67057 .72155 Mdot
.6745 .71763 Mdot
.67842 .72939 Mdot
.67842 .73332 Mdot
.68234 .73724 Mdot
.6745 .72939 Mdot
.66665 .72939 Mdot
.68234 .74508 Mdot
.67842 .74116 Mdot
.67842 .72547 Mdot
.76076 .79998 Mdot
.84703 .87448 Mdot
.50196 .58823 Mdot
.53333 .62352 Mdot
.54902 .63528 Mdot
.54902 .63136 Mdot
.53333 .61568 Mdot
.54117 .61568 Mdot
.54902 .61568 Mdot
.55686 .62352 Mdot
.55686 .62352 Mdot
.55686 .62352 Mdot
.5647 .63528 Mdot
.57646 .64705 Mdot
.57254 .64313 Mdot
.57646 .65097 Mdot
.58039 .65489 Mdot
.58039 .65489 Mdot
.58431 .65097 Mdot
.58823 .65489 Mdot
.59999 .67057 Mdot
.60391 .67057 Mdot
.61176 .67842 Mdot
.61568 .67842 Mdot
.62352 .68626 Mdot
.63528 .70194 Mdot
.63528 .6941 Mdot
.63528 .69018 Mdot
.63528 .69018 Mdot
.63528 .6941 Mdot
.65097 .70587 Mdot
.65097 .69802 Mdot
.65881 .70979 Mdot
.66665 .71763 Mdot
.66273 .71371 Mdot
.66273 .70979 Mdot
.66665 .71371 Mdot
.6745 .72547 Mdot
.68626 .73332 Mdot
.68234 .73332 Mdot
.67842 .73332 Mdot
.67842 .73332 Mdot
.67842 .73724 Mdot
.67842 .73724 Mdot
.6941 .749 Mdot
.6941 .749 Mdot
.6941 .749 Mdot
.69802 .749 Mdot
.69018 .74116 Mdot
.69802 .74116 Mdot
.76076 .79213 Mdot
.84311 .87448 Mdot
.51372 .58823 Mdot
.53725 .6196 Mdot
.55294 .63528 Mdot
.54509 .62352 Mdot
.53725 .6196 Mdot
.54117 .6196 Mdot
.54509 .61176 Mdot
.55294 .62744 Mdot
.56078 .63136 Mdot
.55294 .6196 Mdot
.57646 .64313 Mdot
.57646 .6392 Mdot
.58039 .65097 Mdot
.57646 .64313 Mdot
.58039 .65097 Mdot
.58039 .64313 Mdot
.58431 .64313 Mdot
.58431 .6392 Mdot
.58431 .64313 Mdot
.58823 .65097 Mdot
.60391 .66273 Mdot
.60783 .66273 Mdot
.6196 .6745 Mdot
.63528 .6941 Mdot
.6392 .69802 Mdot
.64313 .6941 Mdot
.64313 .69018 Mdot
.65097 .69802 Mdot
.64313 .6941 Mdot
.65489 .70194 Mdot
.65881 .70194 Mdot
.65881 .70587 Mdot
.66273 .70979 Mdot
.67842 .72155 Mdot
.6745 .72155 Mdot
.6745 .72155 Mdot
.68234 .72547 Mdot
.68626 .72939 Mdot
.67842 .72939 Mdot
.68234 .74116 Mdot
.68234 .74116 Mdot
.68234 .74116 Mdot
.6941 .749 Mdot
.70194 .75292 Mdot
.69802 .749 Mdot
.70194 .749 Mdot
.70194 .74508 Mdot
.71371 .75292 Mdot
.70587 .749 Mdot
.6941 .749 Mdot
.67842 .73332 Mdot
.8235 .85095 Mdot
.89801 .91761 Mdot
.46275 .52549 Mdot
.54902 .62352 Mdot
.53725 .61568 Mdot
.52157 .59999 Mdot
.51765 .59215 Mdot
.52549 .60783 Mdot
.53333 .60783 Mdot
.55294 .62352 Mdot
.55686 .62744 Mdot
.56078 .62744 Mdot
.55686 .62352 Mdot
.56862 .63528 Mdot
.57254 .6392 Mdot
.57254 .64313 Mdot
.57646 .64705 Mdot
.57646 .64313 Mdot
.58823 .65097 Mdot
.59999 .65489 Mdot
.59999 .65881 Mdot
.59215 .65489 Mdot
.59215 .65489 Mdot
.60391 .65881 Mdot
.60391 .65881 Mdot
.60783 .66273 Mdot
.61568 .6745 Mdot
.63136 .68626 Mdot
.6392 .68626 Mdot
.65489 .70194 Mdot
.65097 .69802 Mdot
.65097 .6941 Mdot
.65097 .69802 Mdot
.65489 .70194 Mdot
.66273 .70194 Mdot
.6745 .71763 Mdot
.67842 .72155 Mdot
.66273 .70587 Mdot
.66665 .71371 Mdot
.67057 .72155 Mdot
.67057 .72547 Mdot
.67057 .72939 Mdot
.67057 .72547 Mdot
.69018 .749 Mdot
.69018 .749 Mdot
.69018 .74116 Mdot
.69018 .74116 Mdot
.70194 .749 Mdot
.70194 .75292 Mdot
.70979 .74508 Mdot
.70587 .749 Mdot
.70979 .75684 Mdot
.70587 .75292 Mdot
.6941 .74508 Mdot
.68626 .74116 Mdot
.59215 .64313 Mdot
.74508 .75292 Mdot
.86272 .86664 Mdot
.48628 .55686 Mdot
.51372 .59607 Mdot
.52941 .61176 Mdot
.52941 .60783 Mdot
.51765 .59215 Mdot
.51765 .59215 Mdot
.51765 .58823 Mdot
.54509 .60783 Mdot
.55686 .6196 Mdot
.55686 .62352 Mdot
.55294 .62352 Mdot
.54902 .62352 Mdot
.56078 .6392 Mdot
.55294 .63136 Mdot
.5647 .64313 Mdot
.56862 .64313 Mdot
.58039 .65097 Mdot
.58431 .65881 Mdot
.58823 .66273 Mdot
.58823 .66273 Mdot
.59607 .67057 Mdot
.59607 .66665 Mdot
.59607 .65881 Mdot
.61176 .66665 Mdot
.61568 .6745 Mdot
.62352 .69018 Mdot
.6392 .69802 Mdot
.64313 .6941 Mdot
.65489 .70587 Mdot
.66273 .70979 Mdot
.66665 .71371 Mdot
.66273 .71371 Mdot
.66273 .70979 Mdot
.65881 .70587 Mdot
.66665 .71763 Mdot
.65881 .70587 Mdot
.66273 .71371 Mdot
.66273 .71371 Mdot
.66665 .71763 Mdot
.6745 .72547 Mdot
.68626 .73332 Mdot
.68234 .73332 Mdot
.69018 .74508 Mdot
.69802 .749 Mdot
.6941 .74508 Mdot
.69802 .74508 Mdot
.70194 .749 Mdot
.70979 .75292 Mdot
.70587 .74508 Mdot
.71371 .75292 Mdot
.70979 .749 Mdot
.70979 .75292 Mdot
.71371 .75292 Mdot
.70587 .74116 Mdot
.67057 .70587 Mdot
.65489 .69018 Mdot
.74116 .76469 Mdot
.79606 .80782 Mdot
.50588 .58431 Mdot
.53725 .60783 Mdot
.54509 .6196 Mdot
.53333 .60783 Mdot
.51765 .58823 Mdot
.52157 .59215 Mdot
.52941 .60391 Mdot
.54117 .60783 Mdot
.54902 .61176 Mdot
.54902 .61568 Mdot
.55294 .6196 Mdot
.55294 .62352 Mdot
.55294 .63136 Mdot
.55686 .6392 Mdot
.56078 .63528 Mdot
.5647 .64313 Mdot
.57254 .64705 Mdot
.56862 .64705 Mdot
.5647 .64705 Mdot
.57646 .65489 Mdot
.58431 .65489 Mdot
.59215 .65881 Mdot
.60391 .65881 Mdot
.61568 .67057 Mdot
.61568 .66665 Mdot
.62352 .6745 Mdot
.63528 .68234 Mdot
.6392 .68626 Mdot
.64313 .68626 Mdot
.65489 .69802 Mdot
.65489 .69802 Mdot
.66273 .70979 Mdot
.66665 .71371 Mdot
.66665 .70979 Mdot
.66273 .70587 Mdot
.66665 .72155 Mdot
.65881 .70979 Mdot
.66665 .72155 Mdot
.66273 .71371 Mdot
.6745 .72547 Mdot
.68626 .72939 Mdot
.68234 .72547 Mdot
.69018 .73724 Mdot
.70194 .749 Mdot
.70194 .749 Mdot
.70194 .749 Mdot
.70979 .749 Mdot
.70587 .749 Mdot
.70979 .74508 Mdot
.71763 .75684 Mdot
.72155 .76469 Mdot
.71371 .76076 Mdot
.71763 .76076 Mdot
.71371 .75292 Mdot
.71371 .74508 Mdot
.70979 .74116 Mdot
.70587 .74508 Mdot
.70194 .74116 Mdot
.6745 .72155 Mdot
.74508 .78037 Mdot
.64313 .63136 Mdot
.46275 .53333 Mdot
.52549 .60783 Mdot
.53333 .61568 Mdot
.52941 .61176 Mdot
.52941 .60391 Mdot
.52549 .59999 Mdot
.53333 .61176 Mdot
.53725 .61568 Mdot
.54509 .6196 Mdot
.54902 .62352 Mdot
.54902 .62352 Mdot
.54509 .6196 Mdot
.54117 .62352 Mdot
.55294 .63528 Mdot
.56078 .6392 Mdot
.57254 .64705 Mdot
.56862 .64705 Mdot
.57254 .65881 Mdot
.5647 .65489 Mdot
.58039 .66665 Mdot
.58431 .65881 Mdot
.59999 .66273 Mdot
.60783 .67057 Mdot
.62352 .68234 Mdot
.63136 .67842 Mdot
.63528 .68234 Mdot
.65097 .69018 Mdot
.65881 .6941 Mdot
.64705 .68234 Mdot
.66273 .70194 Mdot
.66273 .70194 Mdot
.67057 .70979 Mdot
.66665 .70587 Mdot
.67057 .70979 Mdot
.67057 .70979 Mdot
.67842 .72155 Mdot
.67842 .72547 Mdot
.67057 .71763 Mdot
.67842 .72939 Mdot
.68234 .72547 Mdot
.68234 .72939 Mdot
.68626 .72547 Mdot
.6941 .73724 Mdot
.69802 .74116 Mdot
.70194 .749 Mdot
.70979 .74508 Mdot
.70587 .749 Mdot
.71371 .749 Mdot
.71371 .749 Mdot
.72155 .76076 Mdot
.71763 .75684 Mdot
.71763 .75684 Mdot
.71371 .75292 Mdot
.70979 .75292 Mdot
.72939 .76861 Mdot
.72547 .76076 Mdot
.72547 .76076 Mdot
.72939 .76469 Mdot
.72939 .76861 Mdot
.74116 .79213 Mdot
.4902 .49804 Mdot
.28629 .26276 Mdot
.65881 .65489 Mdot
.88624 .89801 Mdot
.45491 .53333 Mdot
.50196 .58431 Mdot
.52549 .60391 Mdot
.53333 .61568 Mdot
.53333 .60783 Mdot
.53725 .61176 Mdot
.53333 .60391 Mdot
.53725 .61568 Mdot
.54509 .6196 Mdot
.54117 .6196 Mdot
.55294 .63136 Mdot
.5647 .63528 Mdot
.56078 .63136 Mdot
.56862 .6392 Mdot
.56862 .64313 Mdot
.56862 .64313 Mdot
.57646 .65489 Mdot
.58823 .66273 Mdot
.58039 .65489 Mdot
.58431 .66273 Mdot
.59999 .6745 Mdot
.60391 .67057 Mdot
.61176 .67057 Mdot
.6196 .67057 Mdot
.6196 .67842 Mdot
.63136 .68234 Mdot
.64313 .6941 Mdot
.65489 .69802 Mdot
.64705 .69018 Mdot
.64705 .6941 Mdot
.65881 .71371 Mdot
.66273 .70979 Mdot
.67057 .71763 Mdot
.6745 .71371 Mdot
.6745 .71763 Mdot
.67842 .72155 Mdot
.68626 .73332 Mdot
.69018 .73332 Mdot
.6941 .74116 Mdot
.6941 .73724 Mdot
.69802 .73332 Mdot
.6941 .72939 Mdot
.70194 .74508 Mdot
.70194 .749 Mdot
.70587 .74508 Mdot
.70194 .749 Mdot
.70979 .75684 Mdot
.71371 .75684 Mdot
.72155 .75684 Mdot
.72547 .75684 Mdot
.74116 .77253 Mdot
.73332 .76076 Mdot
.73332 .76076 Mdot
.73332 .76469 Mdot
.73332 .76076 Mdot
.74116 .76469 Mdot
.74508 .77253 Mdot
.74116 .77645 Mdot
.73724 .77645 Mdot
.74508 .79213 Mdot
.71763 .76469 Mdot
.4902 .50588 Mdot
.36864 .35295 Mdot
.6941 .73724 Mdot
.59607 .6196 Mdot
.83135 .85095 Mdot
.90977 .92154 Mdot
.44314 .51765 Mdot
.5098 .58431 Mdot
.52157 .59999 Mdot
.52549 .60391 Mdot
.51765 .59215 Mdot
.52157 .59999 Mdot
.52157 .59607 Mdot
.52549 .60391 Mdot
.53333 .61568 Mdot
.54509 .62744 Mdot
.55294 .63136 Mdot
.54902 .62352 Mdot
.54902 .6196 Mdot
.55686 .63528 Mdot
.56078 .64705 Mdot
.54509 .62744 Mdot
.55294 .6392 Mdot
.56862 .65097 Mdot
.58431 .66273 Mdot
.58823 .66665 Mdot
.59215 .66273 Mdot
.59215 .66273 Mdot
.60783 .67057 Mdot
.61176 .67057 Mdot
.60783 .66665 Mdot
.6196 .67842 Mdot
.61568 .67842 Mdot
.62352 .67842 Mdot
.62744 .67842 Mdot
.6392 .69018 Mdot
.65097 .70194 Mdot
.65097 .70587 Mdot
.65881 .70979 Mdot
.65489 .70194 Mdot
.65881 .69802 Mdot
.67057 .70979 Mdot
.6745 .71371 Mdot
.6745 .70979 Mdot
.68234 .72155 Mdot
.6745 .70979 Mdot
.68626 .71371 Mdot
.69018 .72155 Mdot
.6941 .73724 Mdot
.69018 .73724 Mdot
.70194 .749 Mdot
.69802 .74116 Mdot
.70194 .74508 Mdot
.70979 .74508 Mdot
.71371 .749 Mdot
.71763 .749 Mdot
.72939 .75292 Mdot
.72939 .75292 Mdot
.73724 .76076 Mdot
.72939 .76076 Mdot
.72547 .75684 Mdot
.72547 .76076 Mdot
.72547 .76469 Mdot
.73332 .76861 Mdot
.72939 .76861 Mdot
.72155 .76469 Mdot
.72155 .76076 Mdot
.70979 .74508 Mdot
.68626 .70587 Mdot
.70587 .72939 Mdot
.71371 .74116 Mdot
.70979 .749 Mdot
.69802 .74116 Mdot
.76861 .79998 Mdot
.69018 .69018 Mdot
.47451 .53725 Mdot
.50588 .57646 Mdot
.50196 .57646 Mdot
.50196 .57646 Mdot
.50588 .58431 Mdot
.52157 .59607 Mdot
.52157 .59999 Mdot
.51765 .59607 Mdot
.52941 .60783 Mdot
.53725 .61568 Mdot
.54509 .62744 Mdot
.54117 .62352 Mdot
.54509 .62352 Mdot
.54509 .62352 Mdot
.54117 .62744 Mdot
.54509 .62744 Mdot
.54902 .62352 Mdot
.5647 .63528 Mdot
.58431 .65489 Mdot
.58039 .64705 Mdot
.58431 .65097 Mdot
.59215 .65097 Mdot
.59607 .64705 Mdot
.60391 .66273 Mdot
.61176 .67057 Mdot
.61176 .66665 Mdot
.61176 .66665 Mdot
.61568 .67057 Mdot
.62744 .68234 Mdot
.6392 .68234 Mdot
.64313 .68234 Mdot
.64313 .68626 Mdot
.67057 .70587 Mdot
.66665 .70194 Mdot
.66273 .69802 Mdot
.66665 .70194 Mdot
.6745 .70194 Mdot
.6745 .70587 Mdot
.67842 .71763 Mdot
.67842 .71371 Mdot
.68626 .71371 Mdot
.68626 .71371 Mdot
.69802 .72939 Mdot
.69802 .73332 Mdot
.70194 .73724 Mdot
.70194 .74116 Mdot
.70587 .749 Mdot
.70194 .74508 Mdot
.69802 .74116 Mdot
.70587 .74508 Mdot
.70979 .74508 Mdot
.71371 .749 Mdot
.72547 .76076 Mdot
.72155 .76076 Mdot
.71763 .76861 Mdot
.70979 .76076 Mdot
.70979 .76076 Mdot
.71371 .76469 Mdot
.71763 .76469 Mdot
.72547 .76861 Mdot
.72939 .76469 Mdot
.73724 .76469 Mdot
.72939 .75684 Mdot
.73332 .75684 Mdot
.72547 .75292 Mdot
.73332 .76469 Mdot
.74116 .76861 Mdot
.72939 .76469 Mdot
.6745 .6941 Mdot
.66273 .67842 Mdot
.75684 .77645 Mdot
.92938 .93722 Mdot
.48235 .54117 Mdot
.50588 .58039 Mdot
.51765 .59607 Mdot
.51372 .59607 Mdot
.5098 .58823 Mdot
.51372 .58823 Mdot
.51765 .59215 Mdot
.52549 .59999 Mdot
.52549 .59999 Mdot
.52941 .60391 Mdot
.54509 .61568 Mdot
.54117 .61176 Mdot
.54509 .6196 Mdot
.55686 .63136 Mdot
.54902 .62744 Mdot
.54902 .62744 Mdot
.55686 .63136 Mdot
.5647 .6392 Mdot
.57646 .64313 Mdot
.58039 .65489 Mdot
.58431 .64313 Mdot
.58823 .64313 Mdot
.60391 .65881 Mdot
.60391 .65489 Mdot
.61176 .66665 Mdot
.62352 .67057 Mdot
.62352 .6745 Mdot
.62744 .6745 Mdot
.6392 .69018 Mdot
.64313 .68626 Mdot
.65097 .69802 Mdot
.65097 .6941 Mdot
.65881 .69802 Mdot
.65881 .6941 Mdot
.65881 .6941 Mdot
.6745 .71371 Mdot
.68234 .71763 Mdot
.69018 .72547 Mdot
.69018 .72547 Mdot
.69018 .72547 Mdot
.69018 .72155 Mdot
.6941 .72547 Mdot
.70587 .74116 Mdot
.70587 .74116 Mdot
.70979 .74116 Mdot
.70587 .74116 Mdot
.70587 .74116 Mdot
.70194 .74116 Mdot
.70587 .749 Mdot
.70587 .749 Mdot
.70587 .74508 Mdot
.70979 .74508 Mdot
.71371 .749 Mdot
.70587 .74508 Mdot
.71371 .75684 Mdot
.72155 .76861 Mdot
.72155 .76469 Mdot
.72939 .77253 Mdot
.72547 .76861 Mdot
.72939 .76469 Mdot
.72547 .76469 Mdot
.72939 .76469 Mdot
.74116 .77645 Mdot
.749 .77645 Mdot
.749 .77645 Mdot
.74508 .77253 Mdot
.74508 .77253 Mdot
.74508 .77645 Mdot
.749 .78037 Mdot
.73724 .76469 Mdot
.73332 .76076 Mdot
.73332 .76469 Mdot
.72939 .76469 Mdot
.86664 .89017 Mdot
.9333 .94114 Mdot
.46275 .52941 Mdot
.50196 .58039 Mdot
.51372 .59215 Mdot
.51765 .60391 Mdot
.51372 .59215 Mdot
.52549 .59999 Mdot
.52157 .59215 Mdot
.52157 .59215 Mdot
.52549 .59999 Mdot
.53725 .60783 Mdot
.53725 .59607 Mdot
.54902 .61176 Mdot
.54902 .61568 Mdot
.55686 .62352 Mdot
.56078 .63528 Mdot
.56862 .64313 Mdot
.56078 .63136 Mdot
.5647 .63136 Mdot
.5647 .63136 Mdot
.58039 .64313 Mdot
.59607 .65097 Mdot
.59215 .64313 Mdot
.59607 .64705 Mdot
.60783 .65489 Mdot
.61176 .66665 Mdot
.61176 .67057 Mdot
.61176 .66665 Mdot
.6196 .67842 Mdot
.62744 .68626 Mdot
.62744 .67842 Mdot
.63136 .68626 Mdot
.64313 .6941 Mdot
.65489 .6941 Mdot
.66273 .69802 Mdot
.67057 .70587 Mdot
.6745 .71371 Mdot
.6745 .70587 Mdot
.67842 .71763 Mdot
.67842 .71371 Mdot
.68234 .72547 Mdot
.68234 .72547 Mdot
.68626 .73332 Mdot
.69018 .73724 Mdot
.69802 .74508 Mdot
.70194 .74116 Mdot
.69802 .73724 Mdot
.69802 .74116 Mdot
.70194 .74508 Mdot
.69802 .73724 Mdot
.72155 .76076 Mdot
.72155 .76076 Mdot
.72155 .75684 Mdot
.72547 .76076 Mdot
.72547 .76469 Mdot
.72547 .76861 Mdot
.72939 .76861 Mdot
.73724 .77253 Mdot
.73332 .76469 Mdot
.73724 .77645 Mdot
.73332 .76861 Mdot
.73724 .77253 Mdot
.72155 .76076 Mdot
.72939 .76469 Mdot
.74116 .77253 Mdot
.749 .78037 Mdot
.749 .78429 Mdot
.75292 .78037 Mdot
.75684 .78429 Mdot
.74508 .77253 Mdot
.749 .78037 Mdot
.749 .78037 Mdot
.75292 .78429 Mdot
.74508 .78429 Mdot
.73332 .77645 Mdot
.72939 .77645 Mdot
.71371 .75684 Mdot
.86272 .89017 Mdot
.43922 .50588 Mdot
.49412 .57254 Mdot
.51372 .58823 Mdot
.52157 .59215 Mdot
.51765 .58823 Mdot
.52157 .59607 Mdot
.52549 .59215 Mdot
.52941 .59607 Mdot
.52549 .59607 Mdot
.52549 .59215 Mdot
.53333 .59999 Mdot
.54902 .61176 Mdot
.54902 .60783 Mdot
.55294 .61176 Mdot
.56078 .62352 Mdot
.56078 .62352 Mdot
.5647 .63136 Mdot
.58039 .63528 Mdot
.58431 .6392 Mdot
.58431 .6392 Mdot
.58823 .6392 Mdot
.60783 .65489 Mdot
.60783 .65489 Mdot
.60391 .65097 Mdot
.60391 .65489 Mdot
.61176 .66273 Mdot
.61176 .66665 Mdot
.60783 .66273 Mdot
.61176 .66273 Mdot
.6196 .6745 Mdot
.63528 .68626 Mdot
.64313 .69018 Mdot
.65097 .69018 Mdot
.65881 .69802 Mdot
.67057 .70194 Mdot
.6745 .71371 Mdot
.6745 .70979 Mdot
.6745 .70979 Mdot
.6745 .70979 Mdot
.67842 .71371 Mdot
.67842 .72155 Mdot
.69018 .73332 Mdot
.69018 .73332 Mdot
.69018 .73332 Mdot
.70587 .74116 Mdot
.70587 .74116 Mdot
.70587 .73724 Mdot
.71371 .74116 Mdot
.72155 .749 Mdot
.72547 .74508 Mdot
.73332 .75684 Mdot
.73332 .75292 Mdot
.72547 .749 Mdot
.72939 .76076 Mdot
.72155 .75292 Mdot
.72939 .76076 Mdot
.74116 .76469 Mdot
.74116 .76861 Mdot
.72939 .75684 Mdot
.74508 .77253 Mdot
.74508 .77645 Mdot
.74116 .77645 Mdot
.73724 .77645 Mdot
.74508 .78821 Mdot
.74508 .78821 Mdot
.74116 .78037 Mdot
.749 .78429 Mdot
.75684 .78429 Mdot
.74508 .77253 Mdot
.75684 .78037 Mdot
.749 .77645 Mdot
.75292 .77253 Mdot
.75684 .78037 Mdot
.74508 .78429 Mdot
.73724 .77645 Mdot
.73332 .77645 Mdot
.73724 .78037 Mdot
.73724 .78429 Mdot
.75292 .78037 Mdot
.81566 .8235 Mdot
.45098 .51765 Mdot
.50196 .57254 Mdot
.51372 .59215 Mdot
.52157 .59215 Mdot
.51765 .58823 Mdot
.51765 .58823 Mdot
.51372 .58823 Mdot
.52941 .60783 Mdot
.52941 .60783 Mdot
.52941 .60783 Mdot
.54902 .6196 Mdot
.55294 .62352 Mdot
.55686 .6196 Mdot
.55686 .61176 Mdot
.5647 .62352 Mdot
.57646 .6392 Mdot
.58431 .63528 Mdot
.58823 .64313 Mdot
.59215 .64313 Mdot
.58823 .64313 Mdot
.59999 .65097 Mdot
.60391 .65881 Mdot
.60391 .65881 Mdot
.61176 .66665 Mdot
.60783 .66273 Mdot
.61568 .66273 Mdot
.61568 .67057 Mdot
.62744 .68234 Mdot
.6196 .67842 Mdot
.61568 .67057 Mdot
.63136 .68626 Mdot
.63528 .69802 Mdot
.64705 .70194 Mdot
.66665 .71371 Mdot
.66273 .70194 Mdot
.67842 .70979 Mdot
.67057 .70194 Mdot
.67842 .71371 Mdot
.68234 .71763 Mdot
.68234 .72547 Mdot
.68626 .72939 Mdot
.69018 .73332 Mdot
.69018 .73332 Mdot
.69802 .74508 Mdot
.70587 .74508 Mdot
.70587 .73724 Mdot
.70587 .73724 Mdot
.71371 .749 Mdot
.72939 .76469 Mdot
.72939 .749 Mdot
.74116 .76469 Mdot
.72939 .749 Mdot
.72939 .749 Mdot
.72547 .75292 Mdot
.72939 .76469 Mdot
.72939 .76076 Mdot
.749 .77645 Mdot
.749 .77253 Mdot
.74508 .76469 Mdot
.75684 .78037 Mdot
.75684 .78429 Mdot
.749 .78037 Mdot
.75292 .78429 Mdot
.749 .78429 Mdot
.74508 .78429 Mdot
.74508 .78037 Mdot
.75292 .79213 Mdot
.75684 .79606 Mdot
.74116 .78037 Mdot
.749 .78429 Mdot
.74508 .78037 Mdot
.74508 .77645 Mdot
.75292 .78821 Mdot
.75292 .78821 Mdot
.74116 .78037 Mdot
.75684 .79998 Mdot
.75684 .79606 Mdot
.749 .78821 Mdot
.74508 .78037 Mdot
.74116 .78037 Mdot
.72547 .76469 Mdot
.80782 .83527 Mdot
.93722 .94898 Mdot
.47843 .56078 Mdot
.52549 .60783 Mdot
.53725 .6196 Mdot
.53333 .59999 Mdot
.52157 .58039 Mdot
.52549 .58823 Mdot
.52157 .58823 Mdot
.52549 .59607 Mdot
.52941 .60783 Mdot
.52941 .60783 Mdot
.53333 .60783 Mdot
.55294 .6196 Mdot
.55294 .6196 Mdot
.55686 .62744 Mdot
.55294 .63136 Mdot
.56078 .63528 Mdot
.5647 .63136 Mdot
.57646 .6392 Mdot
.58039 .64313 Mdot
.57646 .64313 Mdot
.59215 .65489 Mdot
.59999 .65489 Mdot
.60391 .65489 Mdot
.60783 .66273 Mdot
.62352 .67057 Mdot
.6196 .66665 Mdot
.62352 .67057 Mdot
.62352 .67842 Mdot
.62744 .68234 Mdot
.63136 .68626 Mdot
.63136 .69018 Mdot
.6392 .69802 Mdot
.6392 .70194 Mdot
.64705 .70194 Mdot
.65097 .6941 Mdot
.66665 .70587 Mdot
.68234 .71763 Mdot
.68626 .71763 Mdot
.68234 .71763 Mdot
.68626 .72155 Mdot
.68626 .72547 Mdot
.68234 .71763 Mdot
.69018 .73332 Mdot
.69018 .73332 Mdot
.69018 .73724 Mdot
.69018 .73332 Mdot
.69802 .73332 Mdot
.70979 .74116 Mdot
.72155 .75292 Mdot
.71371 .73724 Mdot
.71763 .749 Mdot
.73332 .75684 Mdot
.73332 .76076 Mdot
.72547 .76076 Mdot
.72547 .75684 Mdot
.72939 .76469 Mdot
.73332 .76861 Mdot
.74508 .77253 Mdot
.75292 .78037 Mdot
.73724 .76861 Mdot
.74116 .76861 Mdot
.75684 .78821 Mdot
.75292 .78037 Mdot
.749 .78037 Mdot
.73332 .77253 Mdot
.73332 .77253 Mdot
.749 .78429 Mdot
.74508 .78821 Mdot
.73724 .78037 Mdot
.74116 .77645 Mdot
.74116 .77253 Mdot
.74508 .78037 Mdot
.75684 .79213 Mdot
.75684 .79606 Mdot
.75684 .79606 Mdot
.76076 .79998 Mdot
.75684 .79606 Mdot
.75292 .79213 Mdot
.74508 .78037 Mdot
.75292 .78821 Mdot
.749 .78429 Mdot
.74508 .78037 Mdot
.74116 .77645 Mdot
.72939 .77253 Mdot
.84311 .86272 Mdot
.90193 .90977 Mdot
.4902 .5647 Mdot
.51765 .58823 Mdot
.52941 .59999 Mdot
.52941 .58823 Mdot
.52941 .57646 Mdot
.53725 .58823 Mdot
.53725 .59999 Mdot
.52941 .60391 Mdot
.53725 .61568 Mdot
.53333 .61568 Mdot
.53725 .61176 Mdot
.54117 .6196 Mdot
.54117 .6196 Mdot
.54902 .62352 Mdot
.55294 .63136 Mdot
.55686 .63136 Mdot
.56862 .63528 Mdot
.56862 .63528 Mdot
.57254 .6392 Mdot
.57254 .64313 Mdot
.58823 .65881 Mdot
.59215 .65097 Mdot
.60391 .65489 Mdot
.60391 .65489 Mdot
.59999 .65097 Mdot
.61568 .66665 Mdot
.6196 .67057 Mdot
.62744 .6745 Mdot
.63136 .6745 Mdot
.62352 .66665 Mdot
.63136 .68626 Mdot
.64313 .69802 Mdot
.64705 .69802 Mdot
.64313 .69802 Mdot
.64705 .69018 Mdot
.65881 .69802 Mdot
.67057 .70587 Mdot
.6745 .70587 Mdot
.67842 .71371 Mdot
.68234 .72155 Mdot
.6745 .71371 Mdot
.67057 .70979 Mdot
.68234 .72155 Mdot
.6941 .73724 Mdot
.69018 .73332 Mdot
.69018 .73332 Mdot
.6941 .72939 Mdot
.70194 .74116 Mdot
.70194 .73724 Mdot
.70979 .74116 Mdot
.71371 .74508 Mdot
.72939 .75292 Mdot
.73332 .76076 Mdot
.72939 .749 Mdot
.72939 .74508 Mdot
.73332 .75292 Mdot
.73332 .75684 Mdot
.73332 .76076 Mdot
.72547 .75684 Mdot
.72939 .76076 Mdot
.73332 .76861 Mdot
.74116 .78037 Mdot
.74116 .77645 Mdot
.74508 .78429 Mdot
.74508 .78429 Mdot
.74508 .77645 Mdot
.749 .78037 Mdot
.749 .77645 Mdot
.749 .78037 Mdot
.749 .78037 Mdot
.75684 .78821 Mdot
.75292 .77645 Mdot
.74508 .76469 Mdot
.75292 .77645 Mdot
.75292 .78821 Mdot
.75684 .79998 Mdot
.75684 .79606 Mdot
.75292 .78821 Mdot
.74508 .78429 Mdot
.749 .78429 Mdot
.74508 .78037 Mdot
.749 .78429 Mdot
.75292 .78429 Mdot
.74116 .77253 Mdot
.73332 .76861 Mdot
.71371 .749 Mdot
.72155 .75684 Mdot
.86272 .88232 Mdot
.5098 .56862 Mdot
.52549 .58431 Mdot
.53725 .59607 Mdot
.52941 .59215 Mdot
.53333 .58823 Mdot
.52549 .58431 Mdot
.51372 .57254 Mdot
.51372 .58431 Mdot
.52941 .60783 Mdot
.53725 .61568 Mdot
.54117 .6196 Mdot
.54902 .62352 Mdot
.55294 .62744 Mdot
.55686 .63136 Mdot
.55686 .63528 Mdot
.57254 .6392 Mdot
.56862 .62744 Mdot
.58039 .63528 Mdot
.58039 .6392 Mdot
.58823 .65097 Mdot
.58431 .64705 Mdot
.60391 .65881 Mdot
.59999 .65489 Mdot
.60783 .65489 Mdot
.59999 .64705 Mdot
.59215 .64313 Mdot
.61176 .66273 Mdot
.6196 .67057 Mdot
.63136 .6745 Mdot
.63528 .68234 Mdot
.63136 .68234 Mdot
.6392 .6941 Mdot
.6392 .69018 Mdot
.64313 .69018 Mdot
.65097 .68626 Mdot
.65489 .68626 Mdot
.66273 .69802 Mdot
.66665 .70587 Mdot
.66665 .70194 Mdot
.68234 .72155 Mdot
.69018 .72939 Mdot
.68626 .72155 Mdot
.68234 .71763 Mdot
.67842 .71763 Mdot
.68234 .72547 Mdot
.6941 .72939 Mdot
.70194 .73724 Mdot
.70979 .73724 Mdot
.70979 .73724 Mdot
.71763 .73724 Mdot
.72155 .74116 Mdot
.73332 .749 Mdot
.73332 .749 Mdot
.73724 .75292 Mdot
.73332 .749 Mdot
.73724 .75684 Mdot
.72939 .75292 Mdot
.73724 .76861 Mdot
.73724 .76861 Mdot
.73332 .76861 Mdot
.72547 .76469 Mdot
.73332 .77253 Mdot
.73724 .77253 Mdot
.74116 .78037 Mdot
.74116 .78037 Mdot
.75292 .78429 Mdot
.75684 .78429 Mdot
.75292 .77645 Mdot
.749 .77645 Mdot
.74508 .77253 Mdot
.75684 .78037 Mdot
.76469 .78429 Mdot
.76469 .78037 Mdot
.76469 .78037 Mdot
.75684 .78037 Mdot
.76469 .79213 Mdot
.75684 .78037 Mdot
.76076 .79213 Mdot
.76076 .79213 Mdot
.75684 .78821 Mdot
.75292 .78429 Mdot
.75292 .78429 Mdot
.749 .77645 Mdot
.75684 .78821 Mdot
.75292 .78037 Mdot
.74116 .77253 Mdot
.73332 .76076 Mdot
.73332 .76861 Mdot
.72155 .76469 Mdot
.78429 .81566 Mdot
.84311 .86664 Mdot
.49412 .56078 Mdot
.51765 .58431 Mdot
.52549 .59607 Mdot
.51765 .58431 Mdot
.51372 .58431 Mdot
.51765 .58431 Mdot
.51372 .58823 Mdot
.52157 .59607 Mdot
.52549 .61176 Mdot
.52549 .61176 Mdot
.53333 .60783 Mdot
.54509 .61568 Mdot
.55686 .62352 Mdot
.57254 .6392 Mdot
.56862 .62744 Mdot
.57254 .62744 Mdot
.58039 .63136 Mdot
.59215 .64313 Mdot
.59999 .64313 Mdot
.59607 .64705 Mdot
.59607 .65097 Mdot
.59607 .65881 Mdot
.60391 .65881 Mdot
.60391 .65881 Mdot
.6196 .6745 Mdot
.61176 .65881 Mdot
.60783 .65881 Mdot
.61568 .66665 Mdot
.62744 .67842 Mdot
.62744 .68234 Mdot
.62352 .6745 Mdot
.62744 .67842 Mdot
.6392 .69018 Mdot
.64313 .69018 Mdot
.65489 .6941 Mdot
.65881 .69802 Mdot
.66665 .70194 Mdot
.67057 .70979 Mdot
.66665 .71371 Mdot
.67842 .72155 Mdot
.67842 .71763 Mdot
.69018 .72155 Mdot
.6941 .73332 Mdot
.69018 .72939 Mdot
.68626 .72939 Mdot
.6941 .73724 Mdot
.70979 .73724 Mdot
.71763 .74116 Mdot
.71763 .73332 Mdot
.72939 .74508 Mdot
.73332 .749 Mdot
.74116 .75684 Mdot
.73724 .75292 Mdot
.73724 .75292 Mdot
.73724 .75292 Mdot
.73724 .75292 Mdot
.72939 .749 Mdot
.73332 .76076 Mdot
.72939 .76076 Mdot
.74116 .77645 Mdot
.749 .78429 Mdot
.74508 .77253 Mdot
.74508 .77253 Mdot
.75292 .77645 Mdot
.75292 .77645 Mdot
.749 .77253 Mdot
.75292 .77645 Mdot
.75684 .78429 Mdot
.75684 .78821 Mdot
.749 .78429 Mdot
.75292 .78429 Mdot
.75684 .78429 Mdot
.76469 .78429 Mdot
.77253 .78821 Mdot
.76469 .78429 Mdot
.77253 .79213 Mdot
.76076 .78429 Mdot
.76076 .78821 Mdot
.76469 .78821 Mdot
.76469 .79606 Mdot
.76469 .79606 Mdot
.75684 .78429 Mdot
.75684 .78821 Mdot
.75684 .79213 Mdot
.75684 .78821 Mdot
.75684 .78821 Mdot
.75292 .78821 Mdot
.74508 .78037 Mdot
.74508 .78821 Mdot
.73724 .78037 Mdot
.73332 .78037 Mdot
.71763 .76469 Mdot
.77645 .81174 Mdot
.92546 .93722 Mdot
.47843 .55294 Mdot
.5098 .58431 Mdot
.52941 .60783 Mdot
.52549 .59607 Mdot
.51372 .58039 Mdot
.5098 .57646 Mdot
.51765 .58823 Mdot
.52549 .59607 Mdot
.52549 .59999 Mdot
.53333 .60783 Mdot
.54117 .61568 Mdot
.55294 .61568 Mdot
.55686 .62744 Mdot
.56862 .63528 Mdot
.57254 .63136 Mdot
.58431 .63136 Mdot
.58039 .62352 Mdot
.58823 .63528 Mdot
.58823 .63528 Mdot
.58823 .6392 Mdot
.59999 .65489 Mdot
.59607 .65097 Mdot
.59999 .65489 Mdot
.60783 .65881 Mdot
.6196 .6745 Mdot
.61176 .66665 Mdot
.62744 .67842 Mdot
.6196 .66665 Mdot
.63528 .67842 Mdot
.6392 .68626 Mdot
.65097 .6941 Mdot
.6392 .68626 Mdot
.64313 .68626 Mdot
.64705 .69018 Mdot
.64705 .6941 Mdot
.64313 .68626 Mdot
.65097 .69802 Mdot
.65489 .70194 Mdot
.66273 .71371 Mdot
.67057 .72155 Mdot
.6745 .71763 Mdot
.68626 .72547 Mdot
.67842 .71371 Mdot
.69018 .72547 Mdot
.69018 .72547 Mdot
.6941 .73332 Mdot
.70587 .73332 Mdot
.71371 .73332 Mdot
.71371 .72939 Mdot
.71763 .73724 Mdot
.72155 .74508 Mdot
.73332 .749 Mdot
.74116 .76076 Mdot
.73332 .75684 Mdot
.73332 .76076 Mdot
.72939 .75684 Mdot
.72939 .75684 Mdot
.74116 .76469 Mdot
.73724 .76076 Mdot
.749 .77645 Mdot
.76076 .79213 Mdot
.74116 .77253 Mdot
.74508 .76861 Mdot
.74508 .77253 Mdot
.74116 .76861 Mdot
.74508 .77645 Mdot
.74508 .76861 Mdot
.75292 .78037 Mdot
.75292 .78429 Mdot
.75684 .78821 Mdot
.75684 .78821 Mdot
.74508 .77645 Mdot
.75684 .78037 Mdot
.77253 .78429 Mdot
.77253 .78821 Mdot
.76861 .78037 Mdot
.76861 .78429 Mdot
.77253 .78821 Mdot
.76861 .78429 Mdot
.77253 .78821 Mdot
.76861 .78821 Mdot
.76469 .78821 Mdot
.76076 .78821 Mdot
.76469 .78821 Mdot
.76861 .78821 Mdot
.76469 .78429 Mdot
.76469 .78821 Mdot
.74508 .77253 Mdot
.74116 .76861 Mdot
.749 .78037 Mdot
.74508 .77645 Mdot
.74116 .77645 Mdot
.73332 .77253 Mdot
.72939 .76861 Mdot
.72547 .76469 Mdot
.8588 .88232 Mdot
.92546 .93722 Mdot
.4902 .55686 Mdot
.50588 .57646 Mdot
.52157 .59607 Mdot
.52549 .59215 Mdot
.51372 .58039 Mdot
.53333 .59607 Mdot
.53333 .59215 Mdot
.53725 .59999 Mdot
.52157 .58823 Mdot
.52549 .59215 Mdot
.53333 .59999 Mdot
.54117 .61176 Mdot
.54902 .6196 Mdot
.56862 .6392 Mdot
.57254 .6392 Mdot
.57254 .62744 Mdot
.58039 .63136 Mdot
.58039 .63528 Mdot
.58039 .6392 Mdot
.58431 .64313 Mdot
.59215 .64705 Mdot
.60783 .65881 Mdot
.61568 .66273 Mdot
.61568 .67057 Mdot
.60783 .65881 Mdot
.61176 .66665 Mdot
.62744 .6745 Mdot
.63136 .6745 Mdot
.63528 .67842 Mdot
.6392 .68234 Mdot
.6392 .68234 Mdot
.6392 .67842 Mdot
.63528 .6745 Mdot
.64313 .68234 Mdot
.64313 .68626 Mdot
.64705 .69018 Mdot
.65097 .6941 Mdot
.65881 .70979 Mdot
.65489 .70587 Mdot
.66273 .70587 Mdot
.6745 .70979 Mdot
.67842 .70979 Mdot
.68234 .71371 Mdot
.67842 .70979 Mdot
.69018 .72155 Mdot
.6941 .72155 Mdot
.70194 .72547 Mdot
.70979 .73724 Mdot
.70979 .73724 Mdot
.72155 .749 Mdot
.71371 .74508 Mdot
.72155 .75292 Mdot
.70587 .73724 Mdot
.71371 .75292 Mdot
.72939 .76469 Mdot
.72547 .76076 Mdot
.72155 .75292 Mdot
.74116 .76861 Mdot
.72547 .749 Mdot
.73332 .749 Mdot
.74508 .76861 Mdot
.74508 .77253 Mdot
.749 .78429 Mdot
.75684 .78429 Mdot
.749 .77253 Mdot
.75292 .78037 Mdot
.74508 .76861 Mdot
.749 .77645 Mdot
.75292 .78429 Mdot
.75684 .78429 Mdot
.75684 .78429 Mdot
.76076 .78821 Mdot
.76861 .78821 Mdot
.76861 .78821 Mdot
.77253 .79213 Mdot
.77253 .78821 Mdot
.77645 .79606 Mdot
.76469 .78037 Mdot
.77253 .78429 Mdot
.77645 .79213 Mdot
.77253 .78821 Mdot
.77645 .78821 Mdot
.77253 .78821 Mdot
.76861 .78429 Mdot
.77253 .78821 Mdot
.77645 .78821 Mdot
.77645 .79213 Mdot
.76469 .78429 Mdot
.76076 .78429 Mdot
.75292 .77645 Mdot
.75292 .78429 Mdot
.749 .77645 Mdot
.74508 .76861 Mdot
.74508 .78037 Mdot
.74508 .78037 Mdot
.72939 .77645 Mdot
.71371 .76469 Mdot
.65881 .69802 Mdot
.84311 .86664 Mdot
.47843 .54902 Mdot
.5098 .57646 Mdot
.51372 .58431 Mdot
.52157 .58823 Mdot
.52157 .58823 Mdot
.52941 .58823 Mdot
.53725 .59999 Mdot
.52941 .59215 Mdot
.52157 .58823 Mdot
.52549 .59999 Mdot
.53725 .61176 Mdot
.54117 .61568 Mdot
.54509 .62352 Mdot
.54902 .62352 Mdot
.55294 .62744 Mdot
.56078 .63136 Mdot
.5647 .62744 Mdot
.56862 .62744 Mdot
.56862 .62744 Mdot
.56862 .63136 Mdot
.59607 .65097 Mdot
.60391 .65489 Mdot
.59999 .64705 Mdot
.60391 .64705 Mdot
.60391 .64705 Mdot
.61568 .66665 Mdot
.6196 .6745 Mdot
.62744 .6745 Mdot
.63136 .67842 Mdot
.62744 .67842 Mdot
.62744 .68234 Mdot
.63528 .68626 Mdot
.6392 .68626 Mdot
.65097 .6941 Mdot
.65097 .69018 Mdot
.64705 .6941 Mdot
.64705 .6941 Mdot
.65097 .69802 Mdot
.65097 .69802 Mdot
.66665 .70194 Mdot
.6745 .70979 Mdot
.68626 .71763 Mdot
.68626 .71763 Mdot
.69802 .72547 Mdot
.69018 .71763 Mdot
.69802 .72939 Mdot
.69018 .72547 Mdot
.70194 .74116 Mdot
.70979 .749 Mdot
.71371 .74508 Mdot
.70979 .749 Mdot
.71371 .749 Mdot
.72155 .75684 Mdot
.71371 .74508 Mdot
.70587 .73724 Mdot
.71371 .74508 Mdot
.70979 .74508 Mdot
.72155 .75684 Mdot
.72547 .75684 Mdot
.73332 .76076 Mdot
.74508 .76861 Mdot
.74508 .76469 Mdot
.75292 .77645 Mdot
.75684 .77645 Mdot
.74508 .76469 Mdot
.749 .76469 Mdot
.74508 .76861 Mdot
.74508 .76469 Mdot
.75684 .78037 Mdot
.75292 .77645 Mdot
.75292 .77253 Mdot
.76469 .78821 Mdot
.78037 .79606 Mdot
.76861 .79213 Mdot
.76076 .78429 Mdot
.77253 .79998 Mdot
.77253 .79213 Mdot
.77645 .79213 Mdot
.77253 .78821 Mdot
.77253 .78429 Mdot
.77253 .78429 Mdot
.76076 .77645 Mdot
.77645 .79213 Mdot
.76469 .78037 Mdot
.76469 .77645 Mdot
.76076 .77645 Mdot
.76861 .78037 Mdot
.76469 .77253 Mdot
.77253 .78821 Mdot
.76076 .77645 Mdot
.76076 .77645 Mdot
.75684 .77253 Mdot
.75292 .77645 Mdot
.749 .77645 Mdot
.75292 .78429 Mdot
.74116 .77253 Mdot
.73332 .76861 Mdot
.72547 .76469 Mdot
.70979 .75292 Mdot
.70194 .749 Mdot
.77253 .80782 Mdot
.79998 .81958 Mdot
.47059 .54117 Mdot
.51372 .59215 Mdot
.52549 .59999 Mdot
.51765 .59215 Mdot
.52157 .59215 Mdot
.52157 .59215 Mdot
.52549 .58823 Mdot
.52549 .59607 Mdot
.51765 .58823 Mdot
.52941 .60391 Mdot
.53333 .61568 Mdot
.53725 .61568 Mdot
.53725 .6196 Mdot
.54117 .6196 Mdot
.54117 .61176 Mdot
.54509 .6196 Mdot
.55294 .6196 Mdot
.5647 .62744 Mdot
.56862 .62744 Mdot
.57646 .63528 Mdot
.58823 .6392 Mdot
.59607 .65097 Mdot
.60783 .65881 Mdot
.59999 .64705 Mdot
.60783 .65489 Mdot
.61176 .66273 Mdot
.61176 .67057 Mdot
.61568 .67057 Mdot
.6196 .67842 Mdot
.6196 .67842 Mdot
.62744 .68234 Mdot
.63528 .68234 Mdot
.65097 .69802 Mdot
.65489 .69802 Mdot
.65097 .6941 Mdot
.64705 .69018 Mdot
.65097 .6941 Mdot
.64705 .69802 Mdot
.65489 .70194 Mdot
.66273 .70194 Mdot
.66665 .69802 Mdot
.67842 .71371 Mdot
.68234 .71763 Mdot
.68234 .71763 Mdot
.68234 .71371 Mdot
.68626 .72547 Mdot
.68234 .72155 Mdot
.68626 .72155 Mdot
.69018 .72547 Mdot
.6941 .72939 Mdot
.70194 .73332 Mdot
.70587 .72939 Mdot
.70979 .73724 Mdot
.71371 .74508 Mdot
.71371 .74508 Mdot
.71371 .74508 Mdot
.71371 .74116 Mdot
.72155 .75292 Mdot
.72547 .75684 Mdot
.73332 .75684 Mdot
.73332 .749 Mdot
.73332 .749 Mdot
.74508 .76469 Mdot
.749 .76861 Mdot
.75292 .77645 Mdot
.75684 .78429 Mdot
.75292 .78037 Mdot
.74508 .76469 Mdot
.74116 .76469 Mdot
.75292 .77645 Mdot
.749 .77253 Mdot
.749 .77253 Mdot
.74116 .76076 Mdot
.75292 .77645 Mdot
.75292 .78037 Mdot
.75292 .78429 Mdot
.76469 .78821 Mdot
.76469 .78037 Mdot
.76861 .78037 Mdot
.75684 .77253 Mdot
.76469 .78037 Mdot
.75684 .78037 Mdot
.76076 .78821 Mdot
.76469 .78429 Mdot
.75684 .78037 Mdot
.76076 .77645 Mdot
.76861 .78821 Mdot
.75684 .77645 Mdot
.76861 .78821 Mdot
.76469 .77645 Mdot
.75684 .76861 Mdot
.76076 .77253 Mdot
.75292 .77253 Mdot
.74508 .77253 Mdot
.74508 .77253 Mdot
.74116 .76861 Mdot
.74508 .78037 Mdot
.73724 .78037 Mdot
.71371 .75684 Mdot
.70979 .75292 Mdot
.71371 .749 Mdot
.70979 .749 Mdot
.70194 .749 Mdot
.749 .78037 Mdot
.91761 .92546 Mdot
.49804 .57646 Mdot
.51372 .58823 Mdot
.52549 .60391 Mdot
.52157 .59607 Mdot
.52941 .60391 Mdot
.52941 .60391 Mdot
.51372 .58431 Mdot
.52157 .59999 Mdot
.52549 .60391 Mdot
.52549 .60391 Mdot
.52549 .59999 Mdot
.52941 .60783 Mdot
.54117 .62352 Mdot
.54902 .62744 Mdot
.55686 .63528 Mdot
.56078 .63528 Mdot
.56862 .6392 Mdot
.56862 .63136 Mdot
.57646 .63136 Mdot
.58431 .63136 Mdot
.58431 .63528 Mdot
.58823 .6392 Mdot
.59607 .64705 Mdot
.61176 .65881 Mdot
.60391 .65489 Mdot
.60783 .66665 Mdot
.61176 .6745 Mdot
.6196 .67842 Mdot
.63528 .68626 Mdot
.63528 .68234 Mdot
.6392 .68626 Mdot
.64313 .68626 Mdot
.64705 .68626 Mdot
.65881 .70194 Mdot
.66273 .70587 Mdot
.65881 .70587 Mdot
.65881 .70587 Mdot
.65881 .70587 Mdot
.65489 .69802 Mdot
.6745 .70979 Mdot
.6745 .70587 Mdot
.67842 .71371 Mdot
.6745 .71371 Mdot
.6745 .71371 Mdot
.67842 .71763 Mdot
.67842 .71763 Mdot
.68626 .72547 Mdot
.6941 .72547 Mdot
.69802 .72547 Mdot
.6941 .72155 Mdot
.70587 .73332 Mdot
.70979 .73332 Mdot
.71371 .73724 Mdot
.71371 .74508 Mdot
.70587 .74508 Mdot
.70587 .74508 Mdot
.71371 .74116 Mdot
.72939 .76076 Mdot
.72939 .75292 Mdot
.73332 .749 Mdot
.73724 .75684 Mdot
.73724 .75684 Mdot
.74116 .76469 Mdot
.73724 .76469 Mdot
.73332 .76469 Mdot
.73332 .76861 Mdot
.72547 .75684 Mdot
.74508 .76861 Mdot
.74508 .76861 Mdot
.74116 .76469 Mdot
.73724 .76076 Mdot
.749 .76861 Mdot
.749 .77253 Mdot
.74508 .76861 Mdot
.74116 .76469 Mdot
.75292 .77645 Mdot
.75292 .77645 Mdot
.76076 .79213 Mdot
.75684 .78429 Mdot
.75292 .78037 Mdot
.76076 .78429 Mdot
.76469 .78037 Mdot
.76076 .78037 Mdot
.76861 .78821 Mdot
.77645 .79213 Mdot
.77253 .78821 Mdot
.75684 .77645 Mdot
.76076 .77645 Mdot
.76861 .78429 Mdot
.76861 .78037 Mdot
.76076 .77645 Mdot
.75684 .77645 Mdot
.749 .77253 Mdot
.75684 .78037 Mdot
.749 .77645 Mdot
.749 .77645 Mdot
.74508 .77645 Mdot
.74508 .78037 Mdot
.74116 .77645 Mdot
.73332 .76076 Mdot
.73332 .76076 Mdot
.73332 .76076 Mdot
.72939 .76076 Mdot
.70979 .74116 Mdot
.70979 .74508 Mdot
.6941 .74116 Mdot
.83135 .85095 Mdot
.90193 .90585 Mdot
.47843 .54902 Mdot
.51372 .58823 Mdot
.52157 .59999 Mdot
.52157 .59607 Mdot
.52549 .59607 Mdot
.52549 .60391 Mdot
.52549 .60391 Mdot
.53333 .61568 Mdot
.52157 .60391 Mdot
.53725 .61568 Mdot
.53725 .61568 Mdot
.53725 .61568 Mdot
.54509 .62744 Mdot
.55686 .6392 Mdot
.5647 .64313 Mdot
.56078 .6392 Mdot
.5647 .6392 Mdot
.57646 .6392 Mdot
.58039 .64313 Mdot
.58039 .64313 Mdot
.58039 .64313 Mdot
.59215 .65489 Mdot
.59215 .65489 Mdot
.60391 .66273 Mdot
.61176 .67057 Mdot
.61568 .6745 Mdot
.62352 .68234 Mdot
.62352 .68234 Mdot
.6392 .69018 Mdot
.65097 .70194 Mdot
.65097 .69018 Mdot
.64313 .68234 Mdot
.65489 .6941 Mdot
.66273 .70587 Mdot
.66273 .70587 Mdot
.66665 .71371 Mdot
.67057 .71371 Mdot
.67057 .71763 Mdot
.66665 .71763 Mdot
.67057 .72547 Mdot
.6745 .72547 Mdot
.67842 .73332 Mdot
.66665 .71371 Mdot
.67842 .72547 Mdot
.68626 .72939 Mdot
.68234 .72939 Mdot
.68626 .72155 Mdot
.69802 .72939 Mdot
.70194 .72547 Mdot
.70587 .72547 Mdot
.70979 .73332 Mdot
.71371 .73724 Mdot
.72547 .75292 Mdot
.71763 .74116 Mdot
.71763 .74508 Mdot
.72547 .76076 Mdot
.72547 .75684 Mdot
.73724 .76861 Mdot
.72547 .76076 Mdot
.72155 .75292 Mdot
.72155 .75292 Mdot
.72939 .76076 Mdot
.73332 .76861 Mdot
.73332 .76861 Mdot
.73332 .76861 Mdot
.73332 .76469 Mdot
.74116 .76861 Mdot
.749 .78037 Mdot
.75292 .77253 Mdot
.75684 .77645 Mdot
.75684 .77645 Mdot
.76469 .78429 Mdot
.749 .76861 Mdot
.75684 .78037 Mdot
.76469 .79213 Mdot
.76076 .78821 Mdot
.75684 .78429 Mdot
.76469 .79998 Mdot
.76469 .79606 Mdot
.76861 .79998 Mdot
.77253 .8039 Mdot
.76861 .79998 Mdot
.76469 .79213 Mdot
.76076 .79213 Mdot
.76076 .78429 Mdot
.76469 .78821 Mdot
.75684 .78429 Mdot
.76076 .78821 Mdot
.76076 .78429 Mdot
.76076 .78821 Mdot
.749 .77253 Mdot
.75684 .77645 Mdot
.75292 .77645 Mdot
.76469 .78429 Mdot
.76469 .78821 Mdot
.76076 .78429 Mdot
.75684 .78429 Mdot
.75292 .77645 Mdot
.76076 .78429 Mdot
.76076 .78429 Mdot
.75684 .78037 Mdot
.749 .77645 Mdot
.749 .77645 Mdot
.74508 .76861 Mdot
.74116 .77253 Mdot
.73332 .76469 Mdot
.71763 .749 Mdot
.70587 .73724 Mdot
.66665 .70194 Mdot
.82743 .85095 Mdot
.47059 .54117 Mdot
.50196 .57254 Mdot
.51765 .58823 Mdot
.51765 .58823 Mdot
.51372 .58431 Mdot
.52941 .60391 Mdot
.52157 .59999 Mdot
.52549 .59607 Mdot
.52157 .59607 Mdot
.52941 .59999 Mdot
.54902 .6196 Mdot
.54902 .6196 Mdot
.54902 .62352 Mdot
.55686 .63528 Mdot
.57254 .64313 Mdot
.56862 .6392 Mdot
.56078 .62352 Mdot
.56078 .62352 Mdot
.56078 .62744 Mdot
.56862 .6392 Mdot
.57646 .64313 Mdot
.58431 .65097 Mdot
.59607 .65881 Mdot
.59607 .65489 Mdot
.60783 .67057 Mdot
.60783 .67057 Mdot
.61176 .6745 Mdot
.62352 .67842 Mdot
.63136 .68626 Mdot
.63528 .68626 Mdot
.65097 .69018 Mdot
.63528 .6745 Mdot
.64705 .69018 Mdot
.65881 .69802 Mdot
.66273 .70194 Mdot
.66665 .70979 Mdot
.66665 .70979 Mdot
.6745 .71371 Mdot
.6745 .71371 Mdot
.67057 .72155 Mdot
.6745 .72547 Mdot
.66665 .71763 Mdot
.66665 .71763 Mdot
.67842 .71763 Mdot
.6941 .72547 Mdot
.69802 .72939 Mdot
.70587 .73332 Mdot
.70979 .72939 Mdot
.70587 .72939 Mdot
.70979 .73332 Mdot
.71763 .73724 Mdot
.71763 .72939 Mdot
.72155 .73332 Mdot
.71371 .72939 Mdot
.72155 .73724 Mdot
.72939 .75292 Mdot
.72939 .75292 Mdot
.73332 .75684 Mdot
.73332 .75292 Mdot
.73332 .75684 Mdot
.73332 .75684 Mdot
.73332 .76076 Mdot
.73724 .77253 Mdot
.74116 .77253 Mdot
.72939 .76076 Mdot
.749 .77253 Mdot
.74116 .76076 Mdot
.75292 .77253 Mdot
.749 .76861 Mdot
.749 .76469 Mdot
.749 .76469 Mdot
.75292 .77253 Mdot
.749 .76861 Mdot
.76469 .78037 Mdot
.75684 .77645 Mdot
.75292 .77253 Mdot
.75684 .78429 Mdot
.75292 .78037 Mdot
.75684 .78429 Mdot
.76861 .78821 Mdot
.77253 .78821 Mdot
.77645 .79606 Mdot
.76469 .78429 Mdot
.76076 .78429 Mdot
.75684 .78037 Mdot
.75684 .78037 Mdot
.75684 .78821 Mdot
.75684 .78429 Mdot
.75684 .78429 Mdot
.76469 .79213 Mdot
.75684 .78037 Mdot
.75684 .78037 Mdot
.76469 .78037 Mdot
.76861 .78429 Mdot
.77253 .78821 Mdot
.77253 .78429 Mdot
.76469 .78037 Mdot
.76469 .78037 Mdot
.76861 .78429 Mdot
.76076 .77645 Mdot
.75684 .78037 Mdot
.75292 .77645 Mdot
.75292 .77645 Mdot
.749 .76861 Mdot
.74508 .76861 Mdot
.73724 .76076 Mdot
.73332 .75684 Mdot
.72155 .74508 Mdot
.71371 .73724 Mdot
.70979 .74116 Mdot
.65881 .69018 Mdot
.72155 .74508 Mdot
.77645 .78821 Mdot
.47451 .54509 Mdot
.50588 .57254 Mdot
.52549 .58823 Mdot
.52549 .58823 Mdot
.50196 .56862 Mdot
.50588 .57254 Mdot
.50196 .58039 Mdot
.51372 .58823 Mdot
.52549 .59999 Mdot
.53725 .60783 Mdot
.53725 .59999 Mdot
.53725 .60391 Mdot
.53725 .60783 Mdot
.54117 .61568 Mdot
.55294 .6196 Mdot
.56078 .6196 Mdot
.57646 .62744 Mdot
.56078 .61568 Mdot
.5647 .62352 Mdot
.5647 .63136 Mdot
.57646 .64705 Mdot
.58431 .65489 Mdot
.58431 .64705 Mdot
.59607 .65489 Mdot
.59607 .65489 Mdot
.59215 .65489 Mdot
.60783 .67057 Mdot
.62352 .67842 Mdot
.62744 .67842 Mdot
.62744 .67057 Mdot
.63136 .67057 Mdot
.63136 .67057 Mdot
.64313 .68626 Mdot
.65097 .69018 Mdot
.65881 .69018 Mdot
.66273 .6941 Mdot
.65881 .6941 Mdot
.65489 .6941 Mdot
.65489 .6941 Mdot
.66665 .70979 Mdot
.66665 .70979 Mdot
.67057 .71371 Mdot
.67842 .72155 Mdot
.68234 .71763 Mdot
.6941 .71763 Mdot
.6941 .72155 Mdot
.70194 .72547 Mdot
.70587 .72939 Mdot
.70194 .72547 Mdot
.70587 .72939 Mdot
.71371 .73332 Mdot
.71763 .74116 Mdot
.72155 .74116 Mdot
.71371 .73332 Mdot
.70979 .73332 Mdot
.70979 .73332 Mdot
.71763 .74116 Mdot
.72155 .75292 Mdot
.72155 .75292 Mdot
.72547 .75292 Mdot
.71763 .74508 Mdot
.71763 .74508 Mdot
.72939 .75684 Mdot
.72939 .74116 Mdot
.72939 .74508 Mdot
.73332 .749 Mdot
.73724 .75684 Mdot
.74116 .76076 Mdot
.74508 .76469 Mdot
.75292 .77253 Mdot
.749 .76469 Mdot
.75684 .76469 Mdot
.76469 .77253 Mdot
.76076 .77253 Mdot
.75684 .76469 Mdot
.76469 .77645 Mdot
.75684 .77645 Mdot
.75684 .78037 Mdot
.76076 .78037 Mdot
.76076 .77645 Mdot
.76469 .78429 Mdot
.76469 .78821 Mdot
.75292 .78037 Mdot
.75684 .78429 Mdot
.74508 .76861 Mdot
.74508 .76469 Mdot
.74508 .76469 Mdot
.75292 .78429 Mdot
.75684 .78037 Mdot
.749 .77253 Mdot
.75292 .78037 Mdot
.749 .77253 Mdot
.749 .77253 Mdot
.76469 .78429 Mdot
.76469 .77645 Mdot
.76076 .76861 Mdot
.76076 .77645 Mdot
.75684 .77645 Mdot
.75684 .77253 Mdot
.75684 .77253 Mdot
.75292 .77253 Mdot
.73724 .76076 Mdot
.74116 .76076 Mdot
.72547 .74508 Mdot
.72155 .74116 Mdot
.73724 .75684 Mdot
.72939 .75292 Mdot
.72939 .75292 Mdot
.72547 .74508 Mdot
.72155 .74116 Mdot
.71371 .72939 Mdot
.70194 .72155 Mdot
.6941 .71763 Mdot
.62744 .65097 Mdot
.70587 .73332 Mdot
.90585 .91761 Mdot
.45883 .54117 Mdot
.49412 .57254 Mdot
.5098 .58039 Mdot
.51372 .57646 Mdot
.5098 .57646 Mdot
.49804 .5647 Mdot
.50196 .58039 Mdot
.49804 .58039 Mdot
.51765 .59215 Mdot
.51765 .59215 Mdot
.52941 .59999 Mdot
.53333 .59999 Mdot
.52941 .60391 Mdot
.53333 .61176 Mdot
.54117 .60783 Mdot
.54902 .61176 Mdot
.55686 .6196 Mdot
.56078 .61568 Mdot
.56862 .62744 Mdot
.55686 .6196 Mdot
.56078 .62744 Mdot
.57254 .6392 Mdot
.57254 .62744 Mdot
.58823 .64313 Mdot
.58823 .64313 Mdot
.59215 .64705 Mdot
.60391 .65881 Mdot
.61568 .67057 Mdot
.62352 .67057 Mdot
.62744 .66665 Mdot
.63136 .66665 Mdot
.63528 .67057 Mdot
.63528 .6745 Mdot
.63528 .6745 Mdot
.65097 .67842 Mdot
.65881 .68626 Mdot
.66273 .6941 Mdot
.66273 .70194 Mdot
.66665 .70587 Mdot
.67057 .70587 Mdot
.6745 .70587 Mdot
.66665 .69802 Mdot
.6745 .70587 Mdot
.67842 .70587 Mdot
.69802 .72155 Mdot
.69018 .71763 Mdot
.70194 .72547 Mdot
.70194 .72547 Mdot
.70194 .72547 Mdot
.70587 .72939 Mdot
.70587 .72547 Mdot
.70979 .72939 Mdot
.72155 .74116 Mdot
.72155 .73724 Mdot
.71371 .73332 Mdot
.70587 .72155 Mdot
.70587 .72547 Mdot
.70979 .73332 Mdot
.71371 .73724 Mdot
.70979 .73724 Mdot
.70979 .74116 Mdot
.71371 .73724 Mdot
.71763 .73332 Mdot
.72939 .74116 Mdot
.73724 .75292 Mdot
.72547 .73724 Mdot
.72939 .74116 Mdot
.73724 .749 Mdot
.74508 .75684 Mdot
.749 .76076 Mdot
.749 .749 Mdot
.749 .749 Mdot
.749 .749 Mdot
.76076 .75684 Mdot
.75292 .749 Mdot
.75684 .76076 Mdot
.75292 .76076 Mdot
.74508 .75684 Mdot
.75292 .77253 Mdot
.76469 .78037 Mdot
.75684 .78037 Mdot
.75684 .77645 Mdot
.74508 .76469 Mdot
.74508 .76861 Mdot
.74508 .76861 Mdot
.74508 .76469 Mdot
.749 .76469 Mdot
.75292 .77253 Mdot
.76861 .77645 Mdot
.76469 .77253 Mdot
.75684 .77253 Mdot
.749 .76469 Mdot
.749 .77253 Mdot
.749 .77253 Mdot
.76861 .78037 Mdot
.76469 .76861 Mdot
.75684 .76469 Mdot
.75684 .77253 Mdot
.74508 .76076 Mdot
.74116 .76469 Mdot
.73332 .75684 Mdot
.72939 .75292 Mdot
.74508 .76861 Mdot
.73332 .75292 Mdot
.72939 .74508 Mdot
.72939 .749 Mdot
.73332 .749 Mdot
.73332 .75684 Mdot
.72155 .73724 Mdot
.72155 .73724 Mdot
.71371 .73332 Mdot
.70587 .72939 Mdot
.70587 .73332 Mdot
.6941 .72547 Mdot
.68234 .71371 Mdot
.67057 .70587 Mdot
.65489 .70194 Mdot
.8235 .84311 Mdot
.84311 .83919 Mdot
.47059 .55686 Mdot
.48628 .57254 Mdot
.5098 .58823 Mdot
.5098 .58431 Mdot
.50196 .57254 Mdot
.50196 .57254 Mdot
.50196 .57646 Mdot
.51372 .58823 Mdot
.51372 .58823 Mdot
.52157 .59215 Mdot
.53333 .59999 Mdot
.54902 .61568 Mdot
.54509 .60783 Mdot
.55294 .62352 Mdot
.54509 .60783 Mdot
.55294 .60783 Mdot
.56078 .6196 Mdot
.56862 .6196 Mdot
.57254 .62744 Mdot
.57646 .63136 Mdot
.58431 .6392 Mdot
.58431 .64313 Mdot
.59215 .64705 Mdot
.58431 .6392 Mdot
.58431 .64313 Mdot
.58823 .6392 Mdot
.60391 .65489 Mdot
.61568 .66665 Mdot
.62352 .6745 Mdot
.62744 .67057 Mdot
.62744 .65881 Mdot
.6392 .66273 Mdot
.64313 .66665 Mdot
.64705 .67057 Mdot
.64313 .66665 Mdot
.66665 .69018 Mdot
.6745 .70587 Mdot
.6745 .69802 Mdot
.67057 .69802 Mdot
.67057 .70194 Mdot
.67842 .70979 Mdot
.67842 .70587 Mdot
.67842 .70194 Mdot
.6941 .71371 Mdot
.68626 .70979 Mdot
.6941 .71371 Mdot
.70194 .72155 Mdot
.70587 .72155 Mdot
.70587 .71763 Mdot
.70587 .72155 Mdot
.70979 .72547 Mdot
.71763 .72939 Mdot
.71371 .72155 Mdot
.72547 .74116 Mdot
.71371 .73724 Mdot
.70979 .72939 Mdot
.71371 .73724 Mdot
.70587 .72155 Mdot
.71763 .73332 Mdot
.72155 .74508 Mdot
.72547 .75292 Mdot
.71371 .73724 Mdot
.71763 .74116 Mdot
.71763 .74116 Mdot
.72939 .749 Mdot
.73724 .75292 Mdot
.73332 .75292 Mdot
.73724 .75292 Mdot
.74116 .749 Mdot
.749 .75292 Mdot
.75684 .75684 Mdot
.75292 .75292 Mdot
.75292 .75292 Mdot
.76076 .75292 Mdot
.76076 .75684 Mdot
.75684 .75292 Mdot
.76076 .75684 Mdot
.75684 .75684 Mdot
.749 .75292 Mdot
.75292 .76469 Mdot
.75684 .76861 Mdot
.75292 .77253 Mdot
.74116 .76076 Mdot
.74508 .76469 Mdot
.74508 .76469 Mdot
.75684 .76469 Mdot
.75292 .76076 Mdot
.75684 .76469 Mdot
.76469 .76861 Mdot
.76861 .77645 Mdot
.76469 .77253 Mdot
.76076 .77253 Mdot
.76469 .77645 Mdot
.76076 .76861 Mdot
.76469 .77253 Mdot
.76469 .77253 Mdot
.76076 .76469 Mdot
.75684 .76076 Mdot
.74116 .75292 Mdot
.74116 .76076 Mdot
.74116 .76076 Mdot
.73724 .75684 Mdot
.73332 .75684 Mdot
.73332 .75292 Mdot
.73724 .75684 Mdot
.72939 .75292 Mdot
.72939 .75292 Mdot
.72547 .749 Mdot
.72939 .75292 Mdot
.72547 .74508 Mdot
.72155 .74116 Mdot
.70979 .72939 Mdot
.70587 .72939 Mdot
.70979 .72939 Mdot
.70194 .72547 Mdot
.69018 .71763 Mdot
.68234 .71763 Mdot
.68234 .71763 Mdot
.57254 .59215 Mdot
.56862 .59999 Mdot
.61176 .59999 Mdot
.45883 .52941 Mdot
.50196 .58039 Mdot
.50588 .58431 Mdot
.51372 .59215 Mdot
.49804 .57646 Mdot
.50196 .57254 Mdot
.50196 .56862 Mdot
.51372 .58431 Mdot
.51765 .58039 Mdot
.51372 .58039 Mdot
.52941 .58823 Mdot
.53725 .59215 Mdot
.53725 .59607 Mdot
.54902 .60391 Mdot
.54902 .61176 Mdot
.54902 .60783 Mdot
.55686 .60391 Mdot
.5647 .60391 Mdot
.57254 .61568 Mdot
.58431 .63136 Mdot
.59215 .6392 Mdot
.58823 .63136 Mdot
.59215 .6392 Mdot
.59215 .64313 Mdot
.59999 .65489 Mdot
.60391 .65097 Mdot
.60783 .65489 Mdot
.60783 .65489 Mdot
.60783 .64705 Mdot
.61568 .65881 Mdot
.61568 .64705 Mdot
.63528 .65489 Mdot
.64705 .66273 Mdot
.65097 .66273 Mdot
.65489 .66273 Mdot
.66273 .6745 Mdot
.67057 .68234 Mdot
.6745 .69018 Mdot
.67842 .6941 Mdot
.69018 .71371 Mdot
.68626 .71371 Mdot
.68626 .70979 Mdot
.69018 .71371 Mdot
.69802 .71763 Mdot
.69018 .70587 Mdot
.6941 .70979 Mdot
.6941 .70979 Mdot
.70194 .71763 Mdot
.70587 .71763 Mdot
.70587 .71763 Mdot
.70979 .72155 Mdot
.70587 .71763 Mdot
.70979 .72547 Mdot
.70979 .72547 Mdot
.71371 .72939 Mdot
.70587 .72547 Mdot
.71371 .73332 Mdot
.72547 .73724 Mdot
.71763 .72547 Mdot
.72547 .73724 Mdot
.72939 .74508 Mdot
.72939 .74116 Mdot
.72547 .73332 Mdot
.72547 .73332 Mdot
.72547 .73724 Mdot
.72939 .74508 Mdot
.73724 .749 Mdot
.73724 .75684 Mdot
.73724 .75684 Mdot
.74508 .76076 Mdot
.74508 .76076 Mdot
.749 .75292 Mdot
.74508 .74508 Mdot
.73332 .72547 Mdot
.75292 .75292 Mdot
.75684 .75292 Mdot
.75292 .749 Mdot
.749 .74508 Mdot
.75292 .75292 Mdot
.75292 .75684 Mdot
.749 .75292 Mdot
.74116 .75292 Mdot
.74116 .75684 Mdot
.74116 .75684 Mdot
.74508 .76469 Mdot
.73724 .75292 Mdot
.75292 .76076 Mdot
.76076 .76076 Mdot
.75684 .76076 Mdot
.75292 .75684 Mdot
.75292 .76469 Mdot
.75292 .76861 Mdot
.75684 .76469 Mdot
.75292 .76076 Mdot
.75292 .75684 Mdot
.749 .75292 Mdot
.74508 .749 Mdot
.749 .75292 Mdot
.74116 .749 Mdot
.72939 .74508 Mdot
.72939 .75684 Mdot
.73332 .76076 Mdot
.74116 .76469 Mdot
.73332 .75684 Mdot
.73332 .749 Mdot
.72939 .749 Mdot
.72939 .749 Mdot
.72939 .75292 Mdot
.73332 .76076 Mdot
.73332 .75292 Mdot
.73332 .75292 Mdot
.72547 .74508 Mdot
.72155 .73724 Mdot
.71763 .73332 Mdot
.70979 .72939 Mdot
.70587 .72155 Mdot
.69802 .71763 Mdot
.68626 .71763 Mdot
.6745 .71371 Mdot
.66665 .70587 Mdot
.56862 .59999 Mdot
.3608 .3608 Mdot
.52157 .51372 Mdot
.58039 .55686 Mdot
.45883 .52549 Mdot
.48235 .55686 Mdot
.49412 .5647 Mdot
.49412 .5647 Mdot
.4902 .56078 Mdot
.48628 .55686 Mdot
.49804 .5647 Mdot
.50196 .57254 Mdot
.5098 .58039 Mdot
.51372 .58039 Mdot
.52549 .59215 Mdot
.53333 .59215 Mdot
.53333 .58823 Mdot
.55294 .61176 Mdot
.54902 .61176 Mdot
.55686 .61568 Mdot
.56078 .61568 Mdot
.56862 .6196 Mdot
.57254 .6196 Mdot
.57254 .62744 Mdot
.58431 .63528 Mdot
.58823 .63528 Mdot
.59607 .6392 Mdot
.58823 .63528 Mdot
.59999 .64313 Mdot
.60391 .65489 Mdot
.60391 .65489 Mdot
.59607 .64313 Mdot
.60783 .65489 Mdot
.61568 .65881 Mdot
.62744 .66273 Mdot
.63136 .66665 Mdot
.64313 .67057 Mdot
.65097 .66665 Mdot
.65881 .67842 Mdot
.65097 .66665 Mdot
.65097 .66665 Mdot
.65881 .6745 Mdot
.66273 .68234 Mdot
.66665 .69018 Mdot
.66665 .6941 Mdot
.6745 .70587 Mdot
.68234 .70979 Mdot
.68626 .70979 Mdot
.69018 .71763 Mdot
.68626 .71763 Mdot
.68626 .71763 Mdot
.68626 .72155 Mdot
.6941 .72939 Mdot
.69802 .72939 Mdot
.69802 .72547 Mdot
.69802 .72155 Mdot
.69802 .72155 Mdot
.70587 .73332 Mdot
.70587 .73332 Mdot
.70194 .72547 Mdot
.70979 .73724 Mdot
.71763 .73724 Mdot
.72155 .72547 Mdot
.72547 .72939 Mdot
.72939 .73332 Mdot
.72547 .72939 Mdot
.72939 .73724 Mdot
.72155 .72939 Mdot
.72547 .73724 Mdot
.72939 .749 Mdot
.72939 .75684 Mdot
.72939 .75684 Mdot
.72939 .749 Mdot
.73332 .75684 Mdot
.73332 .75684 Mdot
.74116 .76469 Mdot
.73332 .75292 Mdot
.74116 .75684 Mdot
.74116 .75684 Mdot
.74508 .76469 Mdot
.73724 .75684 Mdot
.74116 .749 Mdot
.74116 .75684 Mdot
.74508 .76076 Mdot
.74116 .76469 Mdot
.74116 .76469 Mdot
.74116 .76469 Mdot
.72939 .749 Mdot
.73724 .75684 Mdot
.74508 .76861 Mdot
.75292 .76861 Mdot
.75292 .76076 Mdot
.75684 .75684 Mdot
.76076 .76861 Mdot
.73724 .749 Mdot
.74508 .76469 Mdot
.74116 .76076 Mdot
.75292 .77253 Mdot
.75684 .76861 Mdot
.749 .76076 Mdot
.74508 .76076 Mdot
.74116 .75292 Mdot
.74508 .76076 Mdot
.74508 .76861 Mdot
.72939 .75292 Mdot
.72547 .75684 Mdot
.72547 .76076 Mdot
.72155 .749 Mdot
.72547 .74508 Mdot
.72155 .73332 Mdot
.71763 .72939 Mdot
.71371 .72939 Mdot
.72155 .74116 Mdot
.72155 .74508 Mdot
.71763 .73332 Mdot
.71763 .73724 Mdot
.71763 .74116 Mdot
.70979 .73332 Mdot
.70587 .72939 Mdot
.70587 .72547 Mdot
.70194 .72155 Mdot
.69802 .72155 Mdot
.68626 .71371 Mdot
.6745 .70587 Mdot
.67842 .71763 Mdot
.65881 .69802 Mdot
.57254 .59999 Mdot
.19218 .14513 Mdot
.22747 .19218 Mdot
.59999 .58431 Mdot
.79606 .78821 Mdot
.47843 .54509 Mdot
.50196 .57254 Mdot
.50196 .57646 Mdot
.50196 .57254 Mdot
.49412 .56078 Mdot
.48628 .55294 Mdot
.50588 .58039 Mdot
.50588 .57646 Mdot
.5098 .58039 Mdot
.5098 .57646 Mdot
.52549 .58431 Mdot
.52549 .58039 Mdot
.54117 .59607 Mdot
.54509 .60391 Mdot
.53333 .59215 Mdot
.54902 .60391 Mdot
.56078 .61176 Mdot
.56862 .62352 Mdot
.5647 .62352 Mdot
.5647 .62352 Mdot
.5647 .62744 Mdot
.57646 .63528 Mdot
.58039 .63136 Mdot
.58039 .63136 Mdot
.58039 .63528 Mdot
.58823 .63136 Mdot
.59215 .64313 Mdot
.59607 .64705 Mdot
.60783 .65489 Mdot
.60783 .65489 Mdot
.60391 .64705 Mdot
.61176 .65097 Mdot
.63136 .66665 Mdot
.63528 .66665 Mdot
.64705 .67057 Mdot
.65097 .6745 Mdot
.65097 .6745 Mdot
.65489 .6745 Mdot
.65097 .67057 Mdot
.65881 .68626 Mdot
.65881 .69018 Mdot
.66273 .6941 Mdot
.67057 .70194 Mdot
.68234 .70979 Mdot
.6745 .70194 Mdot
.6745 .70587 Mdot
.6745 .70587 Mdot
.68626 .72547 Mdot
.69802 .73332 Mdot
.69802 .73332 Mdot
.6941 .72547 Mdot
.70194 .72939 Mdot
.70587 .72939 Mdot
.70587 .73332 Mdot
.70194 .72939 Mdot
.6941 .72939 Mdot
.69802 .72547 Mdot
.70194 .72939 Mdot
.70587 .72939 Mdot
.71371 .73332 Mdot
.71763 .73724 Mdot
.71371 .73332 Mdot
.72155 .73332 Mdot
.72547 .74116 Mdot
.71371 .73724 Mdot
.70587 .73332 Mdot
.72155 .75292 Mdot
.71763 .74508 Mdot
.71371 .74116 Mdot
.71371 .74116 Mdot
.71763 .74508 Mdot
.71763 .749 Mdot
.71763 .74508 Mdot
.72547 .74116 Mdot
.72939 .749 Mdot
.72939 .749 Mdot
.73332 .75684 Mdot
.73332 .749 Mdot
.73332 .75292 Mdot
.73332 .75292 Mdot
.73724 .76076 Mdot
.72939 .75684 Mdot
.72939 .76469 Mdot
.72155 .75684 Mdot
.72547 .75292 Mdot
.72939 .75292 Mdot
.73332 .75292 Mdot
.73332 .74508 Mdot
.749 .75292 Mdot
.74116 .74508 Mdot
.73724 .749 Mdot
.73332 .749 Mdot
.73332 .749 Mdot
.73332 .749 Mdot
.72939 .74508 Mdot
.72939 .74508 Mdot
.73332 .749 Mdot
.73332 .749 Mdot
.73332 .75292 Mdot
.73332 .76076 Mdot
.73332 .76076 Mdot
.73332 .76076 Mdot
.72155 .75684 Mdot
.72155 .74508 Mdot
.72547 .74116 Mdot
.72547 .74116 Mdot
.72547 .74508 Mdot
.72155 .74508 Mdot
.71763 .74508 Mdot
.71763 .74508 Mdot
.70979 .73724 Mdot
.70587 .73724 Mdot
.70979 .74508 Mdot
.70587 .73724 Mdot
.69802 .72547 Mdot
.69802 .72547 Mdot
.68234 .70979 Mdot
.6745 .70979 Mdot
.67057 .70587 Mdot
.66273 .70194 Mdot
.65881 .69802 Mdot
.65489 .6941 Mdot
.66273 .70587 Mdot
.44314 .44706 Mdot
.30198 .28629 Mdot
.21963 .18826 Mdot
.20787 .1765 Mdot
.19218 .15689 Mdot
.59215 .57646 Mdot
.78821 .78037 Mdot
.47059 .53333 Mdot
.4902 .55686 Mdot
.4902 .55686 Mdot
.49804 .5647 Mdot
.49412 .55686 Mdot
.48628 .54902 Mdot
.49412 .5647 Mdot
.50588 .57646 Mdot
.50196 .56862 Mdot
.51372 .57254 Mdot
.52941 .58823 Mdot
.54902 .60391 Mdot
.54117 .59607 Mdot
.54902 .60783 Mdot
.54902 .60783 Mdot
.55294 .60783 Mdot
.55686 .61176 Mdot
.56078 .6196 Mdot
.5647 .62352 Mdot
.57254 .63136 Mdot
.5647 .62744 Mdot
.57646 .6392 Mdot
.58431 .64705 Mdot
.58431 .6392 Mdot
.58431 .63528 Mdot
.58039 .62744 Mdot
.58431 .62744 Mdot
.59215 .63528 Mdot
.60391 .64705 Mdot
.61176 .66273 Mdot
.59999 .64705 Mdot
.59607 .64313 Mdot
.61176 .65489 Mdot
.62352 .66273 Mdot
.63136 .66273 Mdot
.6392 .66665 Mdot
.64705 .66665 Mdot
.65097 .6745 Mdot
.65097 .68234 Mdot
.64313 .67842 Mdot
.65097 .68234 Mdot
.64705 .68234 Mdot
.65489 .68626 Mdot
.66665 .69802 Mdot
.66665 .69802 Mdot
.67057 .70979 Mdot
.67057 .71371 Mdot
.67842 .72155 Mdot
.6745 .70587 Mdot
.68626 .71763 Mdot
.6941 .72155 Mdot
.70194 .72547 Mdot
.70979 .72155 Mdot
.70194 .71371 Mdot
.69802 .71763 Mdot
.6941 .72547 Mdot
.69018 .72547 Mdot
.69802 .73332 Mdot
.6941 .72547 Mdot
.70194 .72547 Mdot
.70194 .72939 Mdot
.6941 .72547 Mdot
.69802 .72155 Mdot
.70587 .72939 Mdot
.71371 .73332 Mdot
.70979 .73724 Mdot
.71371 .73724 Mdot
.71371 .74508 Mdot
.71371 .74116 Mdot
.71763 .74508 Mdot
.72939 .75684 Mdot
.72547 .75292 Mdot
.71763 .749 Mdot
.72155 .74508 Mdot
.72547 .74116 Mdot
.72547 .73724 Mdot
.72939 .749 Mdot
.73332 .749 Mdot
.72939 .74508 Mdot
.73724 .74116 Mdot
.73724 .74508 Mdot
.73724 .75292 Mdot
.72547 .749 Mdot
.72547 .75684 Mdot
.72155 .75292 Mdot
.72155 .75292 Mdot
.72547 .75292 Mdot
.72939 .74508 Mdot
.72939 .74116 Mdot
.73332 .74508 Mdot
.73724 .75292 Mdot
.72939 .74116 Mdot
.72939 .74116 Mdot
.72939 .74116 Mdot
.73332 .749 Mdot
.72155 .73724 Mdot
.73332 .74508 Mdot
.73724 .749 Mdot
.72547 .74116 Mdot
.72155 .74116 Mdot
.71763 .73724 Mdot
.72155 .74116 Mdot
.72939 .74508 Mdot
.72547 .74508 Mdot
.72155 .73724 Mdot
.72547 .74508 Mdot
.71371 .74116 Mdot
.70194 .73724 Mdot
.70587 .74508 Mdot
.70979 .749 Mdot
.69802 .74116 Mdot
.69802 .73724 Mdot
.6941 .73724 Mdot
.6941 .72939 Mdot
.6941 .72547 Mdot
.70587 .73724 Mdot
.6941 .72547 Mdot
.68234 .71763 Mdot
.6745 .70587 Mdot
.67057 .70194 Mdot
.66665 .70587 Mdot
.66273 .70194 Mdot
.66273 .70587 Mdot
.64313 .68626 Mdot
.55294 .58039 Mdot
.31766 .30982 Mdot
.27845 .26276 Mdot
.26668 .25492 Mdot
.23139 .21179 Mdot
.20002 .18434 Mdot
.3608 .34903 Mdot
.58431 .58431 Mdot
.45491 .51765 Mdot
.47843 .53725 Mdot
.4902 .55686 Mdot
.49804 .56078 Mdot
.49804 .55686 Mdot
.49804 .55686 Mdot
.49412 .56078 Mdot
.49412 .55686 Mdot
.50196 .56862 Mdot
.5098 .57254 Mdot
.52157 .57646 Mdot
.54509 .59999 Mdot
.54117 .59215 Mdot
.52941 .58823 Mdot
.54509 .60391 Mdot
.5647 .62352 Mdot
.57254 .6196 Mdot
.56078 .60783 Mdot
.55686 .61176 Mdot
.5647 .6196 Mdot
.5647 .62352 Mdot
.5647 .62352 Mdot
.57254 .62744 Mdot
.58039 .62744 Mdot
.58823 .63136 Mdot
.58431 .62744 Mdot
.59215 .63136 Mdot
.59607 .63528 Mdot
.61176 .65097 Mdot
.59999 .64313 Mdot
.61176 .65097 Mdot
.62352 .65881 Mdot
.62744 .66665 Mdot
.62352 .65881 Mdot
.6392 .66273 Mdot
.63528 .65881 Mdot
.64705 .67057 Mdot
.65489 .67842 Mdot
.64313 .6745 Mdot
.64313 .67842 Mdot
.64705 .68626 Mdot
.64313 .68234 Mdot
.65489 .69018 Mdot
.65881 .69018 Mdot
.66665 .70194 Mdot
.66665 .69802 Mdot
.67057 .70587 Mdot
.68234 .71371 Mdot
.68626 .71371 Mdot
.69802 .72155 Mdot
.6941 .71763 Mdot
.69802 .70979 Mdot
.69802 .70194 Mdot
.70587 .70979 Mdot
.70979 .72155 Mdot
.70587 .72547 Mdot
.69802 .72547 Mdot
.70194 .72547 Mdot
.70979 .72939 Mdot
.70979 .72155 Mdot
.70979 .72547 Mdot
.70194 .72547 Mdot
.6941 .72547 Mdot
.6941 .71763 Mdot
.69802 .72155 Mdot
.70194 .72547 Mdot
.70587 .73724 Mdot
.70587 .72939 Mdot
.70587 .72939 Mdot
.71371 .74116 Mdot
.70979 .74116 Mdot
.70979 .73724 Mdot
.70979 .72547 Mdot
.71763 .73332 Mdot
.72547 .73724 Mdot
.73332 .73724 Mdot
.73724 .74116 Mdot
.73332 .74116 Mdot
.73332 .73724 Mdot
.73724 .73724 Mdot
.73332 .73332 Mdot
.72939 .74116 Mdot
.73332 .749 Mdot
.72155 .73724 Mdot
.71371 .73724 Mdot
.71763 .74508 Mdot
.71763 .73724 Mdot
.72547 .73724 Mdot
.72939 .74116 Mdot
.73332 .75292 Mdot
.72939 .74116 Mdot
.73332 .749 Mdot
.72155 .73332 Mdot
.72939 .73332 Mdot
.73332 .74508 Mdot
.72547 .74116 Mdot
.72939 .74508 Mdot
.72547 .73724 Mdot
.72939 .73724 Mdot
.72547 .72939 Mdot
.72547 .73332 Mdot
.72547 .73724 Mdot
.71763 .72939 Mdot
.71763 .73332 Mdot
.71371 .72939 Mdot
.70979 .72939 Mdot
.70194 .73332 Mdot
.6941 .72547 Mdot
.69802 .72939 Mdot
.70194 .73724 Mdot
.70194 .73724 Mdot
.70194 .73724 Mdot
.70194 .73724 Mdot
.6941 .72939 Mdot
.6941 .72547 Mdot
.69802 .72155 Mdot
.6941 .72547 Mdot
.69018 .72155 Mdot
.68234 .71371 Mdot
.67057 .69802 Mdot
.66665 .6941 Mdot
.65881 .6941 Mdot
.65881 .6941 Mdot
.65489 .69802 Mdot
.65881 .70194 Mdot
.59607 .62744 Mdot
.48235 .48628 Mdot
.48628 .50196 Mdot
.45098 .47059 Mdot
.21963 .21963 Mdot
.18434 .1961 Mdot
.14513 .15689 Mdot
.13728 .14905 Mdot
.34511 .34903 Mdot
.56078 .56862 Mdot
.45491 .51765 Mdot
.47843 .54509 Mdot
.4902 .55294 Mdot
.48235 .54509 Mdot
.49412 .55294 Mdot
.49412 .56078 Mdot
.4902 .56078 Mdot
.49804 .56862 Mdot
.49412 .5647 Mdot
.49804 .56862 Mdot
.51765 .58431 Mdot
.52549 .58431 Mdot
.53333 .58823 Mdot
.53333 .59215 Mdot
.53333 .58823 Mdot
.54117 .59999 Mdot
.54509 .59999 Mdot
.53725 .59215 Mdot
.54902 .60391 Mdot
.55686 .61568 Mdot
.56078 .62352 Mdot
.56862 .63136 Mdot
.58039 .63136 Mdot
.58039 .62744 Mdot
.59607 .63136 Mdot
.60391 .6392 Mdot
.60783 .64705 Mdot
.60783 .64705 Mdot
.60391 .6392 Mdot
.60391 .63528 Mdot
.60391 .6392 Mdot
.6196 .66273 Mdot
.61568 .65881 Mdot
.6196 .66273 Mdot
.62744 .66273 Mdot
.64313 .67057 Mdot
.6392 .66665 Mdot
.63528 .66665 Mdot
.63136 .66273 Mdot
.63528 .66665 Mdot
.63136 .66665 Mdot
.64705 .67842 Mdot
.64705 .68234 Mdot
.64705 .68626 Mdot
.65489 .69802 Mdot
.65489 .69018 Mdot
.66273 .70194 Mdot
.6745 .70979 Mdot
.68234 .71763 Mdot
.69018 .72155 Mdot
.6941 .71763 Mdot
.70194 .71763 Mdot
.70194 .71371 Mdot
.71371 .72155 Mdot
.70587 .71371 Mdot
.70194 .71763 Mdot
.70194 .71763 Mdot
.70194 .71763 Mdot
.70979 .72155 Mdot
.71763 .72155 Mdot
.72155 .72547 Mdot
.70587 .72155 Mdot
.70194 .72547 Mdot
.69018 .72155 Mdot
.6941 .72939 Mdot
.6941 .72155 Mdot
.70194 .73724 Mdot
.70194 .73332 Mdot
.70587 .73724 Mdot
.70587 .73332 Mdot
.70979 .74116 Mdot
.71371 .74116 Mdot
.71763 .72939 Mdot
.71763 .72939 Mdot
.72155 .72939 Mdot
.72939 .74116 Mdot
.72939 .73724 Mdot
.72155 .72547 Mdot
.72939 .72547 Mdot
.74116 .73724 Mdot
.73332 .73332 Mdot
.72547 .73724 Mdot
.72155 .73724 Mdot
.72155 .73724 Mdot
.70979 .73332 Mdot
.70587 .72939 Mdot
.70979 .74116 Mdot
.70979 .73332 Mdot
.71371 .73724 Mdot
.71763 .73332 Mdot
.72547 .74116 Mdot
.72155 .74116 Mdot
.72547 .73724 Mdot
.71763 .73332 Mdot
.71371 .72939 Mdot
.71763 .72939 Mdot
.72155 .73724 Mdot
.72155 .73332 Mdot
.72547 .73332 Mdot
.72939 .72939 Mdot
.72547 .72547 Mdot
.72547 .73332 Mdot
.71371 .71763 Mdot
.71371 .72155 Mdot
.70979 .72155 Mdot
.71371 .73332 Mdot
.70194 .73332 Mdot
.6941 .72155 Mdot
.69802 .72939 Mdot
.69018 .72547 Mdot
.69018 .72547 Mdot
.69802 .73332 Mdot
.69018 .72547 Mdot
.69018 .72155 Mdot
.69018 .71371 Mdot
.6941 .72155 Mdot
.68626 .70979 Mdot
.68234 .70587 Mdot
.67842 .70587 Mdot
.6745 .70194 Mdot
.67057 .70194 Mdot
.65881 .69018 Mdot
.65489 .69018 Mdot
.65097 .68626 Mdot
.64705 .68234 Mdot
.64705 .67842 Mdot
.64705 .67842 Mdot
.63136 .67057 Mdot
.61176 .66665 Mdot
.50588 .57254 Mdot
.15297 .16081 Mdot
.16081 .18434 Mdot
.14513 .16081 Mdot
.12552 .1412 Mdot
.11768 .13728 Mdot
.12552 .13728 Mdot
.57254 .57646 Mdot
.78429 .78821 Mdot
.45491 .52549 Mdot
.47843 .55294 Mdot
.48628 .55294 Mdot
.47843 .54509 Mdot
.4902 .55686 Mdot
.48628 .55294 Mdot
.4902 .55686 Mdot
.4902 .55294 Mdot
.50196 .56862 Mdot
.5098 .57646 Mdot
.51765 .58823 Mdot
.52157 .59215 Mdot
.52157 .58823 Mdot
.53333 .58823 Mdot
.53725 .59215 Mdot
.53725 .59215 Mdot
.53333 .59215 Mdot
.54117 .59607 Mdot
.55294 .60391 Mdot
.56078 .61568 Mdot
.55686 .6196 Mdot
.56078 .6196 Mdot
.5647 .61568 Mdot
.58039 .62352 Mdot
.59215 .63528 Mdot
.60391 .64313 Mdot
.59999 .6392 Mdot
.59999 .63528 Mdot
.61176 .64705 Mdot
.61568 .65097 Mdot
.59999 .6392 Mdot
.60783 .65097 Mdot
.60783 .65097 Mdot
.60783 .65489 Mdot
.62352 .65881 Mdot
.63136 .67057 Mdot
.63136 .66665 Mdot
.62744 .65881 Mdot
.63136 .66273 Mdot
.6392 .67057 Mdot
.65097 .68234 Mdot
.64705 .6745 Mdot
.65489 .68234 Mdot
.66665 .69802 Mdot
.67057 .69802 Mdot
.6745 .70194 Mdot
.66665 .6941 Mdot
.67057 .69802 Mdot
.67057 .69802 Mdot
.68234 .70979 Mdot
.69018 .70979 Mdot
.6941 .71763 Mdot
.6941 .71763 Mdot
.69018 .71763 Mdot
.68626 .71763 Mdot
.6941 .72155 Mdot
.70194 .71763 Mdot
.69802 .71371 Mdot
.70194 .72547 Mdot
.70979 .72547 Mdot
.70587 .72155 Mdot
.69802 .72155 Mdot
.69802 .71763 Mdot
.69802 .72547 Mdot
.68234 .71371 Mdot
.68234 .71763 Mdot
.69018 .72547 Mdot
.6941 .72547 Mdot
.69802 .72939 Mdot
.70194 .72939 Mdot
.70194 .72939 Mdot
.70979 .74116 Mdot
.71763 .74508 Mdot
.71763 .73724 Mdot
.71371 .72939 Mdot
.71763 .73332 Mdot
.71371 .73332 Mdot
.70587 .72155 Mdot
.70979 .71763 Mdot
.72155 .72547 Mdot
.72155 .73332 Mdot
.71763 .73724 Mdot
.70979 .73724 Mdot
.71371 .73724 Mdot
.70979 .73332 Mdot
.70587 .72547 Mdot
.71371 .72939 Mdot
.72155 .73332 Mdot
.72547 .73724 Mdot
.71763 .73332 Mdot
.72155 .73332 Mdot
.71371 .73332 Mdot
.70587 .72939 Mdot
.70194 .72939 Mdot
.69802 .72547 Mdot
.70587 .73332 Mdot
.71371 .74508 Mdot
.72939 .75292 Mdot
.72939 .74116 Mdot
.73332 .74116 Mdot
.72939 .73332 Mdot
.72155 .72939 Mdot
.71763 .72155 Mdot
.70587 .71371 Mdot
.70587 .71371 Mdot
.70587 .72155 Mdot
.70194 .72939 Mdot
.6941 .72547 Mdot
.69018 .73332 Mdot
.69018 .73332 Mdot
.68234 .72547 Mdot
.68234 .71763 Mdot
.68626 .72155 Mdot
.68626 .71371 Mdot
.68626 .70587 Mdot
.69018 .71763 Mdot
.68234 .70194 Mdot
.68626 .71371 Mdot
.66665 .69802 Mdot
.66665 .69802 Mdot
.66273 .69802 Mdot
.65489 .6941 Mdot
.65097 .69018 Mdot
.64705 .68626 Mdot
.64705 .67842 Mdot
.6392 .66665 Mdot
.64705 .68234 Mdot
.62744 .6745 Mdot
.6196 .67057 Mdot
.61176 .68234 Mdot
.42746 .47059 Mdot
.31374 .34119 Mdot
.21963 .23924 Mdot
.18826 .20394 Mdot
.15297 .16473 Mdot
.16473 .18042 Mdot
.20394 .22747 Mdot
.28237 .31766 Mdot
.15689 .16473 Mdot
.58431 .58431 Mdot
.78429 .78429 Mdot
.46275 .54117 Mdot
.48235 .5647 Mdot
.49412 .56862 Mdot
.49412 .56078 Mdot
.48628 .55294 Mdot
.4902 .55294 Mdot
.50196 .56078 Mdot
.51372 .56862 Mdot
.51765 .57254 Mdot
.51765 .57646 Mdot
.52157 .58823 Mdot
.51372 .58431 Mdot
.51765 .58431 Mdot
.52941 .58431 Mdot
.53333 .58823 Mdot
.54117 .59999 Mdot
.54117 .60391 Mdot
.53725 .60391 Mdot
.53725 .60391 Mdot
.54902 .61176 Mdot
.55686 .6196 Mdot
.55294 .61176 Mdot
.56078 .6196 Mdot
.5647 .62352 Mdot
.57254 .62352 Mdot
.58431 .63528 Mdot
.59215 .64313 Mdot
.58823 .63528 Mdot
.59999 .64313 Mdot
.59607 .64313 Mdot
.59607 .6392 Mdot
.59999 .64705 Mdot
.59999 .64705 Mdot
.60783 .65489 Mdot
.6196 .66273 Mdot
.62744 .66665 Mdot
.63136 .66665 Mdot
.62744 .65881 Mdot
.63136 .66665 Mdot
.6392 .67057 Mdot
.64705 .6745 Mdot
.65097 .6745 Mdot
.64705 .6745 Mdot
.65097 .68234 Mdot
.65881 .68626 Mdot
.66273 .6941 Mdot
.66273 .6941 Mdot
.67057 .70194 Mdot
.6745 .70979 Mdot
.67057 .70194 Mdot
.67842 .70979 Mdot
.68626 .71371 Mdot
.68626 .71371 Mdot
.68626 .71763 Mdot
.68234 .71763 Mdot
.68626 .71763 Mdot
.6941 .72155 Mdot
.6941 .71763 Mdot
.70194 .72547 Mdot
.69802 .72155 Mdot
.69802 .71763 Mdot
.6941 .71763 Mdot
.68626 .70194 Mdot
.6941 .70979 Mdot
.6941 .71763 Mdot
.6941 .72155 Mdot
.69018 .72155 Mdot
.6941 .72547 Mdot
.6941 .72155 Mdot
.69802 .72547 Mdot
.70194 .73332 Mdot
.6941 .72547 Mdot
.69802 .72547 Mdot
.70194 .72939 Mdot
.69802 .72939 Mdot
.6941 .72155 Mdot
.6941 .72547 Mdot
.69802 .72939 Mdot
.70587 .72939 Mdot
.71371 .73332 Mdot
.71371 .73332 Mdot
.71371 .73332 Mdot
.70587 .72939 Mdot
.70587 .73332 Mdot
.70979 .72939 Mdot
.71763 .73332 Mdot
.71371 .72547 Mdot
.70979 .72155 Mdot
.70979 .72547 Mdot
.70979 .73332 Mdot
.70979 .73332 Mdot
.71371 .73724 Mdot
.70194 .72547 Mdot
.6941 .72155 Mdot
.70194 .73332 Mdot
.70979 .73332 Mdot
.71763 .73724 Mdot
.71763 .73332 Mdot
.72155 .73724 Mdot
.71371 .73724 Mdot
.70587 .72939 Mdot
.71763 .73724 Mdot
.70979 .72155 Mdot
.70979 .72155 Mdot
.70587 .72155 Mdot
.6941 .70979 Mdot
.69018 .71763 Mdot
.6941 .72155 Mdot
.69018 .72155 Mdot
.68234 .71371 Mdot
.69018 .72155 Mdot
.69018 .72155 Mdot
.69018 .71371 Mdot
.69018 .71371 Mdot
.68626 .71371 Mdot
.67842 .70979 Mdot
.67057 .70194 Mdot
.66665 .69802 Mdot
.66273 .69802 Mdot
.65489 .69018 Mdot
.65489 .69018 Mdot
.65097 .6941 Mdot
.65489 .70194 Mdot
.65881 .70194 Mdot
.64313 .68626 Mdot
.63136 .67057 Mdot
.63528 .68234 Mdot
.63136 .67842 Mdot
.62352 .67842 Mdot
.61176 .67057 Mdot
.60391 .65881 Mdot
.59607 .65097 Mdot
.44706 .47843 Mdot
.3804 .40001 Mdot
.28237 .27845 Mdot
.29021 .29021 Mdot
.57646 .6392 Mdot
.51765 .5647 Mdot
.31766 .33727 Mdot
.31766 .35295 Mdot
.11376 .10199 Mdot
.32943 .30982 Mdot
.55294 .54117 Mdot
.45491 .51765 Mdot
.48235 .54902 Mdot
.49412 .56078 Mdot
.4902 .56078 Mdot
.4902 .55686 Mdot
.48628 .54509 Mdot
.50588 .55686 Mdot
.51372 .56078 Mdot
.51765 .5647 Mdot
.51372 .5647 Mdot
.51372 .56862 Mdot
.50588 .56078 Mdot
.51372 .5647 Mdot
.52157 .57646 Mdot
.52549 .57646 Mdot
.52549 .58431 Mdot
.53333 .59999 Mdot
.53333 .59999 Mdot
.53725 .60391 Mdot
.55294 .61568 Mdot
.55686 .61176 Mdot
.54902 .59999 Mdot
.56078 .61176 Mdot
.56078 .61176 Mdot
.5647 .6196 Mdot
.56862 .62352 Mdot
.58039 .62744 Mdot
.59607 .64313 Mdot
.59215 .6392 Mdot
.59607 .64313 Mdot
.59999 .64705 Mdot
.60783 .65097 Mdot
.60391 .64705 Mdot
.60783 .64313 Mdot
.61176 .64705 Mdot
.62352 .65881 Mdot
.63136 .66273 Mdot
.63136 .66273 Mdot
.63528 .66273 Mdot
.63528 .6745 Mdot
.63136 .66273 Mdot
.6392 .6745 Mdot
.6392 .6745 Mdot
.64313 .67842 Mdot
.6392 .6745 Mdot
.65489 .69018 Mdot
.65097 .68626 Mdot
.66665 .6941 Mdot
.65489 .69018 Mdot
.65489 .69018 Mdot
.67057 .70194 Mdot
.67842 .70587 Mdot
.68626 .71371 Mdot
.68626 .71763 Mdot
.68234 .72155 Mdot
.68626 .72547 Mdot
.67842 .71371 Mdot
.68626 .71763 Mdot
.68234 .71371 Mdot
.69018 .71763 Mdot
.68626 .71371 Mdot
.67842 .70979 Mdot
.69018 .70979 Mdot
.6941 .71371 Mdot
.69802 .71763 Mdot
.69802 .71763 Mdot
.6941 .71763 Mdot
.70194 .71763 Mdot
.69802 .71371 Mdot
.70587 .71763 Mdot
.70587 .72155 Mdot
.69802 .71763 Mdot
.69018 .72547 Mdot
.69018 .72547 Mdot
.6941 .72547 Mdot
.6941 .72155 Mdot
.6941 .72547 Mdot
.69018 .72547 Mdot
.69802 .72939 Mdot
.71371 .74116 Mdot
.70979 .73332 Mdot
.70979 .73332 Mdot
.70587 .72547 Mdot
.70194 .72155 Mdot
.71371 .72547 Mdot
.70587 .71371 Mdot
.71371 .71763 Mdot
.70979 .72155 Mdot
.71371 .73724 Mdot
.71371 .73332 Mdot
.71763 .73332 Mdot
.71763 .72939 Mdot
.70979 .72547 Mdot
.71371 .73724 Mdot
.71763 .74116 Mdot
.71371 .73332 Mdot
.71371 .72939 Mdot
.71371 .73332 Mdot
.70587 .72155 Mdot
.70979 .72939 Mdot
.70587 .72547 Mdot
.71371 .72939 Mdot
.70979 .71763 Mdot
.70979 .71763 Mdot
.70979 .72155 Mdot
.70587 .72155 Mdot
.69018 .70587 Mdot
.68234 .70194 Mdot
.67842 .70587 Mdot
.68234 .71763 Mdot
.69018 .72547 Mdot
.69802 .72939 Mdot
.69802 .72547 Mdot
.6941 .71763 Mdot
.69018 .71371 Mdot
.6745 .70587 Mdot
.65489 .69018 Mdot
.66273 .69802 Mdot
.66665 .70194 Mdot
.66273 .6941 Mdot
.65881 .6941 Mdot
.66273 .69802 Mdot
.66665 .70587 Mdot
.65097 .6941 Mdot
.64313 .68234 Mdot
.63528 .67057 Mdot
.63136 .67057 Mdot
.63528 .67842 Mdot
.63136 .68234 Mdot
.62352 .6745 Mdot
.61568 .65881 Mdot
.61176 .65489 Mdot
.60783 .64313 Mdot
.59607 .63528 Mdot
.55686 .59215 Mdot
.54509 .58039 Mdot
.56078 .59999 Mdot
.57254 .6196 Mdot
.55686 .60783 Mdot
.57646 .63528 Mdot
.29806 .3059 Mdot
.08631 .06278 Mdot
.10591 .08631 Mdot
.09415 .07846 Mdot
.31374 .30198 Mdot
.52549 .52157 Mdot
.42354 .47059 Mdot
.48235 .54117 Mdot
.4902 .54902 Mdot
.48628 .54902 Mdot
.48628 .54509 Mdot
.48628 .54902 Mdot
.50196 .55686 Mdot
.50588 .55686 Mdot
.5098 .55686 Mdot
.51372 .56078 Mdot
.5098 .55686 Mdot
.51372 .56078 Mdot
.52157 .57254 Mdot
.52157 .57254 Mdot
.52549 .57646 Mdot
.52549 .58039 Mdot
.52941 .59215 Mdot
.52941 .59999 Mdot
.52549 .59215 Mdot
.53333 .60391 Mdot
.54902 .61568 Mdot
.55294 .61568 Mdot
.56078 .60783 Mdot
.5647 .60391 Mdot
.56862 .60783 Mdot
.57254 .61176 Mdot
.57646 .61568 Mdot
.58431 .6196 Mdot
.58823 .62352 Mdot
.59215 .63136 Mdot
.59999 .64313 Mdot
.61176 .65097 Mdot
.60783 .65097 Mdot
.61176 .64705 Mdot
.6196 .65881 Mdot
.61568 .65097 Mdot
.63528 .66273 Mdot
.63528 .65881 Mdot
.63528 .66273 Mdot
.64705 .67842 Mdot
.6392 .67057 Mdot
.63528 .66665 Mdot
.64313 .6745 Mdot
.6392 .6745 Mdot
.64705 .68234 Mdot
.65097 .68234 Mdot
.65097 .67842 Mdot
.66273 .68626 Mdot
.65881 .68234 Mdot
.66273 .69018 Mdot
.67057 .70194 Mdot
.67057 .70194 Mdot
.6745 .70587 Mdot
.67057 .70194 Mdot
.67842 .70979 Mdot
.6745 .70587 Mdot
.6745 .71371 Mdot
.68234 .71763 Mdot
.6745 .70194 Mdot
.6745 .70194 Mdot
.68234 .70587 Mdot
.69018 .70979 Mdot
.69802 .71763 Mdot
.69802 .71763 Mdot
.69018 .70587 Mdot
.6941 .71763 Mdot
.69018 .71763 Mdot
.6941 .71371 Mdot
.69802 .71371 Mdot
.70194 .71763 Mdot
.71371 .72547 Mdot
.69018 .70587 Mdot
.6941 .70979 Mdot
.70587 .72547 Mdot
.70587 .72155 Mdot
.70194 .72155 Mdot
.69802 .72155 Mdot
.6941 .71371 Mdot
.70194 .71763 Mdot
.70194 .72547 Mdot
.70587 .72939 Mdot
.70194 .72155 Mdot
.70194 .72547 Mdot
.6941 .71371 Mdot
.6941 .71371 Mdot
.70194 .71763 Mdot
.70194 .70979 Mdot
.70979 .71371 Mdot
.70587 .71371 Mdot
.70979 .72155 Mdot
.70194 .71763 Mdot
.70194 .71763 Mdot
.70587 .72547 Mdot
.70587 .73332 Mdot
.71371 .74116 Mdot
.70979 .74116 Mdot
.71371 .73332 Mdot
.71371 .72547 Mdot
.70979 .71371 Mdot
.70194 .70979 Mdot
.70587 .71371 Mdot
.70194 .71371 Mdot
.70979 .71763 Mdot
.70587 .71371 Mdot
.70194 .71371 Mdot
.69802 .70979 Mdot
.6941 .70979 Mdot
.69802 .72155 Mdot
.6941 .72155 Mdot
.68626 .71763 Mdot
.68234 .71763 Mdot
.67842 .71371 Mdot
.68234 .71371 Mdot
.68234 .70979 Mdot
.68626 .70587 Mdot
.68234 .70587 Mdot
.67057 .70587 Mdot
.66273 .69802 Mdot
.66273 .6941 Mdot
.66665 .69802 Mdot
.65881 .69018 Mdot
.65881 .69018 Mdot
.65489 .67842 Mdot
.65881 .68234 Mdot
.65489 .68234 Mdot
.64705 .67842 Mdot
.63528 .66665 Mdot
.63528 .6745 Mdot
.62352 .66665 Mdot
.61568 .65489 Mdot
.60783 .64705 Mdot
.61568 .65489 Mdot
.61568 .64705 Mdot
.62352 .65489 Mdot
.60783 .64313 Mdot
.59999 .6392 Mdot
.59607 .63136 Mdot
.59215 .63136 Mdot
.58823 .62352 Mdot
.56078 .60783 Mdot
.52941 .58039 Mdot
.29413 .31374 Mdot
.18434 .18434 Mdot
.14513 .14513 Mdot
.11376 .10591 Mdot
.08631 .07454 Mdot
.11768 .11376 Mdot
.60391 .60391 Mdot
.78821 .78429 Mdot
.43922 .49412 Mdot
.47843 .53725 Mdot
.49804 .55294 Mdot
.49804 .55294 Mdot
.48628 .54509 Mdot
.48235 .54117 Mdot
.4902 .55294 Mdot
.50196 .5647 Mdot
.51765 .57646 Mdot
.5098 .5647 Mdot
.5098 .56862 Mdot
.50588 .56078 Mdot
.5098 .56862 Mdot
.51765 .57646 Mdot
.51765 .57646 Mdot
.52549 .58823 Mdot
.52941 .59215 Mdot
.51372 .57646 Mdot
.51765 .58431 Mdot
.52549 .58431 Mdot
.52549 .58039 Mdot
.54117 .59607 Mdot
.54902 .59999 Mdot
.56078 .60391 Mdot
.56078 .59999 Mdot
.5647 .60783 Mdot
.56862 .6196 Mdot
.57254 .61568 Mdot
.58431 .62744 Mdot
.59999 .63528 Mdot
.59607 .63136 Mdot
.59999 .63528 Mdot
.60391 .64313 Mdot
.60391 .64313 Mdot
.61176 .65097 Mdot
.61568 .64705 Mdot
.62744 .65489 Mdot
.62744 .65097 Mdot
.6196 .64705 Mdot
.62744 .65881 Mdot
.63528 .66273 Mdot
.63136 .66665 Mdot
.6392 .6745 Mdot
.6392 .67842 Mdot
.6392 .6745 Mdot
.63528 .66665 Mdot
.65489 .68234 Mdot
.65489 .6745 Mdot
.66665 .69018 Mdot
.65881 .68234 Mdot
.65881 .68626 Mdot
.66273 .6941 Mdot
.66273 .6941 Mdot
.6745 .70194 Mdot
.66665 .6941 Mdot
.67057 .69802 Mdot
.66665 .6941 Mdot
.67057 .70194 Mdot
.67842 .6941 Mdot
.67842 .69802 Mdot
.68626 .70979 Mdot
.68234 .70587 Mdot
.6941 .71371 Mdot
.69018 .70194 Mdot
.68234 .69802 Mdot
.67842 .6941 Mdot
.69018 .70979 Mdot
.68626 .70587 Mdot
.67842 .69802 Mdot
.68234 .70587 Mdot
.69018 .70587 Mdot
.70194 .71371 Mdot
.69802 .71371 Mdot
.69018 .70194 Mdot
.6941 .70979 Mdot
.6941 .70979 Mdot
.6941 .71371 Mdot
.69018 .70587 Mdot
.70194 .71763 Mdot
.69802 .71763 Mdot
.6941 .71763 Mdot
.6941 .71371 Mdot
.69018 .71371 Mdot
.69018 .70979 Mdot
.68626 .70587 Mdot
.69802 .71371 Mdot
.70194 .70979 Mdot
.70587 .70979 Mdot
.70587 .71371 Mdot
.70979 .71763 Mdot
.70194 .71371 Mdot
.70194 .71763 Mdot
.69802 .71763 Mdot
.69802 .72155 Mdot
.6941 .71371 Mdot
.6941 .70979 Mdot
.69802 .71763 Mdot
.69018 .70587 Mdot
.69802 .70979 Mdot
.69802 .70979 Mdot
.6941 .70979 Mdot
.68234 .70587 Mdot
.67842 .70194 Mdot
.67842 .69802 Mdot
.68234 .70587 Mdot
.68234 .69802 Mdot
.67842 .70194 Mdot
.67842 .70587 Mdot
.67057 .70194 Mdot
.6745 .70194 Mdot
.68234 .71763 Mdot
.6745 .70979 Mdot
.67842 .71763 Mdot
.67057 .70194 Mdot
.68234 .70979 Mdot
.67842 .70587 Mdot
.66665 .70194 Mdot
.65489 .6941 Mdot
.65489 .69018 Mdot
.64705 .68234 Mdot
.65489 .68626 Mdot
.65881 .6745 Mdot
.65097 .65881 Mdot
.65489 .66273 Mdot
.65489 .67057 Mdot
.65097 .66665 Mdot
.65489 .67057 Mdot
.6392 .65881 Mdot
.62744 .65881 Mdot
.6196 .65881 Mdot
.62352 .65881 Mdot
.61176 .64705 Mdot
.61176 .6392 Mdot
.60783 .6392 Mdot
.59607 .63136 Mdot
.59607 .62744 Mdot
.59215 .62744 Mdot
.59607 .62352 Mdot
.59215 .62352 Mdot
.57646 .60783 Mdot
.5647 .61568 Mdot
.54509 .59607 Mdot
.52549 .58039 Mdot
.40785 .44314 Mdot
.20787 .20002 Mdot
.20002 .19218 Mdot
.16081 .14905 Mdot
.20002 .1961 Mdot
.21179 .21571 Mdot
.17257 .17257 Mdot
.57254 .57254 Mdot
.78429 .78429 Mdot
.45491 .5098 Mdot
.47059 .53333 Mdot
.48628 .54902 Mdot
.4902 .54902 Mdot
.49412 .55294 Mdot
.47843 .54117 Mdot
.48235 .54902 Mdot
.50196 .55686 Mdot
.50196 .54902 Mdot
.49804 .54902 Mdot
.4902 .54509 Mdot
.4902 .55294 Mdot
.4902 .55294 Mdot
.49804 .5647 Mdot
.50588 .57254 Mdot
.51372 .57646 Mdot
.52157 .58823 Mdot
.52157 .57646 Mdot
.52549 .58039 Mdot
.52941 .58823 Mdot
.52941 .58039 Mdot
.53333 .58431 Mdot
.55294 .59607 Mdot
.56078 .59999 Mdot
.56078 .59999 Mdot
.55294 .59215 Mdot
.55294 .58823 Mdot
.5647 .60391 Mdot
.58039 .61568 Mdot
.59215 .62352 Mdot
.59215 .6196 Mdot
.59999 .63136 Mdot
.58823 .6196 Mdot
.59999 .63528 Mdot
.61568 .65489 Mdot
.61176 .64705 Mdot
.60391 .6392 Mdot
.60783 .63528 Mdot
.60783 .64313 Mdot
.62744 .65881 Mdot
.61568 .65097 Mdot
.62352 .66273 Mdot
.62352 .66273 Mdot
.62352 .65881 Mdot
.64313 .67842 Mdot
.6392 .6745 Mdot
.64705 .67057 Mdot
.65489 .68626 Mdot
.65489 .6745 Mdot
.65097 .6745 Mdot
.64705 .6745 Mdot
.65881 .68234 Mdot
.66665 .69018 Mdot
.6745 .69802 Mdot
.6745 .69802 Mdot
.66665 .6941 Mdot
.65881 .68626 Mdot
.65881 .68626 Mdot
.66273 .68626 Mdot
.66665 .69018 Mdot
.67057 .6941 Mdot
.67057 .68626 Mdot
.66665 .68234 Mdot
.67057 .6941 Mdot
.66665 .68234 Mdot
.67057 .68234 Mdot
.67842 .6941 Mdot
.67842 .69802 Mdot
.68626 .69802 Mdot
.68626 .70194 Mdot
.67842 .69802 Mdot
.67842 .69802 Mdot
.67842 .69802 Mdot
.6745 .69018 Mdot
.67842 .69802 Mdot
.68626 .70194 Mdot
.68626 .69802 Mdot
.68234 .69802 Mdot
.68234 .70194 Mdot
.6941 .71371 Mdot
.69018 .70587 Mdot
.6941 .70587 Mdot
.68626 .6941 Mdot
.67842 .69018 Mdot
.69018 .70587 Mdot
.68626 .70587 Mdot
.69018 .70979 Mdot
.68626 .69018 Mdot
.68626 .6941 Mdot
.69018 .6941 Mdot
.69802 .69802 Mdot
.69802 .70194 Mdot
.68234 .70194 Mdot
.69018 .71371 Mdot
.69018 .70979 Mdot
.69018 .70587 Mdot
.67842 .69802 Mdot
.68234 .70194 Mdot
.68234 .70587 Mdot
.67842 .70194 Mdot
.6745 .70194 Mdot
.67057 .6941 Mdot
.67057 .6941 Mdot
.67057 .69802 Mdot
.67057 .69802 Mdot
.6745 .69018 Mdot
.68234 .70194 Mdot
.67057 .69018 Mdot
.6745 .70194 Mdot
.67842 .70194 Mdot
.67057 .6941 Mdot
.67057 .69802 Mdot
.6745 .69802 Mdot
.66665 .6941 Mdot
.66273 .68626 Mdot
.65097 .67842 Mdot
.65489 .68626 Mdot
.65097 .69018 Mdot
.64313 .68234 Mdot
.6392 .67057 Mdot
.64705 .6745 Mdot
.64705 .66665 Mdot
.65097 .66273 Mdot
.65097 .65881 Mdot
.63528 .64313 Mdot
.6392 .65097 Mdot
.63528 .65097 Mdot
.63136 .65097 Mdot
.6196 .64313 Mdot
.6196 .64705 Mdot
.60391 .6392 Mdot
.59607 .62744 Mdot
.59607 .62352 Mdot
.59215 .6196 Mdot
.59215 .6196 Mdot
.59215 .61568 Mdot
.58823 .61568 Mdot
.58039 .60783 Mdot
.5647 .59607 Mdot
.56078 .59215 Mdot
.56078 .59999 Mdot
.54509 .58823 Mdot
.54509 .58431 Mdot
.54509 .58431 Mdot
.48235 .51765 Mdot
.45491 .49804 Mdot
.40393 .43922 Mdot
.36472 .40001 Mdot
.251 .26276 Mdot
.20002 .20394 Mdot
.24316 .25884 Mdot
.31766 .35295 Mdot
.41569 .42746 Mdot
.53725 .53333 Mdot
.41961 .48628 Mdot
.47451 .54509 Mdot
.48628 .55294 Mdot
.4902 .55686 Mdot
.47843 .54117 Mdot
.48628 .55294 Mdot
.47843 .54509 Mdot
.48235 .54902 Mdot
.48628 .54509 Mdot
.50196 .55686 Mdot
.49804 .55686 Mdot
.4902 .55294 Mdot
.48628 .54902 Mdot
.49412 .56078 Mdot
.50196 .56862 Mdot
.5098 .57254 Mdot
.52157 .57646 Mdot
.52157 .57646 Mdot
.52549 .58431 Mdot
.52157 .58431 Mdot
.53333 .58823 Mdot
.54117 .59215 Mdot
.55686 .60391 Mdot
.55294 .59215 Mdot
.55686 .59999 Mdot
.55294 .59215 Mdot
.55686 .59999 Mdot
.55294 .59607 Mdot
.56078 .60783 Mdot
.58039 .62352 Mdot
.58431 .62352 Mdot
.59215 .62352 Mdot
.59215 .62744 Mdot
.58039 .6196 Mdot
.58039 .62744 Mdot
.58431 .63136 Mdot
.58823 .62744 Mdot
.59607 .63528 Mdot
.60391 .64705 Mdot
.60783 .65489 Mdot
.61176 .66273 Mdot
.61176 .66273 Mdot
.62352 .66273 Mdot
.61176 .65097 Mdot
.6196 .65881 Mdot
.63528 .67057 Mdot
.6392 .67057 Mdot
.64705 .6745 Mdot
.65489 .67842 Mdot
.65489 .67842 Mdot
.64705 .67057 Mdot
.65097 .67842 Mdot
.64705 .6745 Mdot
.65097 .6745 Mdot
.65489 .68234 Mdot
.65881 .68626 Mdot
.65489 .68626 Mdot
.65489 .68626 Mdot
.65489 .68234 Mdot
.66273 .69018 Mdot
.65881 .69018 Mdot
.65489 .68234 Mdot
.65097 .67842 Mdot
.66273 .68626 Mdot
.66273 .69018 Mdot
.66665 .6941 Mdot
.67057 .69802 Mdot
.67057 .69802 Mdot
.66273 .67842 Mdot
.67057 .68234 Mdot
.66665 .67842 Mdot
.66665 .68626 Mdot
.66273 .69018 Mdot
.67057 .68626 Mdot
.67057 .68626 Mdot
.67842 .6941 Mdot
.68234 .69802 Mdot
.68234 .70194 Mdot
.6745 .6941 Mdot
.67842 .70194 Mdot
.67842 .69802 Mdot
.68234 .70194 Mdot
.67842 .6941 Mdot
.68234 .70194 Mdot
.68234 .70194 Mdot
.67842 .69802 Mdot
.68234 .70194 Mdot
.67842 .6941 Mdot
.67842 .69018 Mdot
.68234 .6941 Mdot
.69018 .69802 Mdot
.67842 .6941 Mdot
.67057 .69018 Mdot
.67057 .6941 Mdot
.67842 .70587 Mdot
.69018 .70979 Mdot
.67842 .70194 Mdot
.67842 .69802 Mdot
.67842 .70194 Mdot
.66273 .69018 Mdot
.66273 .6941 Mdot
.67057 .70587 Mdot
.6745 .70587 Mdot
.67057 .69802 Mdot
.66273 .6941 Mdot
.66665 .6941 Mdot
.66665 .69018 Mdot
.66273 .68626 Mdot
.66273 .68234 Mdot
.66665 .68626 Mdot
.6745 .6941 Mdot
.67057 .6941 Mdot
.66273 .67842 Mdot
.67057 .69018 Mdot
.66273 .68234 Mdot
.64705 .6745 Mdot
.64313 .6745 Mdot
.65489 .68626 Mdot
.65097 .67842 Mdot
.64313 .6745 Mdot
.64313 .66665 Mdot
.63528 .65881 Mdot
.6392 .66273 Mdot
.63528 .65881 Mdot
.62744 .65097 Mdot
.63136 .65489 Mdot
.62352 .65097 Mdot
.60783 .6392 Mdot
.60783 .6392 Mdot
.60783 .64313 Mdot
.60783 .64313 Mdot
.59607 .63528 Mdot
.59607 .63528 Mdot
.59607 .6392 Mdot
.59607 .6392 Mdot
.59215 .62352 Mdot
.58431 .61568 Mdot
.58431 .62352 Mdot
.57646 .61568 Mdot
.58039 .61568 Mdot
.57254 .60783 Mdot
.56078 .59999 Mdot
.56078 .59607 Mdot
.54902 .58431 Mdot
.54117 .58039 Mdot
.52941 .5647 Mdot
.51765 .56078 Mdot
.50588 .55294 Mdot
.47451 .52549 Mdot
.47059 .51765 Mdot
.47059 .52157 Mdot
.47843 .53333 Mdot
.40785 .45883 Mdot
.14513 .15689 Mdot
.20394 .23924 Mdot
.27845 .28629 Mdot
.51372 .52157 Mdot
.42354 .48628 Mdot
.45491 .52549 Mdot
.47451 .54902 Mdot
.48628 .55686 Mdot
.47451 .54117 Mdot
.47843 .54509 Mdot
.48235 .54902 Mdot
.48235 .54902 Mdot
.48235 .54902 Mdot
.48235 .54902 Mdot
.48628 .54902 Mdot
.48235 .54902 Mdot
.48628 .55294 Mdot
.4902 .55294 Mdot
.49804 .57254 Mdot
.50196 .56862 Mdot
.51372 .57646 Mdot
.52549 .58431 Mdot
.51765 .58431 Mdot
.51372 .58431 Mdot
.52157 .58823 Mdot
.52941 .58823 Mdot
.53725 .59215 Mdot
.54117 .58431 Mdot
.53725 .58431 Mdot
.53725 .58431 Mdot
.54117 .59215 Mdot
.53725 .58823 Mdot
.54902 .60391 Mdot
.55686 .61176 Mdot
.5647 .61176 Mdot
.56862 .60783 Mdot
.57254 .61568 Mdot
.56078 .61176 Mdot
.5647 .6196 Mdot
.56862 .62352 Mdot
.5647 .6196 Mdot
.57646 .62744 Mdot
.58039 .62744 Mdot
.58431 .63528 Mdot
.58823 .64313 Mdot
.58431 .64313 Mdot
.60391 .65489 Mdot
.60783 .65097 Mdot
.60783 .65097 Mdot
.61568 .65489 Mdot
.63136 .67057 Mdot
.63136 .66273 Mdot
.6392 .66665 Mdot
.64705 .6745 Mdot
.64705 .6745 Mdot
.64313 .67057 Mdot
.64313 .67057 Mdot
.64705 .6745 Mdot
.65097 .6745 Mdot
.64313 .67057 Mdot
.64705 .67842 Mdot
.64705 .68234 Mdot
.64313 .68234 Mdot
.64705 .67842 Mdot
.65097 .68626 Mdot
.65097 .68234 Mdot
.65097 .6745 Mdot
.65881 .68234 Mdot
.65881 .68626 Mdot
.65881 .68626 Mdot
.65489 .68626 Mdot
.65489 .68626 Mdot
.65881 .69018 Mdot
.66665 .69018 Mdot
.6745 .68626 Mdot
.66665 .68234 Mdot
.66273 .68626 Mdot
.66665 .68626 Mdot
.68234 .69802 Mdot
.67842 .70194 Mdot
.67842 .69802 Mdot
.6745 .68626 Mdot
.6745 .6941 Mdot
.67057 .69802 Mdot
.67057 .69802 Mdot
.67057 .69802 Mdot
.65881 .68626 Mdot
.65881 .68626 Mdot
.66665 .6941 Mdot
.66273 .6941 Mdot
.66273 .69018 Mdot
.66665 .69018 Mdot
.66273 .67842 Mdot
.67057 .6941 Mdot
.6745 .69802 Mdot
.67057 .69802 Mdot
.67057 .6941 Mdot
.66273 .68626 Mdot
.65489 .68234 Mdot
.66273 .6941 Mdot
.66273 .69018 Mdot
.66665 .6941 Mdot
.6745 .69802 Mdot
.66665 .6941 Mdot
.66273 .68626 Mdot
.66273 .69018 Mdot
.66665 .6941 Mdot
.66665 .6941 Mdot
.66665 .6941 Mdot
.65489 .68234 Mdot
.65881 .68626 Mdot
.65881 .68626 Mdot
.65097 .67842 Mdot
.65881 .68234 Mdot
.65489 .67842 Mdot
.66273 .68234 Mdot
.66273 .69018 Mdot
.66273 .69018 Mdot
.65489 .67842 Mdot
.64705 .66665 Mdot
.64313 .66665 Mdot
.6392 .66273 Mdot
.6392 .66273 Mdot
.6392 .66665 Mdot
.63136 .65489 Mdot
.6392 .66273 Mdot
.6392 .65881 Mdot
.62744 .65881 Mdot
.62744 .66273 Mdot
.62352 .66273 Mdot
.60783 .64705 Mdot
.59607 .63528 Mdot
.59999 .64313 Mdot
.59999 .63136 Mdot
.59215 .63136 Mdot
.58823 .63136 Mdot
.58039 .63136 Mdot
.57646 .62744 Mdot
.57646 .61568 Mdot
.57646 .61176 Mdot
.57254 .60783 Mdot
.57254 .61176 Mdot
.56862 .61568 Mdot
.5647 .60783 Mdot
.55686 .59999 Mdot
.55686 .59999 Mdot
.56078 .60391 Mdot
.55294 .59607 Mdot
.54509 .58823 Mdot
.52549 .57254 Mdot
.51372 .5647 Mdot
.5098 .5647 Mdot
.50588 .56078 Mdot
.49412 .54509 Mdot
.4902 .54117 Mdot
.48235 .52941 Mdot
.47843 .53725 Mdot
.4353 .4902 Mdot
.43138 .50588 Mdot
.20002 .251 Mdot
.07454 .10199 Mdot
.04709 .07062 Mdot
.50196 .5098 Mdot
.75292 .75292 Mdot
.41569 .48628 Mdot
.47059 .54117 Mdot
.48235 .54509 Mdot
.48235 .54509 Mdot
.47451 .54117 Mdot
.47059 .53333 Mdot
.45098 .51372 Mdot
.45098 .52157 Mdot
.45883 .53333 Mdot
.47451 .54902 Mdot
.47451 .54509 Mdot
.48235 .54902 Mdot
.48235 .54509 Mdot
.4902 .55294 Mdot
.49412 .56078 Mdot
.49804 .5647 Mdot
.51372 .57646 Mdot
.52157 .58039 Mdot
.51765 .56862 Mdot
.51765 .57646 Mdot
.5098 .57646 Mdot
.51765 .58039 Mdot
.52941 .58823 Mdot
.53333 .58823 Mdot
.53725 .58431 Mdot
.53725 .58431 Mdot
.52941 .57646 Mdot
.53725 .58431 Mdot
.53725 .58823 Mdot
.54117 .59607 Mdot
.55686 .60391 Mdot
.56078 .59999 Mdot
.5647 .60783 Mdot
.56078 .60391 Mdot
.5647 .60783 Mdot
.56862 .61568 Mdot
.5647 .61568 Mdot
.56862 .6196 Mdot
.58039 .62744 Mdot
.57646 .62744 Mdot
.57254 .62744 Mdot
.57254 .63136 Mdot
.58823 .64313 Mdot
.60783 .65489 Mdot
.60783 .65097 Mdot
.61568 .65489 Mdot
.62744 .66273 Mdot
.63528 .66665 Mdot
.63528 .66273 Mdot
.6392 .66273 Mdot
.64313 .66665 Mdot
.64705 .66665 Mdot
.6392 .65881 Mdot
.64313 .66273 Mdot
.65097 .67057 Mdot
.63528 .65881 Mdot
.64705 .66273 Mdot
.65097 .6745 Mdot
.64705 .6745 Mdot
.6392 .6745 Mdot
.6392 .67842 Mdot
.6392 .6745 Mdot
.64313 .66665 Mdot
.64313 .66665 Mdot
.65097 .6745 Mdot
.65097 .6745 Mdot
.65097 .6745 Mdot
.65489 .67842 Mdot
.65097 .67057 Mdot
.65489 .6745 Mdot
.66273 .67842 Mdot
.65881 .68234 Mdot
.66273 .69018 Mdot
.66665 .6941 Mdot
.65881 .6745 Mdot
.66273 .67842 Mdot
.66665 .68234 Mdot
.6745 .68626 Mdot
.67057 .68234 Mdot
.67057 .68234 Mdot
.66273 .6745 Mdot
.65489 .67057 Mdot
.64705 .66665 Mdot
.65097 .6745 Mdot
.65489 .68234 Mdot
.66273 .68626 Mdot
.66273 .67842 Mdot
.65881 .6745 Mdot
.66665 .67842 Mdot
.66273 .67057 Mdot
.66273 .6745 Mdot
.66665 .68234 Mdot
.66273 .67842 Mdot
.65489 .67842 Mdot
.65097 .6745 Mdot
.65489 .67842 Mdot
.65881 .68626 Mdot
.65489 .68234 Mdot
.66273 .68626 Mdot
.65881 .68234 Mdot
.64313 .67057 Mdot
.65489 .68234 Mdot
.65881 .68234 Mdot
.65489 .68234 Mdot
.65097 .6745 Mdot
.64705 .67057 Mdot
.65489 .68234 Mdot
.65097 .6745 Mdot
.65097 .67842 Mdot
.65489 .6745 Mdot
.64705 .67057 Mdot
.6392 .66273 Mdot
.63528 .66273 Mdot
.63528 .65881 Mdot
.64705 .67057 Mdot
.64313 .66665 Mdot
.62744 .65097 Mdot
.62352 .64313 Mdot
.62352 .64705 Mdot
.62352 .65097 Mdot
.62352 .65097 Mdot
.63136 .65097 Mdot
.63136 .65097 Mdot
.61176 .63136 Mdot
.61568 .64313 Mdot
.59999 .63136 Mdot
.59607 .62744 Mdot
.61176 .64313 Mdot
.59999 .63528 Mdot
.59215 .63528 Mdot
.58823 .63528 Mdot
.58039 .63136 Mdot
.57646 .62744 Mdot
.57646 .6196 Mdot
.58039 .61176 Mdot
.57646 .61568 Mdot
.56078 .60391 Mdot
.56078 .60783 Mdot
.56078 .61176 Mdot
.55294 .60391 Mdot
.54902 .59999 Mdot
.55686 .59607 Mdot
.54902 .59215 Mdot
.54117 .58823 Mdot
.53725 .58431 Mdot
.5098 .55686 Mdot
.51372 .56862 Mdot
.51372 .56862 Mdot
.51765 .5647 Mdot
.5098 .54902 Mdot
.5098 .55294 Mdot
.49804 .55294 Mdot
.48628 .54117 Mdot
.47843 .53333 Mdot
.45883 .5098 Mdot
.48235 .54902 Mdot
.21571 .25492 Mdot
.03925 .04709 Mdot
.03141 .03533 Mdot
.02357 .01965 Mdot
.41961 .48628 Mdot
.47451 .54117 Mdot
.48628 .55294 Mdot
.48235 .54509 Mdot
.47843 .54117 Mdot
.46667 .53333 Mdot
.45491 .52157 Mdot
.45491 .52941 Mdot
.45883 .53333 Mdot
.46275 .53725 Mdot
.48235 .54902 Mdot
.4902 .54902 Mdot
.48628 .54902 Mdot
.49412 .56078 Mdot
.5098 .58039 Mdot
.50196 .57254 Mdot
.5098 .58039 Mdot
.51372 .57646 Mdot
.51372 .56862 Mdot
.51765 .58431 Mdot
.51372 .58039 Mdot
.51372 .58039 Mdot
.52157 .58823 Mdot
.52157 .57646 Mdot
.53333 .58431 Mdot
.52941 .57254 Mdot
.53333 .58039 Mdot
.52941 .58823 Mdot
.53725 .59607 Mdot
.55294 .60391 Mdot
.57254 .61568 Mdot
.55686 .58823 Mdot
.56862 .60391 Mdot
.56862 .60783 Mdot
.56862 .60391 Mdot
.57254 .61176 Mdot
.57254 .61176 Mdot
.57646 .6196 Mdot
.58039 .62352 Mdot
.57646 .6196 Mdot
.58431 .63528 Mdot
.58823 .63528 Mdot
.59215 .6392 Mdot
.60783 .64705 Mdot
.61176 .65097 Mdot
.60783 .6392 Mdot
.6196 .65489 Mdot
.62744 .66665 Mdot
.63528 .66665 Mdot
.64313 .66273 Mdot
.63528 .65489 Mdot
.6392 .65489 Mdot
.64705 .66273 Mdot
.64705 .66665 Mdot
.62744 .65489 Mdot
.62744 .65881 Mdot
.63528 .65881 Mdot
.64705 .66665 Mdot
.64705 .66665 Mdot
.64313 .67057 Mdot
.64313 .67842 Mdot
.65097 .6745 Mdot
.64705 .66665 Mdot
.65489 .6745 Mdot
.65097 .6745 Mdot
.64313 .67057 Mdot
.65489 .68234 Mdot
.65489 .67842 Mdot
.65489 .6745 Mdot
.65097 .6745 Mdot
.65097 .67057 Mdot
.65097 .67842 Mdot
.65489 .68234 Mdot
.65097 .6745 Mdot
.65489 .67842 Mdot
.65881 .67842 Mdot
.65881 .67842 Mdot
.65097 .67057 Mdot
.65489 .67057 Mdot
.65881 .6745 Mdot
.65097 .66665 Mdot
.65097 .67057 Mdot
.65881 .6745 Mdot
.65489 .6745 Mdot
.66273 .68234 Mdot
.66273 .68234 Mdot
.65881 .67057 Mdot
.65489 .66273 Mdot
.66273 .67842 Mdot
.66273 .67842 Mdot
.66665 .6745 Mdot
.65881 .67057 Mdot
.65881 .6745 Mdot
.65881 .68234 Mdot
.65097 .6745 Mdot
.65097 .6745 Mdot
.65489 .67842 Mdot
.65489 .67842 Mdot
.65097 .67057 Mdot
.65881 .68234 Mdot
.65881 .68234 Mdot
.65881 .68234 Mdot
.65489 .67842 Mdot
.66273 .68234 Mdot
.65881 .6745 Mdot
.65881 .67842 Mdot
.66273 .67842 Mdot
.65881 .67842 Mdot
.66273 .68234 Mdot
.65489 .6745 Mdot
.64705 .67057 Mdot
.63528 .65881 Mdot
.63528 .66665 Mdot
.62744 .66665 Mdot
.62744 .65881 Mdot
.62352 .65489 Mdot
.62352 .65097 Mdot
.62352 .65097 Mdot
.63136 .65489 Mdot
.6196 .64313 Mdot
.6196 .6392 Mdot
.63136 .65097 Mdot
.6196 .63528 Mdot
.62352 .64313 Mdot
.61176 .6392 Mdot
.60391 .63528 Mdot
.60391 .63136 Mdot
.60783 .6392 Mdot
.60783 .6392 Mdot
.59215 .62352 Mdot
.58431 .62744 Mdot
.58039 .62744 Mdot
.56862 .61176 Mdot
.57646 .6196 Mdot
.57646 .6196 Mdot
.56862 .61568 Mdot
.55294 .60783 Mdot
.54902 .60783 Mdot
.54509 .60391 Mdot
.54117 .60391 Mdot
.54117 .59607 Mdot
.54902 .59607 Mdot
.53333 .58039 Mdot
.52941 .58039 Mdot
.52941 .58823 Mdot
.5098 .5647 Mdot
.51372 .56078 Mdot
.52157 .5647 Mdot
.51765 .55686 Mdot
.5098 .54509 Mdot
.50588 .54509 Mdot
.48628 .53725 Mdot
.47843 .52549 Mdot
.48235 .52941 Mdot
.47451 .5098 Mdot
.47843 .51765 Mdot
.46667 .51765 Mdot
.18434 .1961 Mdot
.14513 .14905 Mdot
.12552 .1216 Mdot
.41569 .47843 Mdot
.47451 .54509 Mdot
.49412 .56078 Mdot
.48628 .54509 Mdot
.48235 .54117 Mdot
.47059 .52941 Mdot
.46667 .53333 Mdot
.47059 .54509 Mdot
.47843 .56078 Mdot
.4902 .5647 Mdot
.4902 .55294 Mdot
.49412 .55294 Mdot
.49804 .55686 Mdot
.50196 .56862 Mdot
.50588 .57254 Mdot
.5098 .57646 Mdot
.51372 .58431 Mdot
.52157 .58431 Mdot
.52157 .57254 Mdot
.52157 .57646 Mdot
.52157 .58039 Mdot
.51372 .58039 Mdot
.51372 .58431 Mdot
.52549 .58823 Mdot
.53333 .58823 Mdot
.54117 .59215 Mdot
.53725 .59215 Mdot
.53333 .58431 Mdot
.54509 .59607 Mdot
.56078 .61176 Mdot
.5647 .60391 Mdot
.56862 .59607 Mdot
.57254 .60391 Mdot
.57254 .60391 Mdot
.57646 .60783 Mdot
.56862 .60391 Mdot
.58823 .61568 Mdot
.58431 .61568 Mdot
.58823 .6196 Mdot
.58431 .62352 Mdot
.59215 .6392 Mdot
.59215 .6392 Mdot
.60783 .64705 Mdot
.61176 .64705 Mdot
.6196 .65489 Mdot
.6196 .65489 Mdot
.6196 .65489 Mdot
.6196 .65489 Mdot
.63136 .66273 Mdot
.64705 .67842 Mdot
.64313 .65881 Mdot
.64313 .66273 Mdot
.64705 .66273 Mdot
.64313 .66665 Mdot
.64313 .6745 Mdot
.6392 .6745 Mdot
.65097 .67842 Mdot
.64705 .67057 Mdot
.64313 .66273 Mdot
.6392 .66273 Mdot
.64705 .66665 Mdot
.64705 .66665 Mdot
.64313 .66665 Mdot
.65489 .67842 Mdot
.65881 .68626 Mdot
.65097 .67842 Mdot
.64705 .6745 Mdot
.65489 .6745 Mdot
.65489 .67842 Mdot
.6392 .66273 Mdot
.64313 .67057 Mdot
.64313 .67057 Mdot
.65097 .68234 Mdot
.64313 .66665 Mdot
.65097 .67842 Mdot
.65881 .68234 Mdot
.65881 .68626 Mdot
.65097 .67057 Mdot
.65097 .67057 Mdot
.64705 .66273 Mdot
.65489 .6745 Mdot
.65881 .67842 Mdot
.65489 .6745 Mdot
.65881 .67842 Mdot
.65881 .67842 Mdot
.66273 .68626 Mdot
.67057 .68234 Mdot
.6745 .68234 Mdot
.6745 .69018 Mdot
.67057 .68626 Mdot
.66665 .67842 Mdot
.67057 .68234 Mdot
.66665 .68626 Mdot
.66273 .6745 Mdot
.66273 .67842 Mdot
.65489 .6745 Mdot
.65489 .67842 Mdot
.65097 .6745 Mdot
.65881 .68234 Mdot
.65097 .6745 Mdot
.65097 .67842 Mdot
.65489 .67842 Mdot
.67057 .6941 Mdot
.6745 .69018 Mdot
.67842 .6941 Mdot
.66665 .68234 Mdot
.66273 .68234 Mdot
.66273 .68234 Mdot
.65489 .6745 Mdot
.64705 .67057 Mdot
.65097 .67842 Mdot
.64313 .67842 Mdot
.63528 .67057 Mdot
.63136 .67057 Mdot
.62352 .66273 Mdot
.61176 .64705 Mdot
.61568 .65097 Mdot
.6196 .65881 Mdot
.62352 .65881 Mdot
.62352 .65489 Mdot
.6196 .64705 Mdot
.62744 .65881 Mdot
.61176 .64313 Mdot
.61176 .64313 Mdot
.59999 .63136 Mdot
.60391 .6392 Mdot
.60783 .64705 Mdot
.60391 .6392 Mdot
.60391 .63528 Mdot
.59607 .63528 Mdot
.58039 .62744 Mdot
.57646 .62744 Mdot
.57646 .62352 Mdot
.57254 .61568 Mdot
.57646 .62352 Mdot
.57254 .6196 Mdot
.5647 .61176 Mdot
.54902 .61176 Mdot
.54117 .60391 Mdot
.54509 .60783 Mdot
.54117 .59999 Mdot
.55294 .61176 Mdot
.54509 .60391 Mdot
.53725 .60391 Mdot
.54117 .59999 Mdot
.52549 .58431 Mdot
.52549 .58039 Mdot
.52941 .56862 Mdot
.52549 .5647 Mdot
.52941 .57254 Mdot
.51372 .55686 Mdot
.49412 .54509 Mdot
.48235 .53333 Mdot
.4902 .53725 Mdot
.49412 .53333 Mdot
.4902 .52157 Mdot
.47843 .51372 Mdot
.45491 .50588 Mdot
.40001 .45098 Mdot
.3804 .44314 Mdot
.40785 .46667 Mdot
.46275 .53725 Mdot
.48235 .54902 Mdot
.47451 .54117 Mdot
.48628 .54902 Mdot
.47843 .54509 Mdot
.46667 .53725 Mdot
.47059 .54509 Mdot
.46275 .53725 Mdot
.47843 .54509 Mdot
.4902 .54902 Mdot
.49412 .55686 Mdot
.49412 .55686 Mdot
.49804 .56078 Mdot
.50196 .5647 Mdot
.50588 .55686 Mdot
.52157 .58039 Mdot
.52549 .58039 Mdot
.52157 .57254 Mdot
.51372 .56078 Mdot
.5098 .5647 Mdot
.51372 .56862 Mdot
.52549 .58823 Mdot
.52941 .58431 Mdot
.52941 .58823 Mdot
.53725 .59215 Mdot
.53333 .58431 Mdot
.54902 .59999 Mdot
.56078 .61176 Mdot
.55686 .60391 Mdot
.55686 .59999 Mdot
.56078 .59999 Mdot
.56862 .60391 Mdot
.56862 .60391 Mdot
.57254 .60391 Mdot
.58039 .61176 Mdot
.59607 .62352 Mdot
.58823 .6196 Mdot
.58039 .61176 Mdot
.58039 .6196 Mdot
.58431 .62744 Mdot
.58823 .63528 Mdot
.59999 .64705 Mdot
.60783 .64705 Mdot
.61176 .65097 Mdot
.60391 .64313 Mdot
.60783 .65097 Mdot
.62352 .65881 Mdot
.61568 .65097 Mdot
.61176 .64313 Mdot
.61176 .64313 Mdot
.62352 .65489 Mdot
.62744 .66273 Mdot
.62744 .66273 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.63528 .66665 Mdot
.63136 .66273 Mdot
.63528 .65881 Mdot
.6392 .66273 Mdot
.64313 .66665 Mdot
.64313 .67057 Mdot
.65097 .68234 Mdot
.64313 .6745 Mdot
.64705 .67057 Mdot
.65097 .67057 Mdot
.64705 .67057 Mdot
.64705 .6745 Mdot
.63528 .65881 Mdot
.63136 .66273 Mdot
.63528 .66665 Mdot
.64313 .6745 Mdot
.64705 .68234 Mdot
.64313 .6745 Mdot
.64313 .67842 Mdot
.6392 .66665 Mdot
.6392 .66665 Mdot
.64313 .66665 Mdot
.64705 .67057 Mdot
.65097 .67057 Mdot
.65489 .67057 Mdot
.65881 .6745 Mdot
.65881 .6745 Mdot
.65489 .6745 Mdot
.64705 .67057 Mdot
.64705 .66665 Mdot
.65881 .67057 Mdot
.66273 .6745 Mdot
.65881 .67057 Mdot
.66273 .6745 Mdot
.65881 .67057 Mdot
.65489 .66665 Mdot
.64705 .65881 Mdot
.65097 .66665 Mdot
.64705 .66273 Mdot
.65489 .6745 Mdot
.64705 .66665 Mdot
.65489 .67842 Mdot
.65489 .67842 Mdot
.65489 .67842 Mdot
.65097 .6745 Mdot
.65097 .67057 Mdot
.65097 .66665 Mdot
.65489 .67057 Mdot
.64705 .67057 Mdot
.64705 .67057 Mdot
.6392 .66273 Mdot
.64705 .67057 Mdot
.64705 .67842 Mdot
.6392 .67057 Mdot
.6392 .6745 Mdot
.63136 .66665 Mdot
.62744 .66273 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.62352 .65881 Mdot
.62352 .65881 Mdot
.6196 .65489 Mdot
.61176 .64705 Mdot
.61176 .65097 Mdot
.61176 .65097 Mdot
.60783 .64705 Mdot
.59999 .64313 Mdot
.59215 .6392 Mdot
.58431 .63136 Mdot
.59607 .63528 Mdot
.59215 .63136 Mdot
.58039 .6196 Mdot
.59215 .6392 Mdot
.59215 .6392 Mdot
.57646 .62744 Mdot
.5647 .6196 Mdot
.56862 .61568 Mdot
.56078 .60783 Mdot
.55294 .59999 Mdot
.55686 .60391 Mdot
.55294 .60391 Mdot
.55294 .61176 Mdot
.54509 .60391 Mdot
.54117 .59999 Mdot
.54509 .60783 Mdot
.53725 .59999 Mdot
.52157 .58823 Mdot
.52157 .58431 Mdot
.52157 .58039 Mdot
.51765 .57646 Mdot
.51765 .5647 Mdot
.5098 .55686 Mdot
.51372 .56078 Mdot
.50588 .55686 Mdot
.50196 .55686 Mdot
.49412 .54509 Mdot
.49412 .54509 Mdot
.49804 .54902 Mdot
.48235 .52941 Mdot
.47059 .52157 Mdot
.46275 .51765 Mdot
.44706 .5098 Mdot
.41569 .48628 Mdot
.38432 .44314 Mdot
.45883 .53725 Mdot
.46275 .54509 Mdot
.46667 .54117 Mdot
.47059 .54117 Mdot
.47451 .54117 Mdot
.47059 .53725 Mdot
.46667 .53333 Mdot
.45883 .52549 Mdot
.47059 .53725 Mdot
.48628 .54509 Mdot
.48235 .54509 Mdot
.48628 .54902 Mdot
.50196 .5647 Mdot
.51765 .56862 Mdot
.51765 .56862 Mdot
.52549 .57646 Mdot
.53725 .58823 Mdot
.52157 .57254 Mdot
.51765 .56862 Mdot
.51765 .57254 Mdot
.51765 .56862 Mdot
.51765 .56862 Mdot
.52941 .57646 Mdot
.52941 .58039 Mdot
.53333 .58039 Mdot
.53333 .58039 Mdot
.53725 .58431 Mdot
.54509 .59215 Mdot
.54117 .58431 Mdot
.55294 .59215 Mdot
.56078 .59607 Mdot
.56078 .58039 Mdot
.56862 .59607 Mdot
.57254 .60391 Mdot
.57646 .61176 Mdot
.57646 .61176 Mdot
.57254 .61176 Mdot
.56862 .60783 Mdot
.57646 .61568 Mdot
.57646 .6196 Mdot
.58431 .62744 Mdot
.58431 .6392 Mdot
.58039 .6392 Mdot
.59607 .64313 Mdot
.59215 .63528 Mdot
.59607 .64705 Mdot
.60391 .64705 Mdot
.60783 .64705 Mdot
.61176 .64313 Mdot
.62352 .65489 Mdot
.6196 .65489 Mdot
.61568 .65097 Mdot
.6196 .65097 Mdot
.6196 .65097 Mdot
.63136 .66273 Mdot
.62352 .65489 Mdot
.6196 .65489 Mdot
.6196 .65489 Mdot
.62744 .65489 Mdot
.63136 .65881 Mdot
.62352 .65489 Mdot
.64313 .66665 Mdot
.64705 .6745 Mdot
.64313 .67057 Mdot
.64705 .66665 Mdot
.64705 .67057 Mdot
.63528 .65881 Mdot
.64313 .66665 Mdot
.64313 .66273 Mdot
.62744 .65097 Mdot
.62352 .65489 Mdot
.63528 .66665 Mdot
.6392 .67057 Mdot
.63528 .67057 Mdot
.63528 .66665 Mdot
.63528 .66273 Mdot
.63136 .65881 Mdot
.63528 .65881 Mdot
.65097 .67057 Mdot
.65097 .66665 Mdot
.65489 .67057 Mdot
.64705 .66273 Mdot
.64705 .65881 Mdot
.65097 .66665 Mdot
.64313 .65881 Mdot
.64313 .65489 Mdot
.65097 .66273 Mdot
.65489 .66665 Mdot
.64705 .65881 Mdot
.65097 .66665 Mdot
.64313 .65881 Mdot
.64705 .65881 Mdot
.64705 .66273 Mdot
.64705 .66665 Mdot
.63528 .65881 Mdot
.6392 .66665 Mdot
.64313 .6745 Mdot
.64313 .67057 Mdot
.64313 .67057 Mdot
.64313 .67842 Mdot
.64705 .67842 Mdot
.63528 .66273 Mdot
.6392 .66665 Mdot
.64313 .66665 Mdot
.6392 .66273 Mdot
.63528 .65881 Mdot
.63528 .65881 Mdot
.6392 .67057 Mdot
.6392 .66665 Mdot
.6392 .66273 Mdot
.6392 .66665 Mdot
.63528 .66273 Mdot
.63136 .65881 Mdot
.62744 .64705 Mdot
.63136 .65489 Mdot
.62744 .65489 Mdot
.6196 .65097 Mdot
.61568 .64705 Mdot
.59999 .63528 Mdot
.60391 .64313 Mdot
.61176 .64705 Mdot
.60783 .64313 Mdot
.59607 .63528 Mdot
.59215 .63528 Mdot
.59607 .6392 Mdot
.59215 .62744 Mdot
.59607 .62744 Mdot
.59215 .62744 Mdot
.58039 .62352 Mdot
.58039 .6196 Mdot
.56862 .61568 Mdot
.56862 .6196 Mdot
.56862 .62352 Mdot
.56078 .61176 Mdot
.54902 .59607 Mdot
.54509 .59607 Mdot
.54902 .59607 Mdot
.54902 .59607 Mdot
.54509 .59215 Mdot
.54509 .59215 Mdot
.53725 .58431 Mdot
.52941 .58039 Mdot
.51765 .56862 Mdot
.51765 .57646 Mdot
.51765 .58039 Mdot
.51372 .57254 Mdot
.51372 .5647 Mdot
.50588 .55686 Mdot
.50588 .56078 Mdot
.50588 .55686 Mdot
.4902 .54509 Mdot
.48628 .54117 Mdot
.48235 .53333 Mdot
.47451 .52549 Mdot
.47059 .51765 Mdot
.45883 .51765 Mdot
.45491 .51372 Mdot
.44314 .50196 Mdot
.43138 .50196 Mdot
.40785 .46667 Mdot
.44706 .52157 Mdot
.45883 .54117 Mdot
.47059 .54117 Mdot
.46667 .54117 Mdot
.46667 .53725 Mdot
.45098 .52157 Mdot
.45491 .52157 Mdot
.45883 .52941 Mdot
.47843 .54902 Mdot
.47451 .54117 Mdot
.48628 .54902 Mdot
.49412 .55686 Mdot
.4902 .54902 Mdot
.5098 .56078 Mdot
.51765 .5647 Mdot
.52157 .56862 Mdot
.53333 .57646 Mdot
.5098 .55294 Mdot
.51765 .5647 Mdot
.52157 .56862 Mdot
.52157 .56862 Mdot
.51765 .56862 Mdot
.53725 .58039 Mdot
.53333 .57254 Mdot
.54117 .56862 Mdot
.54117 .57646 Mdot
.53333 .57646 Mdot
.54902 .58823 Mdot
.55686 .59215 Mdot
.56862 .59999 Mdot
.57254 .59607 Mdot
.58039 .59999 Mdot
.56862 .58823 Mdot
.57254 .59215 Mdot
.57254 .59999 Mdot
.57254 .60391 Mdot
.57254 .60783 Mdot
.57254 .61176 Mdot
.57254 .61176 Mdot
.57646 .62352 Mdot
.56862 .61568 Mdot
.58039 .63136 Mdot
.58039 .63136 Mdot
.58039 .62744 Mdot
.58823 .63136 Mdot
.59215 .63528 Mdot
.59607 .63528 Mdot
.58823 .62744 Mdot
.61568 .65097 Mdot
.61568 .64313 Mdot
.61568 .64313 Mdot
.61176 .6392 Mdot
.61568 .64705 Mdot
.60783 .64705 Mdot
.61568 .65489 Mdot
.6196 .65489 Mdot
.62744 .65489 Mdot
.62352 .65489 Mdot
.6196 .65097 Mdot
.62352 .65489 Mdot
.62352 .65097 Mdot
.63136 .65881 Mdot
.6392 .66273 Mdot
.6392 .66273 Mdot
.6392 .66273 Mdot
.63528 .65881 Mdot
.63528 .65881 Mdot
.63528 .65881 Mdot
.6392 .65881 Mdot
.64313 .66273 Mdot
.64313 .65881 Mdot
.6392 .65881 Mdot
.63528 .65881 Mdot
.63528 .65881 Mdot
.63528 .65881 Mdot
.63136 .65097 Mdot
.63528 .65489 Mdot
.63528 .65489 Mdot
.65097 .67057 Mdot
.64313 .66273 Mdot
.6392 .65881 Mdot
.64705 .66665 Mdot
.64313 .65881 Mdot
.64313 .65881 Mdot
.65097 .66665 Mdot
.65489 .67057 Mdot
.65489 .66665 Mdot
.65489 .66665 Mdot
.64705 .66665 Mdot
.64705 .66273 Mdot
.64705 .66273 Mdot
.64313 .65881 Mdot
.65489 .6745 Mdot
.64705 .66273 Mdot
.6392 .65489 Mdot
.63528 .66273 Mdot
.63136 .66273 Mdot
.6392 .67057 Mdot
.6392 .66665 Mdot
.64313 .67057 Mdot
.64313 .67057 Mdot
.63136 .65881 Mdot
.6392 .66665 Mdot
.64313 .67057 Mdot
.6392 .66665 Mdot
.63528 .65881 Mdot
.64313 .66665 Mdot
.64313 .66665 Mdot
.63528 .66273 Mdot
.63528 .65097 Mdot
.63528 .65489 Mdot
.63528 .65881 Mdot
.63136 .65097 Mdot
.6196 .64313 Mdot
.62352 .65097 Mdot
.6196 .6392 Mdot
.62744 .65097 Mdot
.61176 .64313 Mdot
.60783 .6392 Mdot
.60783 .6392 Mdot
.60783 .64313 Mdot
.60391 .6392 Mdot
.59607 .63528 Mdot
.59215 .62352 Mdot
.59607 .62744 Mdot
.59999 .63136 Mdot
.59215 .62352 Mdot
.59999 .63528 Mdot
.59215 .62744 Mdot
.58431 .6196 Mdot
.57646 .61176 Mdot
.56862 .61176 Mdot
.56078 .60391 Mdot
.56862 .61176 Mdot
.57254 .61568 Mdot
.56078 .60783 Mdot
.55686 .60783 Mdot
.54509 .59607 Mdot
.54509 .59215 Mdot
.54902 .59215 Mdot
.54509 .58823 Mdot
.53333 .57254 Mdot
.52549 .57254 Mdot
.52549 .57646 Mdot
.52157 .57646 Mdot
.52549 .58431 Mdot
.52549 .56862 Mdot
.52157 .5647 Mdot
.50588 .54902 Mdot
.4902 .53333 Mdot
.47843 .52549 Mdot
.47451 .52549 Mdot
.47059 .52941 Mdot
.47451 .53333 Mdot
.47059 .53333 Mdot
.46667 .53333 Mdot
.45491 .52549 Mdot
.45098 .52157 Mdot
.43138 .50588 Mdot
.39609 .45883 Mdot
.44706 .52157 Mdot
.45098 .53333 Mdot
.45883 .54117 Mdot
.45491 .52549 Mdot
.44314 .51765 Mdot
.4353 .5098 Mdot
.45491 .53333 Mdot
.45098 .52941 Mdot
.45883 .53333 Mdot
.46667 .54117 Mdot
.46667 .53725 Mdot
.47059 .53333 Mdot
.4902 .55294 Mdot
.4902 .53725 Mdot
.50588 .55294 Mdot
.5098 .5647 Mdot
.51765 .56862 Mdot
.51765 .56862 Mdot
.51765 .56862 Mdot
.52549 .57646 Mdot
.52941 .58431 Mdot
.52941 .58431 Mdot
.53333 .58823 Mdot
.53333 .58039 Mdot
.53725 .58431 Mdot
.52941 .57254 Mdot
.53725 .58431 Mdot
.54117 .58039 Mdot
.54902 .58823 Mdot
.55686 .59215 Mdot
.55686 .59215 Mdot
.56862 .59607 Mdot
.56862 .59999 Mdot
.5647 .59215 Mdot
.5647 .59999 Mdot
.56078 .59607 Mdot
.56862 .60391 Mdot
.5647 .60391 Mdot
.56862 .61176 Mdot
.57646 .61568 Mdot
.57254 .61568 Mdot
.57646 .6196 Mdot
.57646 .6196 Mdot
.57254 .61568 Mdot
.58039 .6196 Mdot
.59607 .6392 Mdot
.59607 .6392 Mdot
.59215 .63136 Mdot
.59215 .62744 Mdot
.59999 .63528 Mdot
.59607 .63136 Mdot
.59607 .63528 Mdot
.60391 .64705 Mdot
.60783 .65489 Mdot
.60391 .65097 Mdot
.59999 .64313 Mdot
.61176 .65881 Mdot
.60391 .65097 Mdot
.61568 .65489 Mdot
.61176 .64705 Mdot
.62352 .65881 Mdot
.62744 .66273 Mdot
.62744 .65489 Mdot
.6196 .65097 Mdot
.62352 .65097 Mdot
.63136 .65881 Mdot
.62352 .65097 Mdot
.63136 .65489 Mdot
.62744 .64705 Mdot
.63136 .65097 Mdot
.62744 .64313 Mdot
.63528 .65881 Mdot
.63136 .65881 Mdot
.62352 .65097 Mdot
.62352 .65489 Mdot
.6196 .65097 Mdot
.62352 .65097 Mdot
.63136 .66273 Mdot
.63528 .66665 Mdot
.63528 .66273 Mdot
.63528 .66665 Mdot
.63136 .66273 Mdot
.62744 .65881 Mdot
.63528 .66273 Mdot
.6392 .66665 Mdot
.64705 .67057 Mdot
.6392 .65489 Mdot
.64313 .66273 Mdot
.63528 .66273 Mdot
.63528 .66273 Mdot
.63136 .65097 Mdot
.62744 .64705 Mdot
.6392 .65489 Mdot
.63528 .65489 Mdot
.64313 .66273 Mdot
.6392 .66273 Mdot
.63136 .66273 Mdot
.63136 .66273 Mdot
.62352 .65881 Mdot
.63136 .65881 Mdot
.63136 .66665 Mdot
.63136 .66273 Mdot
.62352 .65881 Mdot
.62352 .66273 Mdot
.62352 .65097 Mdot
.62744 .65881 Mdot
.64313 .67057 Mdot
.64313 .67057 Mdot
.63528 .66665 Mdot
.62352 .65097 Mdot
.61568 .64705 Mdot
.61568 .65097 Mdot
.62744 .65489 Mdot
.6196 .64705 Mdot
.61568 .65097 Mdot
.62352 .65881 Mdot
.61568 .64705 Mdot
.60391 .63136 Mdot
.60391 .63528 Mdot
.60391 .63528 Mdot
.59999 .63528 Mdot
.59607 .63136 Mdot
.58823 .63136 Mdot
.58823 .62352 Mdot
.59215 .6196 Mdot
.59607 .62352 Mdot
.58431 .61568 Mdot
.58823 .62352 Mdot
.57646 .60783 Mdot
.57646 .61568 Mdot
.57254 .61176 Mdot
.5647 .60783 Mdot
.55294 .59607 Mdot
.54902 .59607 Mdot
.56078 .60391 Mdot
.55294 .59607 Mdot
.56078 .59999 Mdot
.55294 .59607 Mdot
.54117 .58823 Mdot
.54117 .58039 Mdot
.52941 .56862 Mdot
.52157 .56078 Mdot
.52157 .56862 Mdot
.51765 .5647 Mdot
.5098 .56862 Mdot
.50588 .5647 Mdot
.50588 .56078 Mdot
.5098 .55686 Mdot
.51372 .54902 Mdot
.5098 .55294 Mdot
.48628 .54117 Mdot
.47059 .53725 Mdot
.46667 .53725 Mdot
.46275 .52941 Mdot
.45491 .52157 Mdot
.45491 .52549 Mdot
.44706 .52157 Mdot
.4353 .5098 Mdot
.4353 .51765 Mdot
.41177 .46667 Mdot
.4353 .50196 Mdot
.4353 .51765 Mdot
.43922 .52157 Mdot
.44706 .52549 Mdot
.45491 .52941 Mdot
.44706 .52549 Mdot
.44314 .52549 Mdot
.43138 .5098 Mdot
.44706 .52549 Mdot
.45883 .54117 Mdot
.45883 .52941 Mdot
.47451 .54509 Mdot
.48628 .54902 Mdot
.48628 .54509 Mdot
.50196 .56078 Mdot
.50196 .55686 Mdot
.50588 .55686 Mdot
.49804 .54902 Mdot
.49804 .56078 Mdot
.49804 .56078 Mdot
.50588 .56862 Mdot
.5098 .57254 Mdot
.5098 .56862 Mdot
.51372 .57254 Mdot
.52157 .57646 Mdot
.53333 .58039 Mdot
.53725 .57646 Mdot
.54117 .58039 Mdot
.54509 .58823 Mdot
.53725 .57646 Mdot
.53725 .57646 Mdot
.55294 .58823 Mdot
.5647 .60391 Mdot
.56078 .59999 Mdot
.55294 .59607 Mdot
.5647 .61176 Mdot
.56078 .60391 Mdot
.56862 .61176 Mdot
.55686 .59607 Mdot
.55686 .59999 Mdot
.55686 .59999 Mdot
.55294 .59999 Mdot
.56078 .61176 Mdot
.5647 .61176 Mdot
.57646 .6196 Mdot
.58039 .62352 Mdot
.58431 .62352 Mdot
.59215 .62744 Mdot
.57646 .61176 Mdot
.58039 .61176 Mdot
.58431 .61176 Mdot
.58431 .62352 Mdot
.58823 .62744 Mdot
.58431 .62744 Mdot
.58039 .62744 Mdot
.57646 .63528 Mdot
.58431 .63528 Mdot
.58431 .62744 Mdot
.58039 .62352 Mdot
.59999 .6392 Mdot
.59215 .63136 Mdot
.59607 .6392 Mdot
.61176 .64705 Mdot
.61176 .64313 Mdot
.61176 .64313 Mdot
.61176 .64705 Mdot
.61568 .65097 Mdot
.61176 .64313 Mdot
.61176 .64705 Mdot
.60783 .6392 Mdot
.61568 .64313 Mdot
.61568 .64705 Mdot
.6196 .65489 Mdot
.61176 .65097 Mdot
.61568 .65097 Mdot
.62352 .65489 Mdot
.62352 .65097 Mdot
.6196 .65097 Mdot
.62352 .65881 Mdot
.62352 .65881 Mdot
.63136 .66273 Mdot
.6196 .65097 Mdot
.62744 .65881 Mdot
.62352 .65489 Mdot
.6196 .64705 Mdot
.62352 .64705 Mdot
.6196 .64705 Mdot
.6196 .65097 Mdot
.61568 .64705 Mdot
.62352 .65489 Mdot
.6196 .65489 Mdot
.61176 .64313 Mdot
.6196 .64313 Mdot
.62744 .65489 Mdot
.6196 .65097 Mdot
.62352 .65489 Mdot
.61568 .65097 Mdot
.61568 .65097 Mdot
.61568 .65097 Mdot
.61176 .65097 Mdot
.6196 .65489 Mdot
.62744 .66665 Mdot
.6196 .66273 Mdot
.61568 .65489 Mdot
.61176 .6392 Mdot
.61176 .64705 Mdot
.61568 .64705 Mdot
.61568 .64705 Mdot
.6196 .65097 Mdot
.6196 .64705 Mdot
.61176 .64313 Mdot
.60783 .63528 Mdot
.60783 .6392 Mdot
.60783 .6392 Mdot
.60783 .64313 Mdot
.60783 .64705 Mdot
.59999 .63528 Mdot
.58823 .62744 Mdot
.58431 .6196 Mdot
.59215 .62352 Mdot
.58823 .62352 Mdot
.58823 .63136 Mdot
.58039 .62352 Mdot
.57646 .61568 Mdot
.58039 .61176 Mdot
.56862 .60391 Mdot
.5647 .61176 Mdot
.55686 .59999 Mdot
.55686 .59999 Mdot
.56078 .60391 Mdot
.5647 .61176 Mdot
.55686 .60391 Mdot
.55686 .60391 Mdot
.54902 .59215 Mdot
.54117 .58039 Mdot
.53725 .56862 Mdot
.54117 .57646 Mdot
.53725 .57254 Mdot
.52941 .57254 Mdot
.52549 .56862 Mdot
.52157 .56862 Mdot
.50588 .55686 Mdot
.50196 .55294 Mdot
.50588 .5647 Mdot
.49804 .56078 Mdot
.4902 .55686 Mdot
.49804 .56078 Mdot
.50196 .5647 Mdot
.49412 .54902 Mdot
.4902 .54509 Mdot
.47451 .52549 Mdot
.46275 .52941 Mdot
.47059 .54117 Mdot
.45098 .51765 Mdot
.44706 .51372 Mdot
.44314 .51765 Mdot
.43922 .51372 Mdot
.43138 .50588 Mdot
.41177 .4902 Mdot
.40001 .45098 Mdot
.41961 .4902 Mdot
.43138 .51765 Mdot
.4353 .52157 Mdot
.44314 .51765 Mdot
.46275 .52941 Mdot
.45491 .52157 Mdot
.45098 .52549 Mdot
.44706 .52941 Mdot
.45491 .54117 Mdot
.45883 .54509 Mdot
.47059 .54902 Mdot
.47059 .54509 Mdot
.47843 .54902 Mdot
.48235 .54902 Mdot
.49412 .55686 Mdot
.49804 .5647 Mdot
.50196 .56862 Mdot
.5098 .56862 Mdot
.49412 .55294 Mdot
.49804 .55686 Mdot
.50588 .56862 Mdot
.50588 .56862 Mdot
.5098 .57646 Mdot
.50588 .57254 Mdot
.5098 .56862 Mdot
.52941 .58039 Mdot
.53333 .58431 Mdot
.52941 .58039 Mdot
.53333 .58431 Mdot
.54902 .59999 Mdot
.54902 .59999 Mdot
.54902 .59607 Mdot
.55294 .59215 Mdot
.55686 .59607 Mdot
.54902 .59215 Mdot
.54509 .59215 Mdot
.55294 .59999 Mdot
.56078 .60391 Mdot
.5647 .61176 Mdot
.56078 .61176 Mdot
.55294 .60783 Mdot
.55294 .60391 Mdot
.55686 .61176 Mdot
.56078 .61568 Mdot
.56862 .61568 Mdot
.58039 .6196 Mdot
.58039 .61568 Mdot
.59215 .62352 Mdot
.58823 .6196 Mdot
.58431 .61568 Mdot
.58431 .61568 Mdot
.58823 .6196 Mdot
.57646 .61176 Mdot
.58039 .63136 Mdot
.58431 .63528 Mdot
.58039 .63136 Mdot
.59215 .63528 Mdot
.60391 .64705 Mdot
.59607 .63136 Mdot
.59607 .63136 Mdot
.59215 .62744 Mdot
.60391 .63136 Mdot
.59999 .62744 Mdot
.60391 .63528 Mdot
.61568 .64705 Mdot
.6196 .65489 Mdot
.61176 .65097 Mdot
.60391 .64705 Mdot
.61568 .65489 Mdot
.61568 .65489 Mdot
.61176 .64313 Mdot
.61568 .65097 Mdot
.6196 .65489 Mdot
.6196 .65881 Mdot
.61176 .65097 Mdot
.62352 .65489 Mdot
.6196 .65097 Mdot
.62352 .65489 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.63136 .65881 Mdot
.63136 .65489 Mdot
.63136 .65881 Mdot
.62352 .65881 Mdot
.62352 .65881 Mdot
.62744 .66273 Mdot
.62744 .66273 Mdot
.6196 .66273 Mdot
.61176 .65489 Mdot
.60783 .65489 Mdot
.61568 .66273 Mdot
.61176 .65489 Mdot
.61176 .64705 Mdot
.61568 .64313 Mdot
.61568 .64705 Mdot
.60783 .64313 Mdot
.6196 .65881 Mdot
.61568 .66273 Mdot
.6196 .66273 Mdot
.6196 .66273 Mdot
.62352 .67057 Mdot
.62744 .6745 Mdot
.63136 .6745 Mdot
.63528 .67057 Mdot
.63136 .67057 Mdot
.63136 .66665 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.63136 .66273 Mdot
.62352 .65489 Mdot
.61568 .64313 Mdot
.62352 .64705 Mdot
.61568 .64313 Mdot
.62352 .65881 Mdot
.6196 .65881 Mdot
.6196 .65881 Mdot
.61176 .64705 Mdot
.60783 .64705 Mdot
.60391 .6392 Mdot
.60391 .6392 Mdot
.59215 .63136 Mdot
.59215 .62744 Mdot
.58823 .63136 Mdot
.58431 .62744 Mdot
.57254 .6196 Mdot
.56862 .61568 Mdot
.56862 .6196 Mdot
.56862 .62352 Mdot
.57254 .6196 Mdot
.57254 .61176 Mdot
.57254 .61176 Mdot
.5647 .60391 Mdot
.55686 .59999 Mdot
.55294 .59607 Mdot
.55686 .59999 Mdot
.54902 .59215 Mdot
.55686 .60391 Mdot
.54509 .59607 Mdot
.53333 .58823 Mdot
.52941 .58823 Mdot
.52549 .58039 Mdot
.51372 .5647 Mdot
.51765 .57254 Mdot
.51765 .56862 Mdot
.51765 .57646 Mdot
.49804 .5647 Mdot
.4902 .55294 Mdot
.48628 .55686 Mdot
.4902 .56078 Mdot
.4902 .55686 Mdot
.47451 .53333 Mdot
.47059 .52941 Mdot
.47843 .54509 Mdot
.46275 .52941 Mdot
.46275 .53725 Mdot
.45491 .53333 Mdot
.44706 .52549 Mdot
.44314 .52549 Mdot
.43922 .52157 Mdot
.41569 .45883 Mdot
.45883 .52157 Mdot
.46275 .53333 Mdot
.45883 .52549 Mdot
.45098 .51372 Mdot
.45883 .52549 Mdot
.46667 .53333 Mdot
.46667 .52941 Mdot
.45883 .52941 Mdot
.45098 .52941 Mdot
.46667 .54117 Mdot
.48235 .54509 Mdot
.47843 .54117 Mdot
.4902 .54902 Mdot
.49412 .56078 Mdot
.49804 .56078 Mdot
.50196 .5647 Mdot
.5098 .56078 Mdot
.51765 .56078 Mdot
.52549 .56862 Mdot
.52157 .56862 Mdot
.51765 .56078 Mdot
.51765 .5647 Mdot
.51765 .5647 Mdot
.52549 .57646 Mdot
.52549 .57646 Mdot
.52941 .57646 Mdot
.53333 .57254 Mdot
.53725 .56862 Mdot
.54117 .58039 Mdot
.54117 .58431 Mdot
.54902 .59607 Mdot
.5647 .60783 Mdot
.55294 .59215 Mdot
.56078 .59999 Mdot
.56078 .59999 Mdot
.55294 .59215 Mdot
.54902 .58431 Mdot
.54902 .58431 Mdot
.5647 .59999 Mdot
.56862 .60783 Mdot
.56078 .60391 Mdot
.55294 .59999 Mdot
.5647 .61176 Mdot
.57646 .6196 Mdot
.58039 .61176 Mdot
.58823 .61568 Mdot
.59607 .6196 Mdot
.59607 .62352 Mdot
.59215 .61568 Mdot
.59607 .6196 Mdot
.59215 .61176 Mdot
.60783 .62744 Mdot
.59215 .61176 Mdot
.59607 .62352 Mdot
.60391 .6392 Mdot
.60391 .63528 Mdot
.59607 .6196 Mdot
.60391 .62744 Mdot
.61176 .64313 Mdot
.61176 .6392 Mdot
.60391 .63136 Mdot
.61176 .63528 Mdot
.61176 .63136 Mdot
.61176 .62352 Mdot
.6196 .63136 Mdot
.6196 .6392 Mdot
.6196 .6392 Mdot
.62352 .64705 Mdot
.6196 .6392 Mdot
.62744 .65097 Mdot
.61568 .64313 Mdot
.60783 .63136 Mdot
.62352 .65097 Mdot
.63136 .65881 Mdot
.6196 .64313 Mdot
.62744 .64705 Mdot
.63528 .65489 Mdot
.63136 .64705 Mdot
.63136 .65097 Mdot
.63136 .65489 Mdot
.6392 .65881 Mdot
.6392 .65881 Mdot
.63528 .65881 Mdot
.62352 .64313 Mdot
.62352 .65097 Mdot
.62352 .65097 Mdot
.61568 .64705 Mdot
.6196 .65097 Mdot
.61568 .65097 Mdot
.61568 .65097 Mdot
.6196 .65881 Mdot
.61176 .64705 Mdot
.63136 .65881 Mdot
.63136 .65489 Mdot
.62744 .64705 Mdot
.61568 .6392 Mdot
.61568 .64313 Mdot
.61568 .6392 Mdot
.62352 .65489 Mdot
.62744 .65489 Mdot
.63136 .65489 Mdot
.6196 .65097 Mdot
.62352 .65489 Mdot
.62744 .64705 Mdot
.62744 .65097 Mdot
.62744 .65489 Mdot
.62744 .65881 Mdot
.63136 .65881 Mdot
.62352 .65097 Mdot
.62744 .65097 Mdot
.62744 .64705 Mdot
.61568 .63136 Mdot
.61568 .63136 Mdot
.61176 .63136 Mdot
.6196 .6392 Mdot
.6196 .6392 Mdot
.61176 .63136 Mdot
.60391 .63136 Mdot
.59999 .63136 Mdot
.59999 .62744 Mdot
.60391 .62744 Mdot
.59999 .62352 Mdot
.59215 .61568 Mdot
.58431 .61568 Mdot
.57646 .61176 Mdot
.57646 .61568 Mdot
.58039 .6196 Mdot
.58039 .61568 Mdot
.57646 .60783 Mdot
.56862 .59215 Mdot
.56078 .58431 Mdot
.56078 .58823 Mdot
.56078 .59215 Mdot
.54509 .57646 Mdot
.54902 .57646 Mdot
.54509 .57646 Mdot
.54509 .58823 Mdot
.54117 .58431 Mdot
.53333 .58039 Mdot
.52549 .57254 Mdot
.52549 .57646 Mdot
.51765 .56078 Mdot
.51765 .56078 Mdot
.52157 .5647 Mdot
.50196 .54902 Mdot
.48235 .53333 Mdot
.48628 .54509 Mdot
.48235 .54509 Mdot
.47843 .54117 Mdot
.47059 .52549 Mdot
.47059 .51765 Mdot
.47451 .52549 Mdot
.46667 .52157 Mdot
.45883 .5098 Mdot
.46667 .52549 Mdot
.45883 .51765 Mdot
.45491 .51765 Mdot
.43922 .50588 Mdot
.41569 .48628 Mdot
.39609 .42746 Mdot
.43922 .49412 Mdot
.44706 .50588 Mdot
.43922 .50196 Mdot
.45491 .51372 Mdot
.45098 .50588 Mdot
.45098 .50588 Mdot
.46275 .52157 Mdot
.46667 .52549 Mdot
.46667 .52941 Mdot
.46667 .52941 Mdot
.47451 .52941 Mdot
.48235 .54117 Mdot
.48628 .54902 Mdot
.48628 .54902 Mdot
.49412 .55294 Mdot
.50196 .55294 Mdot
.51765 .56862 Mdot
.5098 .55294 Mdot
.52549 .5647 Mdot
.51765 .55686 Mdot
.51765 .56078 Mdot
.51765 .56862 Mdot
.5098 .56078 Mdot
.5098 .56078 Mdot
.51765 .56862 Mdot
.52157 .57646 Mdot
.52549 .58039 Mdot
.53333 .58039 Mdot
.53725 .57646 Mdot
.54509 .58039 Mdot
.54902 .58039 Mdot
.55294 .59607 Mdot
.54902 .59607 Mdot
.55686 .59607 Mdot
.5647 .59999 Mdot
.54902 .58823 Mdot
.54509 .58823 Mdot
.55294 .59607 Mdot
.56862 .60783 Mdot
.56078 .59999 Mdot
.55294 .58823 Mdot
.56078 .59607 Mdot
.56078 .59999 Mdot
.57254 .61176 Mdot
.57646 .61568 Mdot
.57646 .61176 Mdot
.58039 .61568 Mdot
.58431 .61568 Mdot
.58823 .61568 Mdot
.59999 .62744 Mdot
.59215 .61568 Mdot
.59999 .6196 Mdot
.59607 .61568 Mdot
.59607 .6196 Mdot
.59607 .6196 Mdot
.59607 .6196 Mdot
.60391 .62744 Mdot
.61176 .63136 Mdot
.60783 .62744 Mdot
.60391 .62744 Mdot
.60783 .63136 Mdot
.61568 .63528 Mdot
.6196 .63528 Mdot
.6196 .63136 Mdot
.6196 .63528 Mdot
.61176 .63136 Mdot
.60783 .63136 Mdot
.61568 .6392 Mdot
.61176 .6392 Mdot
.61176 .63528 Mdot
.6196 .64705 Mdot
.6196 .64705 Mdot
.6196 .65097 Mdot
.62744 .64705 Mdot
.63136 .65097 Mdot
.63136 .64705 Mdot
.63136 .6392 Mdot
.6196 .62744 Mdot
.62352 .63528 Mdot
.62744 .64313 Mdot
.63528 .65097 Mdot
.62744 .64313 Mdot
.63136 .64705 Mdot
.63136 .64313 Mdot
.63136 .64313 Mdot
.62744 .6392 Mdot
.63136 .64705 Mdot
.62744 .64313 Mdot
.62744 .64313 Mdot
.63136 .65097 Mdot
.63136 .65489 Mdot
.63528 .65881 Mdot
.63528 .65881 Mdot
.62352 .6392 Mdot
.6196 .63528 Mdot
.63136 .64705 Mdot
.62744 .64705 Mdot
.61176 .63528 Mdot
.61568 .64705 Mdot
.62744 .64705 Mdot
.63136 .65097 Mdot
.6196 .63136 Mdot
.62352 .63528 Mdot
.62744 .64313 Mdot
.62352 .63136 Mdot
.63528 .64313 Mdot
.63136 .64313 Mdot
.6196 .63528 Mdot
.61568 .6392 Mdot
.60783 .63136 Mdot
.61568 .6392 Mdot
.61568 .63528 Mdot
.59999 .6196 Mdot
.60783 .63528 Mdot
.60783 .63136 Mdot
.60391 .62744 Mdot
.59999 .62744 Mdot
.59999 .63136 Mdot
.59607 .62352 Mdot
.59607 .62352 Mdot
.59999 .62352 Mdot
.59999 .61176 Mdot
.60391 .62352 Mdot
.58431 .61176 Mdot
.58039 .60783 Mdot
.57646 .60783 Mdot
.5647 .59215 Mdot
.58039 .60783 Mdot
.58431 .60783 Mdot
.57254 .58823 Mdot
.55686 .57646 Mdot
.5647 .58823 Mdot
.55686 .58039 Mdot
.55686 .58823 Mdot
.54902 .57646 Mdot
.53333 .56862 Mdot
.53725 .58039 Mdot
.52941 .57254 Mdot
.52549 .56862 Mdot
.52941 .57646 Mdot
.51372 .55294 Mdot
.52157 .56078 Mdot
.51765 .55294 Mdot
.51765 .54902 Mdot
.50588 .53725 Mdot
.4902 .53333 Mdot
.49412 .54117 Mdot
.50588 .55686 Mdot
.48628 .53333 Mdot
.48235 .52941 Mdot
.46667 .51372 Mdot
.45883 .50588 Mdot
.47059 .51765 Mdot
.46667 .5098 Mdot
.45883 .50588 Mdot
.45098 .50196 Mdot
.44314 .50196 Mdot
.4353 .50588 Mdot
.41177 .48628 Mdot
.39609 .4353 Mdot
.4353 .48628 Mdot
.45098 .51372 Mdot
.45491 .51765 Mdot
.44706 .5098 Mdot
.45491 .5098 Mdot
.45098 .5098 Mdot
.47059 .52941 Mdot
.47451 .53725 Mdot
.48235 .54509 Mdot
.47451 .54117 Mdot
.47451 .54509 Mdot
.47843 .54509 Mdot
.48628 .55294 Mdot
.4902 .55294 Mdot
.49804 .56078 Mdot
.50196 .55294 Mdot
.5098 .55686 Mdot
.49804 .54509 Mdot
.50588 .55294 Mdot
.51372 .55686 Mdot
.51765 .55686 Mdot
.5098 .56078 Mdot
.5098 .5647 Mdot
.50588 .5647 Mdot
.50196 .56862 Mdot
.50588 .57254 Mdot
.51372 .57646 Mdot
.52549 .58431 Mdot
.52941 .58039 Mdot
.52941 .58039 Mdot
.54117 .58039 Mdot
.53725 .58431 Mdot
.53725 .58431 Mdot
.54117 .58431 Mdot
.54509 .58431 Mdot
.56078 .59607 Mdot
.56078 .59607 Mdot
.55686 .59999 Mdot
.56862 .61568 Mdot
.5647 .60783 Mdot
.5647 .60391 Mdot
.55686 .59215 Mdot
.5647 .60391 Mdot
.5647 .60391 Mdot
.57254 .61568 Mdot
.5647 .61176 Mdot
.56862 .61176 Mdot
.56078 .59999 Mdot
.58039 .61568 Mdot
.59215 .62352 Mdot
.59215 .61568 Mdot
.58823 .61176 Mdot
.58823 .61568 Mdot
.59215 .61176 Mdot
.59999 .6196 Mdot
.59999 .61568 Mdot
.59215 .61176 Mdot
.60391 .62352 Mdot
.61176 .63528 Mdot
.61176 .6392 Mdot
.61176 .6392 Mdot
.61176 .63136 Mdot
.60783 .62744 Mdot
.61176 .6392 Mdot
.60783 .63136 Mdot
.60391 .63136 Mdot
.59999 .63528 Mdot
.60783 .6392 Mdot
.60783 .6392 Mdot
.60391 .63528 Mdot
.60783 .65097 Mdot
.60391 .65097 Mdot
.60391 .64313 Mdot
.60783 .63528 Mdot
.62352 .64313 Mdot
.62744 .64705 Mdot
.62744 .64313 Mdot
.6196 .6392 Mdot
.63136 .65097 Mdot
.62744 .64313 Mdot
.63528 .65097 Mdot
.63528 .65097 Mdot
.63136 .64705 Mdot
.63136 .64313 Mdot
.62744 .64313 Mdot
.63528 .65097 Mdot
.62744 .64313 Mdot
.62352 .6392 Mdot
.6196 .6392 Mdot
.6196 .65097 Mdot
.61176 .64313 Mdot
.61568 .64313 Mdot
.61568 .64313 Mdot
.61568 .6392 Mdot
.61568 .6392 Mdot
.61568 .64313 Mdot
.61568 .64705 Mdot
.61568 .64313 Mdot
.6196 .64705 Mdot
.61568 .63136 Mdot
.62352 .6392 Mdot
.62352 .6392 Mdot
.61176 .62352 Mdot
.62352 .63136 Mdot
.62352 .63528 Mdot
.62352 .63528 Mdot
.62744 .64313 Mdot
.6196 .64313 Mdot
.61176 .6392 Mdot
.59607 .6196 Mdot
.59607 .6196 Mdot
.60391 .63528 Mdot
.59999 .62352 Mdot
.59999 .62744 Mdot
.59999 .63136 Mdot
.59999 .63528 Mdot
.58823 .6196 Mdot
.58039 .61176 Mdot
.58431 .6196 Mdot
.59215 .62744 Mdot
.59215 .62352 Mdot
.58431 .61568 Mdot
.58431 .61568 Mdot
.58431 .61176 Mdot
.57254 .60391 Mdot
.5647 .59999 Mdot
.55686 .58431 Mdot
.5647 .59999 Mdot
.5647 .59215 Mdot
.56078 .58431 Mdot
.55294 .57646 Mdot
.54902 .57254 Mdot
.53333 .5647 Mdot
.53333 .5647 Mdot
.53725 .57254 Mdot
.52941 .5647 Mdot
.52941 .57646 Mdot
.52157 .57646 Mdot
.51765 .57254 Mdot
.51372 .56862 Mdot
.50196 .56078 Mdot
.51372 .56862 Mdot
.50196 .55294 Mdot
.5098 .55294 Mdot
.50588 .54902 Mdot
.49804 .54509 Mdot
.4902 .53725 Mdot
.4902 .53725 Mdot
.48235 .52941 Mdot
.47843 .51765 Mdot
.47451 .51372 Mdot
.45883 .50196 Mdot
.45883 .50588 Mdot
.46275 .51372 Mdot
.44314 .50196 Mdot
.4353 .49804 Mdot
.43138 .50196 Mdot
.41569 .4902 Mdot
.40393 .48628 Mdot
.38824 .4353 Mdot
.4353 .4902 Mdot
.45491 .50196 Mdot
.45491 .50588 Mdot
.45098 .50588 Mdot
.45098 .50196 Mdot
.46275 .51372 Mdot
.47843 .53333 Mdot
.48628 .54117 Mdot
.47843 .53725 Mdot
.47451 .53725 Mdot
.47059 .54117 Mdot
.46275 .53725 Mdot
.47451 .54117 Mdot
.48235 .54509 Mdot
.49804 .55294 Mdot
.5098 .55686 Mdot
.5098 .55294 Mdot
.50196 .54902 Mdot
.50588 .55686 Mdot
.50196 .54902 Mdot
.51765 .5647 Mdot
.52157 .57254 Mdot
.51372 .56862 Mdot
.50588 .5647 Mdot
.50588 .5647 Mdot
.50196 .56862 Mdot
.5098 .57254 Mdot
.51372 .57254 Mdot
.51765 .56862 Mdot
.52157 .5647 Mdot
.53333 .57646 Mdot
.54902 .59607 Mdot
.55294 .59607 Mdot
.55686 .59607 Mdot
.55686 .58823 Mdot
.5647 .59607 Mdot
.56078 .59607 Mdot
.5647 .60783 Mdot
.55686 .59999 Mdot
.55686 .60391 Mdot
.55294 .59215 Mdot
.5647 .59607 Mdot
.5647 .59215 Mdot
.57254 .59607 Mdot
.5647 .59607 Mdot
.55294 .59215 Mdot
.56078 .59999 Mdot
.56862 .60783 Mdot
.57254 .59999 Mdot
.58039 .61176 Mdot
.58823 .60783 Mdot
.57646 .59999 Mdot
.58431 .61176 Mdot
.58823 .61568 Mdot
.59607 .6196 Mdot
.59607 .61176 Mdot
.59215 .61176 Mdot
.59999 .6196 Mdot
.59607 .6196 Mdot
.59999 .62744 Mdot
.59607 .62352 Mdot
.60783 .63136 Mdot
.61568 .6392 Mdot
.61176 .63136 Mdot
.60783 .6392 Mdot
.60783 .64313 Mdot
.59215 .62352 Mdot
.59607 .62352 Mdot
.60391 .63528 Mdot
.60783 .63528 Mdot
.60783 .6392 Mdot
.59607 .63528 Mdot
.59999 .64313 Mdot
.60391 .64313 Mdot
.60391 .6392 Mdot
.61568 .64705 Mdot
.62352 .65097 Mdot
.62744 .65489 Mdot
.62744 .65097 Mdot
.62352 .64705 Mdot
.62352 .64313 Mdot
.62352 .63528 Mdot
.63136 .6392 Mdot
.62744 .64313 Mdot
.62744 .64705 Mdot
.62744 .65097 Mdot
.61568 .63528 Mdot
.61176 .62352 Mdot
.61568 .63528 Mdot
.61176 .63528 Mdot
.59999 .62744 Mdot
.60783 .6392 Mdot
.61176 .64313 Mdot
.61568 .64313 Mdot
.6196 .64705 Mdot
.61176 .63136 Mdot
.60391 .62744 Mdot
.61176 .6392 Mdot
.61568 .64705 Mdot
.60783 .63136 Mdot
.6196 .6392 Mdot
.62352 .64313 Mdot
.62352 .6392 Mdot
.61176 .62352 Mdot
.60783 .62352 Mdot
.60391 .6196 Mdot
.61568 .62744 Mdot
.62352 .64313 Mdot
.61176 .63528 Mdot
.59607 .6196 Mdot
.59215 .61568 Mdot
.59215 .62352 Mdot
.59607 .63136 Mdot
.59215 .6196 Mdot
.58431 .61176 Mdot
.58823 .6196 Mdot
.58823 .6196 Mdot
.57646 .61568 Mdot
.57646 .61568 Mdot
.57646 .61176 Mdot
.58039 .61176 Mdot
.56862 .59999 Mdot
.5647 .59999 Mdot
.55294 .59215 Mdot
.55294 .58431 Mdot
.54902 .58823 Mdot
.55686 .59607 Mdot
.55686 .58823 Mdot
.55294 .58431 Mdot
.55686 .58431 Mdot
.54902 .57254 Mdot
.54117 .56862 Mdot
.54509 .58039 Mdot
.53333 .56862 Mdot
.54117 .57254 Mdot
.54117 .56862 Mdot
.53333 .5647 Mdot
.52157 .56862 Mdot
.5098 .5647 Mdot
.50196 .56078 Mdot
.50196 .55686 Mdot
.50588 .56078 Mdot
.50588 .54902 Mdot
.5098 .54509 Mdot
.50196 .53725 Mdot
.49412 .53333 Mdot
.48628 .53333 Mdot
.4902 .53725 Mdot
.48235 .52549 Mdot
.47451 .5098 Mdot
.47843 .51372 Mdot
.46667 .50588 Mdot
.45491 .49804 Mdot
.45098 .50588 Mdot
.43138 .49412 Mdot
.43922 .50196 Mdot
.41569 .48628 Mdot
.41961 .49412 Mdot
.40785 .48628 Mdot
.38432 .42746 Mdot
.43138 .48235 Mdot
.44706 .49412 Mdot
.45098 .50196 Mdot
.44314 .4902 Mdot
.45098 .50196 Mdot
.46275 .51372 Mdot
.45883 .5098 Mdot
.47059 .52157 Mdot
.47843 .53333 Mdot
.47451 .53333 Mdot
.47451 .54117 Mdot
.47059 .54117 Mdot
.47451 .54509 Mdot
.47451 .54117 Mdot
.48235 .54509 Mdot
.4902 .54509 Mdot
.49804 .54902 Mdot
.50196 .54902 Mdot
.50196 .54902 Mdot
.50196 .54902 Mdot
.50196 .55294 Mdot
.51765 .5647 Mdot
.51765 .5647 Mdot
.52157 .5647 Mdot
.51372 .57254 Mdot
.51372 .57254 Mdot
.51765 .57646 Mdot
.52549 .58039 Mdot
.52157 .58039 Mdot
.52549 .57646 Mdot
.52549 .57254 Mdot
.53333 .57254 Mdot
.54509 .58431 Mdot
.54117 .57646 Mdot
.55294 .58823 Mdot
.5647 .58823 Mdot
.57254 .59215 Mdot
.5647 .58823 Mdot
.56862 .59215 Mdot
.5647 .58823 Mdot
.56078 .58431 Mdot
.57254 .59607 Mdot
.56862 .59607 Mdot
.56862 .58431 Mdot
.57254 .59607 Mdot
.57646 .59999 Mdot
.57254 .60391 Mdot
.56078 .58823 Mdot
.57646 .59607 Mdot
.57646 .59607 Mdot
.57646 .59999 Mdot
.58039 .60391 Mdot
.57254 .59999 Mdot
.57646 .60391 Mdot
.58039 .60783 Mdot
.58039 .60783 Mdot
.58039 .60391 Mdot
.58039 .59999 Mdot
.58823 .61568 Mdot
.59607 .62744 Mdot
.59607 .62352 Mdot
.59999 .62352 Mdot
.59999 .6196 Mdot
.59999 .61568 Mdot
.58823 .60391 Mdot
.59215 .6196 Mdot
.59215 .62352 Mdot
.59607 .62352 Mdot
.59999 .62352 Mdot
.60783 .62352 Mdot
.60391 .6196 Mdot
.59999 .62352 Mdot
.59999 .63136 Mdot
.59215 .6196 Mdot
.59999 .63136 Mdot
.59607 .62352 Mdot
.59999 .62744 Mdot
.59999 .62744 Mdot
.59607 .62744 Mdot
.59607 .63136 Mdot
.60783 .6392 Mdot
.6196 .64313 Mdot
.62744 .64705 Mdot
.62352 .6392 Mdot
.62352 .6392 Mdot
.62744 .64705 Mdot
.6196 .6392 Mdot
.61176 .63136 Mdot
.60391 .62744 Mdot
.60391 .63136 Mdot
.59215 .6196 Mdot
.58823 .62352 Mdot
.59215 .62744 Mdot
.59999 .6196 Mdot
.61568 .63528 Mdot
.6196 .6392 Mdot
.59999 .62352 Mdot
.60391 .63136 Mdot
.60391 .62744 Mdot
.59607 .62352 Mdot
.60391 .62744 Mdot
.61176 .63136 Mdot
.6196 .63528 Mdot
.6196 .63528 Mdot
.61176 .62352 Mdot
.60391 .6196 Mdot
.59999 .61568 Mdot
.61176 .62352 Mdot
.60391 .6196 Mdot
.60783 .62352 Mdot
.59607 .62352 Mdot
.58823 .61568 Mdot
.58823 .61176 Mdot
.58039 .60783 Mdot
.58431 .61176 Mdot
.57646 .60391 Mdot
.58039 .60783 Mdot
.58431 .61176 Mdot
.58431 .6196 Mdot
.57254 .60783 Mdot
.56078 .58823 Mdot
.5647 .59607 Mdot
.5647 .59999 Mdot
.54509 .58431 Mdot
.54117 .57646 Mdot
.54902 .58823 Mdot
.56078 .59215 Mdot
.5647 .58823 Mdot
.55686 .58431 Mdot
.55686 .58431 Mdot
.54902 .57254 Mdot
.54902 .57646 Mdot
.54509 .57254 Mdot
.53333 .5647 Mdot
.53333 .56078 Mdot
.53725 .56078 Mdot
.54117 .57254 Mdot
.52157 .55686 Mdot
.50588 .54902 Mdot
.49412 .54509 Mdot
.4902 .54117 Mdot
.50588 .55294 Mdot
.50196 .53725 Mdot
.5098 .54509 Mdot
.51372 .54117 Mdot
.50196 .52941 Mdot
.48628 .51372 Mdot
.48235 .5098 Mdot
.48235 .51372 Mdot
.47843 .50588 Mdot
.47451 .49412 Mdot
.47059 .4902 Mdot
.46275 .49412 Mdot
.45098 .49804 Mdot
.43138 .49412 Mdot
.42354 .4902 Mdot
.42354 .49412 Mdot
.42354 .50196 Mdot
.41569 .4902 Mdot
.38432 .42746 Mdot
.42746 .48235 Mdot
.44314 .50196 Mdot
.45098 .50196 Mdot
.44706 .49412 Mdot
.45098 .50196 Mdot
.45883 .51372 Mdot
.45098 .50196 Mdot
.46667 .51765 Mdot
.47059 .52549 Mdot
.46275 .51372 Mdot
.46667 .52549 Mdot
.47843 .54117 Mdot
.48628 .54902 Mdot
.48628 .54902 Mdot
.48628 .54509 Mdot
.4902 .54902 Mdot
.49804 .56078 Mdot
.50196 .55686 Mdot
.49804 .54902 Mdot
.5098 .55686 Mdot
.51372 .55294 Mdot
.51372 .55686 Mdot
.51372 .55686 Mdot
.5098 .55294 Mdot
.5098 .55686 Mdot
.50588 .55686 Mdot
.5098 .5647 Mdot
.51372 .56862 Mdot
.52157 .57646 Mdot
.52157 .58039 Mdot
.53333 .58431 Mdot
.53333 .58431 Mdot
.54117 .58431 Mdot
.54509 .58431 Mdot
.56078 .59215 Mdot
.56078 .58823 Mdot
.56078 .58431 Mdot
.55686 .58431 Mdot
.56078 .58823 Mdot
.56862 .59607 Mdot
.56078 .58823 Mdot
.55686 .58431 Mdot
.5647 .59607 Mdot
.5647 .58823 Mdot
.56862 .60391 Mdot
.57254 .60391 Mdot
.57254 .59999 Mdot
.57646 .59999 Mdot
.57646 .59999 Mdot
.58039 .59999 Mdot
.58431 .60391 Mdot
.58039 .60391 Mdot
.58039 .60783 Mdot
.58431 .61176 Mdot
.58039 .60783 Mdot
.57254 .60391 Mdot
.57646 .60391 Mdot
.57254 .59999 Mdot
.58039 .61176 Mdot
.59215 .6196 Mdot
.59215 .61568 Mdot
.58823 .60783 Mdot
.60391 .6196 Mdot
.59999 .61568 Mdot
.58431 .60783 Mdot
.59215 .6196 Mdot
.59607 .62352 Mdot
.59607 .62352 Mdot
.60391 .62352 Mdot
.61176 .62744 Mdot
.60391 .62352 Mdot
.60391 .63136 Mdot
.59999 .63136 Mdot
.59999 .62744 Mdot
.59607 .6196 Mdot
.58823 .6196 Mdot
.58823 .6196 Mdot
.58431 .61568 Mdot
.59215 .63136 Mdot
.58823 .62744 Mdot
.60783 .64313 Mdot
.60391 .63136 Mdot
.61568 .63528 Mdot
.61568 .63528 Mdot
.6196 .6392 Mdot
.6196 .63528 Mdot
.61568 .63528 Mdot
.61568 .64313 Mdot
.61176 .6392 Mdot
.60783 .63136 Mdot
.60783 .63136 Mdot
.60783 .6392 Mdot
.59999 .62744 Mdot
.59607 .61568 Mdot
.59607 .61568 Mdot
.59607 .62352 Mdot
.59607 .62352 Mdot
.59215 .62352 Mdot
.59999 .62744 Mdot
.59215 .61568 Mdot
.60391 .62744 Mdot
.60783 .62744 Mdot
.60783 .63136 Mdot
.60783 .63136 Mdot
.60783 .62352 Mdot
.61176 .62744 Mdot
.61568 .6196 Mdot
.61176 .61176 Mdot
.60783 .60783 Mdot
.60391 .61176 Mdot
.59999 .6196 Mdot
.59607 .6196 Mdot
.59215 .61568 Mdot
.58431 .61176 Mdot
.58431 .61176 Mdot
.58431 .61176 Mdot
.57646 .60391 Mdot
.57646 .60391 Mdot
.57254 .60391 Mdot
.57254 .60391 Mdot
.57254 .60783 Mdot
.55686 .59215 Mdot
.55294 .58823 Mdot
.55294 .59215 Mdot
.54509 .58039 Mdot
.55686 .59215 Mdot
.55686 .58039 Mdot
.55686 .57646 Mdot
.5647 .58431 Mdot
.54117 .5647 Mdot
.54117 .56862 Mdot
.54117 .58039 Mdot
.54902 .58431 Mdot
.52941 .56078 Mdot
.52549 .55294 Mdot
.52549 .54509 Mdot
.53333 .55686 Mdot
.52549 .55686 Mdot
.51372 .54509 Mdot
.51372 .54117 Mdot
.5098 .53725 Mdot
.50196 .53333 Mdot
.50196 .52941 Mdot
.5098 .52549 Mdot
.50588 .52157 Mdot
.49804 .51765 Mdot
.48628 .51372 Mdot
.48628 .5098 Mdot
.48235 .5098 Mdot
.47059 .49412 Mdot
.47059 .49804 Mdot
.45883 .49412 Mdot
.45883 .49804 Mdot
.45098 .49804 Mdot
.42354 .47843 Mdot
.42354 .48235 Mdot
.41569 .48235 Mdot
.40393 .47451 Mdot
.40001 .47451 Mdot
.39609 .4353 Mdot
.4353 .4902 Mdot
.44314 .50196 Mdot
.45491 .5098 Mdot
.45491 .50588 Mdot
.45098 .49804 Mdot
.45491 .50588 Mdot
.45491 .50196 Mdot
.46275 .51765 Mdot
.46275 .51372 Mdot
.47059 .52157 Mdot
.4902 .54509 Mdot
.48235 .54117 Mdot
.4902 .54902 Mdot
.48235 .54117 Mdot
.48628 .54509 Mdot
.4902 .54902 Mdot
.5098 .56862 Mdot
.50196 .55294 Mdot
.50196 .54902 Mdot
.50588 .55294 Mdot
.51765 .56078 Mdot
.5098 .55686 Mdot
.50588 .55686 Mdot
.50588 .55686 Mdot
.51372 .56078 Mdot
.51372 .56078 Mdot
.51372 .5647 Mdot
.52157 .57646 Mdot
.51765 .56862 Mdot
.52549 .57254 Mdot
.52941 .57254 Mdot
.53333 .57646 Mdot
.54509 .58431 Mdot
.55294 .59607 Mdot
.54509 .58431 Mdot
.55294 .59607 Mdot
.55294 .58431 Mdot
.54902 .58039 Mdot
.54902 .57646 Mdot
.54902 .57646 Mdot
.56078 .59215 Mdot
.56078 .58431 Mdot
.56078 .58823 Mdot
.55294 .58039 Mdot
.55686 .58823 Mdot
.5647 .58431 Mdot
.5647 .58431 Mdot
.56078 .58431 Mdot
.56862 .59215 Mdot
.57254 .59607 Mdot
.5647 .58823 Mdot
.56862 .59215 Mdot
.57254 .59607 Mdot
.58431 .60783 Mdot
.57646 .60783 Mdot
.57646 .60783 Mdot
.57646 .60391 Mdot
.58039 .61176 Mdot
.58039 .61176 Mdot
.59215 .6196 Mdot
.59607 .62352 Mdot
.59215 .6196 Mdot
.58823 .61568 Mdot
.58823 .61568 Mdot
.58431 .61176 Mdot
.58431 .61176 Mdot
.58431 .61176 Mdot
.59607 .6196 Mdot
.59215 .61568 Mdot
.58823 .60783 Mdot
.59999 .62352 Mdot
.59607 .62352 Mdot
.59215 .6196 Mdot
.58431 .61176 Mdot
.58431 .61176 Mdot
.58431 .62352 Mdot
.58039 .61176 Mdot
.59607 .62352 Mdot
.60391 .63528 Mdot
.59999 .63528 Mdot
.59999 .62744 Mdot
.59999 .62352 Mdot
.61176 .63136 Mdot
.61176 .62744 Mdot
.60783 .62352 Mdot
.61176 .62352 Mdot
.6196 .63528 Mdot
.6196 .64313 Mdot
.6196 .64313 Mdot
.62744 .64705 Mdot
.61568 .63136 Mdot
.61568 .63136 Mdot
.60783 .62352 Mdot
.60391 .62352 Mdot
.60391 .62744 Mdot
.59999 .62352 Mdot
.59999 .62744 Mdot
.59999 .62744 Mdot
.60391 .62744 Mdot
.59999 .62352 Mdot
.59999 .6196 Mdot
.61176 .62352 Mdot
.60391 .61568 Mdot
.60391 .61568 Mdot
.59999 .60783 Mdot
.60391 .61568 Mdot
.61176 .6196 Mdot
.61568 .61568 Mdot
.60783 .61176 Mdot
.60391 .61568 Mdot
.58823 .60783 Mdot
.58431 .61176 Mdot
.58823 .61568 Mdot
.58431 .61176 Mdot
.57254 .60391 Mdot
.57254 .60783 Mdot
.57254 .60391 Mdot
.56078 .59215 Mdot
.56862 .59999 Mdot
.55294 .58431 Mdot
.55294 .58823 Mdot
.55686 .59215 Mdot
.55686 .59607 Mdot
.55686 .59215 Mdot
.55686 .58823 Mdot
.55294 .57646 Mdot
.55294 .57646 Mdot
.54902 .56862 Mdot
.54117 .5647 Mdot
.54902 .57254 Mdot
.52549 .56078 Mdot
.53333 .57254 Mdot
.52549 .56078 Mdot
.53333 .5647 Mdot
.52941 .55686 Mdot
.51372 .54902 Mdot
.51372 .54117 Mdot
.52549 .55686 Mdot
.51372 .54509 Mdot
.5098 .54117 Mdot
.50588 .53333 Mdot
.49804 .52549 Mdot
.50196 .52157 Mdot
.50196 .51765 Mdot
.50196 .51765 Mdot
.48235 .50588 Mdot
.47843 .50588 Mdot
.47451 .50588 Mdot
.46275 .49804 Mdot
.45883 .49412 Mdot
.44706 .48628 Mdot
.45098 .4902 Mdot
.45491 .49804 Mdot
.44706 .49412 Mdot
.4353 .48235 Mdot
.42746 .47451 Mdot
.41569 .47059 Mdot
.40785 .47059 Mdot
.39217 .46275 Mdot
.38824 .42746 Mdot
.41961 .47059 Mdot
.43138 .4902 Mdot
.43922 .49804 Mdot
.45098 .50196 Mdot
.45098 .49804 Mdot
.45098 .49804 Mdot
.45098 .50196 Mdot
.45883 .5098 Mdot
.45883 .5098 Mdot
.47059 .52549 Mdot
.48628 .53333 Mdot
.4902 .54509 Mdot
.48235 .54509 Mdot
.48628 .54509 Mdot
.49804 .55294 Mdot
.49804 .54902 Mdot
.5098 .56078 Mdot
.50588 .56078 Mdot
.49412 .55294 Mdot
.49804 .54509 Mdot
.49412 .54117 Mdot
.51765 .5647 Mdot
.51372 .56078 Mdot
.52157 .56862 Mdot
.51765 .5647 Mdot
.51765 .5647 Mdot
.52157 .5647 Mdot
.52157 .57254 Mdot
.52157 .56078 Mdot
.52549 .56862 Mdot
.53725 .58431 Mdot
.52941 .57254 Mdot
.53333 .57646 Mdot
.52941 .57646 Mdot
.53333 .58823 Mdot
.54117 .59215 Mdot
.54117 .58039 Mdot
.54902 .58431 Mdot
.54117 .57254 Mdot
.54509 .58039 Mdot
.54509 .57646 Mdot
.55294 .58431 Mdot
.54902 .57646 Mdot
.56078 .58823 Mdot
.5647 .58431 Mdot
.5647 .58823 Mdot
.5647 .58823 Mdot
.56862 .59215 Mdot
.57646 .59607 Mdot
.58039 .60391 Mdot
.58431 .59999 Mdot
.57646 .59999 Mdot
.58039 .60391 Mdot
.58039 .59999 Mdot
.57646 .59607 Mdot
.57646 .59607 Mdot
.58039 .60391 Mdot
.57646 .60391 Mdot
.58431 .61568 Mdot
.59607 .62352 Mdot
.58823 .61176 Mdot
.58431 .60783 Mdot
.57646 .59999 Mdot
.59215 .61568 Mdot
.58823 .61176 Mdot
.59215 .6196 Mdot
.59607 .6196 Mdot
.59607 .61568 Mdot
.59607 .61568 Mdot
.60783 .62744 Mdot
.60391 .61568 Mdot
.59607 .61176 Mdot
.59999 .61568 Mdot
.59215 .6196 Mdot
.58823 .61568 Mdot
.59215 .6196 Mdot
.58431 .61176 Mdot
.58823 .61568 Mdot
.59607 .62352 Mdot
.59999 .62744 Mdot
.60391 .62744 Mdot
.59999 .62744 Mdot
.60391 .62352 Mdot
.60783 .62352 Mdot
.61176 .62352 Mdot
.60783 .62352 Mdot
.59999 .61568 Mdot
.60391 .6196 Mdot
.60783 .62744 Mdot
.61176 .62352 Mdot
.60783 .62352 Mdot
.61176 .6196 Mdot
.6196 .63136 Mdot
.61568 .63136 Mdot
.61176 .62352 Mdot
.61176 .62352 Mdot
.59999 .61568 Mdot
.60391 .62352 Mdot
.61176 .62352 Mdot
.59999 .61176 Mdot
.60391 .6196 Mdot
.60391 .61176 Mdot
.60391 .61568 Mdot
.60783 .6196 Mdot
.59999 .61176 Mdot
.59607 .60783 Mdot
.59999 .61176 Mdot
.60783 .61568 Mdot
.59215 .60391 Mdot
.58823 .60391 Mdot
.58039 .60391 Mdot
.58431 .61176 Mdot
.58039 .60391 Mdot
.58039 .60783 Mdot
.57254 .59999 Mdot
.5647 .59999 Mdot
.5647 .59999 Mdot
.57254 .60391 Mdot
.56862 .59607 Mdot
.56078 .58431 Mdot
.55686 .58039 Mdot
.56078 .58823 Mdot
.54902 .57254 Mdot
.56078 .58431 Mdot
.5647 .58431 Mdot
.55294 .57254 Mdot
.54117 .56078 Mdot
.54509 .56862 Mdot
.53725 .56078 Mdot
.52941 .55686 Mdot
.52549 .55686 Mdot
.52157 .55686 Mdot
.51372 .54509 Mdot
.53333 .55686 Mdot
.52549 .54902 Mdot
.52157 .54509 Mdot
.52157 .54117 Mdot
.51372 .53725 Mdot
.50588 .52941 Mdot
.50196 .52941 Mdot
.49412 .52157 Mdot
.49804 .51372 Mdot
.48628 .50196 Mdot
.4902 .50588 Mdot
.48235 .49804 Mdot
.48628 .5098 Mdot
.47451 .49804 Mdot
.46667 .49412 Mdot
.45883 .48628 Mdot
.45098 .48235 Mdot
.43922 .47451 Mdot
.43922 .47843 Mdot
.44314 .47451 Mdot
.44706 .48235 Mdot
.43922 .47451 Mdot
.42746 .46275 Mdot
.41569 .46275 Mdot
.40393 .46275 Mdot
.38432 .45098 Mdot
.39609 .44706 Mdot
.42746 .47843 Mdot
.43922 .49412 Mdot
.44314 .49412 Mdot
.45098 .49804 Mdot
.44706 .4902 Mdot
.44706 .4902 Mdot
.45098 .50196 Mdot
.46667 .51372 Mdot
.47059 .51765 Mdot
.47059 .51765 Mdot
.47451 .52157 Mdot
.47451 .52941 Mdot
.47843 .53725 Mdot
.48235 .54509 Mdot
.48235 .54902 Mdot
.49804 .56078 Mdot
.49804 .55294 Mdot
.49412 .55294 Mdot
.49804 .55294 Mdot
.50588 .56078 Mdot
.49804 .55686 Mdot
.5098 .5647 Mdot
.5098 .55686 Mdot
.51372 .5647 Mdot
.51372 .56078 Mdot
.51765 .55686 Mdot
.51765 .55686 Mdot
.52157 .5647 Mdot
.52157 .5647 Mdot
.51372 .56078 Mdot
.52549 .56862 Mdot
.52941 .57254 Mdot
.52549 .5647 Mdot
.51765 .56078 Mdot
.52941 .58039 Mdot
.53333 .58823 Mdot
.54117 .58823 Mdot
.55294 .58823 Mdot
.55686 .59215 Mdot
.55294 .58823 Mdot
.55686 .59999 Mdot
.54509 .58039 Mdot
.55294 .59215 Mdot
.54902 .58823 Mdot
.56862 .59607 Mdot
.5647 .58039 Mdot
.57254 .59607 Mdot
.56862 .59999 Mdot
.58039 .61176 Mdot
.58823 .61176 Mdot
.58431 .60783 Mdot
.57646 .59215 Mdot
.58431 .59999 Mdot
.57646 .59607 Mdot
.57646 .59999 Mdot
.57254 .59999 Mdot
.57646 .60391 Mdot
.58039 .61176 Mdot
.58039 .60391 Mdot
.58823 .60783 Mdot
.58431 .60783 Mdot
.57254 .59215 Mdot
.57646 .59999 Mdot
.57646 .60391 Mdot
.58431 .60783 Mdot
.58823 .61176 Mdot
.58431 .60783 Mdot
.58823 .60783 Mdot
.59607 .61176 Mdot
.60391 .6196 Mdot
.59607 .61568 Mdot
.60391 .6196 Mdot
.59215 .61176 Mdot
.58823 .61568 Mdot
.58039 .60391 Mdot
.57646 .61176 Mdot
.57646 .61568 Mdot
.58823 .6196 Mdot
.58823 .6196 Mdot
.59607 .62352 Mdot
.59215 .6196 Mdot
.59215 .6196 Mdot
.60391 .62352 Mdot
.59215 .61176 Mdot
.59215 .61176 Mdot
.60391 .61568 Mdot
.60783 .6196 Mdot
.59999 .61568 Mdot
.59607 .61568 Mdot
.59215 .61176 Mdot
.59999 .6196 Mdot
.60391 .62352 Mdot
.61568 .62352 Mdot
.60783 .61568 Mdot
.61176 .62352 Mdot
.59999 .61176 Mdot
.59607 .61568 Mdot
.60783 .62744 Mdot
.60783 .62744 Mdot
.59999 .61176 Mdot
.59999 .61568 Mdot
.59999 .61176 Mdot
.59215 .60391 Mdot
.59607 .61176 Mdot
.59607 .61568 Mdot
.59215 .61176 Mdot
.59607 .61568 Mdot
.59607 .61176 Mdot
.58431 .60783 Mdot
.58039 .60391 Mdot
.57254 .59607 Mdot
.57646 .58823 Mdot
.57646 .58823 Mdot
.58039 .59607 Mdot
.56078 .58431 Mdot
.54902 .58431 Mdot
.54902 .58431 Mdot
.54509 .58039 Mdot
.55686 .58823 Mdot
.55686 .58039 Mdot
.5647 .58431 Mdot
.56078 .58039 Mdot
.55294 .57646 Mdot
.54509 .57254 Mdot
.52941 .56078 Mdot
.54902 .57646 Mdot
.54902 .5647 Mdot
.54117 .55686 Mdot
.54509 .55686 Mdot
.54509 .56862 Mdot
.53333 .55294 Mdot
.52941 .55686 Mdot
.51765 .54509 Mdot
.51372 .54117 Mdot
.51765 .54509 Mdot
.51765 .53333 Mdot
.52157 .53333 Mdot
.51372 .52941 Mdot
.5098 .53333 Mdot
.48628 .51765 Mdot
.47451 .50588 Mdot
.4902 .51765 Mdot
.4902 .5098 Mdot
.48628 .50588 Mdot
.47843 .49804 Mdot
.47451 .50196 Mdot
.46667 .50588 Mdot
.44706 .48628 Mdot
.44706 .4902 Mdot
.45098 .4902 Mdot
.44314 .48235 Mdot
.43922 .48235 Mdot
.4353 .47059 Mdot
.42746 .46275 Mdot
.41569 .45491 Mdot
.40785 .45491 Mdot
.40393 .45491 Mdot
.39609 .45491 Mdot
.38432 .44314 Mdot
.38824 .4353 Mdot
.41961 .46667 Mdot
.44314 .49412 Mdot
.45491 .50196 Mdot
.45491 .4902 Mdot
.45883 .49412 Mdot
.45491 .48628 Mdot
.46275 .4902 Mdot
.47451 .50588 Mdot
.48235 .51372 Mdot
.47843 .5098 Mdot
.48628 .52549 Mdot
.47843 .52549 Mdot
.47843 .53333 Mdot
.48628 .54509 Mdot
.4902 .55294 Mdot
.48235 .54117 Mdot
.49412 .55294 Mdot
.4902 .55686 Mdot
.49412 .55686 Mdot
.50196 .5647 Mdot
.50588 .56078 Mdot
.49804 .55686 Mdot
.49412 .56078 Mdot
.51765 .57646 Mdot
.52157 .5647 Mdot
.53725 .57254 Mdot
.53333 .56862 Mdot
.52549 .56078 Mdot
.52941 .57646 Mdot
.52157 .56862 Mdot
.52941 .56862 Mdot
.53725 .57254 Mdot
.53333 .56862 Mdot
.52941 .5647 Mdot
.53725 .57254 Mdot
.53725 .57254 Mdot
.54509 .58039 Mdot
.56078 .59215 Mdot
.55686 .58823 Mdot
.55686 .59215 Mdot
.54902 .58431 Mdot
.54902 .58039 Mdot
.55294 .58823 Mdot
.55294 .58823 Mdot
.54902 .58823 Mdot
.55686 .58823 Mdot
.55686 .59607 Mdot
.55294 .59607 Mdot
.56862 .60391 Mdot
.57646 .60783 Mdot
.56862 .59607 Mdot
.57254 .59999 Mdot
.57646 .59607 Mdot
.57646 .59607 Mdot
.57646 .59999 Mdot
.57646 .60391 Mdot
.57646 .59607 Mdot
.58431 .60391 Mdot
.57646 .59999 Mdot
.58039 .59999 Mdot
.56862 .58823 Mdot
.5647 .58823 Mdot
.5647 .58823 Mdot
.5647 .58431 Mdot
.56862 .59607 Mdot
.57646 .60391 Mdot
.57254 .60391 Mdot
.58039 .60391 Mdot
.58039 .60391 Mdot
.58431 .61176 Mdot
.58431 .61176 Mdot
.58823 .61176 Mdot
.59607 .6196 Mdot
.58431 .60783 Mdot
.58039 .60391 Mdot
.58431 .6196 Mdot
.58431 .62352 Mdot
.58823 .62352 Mdot
.58823 .6196 Mdot
.58823 .6196 Mdot
.58039 .61176 Mdot
.59607 .62352 Mdot
.59215 .61568 Mdot
.59607 .61568 Mdot
.59215 .60783 Mdot
.59999 .61176 Mdot
.60783 .6196 Mdot
.59607 .61176 Mdot
.59215 .61568 Mdot
.58823 .61568 Mdot
.58823 .61176 Mdot
.59607 .61568 Mdot
.59999 .61568 Mdot
.59607 .60783 Mdot
.59999 .61176 Mdot
.59215 .60783 Mdot
.58431 .60391 Mdot
.58823 .61176 Mdot
.58039 .60391 Mdot
.58823 .61176 Mdot
.59215 .61176 Mdot
.58823 .60783 Mdot
.58039 .59999 Mdot
.58039 .59999 Mdot
.57646 .59607 Mdot
.58039 .59607 Mdot
.58039 .60391 Mdot
.58039 .59607 Mdot
.57646 .59215 Mdot
.56862 .58823 Mdot
.57254 .59215 Mdot
.57646 .59607 Mdot
.56862 .58431 Mdot
.56862 .58431 Mdot
.5647 .58431 Mdot
.55686 .58431 Mdot
.54509 .58039 Mdot
.54509 .58431 Mdot
.54902 .58431 Mdot
.54117 .57254 Mdot
.54509 .57646 Mdot
.54902 .57254 Mdot
.54509 .56862 Mdot
.54902 .58039 Mdot
.53725 .56862 Mdot
.53725 .57254 Mdot
.54117 .56078 Mdot
.54117 .55294 Mdot
.54117 .55686 Mdot
.53333 .54902 Mdot
.52941 .54902 Mdot
.51372 .54509 Mdot
.49804 .53725 Mdot
.50196 .54509 Mdot
.49804 .52941 Mdot
.50588 .53725 Mdot
.50588 .52941 Mdot
.49804 .52157 Mdot
.49804 .53333 Mdot
.48628 .52157 Mdot
.47451 .51765 Mdot
.47451 .51372 Mdot
.47059 .50196 Mdot
.47451 .49804 Mdot
.47451 .49412 Mdot
.46667 .48628 Mdot
.45883 .4902 Mdot
.44706 .48235 Mdot
.43922 .47451 Mdot
.43138 .46275 Mdot
.43138 .46667 Mdot
.42746 .45491 Mdot
.41569 .44706 Mdot
.41569 .44706 Mdot
.41177 .44314 Mdot
.38824 .4353 Mdot
.39609 .44706 Mdot
.38432 .44314 Mdot
.37256 .4353 Mdot
.40001 .4353 Mdot
.41177 .45098 Mdot
.4353 .48235 Mdot
.44706 .4902 Mdot
.45883 .49804 Mdot
.46667 .49412 Mdot
.46275 .47843 Mdot
.46275 .47843 Mdot
.47843 .49804 Mdot
.47059 .50196 Mdot
.47843 .51372 Mdot
.4902 .52941 Mdot
.48628 .53333 Mdot
.48628 .53725 Mdot
.49412 .54117 Mdot
.49804 .54902 Mdot
.49804 .55294 Mdot
.50196 .55686 Mdot
.50196 .55686 Mdot
.49804 .55294 Mdot
.50588 .55686 Mdot
.4902 .53725 Mdot
.49804 .54902 Mdot
.49412 .54902 Mdot
.5098 .5647 Mdot
.5098 .56078 Mdot
.52549 .5647 Mdot
.51765 .55294 Mdot
.52941 .56078 Mdot
.53333 .56078 Mdot
.53725 .56862 Mdot
.54117 .57254 Mdot
.54117 .57646 Mdot
.53725 .56862 Mdot
.54117 .56862 Mdot
.54117 .56078 Mdot
.55686 .57254 Mdot
.54509 .56078 Mdot
.54902 .56862 Mdot
.56078 .58431 Mdot
.54902 .57646 Mdot
.53333 .5647 Mdot
.55686 .58039 Mdot
.55686 .58431 Mdot
.55294 .58039 Mdot
.53725 .56862 Mdot
.53333 .57646 Mdot
.52941 .58039 Mdot
.53333 .58431 Mdot
.55294 .59999 Mdot
.56862 .60391 Mdot
.56078 .58823 Mdot
.56862 .59215 Mdot
.56862 .59215 Mdot
.56862 .59607 Mdot
.57254 .59999 Mdot
.56862 .59215 Mdot
.57646 .60391 Mdot
.57646 .60391 Mdot
.58431 .59607 Mdot
.57254 .58823 Mdot
.57254 .59607 Mdot
.58039 .60783 Mdot
.57646 .59999 Mdot
.57646 .59999 Mdot
.57646 .59999 Mdot
.56078 .58431 Mdot
.5647 .59215 Mdot
.56862 .59999 Mdot
.56862 .59215 Mdot
.56862 .59607 Mdot
.57254 .59215 Mdot
.57254 .58823 Mdot
.57646 .59607 Mdot
.57646 .59999 Mdot
.57646 .60391 Mdot
.58039 .60783 Mdot
.57254 .60391 Mdot
.58039 .61176 Mdot
.58039 .60783 Mdot
.58431 .60391 Mdot
.58039 .59999 Mdot
.58431 .60391 Mdot
.59215 .60783 Mdot
.58823 .59999 Mdot
.59215 .60391 Mdot
.59215 .59999 Mdot
.59215 .60391 Mdot
.58823 .60391 Mdot
.58039 .60391 Mdot
.58823 .61176 Mdot
.58431 .60783 Mdot
.58431 .59999 Mdot
.59607 .60783 Mdot
.59607 .60783 Mdot
.59607 .60391 Mdot
.59215 .59999 Mdot
.58431 .59607 Mdot
.58823 .60391 Mdot
.58431 .59999 Mdot
.58823 .60391 Mdot
.58431 .60391 Mdot
.58823 .59999 Mdot
.58039 .58431 Mdot
.58039 .58823 Mdot
.58039 .58431 Mdot
.58823 .59215 Mdot
.58431 .59215 Mdot
.57646 .59215 Mdot
.57646 .59215 Mdot
.58039 .58431 Mdot
.58039 .59215 Mdot
.57254 .58431 Mdot
.57254 .58823 Mdot
.56862 .58431 Mdot
.55686 .58039 Mdot
.55294 .57646 Mdot
.55686 .58431 Mdot
.55294 .57646 Mdot
.53725 .56078 Mdot
.54509 .56862 Mdot
.53725 .56078 Mdot
.54117 .56862 Mdot
.54117 .5647 Mdot
.54117 .56862 Mdot
.54902 .57646 Mdot
.54117 .56862 Mdot
.53725 .56078 Mdot
.54509 .55294 Mdot
.54509 .56078 Mdot
.53333 .54509 Mdot
.52549 .53333 Mdot
.52549 .54117 Mdot
.5098 .52941 Mdot
.50196 .53725 Mdot
.4902 .52157 Mdot
.4902 .51765 Mdot
.48628 .51372 Mdot
.49412 .51765 Mdot
.49412 .51765 Mdot
.48628 .5098 Mdot
.47451 .50196 Mdot
.46667 .49804 Mdot
.45883 .48628 Mdot
.46275 .48628 Mdot
.46667 .49412 Mdot
.45883 .47843 Mdot
.44706 .47451 Mdot
.43922 .47059 Mdot
.43922 .47059 Mdot
.43138 .45883 Mdot
.42354 .45098 Mdot
.42354 .45491 Mdot
.40785 .43922 Mdot
.40001 .42746 Mdot
.40001 .4353 Mdot
.39609 .43922 Mdot
.38824 .42746 Mdot
.3804 .4353 Mdot
.36864 .42746 Mdot
.41177 .42746 Mdot
.4353 .45491 Mdot
.45491 .47843 Mdot
.45883 .48628 Mdot
.46667 .4902 Mdot
.46667 .47843 Mdot
.46667 .47843 Mdot
.47059 .48235 Mdot
.48235 .49804 Mdot
.4902 .51372 Mdot
.49412 .53333 Mdot
.48628 .52941 Mdot
.48235 .51372 Mdot
.4902 .52549 Mdot
.48628 .52549 Mdot
.48628 .52941 Mdot
.49804 .54902 Mdot
.50196 .55686 Mdot
.5098 .56078 Mdot
.5098 .55686 Mdot
.50196 .54902 Mdot
.5098 .54902 Mdot
.51372 .55294 Mdot
.49804 .54509 Mdot
.51372 .5647 Mdot
.52549 .57254 Mdot
.53333 .56862 Mdot
.53333 .5647 Mdot
.53725 .55686 Mdot
.54902 .5647 Mdot
.55294 .57254 Mdot
.54117 .5647 Mdot
.54117 .57254 Mdot
.54117 .56862 Mdot
.54117 .56078 Mdot
.55294 .57254 Mdot
.5647 .58039 Mdot
.55686 .57254 Mdot
.54509 .56078 Mdot
.54509 .56862 Mdot
.54509 .57646 Mdot
.55686 .58039 Mdot
.54902 .56862 Mdot
.54902 .56862 Mdot
.54117 .56078 Mdot
.53333 .55294 Mdot
.51765 .54509 Mdot
.51765 .55294 Mdot
.51765 .54902 Mdot
.51765 .54117 Mdot
.53333 .54902 Mdot
.54509 .55294 Mdot
.54902 .5647 Mdot
.54509 .56862 Mdot
.53725 .56862 Mdot
.54902 .58431 Mdot
.55686 .58823 Mdot
.56078 .58823 Mdot
.5647 .58823 Mdot
.57254 .59607 Mdot
.58039 .60783 Mdot
.5647 .59215 Mdot
.57254 .60391 Mdot
.57254 .60391 Mdot
.58039 .60783 Mdot
.58039 .60783 Mdot
.57646 .59999 Mdot
.58039 .60783 Mdot
.5647 .59215 Mdot
.56862 .59215 Mdot
.57646 .60391 Mdot
.57646 .59215 Mdot
.58039 .59607 Mdot
.58431 .59999 Mdot
.59607 .61568 Mdot
.58431 .59999 Mdot
.58039 .59607 Mdot
.58823 .60783 Mdot
.58823 .60783 Mdot
.58823 .60391 Mdot
.59215 .60391 Mdot
.58431 .59215 Mdot
.58823 .60391 Mdot
.58039 .59215 Mdot
.58431 .59999 Mdot
.58823 .59607 Mdot
.59607 .60391 Mdot
.59999 .60783 Mdot
.60391 .61176 Mdot
.58823 .59999 Mdot
.58823 .60391 Mdot
.58823 .60391 Mdot
.58823 .59999 Mdot
.59607 .59999 Mdot
.59215 .59215 Mdot
.59215 .59607 Mdot
.58823 .59607 Mdot
.59215 .60391 Mdot
.58431 .59607 Mdot
.58823 .59999 Mdot
.58823 .59999 Mdot
.58823 .59607 Mdot
.58431 .59607 Mdot
.57254 .58039 Mdot
.57646 .58039 Mdot
.58039 .58823 Mdot
.57254 .57646 Mdot
.57254 .58039 Mdot
.58431 .59215 Mdot
.58431 .59215 Mdot
.57254 .57646 Mdot
.57646 .58431 Mdot
.57254 .57646 Mdot
.5647 .57254 Mdot
.56862 .58039 Mdot
.56862 .57646 Mdot
.5647 .57646 Mdot
.55294 .56862 Mdot
.54902 .56862 Mdot
.54509 .5647 Mdot
.54902 .57254 Mdot
.55294 .57646 Mdot
.52941 .55686 Mdot
.52941 .55294 Mdot
.53725 .55686 Mdot
.53725 .56078 Mdot
.53333 .55294 Mdot
.52941 .54509 Mdot
.53333 .54902 Mdot
.54509 .55686 Mdot
.53333 .53333 Mdot
.52549 .52941 Mdot
.51765 .52549 Mdot
.50196 .52157 Mdot
.49412 .51765 Mdot
.4902 .52157 Mdot
.4902 .52157 Mdot
.49412 .51765 Mdot
.49412 .51372 Mdot
.50196 .52157 Mdot
.4902 .50588 Mdot
.48628 .49804 Mdot
.48235 .50196 Mdot
.47451 .49412 Mdot
.47059 .4902 Mdot
.46667 .48235 Mdot
.45491 .47059 Mdot
.45098 .47059 Mdot
.44314 .47059 Mdot
.42746 .45491 Mdot
.41569 .44706 Mdot
.42354 .45883 Mdot
.42354 .45883 Mdot
.42354 .45491 Mdot
.40785 .44314 Mdot
.40785 .43922 Mdot
.40785 .43138 Mdot
.39609 .41961 Mdot
.37648 .41177 Mdot
.37256 .41961 Mdot
.41961 .43138 Mdot
.46275 .48235 Mdot
.47843 .50588 Mdot
.47843 .50196 Mdot
.48628 .50196 Mdot
.47843 .4902 Mdot
.47843 .48235 Mdot
.4902 .49804 Mdot
.4902 .50588 Mdot
.4902 .5098 Mdot
.49804 .52549 Mdot
.50588 .53333 Mdot
.49804 .52157 Mdot
.5098 .53333 Mdot
.5098 .53725 Mdot
.50196 .53725 Mdot
.49804 .54509 Mdot
.5098 .56078 Mdot
.5098 .5647 Mdot
.51765 .56078 Mdot
.51765 .55686 Mdot
.52549 .55686 Mdot
.52157 .54902 Mdot
.50588 .53333 Mdot
.50588 .54117 Mdot
.51765 .55686 Mdot
.52941 .56862 Mdot
.53725 .5647 Mdot
.54117 .56078 Mdot
.55294 .5647 Mdot
.54509 .56078 Mdot
.54509 .5647 Mdot
.54509 .5647 Mdot
.54117 .56078 Mdot
.54902 .56862 Mdot
.54902 .5647 Mdot
.56078 .57254 Mdot
.55294 .56862 Mdot
.54902 .5647 Mdot
.54509 .5647 Mdot
.55686 .58039 Mdot
.5647 .58823 Mdot
.55686 .57646 Mdot
.55294 .57254 Mdot
.54509 .56078 Mdot
.54117 .55686 Mdot
.53333 .55294 Mdot
.52157 .54902 Mdot
.51765 .54117 Mdot
.51765 .52941 Mdot
.52549 .52941 Mdot
.52157 .51372 Mdot
.52157 .51372 Mdot
.5098 .5098 Mdot
.49412 .50588 Mdot
.49804 .52549 Mdot
.49804 .52941 Mdot
.51372 .53725 Mdot
.52157 .54117 Mdot
.53333 .55686 Mdot
.54117 .5647 Mdot
.53333 .56862 Mdot
.54902 .58431 Mdot
.56078 .60391 Mdot
.57254 .61568 Mdot
.56862 .60783 Mdot
.58039 .60783 Mdot
.57646 .60783 Mdot
.56078 .58823 Mdot
.57254 .60391 Mdot
.57646 .60783 Mdot
.57646 .60783 Mdot
.58431 .60783 Mdot
.58823 .60391 Mdot
.59215 .61176 Mdot
.58823 .61176 Mdot
.57254 .59215 Mdot
.58431 .60783 Mdot
.59215 .61176 Mdot
.58823 .60391 Mdot
.58823 .59607 Mdot
.59215 .59999 Mdot
.58823 .60391 Mdot
.57646 .59999 Mdot
.56862 .59215 Mdot
.58431 .59999 Mdot
.59215 .60783 Mdot
.58823 .59607 Mdot
.58823 .58823 Mdot
.58039 .58431 Mdot
.58431 .59607 Mdot
.58431 .59999 Mdot
.58431 .59607 Mdot
.59607 .60391 Mdot
.59607 .59607 Mdot
.59215 .59215 Mdot
.58823 .59215 Mdot
.58431 .59607 Mdot
.58039 .58823 Mdot
.57646 .58431 Mdot
.59215 .60391 Mdot
.59215 .59999 Mdot
.59215 .60391 Mdot
.57254 .58431 Mdot
.56862 .58039 Mdot
.57254 .58039 Mdot
.57254 .58039 Mdot
.57646 .58431 Mdot
.58431 .58431 Mdot
.58039 .58039 Mdot
.57254 .57254 Mdot
.58431 .58823 Mdot
.57646 .58431 Mdot
.57254 .58431 Mdot
.56862 .57646 Mdot
.56078 .56862 Mdot
.56078 .56862 Mdot
.54902 .5647 Mdot
.54117 .5647 Mdot
.54902 .56862 Mdot
.54902 .57254 Mdot
.55686 .57646 Mdot
.55686 .56862 Mdot
.54902 .55294 Mdot
.54117 .54902 Mdot
.52549 .53725 Mdot
.53333 .55294 Mdot
.52941 .54509 Mdot
.53333 .55294 Mdot
.54117 .55294 Mdot
.53725 .54117 Mdot
.53333 .53333 Mdot
.52549 .52549 Mdot
.5098 .52157 Mdot
.49804 .51765 Mdot
.48235 .51372 Mdot
.4902 .51765 Mdot
.4902 .5098 Mdot
.4902 .50588 Mdot
.49804 .5098 Mdot
.49804 .50588 Mdot
.48628 .49804 Mdot
.47843 .49412 Mdot
.47451 .49412 Mdot
.47451 .48628 Mdot
.47843 .48628 Mdot
.47451 .48235 Mdot
.46275 .47059 Mdot
.45491 .46667 Mdot
.43922 .45491 Mdot
.41961 .44314 Mdot
.41569 .44314 Mdot
.41961 .45491 Mdot
.41177 .45098 Mdot
.41177 .4353 Mdot
.41569 .43138 Mdot
.40001 .41177 Mdot
.40393 .41569 Mdot
.39609 .41177 Mdot
.3608 .38432 Mdot
.41961 .43138 Mdot
.46667 .48628 Mdot
.46667 .4902 Mdot
.47059 .48628 Mdot
.47451 .48235 Mdot
.48235 .49412 Mdot
.48235 .4902 Mdot
.48628 .49804 Mdot
.4902 .49804 Mdot
.49804 .51372 Mdot
.50196 .52157 Mdot
.50196 .51765 Mdot
.50588 .52549 Mdot
.50588 .52941 Mdot
.51765 .54509 Mdot
.5098 .54117 Mdot
.5098 .54902 Mdot
.51372 .56078 Mdot
.51765 .56078 Mdot
.52157 .5647 Mdot
.51765 .55294 Mdot
.53333 .5647 Mdot
.52157 .55294 Mdot
.52549 .55294 Mdot
.52549 .55686 Mdot
.54117 .5647 Mdot
.54509 .57254 Mdot
.54509 .5647 Mdot
.54509 .5647 Mdot
.54902 .56078 Mdot
.54902 .55686 Mdot
.54902 .5647 Mdot
.54509 .56078 Mdot
.54509 .5647 Mdot
.54117 .56078 Mdot
.55294 .57254 Mdot
.56078 .57646 Mdot
.55294 .56862 Mdot
.55294 .57254 Mdot
.55686 .57646 Mdot
.56078 .58823 Mdot
.56078 .58431 Mdot
.56862 .58431 Mdot
.56078 .56862 Mdot
.5647 .57254 Mdot
.56078 .57646 Mdot
.56078 .57646 Mdot
.56078 .58039 Mdot
.55294 .56862 Mdot
.55686 .56862 Mdot
.54902 .55294 Mdot
.54509 .54509 Mdot
.52941 .51765 Mdot
.52549 .52157 Mdot
.5098 .5098 Mdot
.50196 .5098 Mdot
.49804 .50588 Mdot
.50196 .50588 Mdot
.50196 .50196 Mdot
.49412 .49804 Mdot
.48628 .49412 Mdot
.47059 .4902 Mdot
.47451 .49804 Mdot
.47451 .49804 Mdot
.47451 .50196 Mdot
.50588 .53333 Mdot
.52941 .55294 Mdot
.54509 .57254 Mdot
.55294 .58039 Mdot
.5647 .59999 Mdot
.57254 .60391 Mdot
.57646 .60783 Mdot
.57254 .60391 Mdot
.57646 .59999 Mdot
.56862 .59215 Mdot
.57646 .60783 Mdot
.5647 .59607 Mdot
.57646 .61176 Mdot
.57254 .60391 Mdot
.58039 .60783 Mdot
.58823 .60783 Mdot
.59607 .60783 Mdot
.58039 .58823 Mdot
.57254 .58823 Mdot
.58039 .59607 Mdot
.58431 .60391 Mdot
.58823 .59607 Mdot
.59607 .59999 Mdot
.58823 .59215 Mdot
.57646 .58039 Mdot
.57254 .58431 Mdot
.57254 .58823 Mdot
.58039 .59215 Mdot
.58039 .59215 Mdot
.57254 .58039 Mdot
.58823 .58431 Mdot
.58823 .59215 Mdot
.57646 .58823 Mdot
.58039 .59215 Mdot
.58431 .59999 Mdot
.58823 .60391 Mdot
.58039 .58823 Mdot
.58823 .59607 Mdot
.58039 .59215 Mdot
.56862 .58431 Mdot
.56862 .58039 Mdot
.58431 .59607 Mdot
.57646 .58431 Mdot
.58431 .58431 Mdot
.57254 .57254 Mdot
.58431 .58823 Mdot
.56862 .57254 Mdot
.56862 .58039 Mdot
.56862 .58039 Mdot
.56862 .58039 Mdot
.55686 .57254 Mdot
.54902 .5647 Mdot
.54902 .56862 Mdot
.54117 .56078 Mdot
.54117 .5647 Mdot
.53333 .55686 Mdot
.54509 .56862 Mdot
.55294 .56862 Mdot
.54509 .55686 Mdot
.54117 .54509 Mdot
.53725 .53725 Mdot
.52941 .53333 Mdot
.53725 .54117 Mdot
.54509 .55294 Mdot
.53725 .54117 Mdot
.53725 .53333 Mdot
.53725 .53333 Mdot
.51372 .5098 Mdot
.50588 .50588 Mdot
.50588 .51765 Mdot
.49412 .5098 Mdot
.48235 .50588 Mdot
.48628 .5098 Mdot
.4902 .5098 Mdot
.49412 .50196 Mdot
.49804 .50588 Mdot
.48628 .49412 Mdot
.47059 .47843 Mdot
.47451 .48628 Mdot
.47059 .47843 Mdot
.46667 .46667 Mdot
.46667 .46275 Mdot
.46275 .46275 Mdot
.44706 .45098 Mdot
.44706 .45491 Mdot
.42746 .44314 Mdot
.40785 .43138 Mdot
.40785 .4353 Mdot
.41177 .43922 Mdot
.41569 .4353 Mdot
.41569 .42746 Mdot
.40001 .40393 Mdot
.39609 .40785 Mdot
.39217 .40785 Mdot
.37648 .40393 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00d?oooone
o`0000_ooooo000:ooooo`03o`000?ooogoooomo01gooomo00?o000007ooo`1oool0T@1ooolBoooo
o`L00?l0[Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooomoooooO`0MooooO`03
0?ooOol00000Oooo0940Oooo4_ooool8003o0:cooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooOoooogl07Oooogl20?ooO`03o`00001oool0Oooo08l0Oooo4_ooool3003o00?o003o
1P00o`2Xooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?ooogoooomo01gooomo0P3o
ogl00ol00000Oooo07ooo`2?07oooa;ooooo0`00o`03o`00o`H00?l0Z?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol0003ooomoooooO`0MooooO`<0oomo00?o000007ooo`1oool0SP1ooolB
ooooo`<00?l01Ol00?l4003o0:Sooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
Ooooogl07Oooogl40?ooO`03o`00001oool0Oooo08d0Oooo4_ooool00ol000000?l0003o0002003o
00?o003o1@00o`2Wooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?ooogoooomo01go
oomo103oogl00ol00000Oooo07ooo`2=07oooa;ooooo00?o0000ooooo`00o`000P00o`04o`00o`H0
0?l0YOooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooomoooooO`0MooooO`D0oomo
00?o000007ooo`1oool0S01ooolBooooo`03o`000?ooool00?l000<00?l00ol00?l6003o0:Gooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooOoooogl07Oooogl50?ooO`03o`00001o
ool0Oooo08`0Oooo4_ooool00ol0003oooooooooo`03003o00?o003o1`00o`2Tooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?ooogoooomo01gooomo1@3oogl00ol00000Oooo07ooo`2<
07oooa;ooooo00Co0000oooooooooooooooo2P00o`03o`00oj?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o0000ooooOoooogl07Oooogl60?ooO`03o`00001oool0Oooo08/0Oooo4_ooool0
0ol0003oooooooooo`03ooooo`P00?l00ol00?nSooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`000?ooogoooomo01gooomo1`3oogl00ol00000Oooo07ooo`2:07oooa;ooooo00?o0000oooo
ooooool00oooool01000o`3o003oo`00ool00?l4003o00?o003o0P00o`2Qooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`000?ooogoooomo01gooomo1`3oogl00ol00000Oooo07ooo`2:07oo
oa;ooooo00?o0000ooooooooool01?ooool3o`00o`@00?l01Ol00?l00`00o`3oooooooooo`2Noooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?ooogoooomo01gooomo203oogl00ol00000
Oooo07ooo`2907oooa;ooooo00?o0000ooooooooool01?ooool3o`00o`@00?l01Ol00?l00`00o`3o
ooooooooo`2Nooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?ooogoooomo01gooomo
2@3oogl00ol00000Oooo07ooo`2807oooa;ooooo00?o0000ooooooooool01_ooool7003o00Go003o
0P00o`2Mooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?ooogoooomo01gooomo2@3o
ogl00ol00000Oooo07ooo`2807oooa;ooooo00?o0000ooooooooool01_ooool9003o00?o003o0P00
o`2Mooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?ooogoooomo01gooomo2P3oogl0
0ol00000Oooo07ooo`2707oooa;ooooo00?o0000ooooooooool01oooool2003o00?o003o0`00o`04
o`00o`D00?l0VOooool00ol0003oooooooooo`09ooooo`002_ooool2o`0001kooomo2`3oogl00ol0
0000Oooo07ooo`2607oooa;ooooo00?o0000ooooooooool01oooool2003o00?o003o1000o`03o`00
o`D00?l0VOooool00ol0003oooooooooo`09ooooo`002_ooool01?l00000Ooooo`000?l0000Loooo
O`/0oomo00?o000007ooo`1oool0QP1ooolBooooo`03o`000?oooooooooo00Oooooo0P00o`03o`00
o`@00?l01?l00?l5003o09Sooooo00?o0000ooooooooool02Oooool000[ooooo00Go000007ooo`1o
ool0Ooooo`00000KooooO``0oomo00?o000007ooo`1oool0Q@1ooolBooooo`03o`000?oooooooooo
00Sooooo2000o`04o`00o`D00?l0V?ooool00ol0003oooooooooo`09ooooo`002_ooool01Ol00000
Oooo07ooo`1ooooo000001_ooomo3@3oogl00ol00000Oooo07ooo`2407oooa;ooooo00?o0000oooo
ooooool02Oooool8003o00Co003o1@00o`2Gooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`00001oool0Oooo0080Oooo00?o0000ooooOoooogl06?ooogl=0?ooO`03o`00001oool0Oooo08@0
Oooo4_ooool00ol0003oooooooooo`0;ooooo`L00?l00ol00?l8003o09Cooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o000007ooo`1oool00`1oool2o`0001Sooomo3P3oogl00ol00000Oooo
07ooo`2307oooa;ooooo00?o0000ooooooooool02oooool7003o00?o003o2000o`2Dooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo00D0Oooo00?o0000ooooOoooogl05Ooo
ogl>0?ooO`03o`00001oool0Oooo08<0Oooo4_ooool00ol0003oooooooooo`0<ooooo`D00?l01?l0
0?l9003o09?ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool01@1oool0
0ol0003ooomoooooO`0EooooO`h0oomo00?o000007ooo`1oool0P`1ooolBooooo`03o`000?oooooo
oooo00gooooo1000o`04o`00o`04003o0?l00?oo003oo`00o`D00?l000Coooooo`00ool00?oo003o
Soooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0607ooo`;o00005Ooo
ogl?0?ooO`03o`00001oool0Oooo0880Oooo4_ooool00ol0003oooooooooo`0>ooooo`<00?l02ol0
0?l2003o0004ooooool00?oo003oo`00ohoooooo00?o0000ooooooooool02Oooool000[ooooo00?o
000007ooo`1oool0201oool00ol0003ooomoooooO`0BooooOa00oomo00?o000007ooo`1oool0P@1o
oolBooooo`03o`000?oooooooooo00kooooo1`00o`07o`00o`<00?l00ol00?n?ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00001oool0Oooo00T0Oooo00?o0000ooooOoooogl04Oooogl@
0?ooO`03o`00001oool0Oooo0840Oooo4_ooool00ol0003oooooooooo`0@ooooo`D00?l01ol00?l3
003o00?o003oSoooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0:07oo
o`03o`000?ooogoooomo013ooomo4@3oogl00ol00000Oooo07ooo`2007oooa;ooooo00?o0000oooo
ooooool04Oooool5003o00Go003o1000o`03o`00ohoooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool02`1oool00ol0003ooomoooooO`0?ooooOa80oomo00?o000007ooo`1o
ool0O`1ooolBooooo`03o`000?oooooooooo01;ooooo1000o`08o`00o`@00?l0Soooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0<07ooo`03o`000?ooogoooomo00kooomo
4P3oogl00ol00000Oooo07ooo`1o07oooa;ooooo00?o0000ooooooooool04oooool4003o00Oo003o
0`00o`03o`00ohgooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool03@1o
ool00ol0003ooomoooooO`0=ooooOa<0oomo00?o000007ooo`1oool0OP1ooolBooooo`03o`000?oo
oooooooo01Cooooo1@00o`0;o`00ohgooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
07ooo`1oool03P1oool00ol0003ooomoooooO`0<ooooOa@0oomo00?o000007ooo`1oool0O@1ooolB
ooooo`03o`000?oooooooooo01Gooooo1000o`0=o`00oh_ooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o000007ooo`1oool03`1oool00ol0003ooomoooooO`0;ooooOa@0oomo00?o000007oo
o`1oool0O@1ooolBooooo`03o`000?oooooooooo01Gooooo1000o`03o`00o`03003o0?l00?oo003o
00Wo003oROooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0@07ooo`03
o`000?ooogoooomo00[ooomo5@3oogl00ol00000Oooo07ooo`1l07oooa;ooooo00?o0000oooooooo
ool05oooool6003o00_o003oROooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`0A07ooo`03o`000?ooogoooomo00Wooomo5@3oogl00ol00000Oooo07ooo`1l07oooa;ooooo
00?o0000ooooooooool05oooool6003o00Oo003o00@00?l0o`00ool00?oo003oROooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0B07ooo`;o00002OoooglE0?ooO`03o`00
001oool0Oooo07`0Oooo4_ooool00ol0003oooooooooo`0Gooooo`L00?l01_l00?l2003o00?o003o
R?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0D07ooo`03o`000?oo
ogoooomo00Kooomo5P3oogl00ol00000Oooo07ooo`1k07oooa;ooooo00?o0000ooooooooool05ooo
ool7003o00Oo003o00@00?l0o`00ool00?oo003oR?ooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol00000Oooo07ooo`0D07ooo`03o`000?ooogoooomo00Kooomo5P3oogl00ol00000Oooo07oo
o`1k07oooa;ooooo00?o0000ooooooooool06?ooool:003o00Oo003o0P00o`26ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00001oool0Oooo01D0Oooo00?o0000ooooOoooogl01OoooglG
0?ooO`03o`00001oool0Oooo07X0Oooo4_ooool00ol0003oooooooooo`0Hooooo`T00?l01Ol00?l5
003o08Kooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool05P1oool2o`00
00Gooomo5`3oogl00ol00000Oooo07ooo`1j07oooa;ooooo00?o0000ooooooooool06Oooool8003o
00Go003o1@00o`26ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo01P0
Oooo00?o0000ooooOoooogl00_oooglH0?ooO`03o`00001oool0Oooo07T0Oooo4_ooool00ol0003o
ooooooooo`0Looooo`D00?l01Ol00?l5003o08Kooooo00?o0000ooooooooool02Oooool000[ooooo
00?o000007ooo`1oool0601oool00ol0003ooomoooooO`02ooooOaT0oomo00?o000007ooo`1oool0
N01ooolBooooo`03o`000?oooooooooo01gooooo1000o`05o`00o`X00?l0POooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0I07ooo`04o`000?ooogoooomoooooOaT0oomo
00?o000007ooo`1oool0N01ooolBooooo`03o`000?oooooooooo01oooooo00<00?l0o`00ool00?l0
1?l00?l:003o087ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool06P1o
ool2o`000003ooooO`3oogl0oomo01P0oomo00?o000007ooo`1oool0M`1ooolBooooo`03o`000?oo
oooooooo01oooooo00<00?l0o`00ool00?l01?l00?l6003o00?o003o00<00?l0ooooooooool0Oooo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0L07ooo`03o`00003oogl0
oomo01T0oomo00?o000007ooo`1oool0MP1ooolBooooo`03o`000?oooooooooo01oooooo00<00?l0
o`00ool00?l01?l00?l2003o00Wo003o00<0003oooooooooool0OOooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000Oooo07ooo`0M07ooo`030000003oogl0oomo01P0oomo00?o000007oo
o`1oool0MP1ooolBooooo`03o`000?oooooooooo027ooooo0P00o`03o`00o`800?l02Ol00?l00`00
0?ooooooooooo`1mooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo01h0
Oooo00<000000?ooO`3oogl0603oogl00ol00000Oooo07ooo`1e07oooa;ooooo00?o0000oooooooo
ool08Oooool7003o00Co003o0P00o`03o`00o`030000oooooooooooo07gooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o000007ooo`1oool07`1oool00`000000oomo0?ooO`0H0?ooO`03o`00
001oool0Oooo07@0Oooo4_ooool00ol0003oooooooooo`0Sooooo``00?l00ol00?l00`00o`3ooooo
ooooo`1looooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0200Oooo00<0
00000?ooO`3oogl05`3oogl00ol00000Oooo07ooo`1d07oooa;ooooo00?o0000ooooooooool08ooo
ool<003o00?o003o0P00o`1mooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0
Oooo0240Oooo00<000000?ooO`3oogl05`3oogl00ol00000Oooo07ooo`1c07oooa;ooooo00?o0000
ooooooooool09_ooool8003o00Oo003oO?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
0000Oooo07ooo`0Q07ooo`030000003oogl0oomo01L0oomo00?o000007ooo`1oool0L`1ooolBoooo
o`03o`000?oooooooooo02Kooooo2000o`07o`00ogcooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool08P1oool2000001L0oomo00?o000007ooo`1oool0L`1ooolBooooo`03
o`000?oooooooooo02Kooooo2000o`09o`00og[ooooo00?o0000ooooooooool02Oooool000[ooooo
00?o000007ooo`1oool0901oool00`000000oomo0?ooO`0E0?ooO`03o`00001oool0Oooo0780Oooo
4_ooool00ol0003oooooooooo`0Wooooo`/00?l01Ol00?mjooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`00001oool0Oooo02D0Oooo00<000000?ooO`3oogl0503oogl00ol00000Oooo07oo
o`1b07oooa;ooooo00?o0000ooooooooool09oooool:003o00Wo003oMoooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000Oooo07ooo`0V07ooo`8000005@3oogl00ol00000Oooo07ooo`1a
07oooa;ooooo00?o0000ooooooooool0:Oooool6003o00_o003oMoooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000Oooo07ooo`0X07ooo`030000003oogl0oomo0180oomo00?o000007oo
o`1oool0L@1ooolBooooo`03o`000?oooooooooo02Wooooo1P00o`05o`00o`03003o0?l00?oo003o
00?o003oMoooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0Y07ooo`03
0000003oogl0oomo0180oomo00?o000007ooo`1oool0L01ooolBooooo`03o`000?oooooooooo02_o
oooo1000o`03o`00o`T00?l0M_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`0Z07ooo`030000003oogl0oomo0180oomo00?o000007ooo`1oool0K`1ooolBooooo`03o`00
0?oooooooooo02_ooooo5000o`1booooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001o
ool0Oooo02X0Oooo00<000000?ooO`3oogl04P3oogl00ol00000Oooo07ooo`1_07oooa;ooooo00?o
0000ooooooooool0;Oooool7003o00Co003o00<0003o003o0000o`001000o`1booooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00001oool0Oooo02/0Oooo0P00000C0?ooO`03o`00001oool0
Oooo06h0Oooo4_ooool00ol0003oooooooooo`0]ooooo`L00?l01?l00?l00`000?l00?l0003o0007
003o06oooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0;@1oool00`00
0000oomo0?ooO`0A0?ooO`03o`00001oool0Oooo06d0Oooo4_ooool00ol0003oooooooooo`0^oooo
o`H00?l01?l00?l00`000?l00?l0o`00o`05o`00o`800?l0Koooool00ol0003oooooooooo`09oooo
o`002_ooool00ol00000Oooo07ooo`0^07ooo`030000003oogl0oomo0100oomo00?o000007ooo`1o
ool0K@1ooolBooooo`03o`000?oooooooooo02kooooo1`00o`03o`00o`800?l01_l00?l00`000?l0
0?l0ooooo`1^ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo02l0Oooo
00<000000?ooO`3oogl0403oogl00ol00000Oooo07ooo`1/07oooa;ooooo00?o0000ooooooooool0
;oooool6003o00?o003o0P00o`06o`00o`030000oooooooooooo06kooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o000007ooo`1oool0<01oool00`000000oomo0?ooO`0?0?ooO`03o`00001o
ool0Oooo06`0Oooo4_ooool00ol0003oooooooooo`0_ooooo`H00?l00ol00?l5003o00?o003o00<0
003oooooooooool0K_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0a
07ooo`03o`00003oogl0oomo00l0oomo00?o000007ooo`1oool0J`1ooolBooooo`03o`000?oooooo
oooo03;ooooo2`00o`03o`00o`800?l0Koooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
0000Oooo07ooo`0b07ooo`030000003oogl0oomo00h0oomo00?o000007ooo`1oool0J`1ooolBoooo
o`03o`000?oooooooooo03;ooooo4000o`1_ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`00001oool0Oooo03<0Oooo00<000000?ooO`3oogl03@3oogl00ol00000Oooo07ooo`1[07oooa;o
oooo00?o0000ooooooooool0<oooool:003o00?o003o1000o`1]ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00001oool0Oooo03@0Oooo0P00000>0?ooO`03o`00001oool0Oooo06X0Oooo
4_ooool00ol0003oooooooooo`0dooooo`T00?l00ol00?l5003o06cooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o000007ooo`1oool0=P1oool00`000000oomo0?ooO`0;0?ooO`03o`00001o
ool0Oooo06X0Oooo4_ooool00ol0003oooooooooo`0dooooo`T00?l00ol00?l00`000?l00?l0003o
0002003o06cooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0=`1oool0
0`000000oomo0?ooO`0:0?ooO`03o`00001oool0Oooo06X0Oooo4_ooool00ol0003oooooooooo`0g
ooooo`L00?l01Ol00?l2003o06cooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007oo
o`1oool0>01oool2000000/0oomo00?o000007ooo`1oool0J@1ooolBooooo`03o`000?oooooooooo
03Oooooo1P00o`000`000?oo003oo`00o`07o`00o`03003o0?oooooooooo06Oooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o000007ooo`1oool0>P1oool00`000000oomo0?ooO`080?ooO`03
o`00001oool0Oooo06T0Oooo4_ooool00ol0003oooooooooo`0gooooo`H00?l000<0003oo`00ool0
0?l01ol00?l00`00o`3oooooooooo`1Wooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
001oool0Oooo03X0Oooo00<000000?ooO`3oogl02@3oogl00ol00000Oooo07ooo`1X07oooa;ooooo
00?o0000ooooooooool0=oooool6003o00<0003o2?l00?mYooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`00001oool0Oooo03/0Oooo0P00000:0?ooO`03o`00001oool0Oooo06L0Oooo4_oo
ool00ol0003oooooooooo`0iooooo`H00?l02Ol00?l3003o06Kooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o000007ooo`1oool0?@1oool00`000000oomo0?ooO`070?ooO`03o`00001oool0
Oooo06L0Oooo4_ooool00ol0003oooooooooo`0jooooo`@00?l03?l00?l00`00o`3oooooooooo`03
003o067ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0?P1oool00`00
0000oomo0?ooO`060?ooO`03o`00001oool0Oooo06L0Oooo4_ooool00ol0003oooooooooo`0joooo
o`@00?l03?l00?l00`00o`3oooooooooo`03003o067ooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool0?`1oool2000000L0oomoJ@1ooolBooooo`03o`000?oooooooooo03_o
oooo0`00o`0<o`00o`03003o0?oooooooooo00<00?l0HOooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol00000Oooo07ooo`1107ooo`8000001@3oogmY07oooa;ooooo00?o0000ooooooooool0
?_ooool00`00o`3o003oo`00o`0;o`00ofGooooo00?o0000ooooooooool02Oooool000[ooooo00?o
000007ooo`1oool0@`1oool00ol00000oomo0?ooO`020?ooO`03o`00001oool0Oooo06H0Oooo4_oo
ool00ol0003oooooooooo`0nooooo`800?l03ol00?mRooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00001oool0Oooo04@0Oooo0_l000000`3oogoo0000o`00001X07oooa;ooooo00?o0000
ooooooooool0?_ooool2003o00oo003oH_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
0000Oooo07ooo`1607ooo`;o0000J@1ooolBooooo`03o`000?oooooooooo043ooooo00<00?l0o`00
ool00?l04?l00?mNooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40
Oooo4_ooool00ol0003oooooooooo`11ooooo`800?l04?l00?mNooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003oooooooooo`12ooooo`03003o
0?l00?oo003o00ko003oG_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07oo
o`2a07oooa;ooooo00?o0000ooooooooool0@_ooool2003o013o003oGOooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0@_ooool2
003o017o003oG?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oo
oa;ooooo00?o0000ooooooooool0AOoooolAo`00oe_ooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo04Gooooo4Ol00?mKooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003ooooo
ooooo`15oooooaCo003oF?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07oo
o`2a07oooa;ooooo00?o0000ooooooooool0A_ooool00`00o`3o003oo`00o`0Ao`00oeOooooo00?o
0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooo
oooo04Kooooo0P00o`0Co`00oeKooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007oo
o`1oool0/@1ooolBooooo`03o`000?oooooooooo04Wooooo00<00?l0o`00ool00?l04_l00?mCoooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003o
ooooooooo`1:oooooaCo003oDoooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`2a07oooa;ooooo00?o0000ooooooooool0B_oooolDo`00o`03003o0?oooooooooo053ooooo
00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oo
oooooooo04[ooooo5_l00?mAooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0
Oooo0;40Oooo4_ooool00ol0003oooooooooo`1<oooooaOo003oC_ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0C?ooool00`00
o`3o003oo`00o`0Do`00odkooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1o
ool0/@1ooolBooooo`03o`000?oooooooooo04cooooo0P00o`0Eo`00odkooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo04oooooo
4ol00?l00`00o`3oooooo`00o`02o`00od[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o
000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo04oooooo0P00o`0Ao`00o`03003o0?oo
oooo003o00;o003oB_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a
07oooa;ooooo00?o0000ooooooooool0Coooool2003o01Ko003o00<00?l0ooooooooool0Aoooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000oooo
ooooool0DOooool00`00o`3o003oo`00o`0Bo`00o`@00?l0Aoooool00ol0003oooooooooo`09oooo
o`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0D_ooool00`00o`3o
003oo`00o`0Ao`00o`04003o0?l00?oo003oo`00odOooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo05?ooooo6?l00?m6ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003ooooo
ooooo`1Cooooo`<00?l05Ol00?l00`00o`3oooooooooo`13ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003oooooooooo`1FoooooaGo003o00<0
0?l0ooooooooool0@oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a
07oooa;ooooo00?o0000ooooooooool0E_ooool20000oaGo003oA?ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0E_ooool00`00
o`00003oo`00o`0Do`00o`800?l0@_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000
Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0FOooool00`000?oo003oo`00o`0Ao`00o`80
0?l0@_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo
00?o0000ooooooooool0FOooool00`000?oo003oo`00o`0Bo`00o`03003o0?oooooooooo043ooooo
00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oo
oooooooo05[ooooo0P000?lBo`00o`800?l0@Oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0F_ooool00`00o`00003oo`00o`0B
o`00o`03003o0?oooooooooo03oooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007oo
o`1oool0/@1ooolBooooo`03o`000?oooooooooo05[ooooo00<00?l00000o`000?l04_l00?l01000
o`00003o0000o`000?lnooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo
0;40Oooo4_ooool00ol0003oooooooooo`1Kooooo`<0003o4ol00?l20000ockooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo05go
oooo0`000?lAo`00o`80003o?_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`2a07oooa;ooooo00?o0000ooooooooool0GOooool30000oa;o003o0P00o`0mooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003ooooooooo
o`1Nooooo`@0003o4Ol00?l30000oc_ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
07ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo063ooooo10000?lAo`00o`030000oooooooo
oooo03Wooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBoooo
o`03o`000?oooooooooo06;ooooo0`000?l@o`00o`030000oooooooooooo03Wooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo06;o
oooo1@000?l?o`00oc_ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0
/@1ooolBooooo`03o`000?oooooooooo06;ooooo00<00?l00000o`000?l010000?l>o`00oc[ooooo
00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oo
oooooooo06;ooooo0P00o`050000o`oo003o>Oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0H_ooool3003o00D0003o4Ol00?lf
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0
003oooooooooo`1Tooooo`@00?l00P000?lAo`00ocKooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo06Gooooo1000o`050000o`oo
003o=?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo
00?o0000ooooooooool0IOooool5003o00H0003o3Ol00?ldooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003oooooooooo`1Uooooo`P00?l00`00
0?l>o`00oc?ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolB
ooooo`03o`000?oooooooooo06Gooooo0`00o`000oooool00?l0003o0002003o00H0003o3?l00?lb
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0
003oooooooooo`1Yooooo`D00?l01P000?l<o`00oc7ooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo06_ooooo1@00o`02ooooo`80
003o3ol00?l^ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo
4_ooool00ol0003oooooooooo`1[ooooo`H00?l00_ooool00`00o`00003oo`00o`0=o`00obkooooo
00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oo
oooooooo06_ooooo1P00o`02ooooo`03003o00000?oo003o00ko003o;Oooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0K?ooool7
003o00?ooooo4?l00?l[ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo
0;40Oooo4_ooool00ol0003oooooooooo`1/ooooo`<00?l000Cooooo003o0000o`000?l00oooool3
0000o`ko003o:_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oo
oa;ooooo00?o0000ooooooooool0K_ooool5003o00?ooooo0`000?l?o`00obWooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo06ko
oooo0`00o`07ooooo`80003o3_l00?l00`00o`3oooooooooo`0Vooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003oooooooooo`1^ooooo`<00?l0
2Oooool20000o`go003o00<00?l0ooooooooool09Oooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0Loooool3003o00Kooooo3Ol0
0?l2003o02Kooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolB
ooooo`03o`000?oooooooooo07?ooooo0`00o`06ooooo`go003o0P00o`0Vooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003oooooooooo`1boooo
o`H00?l01oooool>o`00obCooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1o
ool0/@1ooolBooooo`03o`000?oooooooooo07;ooooo1P00o`07ooooo`oo003o8oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0
L_ooool6003o00Sooooo00<0003oo`00ool00?l02ol00?lSooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003oooooooooo`21ooooo`<0003o2_l0
0?lSooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool0
0ol0003oooooooooo`21ooooo`@0003o1_l00?l3ooooo`<00?l08?ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0Q?ooool20000
o`Co003o10000?l3003o023ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1o
ool0/@1ooolBooooo`03o`000?oooooooooo08Kooooo00@00?l0o`00ool00?oo003o10000?l3003o
023ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03
o`000?oooooooooo08Kooooo00@00?l0o`00ool00?oo003o0P000?l3o`00o`<0003o7oooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000oooooooo
ool0NOooool3003o00_ooooo1@000?l3o`00o`@0003o7_ooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0NOooool3003o00cooooo
00@00?l00000o`000?l0003o0ol00?l40000oakooooo00?o0000ooooooooool02Oooool000[ooooo
00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo07Wooooo0`00o`0=ooooo`X0003o
00Coooooo`00ool00?oo003o6_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`2a07oooa;ooooo00?o0000ooooooooool0ROooool70000o`?o003o00Coooooo`00ool00?oo
003o6_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo
00?o0000ooooooooool0Q?ooool3003o00Cooooo0`00o`020000o`Oo003o00<00?l0ooooooooool0
5oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o
0000ooooooooool0Q?ooool3003o00Oooooo0P000?l5o`00o`<00?l06Oooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0Q?ooool3
003o00Oooooo0`000?l4o`00o`80003o00<00?l0ooooooooool05oooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0T_ooool20000
o`?o003o0`000?lGooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40
Oooo4_ooool00ol0003oooooooooo`2Booooo`80003o0ol00?l30000oaOooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo09Cooooo
0ol00?l30000o`800?l05Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07oo
o`2a07oooa;ooooo00?o0000ooooooooool0U?ooool60000o`<00?l05?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0U?ooool9
0000o`03003o0?oooooooooo017ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007oo
o`1oool0/@1ooolBooooo`03o`000?oooooooooo09Oooooo1P000?l00`00o`3oooooooooo`0Aoooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003o
ooooooooo`2Gooooo`P0003o4_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`2a07oooa;ooooo00?o0000ooooooooool0V_ooool01000o`00003o0000o`000?l3o`00oa3o
oooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`00
0?oooooooooo09[ooooo00@00?l00000o`000?l0003o0ol00?l@ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003oooooooooo`2Looooo`80003o
1?l00?l?ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_oo
ool00ol0003oooooooooo`2Looooo`<0003o0ol00?l00`000?ooooooooooo`0<ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003oooooooooo`2L
ooooo`<0003o1Ol00?l=ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo
0;40Oooo4_ooool00ol0003oooooooooo`2Pooooo`050000ool00?oo003oo`00o`00o`003?ooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000oooo
ooooool0XOooool3o`00o`80003o2oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000
Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0XOooool60000o`[ooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo0:?ooooo
1@000?l9ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_oo
ool00ol0003oooooooooo`2Tooooo`@0003o2Oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooooooool0YOooool30000o`Wooooo00?o0000
ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo
0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03
o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0
/@1ooolBooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o
000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo0;7ooooo00?o0000
ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03o`000?oooooooooo
0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`03
o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo]?l0000BoooookGo0000
2oooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0557921, \
-0.0252998, 0.00554406, 0.00554406}, {{10.0625, 190.438}, {184.875, 4.5}} -> \
{-14.4348, -6.64788, 1.41581, 1.41581}, {{10.0625, 190.438}, {184.875, 4.5}} -> \
{-14.4348, -6.64788, 1.41581, 1.41581}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-295.282, -6.60135, 1.41532, 1.41532}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RB plane", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(decRB = 
        ShowTwoClassificationRegions[p1rb, p2rb, pr, x, y, classColors, 
          False, Axes \[Rule] False, Frame \[Rule] True, \ 
          FrameTicks \[Rule] None, nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{decRB, distRB}}], 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
4e-05 4e-05 m
.01519 4e-05 L
.03171 4e-05 L
.04723 4e-05 L
.06215 4e-05 L
.07803 4e-05 L
.09332 4e-05 L
.10957 4e-05 L
.12523 4e-05 L
.14029 4e-05 L
.15632 4e-05 L
.17175 4e-05 L
.18658 4e-05 L
.20238 4e-05 L
.21758 4e-05 L
.23375 4e-05 L
.24932 4e-05 L
.2643 4e-05 L
.28023 4e-05 L
.29558 4e-05 L
.31188 4e-05 L
.32759 4e-05 L
.34271 4e-05 L
.35879 4e-05 L
.37348 4e-05 L
s
4e-05 .17004 m
.01519 .18108 L
.03171 .19308 L
.04723 .20432 L
.06215 .21509 L
.07803 .22652 L
.09332 .23749 L
.10957 .2491 L
.12523 .26024 L
.14029 .27091 L
.15632 .28221 L
.17175 .29303 L
.18658 .30339 L
.20238 .31435 L
.21758 .32483 L
.23375 .33591 L
.24932 .34649 L
.2643 .35659 L
.28023 .36724 L
.29558 .37739 L
.31188 .38805 L
.32759 .3982 L
.34271 .40782 L
.35879 .4179 L
.37348 .42695 L
s
1 1 .5 r
4e-05 4e-05 m
.01519 4e-05 L
.03171 4e-05 L
.04723 4e-05 L
.06215 4e-05 L
.07803 4e-05 L
.09332 4e-05 L
.10957 4e-05 L
.12523 4e-05 L
.14029 4e-05 L
.15632 4e-05 L
.17175 4e-05 L
.18658 4e-05 L
.20238 4e-05 L
.21758 4e-05 L
.23375 4e-05 L
.24932 4e-05 L
.2643 4e-05 L
.28023 4e-05 L
.29558 4e-05 L
.31188 4e-05 L
.32759 4e-05 L
.34271 4e-05 L
.35879 4e-05 L
.37348 4e-05 L
.37348 .42695 L
.35879 .4179 L
.34271 .40782 L
.32759 .3982 L
.31188 .38805 L
.29558 .37739 L
.28023 .36724 L
.2643 .35659 L
.24932 .34649 L
.23375 .33591 L
.21758 .32483 L
.20238 .31435 L
.18658 .30339 L
.17175 .29303 L
.15632 .28221 L
.14029 .27091 L
.12523 .26024 L
.10957 .2491 L
.09332 .23749 L
.07803 .22652 L
.06215 .21509 L
.04723 .20432 L
.03171 .19308 L
.01519 .18108 L
4e-05 .17004 L
F
0 g
4e-05 4e-05 m
.01519 4e-05 L
.03171 4e-05 L
.04723 4e-05 L
.06215 4e-05 L
.07803 4e-05 L
.09332 4e-05 L
.10957 4e-05 L
.12523 4e-05 L
.14029 4e-05 L
.15632 4e-05 L
.17175 4e-05 L
.18658 4e-05 L
.20238 4e-05 L
.21758 4e-05 L
.23375 4e-05 L
.24932 4e-05 L
.2643 4e-05 L
.28023 4e-05 L
.29558 4e-05 L
.31188 4e-05 L
.32759 4e-05 L
.34271 4e-05 L
.35879 4e-05 L
.37348 4e-05 L
s
4e-05 .17004 m
.01519 .18108 L
.03171 .19308 L
.04723 .20432 L
.06215 .21509 L
.07803 .22652 L
.09332 .23749 L
.10957 .2491 L
.12523 .26024 L
.14029 .27091 L
.15632 .28221 L
.17175 .29303 L
.18658 .30339 L
.20238 .31435 L
.21758 .32483 L
.23375 .33591 L
.24932 .34649 L
.2643 .35659 L
.28023 .36724 L
.29558 .37739 L
.31188 .38805 L
.32759 .3982 L
.34271 .40782 L
.35879 .4179 L
.37348 .42695 L
s
.37348 4e-05 m
.38214 .01544 L
.39159 .03232 L
.40046 .04824 L
.40899 .06364 L
.41807 .08011 L
.42682 .09606 L
.43611 .11313 L
.44506 .1297 L
.45367 .14576 L
.46283 .16299 L
.47166 .17975 L
.48014 .19603 L
.48917 .21357 L
.49786 .23069 L
.50711 .24919 L
.51601 .26734 L
.52457 .28519 L
.53368 .30468 L
.54246 .32408 L
.55178 .3456 L
.56076 .36761 L
.5694 .39067 L
.57379 .40352 L
.5786 .41923 L
.58069 .42695 L
.58294 .43631 L
.58403 .44152 L
.58506 .44719 L
.58599 .45347 L
.58624 .45559 L
.58651 .45821 L
.58674 .46105 L
.587 .46804 L
s
.37348 .42695 m
.38214 .4322 L
.39159 .43785 L
.40046 .44308 L
.40899 .44803 L
.41807 .45322 L
.42682 .45811 L
.43611 .4632 L
.44506 .46798 L
.45367 .47246 L
.46283 .47708 L
.47166 .48136 L
.48014 .4853 L
.48917 .4893 L
.49786 .49291 L
.50711 .49645 L
.51601 .49953 L
.52457 .5021 L
.53368 .50434 L
.5379 .50516 L
.54246 .50586 L
.54496 .50616 L
.54605 .50627 L
.54726 .50637 L
.54832 .50644 L
.54945 .5065 L
.55008 .50653 L
.55066 .50655 L
.55093 .50656 L
.55123 .50656 L
.55152 .50657 L
.55178 .50657 L
.55203 .50658 L
.5523 .50658 L
.55257 .50658 L
.55286 .50658 L
.55312 .50658 L
.55339 .50657 L
.55365 .50657 L
.55389 .50657 L
.55446 .50655 L
.55508 .50653 L
.55567 .5065 L
.55621 .50647 L
.5573 .5064 L
.5585 .50628 L
.55974 .50613 L
.56092 .50596 L
.5632 .50553 L
.56528 .505 L
Mistroke
.56752 .50429 L
.56996 .50328 L
.57438 .50072 L
.57685 .49869 L
.57909 .49632 L
.58107 .49359 L
.58289 .49028 L
.58384 .48806 L
.58489 .48496 L
.58542 .48299 L
.58598 .48033 L
.58625 .47871 L
.58651 .4768 L
.58674 .47449 L
.587 .46812 L
Mfstroke
1 1 .5 r
.37348 4e-05 m
.38214 .01544 L
.39159 .03232 L
.40046 .04824 L
.40899 .06364 L
.41807 .08011 L
.42682 .09606 L
.43611 .11313 L
.44506 .1297 L
.45367 .14576 L
.46283 .16299 L
.47166 .17975 L
.48014 .19603 L
.48917 .21357 L
.49786 .23069 L
.50711 .24919 L
.51601 .26734 L
.52457 .28519 L
.53368 .30468 L
.54246 .32408 L
.55178 .3456 L
.56076 .36761 L
.5694 .39067 L
.57379 .40352 L
.5786 .41923 L
.58069 .42695 L
.58294 .43631 L
.58403 .44152 L
.58506 .44719 L
.58599 .45347 L
.58624 .45559 L
.58651 .45821 L
.58674 .46105 L
.587 .46804 L
.587 .46812 L
.58674 .47449 L
.58651 .4768 L
.58625 .47871 L
.58598 .48033 L
.58542 .48299 L
.58489 .48496 L
.58384 .48806 L
.58289 .49028 L
.58107 .49359 L
.57909 .49632 L
.57685 .49869 L
.57438 .50072 L
.56996 .50328 L
.56752 .50429 L
.56528 .505 L
.5632 .50553 L
.56092 .50596 L
.55974 .50613 L
.5585 .50628 L
.5573 .5064 L
.55621 .50647 L
.55567 .5065 L
.55508 .50653 L
.55446 .50655 L
.55389 .50657 L
.55365 .50657 L
.55339 .50657 L
.55312 .50658 L
.55286 .50658 L
.55257 .50658 L
.5523 .50658 L
.55203 .50658 L
.55178 .50657 L
.55152 .50657 L
.55123 .50656 L
.55093 .50656 L
.55066 .50655 L
.55008 .50653 L
.54945 .5065 L
.54832 .50644 L
.54726 .50637 L
.54605 .50627 L
.54496 .50616 L
.54246 .50586 L
.5379 .50516 L
.53368 .50434 L
.52457 .5021 L
.51601 .49953 L
.50711 .49645 L
.49786 .49291 L
.48917 .4893 L
.48014 .4853 L
.47166 .48136 L
.46283 .47708 L
.45367 .47246 L
.44506 .46798 L
.43611 .4632 L
.42682 .45811 L
.41807 .45322 L
.40899 .44803 L
.40046 .44308 L
.39159 .43785 L
.38214 .4322 L
.37348 .42695 L
F
0 g
.37348 4e-05 m
.38214 .01544 L
.39159 .03232 L
.40046 .04824 L
.40899 .06364 L
.41807 .08011 L
.42682 .09606 L
.43611 .11313 L
.44506 .1297 L
.45367 .14576 L
.46283 .16299 L
.47166 .17975 L
.48014 .19603 L
.48917 .21357 L
.49786 .23069 L
.50711 .24919 L
.51601 .26734 L
.52457 .28519 L
.53368 .30468 L
.54246 .32408 L
.55178 .3456 L
.56076 .36761 L
.5694 .39067 L
.57379 .40352 L
.5786 .41923 L
.58069 .42695 L
.58294 .43631 L
.58403 .44152 L
.58506 .44719 L
.58599 .45347 L
.58624 .45559 L
.58651 .45821 L
.58674 .46105 L
.587 .46804 L
s
.37348 .42695 m
.38214 .4322 L
.39159 .43785 L
.40046 .44308 L
.40899 .44803 L
.41807 .45322 L
.42682 .45811 L
.43611 .4632 L
.44506 .46798 L
.45367 .47246 L
.46283 .47708 L
.47166 .48136 L
.48014 .4853 L
.48917 .4893 L
.49786 .49291 L
.50711 .49645 L
.51601 .49953 L
.52457 .5021 L
.53368 .50434 L
.5379 .50516 L
.54246 .50586 L
.54496 .50616 L
.54605 .50627 L
.54726 .50637 L
.54832 .50644 L
.54945 .5065 L
.55008 .50653 L
.55066 .50655 L
.55093 .50656 L
.55123 .50656 L
.55152 .50657 L
.55178 .50657 L
.55203 .50658 L
.5523 .50658 L
.55257 .50658 L
.55286 .50658 L
.55312 .50658 L
.55339 .50657 L
.55365 .50657 L
.55389 .50657 L
.55446 .50655 L
.55508 .50653 L
.55567 .5065 L
.55621 .50647 L
.5573 .5064 L
.5585 .50628 L
.55974 .50613 L
.56092 .50596 L
.5632 .50553 L
.56528 .505 L
Mistroke
.56752 .50429 L
.56996 .50328 L
.57438 .50072 L
.57685 .49869 L
.57909 .49632 L
.58107 .49359 L
.58289 .49028 L
.58384 .48806 L
.58489 .48496 L
.58542 .48299 L
.58598 .48033 L
.58625 .47871 L
.58651 .4768 L
.58674 .47449 L
.587 .46812 L
Mfstroke
4e-05 .17004 m
.01519 .18108 L
.03171 .19308 L
.04723 .20432 L
.06215 .21509 L
.07803 .22652 L
.09332 .23749 L
.10957 .2491 L
.12523 .26024 L
.14029 .27091 L
.15632 .28221 L
.17175 .29303 L
.18658 .30339 L
.20238 .31435 L
.21758 .32483 L
.23375 .33591 L
.24932 .34649 L
.2643 .35659 L
.28023 .36724 L
.29558 .37739 L
.31188 .38805 L
.32759 .3982 L
.34271 .40782 L
.35879 .4179 L
.37348 .42695 L
s
4e-05 .99996 m
.01519 .99996 L
.03171 .99996 L
.04723 .99996 L
.06215 .99996 L
.07803 .99996 L
.09332 .99996 L
.10957 .99996 L
.12523 .99996 L
.14029 .99996 L
.15632 .99996 L
.17175 .99996 L
.18658 .99996 L
.20238 .99996 L
.21758 .99996 L
.23375 .99996 L
.24932 .99996 L
.2643 .99996 L
.28023 .99996 L
.29558 .99996 L
.31188 .99996 L
.32759 .99996 L
.34271 .99996 L
.35879 .99996 L
.37348 .99996 L
s
.5 1 1 r
4e-05 .17004 m
.01519 .18108 L
.03171 .19308 L
.04723 .20432 L
.06215 .21509 L
.07803 .22652 L
.09332 .23749 L
.10957 .2491 L
.12523 .26024 L
.14029 .27091 L
.15632 .28221 L
.17175 .29303 L
.18658 .30339 L
.20238 .31435 L
.21758 .32483 L
.23375 .33591 L
.24932 .34649 L
.2643 .35659 L
.28023 .36724 L
.29558 .37739 L
.31188 .38805 L
.32759 .3982 L
.34271 .40782 L
.35879 .4179 L
.37348 .42695 L
.37348 .99996 L
.35879 .99996 L
.34271 .99996 L
.32759 .99996 L
.31188 .99996 L
.29558 .99996 L
.28023 .99996 L
.2643 .99996 L
.24932 .99996 L
.23375 .99996 L
.21758 .99996 L
.20238 .99996 L
.18658 .99996 L
.17175 .99996 L
.15632 .99996 L
.14029 .99996 L
.12523 .99996 L
.10957 .99996 L
.09332 .99996 L
.07803 .99996 L
.06215 .99996 L
.04723 .99996 L
.03171 .99996 L
.01519 .99996 L
4e-05 .99996 L
F
0 g
4e-05 .17004 m
.01519 .18108 L
.03171 .19308 L
.04723 .20432 L
.06215 .21509 L
.07803 .22652 L
.09332 .23749 L
.10957 .2491 L
.12523 .26024 L
.14029 .27091 L
.15632 .28221 L
.17175 .29303 L
.18658 .30339 L
.20238 .31435 L
.21758 .32483 L
.23375 .33591 L
.24932 .34649 L
.2643 .35659 L
.28023 .36724 L
.29558 .37739 L
.31188 .38805 L
.32759 .3982 L
.34271 .40782 L
.35879 .4179 L
.37348 .42695 L
s
4e-05 .99996 m
.01519 .99996 L
.03171 .99996 L
.04723 .99996 L
.06215 .99996 L
.07803 .99996 L
.09332 .99996 L
.10957 .99996 L
.12523 .99996 L
.14029 .99996 L
.15632 .99996 L
.17175 .99996 L
.18658 .99996 L
.20238 .99996 L
.21758 .99996 L
.23375 .99996 L
.24932 .99996 L
.2643 .99996 L
.28023 .99996 L
.29558 .99996 L
.31188 .99996 L
.32759 .99996 L
.34271 .99996 L
.35879 .99996 L
.37348 .99996 L
s
.37348 4e-05 m
.38214 4e-05 L
.39159 4e-05 L
.40046 4e-05 L
.40899 4e-05 L
.41807 4e-05 L
.42682 4e-05 L
.43611 4e-05 L
.44506 4e-05 L
.45367 4e-05 L
.46283 4e-05 L
.47166 4e-05 L
.48014 4e-05 L
.48917 4e-05 L
.49786 4e-05 L
.50711 4e-05 L
.51601 4e-05 L
.52457 4e-05 L
.53368 4e-05 L
.54246 4e-05 L
.55178 4e-05 L
.56076 4e-05 L
.5694 4e-05 L
.5786 4e-05 L
.587 4e-05 L
s
.37348 4e-05 m
.38214 .01544 L
.39159 .03232 L
.40046 .04824 L
.40899 .06364 L
.41807 .08011 L
.42682 .09606 L
.43611 .11313 L
.44506 .1297 L
.45367 .14576 L
.46283 .16299 L
.47166 .17975 L
.48014 .19603 L
.48917 .21357 L
.49786 .23069 L
.50711 .24919 L
.51601 .26734 L
.52457 .28519 L
.53368 .30468 L
.54246 .32408 L
.55178 .3456 L
.56076 .36761 L
.5694 .39067 L
.57379 .40352 L
.5786 .41923 L
.58069 .42695 L
.58294 .43631 L
.58403 .44152 L
.58506 .44719 L
.58599 .45347 L
.58624 .45559 L
.58651 .45821 L
.58674 .46105 L
.587 .46804 L
s
.5 1 1 r
.37348 4e-05 m
.38214 4e-05 L
.39159 4e-05 L
.40046 4e-05 L
.40899 4e-05 L
.41807 4e-05 L
.42682 4e-05 L
.43611 4e-05 L
.44506 4e-05 L
.45367 4e-05 L
.46283 4e-05 L
.47166 4e-05 L
.48014 4e-05 L
.48917 4e-05 L
.49786 4e-05 L
.50711 4e-05 L
.51601 4e-05 L
.52457 4e-05 L
.53368 4e-05 L
.54246 4e-05 L
.55178 4e-05 L
.56076 4e-05 L
.5694 4e-05 L
.5786 4e-05 L
.587 4e-05 L
.587 .46804 L
.58674 .46105 L
.58651 .45821 L
.58624 .45559 L
.58599 .45347 L
.58506 .44719 L
.58403 .44152 L
.58294 .43631 L
.58069 .42695 L
.5786 .41923 L
.57379 .40352 L
.5694 .39067 L
.56076 .36761 L
.55178 .3456 L
.54246 .32408 L
.53368 .30468 L
.52457 .28519 L
.51601 .26734 L
.50711 .24919 L
.49786 .23069 L
.48917 .21357 L
.48014 .19603 L
.47166 .17975 L
.46283 .16299 L
.45367 .14576 L
.44506 .1297 L
.43611 .11313 L
.42682 .09606 L
.41807 .08011 L
.40899 .06364 L
.40046 .04824 L
.39159 .03232 L
.38214 .01544 L
.37348 4e-05 L
F
0 g
.37348 4e-05 m
.38214 4e-05 L
.39159 4e-05 L
.40046 4e-05 L
.40899 4e-05 L
.41807 4e-05 L
.42682 4e-05 L
.43611 4e-05 L
.44506 4e-05 L
.45367 4e-05 L
.46283 4e-05 L
.47166 4e-05 L
.48014 4e-05 L
.48917 4e-05 L
.49786 4e-05 L
.50711 4e-05 L
.51601 4e-05 L
.52457 4e-05 L
.53368 4e-05 L
.54246 4e-05 L
.55178 4e-05 L
.56076 4e-05 L
.5694 4e-05 L
.5786 4e-05 L
.587 4e-05 L
s
.37348 4e-05 m
.38214 .01544 L
.39159 .03232 L
.40046 .04824 L
.40899 .06364 L
.41807 .08011 L
.42682 .09606 L
.43611 .11313 L
.44506 .1297 L
.45367 .14576 L
.46283 .16299 L
.47166 .17975 L
.48014 .19603 L
.48917 .21357 L
.49786 .23069 L
.50711 .24919 L
.51601 .26734 L
.52457 .28519 L
.53368 .30468 L
.54246 .32408 L
.55178 .3456 L
.56076 .36761 L
.5694 .39067 L
.57379 .40352 L
.5786 .41923 L
.58069 .42695 L
.58294 .43631 L
.58403 .44152 L
.58506 .44719 L
.58599 .45347 L
.58624 .45559 L
.58651 .45821 L
.58674 .46105 L
.587 .46804 L
s
.587 4e-05 m
.60375 4e-05 L
.62202 4e-05 L
.63918 4e-05 L
.65568 4e-05 L
.67325 4e-05 L
.69015 4e-05 L
.70812 4e-05 L
.72544 4e-05 L
.7421 4e-05 L
.75982 4e-05 L
.77688 4e-05 L
.79328 4e-05 L
.81075 4e-05 L
.82757 4e-05 L
.84544 4e-05 L
.86266 4e-05 L
.87922 4e-05 L
.89684 4e-05 L
.91381 4e-05 L
.93184 4e-05 L
.94922 4e-05 L
.96593 4e-05 L
.98371 4e-05 L
.99996 4e-05 L
s
.587 .99996 m
.60375 .99996 L
.62202 .99996 L
.63918 .99996 L
.65568 .99996 L
.67325 .99996 L
.69015 .99996 L
.70812 .99996 L
.72544 .99996 L
.7421 .99996 L
.75982 .99996 L
.77688 .99996 L
.79328 .99996 L
.81075 .99996 L
.82757 .99996 L
.84544 .99996 L
.86266 .99996 L
.87922 .99996 L
.89684 .99996 L
.91381 .99996 L
.93184 .99996 L
.94922 .99996 L
.96593 .99996 L
.98371 .99996 L
.99996 .99996 L
s
.5 1 1 r
.587 4e-05 m
.60375 4e-05 L
.62202 4e-05 L
.63918 4e-05 L
.65568 4e-05 L
.67325 4e-05 L
.69015 4e-05 L
.70812 4e-05 L
.72544 4e-05 L
.7421 4e-05 L
.75982 4e-05 L
.77688 4e-05 L
.79328 4e-05 L
.81075 4e-05 L
.82757 4e-05 L
.84544 4e-05 L
.86266 4e-05 L
.87922 4e-05 L
.89684 4e-05 L
.91381 4e-05 L
.93184 4e-05 L
.94922 4e-05 L
.96593 4e-05 L
.98371 4e-05 L
.99996 4e-05 L
.99996 .99996 L
.98371 .99996 L
.96593 .99996 L
.94922 .99996 L
.93184 .99996 L
.91381 .99996 L
.89684 .99996 L
.87922 .99996 L
.86266 .99996 L
.84544 .99996 L
.82757 .99996 L
.81075 .99996 L
.79328 .99996 L
.77688 .99996 L
.75982 .99996 L
.7421 .99996 L
.72544 .99996 L
.70812 .99996 L
.69015 .99996 L
.67325 .99996 L
.65568 .99996 L
.63918 .99996 L
.62202 .99996 L
.60375 .99996 L
.587 .99996 L
F
0 g
.587 4e-05 m
.60375 4e-05 L
.62202 4e-05 L
.63918 4e-05 L
.65568 4e-05 L
.67325 4e-05 L
.69015 4e-05 L
.70812 4e-05 L
.72544 4e-05 L
.7421 4e-05 L
.75982 4e-05 L
.77688 4e-05 L
.79328 4e-05 L
.81075 4e-05 L
.82757 4e-05 L
.84544 4e-05 L
.86266 4e-05 L
.87922 4e-05 L
.89684 4e-05 L
.91381 4e-05 L
.93184 4e-05 L
.94922 4e-05 L
.96593 4e-05 L
.98371 4e-05 L
.99996 4e-05 L
s
.587 .99996 m
.60375 .99996 L
.62202 .99996 L
.63918 .99996 L
.65568 .99996 L
.67325 .99996 L
.69015 .99996 L
.70812 .99996 L
.72544 .99996 L
.7421 .99996 L
.75982 .99996 L
.77688 .99996 L
.79328 .99996 L
.81075 .99996 L
.82757 .99996 L
.84544 .99996 L
.86266 .99996 L
.87922 .99996 L
.89684 .99996 L
.91381 .99996 L
.93184 .99996 L
.94922 .99996 L
.96593 .99996 L
.98371 .99996 L
.99996 .99996 L
s
.37348 .42695 m
.38214 .4322 L
.39159 .43785 L
.40046 .44308 L
.40899 .44803 L
.41807 .45322 L
.42682 .45811 L
.43611 .4632 L
.44506 .46798 L
.45367 .47246 L
.46283 .47708 L
.47166 .48136 L
.48014 .4853 L
.48917 .4893 L
.49786 .49291 L
.50711 .49645 L
.51601 .49953 L
.52457 .5021 L
.53368 .50434 L
.5379 .50516 L
.54246 .50586 L
.54496 .50616 L
.54605 .50627 L
.54726 .50637 L
.54832 .50644 L
.54945 .5065 L
.55008 .50653 L
.55066 .50655 L
.55093 .50656 L
.55123 .50656 L
.55152 .50657 L
.55178 .50657 L
.55203 .50658 L
.5523 .50658 L
.55257 .50658 L
.55286 .50658 L
.55312 .50658 L
.55339 .50657 L
.55365 .50657 L
.55389 .50657 L
.55446 .50655 L
.55508 .50653 L
.55567 .5065 L
.55621 .50647 L
.5573 .5064 L
.5585 .50628 L
.55974 .50613 L
.56092 .50596 L
.5632 .50553 L
.56528 .505 L
Mistroke
.56752 .50429 L
.56996 .50328 L
.57438 .50072 L
.57685 .49869 L
.57909 .49632 L
.58107 .49359 L
.58289 .49028 L
.58384 .48806 L
.58489 .48496 L
.58542 .48299 L
.58598 .48033 L
.58625 .47871 L
.58651 .4768 L
.58674 .47449 L
.587 .46812 L
Mfstroke
.37348 .99996 m
.38214 .99996 L
.39159 .99996 L
.40046 .99996 L
.40899 .99996 L
.41807 .99996 L
.42682 .99996 L
.43611 .99996 L
.44506 .99996 L
.45367 .99996 L
.46283 .99996 L
.47166 .99996 L
.48014 .99996 L
.48917 .99996 L
.49786 .99996 L
.50711 .99996 L
.51601 .99996 L
.52457 .99996 L
.53368 .99996 L
.54246 .99996 L
.55178 .99996 L
.56076 .99996 L
.5694 .99996 L
.5786 .99996 L
.587 .99996 L
s
.5 1 1 r
.37348 .42695 m
.38214 .4322 L
.39159 .43785 L
.40046 .44308 L
.40899 .44803 L
.41807 .45322 L
.42682 .45811 L
.43611 .4632 L
.44506 .46798 L
.45367 .47246 L
.46283 .47708 L
.47166 .48136 L
.48014 .4853 L
.48917 .4893 L
.49786 .49291 L
.50711 .49645 L
.51601 .49953 L
.52457 .5021 L
.53368 .50434 L
.5379 .50516 L
.54246 .50586 L
.54496 .50616 L
.54605 .50627 L
.54726 .50637 L
.54832 .50644 L
.54945 .5065 L
.55008 .50653 L
.55066 .50655 L
.55093 .50656 L
.55123 .50656 L
.55152 .50657 L
.55178 .50657 L
.55203 .50658 L
.5523 .50658 L
.55257 .50658 L
.55286 .50658 L
.55312 .50658 L
.55339 .50657 L
.55365 .50657 L
.55389 .50657 L
.55446 .50655 L
.55508 .50653 L
.55567 .5065 L
.55621 .50647 L
.5573 .5064 L
.5585 .50628 L
.55974 .50613 L
.56092 .50596 L
.5632 .50553 L
.56528 .505 L
.56752 .50429 L
.56996 .50328 L
.57438 .50072 L
.57685 .49869 L
.57909 .49632 L
.58107 .49359 L
.58289 .49028 L
.58384 .48806 L
.58489 .48496 L
.58542 .48299 L
.58598 .48033 L
.58625 .47871 L
.58651 .4768 L
.58674 .47449 L
.587 .46812 L
.587 .99996 L
.5786 .99996 L
.5694 .99996 L
.56076 .99996 L
.55178 .99996 L
.54246 .99996 L
.53368 .99996 L
.52457 .99996 L
.51601 .99996 L
.50711 .99996 L
.49786 .99996 L
.48917 .99996 L
.48014 .99996 L
.47166 .99996 L
.46283 .99996 L
.45367 .99996 L
.44506 .99996 L
.43611 .99996 L
.42682 .99996 L
.41807 .99996 L
.40899 .99996 L
.40046 .99996 L
.39159 .99996 L
.38214 .99996 L
.37348 .99996 L
F
0 g
.37348 .42695 m
.38214 .4322 L
.39159 .43785 L
.40046 .44308 L
.40899 .44803 L
.41807 .45322 L
.42682 .45811 L
.43611 .4632 L
.44506 .46798 L
.45367 .47246 L
.46283 .47708 L
.47166 .48136 L
.48014 .4853 L
.48917 .4893 L
.49786 .49291 L
.50711 .49645 L
.51601 .49953 L
.52457 .5021 L
.53368 .50434 L
.5379 .50516 L
.54246 .50586 L
.54496 .50616 L
.54605 .50627 L
.54726 .50637 L
.54832 .50644 L
.54945 .5065 L
.55008 .50653 L
.55066 .50655 L
.55093 .50656 L
.55123 .50656 L
.55152 .50657 L
.55178 .50657 L
.55203 .50658 L
.5523 .50658 L
.55257 .50658 L
.55286 .50658 L
.55312 .50658 L
.55339 .50657 L
.55365 .50657 L
.55389 .50657 L
.55446 .50655 L
.55508 .50653 L
.55567 .5065 L
.55621 .50647 L
.5573 .5064 L
.5585 .50628 L
.55974 .50613 L
.56092 .50596 L
.5632 .50553 L
.56528 .505 L
Mistroke
.56752 .50429 L
.56996 .50328 L
.57438 .50072 L
.57685 .49869 L
.57909 .49632 L
.58107 .49359 L
.58289 .49028 L
.58384 .48806 L
.58489 .48496 L
.58542 .48299 L
.58598 .48033 L
.58625 .47871 L
.58651 .4768 L
.58674 .47449 L
.587 .46812 L
Mfstroke
.37348 .99996 m
.38214 .99996 L
.39159 .99996 L
.40046 .99996 L
.40899 .99996 L
.41807 .99996 L
.42682 .99996 L
.43611 .99996 L
.44506 .99996 L
.45367 .99996 L
.46283 .99996 L
.47166 .99996 L
.48014 .99996 L
.48917 .99996 L
.49786 .99996 L
.50711 .99996 L
.51601 .99996 L
.52457 .99996 L
.53368 .99996 L
.54246 .99996 L
.55178 .99996 L
.56076 .99996 L
.5694 .99996 L
.5786 .99996 L
.587 .99996 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 0 r
.02 w
.06278 .03141 Mdot
.06278 .02749 Mdot
.06278 .03533 Mdot
.0667 .04317 Mdot
.0667 .05102 Mdot
.07062 .05494 Mdot
.07062 .05102 Mdot
.08239 .05102 Mdot
.07846 .04709 Mdot
.08239 .05102 Mdot
.08631 .05494 Mdot
.07454 .05102 Mdot
.07846 .04709 Mdot
.07454 .04709 Mdot
.0667 .04317 Mdot
.0667 .05102 Mdot
.0667 .04709 Mdot
.07454 .05102 Mdot
.07846 .05102 Mdot
.0667 .04317 Mdot
.0667 .04317 Mdot
.06278 .04317 Mdot
.05494 .03925 Mdot
.05494 .04317 Mdot
.06278 .05102 Mdot
.06278 .05886 Mdot
.0667 .05886 Mdot
.06278 .05886 Mdot
.07062 .05886 Mdot
.07454 .05886 Mdot
.08239 .05886 Mdot
.07846 .05494 Mdot
.07846 .05102 Mdot
.07454 .04709 Mdot
.08239 .05886 Mdot
.08631 .06278 Mdot
.08631 .06278 Mdot
.07846 .05494 Mdot
.07846 .05102 Mdot
.08239 .05886 Mdot
.07846 .05494 Mdot
.07846 .05102 Mdot
.07062 .05494 Mdot
.07454 .0667 Mdot
.07846 .06278 Mdot
.07454 .05886 Mdot
.07454 .05102 Mdot
.07454 .04709 Mdot
.07846 .05102 Mdot
.08239 .05102 Mdot
.09023 .05886 Mdot
.09023 .05886 Mdot
.09023 .06278 Mdot
.09415 .07846 Mdot
.08631 .07454 Mdot
.09023 .08239 Mdot
.09023 .07846 Mdot
.08631 .07454 Mdot
.07846 .07062 Mdot
.07846 .07062 Mdot
.07846 .07062 Mdot
.07062 .06278 Mdot
.0667 .05494 Mdot
.07062 .05102 Mdot
.07062 .05102 Mdot
.07062 .04709 Mdot
.07846 .05494 Mdot
.07846 .06278 Mdot
.08239 .0667 Mdot
.08239 .07454 Mdot
.08239 .07454 Mdot
.09023 .07846 Mdot
.09023 .07846 Mdot
.07846 .06278 Mdot
.07846 .0667 Mdot
.07454 .06278 Mdot
.07846 .0667 Mdot
.08631 .07454 Mdot
.09023 .07454 Mdot
.09023 .0667 Mdot
.08239 .05886 Mdot
.08631 .07062 Mdot
.08239 .0667 Mdot
.08239 .0667 Mdot
.08239 .07062 Mdot
.08239 .0667 Mdot
.09023 .0667 Mdot
.08631 .05494 Mdot
.08631 .05886 Mdot
.08631 .0667 Mdot
.08631 .06278 Mdot
.09023 .06278 Mdot
.08631 .06278 Mdot
.08631 .07062 Mdot
.08239 .07062 Mdot
.08631 .07846 Mdot
.07846 .07454 Mdot
.07846 .07454 Mdot
.07454 .0667 Mdot
.07454 .06278 Mdot
.08631 .0667 Mdot
.07846 .05886 Mdot
.07454 .05102 Mdot
.07454 .05494 Mdot
.07062 .04709 Mdot
.07454 .05102 Mdot
.06278 .05102 Mdot
.0667 .05886 Mdot
.07062 .05102 Mdot
.0667 .05102 Mdot
.07846 .05886 Mdot
.07454 .05886 Mdot
.07062 .05494 Mdot
.0667 .05102 Mdot
.07062 .05886 Mdot
.0667 .05494 Mdot
.0667 .04709 Mdot
.05494 .03533 Mdot
.05886 .03533 Mdot
.05494 .03925 Mdot
.05494 .03925 Mdot
.05886 .03925 Mdot
.06278 .04709 Mdot
.05494 .04709 Mdot
.05102 .04317 Mdot
.04709 .03533 Mdot
.04317 .02749 Mdot
.03925 .02357 Mdot
.04709 .03141 Mdot
.04317 .03141 Mdot
.04317 .02357 Mdot
.04317 .02749 Mdot
.05494 .04317 Mdot
.04709 .05102 Mdot
.04317 .0667 Mdot
.04317 .0667 Mdot
.05102 .0667 Mdot
.04709 .05494 Mdot
.04709 .03925 Mdot
.04317 .03925 Mdot
.03533 .03925 Mdot
.03533 .04317 Mdot
.03533 .05102 Mdot
.04709 .07062 Mdot
.00396 .02749 Mdot
.00396 .01572 Mdot
.00788 .0118 Mdot
.00396 .01572 Mdot
.00788 .02357 Mdot
.00788 .02749 Mdot
.00788 .03141 Mdot
.0118 .03141 Mdot
.0118 .02357 Mdot
.0118 .01965 Mdot
.00788 .02357 Mdot
.00396 .01965 Mdot
.00788 .01572 Mdot
.01572 .01572 Mdot
.01572 .01572 Mdot
.01965 .0118 Mdot
.08631 .08631 Mdot
.10591 .10591 Mdot
.11768 .11768 Mdot
.11768 .1216 Mdot
.11376 .12944 Mdot
.11768 .14513 Mdot
.1216 .12944 Mdot
.11768 .10983 Mdot
.10591 .09023 Mdot
.10199 .08239 Mdot
.10983 .07846 Mdot
.11768 .08239 Mdot
.12552 .08631 Mdot
.1216 .08239 Mdot
.1216 .07846 Mdot
.11768 .07454 Mdot
.1216 .07846 Mdot
.11768 .07846 Mdot
.11768 .07846 Mdot
.1216 .08239 Mdot
.1216 .08631 Mdot
.11768 .08239 Mdot
.10199 .07454 Mdot
.10983 .08239 Mdot
.10591 .07846 Mdot
.10199 .07846 Mdot
.10591 .08239 Mdot
.11376 .09415 Mdot
.12552 .10199 Mdot
.12944 .10983 Mdot
.12552 .10591 Mdot
.12944 .10591 Mdot
.13336 .10199 Mdot
.13336 .09807 Mdot
.12944 .09807 Mdot
.11768 .09807 Mdot
.12552 .10199 Mdot
.13336 .10591 Mdot
.13728 .10199 Mdot
.14513 .10983 Mdot
.13728 .10199 Mdot
.14513 .10591 Mdot
.13728 .09807 Mdot
.13728 .10591 Mdot
.14905 .10983 Mdot
.1412 .10199 Mdot
.13728 .10199 Mdot
.1412 .10591 Mdot
.14905 .10983 Mdot
.15297 .10983 Mdot
.16473 .11768 Mdot
.15689 .11768 Mdot
.15689 .12944 Mdot
.1412 .1216 Mdot
.14513 .1216 Mdot
.14905 .12944 Mdot
.13728 .11376 Mdot
.14905 .1216 Mdot
.14905 .11376 Mdot
.15297 .11376 Mdot
.15689 .1216 Mdot
.14905 .11768 Mdot
.15689 .1216 Mdot
.15297 .11376 Mdot
.14905 .10983 Mdot
.14513 .10591 Mdot
.14905 .10983 Mdot
.14905 .11376 Mdot
.15297 .11768 Mdot
.14905 .12944 Mdot
.13336 .11376 Mdot
.1412 .10591 Mdot
.14905 .10983 Mdot
.14513 .10983 Mdot
.15297 .11768 Mdot
.14905 .10983 Mdot
.14513 .10983 Mdot
.16865 .12552 Mdot
.14905 .10591 Mdot
.14905 .10199 Mdot
.15689 .11376 Mdot
.17257 .12944 Mdot
.1412 .09807 Mdot
.16081 .11376 Mdot
.14905 .10983 Mdot
.15689 .11768 Mdot
.16081 .1216 Mdot
.1765 .12552 Mdot
.1765 .12944 Mdot
.17257 .12552 Mdot
.17257 .13336 Mdot
.17257 .12944 Mdot
.1765 .14513 Mdot
.16081 .12944 Mdot
.15297 .11376 Mdot
.14513 .10199 Mdot
.14905 .10591 Mdot
.14513 .10983 Mdot
.15689 .11376 Mdot
.16473 .11376 Mdot
.16473 .11376 Mdot
.16473 .11768 Mdot
.16473 .1216 Mdot
.15689 .1216 Mdot
.16081 .12552 Mdot
.16473 .13728 Mdot
.13728 .11768 Mdot
.13336 .10983 Mdot
.12944 .09415 Mdot
.1216 .09023 Mdot
.12944 .09415 Mdot
.13336 .10199 Mdot
.12552 .10591 Mdot
.12552 .10591 Mdot
.13336 .10591 Mdot
.12552 .09807 Mdot
.1216 .08631 Mdot
.10591 .07062 Mdot
.1412 .09415 Mdot
.12944 .08631 Mdot
.13336 .08631 Mdot
.13336 .08631 Mdot
.12944 .07846 Mdot
.10983 .07062 Mdot
.10591 .0667 Mdot
.11376 .0667 Mdot
.11376 .0667 Mdot
.10591 .06278 Mdot
.10199 .0667 Mdot
.10591 .07062 Mdot
.09807 .0667 Mdot
.10591 .07062 Mdot
.09807 .07454 Mdot
.09023 .08239 Mdot
.09023 .08631 Mdot
.11768 .12944 Mdot
.04709 .08631 Mdot
.05102 .07454 Mdot
.05102 .05102 Mdot
.03533 .03141 Mdot
.03533 .02749 Mdot
.07846 .06278 Mdot
.05102 .04317 Mdot
.00396 .00396 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00788 .0118 Mdot
.00788 .01572 Mdot
.00396 .01572 Mdot
.00396 .01572 Mdot
.00396 .0118 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00788 .00396 Mdot
.01572 .00396 Mdot
.01965 .00396 Mdot
.59215 .59607 Mdot
.61176 .62352 Mdot
.62352 .63528 Mdot
.62352 .63136 Mdot
.4902 .49804 Mdot
.12552 .16865 Mdot
.09807 .1216 Mdot
.09807 .10591 Mdot
.0667 .0667 Mdot
.05886 .04709 Mdot
.05886 .03533 Mdot
.07454 .04317 Mdot
.09415 .05494 Mdot
.09807 .05494 Mdot
.10199 .05886 Mdot
.10591 .05494 Mdot
.10983 .05886 Mdot
.10591 .05886 Mdot
.10983 .05886 Mdot
.11376 .06278 Mdot
.10199 .06278 Mdot
.10983 .07454 Mdot
.10983 .07846 Mdot
.1216 .08631 Mdot
.11768 .09023 Mdot
.11376 .09023 Mdot
.1216 .10199 Mdot
.11768 .09807 Mdot
.11768 .09807 Mdot
.1216 .10591 Mdot
.12552 .10591 Mdot
.12944 .10591 Mdot
.12944 .09807 Mdot
.12944 .09415 Mdot
.12552 .09023 Mdot
.11768 .08239 Mdot
.1216 .09023 Mdot
.10983 .08239 Mdot
.11768 .07846 Mdot
.13336 .08631 Mdot
.13728 .09415 Mdot
.1412 .09415 Mdot
.13336 .08631 Mdot
.13728 .09415 Mdot
.1412 .09807 Mdot
.1216 .07846 Mdot
.12552 .08239 Mdot
.12944 .08631 Mdot
.13336 .09807 Mdot
.13336 .09807 Mdot
.14513 .10199 Mdot
.14905 .11768 Mdot
.14905 .12944 Mdot
.1412 .12552 Mdot
.14905 .13336 Mdot
.1412 .12552 Mdot
.14513 .11376 Mdot
.15297 .10983 Mdot
.15689 .10591 Mdot
.16081 .09807 Mdot
.16081 .09807 Mdot
.16473 .1216 Mdot
.16081 .1216 Mdot
.16081 .11768 Mdot
.16081 .11376 Mdot
.16081 .11376 Mdot
.15297 .10591 Mdot
.16473 .11376 Mdot
.16081 .11376 Mdot
.15297 .11376 Mdot
.15297 .11376 Mdot
.16081 .11376 Mdot
.16473 .11376 Mdot
.16081 .10591 Mdot
.16081 .11768 Mdot
.14513 .10199 Mdot
.15689 .10199 Mdot
.16081 .09807 Mdot
.16865 .10199 Mdot
.16473 .09807 Mdot
.16081 .09415 Mdot
.15297 .09807 Mdot
.14513 .09023 Mdot
.14905 .09807 Mdot
.14905 .10591 Mdot
.14513 .10199 Mdot
.15297 .10591 Mdot
.15689 .11768 Mdot
.16865 .13336 Mdot
.17257 .13336 Mdot
.18042 .13336 Mdot
.18434 .13728 Mdot
.1765 .13728 Mdot
.16473 .12552 Mdot
.16865 .12552 Mdot
.17257 .12552 Mdot
.16473 .11768 Mdot
.18434 .12944 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.18042 .13336 Mdot
.19218 .14905 Mdot
.19218 .15689 Mdot
.18042 .1412 Mdot
.18434 .14513 Mdot
.18434 .14905 Mdot
.1765 .14513 Mdot
.16865 .13728 Mdot
.15689 .12552 Mdot
.16473 .13336 Mdot
.16865 .13336 Mdot
.18042 .1412 Mdot
.1765 .14513 Mdot
.15297 .12552 Mdot
.15297 .11768 Mdot
.14905 .10983 Mdot
.1412 .10199 Mdot
.14905 .10983 Mdot
.14513 .10199 Mdot
.1412 .09023 Mdot
.14513 .08239 Mdot
.15297 .09415 Mdot
.14513 .09023 Mdot
.14513 .09023 Mdot
.14513 .08631 Mdot
.13728 .08239 Mdot
.14513 .09415 Mdot
.1412 .09415 Mdot
.13336 .09023 Mdot
.13728 .09807 Mdot
.1216 .08631 Mdot
.12552 .08631 Mdot
.12552 .08239 Mdot
.12944 .07846 Mdot
.10591 .05886 Mdot
.10983 .06278 Mdot
.10591 .05102 Mdot
.09023 .04709 Mdot
.09023 .07062 Mdot
.09023 .07846 Mdot
.08239 .07846 Mdot
.09415 .08239 Mdot
.10199 .07846 Mdot
.08631 .05102 Mdot
.08239 .04709 Mdot
.08239 .05494 Mdot
.07454 .05102 Mdot
.07062 .05102 Mdot
.09023 .05886 Mdot
.09415 .06278 Mdot
.09023 .07062 Mdot
.07846 .0667 Mdot
.07846 .07062 Mdot
.07454 .06278 Mdot
.07846 .07454 Mdot
.07846 .07846 Mdot
.08239 .07454 Mdot
.08631 .07062 Mdot
.08239 .0667 Mdot
.08631 .07062 Mdot
.59215 .61176 Mdot
.61568 .64705 Mdot
.63136 .64705 Mdot
.62352 .63136 Mdot
.59999 .60391 Mdot
.25492 .28629 Mdot
.07062 .09415 Mdot
.09807 .10591 Mdot
.08631 .09023 Mdot
.07454 .07062 Mdot
.08239 .06278 Mdot
.08631 .05494 Mdot
.10199 .05886 Mdot
.10199 .05494 Mdot
.09415 .05494 Mdot
.09807 .05494 Mdot
.10591 .05886 Mdot
.11768 .07062 Mdot
.1216 .0667 Mdot
.1216 .0667 Mdot
.1216 .07846 Mdot
.1216 .08239 Mdot
.1216 .09807 Mdot
.12552 .10591 Mdot
.12944 .10591 Mdot
.12944 .10591 Mdot
.12552 .10983 Mdot
.10591 .09415 Mdot
.11376 .10199 Mdot
.11768 .10591 Mdot
.1216 .10591 Mdot
.1216 .10199 Mdot
.1216 .09415 Mdot
.1216 .09415 Mdot
.1216 .08239 Mdot
.12944 .08631 Mdot
.1412 .10199 Mdot
.1412 .09807 Mdot
.12944 .09023 Mdot
.13336 .09023 Mdot
.14513 .09023 Mdot
.14513 .09415 Mdot
.14513 .09023 Mdot
.1412 .09415 Mdot
.14513 .09807 Mdot
.1412 .09415 Mdot
.13336 .09023 Mdot
.1412 .09807 Mdot
.13728 .10591 Mdot
.13336 .10199 Mdot
.1412 .10591 Mdot
.15689 .12944 Mdot
.14905 .13336 Mdot
.1412 .12552 Mdot
.13728 .11768 Mdot
.14905 .11768 Mdot
.15297 .10591 Mdot
.16081 .09415 Mdot
.16865 .09415 Mdot
.16473 .09023 Mdot
.17257 .10591 Mdot
.1961 .13336 Mdot
.18826 .12944 Mdot
.1765 .12944 Mdot
.1961 .1412 Mdot
.18434 .13336 Mdot
.18042 .12552 Mdot
.18042 .12552 Mdot
.15689 .11376 Mdot
.14513 .10983 Mdot
.14513 .10983 Mdot
.14905 .10983 Mdot
.18826 .13728 Mdot
.16473 .11768 Mdot
.14513 .10199 Mdot
.14905 .10199 Mdot
.15297 .09415 Mdot
.16081 .09807 Mdot
.15297 .09023 Mdot
.15297 .09023 Mdot
.15689 .09415 Mdot
.16081 .10199 Mdot
.14905 .09023 Mdot
.14513 .09023 Mdot
.14905 .10591 Mdot
.14905 .11376 Mdot
.15297 .11376 Mdot
.16081 .12944 Mdot
.16081 .12944 Mdot
.16865 .1412 Mdot
.1765 .14513 Mdot
.18042 .14513 Mdot
.17257 .13728 Mdot
.17257 .12944 Mdot
.15297 .10983 Mdot
.15689 .10983 Mdot
.16865 .10983 Mdot
.1765 .11376 Mdot
.18042 .11768 Mdot
.18434 .1216 Mdot
.16865 .11768 Mdot
.18042 .13336 Mdot
.18434 .13728 Mdot
.18042 .12944 Mdot
.18042 .13728 Mdot
.20002 .14905 Mdot
.19218 .14513 Mdot
.17257 .13728 Mdot
.17257 .14513 Mdot
.16865 .14513 Mdot
.16865 .13728 Mdot
.18042 .13728 Mdot
.1765 .13728 Mdot
.16473 .12944 Mdot
.15689 .10983 Mdot
.15297 .10591 Mdot
.15297 .10591 Mdot
.14905 .10199 Mdot
.15297 .10199 Mdot
.15297 .10199 Mdot
.15689 .10199 Mdot
.15297 .10199 Mdot
.15297 .10199 Mdot
.14513 .09415 Mdot
.14513 .09415 Mdot
.15297 .10591 Mdot
.14905 .10591 Mdot
.13728 .10591 Mdot
.13336 .10199 Mdot
.13336 .10199 Mdot
.12552 .09807 Mdot
.1216 .09023 Mdot
.12552 .09023 Mdot
.12552 .09415 Mdot
.1216 .09023 Mdot
.1216 .09023 Mdot
.12944 .09415 Mdot
.11376 .08239 Mdot
.09415 .07062 Mdot
.09415 .08239 Mdot
.09023 .08239 Mdot
.08631 .07846 Mdot
.08239 .07062 Mdot
.09023 .06278 Mdot
.09415 .06278 Mdot
.09807 .0667 Mdot
.09023 .05494 Mdot
.09415 .06278 Mdot
.10199 .07062 Mdot
.09807 .07846 Mdot
.09807 .08239 Mdot
.08239 .08239 Mdot
.08239 .07846 Mdot
.08239 .08239 Mdot
.09023 .08631 Mdot
.08631 .08239 Mdot
.09023 .08239 Mdot
.09415 .08631 Mdot
.09023 .08239 Mdot
.08239 .07062 Mdot
.58039 .60783 Mdot
.62352 .65881 Mdot
.63528 .66273 Mdot
.62352 .63528 Mdot
.61568 .62744 Mdot
.42746 .44706 Mdot
.1216 .15297 Mdot
.10983 .12552 Mdot
.09023 .09415 Mdot
.07454 .07454 Mdot
.07846 .0667 Mdot
.08239 .06278 Mdot
.09023 .06278 Mdot
.10199 .0667 Mdot
.11376 .07062 Mdot
.11768 .08239 Mdot
.11768 .07454 Mdot
.12944 .08631 Mdot
.13336 .08631 Mdot
.13728 .08631 Mdot
.13728 .09807 Mdot
.13336 .10983 Mdot
.12944 .10983 Mdot
.1216 .10591 Mdot
.11768 .09807 Mdot
.10983 .09807 Mdot
.1216 .11376 Mdot
.10983 .10199 Mdot
.11376 .09807 Mdot
.11376 .09415 Mdot
.11768 .09415 Mdot
.1216 .09415 Mdot
.1216 .08239 Mdot
.1216 .07846 Mdot
.1216 .07454 Mdot
.13336 .08631 Mdot
.14513 .09023 Mdot
.13728 .07846 Mdot
.1412 .08239 Mdot
.14905 .09807 Mdot
.14905 .10199 Mdot
.14513 .09807 Mdot
.1412 .09807 Mdot
.14905 .10199 Mdot
.15297 .10983 Mdot
.14905 .10591 Mdot
.14905 .09807 Mdot
.14905 .10199 Mdot
.1412 .09807 Mdot
.14513 .10199 Mdot
.14513 .10199 Mdot
.15297 .1216 Mdot
.14513 .12552 Mdot
.13336 .1216 Mdot
.12944 .11376 Mdot
.14905 .11768 Mdot
.16081 .11376 Mdot
.1765 .10199 Mdot
.17257 .10199 Mdot
.18042 .10983 Mdot
.18042 .11376 Mdot
.18042 .11768 Mdot
.1961 .13728 Mdot
.18434 .13336 Mdot
.18826 .13728 Mdot
.18826 .1412 Mdot
.18826 .13728 Mdot
.19218 .1412 Mdot
.17257 .12944 Mdot
.16081 .12552 Mdot
.16473 .13336 Mdot
.15689 .1216 Mdot
.14905 .10199 Mdot
.14905 .10199 Mdot
.14905 .10199 Mdot
.1412 .09023 Mdot
.15297 .09415 Mdot
.15689 .09415 Mdot
.16473 .09807 Mdot
.16865 .10199 Mdot
.16865 .10983 Mdot
.16865 .11768 Mdot
.16081 .10983 Mdot
.15689 .10983 Mdot
.14513 .10983 Mdot
.14905 .1216 Mdot
.14905 .1216 Mdot
.16473 .1412 Mdot
.15689 .13336 Mdot
.16473 .1412 Mdot
.1765 .14513 Mdot
.18042 .14513 Mdot
.16865 .13336 Mdot
.16473 .12944 Mdot
.16865 .1216 Mdot
.1765 .11376 Mdot
.18042 .11376 Mdot
.19218 .12552 Mdot
.18434 .12552 Mdot
.16865 .11768 Mdot
.1765 .13336 Mdot
.1765 .13728 Mdot
.18434 .14905 Mdot
.18434 .15297 Mdot
.18434 .14513 Mdot
.18434 .1412 Mdot
.19218 .14905 Mdot
.19218 .14905 Mdot
.18826 .14905 Mdot
.18434 .15297 Mdot
.18042 .1412 Mdot
.18042 .13336 Mdot
.1765 .1216 Mdot
.18042 .12552 Mdot
.18042 .1216 Mdot
.1765 .1216 Mdot
.16865 .11768 Mdot
.16081 .11376 Mdot
.16081 .11376 Mdot
.16473 .1216 Mdot
.16473 .1216 Mdot
.15689 .12552 Mdot
.14905 .11768 Mdot
.15689 .11768 Mdot
.14905 .10983 Mdot
.14513 .10591 Mdot
.14513 .10983 Mdot
.13728 .10591 Mdot
.13728 .10591 Mdot
.1412 .10591 Mdot
.12552 .09415 Mdot
.12552 .09415 Mdot
.12552 .09023 Mdot
.1412 .09415 Mdot
.13336 .07846 Mdot
.13336 .09023 Mdot
.12552 .09023 Mdot
.11768 .08631 Mdot
.10591 .08631 Mdot
.09807 .08631 Mdot
.09023 .07846 Mdot
.09023 .07454 Mdot
.09415 .07454 Mdot
.09807 .06278 Mdot
.10591 .05886 Mdot
.10591 .05886 Mdot
.10591 .06278 Mdot
.10591 .0667 Mdot
.11376 .08239 Mdot
.10983 .07846 Mdot
.10983 .09023 Mdot
.10199 .09807 Mdot
.09023 .09023 Mdot
.09415 .08631 Mdot
.09807 .09023 Mdot
.09023 .08239 Mdot
.09415 .08239 Mdot
.10199 .07846 Mdot
.09023 .06278 Mdot
.09415 .05886 Mdot
.45491 .43922 Mdot
.59215 .57254 Mdot
.60391 .59999 Mdot
.6196 .62352 Mdot
.6196 .62352 Mdot
.5647 .55686 Mdot
.26276 .27453 Mdot
.0667 .08239 Mdot
.09807 .09807 Mdot
.06278 .05886 Mdot
.05886 .04709 Mdot
.07062 .05102 Mdot
.08239 .06278 Mdot
.09415 .0667 Mdot
.10199 .07454 Mdot
.10983 .08631 Mdot
.11768 .08631 Mdot
.12944 .10199 Mdot
.13336 .10591 Mdot
.14513 .10983 Mdot
.13728 .10199 Mdot
.13728 .10983 Mdot
.12944 .10199 Mdot
.12944 .09807 Mdot
.12944 .09415 Mdot
.1216 .08239 Mdot
.11376 .08239 Mdot
.11768 .08631 Mdot
.1216 .09023 Mdot
.11376 .07846 Mdot
.1216 .08239 Mdot
.1216 .08239 Mdot
.13728 .09415 Mdot
.14905 .10199 Mdot
.14513 .10199 Mdot
.12552 .09415 Mdot
.14513 .10983 Mdot
.14513 .10199 Mdot
.1412 .10199 Mdot
.15689 .11768 Mdot
.15689 .11376 Mdot
.15689 .10983 Mdot
.15689 .10983 Mdot
.15689 .10983 Mdot
.14513 .10199 Mdot
.15689 .10199 Mdot
.15689 .09807 Mdot
.15297 .10591 Mdot
.13728 .09023 Mdot
.13336 .09023 Mdot
.1216 .09415 Mdot
.12552 .10591 Mdot
.12944 .11768 Mdot
.12944 .12552 Mdot
.14513 .12944 Mdot
.16081 .13336 Mdot
.15297 .11768 Mdot
.16081 .10983 Mdot
.1765 .11768 Mdot
.18042 .1216 Mdot
.18042 .12944 Mdot
.18042 .12552 Mdot
.18826 .13336 Mdot
.1765 .12552 Mdot
.18434 .13728 Mdot
.18434 .14905 Mdot
.18434 .1412 Mdot
.19218 .13336 Mdot
.18826 .12552 Mdot
.18434 .1216 Mdot
.18434 .12944 Mdot
.16081 .11376 Mdot
.15689 .10591 Mdot
.15689 .10591 Mdot
.14905 .09415 Mdot
.14905 .08631 Mdot
.15689 .09023 Mdot
.16865 .10591 Mdot
.16865 .10983 Mdot
.17257 .11768 Mdot
.16081 .11768 Mdot
.16081 .11768 Mdot
.15689 .12552 Mdot
.15297 .1216 Mdot
.14513 .10983 Mdot
.14513 .10591 Mdot
.14513 .09415 Mdot
.16081 .11768 Mdot
.16865 .12552 Mdot
.17257 .12944 Mdot
.17257 .12944 Mdot
.17257 .12552 Mdot
.16865 .12552 Mdot
.18042 .13728 Mdot
.1765 .13336 Mdot
.18826 .1412 Mdot
.20002 .14905 Mdot
.1961 .14905 Mdot
.19218 .15689 Mdot
.18434 .16081 Mdot
.18826 .16865 Mdot
.1765 .15689 Mdot
.1765 .15689 Mdot
.1765 .14905 Mdot
.18042 .14905 Mdot
.18434 .15297 Mdot
.1765 .14905 Mdot
.18042 .13728 Mdot
.18042 .13336 Mdot
.18042 .13336 Mdot
.1765 .12552 Mdot
.18434 .12552 Mdot
.18826 .1216 Mdot
.19218 .12944 Mdot
.1961 .13336 Mdot
.19218 .1412 Mdot
.18826 .14905 Mdot
.1765 .14513 Mdot
.16473 .13728 Mdot
.15297 .12944 Mdot
.16473 .13728 Mdot
.14905 .12552 Mdot
.14905 .12552 Mdot
.15297 .11376 Mdot
.15689 .10983 Mdot
.15297 .10983 Mdot
.1412 .09807 Mdot
.1412 .09415 Mdot
.13728 .09415 Mdot
.13728 .09415 Mdot
.13336 .08631 Mdot
.13728 .08239 Mdot
.13728 .07846 Mdot
.13728 .07454 Mdot
.12944 .07454 Mdot
.11768 .07846 Mdot
.1216 .09023 Mdot
.11376 .09023 Mdot
.10199 .09023 Mdot
.10199 .09023 Mdot
.09807 .07454 Mdot
.09023 .0667 Mdot
.09023 .06278 Mdot
.09415 .04709 Mdot
.09023 .03925 Mdot
.09415 .04317 Mdot
.09415 .05102 Mdot
.09415 .05886 Mdot
.10591 .07846 Mdot
.10983 .08239 Mdot
.09807 .07846 Mdot
.10591 .08239 Mdot
.10591 .08631 Mdot
.10199 .08239 Mdot
.09807 .08239 Mdot
.09415 .07454 Mdot
.09023 .06278 Mdot
.09415 .06278 Mdot
.09415 .06278 Mdot
.08239 .04709 Mdot
.15689 .13336 Mdot
.25884 .23139 Mdot
.34119 .30982 Mdot
.47451 .42746 Mdot
.52157 .47843 Mdot
.58431 .54117 Mdot
.38824 .35295 Mdot
.05886 .05102 Mdot
.07062 .05886 Mdot
.05886 .04709 Mdot
.05102 .04709 Mdot
.05494 .05102 Mdot
.07454 .06278 Mdot
.08631 .06278 Mdot
.09415 .07062 Mdot
.10199 .07454 Mdot
.10983 .08239 Mdot
.12552 .09023 Mdot
.12552 .09807 Mdot
.13728 .09023 Mdot
.13336 .08631 Mdot
.12944 .08631 Mdot
.13728 .09807 Mdot
.14513 .10591 Mdot
.1412 .10591 Mdot
.14513 .10591 Mdot
.13336 .09023 Mdot
.13728 .09023 Mdot
.1412 .09415 Mdot
.13728 .08631 Mdot
.13728 .08631 Mdot
.13336 .09023 Mdot
.14513 .10199 Mdot
.13728 .10199 Mdot
.13336 .10983 Mdot
.13336 .11376 Mdot
.13336 .10591 Mdot
.13336 .10199 Mdot
.1412 .10591 Mdot
.13728 .10591 Mdot
.14513 .10591 Mdot
.14905 .10591 Mdot
.16473 .11376 Mdot
.16865 .10983 Mdot
.15689 .10199 Mdot
.14513 .09807 Mdot
.15297 .10591 Mdot
.14905 .10199 Mdot
.1412 .10199 Mdot
.13728 .10199 Mdot
.13728 .11376 Mdot
.13336 .11376 Mdot
.14905 .13336 Mdot
.13728 .11768 Mdot
.1412 .11376 Mdot
.14513 .11768 Mdot
.15689 .1216 Mdot
.15689 .10983 Mdot
.15297 .09807 Mdot
.17257 .10591 Mdot
.1765 .10983 Mdot
.17257 .11768 Mdot
.1765 .12552 Mdot
.1765 .12552 Mdot
.18042 .13728 Mdot
.18042 .1412 Mdot
.1961 .16081 Mdot
.20002 .15297 Mdot
.20002 .13336 Mdot
.20002 .12944 Mdot
.18042 .10983 Mdot
.18826 .11768 Mdot
.17257 .11768 Mdot
.16081 .10983 Mdot
.14905 .09807 Mdot
.1412 .09807 Mdot
.14905 .10199 Mdot
.1412 .10591 Mdot
.14905 .10983 Mdot
.14513 .09807 Mdot
.15689 .10983 Mdot
.15297 .11376 Mdot
.15689 .11768 Mdot
.15689 .11376 Mdot
.15689 .10983 Mdot
.15297 .10199 Mdot
.14905 .09023 Mdot
.16865 .10591 Mdot
.18042 .11768 Mdot
.17257 .11376 Mdot
.1765 .12552 Mdot
.18042 .12944 Mdot
.16865 .12552 Mdot
.17257 .13336 Mdot
.17257 .13336 Mdot
.18042 .13336 Mdot
.19218 .1412 Mdot
.19218 .14513 Mdot
.20394 .16081 Mdot
.1961 .16473 Mdot
.19218 .16865 Mdot
.18434 .16081 Mdot
.1765 .14513 Mdot
.17257 .13336 Mdot
.18042 .13728 Mdot
.17257 .13728 Mdot
.1765 .14513 Mdot
.19218 .14905 Mdot
.19218 .1412 Mdot
.18434 .13336 Mdot
.17257 .1216 Mdot
.18826 .13336 Mdot
.1961 .13336 Mdot
.20394 .12944 Mdot
.20002 .13336 Mdot
.18826 .12944 Mdot
.16473 .11768 Mdot
.1765 .12944 Mdot
.15297 .11376 Mdot
.15689 .11376 Mdot
.15689 .11376 Mdot
.14513 .10983 Mdot
.14513 .10591 Mdot
.13728 .09023 Mdot
.14513 .08631 Mdot
.15689 .09415 Mdot
.15297 .10199 Mdot
.14513 .09415 Mdot
.1412 .09023 Mdot
.14513 .09807 Mdot
.13728 .08631 Mdot
.1412 .08631 Mdot
.13336 .08239 Mdot
.12944 .07454 Mdot
.10983 .06278 Mdot
.11376 .07846 Mdot
.11768 .08631 Mdot
.10591 .08631 Mdot
.10199 .09023 Mdot
.09807 .08239 Mdot
.09415 .0667 Mdot
.09415 .06278 Mdot
.07454 .04709 Mdot
.09023 .05886 Mdot
.07846 .03925 Mdot
.07454 .03533 Mdot
.07454 .03141 Mdot
.09023 .05102 Mdot
.09415 .06278 Mdot
.09807 .0667 Mdot
.09807 .0667 Mdot
.11376 .08631 Mdot
.10591 .08239 Mdot
.10199 .07846 Mdot
.09807 .07062 Mdot
.09807 .0667 Mdot
.08631 .04317 Mdot
.08631 .03141 Mdot
.09023 .03925 Mdot
.07846 .03925 Mdot
.09807 .07454 Mdot
.12552 .10199 Mdot
.1216 .09415 Mdot
.13336 .10199 Mdot
.21963 .16473 Mdot
.32943 .26276 Mdot
.30198 .24316 Mdot
.13336 .09415 Mdot
.13728 .11376 Mdot
.11376 .09415 Mdot
.09023 .07846 Mdot
.07846 .06278 Mdot
.09415 .07454 Mdot
.09415 .07062 Mdot
.09415 .07846 Mdot
.10983 .08631 Mdot
.1216 .09023 Mdot
.12552 .09415 Mdot
.13728 .10199 Mdot
.13728 .10199 Mdot
.13728 .10199 Mdot
.13728 .10199 Mdot
.1412 .11376 Mdot
.15297 .11768 Mdot
.15297 .11768 Mdot
.15297 .11768 Mdot
.14513 .10591 Mdot
.14513 .09807 Mdot
.1412 .08631 Mdot
.12552 .07454 Mdot
.13728 .07846 Mdot
.13728 .08239 Mdot
.13728 .09023 Mdot
.1412 .10591 Mdot
.1412 .10983 Mdot
.14905 .12944 Mdot
.14513 .12552 Mdot
.13728 .11768 Mdot
.14513 .12552 Mdot
.15297 .12944 Mdot
.15689 .12552 Mdot
.15297 .11768 Mdot
.14905 .10591 Mdot
.16081 .10983 Mdot
.16473 .10591 Mdot
.15297 .09807 Mdot
.15689 .10591 Mdot
.16865 .1216 Mdot
.16081 .12552 Mdot
.16865 .12552 Mdot
.16473 .12552 Mdot
.16473 .12552 Mdot
.15689 .11768 Mdot
.15689 .10983 Mdot
.16081 .09807 Mdot
.14905 .09415 Mdot
.15297 .10591 Mdot
.1412 .09023 Mdot
.16081 .09807 Mdot
.17257 .10591 Mdot
.17257 .10199 Mdot
.18042 .10591 Mdot
.18434 .11376 Mdot
.18434 .1216 Mdot
.1765 .12944 Mdot
.18042 .13728 Mdot
.19218 .15297 Mdot
.19218 .1412 Mdot
.1961 .1412 Mdot
.18826 .13336 Mdot
.18434 .12552 Mdot
.18042 .11768 Mdot
.16473 .10591 Mdot
.16473 .10591 Mdot
.16081 .10983 Mdot
.15297 .11376 Mdot
.14513 .10591 Mdot
.12552 .09415 Mdot
.12552 .09023 Mdot
.1412 .09807 Mdot
.14513 .10983 Mdot
.16081 .11768 Mdot
.16081 .11376 Mdot
.16081 .11768 Mdot
.15689 .11376 Mdot
.15297 .10983 Mdot
.14905 .10199 Mdot
.16865 .10591 Mdot
.1765 .11376 Mdot
.17257 .10983 Mdot
.16865 .11376 Mdot
.1765 .1216 Mdot
.17257 .1216 Mdot
.1765 .1216 Mdot
.1765 .1216 Mdot
.18042 .12944 Mdot
.18042 .12944 Mdot
.1961 .14513 Mdot
.20394 .16473 Mdot
.1961 .16473 Mdot
.19218 .16865 Mdot
.19218 .16081 Mdot
.18434 .14513 Mdot
.1765 .12944 Mdot
.1765 .12944 Mdot
.18434 .13728 Mdot
.19218 .14905 Mdot
.18434 .14513 Mdot
.18434 .1412 Mdot
.19218 .14513 Mdot
.18434 .1412 Mdot
.18434 .13336 Mdot
.20002 .13336 Mdot
.20787 .13728 Mdot
.20002 .12944 Mdot
.19218 .11768 Mdot
.18042 .10983 Mdot
.1765 .10591 Mdot
.16865 .10199 Mdot
.17257 .11376 Mdot
.17257 .11376 Mdot
.16081 .11376 Mdot
.16473 .11768 Mdot
.16473 .11376 Mdot
.15689 .10199 Mdot
.16081 .10199 Mdot
.17257 .11768 Mdot
.16081 .11376 Mdot
.16081 .11768 Mdot
.1412 .10591 Mdot
.1412 .09807 Mdot
.1412 .09415 Mdot
.12944 .08239 Mdot
.1216 .07846 Mdot
.12944 .08239 Mdot
.12552 .08239 Mdot
.11768 .07454 Mdot
.11768 .08239 Mdot
.10983 .08239 Mdot
.10199 .07454 Mdot
.09807 .05886 Mdot
.09807 .05494 Mdot
.09807 .04709 Mdot
.09807 .05886 Mdot
.10199 .05886 Mdot
.09415 .05102 Mdot
.09023 .04709 Mdot
.09807 .04709 Mdot
.10983 .0667 Mdot
.10591 .06278 Mdot
.08631 .05886 Mdot
.10199 .07062 Mdot
.10591 .07846 Mdot
.10199 .07846 Mdot
.09415 .0667 Mdot
.08239 .05886 Mdot
.08239 .05102 Mdot
.07846 .03925 Mdot
.07454 .03533 Mdot
.05886 .01965 Mdot
.05886 .04317 Mdot
.07454 .0667 Mdot
.08239 .0667 Mdot
.08631 .07454 Mdot
.11376 .09415 Mdot
.12944 .10591 Mdot
.12944 .10591 Mdot
.11768 .09023 Mdot
.11376 .08239 Mdot
.10591 .07062 Mdot
.09807 .06278 Mdot
.09023 .05102 Mdot
.08631 .04709 Mdot
.09415 .06278 Mdot
.10199 .07454 Mdot
.09023 .0667 Mdot
.10591 .07846 Mdot
.11768 .08631 Mdot
.13728 .09415 Mdot
.14513 .10199 Mdot
.1412 .10199 Mdot
.13336 .09415 Mdot
.13728 .09807 Mdot
.14905 .10983 Mdot
.15297 .11376 Mdot
.15297 .11376 Mdot
.14905 .10983 Mdot
.14905 .09807 Mdot
.15297 .10199 Mdot
.14905 .09807 Mdot
.13728 .09023 Mdot
.13728 .09415 Mdot
.1412 .09807 Mdot
.14905 .10591 Mdot
.1412 .11376 Mdot
.14905 .12552 Mdot
.15297 .12944 Mdot
.15297 .12944 Mdot
.15297 .13336 Mdot
.15689 .12944 Mdot
.14513 .1216 Mdot
.13728 .10983 Mdot
.15689 .11376 Mdot
.16473 .10983 Mdot
.16865 .11376 Mdot
.16081 .10983 Mdot
.16473 .11768 Mdot
.16473 .12944 Mdot
.17257 .1412 Mdot
.16473 .13728 Mdot
.16473 .13336 Mdot
.16865 .13336 Mdot
.17257 .12944 Mdot
.16865 .11768 Mdot
.16081 .09415 Mdot
.14905 .09023 Mdot
.15297 .10199 Mdot
.16473 .11376 Mdot
.16473 .10591 Mdot
.18434 .11768 Mdot
.18434 .1216 Mdot
.18826 .12552 Mdot
.1961 .12944 Mdot
.18434 .1216 Mdot
.18826 .12944 Mdot
.1961 .14513 Mdot
.20394 .15689 Mdot
.1961 .14513 Mdot
.20787 .15297 Mdot
.18434 .13336 Mdot
.1765 .12552 Mdot
.18434 .13336 Mdot
.1765 .12552 Mdot
.1765 .1216 Mdot
.16865 .11768 Mdot
.16473 .11768 Mdot
.16081 .11768 Mdot
.14905 .10591 Mdot
.13728 .10199 Mdot
.1412 .10199 Mdot
.15297 .11376 Mdot
.14905 .10591 Mdot
.15297 .10983 Mdot
.16081 .11768 Mdot
.16473 .12552 Mdot
.14905 .11768 Mdot
.13728 .10591 Mdot
.14905 .10591 Mdot
.16473 .11376 Mdot
.16473 .10591 Mdot
.17257 .1216 Mdot
.1765 .12552 Mdot
.18042 .12944 Mdot
.1765 .12552 Mdot
.1765 .1216 Mdot
.18042 .12552 Mdot
.18434 .12944 Mdot
.18826 .13336 Mdot
.1961 .1412 Mdot
.20394 .15689 Mdot
.20787 .17257 Mdot
.1961 .16473 Mdot
.18042 .14513 Mdot
.17257 .12552 Mdot
.1765 .1216 Mdot
.18434 .12944 Mdot
.18434 .13728 Mdot
.18826 .14513 Mdot
.19218 .14905 Mdot
.19218 .14905 Mdot
.1961 .14905 Mdot
.19218 .13728 Mdot
.1961 .13336 Mdot
.1961 .13336 Mdot
.19218 .12944 Mdot
.1961 .12552 Mdot
.20394 .12944 Mdot
.18042 .11376 Mdot
.17257 .11376 Mdot
.17257 .1216 Mdot
.16865 .11768 Mdot
.17257 .11768 Mdot
.16473 .11376 Mdot
.15689 .10983 Mdot
.1765 .11768 Mdot
.16473 .10591 Mdot
.16473 .10983 Mdot
.16865 .12552 Mdot
.16865 .13336 Mdot
.15297 .11768 Mdot
.13728 .10591 Mdot
.1412 .09415 Mdot
.14513 .09415 Mdot
.13336 .08631 Mdot
.13336 .09023 Mdot
.12944 .08631 Mdot
.13336 .08631 Mdot
.12944 .08631 Mdot
.12552 .08239 Mdot
.11768 .07846 Mdot
.11768 .07454 Mdot
.11376 .06278 Mdot
.11376 .06278 Mdot
.10199 .05102 Mdot
.09415 .05102 Mdot
.09807 .05102 Mdot
.09415 .05102 Mdot
.09415 .05102 Mdot
.10591 .05494 Mdot
.10591 .05102 Mdot
.10199 .05102 Mdot
.10983 .07062 Mdot
.09807 .05886 Mdot
.09415 .05886 Mdot
.09415 .06278 Mdot
.09415 .06278 Mdot
.08239 .05494 Mdot
.07062 .03925 Mdot
.06278 .02357 Mdot
.0667 .02749 Mdot
.05494 .04317 Mdot
.0667 .04709 Mdot
.0667 .03925 Mdot
.08631 .05886 Mdot
.09023 .07062 Mdot
.10591 .09415 Mdot
.10983 .09415 Mdot
.10591 .09023 Mdot
.10199 .08239 Mdot
.10591 .07846 Mdot
.10591 .07846 Mdot
.10199 .07454 Mdot
.10199 .07062 Mdot
.10199 .0667 Mdot
.09807 .07062 Mdot
.09023 .05886 Mdot
.10983 .0667 Mdot
.11768 .07062 Mdot
.1216 .07454 Mdot
.13336 .08631 Mdot
.12552 .07846 Mdot
.13728 .09023 Mdot
.13728 .09415 Mdot
.13728 .09415 Mdot
.14513 .09415 Mdot
.14513 .09807 Mdot
.14905 .10983 Mdot
.14513 .10591 Mdot
.15297 .11768 Mdot
.14905 .1216 Mdot
.14513 .11376 Mdot
.14513 .10983 Mdot
.13728 .10983 Mdot
.13336 .10983 Mdot
.14905 .12552 Mdot
.14905 .1216 Mdot
.15689 .12552 Mdot
.15297 .1216 Mdot
.14905 .10983 Mdot
.15689 .11768 Mdot
.15297 .10983 Mdot
.15297 .10983 Mdot
.16865 .1216 Mdot
.16473 .1216 Mdot
.17257 .12552 Mdot
.16865 .11768 Mdot
.17257 .12552 Mdot
.16473 .1216 Mdot
.16473 .1216 Mdot
.16865 .12944 Mdot
.17257 .13336 Mdot
.16081 .11768 Mdot
.16081 .11768 Mdot
.16865 .12552 Mdot
.16081 .11768 Mdot
.15297 .10983 Mdot
.16865 .11768 Mdot
.17257 .11376 Mdot
.17257 .1216 Mdot
.1765 .1216 Mdot
.18434 .12552 Mdot
.19218 .12944 Mdot
.1765 .11768 Mdot
.18434 .12552 Mdot
.19218 .13336 Mdot
.20002 .15297 Mdot
.20002 .15297 Mdot
.20002 .15297 Mdot
.20787 .16865 Mdot
.20394 .16081 Mdot
.19218 .15297 Mdot
.18434 .14513 Mdot
.18434 .13728 Mdot
.18042 .13336 Mdot
.18042 .12552 Mdot
.17257 .11376 Mdot
.1765 .11376 Mdot
.16473 .10591 Mdot
.16865 .11768 Mdot
.18042 .12552 Mdot
.17257 .11376 Mdot
.16473 .10983 Mdot
.15689 .10591 Mdot
.16865 .10983 Mdot
.16865 .1216 Mdot
.16473 .12552 Mdot
.16473 .1216 Mdot
.16081 .10983 Mdot
.16081 .10591 Mdot
.15297 .09415 Mdot
.15689 .10591 Mdot
.16865 .11768 Mdot
.18042 .12944 Mdot
.18042 .13336 Mdot
.18434 .12944 Mdot
.18826 .13728 Mdot
.18434 .12944 Mdot
.18042 .1216 Mdot
.18042 .1216 Mdot
.20394 .14513 Mdot
.20787 .15689 Mdot
.21179 .16473 Mdot
.20394 .15689 Mdot
.1961 .14905 Mdot
.18826 .13336 Mdot
.18434 .1216 Mdot
.18826 .12552 Mdot
.19218 .13336 Mdot
.20394 .14905 Mdot
.20394 .15297 Mdot
.19218 .1412 Mdot
.1961 .13728 Mdot
.20787 .1412 Mdot
.19218 .12944 Mdot
.18434 .12944 Mdot
.18042 .1216 Mdot
.18826 .12944 Mdot
.18826 .12552 Mdot
.18434 .12944 Mdot
.1765 .12944 Mdot
.1765 .12944 Mdot
.18042 .13336 Mdot
.1765 .12944 Mdot
.1765 .13336 Mdot
.17257 .13336 Mdot
.16473 .1216 Mdot
.17257 .12944 Mdot
.1765 .13728 Mdot
.16473 .13336 Mdot
.16473 .13336 Mdot
.15689 .12552 Mdot
.13728 .10199 Mdot
.13336 .09807 Mdot
.12944 .08631 Mdot
.13336 .08631 Mdot
.1412 .09023 Mdot
.14513 .09807 Mdot
.13336 .09023 Mdot
.13336 .09023 Mdot
.12944 .08631 Mdot
.1216 .08239 Mdot
.12552 .08239 Mdot
.12944 .07846 Mdot
.11768 .06278 Mdot
.11768 .05886 Mdot
.11768 .06278 Mdot
.10983 .07062 Mdot
.10983 .0667 Mdot
.10199 .05102 Mdot
.10591 .05102 Mdot
.10983 .05886 Mdot
.10591 .0667 Mdot
.09023 .05886 Mdot
.09023 .05886 Mdot
.09023 .05886 Mdot
.09807 .0667 Mdot
.0667 .03533 Mdot
.0667 .03533 Mdot
.06278 .03141 Mdot
.07062 .03533 Mdot
.03141 .01572 Mdot
.04317 .01965 Mdot
.04709 .01965 Mdot
.07846 .04317 Mdot
.09415 .07454 Mdot
.09415 .08631 Mdot
.09415 .08239 Mdot
.09415 .07846 Mdot
.10983 .10199 Mdot
.1216 .10199 Mdot
.10983 .08239 Mdot
.1216 .08631 Mdot
.11376 .07846 Mdot
.09807 .07062 Mdot
.09415 .06278 Mdot
.10199 .07062 Mdot
.10983 .0667 Mdot
.11768 .07062 Mdot
.11768 .07062 Mdot
.12944 .08631 Mdot
.12944 .08239 Mdot
.13336 .09023 Mdot
.14905 .10591 Mdot
.14513 .09807 Mdot
.15297 .10591 Mdot
.15297 .10591 Mdot
.15689 .11376 Mdot
.15689 .12552 Mdot
.15297 .13336 Mdot
.14513 .12944 Mdot
.14905 .12944 Mdot
.14905 .12944 Mdot
.14905 .13728 Mdot
.14513 .12552 Mdot
.14905 .12944 Mdot
.14905 .1216 Mdot
.16473 .1216 Mdot
.15689 .10983 Mdot
.14905 .10591 Mdot
.15689 .10591 Mdot
.15297 .10591 Mdot
.15689 .10983 Mdot
.1765 .11768 Mdot
.17257 .11768 Mdot
.16865 .12552 Mdot
.17257 .1216 Mdot
.18042 .12944 Mdot
.18826 .13728 Mdot
.18434 .13336 Mdot
.16865 .12552 Mdot
.15689 .1216 Mdot
.16081 .12944 Mdot
.16865 .12552 Mdot
.16865 .12552 Mdot
.17257 .13728 Mdot
.16473 .13336 Mdot
.16473 .1216 Mdot
.16473 .1216 Mdot
.15689 .11376 Mdot
.17257 .1216 Mdot
.17257 .11768 Mdot
.17257 .12552 Mdot
.1765 .12944 Mdot
.17257 .12944 Mdot
.1765 .13728 Mdot
.18826 .14513 Mdot
.1961 .15689 Mdot
.20002 .15689 Mdot
.20002 .16473 Mdot
.1961 .16473 Mdot
.18826 .16473 Mdot
.1961 .17257 Mdot
.1765 .14905 Mdot
.17257 .13728 Mdot
.16473 .1216 Mdot
.16865 .1216 Mdot
.16865 .10983 Mdot
.16865 .10591 Mdot
.16865 .10199 Mdot
.18434 .1216 Mdot
.18434 .12552 Mdot
.19218 .13336 Mdot
.18434 .12944 Mdot
.18042 .1216 Mdot
.17257 .12552 Mdot
.17257 .12552 Mdot
.16865 .1216 Mdot
.16473 .11376 Mdot
.16081 .10199 Mdot
.16081 .09807 Mdot
.16081 .10591 Mdot
.17257 .11768 Mdot
.18042 .12944 Mdot
.18826 .13728 Mdot
.19218 .1412 Mdot
.20002 .14905 Mdot
.20002 .14513 Mdot
.19218 .13336 Mdot
.19218 .12552 Mdot
.18826 .11768 Mdot
.19218 .12552 Mdot
.20394 .1412 Mdot
.18826 .13336 Mdot
.18826 .13728 Mdot
.1961 .1412 Mdot
.19218 .12944 Mdot
.19218 .12944 Mdot
.18434 .1216 Mdot
.19218 .13336 Mdot
.18434 .12944 Mdot
.18826 .13728 Mdot
.19218 .1412 Mdot
.1961 .1412 Mdot
.1961 .13728 Mdot
.18826 .13728 Mdot
.18434 .12944 Mdot
.1765 .11768 Mdot
.1765 .1216 Mdot
.16473 .11376 Mdot
.16473 .11768 Mdot
.16473 .1216 Mdot
.16081 .12552 Mdot
.17257 .13336 Mdot
.1765 .12944 Mdot
.17257 .12552 Mdot
.16865 .12552 Mdot
.16081 .13336 Mdot
.17257 .13728 Mdot
.17257 .13728 Mdot
.16081 .12944 Mdot
.16081 .1216 Mdot
.1216 .08631 Mdot
.12552 .08631 Mdot
.1216 .07454 Mdot
.11768 .0667 Mdot
.12552 .07062 Mdot
.13728 .08631 Mdot
.14513 .09807 Mdot
.13336 .08631 Mdot
.11768 .07846 Mdot
.10591 .07454 Mdot
.10983 .07846 Mdot
.12944 .08631 Mdot
.11768 .07454 Mdot
.11376 .07454 Mdot
.11768 .08239 Mdot
.11376 .08239 Mdot
.11376 .08239 Mdot
.11376 .07846 Mdot
.11768 .07062 Mdot
.10983 .05886 Mdot
.10591 .05494 Mdot
.10983 .05886 Mdot
.10199 .05494 Mdot
.10199 .05494 Mdot
.10199 .05886 Mdot
.09807 .05494 Mdot
.07846 .04709 Mdot
.07846 .05494 Mdot
.07454 .05102 Mdot
.02749 .0118 Mdot
.03925 .01572 Mdot
.0667 .03533 Mdot
.09023 .05886 Mdot
.11376 .08239 Mdot
.10591 .07846 Mdot
.08239 .05886 Mdot
.08239 .0667 Mdot
.09807 .07846 Mdot
.08631 .0667 Mdot
.09023 .07062 Mdot
.09415 .07454 Mdot
.10199 .07846 Mdot
.10983 .08239 Mdot
.10983 .07454 Mdot
.10983 .0667 Mdot
.10591 .05886 Mdot
.11768 .0667 Mdot
.11768 .0667 Mdot
.1216 .07454 Mdot
.1216 .08239 Mdot
.12552 .09415 Mdot
.14513 .10199 Mdot
.14905 .10199 Mdot
.14513 .10199 Mdot
.15297 .10983 Mdot
.16865 .1216 Mdot
.16473 .12552 Mdot
.16081 .13728 Mdot
.14905 .13336 Mdot
.14905 .13728 Mdot
.15297 .1412 Mdot
.15689 .14905 Mdot
.16081 .14513 Mdot
.15689 .13336 Mdot
.14513 .11376 Mdot
.15689 .11768 Mdot
.15689 .10983 Mdot
.15689 .10591 Mdot
.16473 .10591 Mdot
.16473 .10591 Mdot
.15689 .09807 Mdot
.16473 .10591 Mdot
.1765 .1216 Mdot
.18434 .12552 Mdot
.18042 .11768 Mdot
.17257 .11376 Mdot
.18042 .12552 Mdot
.1765 .12552 Mdot
.1765 .12944 Mdot
.16865 .13336 Mdot
.17257 .1412 Mdot
.1765 .14513 Mdot
.17257 .1412 Mdot
.16473 .13728 Mdot
.16865 .13336 Mdot
.17257 .13336 Mdot
.1765 .13728 Mdot
.16865 .12944 Mdot
.16473 .12944 Mdot
.15689 .11768 Mdot
.16473 .1216 Mdot
.1765 .12552 Mdot
.17257 .1216 Mdot
.1765 .12552 Mdot
.18042 .12552 Mdot
.19218 .1412 Mdot
.19218 .14905 Mdot
.1961 .15689 Mdot
.18826 .15297 Mdot
.20394 .16865 Mdot
.20394 .17257 Mdot
.1961 .16865 Mdot
.18042 .15297 Mdot
.1765 .1412 Mdot
.1765 .12944 Mdot
.17257 .11376 Mdot
.16865 .10199 Mdot
.18042 .10591 Mdot
.1765 .11376 Mdot
.18434 .1216 Mdot
.18434 .12944 Mdot
.18434 .12944 Mdot
.18434 .12944 Mdot
.1765 .12552 Mdot
.18042 .12944 Mdot
.18434 .13336 Mdot
.1765 .12552 Mdot
.1765 .1216 Mdot
.17257 .11768 Mdot
.16473 .11768 Mdot
.17257 .1216 Mdot
.18826 .13336 Mdot
.18826 .13728 Mdot
.19218 .14513 Mdot
.18826 .13728 Mdot
.1961 .13336 Mdot
.1961 .1216 Mdot
.1961 .11768 Mdot
.20394 .12552 Mdot
.1961 .12944 Mdot
.20002 .13336 Mdot
.20394 .13728 Mdot
.20002 .1412 Mdot
.20002 .14905 Mdot
.1961 .1412 Mdot
.19218 .13336 Mdot
.18826 .13336 Mdot
.19218 .13336 Mdot
.19218 .1412 Mdot
.1961 .14905 Mdot
.20002 .14905 Mdot
.1961 .14513 Mdot
.18826 .13728 Mdot
.18434 .13728 Mdot
.17257 .12944 Mdot
.16473 .11768 Mdot
.16865 .12944 Mdot
.17257 .12944 Mdot
.1765 .13336 Mdot
.16473 .12552 Mdot
.17257 .12552 Mdot
.1765 .12944 Mdot
.1765 .12944 Mdot
.16865 .1216 Mdot
.1765 .13336 Mdot
.17257 .13728 Mdot
.16081 .12552 Mdot
.16473 .12552 Mdot
.16081 .1216 Mdot
.16081 .11768 Mdot
.14513 .10199 Mdot
.14905 .10199 Mdot
.13336 .08631 Mdot
.12944 .07846 Mdot
.12552 .07454 Mdot
.14513 .09415 Mdot
.14513 .10199 Mdot
.1412 .09023 Mdot
.1412 .09415 Mdot
.12944 .08631 Mdot
.11768 .07846 Mdot
.11768 .07846 Mdot
.10983 .07062 Mdot
.10591 .07062 Mdot
.10199 .07454 Mdot
.09807 .07846 Mdot
.09415 .07062 Mdot
.10199 .07454 Mdot
.12552 .08631 Mdot
.11376 .07454 Mdot
.09807 .06278 Mdot
.09807 .05102 Mdot
.10983 .05102 Mdot
.10983 .04709 Mdot
.10591 .04317 Mdot
.10591 .05494 Mdot
.08631 .04317 Mdot
.08239 .04317 Mdot
.0667 .03533 Mdot
.03533 .01572 Mdot
.05102 .02357 Mdot
.05494 .02357 Mdot
.05494 .03141 Mdot
.07062 .03925 Mdot
.08239 .04317 Mdot
.08631 .03925 Mdot
.0667 .04317 Mdot
.05494 .04317 Mdot
.03533 .02749 Mdot
.05102 .03533 Mdot
.07454 .05102 Mdot
.09023 .06278 Mdot
.09415 .06278 Mdot
.09807 .0667 Mdot
.11376 .07062 Mdot
.11376 .07062 Mdot
.11376 .07062 Mdot
.1216 .07846 Mdot
.11768 .08631 Mdot
.12552 .09807 Mdot
.12944 .09807 Mdot
.1412 .10591 Mdot
.14513 .10591 Mdot
.1412 .09807 Mdot
.16081 .10983 Mdot
.16865 .11376 Mdot
.16865 .11768 Mdot
.16865 .1216 Mdot
.16081 .12552 Mdot
.14513 .12552 Mdot
.15297 .13336 Mdot
.15297 .13336 Mdot
.14905 .12944 Mdot
.15689 .13728 Mdot
.15689 .13728 Mdot
.16081 .13728 Mdot
.16473 .12552 Mdot
.1765 .13336 Mdot
.17257 .1216 Mdot
.16865 .11768 Mdot
.16081 .11376 Mdot
.16473 .11376 Mdot
.16865 .11376 Mdot
.18042 .11768 Mdot
.18042 .11376 Mdot
.18826 .1216 Mdot
.18826 .11768 Mdot
.18826 .10983 Mdot
.18826 .11376 Mdot
.17257 .11768 Mdot
.16081 .11768 Mdot
.16865 .12552 Mdot
.1765 .13728 Mdot
.1765 .14513 Mdot
.1765 .14905 Mdot
.16865 .1412 Mdot
.1765 .14513 Mdot
.18042 .14905 Mdot
.1765 .1412 Mdot
.16081 .1216 Mdot
.15297 .10983 Mdot
.16081 .11376 Mdot
.16865 .11376 Mdot
.18042 .11768 Mdot
.18434 .11768 Mdot
.1961 .13336 Mdot
.20002 .14513 Mdot
.19218 .14513 Mdot
.18042 .13728 Mdot
.20002 .14905 Mdot
.20002 .15297 Mdot
.19218 .15689 Mdot
.18826 .14905 Mdot
.19218 .15297 Mdot
.1961 .14905 Mdot
.18434 .12944 Mdot
.18434 .12944 Mdot
.19218 .12944 Mdot
.19218 .12552 Mdot
.20002 .12944 Mdot
.18826 .11768 Mdot
.19218 .1216 Mdot
.19218 .13336 Mdot
.20002 .14513 Mdot
.1961 .14905 Mdot
.18826 .14905 Mdot
.18434 .1412 Mdot
.19218 .1412 Mdot
.18042 .1216 Mdot
.1765 .11376 Mdot
.1765 .11376 Mdot
.18042 .10983 Mdot
.18434 .11768 Mdot
.1961 .13336 Mdot
.1961 .13336 Mdot
.19218 .1216 Mdot
.20002 .11768 Mdot
.1961 .10199 Mdot
.20787 .1216 Mdot
.20394 .13336 Mdot
.1961 .13336 Mdot
.19218 .13336 Mdot
.18826 .13336 Mdot
.1961 .1412 Mdot
.1961 .13336 Mdot
.18826 .13336 Mdot
.18042 .12552 Mdot
.1961 .13336 Mdot
.20002 .14513 Mdot
.20394 .15297 Mdot
.20002 .14905 Mdot
.1961 .14905 Mdot
.19218 .14513 Mdot
.18826 .1412 Mdot
.18042 .13728 Mdot
.16473 .13336 Mdot
.16081 .13728 Mdot
.16473 .13336 Mdot
.16865 .13336 Mdot
.17257 .13728 Mdot
.17257 .13728 Mdot
.17257 .12944 Mdot
.16473 .12552 Mdot
.17257 .13336 Mdot
.17257 .13728 Mdot
.17257 .1412 Mdot
.16473 .12944 Mdot
.14905 .11376 Mdot
.15297 .11376 Mdot
.14905 .09807 Mdot
.14905 .09807 Mdot
.14513 .09415 Mdot
.14905 .09415 Mdot
.1412 .08631 Mdot
.12944 .07454 Mdot
.13728 .08631 Mdot
.1412 .08631 Mdot
.13728 .09415 Mdot
.13728 .10591 Mdot
.13336 .10983 Mdot
.12552 .10199 Mdot
.12552 .09415 Mdot
.11376 .08239 Mdot
.10591 .07454 Mdot
.09807 .06278 Mdot
.10591 .07454 Mdot
.10199 .07062 Mdot
.11768 .08631 Mdot
.12552 .09023 Mdot
.11768 .08631 Mdot
.10591 .0667 Mdot
.10591 .06278 Mdot
.10591 .05886 Mdot
.10983 .04709 Mdot
.10199 .03925 Mdot
.10199 .03925 Mdot
.09807 .03533 Mdot
.08631 .03533 Mdot
.07454 .03141 Mdot
.02357 .01572 Mdot
.02749 .01572 Mdot
.02357 .00788 Mdot
.03533 .0118 Mdot
.04317 .01572 Mdot
.05886 .01965 Mdot
.08239 .03925 Mdot
.07454 .03533 Mdot
.06278 .02749 Mdot
.03925 .01572 Mdot
.04709 .02357 Mdot
.05886 .03533 Mdot
.05102 .02749 Mdot
.04709 .02357 Mdot
.07062 .04709 Mdot
.09807 .07062 Mdot
.11376 .08239 Mdot
.11768 .08239 Mdot
.13336 .09807 Mdot
.12944 .10591 Mdot
.12944 .10983 Mdot
.13728 .11376 Mdot
.13336 .10591 Mdot
.13728 .10591 Mdot
.12944 .09415 Mdot
.1412 .09415 Mdot
.14905 .09807 Mdot
.14905 .09807 Mdot
.15689 .10591 Mdot
.16081 .11768 Mdot
.15689 .1216 Mdot
.14905 .11768 Mdot
.16081 .12552 Mdot
.16473 .12552 Mdot
.18042 .1412 Mdot
.17257 .12944 Mdot
.18042 .13336 Mdot
.18434 .13336 Mdot
.1765 .12552 Mdot
.18042 .12944 Mdot
.18042 .13336 Mdot
.18434 .13728 Mdot
.18042 .12944 Mdot
.1765 .12944 Mdot
.18042 .12944 Mdot
.19218 .13336 Mdot
.1961 .13728 Mdot
.19218 .12944 Mdot
.18826 .12552 Mdot
.18434 .12944 Mdot
.18042 .12552 Mdot
.17257 .11768 Mdot
.16865 .11768 Mdot
.16865 .12944 Mdot
.16865 .12944 Mdot
.1765 .1412 Mdot
.18042 .14513 Mdot
.18042 .14905 Mdot
.18042 .14905 Mdot
.18042 .1412 Mdot
.1765 .1412 Mdot
.18042 .1412 Mdot
.17257 .12944 Mdot
.16865 .11768 Mdot
.16081 .10199 Mdot
.16865 .11376 Mdot
.1765 .12552 Mdot
.18042 .13336 Mdot
.18434 .13728 Mdot
.18826 .13728 Mdot
.1961 .14513 Mdot
.1961 .14513 Mdot
.20394 .14513 Mdot
.20787 .15297 Mdot
.20787 .15297 Mdot
.20394 .14513 Mdot
.20787 .1412 Mdot
.1961 .12944 Mdot
.20394 .13728 Mdot
.20002 .13336 Mdot
.1961 .13728 Mdot
.1961 .13336 Mdot
.20002 .13336 Mdot
.1961 .12944 Mdot
.20002 .13336 Mdot
.20394 .1412 Mdot
.20002 .14513 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.18042 .1216 Mdot
.1765 .11376 Mdot
.18042 .10983 Mdot
.18434 .11376 Mdot
.1961 .12552 Mdot
.19218 .1216 Mdot
.19218 .1216 Mdot
.20002 .11768 Mdot
.20002 .11768 Mdot
.21179 .13336 Mdot
.22747 .15297 Mdot
.21571 .15297 Mdot
.19218 .13728 Mdot
.18042 .12552 Mdot
.18826 .12944 Mdot
.18826 .12944 Mdot
.19218 .13336 Mdot
.19218 .13728 Mdot
.19218 .13728 Mdot
.20002 .1412 Mdot
.1961 .13728 Mdot
.18826 .12944 Mdot
.1765 .1216 Mdot
.18434 .13336 Mdot
.18042 .12944 Mdot
.18826 .13728 Mdot
.1765 .13336 Mdot
.17257 .13336 Mdot
.17257 .1412 Mdot
.18042 .14513 Mdot
.1765 .1412 Mdot
.18042 .1412 Mdot
.1765 .13728 Mdot
.17257 .13336 Mdot
.16865 .12944 Mdot
.17257 .12944 Mdot
.17257 .13336 Mdot
.17257 .12552 Mdot
.16865 .1216 Mdot
.16865 .11768 Mdot
.15297 .08631 Mdot
.15689 .08631 Mdot
.15689 .08631 Mdot
.16081 .10199 Mdot
.16473 .10591 Mdot
.13336 .08239 Mdot
.13336 .09415 Mdot
.13728 .09415 Mdot
.13336 .09807 Mdot
.12944 .09807 Mdot
.12944 .10199 Mdot
.12944 .10591 Mdot
.12552 .09807 Mdot
.12944 .09023 Mdot
.12552 .08239 Mdot
.12944 .08631 Mdot
.13728 .09023 Mdot
.11376 .07062 Mdot
.11768 .07062 Mdot
.12944 .08239 Mdot
.1216 .07846 Mdot
.11376 .07454 Mdot
.11376 .07454 Mdot
.10591 .06278 Mdot
.10591 .05886 Mdot
.10983 .06278 Mdot
.10983 .06278 Mdot
.10983 .06278 Mdot
.09415 .05494 Mdot
.07846 .04317 Mdot
.01572 .02357 Mdot
.02357 .01965 Mdot
.01965 .00788 Mdot
.02357 .00396 Mdot
.02357 .00396 Mdot
.04709 .0118 Mdot
.05494 .0118 Mdot
.05886 .01572 Mdot
.06278 .0118 Mdot
.05886 .0118 Mdot
.06278 .01965 Mdot
.06278 .02749 Mdot
.06278 .03533 Mdot
.05102 .02357 Mdot
.05102 .02749 Mdot
.05102 .02749 Mdot
.07846 .05102 Mdot
.10199 .06278 Mdot
.11768 .06278 Mdot
.13336 .08631 Mdot
.13728 .09807 Mdot
.1412 .10199 Mdot
.14513 .10199 Mdot
.13728 .09415 Mdot
.13336 .09807 Mdot
.13728 .09807 Mdot
.13728 .09023 Mdot
.14905 .09807 Mdot
.15297 .10591 Mdot
.15689 .11768 Mdot
.15689 .1216 Mdot
.16081 .11768 Mdot
.17257 .1216 Mdot
.1765 .1216 Mdot
.18434 .13336 Mdot
.18434 .13336 Mdot
.18434 .13728 Mdot
.18826 .1412 Mdot
.1961 .14513 Mdot
.20002 .14513 Mdot
.1961 .1412 Mdot
.19218 .1412 Mdot
.19218 .1412 Mdot
.18042 .13728 Mdot
.1765 .13336 Mdot
.18042 .1412 Mdot
.18042 .13728 Mdot
.18434 .13336 Mdot
.18826 .13728 Mdot
.19218 .1412 Mdot
.19218 .13728 Mdot
.19218 .12552 Mdot
.1765 .10983 Mdot
.1765 .1216 Mdot
.17257 .1216 Mdot
.1765 .12552 Mdot
.1765 .12552 Mdot
.18826 .1412 Mdot
.18434 .14905 Mdot
.18434 .15297 Mdot
.1765 .14513 Mdot
.17257 .13728 Mdot
.17257 .13728 Mdot
.1765 .1412 Mdot
.16081 .12552 Mdot
.17257 .12944 Mdot
.16865 .12552 Mdot
.17257 .12552 Mdot
.18042 .12552 Mdot
.19218 .1412 Mdot
.1961 .13728 Mdot
.1961 .13336 Mdot
.20787 .13728 Mdot
.21179 .1412 Mdot
.21571 .14905 Mdot
.20394 .1412 Mdot
.20002 .13728 Mdot
.20787 .1412 Mdot
.20787 .1412 Mdot
.21179 .15297 Mdot
.21179 .15689 Mdot
.20787 .15689 Mdot
.21179 .15689 Mdot
.20002 .1412 Mdot
.20394 .13336 Mdot
.20787 .13336 Mdot
.20002 .13728 Mdot
.1961 .13336 Mdot
.18826 .13728 Mdot
.18434 .13336 Mdot
.1765 .12552 Mdot
.17257 .11768 Mdot
.17257 .11376 Mdot
.1765 .11376 Mdot
.18826 .1216 Mdot
.18434 .1216 Mdot
.1961 .13728 Mdot
.20002 .13728 Mdot
.20394 .13336 Mdot
.20394 .13336 Mdot
.21179 .14905 Mdot
.21571 .15297 Mdot
.21571 .15297 Mdot
.1961 .13728 Mdot
.18434 .12552 Mdot
.1961 .13336 Mdot
.20787 .14513 Mdot
.20787 .14513 Mdot
.20394 .13728 Mdot
.20394 .13728 Mdot
.18434 .12552 Mdot
.18434 .12552 Mdot
.18042 .11768 Mdot
.17257 .10983 Mdot
.18042 .1216 Mdot
.18826 .12944 Mdot
.18042 .12552 Mdot
.1765 .12944 Mdot
.1765 .13728 Mdot
.18042 .14513 Mdot
.18042 .14513 Mdot
.18826 .13728 Mdot
.18826 .13336 Mdot
.1765 .13728 Mdot
.1765 .1412 Mdot
.18042 .1412 Mdot
.1765 .13336 Mdot
.17257 .12552 Mdot
.16473 .11376 Mdot
.15297 .09415 Mdot
.1412 .07846 Mdot
.14905 .07846 Mdot
.1412 .07454 Mdot
.15297 .09023 Mdot
.16865 .11376 Mdot
.16081 .11376 Mdot
.1412 .10591 Mdot
.14513 .10983 Mdot
.13728 .10199 Mdot
.12552 .09415 Mdot
.1216 .09807 Mdot
.12552 .10199 Mdot
.1216 .09807 Mdot
.10983 .08239 Mdot
.11768 .08239 Mdot
.11768 .07846 Mdot
.12552 .08631 Mdot
.11376 .07454 Mdot
.10591 .05494 Mdot
.12552 .06278 Mdot
.1216 .07062 Mdot
.12552 .07062 Mdot
.11376 .0667 Mdot
.09807 .05886 Mdot
.08631 .05494 Mdot
.10591 .07454 Mdot
.09415 .07062 Mdot
.09807 .07454 Mdot
.08631 .06278 Mdot
.07846 .05494 Mdot
.01572 .02749 Mdot
.02357 .01965 Mdot
.02749 .00788 Mdot
.02357 .00788 Mdot
.01572 .00396 Mdot
.01965 .00396 Mdot
.02749 .00396 Mdot
.01965 .00396 Mdot
.03533 .00396 Mdot
.06278 .0118 Mdot
.08239 .03925 Mdot
.10199 .05494 Mdot
.08631 .04709 Mdot
.0667 .03533 Mdot
.05102 .02357 Mdot
.03925 .01965 Mdot
.03141 .01572 Mdot
.05494 .02357 Mdot
.07454 .02749 Mdot
.10591 .05102 Mdot
.1216 .0667 Mdot
.13728 .08631 Mdot
.15297 .10983 Mdot
.14905 .10199 Mdot
.15297 .11768 Mdot
.14905 .11768 Mdot
.15689 .11768 Mdot
.15689 .11768 Mdot
.14905 .11376 Mdot
.14513 .10199 Mdot
.15297 .10199 Mdot
.16081 .10591 Mdot
.16081 .09807 Mdot
.17257 .10591 Mdot
.18826 .12552 Mdot
.18042 .1216 Mdot
.18434 .13336 Mdot
.18434 .13728 Mdot
.19218 .15297 Mdot
.20002 .16473 Mdot
.1961 .15689 Mdot
.20002 .15689 Mdot
.19218 .15297 Mdot
.18042 .1412 Mdot
.18042 .14513 Mdot
.18434 .1412 Mdot
.18826 .1412 Mdot
.20002 .14513 Mdot
.20002 .1412 Mdot
.1961 .14513 Mdot
.20002 .14513 Mdot
.19218 .12552 Mdot
.18042 .10983 Mdot
.18042 .11376 Mdot
.19218 .12944 Mdot
.18826 .13336 Mdot
.18826 .13728 Mdot
.19218 .1412 Mdot
.1961 .14513 Mdot
.1961 .14905 Mdot
.18042 .14513 Mdot
.1765 .1412 Mdot
.18042 .1412 Mdot
.18434 .14513 Mdot
.18826 .1412 Mdot
.18434 .12552 Mdot
.1961 .12944 Mdot
.18042 .1216 Mdot
.1765 .11376 Mdot
.18042 .12552 Mdot
.18826 .12944 Mdot
.19218 .13336 Mdot
.20394 .1412 Mdot
.20787 .1412 Mdot
.20394 .1412 Mdot
.1961 .13336 Mdot
.1961 .12944 Mdot
.20787 .13728 Mdot
.20002 .12944 Mdot
.21179 .14513 Mdot
.21963 .15689 Mdot
.21963 .16473 Mdot
.21571 .16081 Mdot
.20394 .14905 Mdot
.20787 .1412 Mdot
.21571 .1412 Mdot
.20787 .14513 Mdot
.20002 .1412 Mdot
.1961 .14905 Mdot
.18042 .13728 Mdot
.17257 .12552 Mdot
.17257 .11376 Mdot
.17257 .11376 Mdot
.17257 .11768 Mdot
.1765 .1216 Mdot
.19218 .12944 Mdot
.1961 .12552 Mdot
.18434 .1216 Mdot
.20002 .12944 Mdot
.20002 .13336 Mdot
.1961 .13728 Mdot
.21179 .14513 Mdot
.21571 .15689 Mdot
.20002 .14513 Mdot
.19218 .1412 Mdot
.18042 .12552 Mdot
.18434 .12944 Mdot
.20002 .14905 Mdot
.21179 .16081 Mdot
.20002 .14905 Mdot
.20787 .15297 Mdot
.20002 .14513 Mdot
.19218 .13336 Mdot
.19218 .12944 Mdot
.1961 .12552 Mdot
.20002 .12944 Mdot
.1765 .11376 Mdot
.18042 .11768 Mdot
.18434 .12944 Mdot
.18826 .13728 Mdot
.19218 .14905 Mdot
.18826 .15297 Mdot
.18826 .15297 Mdot
.18434 .15297 Mdot
.18042 .15297 Mdot
.1765 .14905 Mdot
.16865 .13728 Mdot
.17257 .13336 Mdot
.16473 .11376 Mdot
.15689 .09807 Mdot
.15297 .09023 Mdot
.1412 .07846 Mdot
.14905 .08631 Mdot
.14905 .09415 Mdot
.16473 .11376 Mdot
.16081 .11768 Mdot
.16081 .12552 Mdot
.15297 .1216 Mdot
.1412 .10983 Mdot
.1412 .11768 Mdot
.1216 .10199 Mdot
.11768 .09807 Mdot
.11376 .09415 Mdot
.1216 .09023 Mdot
.1216 .08631 Mdot
.1216 .09023 Mdot
.11768 .09023 Mdot
.11376 .09023 Mdot
.11376 .08239 Mdot
.10199 .0667 Mdot
.10199 .06278 Mdot
.11376 .07454 Mdot
.11768 .07062 Mdot
.11768 .07062 Mdot
.10591 .06278 Mdot
.09807 .0667 Mdot
.09807 .07454 Mdot
.09807 .07454 Mdot
.08239 .05886 Mdot
.0667 .04317 Mdot
.01965 .02357 Mdot
.01965 .0118 Mdot
.02749 .00788 Mdot
.03141 .00788 Mdot
.02749 .00396 Mdot
.0118 .00396 Mdot
.00788 .00396 Mdot
.01572 .00396 Mdot
.03533 .00396 Mdot
.03925 .00396 Mdot
.08239 .02357 Mdot
.09807 .04317 Mdot
.09415 .04317 Mdot
.07454 .03533 Mdot
.04709 .01572 Mdot
.04709 .00788 Mdot
.04317 .00788 Mdot
.03141 .00396 Mdot
.03533 .00788 Mdot
.0667 .02357 Mdot
.10983 .05886 Mdot
.13336 .09023 Mdot
.14905 .11376 Mdot
.16081 .12944 Mdot
.16865 .15297 Mdot
.16865 .15689 Mdot
.17257 .15297 Mdot
.16081 .13336 Mdot
.15689 .1216 Mdot
.14905 .10199 Mdot
.1412 .08631 Mdot
.14905 .08239 Mdot
.16473 .09415 Mdot
.17257 .10199 Mdot
.18434 .11376 Mdot
.20002 .12944 Mdot
.20002 .1412 Mdot
.20394 .15689 Mdot
.1961 .16473 Mdot
.19218 .1765 Mdot
.18826 .17257 Mdot
.19218 .1765 Mdot
.18434 .16865 Mdot
.18042 .16473 Mdot
.18826 .15297 Mdot
.19218 .14905 Mdot
.20002 .15297 Mdot
.20394 .14513 Mdot
.21571 .14513 Mdot
.21179 .13336 Mdot
.20787 .13336 Mdot
.20394 .12552 Mdot
.20787 .12944 Mdot
.21571 .14513 Mdot
.21179 .14905 Mdot
.20394 .15689 Mdot
.20002 .16473 Mdot
.20394 .16865 Mdot
.18826 .15297 Mdot
.1961 .14905 Mdot
.18826 .14905 Mdot
.1765 .1412 Mdot
.17257 .13336 Mdot
.18042 .13728 Mdot
.19218 .13728 Mdot
.20394 .13336 Mdot
.1961 .12552 Mdot
.20002 .12552 Mdot
.20002 .12944 Mdot
.20002 .13336 Mdot
.20002 .13336 Mdot
.1961 .13336 Mdot
.1961 .14513 Mdot
.20002 .14513 Mdot
.1961 .1412 Mdot
.20787 .15297 Mdot
.21963 .15689 Mdot
.20787 .1412 Mdot
.21963 .14513 Mdot
.21179 .1412 Mdot
.22355 .16473 Mdot
.21963 .15689 Mdot
.23139 .16473 Mdot
.22747 .14905 Mdot
.21571 .1412 Mdot
.21571 .14513 Mdot
.21571 .14905 Mdot
.20394 .14513 Mdot
.19218 .14513 Mdot
.18434 .14905 Mdot
.17257 .13728 Mdot
.16473 .12552 Mdot
.16473 .1216 Mdot
.16865 .12944 Mdot
.16865 .11768 Mdot
.18826 .12944 Mdot
.18826 .11768 Mdot
.18826 .11376 Mdot
.18434 .10591 Mdot
.19218 .11768 Mdot
.1961 .12552 Mdot
.20787 .1412 Mdot
.21571 .14905 Mdot
.20787 .15297 Mdot
.1961 .14905 Mdot
.20787 .16865 Mdot
.19218 .16081 Mdot
.18826 .16081 Mdot
.20002 .16473 Mdot
.20787 .17257 Mdot
.21179 .16081 Mdot
.20787 .16081 Mdot
.20394 .15689 Mdot
.1961 .1412 Mdot
.1961 .12944 Mdot
.1961 .12552 Mdot
.19218 .1216 Mdot
.18434 .12552 Mdot
.19218 .13728 Mdot
.1961 .1412 Mdot
.18826 .14513 Mdot
.19218 .15689 Mdot
.19218 .16473 Mdot
.18826 .16081 Mdot
.18042 .16081 Mdot
.1765 .15297 Mdot
.18042 .15297 Mdot
.15689 .12944 Mdot
.16473 .1216 Mdot
.16081 .11376 Mdot
.15689 .10591 Mdot
.16473 .10199 Mdot
.16473 .09807 Mdot
.16865 .10983 Mdot
.1765 .11376 Mdot
.18042 .11376 Mdot
.17257 .11768 Mdot
.16865 .11376 Mdot
.17257 .12552 Mdot
.16081 .11768 Mdot
.13728 .09807 Mdot
.12944 .09415 Mdot
.12552 .09023 Mdot
.12552 .09415 Mdot
.12552 .10199 Mdot
.12552 .10591 Mdot
.12944 .10983 Mdot
.13728 .1216 Mdot
.13728 .11768 Mdot
.12552 .10199 Mdot
.11376 .08631 Mdot
.11768 .08631 Mdot
.11768 .07062 Mdot
.11768 .06278 Mdot
.11768 .06278 Mdot
.10591 .05494 Mdot
.10591 .06278 Mdot
.09807 .05102 Mdot
.09415 .03925 Mdot
.07454 .02749 Mdot
.02749 .0118 Mdot
.03533 .01965 Mdot
.04317 .01965 Mdot
.05102 .01572 Mdot
.04317 .0118 Mdot
.03925 .00396 Mdot
.03141 .00396 Mdot
.03925 .00788 Mdot
.04317 .00396 Mdot
.03925 .00396 Mdot
.05102 .00396 Mdot
.05494 .00788 Mdot
.06278 .01572 Mdot
.05886 .00788 Mdot
.0667 .00788 Mdot
.05494 .00788 Mdot
.05102 .00788 Mdot
.04709 .00788 Mdot
.03533 .00396 Mdot
.03925 .00788 Mdot
.06278 .03533 Mdot
.10983 .09023 Mdot
.15297 .13728 Mdot
.16865 .16081 Mdot
.17257 .1765 Mdot
.16473 .1765 Mdot
.17257 .17257 Mdot
.16473 .14905 Mdot
.16081 .13336 Mdot
.16081 .11376 Mdot
.16473 .10199 Mdot
.16473 .08631 Mdot
.16865 .08631 Mdot
.18042 .09023 Mdot
.1765 .09415 Mdot
.18826 .11376 Mdot
.20394 .14513 Mdot
.20394 .15297 Mdot
.20394 .16473 Mdot
.18826 .17257 Mdot
.18826 .18434 Mdot
.1765 .18434 Mdot
.18042 .18042 Mdot
.18042 .17257 Mdot
.19218 .16473 Mdot
.20394 .15689 Mdot
.21179 .15297 Mdot
.21179 .13728 Mdot
.21571 .13336 Mdot
.21963 .12944 Mdot
.23924 .14513 Mdot
.22747 .14905 Mdot
.23139 .15297 Mdot
.22747 .16473 Mdot
.21963 .18042 Mdot
.20787 .18042 Mdot
.20394 .18042 Mdot
.20394 .18434 Mdot
.20394 .17257 Mdot
.20002 .16081 Mdot
.19218 .14905 Mdot
.18434 .1412 Mdot
.18042 .12944 Mdot
.19218 .12944 Mdot
.20394 .13336 Mdot
.21963 .13728 Mdot
.21963 .13728 Mdot
.23531 .15297 Mdot
.23531 .16081 Mdot
.22747 .16081 Mdot
.22747 .16473 Mdot
.21571 .17257 Mdot
.20787 .16865 Mdot
.22747 .18042 Mdot
.21571 .16865 Mdot
.21179 .16473 Mdot
.22355 .16865 Mdot
.21963 .15689 Mdot
.21179 .14513 Mdot
.20394 .13336 Mdot
.21571 .1412 Mdot
.22747 .14513 Mdot
.23139 .14905 Mdot
.23531 .16081 Mdot
.22747 .16473 Mdot
.22747 .17257 Mdot
.21179 .16081 Mdot
.20002 .16081 Mdot
.1961 .16081 Mdot
.18826 .15689 Mdot
.16865 .14513 Mdot
.17257 .14513 Mdot
.17257 .1412 Mdot
.16865 .12944 Mdot
.16473 .11376 Mdot
.1765 .10983 Mdot
.18434 .10199 Mdot
.19218 .09807 Mdot
.1961 .08631 Mdot
.20002 .09807 Mdot
.21571 .13336 Mdot
.21179 .13728 Mdot
.21571 .15297 Mdot
.22355 .1765 Mdot
.22355 .18434 Mdot
.21963 .18826 Mdot
.20394 .18434 Mdot
.1961 .18042 Mdot
.1765 .15689 Mdot
.18434 .14905 Mdot
.1961 .14905 Mdot
.20394 .14513 Mdot
.20787 .14513 Mdot
.20394 .13336 Mdot
.20002 .12552 Mdot
.1961 .1216 Mdot
.20787 .13336 Mdot
.20787 .13728 Mdot
.20787 .14513 Mdot
.20787 .14905 Mdot
.21179 .16865 Mdot
.20002 .1765 Mdot
.19218 .1765 Mdot
.1961 .18042 Mdot
.18826 .17257 Mdot
.1765 .15689 Mdot
.1765 .15297 Mdot
.16865 .1412 Mdot
.16473 .13336 Mdot
.16473 .12944 Mdot
.16081 .11376 Mdot
.16865 .11376 Mdot
.17257 .10591 Mdot
.17257 .10983 Mdot
.1765 .10983 Mdot
.18434 .11376 Mdot
.18042 .10983 Mdot
.18826 .12552 Mdot
.18434 .13336 Mdot
.17257 .12944 Mdot
.16081 .12552 Mdot
.1412 .11768 Mdot
.13728 .11376 Mdot
.12944 .11376 Mdot
.13336 .11768 Mdot
.12944 .11768 Mdot
.12944 .1216 Mdot
.13336 .1216 Mdot
.13336 .1216 Mdot
.12552 .10591 Mdot
.1216 .09415 Mdot
.1216 .08239 Mdot
.12552 .07454 Mdot
.11376 .05886 Mdot
.11768 .05886 Mdot
.1216 .06278 Mdot
.1216 .05886 Mdot
.11768 .05494 Mdot
.11768 .04709 Mdot
.09023 .03141 Mdot
.03925 .01965 Mdot
.05102 .02357 Mdot
.07062 .03141 Mdot
.06278 .02357 Mdot
.05102 .01965 Mdot
.03925 .0118 Mdot
.03141 .00396 Mdot
.04317 .00788 Mdot
.03925 .00396 Mdot
.04709 .00788 Mdot
.03925 .00396 Mdot
.02749 .00396 Mdot
.04317 .00396 Mdot
.05494 .00788 Mdot
.05886 .01572 Mdot
.05886 .01572 Mdot
.05886 .02357 Mdot
.05494 .02357 Mdot
.04317 .02357 Mdot
.03925 .03141 Mdot
.03141 .03533 Mdot
.07846 .08239 Mdot
.10591 .11376 Mdot
.13728 .15297 Mdot
.15689 .16865 Mdot
.16473 .17257 Mdot
.16081 .15689 Mdot
.16473 .14513 Mdot
.16081 .12552 Mdot
.15689 .10983 Mdot
.16473 .10199 Mdot
.17257 .09415 Mdot
.18826 .09807 Mdot
.18826 .10983 Mdot
.19218 .11768 Mdot
.20002 .13336 Mdot
.20394 .15297 Mdot
.20787 .16865 Mdot
.20002 .16865 Mdot
.1961 .17257 Mdot
.1961 .18434 Mdot
.1961 .18826 Mdot
.1961 .18042 Mdot
.19218 .16865 Mdot
.20002 .16473 Mdot
.1961 .15297 Mdot
.21571 .15297 Mdot
.23924 .16473 Mdot
.23531 .15689 Mdot
.24316 .14905 Mdot
.24708 .15689 Mdot
.24708 .17257 Mdot
.24316 .18434 Mdot
.22747 .18434 Mdot
.22747 .1961 Mdot
.21963 .20002 Mdot
.21963 .20394 Mdot
.21571 .1961 Mdot
.20787 .18434 Mdot
.20002 .17257 Mdot
.20787 .16865 Mdot
.20394 .15689 Mdot
.20394 .1412 Mdot
.21571 .1412 Mdot
.21963 .1412 Mdot
.23924 .14905 Mdot
.23924 .15689 Mdot
.251 .17257 Mdot
.24316 .18434 Mdot
.23139 .18434 Mdot
.22355 .1961 Mdot
.22747 .20002 Mdot
.21963 .1961 Mdot
.20787 .18434 Mdot
.21963 .18434 Mdot
.21179 .17257 Mdot
.22355 .17257 Mdot
.22747 .15689 Mdot
.22747 .15689 Mdot
.22355 .14905 Mdot
.22747 .14905 Mdot
.22747 .14513 Mdot
.23924 .16473 Mdot
.23531 .17257 Mdot
.23924 .19218 Mdot
.23531 .20002 Mdot
.21963 .19218 Mdot
.20394 .18042 Mdot
.20787 .1765 Mdot
.19218 .16473 Mdot
.18042 .14905 Mdot
.18434 .14905 Mdot
.1765 .13336 Mdot
.18042 .1216 Mdot
.16865 .10199 Mdot
.16473 .08239 Mdot
.16865 .08239 Mdot
.18042 .08239 Mdot
.19218 .08631 Mdot
.20394 .10199 Mdot
.21179 .12552 Mdot
.21179 .13728 Mdot
.21571 .16081 Mdot
.21571 .16865 Mdot
.21179 .18042 Mdot
.20787 .18826 Mdot
.21179 .18434 Mdot
.20002 .17257 Mdot
.1961 .15297 Mdot
.18826 .12944 Mdot
.18434 .10199 Mdot
.19218 .09807 Mdot
.20002 .10199 Mdot
.1961 .10591 Mdot
.20394 .11768 Mdot
.21571 .12944 Mdot
.22355 .14905 Mdot
.21963 .14905 Mdot
.20787 .15689 Mdot
.20002 .16081 Mdot
.19218 .15689 Mdot
.18826 .17257 Mdot
.19218 .19218 Mdot
.17257 .17257 Mdot
.17257 .16473 Mdot
.16081 .14905 Mdot
.16473 .1412 Mdot
.16473 .12944 Mdot
.17257 .13336 Mdot
.18042 .1412 Mdot
.17257 .12944 Mdot
.1765 .1216 Mdot
.18042 .11768 Mdot
.18434 .1216 Mdot
.19218 .12552 Mdot
.1961 .13336 Mdot
.20002 .14513 Mdot
.19218 .14905 Mdot
.1765 .13728 Mdot
.17257 .14513 Mdot
.15689 .14513 Mdot
.15297 .14513 Mdot
.13336 .12944 Mdot
.11376 .11376 Mdot
.1216 .11768 Mdot
.11768 .10983 Mdot
.12552 .11376 Mdot
.12944 .10983 Mdot
.13728 .10983 Mdot
.13336 .09807 Mdot
.1216 .07846 Mdot
.12552 .07454 Mdot
.12552 .07062 Mdot
.1216 .05886 Mdot
.11768 .04317 Mdot
.12552 .04709 Mdot
.1216 .04317 Mdot
.12552 .05102 Mdot
.1216 .05494 Mdot
.11376 .05102 Mdot
.05886 .03925 Mdot
.05494 .03533 Mdot
.05494 .03533 Mdot
.04709 .02357 Mdot
.02749 .0118 Mdot
.01965 .0118 Mdot
.02357 .00788 Mdot
.04709 .01965 Mdot
.05494 .02357 Mdot
.04709 .00788 Mdot
.04317 .00788 Mdot
.03533 .00396 Mdot
.04317 .00396 Mdot
.04709 .0118 Mdot
.06278 .02357 Mdot
.05886 .01965 Mdot
.04317 .01572 Mdot
.03141 .00788 Mdot
.02749 .00788 Mdot
.03925 .03141 Mdot
.04709 .04317 Mdot
.04317 .04709 Mdot
.06278 .07846 Mdot
.09415 .11768 Mdot
.13336 .14905 Mdot
.14905 .15689 Mdot
.15689 .16081 Mdot
.15297 .14513 Mdot
.15689 .13336 Mdot
.17257 .12552 Mdot
.1765 .1216 Mdot
.1765 .11768 Mdot
.18826 .11768 Mdot
.18434 .10983 Mdot
.18826 .12552 Mdot
.18826 .13728 Mdot
.20787 .15689 Mdot
.21571 .1765 Mdot
.20002 .1765 Mdot
.20394 .18434 Mdot
.21571 .20002 Mdot
.20394 .19218 Mdot
.1961 .18042 Mdot
.18826 .16473 Mdot
.19218 .15689 Mdot
.19218 .1412 Mdot
.21179 .14513 Mdot
.21963 .14905 Mdot
.22355 .15297 Mdot
.22747 .15297 Mdot
.22747 .15689 Mdot
.22747 .15689 Mdot
.23924 .1765 Mdot
.22747 .18434 Mdot
.23139 .18826 Mdot
.22355 .18826 Mdot
.21963 .1961 Mdot
.21179 .18826 Mdot
.20787 .18042 Mdot
.21571 .18434 Mdot
.21963 .18042 Mdot
.21571 .17257 Mdot
.21179 .15689 Mdot
.21963 .14905 Mdot
.22355 .1412 Mdot
.23139 .14513 Mdot
.23924 .15689 Mdot
.24316 .16865 Mdot
.23531 .18042 Mdot
.23139 .18826 Mdot
.23139 .20787 Mdot
.21571 .20787 Mdot
.20787 .20002 Mdot
.21963 .20787 Mdot
.21179 .1961 Mdot
.21571 .18042 Mdot
.22355 .16865 Mdot
.23139 .16473 Mdot
.22747 .15297 Mdot
.21963 .14513 Mdot
.21963 .15297 Mdot
.22355 .16081 Mdot
.23924 .17257 Mdot
.23924 .18042 Mdot
.24708 .1961 Mdot
.24316 .20002 Mdot
.22747 .20394 Mdot
.21179 .19218 Mdot
.20787 .18434 Mdot
.20394 .16865 Mdot
.20002 .16081 Mdot
.18826 .13728 Mdot
.18042 .12552 Mdot
.18434 .10983 Mdot
.1765 .09415 Mdot
.16865 .09023 Mdot
.16473 .08631 Mdot
.16865 .08631 Mdot
.17257 .08631 Mdot
.18434 .09023 Mdot
.18826 .10983 Mdot
.18826 .11768 Mdot
.20002 .1412 Mdot
.20002 .14905 Mdot
.1961 .16081 Mdot
.20002 .1765 Mdot
.20394 .17257 Mdot
.20002 .15689 Mdot
.1961 .14513 Mdot
.18826 .12552 Mdot
.18042 .10983 Mdot
.19218 .10199 Mdot
.20002 .10591 Mdot
.20394 .10591 Mdot
.21179 .11768 Mdot
.21571 .12944 Mdot
.21963 .1412 Mdot
.21963 .15297 Mdot
.21571 .16865 Mdot
.1961 .15689 Mdot
.18042 .15297 Mdot
.16865 .15689 Mdot
.15689 .15297 Mdot
.16473 .16865 Mdot
.16865 .15689 Mdot
.17257 .14905 Mdot
.18042 .14905 Mdot
.18042 .13728 Mdot
.17257 .1216 Mdot
.18042 .13336 Mdot
.18826 .13728 Mdot
.18434 .12552 Mdot
.19218 .1216 Mdot
.18826 .11768 Mdot
.1961 .12552 Mdot
.19218 .12552 Mdot
.18826 .12944 Mdot
.20002 .15297 Mdot
.18042 .14905 Mdot
.18042 .15689 Mdot
.16865 .16081 Mdot
.14905 .14905 Mdot
.13336 .12944 Mdot
.12552 .11768 Mdot
.1216 .11376 Mdot
.11768 .10591 Mdot
.12552 .10591 Mdot
.12552 .09807 Mdot
.1216 .09023 Mdot
.12944 .09023 Mdot
.12552 .09023 Mdot
.12944 .07846 Mdot
.12552 .07062 Mdot
.11768 .05886 Mdot
.10199 .04317 Mdot
.1216 .04709 Mdot
.12552 .05886 Mdot
.12552 .05886 Mdot
.1216 .05494 Mdot
.11376 .05494 Mdot
.06278 .05494 Mdot
.05102 .05102 Mdot
.04317 .03925 Mdot
.03925 .03141 Mdot
.04317 .03925 Mdot
.02749 .02357 Mdot
.02357 .0118 Mdot
.02749 .00788 Mdot
.03925 .01572 Mdot
.03141 .00788 Mdot
.02749 .00788 Mdot
.03533 .00396 Mdot
.03533 .00396 Mdot
.04317 .00788 Mdot
.03925 .00788 Mdot
.03925 .00788 Mdot
.03533 .00788 Mdot
.02357 .00396 Mdot
.01965 .00396 Mdot
.05886 .03141 Mdot
.09023 .07062 Mdot
.09415 .08631 Mdot
.09023 .10199 Mdot
.09807 .11768 Mdot
.10983 .14513 Mdot
.13336 .16473 Mdot
.14513 .1765 Mdot
.15297 .1765 Mdot
.14905 .16473 Mdot
.16473 .15689 Mdot
.17257 .14513 Mdot
.18042 .13728 Mdot
.18826 .12944 Mdot
.18826 .12552 Mdot
.19218 .12944 Mdot
.20002 .13728 Mdot
.20787 .14905 Mdot
.22747 .17257 Mdot
.22747 .18042 Mdot
.21571 .18042 Mdot
.21963 .18826 Mdot
.20787 .18826 Mdot
.20787 .18434 Mdot
.20787 .18826 Mdot
.1961 .16865 Mdot
.20002 .16473 Mdot
.20787 .16473 Mdot
.21179 .15297 Mdot
.22747 .15689 Mdot
.22355 .15297 Mdot
.22355 .14905 Mdot
.22355 .14513 Mdot
.23531 .15689 Mdot
.23139 .16473 Mdot
.23531 .1765 Mdot
.23531 .19218 Mdot
.22747 .1961 Mdot
.22355 .20002 Mdot
.22355 .20002 Mdot
.21571 .1961 Mdot
.20787 .19218 Mdot
.21179 .1961 Mdot
.21179 .18434 Mdot
.20394 .15689 Mdot
.20787 .13728 Mdot
.21963 .1412 Mdot
.22747 .1412 Mdot
.22747 .14513 Mdot
.23531 .15689 Mdot
.23924 .16865 Mdot
.23531 .18434 Mdot
.22355 .1961 Mdot
.21179 .19218 Mdot
.20787 .19218 Mdot
.21179 .19218 Mdot
.21963 .18826 Mdot
.22355 .18434 Mdot
.23139 .18042 Mdot
.24708 .17257 Mdot
.24316 .16473 Mdot
.23924 .16865 Mdot
.23924 .16865 Mdot
.24316 .17257 Mdot
.251 .18434 Mdot
.24708 .18042 Mdot
.251 .19218 Mdot
.24708 .20002 Mdot
.23139 .20002 Mdot
.23531 .20002 Mdot
.21963 .18826 Mdot
.20787 .18042 Mdot
.20002 .16473 Mdot
.18434 .1412 Mdot
.18042 .12552 Mdot
.1765 .10983 Mdot
.16081 .09807 Mdot
.16865 .10591 Mdot
.17257 .10591 Mdot
.16865 .09807 Mdot
.1765 .10199 Mdot
.1765 .10199 Mdot
.18434 .1216 Mdot
.19218 .13336 Mdot
.20787 .14513 Mdot
.21571 .15689 Mdot
.21179 .16081 Mdot
.21963 .16865 Mdot
.20394 .15297 Mdot
.20394 .14905 Mdot
.1961 .14513 Mdot
.20002 .14513 Mdot
.20002 .13336 Mdot
.19218 .11768 Mdot
.19218 .11376 Mdot
.20002 .11768 Mdot
.20787 .1216 Mdot
.21571 .12944 Mdot
.22355 .14513 Mdot
.22747 .15689 Mdot
.20787 .14905 Mdot
.19218 .14513 Mdot
.18434 .15689 Mdot
.1765 .15689 Mdot
.17257 .15297 Mdot
.1765 .15297 Mdot
.18042 .15297 Mdot
.18434 .14513 Mdot
.18434 .14513 Mdot
.18042 .13728 Mdot
.18826 .14513 Mdot
.18434 .13728 Mdot
.18826 .13728 Mdot
.18042 .12552 Mdot
.18434 .1216 Mdot
.18826 .1216 Mdot
.1961 .12944 Mdot
.18826 .12552 Mdot
.18826 .13336 Mdot
.19218 .13728 Mdot
.18042 .13728 Mdot
.1765 .13728 Mdot
.17257 .1412 Mdot
.16081 .12944 Mdot
.14513 .11768 Mdot
.13728 .11376 Mdot
.12552 .10591 Mdot
.12552 .10199 Mdot
.12552 .10199 Mdot
.11768 .09807 Mdot
.1216 .09415 Mdot
.12944 .09807 Mdot
.13336 .09807 Mdot
.13336 .09415 Mdot
.13336 .08631 Mdot
.1216 .07454 Mdot
.11768 .0667 Mdot
.1216 .0667 Mdot
.1216 .0667 Mdot
.11768 .07062 Mdot
.11376 .07062 Mdot
.04709 .04317 Mdot
.04709 .04709 Mdot
.03533 .03141 Mdot
.03925 .03141 Mdot
.04317 .03141 Mdot
.03141 .02357 Mdot
.02357 .01572 Mdot
.02749 .01965 Mdot
.02749 .0118 Mdot
.03141 .01572 Mdot
.03533 .01572 Mdot
.03141 .0118 Mdot
.03141 .00788 Mdot
.03533 .00788 Mdot
.02749 .00396 Mdot
.02357 .00396 Mdot
.01965 .00396 Mdot
.01965 .00396 Mdot
.01572 .00396 Mdot
.01965 .00396 Mdot
.0667 .04709 Mdot
.1216 .10199 Mdot
.18042 .16865 Mdot
.20002 .1961 Mdot
.18826 .20002 Mdot
.17257 .18826 Mdot
.16865 .19218 Mdot
.17257 .1961 Mdot
.18042 .20002 Mdot
.16473 .18042 Mdot
.16081 .15689 Mdot
.15297 .13728 Mdot
.15689 .12552 Mdot
.15689 .1216 Mdot
.16865 .11768 Mdot
.16865 .11376 Mdot
.18434 .12552 Mdot
.19218 .13728 Mdot
.20787 .15689 Mdot
.20394 .16865 Mdot
.20787 .1765 Mdot
.21179 .18042 Mdot
.20002 .1765 Mdot
.21179 .18826 Mdot
.18434 .16473 Mdot
.19218 .16473 Mdot
.19218 .14905 Mdot
.20787 .15689 Mdot
.20394 .14905 Mdot
.20787 .14513 Mdot
.20787 .1412 Mdot
.20394 .13336 Mdot
.21571 .14513 Mdot
.21571 .14905 Mdot
.22355 .16865 Mdot
.22747 .1765 Mdot
.21963 .16865 Mdot
.21179 .16865 Mdot
.21963 .18434 Mdot
.21571 .18826 Mdot
.22355 .1961 Mdot
.21179 .1961 Mdot
.21179 .19218 Mdot
.20787 .18042 Mdot
.21571 .16865 Mdot
.21571 .15297 Mdot
.21571 .14905 Mdot
.20787 .13728 Mdot
.21963 .1412 Mdot
.21571 .13728 Mdot
.22747 .15297 Mdot
.23139 .16473 Mdot
.23139 .17257 Mdot
.22747 .17257 Mdot
.21571 .16865 Mdot
.21571 .17257 Mdot
.23531 .18826 Mdot
.23924 .18042 Mdot
.23924 .17257 Mdot
.23531 .16473 Mdot
.23924 .17257 Mdot
.23139 .16865 Mdot
.23924 .1765 Mdot
.22355 .16081 Mdot
.23139 .16865 Mdot
.23924 .17257 Mdot
.23924 .18042 Mdot
.23924 .19218 Mdot
.23531 .20002 Mdot
.23139 .1961 Mdot
.22747 .19218 Mdot
.21179 .17257 Mdot
.18434 .1412 Mdot
.1765 .12944 Mdot
.16865 .1216 Mdot
.16473 .11768 Mdot
.16473 .11768 Mdot
.16865 .11376 Mdot
.17257 .11376 Mdot
.1765 .11768 Mdot
.16865 .11376 Mdot
.16473 .10591 Mdot
.1765 .10983 Mdot
.18042 .11768 Mdot
.19218 .12944 Mdot
.1961 .13336 Mdot
.19218 .13336 Mdot
.20002 .1412 Mdot
.20394 .14513 Mdot
.20787 .14905 Mdot
.20787 .15689 Mdot
.21571 .16081 Mdot
.21179 .15297 Mdot
.20002 .13336 Mdot
.20002 .12552 Mdot
.1961 .1216 Mdot
.18434 .10983 Mdot
.20394 .11768 Mdot
.22355 .1412 Mdot
.22747 .14905 Mdot
.21571 .14513 Mdot
.20394 .15297 Mdot
.19218 .15689 Mdot
.18042 .14513 Mdot
.18042 .14513 Mdot
.18042 .14905 Mdot
.18826 .16081 Mdot
.18434 .15689 Mdot
.16865 .14905 Mdot
.16865 .14905 Mdot
.16473 .1412 Mdot
.16865 .12944 Mdot
.17257 .1216 Mdot
.1765 .1216 Mdot
.18434 .11768 Mdot
.1961 .11768 Mdot
.18826 .11376 Mdot
.18042 .10983 Mdot
.18434 .11768 Mdot
.18434 .11376 Mdot
.18826 .10983 Mdot
.16865 .09415 Mdot
.18042 .10983 Mdot
.16865 .11768 Mdot
.15297 .11768 Mdot
.14513 .1216 Mdot
.13336 .11376 Mdot
.13336 .11376 Mdot
.12552 .1216 Mdot
.1216 .11376 Mdot
.1216 .11376 Mdot
.11768 .10591 Mdot
.1216 .09415 Mdot
.10983 .08631 Mdot
.11376 .08239 Mdot
.1216 .08631 Mdot
.13336 .08631 Mdot
.12552 .07846 Mdot
.1216 .07846 Mdot
.10983 .07454 Mdot
.03141 .01572 Mdot
.03533 .01965 Mdot
.03925 .02357 Mdot
.03925 .01572 Mdot
.03141 .0118 Mdot
.03533 .01572 Mdot
.04709 .02357 Mdot
.05886 .04317 Mdot
.06278 .04317 Mdot
.05494 .03533 Mdot
.06278 .03925 Mdot
.05102 .02357 Mdot
.04317 .0118 Mdot
.03533 .00788 Mdot
.02749 .00396 Mdot
.01965 .00396 Mdot
.01965 .00396 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.00788 .00396 Mdot
.07062 .05494 Mdot
.22355 .1961 Mdot
.22355 .20002 Mdot
.20394 .19218 Mdot
.20394 .20002 Mdot
.20002 .20002 Mdot
.20002 .1961 Mdot
.21571 .21179 Mdot
.20002 .20002 Mdot
.15297 .15689 Mdot
.12944 .1216 Mdot
.1216 .10591 Mdot
.1216 .08631 Mdot
.12552 .07846 Mdot
.13728 .08239 Mdot
.1412 .08631 Mdot
.14513 .08631 Mdot
.16473 .10199 Mdot
.18042 .13336 Mdot
.19218 .15297 Mdot
.20394 .16473 Mdot
.21571 .17257 Mdot
.22747 .18826 Mdot
.22747 .18434 Mdot
.21179 .16865 Mdot
.21571 .16473 Mdot
.22355 .16081 Mdot
.21179 .15297 Mdot
.22355 .16473 Mdot
.21963 .15689 Mdot
.22355 .16473 Mdot
.21963 .16081 Mdot
.21963 .16473 Mdot
.21963 .16081 Mdot
.22355 .16473 Mdot
.22355 .16865 Mdot
.21963 .16473 Mdot
.21963 .16865 Mdot
.21963 .16473 Mdot
.22355 .17257 Mdot
.23139 .18826 Mdot
.22747 .19218 Mdot
.22355 .18826 Mdot
.22355 .18826 Mdot
.22747 .18042 Mdot
.22747 .17257 Mdot
.20787 .14513 Mdot
.21571 .14513 Mdot
.21571 .1412 Mdot
.21571 .1412 Mdot
.22355 .1412 Mdot
.21963 .14513 Mdot
.22355 .15689 Mdot
.21963 .16081 Mdot
.21571 .15297 Mdot
.23139 .16081 Mdot
.22747 .15297 Mdot
.23531 .16473 Mdot
.23924 .1765 Mdot
.23531 .18434 Mdot
.23531 .1961 Mdot
.22355 .18434 Mdot
.21571 .17257 Mdot
.21571 .16865 Mdot
.22355 .16865 Mdot
.22747 .16865 Mdot
.23139 .17257 Mdot
.23139 .17257 Mdot
.23531 .1765 Mdot
.23924 .18434 Mdot
.21571 .16081 Mdot
.20002 .14513 Mdot
.18042 .12944 Mdot
.17257 .12552 Mdot
.17257 .12552 Mdot
.16865 .11376 Mdot
.1765 .1216 Mdot
.1765 .1216 Mdot
.17257 .11376 Mdot
.16081 .10591 Mdot
.16473 .10983 Mdot
.16865 .11376 Mdot
.16865 .11376 Mdot
.1765 .11376 Mdot
.1765 .11376 Mdot
.1765 .11376 Mdot
.1961 .12552 Mdot
.21179 .13336 Mdot
.21571 .14513 Mdot
.21571 .15297 Mdot
.21963 .16865 Mdot
.21963 .16865 Mdot
.21571 .16473 Mdot
.20787 .14905 Mdot
.1961 .13336 Mdot
.18434 .11768 Mdot
.1961 .12552 Mdot
.20394 .13336 Mdot
.19218 .1216 Mdot
.20002 .12944 Mdot
.20002 .13728 Mdot
.18434 .13336 Mdot
.18042 .13336 Mdot
.18434 .12944 Mdot
.17257 .12552 Mdot
.16081 .11768 Mdot
.1765 .12552 Mdot
.18042 .14513 Mdot
.1765 .14905 Mdot
.17257 .14513 Mdot
.1765 .14513 Mdot
.1765 .1412 Mdot
.17257 .12944 Mdot
.18042 .12552 Mdot
.18826 .12944 Mdot
.18042 .11768 Mdot
.18042 .11768 Mdot
.16865 .10591 Mdot
.16473 .09807 Mdot
.17257 .09807 Mdot
.16081 .08239 Mdot
.15297 .07846 Mdot
.14513 .08631 Mdot
.15297 .10199 Mdot
.14905 .10591 Mdot
.12944 .10199 Mdot
.13728 .11376 Mdot
.12944 .11768 Mdot
.13336 .1216 Mdot
.12944 .1216 Mdot
.12552 .11768 Mdot
.11376 .10199 Mdot
.10983 .10199 Mdot
.1216 .10591 Mdot
.10983 .09415 Mdot
.11376 .09807 Mdot
.12944 .10591 Mdot
.12944 .10591 Mdot
.11376 .09023 Mdot
.02357 .0118 Mdot
.02357 .00396 Mdot
.04317 .0118 Mdot
.05494 .01572 Mdot
.04317 .0118 Mdot
.04709 .01965 Mdot
.0667 .03925 Mdot
.07846 .05886 Mdot
.09023 .0667 Mdot
.07846 .0667 Mdot
.08631 .07454 Mdot
.07846 .05494 Mdot
.07062 .03533 Mdot
.04709 .01965 Mdot
.03141 .0118 Mdot
.01965 .00788 Mdot
.02749 .00788 Mdot
.02749 .0118 Mdot
.01572 .00396 Mdot
.0118 .00396 Mdot
.01965 .0118 Mdot
.01572 .00788 Mdot
.08631 .06278 Mdot
.11376 .08239 Mdot
.18042 .1412 Mdot
.27845 .23139 Mdot
.1961 .15689 Mdot
.19218 .15689 Mdot
.21963 .18826 Mdot
.20002 .18042 Mdot
.09807 .09023 Mdot
.08631 .07846 Mdot
.0667 .05494 Mdot
.07062 .04709 Mdot
.07454 .04317 Mdot
.10199 .05102 Mdot
.11768 .05886 Mdot
.1216 .06278 Mdot
.1412 .08239 Mdot
.17257 .11768 Mdot
.1961 .14905 Mdot
.21179 .16865 Mdot
.21963 .18042 Mdot
.23139 .18434 Mdot
.22355 .17257 Mdot
.22747 .17257 Mdot
.23139 .16473 Mdot
.23924 .16473 Mdot
.24316 .16081 Mdot
.25492 .17257 Mdot
.25492 .18042 Mdot
.251 .18042 Mdot
.24708 .18042 Mdot
.23531 .1765 Mdot
.23139 .1765 Mdot
.23531 .1765 Mdot
.23531 .18042 Mdot
.23924 .18826 Mdot
.24708 .18826 Mdot
.22355 .17257 Mdot
.23139 .1765 Mdot
.23139 .18042 Mdot
.24316 .19218 Mdot
.23924 .19218 Mdot
.23924 .1961 Mdot
.24708 .19218 Mdot
.24316 .1765 Mdot
.23139 .16473 Mdot
.22747 .15689 Mdot
.23139 .15689 Mdot
.24316 .16473 Mdot
.23531 .16081 Mdot
.23531 .16081 Mdot
.22747 .15689 Mdot
.23139 .16081 Mdot
.23531 .16081 Mdot
.23139 .15689 Mdot
.23531 .15689 Mdot
.251 .16865 Mdot
.25884 .18826 Mdot
.26668 .20002 Mdot
.25884 .21179 Mdot
.24316 .20002 Mdot
.23139 .1961 Mdot
.22355 .18042 Mdot
.21571 .16865 Mdot
.22355 .17257 Mdot
.22747 .17257 Mdot
.22355 .16081 Mdot
.23531 .17257 Mdot
.23139 .1765 Mdot
.23139 .18042 Mdot
.22355 .17257 Mdot
.20787 .15689 Mdot
.18042 .13336 Mdot
.18042 .13336 Mdot
.18042 .12944 Mdot
.1765 .1216 Mdot
.18434 .12552 Mdot
.19218 .13336 Mdot
.18434 .12552 Mdot
.1765 .12552 Mdot
.1765 .12944 Mdot
.18042 .1216 Mdot
.1765 .11376 Mdot
.1765 .1216 Mdot
.17257 .11376 Mdot
.18042 .1216 Mdot
.18434 .12552 Mdot
.19218 .12944 Mdot
.20002 .13728 Mdot
.20787 .14513 Mdot
.20787 .15297 Mdot
.21963 .16865 Mdot
.21963 .16865 Mdot
.21963 .16081 Mdot
.20394 .1412 Mdot
.20394 .1412 Mdot
.19218 .13728 Mdot
.1961 .14513 Mdot
.18826 .1412 Mdot
.20002 .14905 Mdot
.20002 .14905 Mdot
.1961 .14905 Mdot
.18042 .13728 Mdot
.18434 .13336 Mdot
.18434 .12944 Mdot
.18042 .1216 Mdot
.18434 .13728 Mdot
.20002 .15689 Mdot
.20002 .16081 Mdot
.18826 .14905 Mdot
.18434 .1412 Mdot
.16865 .13336 Mdot
.18434 .1412 Mdot
.18042 .13336 Mdot
.18434 .13336 Mdot
.18434 .12944 Mdot
.1765 .12552 Mdot
.17257 .11768 Mdot
.17257 .11376 Mdot
.16081 .10199 Mdot
.15689 .09023 Mdot
.15297 .09415 Mdot
.15689 .10591 Mdot
.14905 .10591 Mdot
.14905 .10591 Mdot
.1412 .10591 Mdot
.14513 .1216 Mdot
.14513 .1216 Mdot
.13728 .11768 Mdot
.12552 .10591 Mdot
.1216 .10591 Mdot
.11768 .10199 Mdot
.11768 .09415 Mdot
.11768 .09415 Mdot
.1216 .09807 Mdot
.1216 .10199 Mdot
.12944 .10199 Mdot
.11768 .09415 Mdot
.02749 .02357 Mdot
.03925 .02749 Mdot
.03533 .01572 Mdot
.03141 .0118 Mdot
.03533 .0118 Mdot
.03141 .0118 Mdot
.04317 .03533 Mdot
.05494 .04709 Mdot
.07846 .06278 Mdot
.09023 .07454 Mdot
.09415 .08239 Mdot
.09807 .08239 Mdot
.08631 .0667 Mdot
.05494 .03533 Mdot
.03925 .01572 Mdot
.02357 .00788 Mdot
.02749 .00788 Mdot
.01572 .00788 Mdot
.01965 .0118 Mdot
.00788 .00788 Mdot
.0118 .00788 Mdot
.02749 .0118 Mdot
.04317 .01965 Mdot
.04709 .0118 Mdot
.05886 .01965 Mdot
.15297 .09807 Mdot
.15689 .10983 Mdot
.16473 .11768 Mdot
.24316 .1961 Mdot
.23924 .20394 Mdot
.15297 .13336 Mdot
.10983 .10591 Mdot
.0667 .0667 Mdot
.05886 .04709 Mdot
.06278 .03925 Mdot
.07062 .03925 Mdot
.08239 .05102 Mdot
.09807 .05886 Mdot
.1412 .09807 Mdot
.17257 .1216 Mdot
.20394 .15297 Mdot
.21179 .16081 Mdot
.23139 .18826 Mdot
.23139 .18434 Mdot
.22747 .1765 Mdot
.22355 .16865 Mdot
.23531 .1765 Mdot
.23531 .16865 Mdot
.24708 .17257 Mdot
.25492 .18042 Mdot
.26276 .19218 Mdot
.25492 .19218 Mdot
.24316 .1765 Mdot
.24316 .18434 Mdot
.23924 .18042 Mdot
.24316 .18434 Mdot
.25492 .1961 Mdot
.25492 .20002 Mdot
.251 .1961 Mdot
.24316 .18826 Mdot
.23924 .1961 Mdot
.23924 .20002 Mdot
.24316 .19218 Mdot
.25492 .19218 Mdot
.251 .1961 Mdot
.251 .19218 Mdot
.23924 .1765 Mdot
.23924 .18042 Mdot
.23139 .1765 Mdot
.24316 .18042 Mdot
.23924 .18042 Mdot
.24316 .18434 Mdot
.23531 .18434 Mdot
.24316 .18042 Mdot
.23924 .16865 Mdot
.23924 .16473 Mdot
.24708 .17257 Mdot
.24708 .16865 Mdot
.26276 .19218 Mdot
.26668 .20002 Mdot
.26276 .20787 Mdot
.26668 .21963 Mdot
.26276 .21963 Mdot
.26276 .21963 Mdot
.24316 .1961 Mdot
.22747 .1765 Mdot
.22355 .16865 Mdot
.21571 .16081 Mdot
.21571 .15689 Mdot
.22747 .16473 Mdot
.23139 .1765 Mdot
.23924 .1961 Mdot
.24708 .20787 Mdot
.22747 .19218 Mdot
.20002 .17257 Mdot
.19218 .16865 Mdot
.18434 .16081 Mdot
.18042 .14513 Mdot
.18826 .14513 Mdot
.19218 .14513 Mdot
.19218 .13336 Mdot
.18434 .1216 Mdot
.18042 .11376 Mdot
.18042 .10983 Mdot
.18042 .10983 Mdot
.1765 .10591 Mdot
.1765 .10591 Mdot
.1765 .10983 Mdot
.1765 .1216 Mdot
.16865 .1216 Mdot
.17257 .12944 Mdot
.1765 .13728 Mdot
.1961 .14905 Mdot
.19218 .14905 Mdot
.1961 .15689 Mdot
.21179 .16473 Mdot
.20394 .14905 Mdot
.20394 .14905 Mdot
.20394 .14905 Mdot
.20002 .15297 Mdot
.1961 .13728 Mdot
.18826 .12944 Mdot
.18826 .13728 Mdot
.20002 .14513 Mdot
.19218 .14513 Mdot
.18434 .13728 Mdot
.18826 .13728 Mdot
.1765 .12944 Mdot
.18042 .13336 Mdot
.18826 .1412 Mdot
.18826 .14513 Mdot
.16865 .12944 Mdot
.1765 .13728 Mdot
.18434 .14513 Mdot
.1765 .13336 Mdot
.17257 .1216 Mdot
.16865 .11768 Mdot
.17257 .1216 Mdot
.18042 .13336 Mdot
.1765 .1216 Mdot
.17257 .10983 Mdot
.16473 .09807 Mdot
.16473 .09415 Mdot
.15689 .09415 Mdot
.15689 .09807 Mdot
.15297 .10983 Mdot
.15297 .11768 Mdot
.13728 .11768 Mdot
.1412 .1216 Mdot
.13728 .11768 Mdot
.13728 .11768 Mdot
.12944 .10983 Mdot
.12944 .09807 Mdot
.1216 .09023 Mdot
.1216 .08631 Mdot
.1216 .09023 Mdot
.12944 .10199 Mdot
.13728 .09807 Mdot
.1412 .10591 Mdot
.12944 .09023 Mdot
.03533 .04317 Mdot
.03141 .03533 Mdot
.04709 .03533 Mdot
.03141 .01965 Mdot
.01965 .00788 Mdot
.01572 .00788 Mdot
.01965 .00788 Mdot
.03533 .03141 Mdot
.04317 .04317 Mdot
.06278 .05886 Mdot
.07846 .07062 Mdot
.08239 .07454 Mdot
.07846 .0667 Mdot
.05886 .04317 Mdot
.04317 .01572 Mdot
.03141 .00396 Mdot
.02357 .00788 Mdot
.01965 .00788 Mdot
.01572 .00788 Mdot
.01572 .0118 Mdot
.01572 .01572 Mdot
.03533 .02749 Mdot
.03141 .01965 Mdot
.03141 .0118 Mdot
.03141 .00788 Mdot
.03141 .0118 Mdot
.05102 .02749 Mdot
.0667 .03925 Mdot
.1412 .10591 Mdot
.18826 .15689 Mdot
.14905 .1216 Mdot
.13336 .10983 Mdot
.1216 .09023 Mdot
.11376 .08239 Mdot
.09807 .07454 Mdot
.08239 .0667 Mdot
.08239 .07062 Mdot
.08631 .0667 Mdot
.12552 .10199 Mdot
.15297 .12944 Mdot
.18434 .15689 Mdot
.20002 .16473 Mdot
.22355 .18826 Mdot
.22747 .19218 Mdot
.22355 .18434 Mdot
.21963 .1765 Mdot
.22355 .16865 Mdot
.22747 .17257 Mdot
.23531 .1765 Mdot
.24316 .18434 Mdot
.24316 .18434 Mdot
.251 .1961 Mdot
.24316 .18434 Mdot
.23924 .18434 Mdot
.251 .1961 Mdot
.25492 .20394 Mdot
.25492 .20394 Mdot
.26276 .21179 Mdot
.251 .20002 Mdot
.25884 .20394 Mdot
.26276 .20787 Mdot
.25492 .20787 Mdot
.25492 .20002 Mdot
.251 .18826 Mdot
.25492 .18826 Mdot
.26276 .19218 Mdot
.24708 .18826 Mdot
.24708 .20002 Mdot
.24316 .20394 Mdot
.24316 .20002 Mdot
.23924 .19218 Mdot
.251 .1961 Mdot
.25492 .20002 Mdot
.251 .19218 Mdot
.24316 .17257 Mdot
.24708 .17257 Mdot
.251 .17257 Mdot
.24316 .17257 Mdot
.24316 .18042 Mdot
.25492 .19218 Mdot
.25884 .21179 Mdot
.26276 .22355 Mdot
.27845 .23924 Mdot
.26668 .22747 Mdot
.26668 .22355 Mdot
.25492 .20787 Mdot
.25884 .21963 Mdot
.23139 .20002 Mdot
.21963 .18826 Mdot
.21963 .18042 Mdot
.21963 .1765 Mdot
.23531 .18434 Mdot
.24708 .1961 Mdot
.24708 .19218 Mdot
.23139 .18434 Mdot
.21571 .1765 Mdot
.21571 .18434 Mdot
.21571 .1765 Mdot
.21179 .17257 Mdot
.1961 .16081 Mdot
.1961 .14905 Mdot
.18826 .13728 Mdot
.18826 .12552 Mdot
.18826 .11768 Mdot
.18826 .11768 Mdot
.1765 .10591 Mdot
.18042 .10983 Mdot
.18434 .11376 Mdot
.18826 .12552 Mdot
.18042 .1216 Mdot
.18042 .1216 Mdot
.1765 .1216 Mdot
.18434 .1412 Mdot
.20002 .15689 Mdot
.19218 .15297 Mdot
.20002 .16473 Mdot
.20787 .16865 Mdot
.20002 .16081 Mdot
.20002 .15297 Mdot
.1961 .1412 Mdot
.18042 .12944 Mdot
.1765 .12944 Mdot
.18042 .12944 Mdot
.19218 .13728 Mdot
.1961 .14513 Mdot
.19218 .14513 Mdot
.1961 .14513 Mdot
.18042 .12944 Mdot
.18434 .12944 Mdot
.19218 .12944 Mdot
.18826 .12552 Mdot
.19218 .13336 Mdot
.18826 .13728 Mdot
.18434 .13728 Mdot
.18826 .14513 Mdot
.1765 .1412 Mdot
.17257 .14513 Mdot
.16473 .1412 Mdot
.16473 .13728 Mdot
.16865 .12944 Mdot
.1765 .12944 Mdot
.1765 .1216 Mdot
.16865 .10591 Mdot
.16081 .09807 Mdot
.16865 .10199 Mdot
.16081 .09807 Mdot
.15689 .10983 Mdot
.14905 .10983 Mdot
.15297 .12552 Mdot
.1412 .11768 Mdot
.13728 .11376 Mdot
.13728 .11376 Mdot
.14905 .1216 Mdot
.13728 .10591 Mdot
.12944 .09415 Mdot
.1216 .09023 Mdot
.1216 .09023 Mdot
.1216 .09023 Mdot
.12552 .09807 Mdot
.11768 .09415 Mdot
.07846 .10591 Mdot
.05886 .08239 Mdot
.04709 .05886 Mdot
.03141 .03141 Mdot
.01965 .01572 Mdot
.01965 .00788 Mdot
.0118 .00396 Mdot
.03141 .01572 Mdot
.06278 .03533 Mdot
.0667 .03925 Mdot
.05886 .03141 Mdot
.0667 .03925 Mdot
.0667 .04317 Mdot
.05494 .03141 Mdot
.04317 .02357 Mdot
.04317 .01572 Mdot
.02749 .0118 Mdot
.02749 .0118 Mdot
.01965 .00788 Mdot
.02357 .0118 Mdot
.03141 .02357 Mdot
.04317 .01965 Mdot
.03141 .0118 Mdot
.01572 .00788 Mdot
.02357 .00788 Mdot
.02749 .0118 Mdot
.02749 .01572 Mdot
.03925 .01965 Mdot
.04317 .02749 Mdot
.07062 .04709 Mdot
.07454 .05102 Mdot
.07846 .05886 Mdot
.09023 .05886 Mdot
.09023 .05494 Mdot
.10199 .0667 Mdot
.13336 .09807 Mdot
.13728 .10199 Mdot
.1216 .09023 Mdot
.1216 .10199 Mdot
.13728 .1216 Mdot
.16473 .14905 Mdot
.18434 .16473 Mdot
.20394 .1765 Mdot
.21963 .18434 Mdot
.21963 .1765 Mdot
.21571 .16865 Mdot
.22747 .1765 Mdot
.22355 .17257 Mdot
.21963 .17257 Mdot
.22355 .18042 Mdot
.23924 .19218 Mdot
.24316 .1961 Mdot
.24708 .20002 Mdot
.251 .1961 Mdot
.26668 .20394 Mdot
.25492 .1961 Mdot
.25492 .19218 Mdot
.25884 .20394 Mdot
.26668 .20787 Mdot
.27845 .21179 Mdot
.26668 .20787 Mdot
.251 .20394 Mdot
.25492 .20394 Mdot
.251 .19218 Mdot
.25884 .1961 Mdot
.26276 .1961 Mdot
.251 .18434 Mdot
.251 .18826 Mdot
.24708 .1961 Mdot
.24708 .1961 Mdot
.25492 .1961 Mdot
.25492 .1961 Mdot
.25884 .20002 Mdot
.26276 .21179 Mdot
.25492 .20002 Mdot
.251 .18826 Mdot
.251 .18826 Mdot
.26276 .20002 Mdot
.25884 .20394 Mdot
.25492 .20394 Mdot
.25492 .20787 Mdot
.26276 .21179 Mdot
.27453 .21179 Mdot
.27453 .21179 Mdot
.27453 .20787 Mdot
.26668 .20002 Mdot
.25492 .20394 Mdot
.26276 .21963 Mdot
.24316 .20394 Mdot
.23924 .1961 Mdot
.22747 .18042 Mdot
.22747 .16865 Mdot
.24708 .17257 Mdot
.24316 .16865 Mdot
.251 .18042 Mdot
.251 .19218 Mdot
.25884 .20787 Mdot
.23924 .19218 Mdot
.22355 .1765 Mdot
.20787 .16865 Mdot
.19218 .16081 Mdot
.20787 .16865 Mdot
.20787 .15689 Mdot
.1961 .13336 Mdot
.19218 .12944 Mdot
.18826 .12552 Mdot
.1961 .12944 Mdot
.18826 .12944 Mdot
.19218 .13728 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.1765 .12944 Mdot
.18434 .14513 Mdot
.18042 .1412 Mdot
.18042 .1412 Mdot
.18042 .14513 Mdot
.18434 .14513 Mdot
.18434 .1412 Mdot
.18826 .13728 Mdot
.20394 .14905 Mdot
.20002 .1412 Mdot
.20002 .1412 Mdot
.19218 .13728 Mdot
.18434 .13728 Mdot
.18042 .1412 Mdot
.20002 .15297 Mdot
.19218 .1412 Mdot
.18042 .12944 Mdot
.16865 .11768 Mdot
.18826 .13336 Mdot
.18042 .12552 Mdot
.18826 .13336 Mdot
.18434 .12944 Mdot
.1765 .12552 Mdot
.1765 .13336 Mdot
.18434 .13728 Mdot
.1765 .13728 Mdot
.1765 .14905 Mdot
.16865 .13728 Mdot
.1765 .1412 Mdot
.16865 .13336 Mdot
.17257 .12552 Mdot
.16865 .11768 Mdot
.16473 .10591 Mdot
.16081 .10591 Mdot
.16473 .11376 Mdot
.16473 .11768 Mdot
.15297 .11768 Mdot
.14905 .11376 Mdot
.14513 .11376 Mdot
.1412 .11376 Mdot
.13728 .10591 Mdot
.1412 .10983 Mdot
.13728 .10199 Mdot
.12552 .09023 Mdot
.1216 .09023 Mdot
.1216 .09023 Mdot
.11768 .08631 Mdot
.11768 .09023 Mdot
.10591 .07846 Mdot
.09023 .1412 Mdot
.08631 .13728 Mdot
.08239 .12944 Mdot
.0667 .10591 Mdot
.04709 .07454 Mdot
.04317 .06278 Mdot
.03533 .04709 Mdot
.05494 .05494 Mdot
.0667 .05886 Mdot
.05494 .03141 Mdot
.04317 .01572 Mdot
.05102 .01965 Mdot
.06278 .03533 Mdot
.0667 .04317 Mdot
.06278 .03533 Mdot
.05886 .02749 Mdot
.04709 .01965 Mdot
.04317 .0118 Mdot
.04709 .02357 Mdot
.03925 .01965 Mdot
.03925 .02749 Mdot
.03533 .02749 Mdot
.02357 .01572 Mdot
.01572 .00788 Mdot
.0118 .00788 Mdot
.01572 .0118 Mdot
.02749 .01965 Mdot
.04709 .03141 Mdot
.05494 .03533 Mdot
.04709 .02749 Mdot
.03925 .03141 Mdot
.05102 .03533 Mdot
.05102 .02749 Mdot
.03925 .0118 Mdot
.05494 .02749 Mdot
.09023 .06278 Mdot
.1412 .10591 Mdot
.15689 .11768 Mdot
.16865 .13336 Mdot
.17257 .1412 Mdot
.18434 .16081 Mdot
.18826 .17257 Mdot
.19218 .16865 Mdot
.19218 .15689 Mdot
.20394 .16473 Mdot
.20394 .16473 Mdot
.20002 .15297 Mdot
.20787 .15297 Mdot
.21179 .16473 Mdot
.21571 .16865 Mdot
.22355 .1765 Mdot
.22355 .18042 Mdot
.22355 .1765 Mdot
.23531 .18826 Mdot
.251 .1961 Mdot
.25884 .20002 Mdot
.26668 .20394 Mdot
.27061 .21571 Mdot
.27453 .22355 Mdot
.27845 .22747 Mdot
.27061 .21571 Mdot
.27061 .21571 Mdot
.27061 .21571 Mdot
.27453 .21571 Mdot
.27453 .21179 Mdot
.27845 .20787 Mdot
.27453 .21179 Mdot
.27061 .21571 Mdot
.25492 .20394 Mdot
.24708 .1961 Mdot
.24708 .19218 Mdot
.25884 .1961 Mdot
.25884 .20394 Mdot
.26668 .21179 Mdot
.25884 .20394 Mdot
.24708 .20394 Mdot
.24708 .20394 Mdot
.24708 .1961 Mdot
.251 .19218 Mdot
.25884 .20002 Mdot
.251 .19218 Mdot
.25492 .18434 Mdot
.25492 .18826 Mdot
.26668 .1961 Mdot
.25884 .18826 Mdot
.27061 .1961 Mdot
.26668 .1961 Mdot
.26668 .20002 Mdot
.26668 .20394 Mdot
.26276 .20002 Mdot
.24708 .18434 Mdot
.24316 .17257 Mdot
.24708 .16473 Mdot
.24708 .15689 Mdot
.24708 .15689 Mdot
.27061 .18434 Mdot
.27061 .1961 Mdot
.26276 .20002 Mdot
.25492 .20002 Mdot
.24316 .1961 Mdot
.22747 .18434 Mdot
.22747 .17257 Mdot
.21571 .15297 Mdot
.20787 .14513 Mdot
.20394 .1412 Mdot
.1961 .13336 Mdot
.19218 .12944 Mdot
.20002 .1412 Mdot
.19218 .12944 Mdot
.18434 .12552 Mdot
.18042 .1216 Mdot
.1765 .12944 Mdot
.1765 .13336 Mdot
.18042 .14905 Mdot
.18826 .15297 Mdot
.18042 .14513 Mdot
.18434 .14513 Mdot
.18826 .14905 Mdot
.18042 .13336 Mdot
.1961 .13728 Mdot
.21179 .1412 Mdot
.21571 .13728 Mdot
.21571 .14513 Mdot
.20394 .13728 Mdot
.19218 .13336 Mdot
.19218 .1412 Mdot
.1961 .14905 Mdot
.19218 .14513 Mdot
.18434 .13336 Mdot
.1765 .12552 Mdot
.1765 .1216 Mdot
.18042 .12552 Mdot
.18042 .12944 Mdot
.18042 .12552 Mdot
.1765 .11768 Mdot
.18042 .12944 Mdot
.18042 .13728 Mdot
.18042 .14513 Mdot
.1765 .1412 Mdot
.18826 .15297 Mdot
.16865 .13728 Mdot
.15689 .12552 Mdot
.16865 .1216 Mdot
.16473 .11376 Mdot
.16865 .11768 Mdot
.16865 .1216 Mdot
.15297 .10983 Mdot
.15297 .10983 Mdot
.14905 .10591 Mdot
.14905 .10983 Mdot
.1412 .10983 Mdot
.12552 .10199 Mdot
.12552 .09807 Mdot
.12552 .10983 Mdot
.11768 .10591 Mdot
.11768 .10199 Mdot
.11768 .09807 Mdot
.10199 .07846 Mdot
.10983 .08239 Mdot
.10591 .07454 Mdot
.1412 .19218 Mdot
.13728 .18434 Mdot
.12944 .16865 Mdot
.11768 .16081 Mdot
.10591 .14513 Mdot
.08239 .11768 Mdot
.0667 .09023 Mdot
.07454 .09023 Mdot
.0667 .07062 Mdot
.04317 .04317 Mdot
.04317 .03533 Mdot
.05494 .03533 Mdot
.05886 .03925 Mdot
.06278 .03533 Mdot
.0667 .03925 Mdot
.05494 .02749 Mdot
.04317 .01965 Mdot
.05102 .01965 Mdot
.05102 .02357 Mdot
.05102 .03141 Mdot
.06278 .05102 Mdot
.05886 .06278 Mdot
.03925 .04709 Mdot
.01965 .02357 Mdot
.01572 .01572 Mdot
.01965 .01965 Mdot
.05494 .05494 Mdot
.07062 .06278 Mdot
.0667 .05102 Mdot
.05494 .04317 Mdot
.05102 .03533 Mdot
.04709 .03141 Mdot
.04709 .03925 Mdot
.03141 .02357 Mdot
.03141 .01572 Mdot
.03925 .01965 Mdot
.05886 .03533 Mdot
.10199 .07454 Mdot
.1765 .13728 Mdot
.20787 .16473 Mdot
.23139 .18042 Mdot
.22747 .18826 Mdot
.21571 .18042 Mdot
.21179 .16865 Mdot
.20787 .16473 Mdot
.20002 .16473 Mdot
.20002 .16081 Mdot
.18434 .14905 Mdot
.18434 .16473 Mdot
.18042 .15689 Mdot
.19218 .16473 Mdot
.20002 .16865 Mdot
.21179 .1765 Mdot
.22747 .18434 Mdot
.23531 .19218 Mdot
.24708 .19218 Mdot
.26276 .21179 Mdot
.27061 .22355 Mdot
.26668 .22355 Mdot
.27061 .23531 Mdot
.27845 .23531 Mdot
.28237 .23531 Mdot
.27845 .22747 Mdot
.28237 .23139 Mdot
.27453 .21571 Mdot
.27061 .21571 Mdot
.27061 .21571 Mdot
.27453 .21963 Mdot
.26276 .21179 Mdot
.26276 .20787 Mdot
.25492 .19218 Mdot
.25884 .19218 Mdot
.25884 .20002 Mdot
.27061 .21179 Mdot
.25492 .20787 Mdot
.24708 .20787 Mdot
.251 .20002 Mdot
.24316 .18042 Mdot
.24316 .18042 Mdot
.24708 .18826 Mdot
.251 .18826 Mdot
.251 .18434 Mdot
.251 .18434 Mdot
.25884 .19218 Mdot
.26276 .19218 Mdot
.27061 .20394 Mdot
.26668 .20787 Mdot
.26668 .20787 Mdot
.25884 .20787 Mdot
.25884 .20394 Mdot
.251 .18826 Mdot
.25492 .18434 Mdot
.251 .16865 Mdot
.23924 .14905 Mdot
.25884 .16473 Mdot
.26276 .16865 Mdot
.25884 .1765 Mdot
.26276 .19218 Mdot
.26276 .20002 Mdot
.251 .20002 Mdot
.26276 .20787 Mdot
.25884 .20002 Mdot
.23531 .18434 Mdot
.22747 .16473 Mdot
.21963 .15297 Mdot
.21179 .14905 Mdot
.20394 .14905 Mdot
.18826 .13728 Mdot
.18042 .12944 Mdot
.19218 .13728 Mdot
.19218 .13336 Mdot
.18042 .11768 Mdot
.18434 .12552 Mdot
.18042 .12944 Mdot
.19218 .14905 Mdot
.18826 .15297 Mdot
.18826 .14905 Mdot
.19218 .16081 Mdot
.18434 .15297 Mdot
.18826 .14513 Mdot
.19218 .13728 Mdot
.20394 .1412 Mdot
.21571 .14513 Mdot
.20787 .1412 Mdot
.19218 .1412 Mdot
.18042 .13336 Mdot
.18042 .13728 Mdot
.19218 .15297 Mdot
.18434 .1412 Mdot
.18434 .13336 Mdot
.18042 .12552 Mdot
.1765 .1216 Mdot
.1765 .1216 Mdot
.18042 .13336 Mdot
.17257 .12552 Mdot
.1765 .13336 Mdot
.17257 .13336 Mdot
.18042 .14513 Mdot
.18042 .13336 Mdot
.1765 .12944 Mdot
.17257 .13336 Mdot
.16473 .1216 Mdot
.16865 .11768 Mdot
.17257 .11376 Mdot
.16865 .11376 Mdot
.16865 .11376 Mdot
.16081 .11768 Mdot
.15297 .1216 Mdot
.1412 .10199 Mdot
.13336 .09807 Mdot
.13336 .10983 Mdot
.12552 .10983 Mdot
.12944 .11768 Mdot
.1216 .10983 Mdot
.1216 .10591 Mdot
.10983 .09023 Mdot
.10591 .08239 Mdot
.10591 .07846 Mdot
.11376 .07454 Mdot
.10591 .06278 Mdot
.13728 .18434 Mdot
.14905 .18826 Mdot
.1412 .16865 Mdot
.13728 .16081 Mdot
.1412 .16081 Mdot
.13728 .15297 Mdot
.12552 .14513 Mdot
.12552 .14513 Mdot
.08239 .09807 Mdot
.06278 .07454 Mdot
.05494 .06278 Mdot
.05886 .05494 Mdot
.0667 .05494 Mdot
.0667 .04709 Mdot
.0667 .03925 Mdot
.05494 .02357 Mdot
.04317 .01572 Mdot
.03925 .01572 Mdot
.05494 .03141 Mdot
.05494 .03141 Mdot
.0667 .05102 Mdot
.05886 .05494 Mdot
.05886 .06278 Mdot
.05102 .05494 Mdot
.02357 .03141 Mdot
.02749 .03141 Mdot
.06278 .06278 Mdot
.08239 .07846 Mdot
.07062 .0667 Mdot
.04709 .03925 Mdot
.03141 .01965 Mdot
.02749 .01572 Mdot
.03141 .01572 Mdot
.03533 .01572 Mdot
.03533 .01572 Mdot
.03533 .0118 Mdot
.03141 .0118 Mdot
.05886 .03533 Mdot
.10199 .06278 Mdot
.13728 .09023 Mdot
.15689 .10983 Mdot
.19218 .14905 Mdot
.22747 .19218 Mdot
.23531 .20002 Mdot
.22747 .1961 Mdot
.21963 .1961 Mdot
.20787 .19218 Mdot
.18826 .1765 Mdot
.17257 .16473 Mdot
.15297 .14905 Mdot
.1412 .13336 Mdot
.13728 .1216 Mdot
.1765 .15297 Mdot
.20394 .16865 Mdot
.22355 .18042 Mdot
.24316 .18826 Mdot
.26276 .20394 Mdot
.27061 .21571 Mdot
.26668 .21963 Mdot
.26276 .22747 Mdot
.26276 .22355 Mdot
.25492 .21571 Mdot
.26668 .21963 Mdot
.27453 .22355 Mdot
.27845 .22355 Mdot
.27453 .22355 Mdot
.29021 .23531 Mdot
.28629 .22747 Mdot
.27845 .21571 Mdot
.27061 .20394 Mdot
.27061 .20394 Mdot
.26668 .1961 Mdot
.26668 .1961 Mdot
.27453 .21179 Mdot
.26668 .21179 Mdot
.27061 .22355 Mdot
.27061 .21963 Mdot
.25884 .20394 Mdot
.251 .18826 Mdot
.26276 .18826 Mdot
.26668 .18826 Mdot
.27061 .19218 Mdot
.25884 .18434 Mdot
.27061 .1961 Mdot
.26276 .20002 Mdot
.26668 .21963 Mdot
.27061 .22355 Mdot
.26276 .21963 Mdot
.26276 .21571 Mdot
.25492 .20787 Mdot
.25492 .1961 Mdot
.26276 .20002 Mdot
.27061 .1961 Mdot
.26668 .18434 Mdot
.27061 .18042 Mdot
.27061 .1765 Mdot
.27453 .1765 Mdot
.251 .17257 Mdot
.24708 .18434 Mdot
.24316 .20394 Mdot
.25492 .21179 Mdot
.24316 .18826 Mdot
.23924 .18042 Mdot
.24316 .1765 Mdot
.23924 .17257 Mdot
.22355 .15689 Mdot
.20787 .14513 Mdot
.18434 .12552 Mdot
.18826 .13728 Mdot
.18042 .12944 Mdot
.18042 .12552 Mdot
.18826 .12552 Mdot
.18826 .12944 Mdot
.18434 .13336 Mdot
.18826 .15297 Mdot
.1961 .16081 Mdot
.18042 .14905 Mdot
.18434 .15689 Mdot
.18826 .16081 Mdot
.18826 .15297 Mdot
.18042 .1412 Mdot
.18434 .13728 Mdot
.20787 .14513 Mdot
.21179 .14513 Mdot
.20787 .14513 Mdot
.20002 .14513 Mdot
.19218 .14905 Mdot
.19218 .14905 Mdot
.19218 .14513 Mdot
.20002 .15297 Mdot
.1961 .14905 Mdot
.18826 .1412 Mdot
.17257 .12552 Mdot
.16473 .12944 Mdot
.16473 .13728 Mdot
.15689 .12944 Mdot
.16473 .13336 Mdot
.1765 .13728 Mdot
.1765 .13728 Mdot
.17257 .12552 Mdot
.17257 .1216 Mdot
.16865 .11376 Mdot
.17257 .10983 Mdot
.17257 .10591 Mdot
.1765 .10591 Mdot
.15689 .09415 Mdot
.16081 .10591 Mdot
.15689 .11768 Mdot
.1412 .10591 Mdot
.14513 .10983 Mdot
.13336 .10983 Mdot
.1216 .10591 Mdot
.13728 .11768 Mdot
.12944 .10983 Mdot
.12552 .10983 Mdot
.11768 .09807 Mdot
.1216 .07846 Mdot
.11768 .07062 Mdot
.11768 .0667 Mdot
.10591 .05102 Mdot
.16081 .1961 Mdot
.16865 .20787 Mdot
.15297 .18042 Mdot
.1412 .16865 Mdot
.14513 .16081 Mdot
.15689 .16865 Mdot
.15297 .1765 Mdot
.1412 .1765 Mdot
.13728 .16473 Mdot
.11768 .14513 Mdot
.09415 .11376 Mdot
.07846 .09023 Mdot
.08631 .07454 Mdot
.07062 .04709 Mdot
.05102 .01965 Mdot
.04709 .00788 Mdot
.04317 .0118 Mdot
.04709 .01965 Mdot
.05886 .02749 Mdot
.06278 .03141 Mdot
.05886 .03533 Mdot
.05494 .04317 Mdot
.05102 .04709 Mdot
.05886 .05494 Mdot
.05102 .04709 Mdot
.06278 .04709 Mdot
.08239 .07062 Mdot
.08631 .0667 Mdot
.07062 .05102 Mdot
.06278 .04317 Mdot
.04709 .01572 Mdot
.02357 .00396 Mdot
.02749 .00396 Mdot
.03141 .00788 Mdot
.03533 .01572 Mdot
.03533 .01572 Mdot
.03533 .01965 Mdot
.03925 .03533 Mdot
.06278 .05886 Mdot
.07846 .07454 Mdot
.09807 .09023 Mdot
.09807 .09023 Mdot
.18434 .16473 Mdot
.24708 .21963 Mdot
.26276 .22747 Mdot
.25884 .22355 Mdot
.251 .22355 Mdot
.20787 .18826 Mdot
.1765 .15689 Mdot
.1412 .12552 Mdot
.10983 .09807 Mdot
.09023 .08631 Mdot
.10199 .09415 Mdot
.14513 .12944 Mdot
.18042 .15689 Mdot
.21179 .18042 Mdot
.24316 .20002 Mdot
.26668 .21179 Mdot
.26276 .20394 Mdot
.251 .20394 Mdot
.25492 .21179 Mdot
.251 .20787 Mdot
.25884 .21179 Mdot
.26668 .21963 Mdot
.27453 .23139 Mdot
.28237 .23924 Mdot
.28237 .23924 Mdot
.27845 .22355 Mdot
.27453 .21571 Mdot
.26668 .20787 Mdot
.27453 .21571 Mdot
.27453 .20394 Mdot
.28237 .20002 Mdot
.27453 .20394 Mdot
.28237 .21179 Mdot
.27845 .21963 Mdot
.27061 .21179 Mdot
.26668 .21571 Mdot
.26668 .21179 Mdot
.26276 .20394 Mdot
.25884 .1961 Mdot
.25884 .1961 Mdot
.26276 .20394 Mdot
.27845 .20787 Mdot
.27453 .21571 Mdot
.27453 .22355 Mdot
.27453 .22355 Mdot
.27845 .22747 Mdot
.28237 .23924 Mdot
.28237 .23139 Mdot
.27845 .22747 Mdot
.27061 .21571 Mdot
.27061 .21571 Mdot
.27453 .21179 Mdot
.27453 .20002 Mdot
.26668 .18826 Mdot
.27061 .19218 Mdot
.25492 .1765 Mdot
.24316 .1765 Mdot
.23924 .18826 Mdot
.23139 .19218 Mdot
.23924 .20394 Mdot
.23924 .19218 Mdot
.24708 .1961 Mdot
.23531 .18434 Mdot
.22747 .1765 Mdot
.23531 .18434 Mdot
.21963 .17257 Mdot
.20787 .16081 Mdot
.18826 .1412 Mdot
.18434 .13336 Mdot
.1961 .1412 Mdot
.19218 .13336 Mdot
.18826 .13728 Mdot
.18826 .1412 Mdot
.20394 .15689 Mdot
.18434 .14905 Mdot
.18826 .15297 Mdot
.1961 .15297 Mdot
.1961 .15297 Mdot
.19218 .14513 Mdot
.18042 .12944 Mdot
.18826 .13336 Mdot
.1961 .1412 Mdot
.20787 .14905 Mdot
.21179 .15689 Mdot
.20787 .16081 Mdot
.18434 .1412 Mdot
.18042 .13728 Mdot
.18042 .13728 Mdot
.1961 .14905 Mdot
.1961 .14905 Mdot
.20002 .14905 Mdot
.18434 .13728 Mdot
.18042 .13728 Mdot
.1765 .13336 Mdot
.16865 .12944 Mdot
.17257 .14513 Mdot
.18042 .1412 Mdot
.18042 .13336 Mdot
.17257 .1216 Mdot
.16473 .11376 Mdot
.18042 .12944 Mdot
.17257 .11768 Mdot
.16865 .10983 Mdot
.17257 .10983 Mdot
.1765 .1216 Mdot
.16473 .1216 Mdot
.15297 .12552 Mdot
.14513 .1216 Mdot
.13728 .11376 Mdot
.12944 .10591 Mdot
.13336 .11376 Mdot
.12944 .10199 Mdot
.12552 .09023 Mdot
.11768 .08239 Mdot
.12552 .08239 Mdot
.12552 .07846 Mdot
.12944 .07454 Mdot
.11768 .0667 Mdot
.16473 .17257 Mdot
.16865 .18826 Mdot
.16473 .18434 Mdot
.15689 .16865 Mdot
.14905 .15689 Mdot
.14905 .15689 Mdot
.15297 .16865 Mdot
.15689 .18826 Mdot
.15297 .19218 Mdot
.14905 .18826 Mdot
.14513 .1765 Mdot
.13336 .15297 Mdot
.11768 .1216 Mdot
.08239 .07062 Mdot
.05886 .04317 Mdot
.05102 .03141 Mdot
.0667 .03925 Mdot
.05494 .03533 Mdot
.05494 .03925 Mdot
.06278 .05102 Mdot
.06278 .04709 Mdot
.02749 .01965 Mdot
.01965 .02357 Mdot
.02357 .02749 Mdot
.02749 .02357 Mdot
.05886 .03925 Mdot
.08239 .05102 Mdot
.09807 .06278 Mdot
.09023 .05494 Mdot
.0667 .03925 Mdot
.05102 .01572 Mdot
.03925 .00396 Mdot
.04317 .0118 Mdot
.03141 .0118 Mdot
.05102 .02749 Mdot
.05102 .03925 Mdot
.04709 .03533 Mdot
.03925 .03533 Mdot
.03925 .04317 Mdot
.05886 .06278 Mdot
.07062 .07454 Mdot
.07846 .07846 Mdot
.09807 .08631 Mdot
.1412 .12552 Mdot
.20002 .17257 Mdot
.23531 .20394 Mdot
.27453 .23531 Mdot
.20394 .1765 Mdot
.16081 .13728 Mdot
.12944 .10199 Mdot
.10591 .07846 Mdot
.09807 .07454 Mdot
.09023 .07062 Mdot
.09415 .08239 Mdot
.13728 .1216 Mdot
.1765 .15689 Mdot
.20394 .17257 Mdot
.23139 .18826 Mdot
.23531 .18826 Mdot
.24316 .18826 Mdot
.25492 .1961 Mdot
.251 .20002 Mdot
.251 .20394 Mdot
.25492 .21571 Mdot
.25884 .21571 Mdot
.26276 .22355 Mdot
.26276 .22355 Mdot
.25492 .21571 Mdot
.25884 .21571 Mdot
.25884 .21179 Mdot
.26668 .20787 Mdot
.26668 .1961 Mdot
.26668 .18434 Mdot
.27453 .18826 Mdot
.27845 .19218 Mdot
.27453 .1961 Mdot
.27061 .20394 Mdot
.25492 .20002 Mdot
.25492 .20002 Mdot
.25492 .20002 Mdot
.25492 .20002 Mdot
.251 .1961 Mdot
.25884 .20394 Mdot
.26668 .21571 Mdot
.27453 .21963 Mdot
.27453 .21571 Mdot
.27061 .21571 Mdot
.27845 .23139 Mdot
.27453 .23139 Mdot
.28237 .23924 Mdot
.27453 .22747 Mdot
.25492 .20394 Mdot
.26276 .20787 Mdot
.25884 .1961 Mdot
.26668 .1961 Mdot
.25884 .18434 Mdot
.25884 .1765 Mdot
.25884 .1765 Mdot
.24316 .17257 Mdot
.23139 .16865 Mdot
.22747 .18042 Mdot
.22355 .18826 Mdot
.23139 .1961 Mdot
.23531 .1961 Mdot
.22747 .20002 Mdot
.22747 .19218 Mdot
.22355 .18434 Mdot
.21963 .16865 Mdot
.21571 .16081 Mdot
.20002 .13728 Mdot
.1961 .13336 Mdot
.20394 .13336 Mdot
.18434 .12552 Mdot
.18042 .12944 Mdot
.1765 .13728 Mdot
.18434 .14905 Mdot
.18826 .14513 Mdot
.18826 .14905 Mdot
.18826 .13336 Mdot
.18434 .12944 Mdot
.18826 .12552 Mdot
.18826 .12552 Mdot
.18042 .1216 Mdot
.18826 .12944 Mdot
.19218 .13336 Mdot
.20394 .1412 Mdot
.19218 .1412 Mdot
.19218 .14513 Mdot
.18826 .13728 Mdot
.18434 .12944 Mdot
.18434 .1216 Mdot
.1961 .13728 Mdot
.21179 .14905 Mdot
.20002 .13728 Mdot
.19218 .1412 Mdot
.18434 .13336 Mdot
.17257 .12552 Mdot
.16081 .11768 Mdot
.15689 .10983 Mdot
.16865 .11376 Mdot
.16473 .10591 Mdot
.16865 .10983 Mdot
.16473 .11376 Mdot
.17257 .12944 Mdot
.1765 .12944 Mdot
.17257 .12552 Mdot
.16865 .12944 Mdot
.16081 .12552 Mdot
.14905 .1216 Mdot
.1412 .11768 Mdot
.13336 .10983 Mdot
.12944 .10199 Mdot
.12552 .09023 Mdot
.1216 .08631 Mdot
.12552 .08631 Mdot
.11376 .07454 Mdot
.1216 .07846 Mdot
.13336 .08631 Mdot
.12552 .08631 Mdot
.10983 .07846 Mdot
.1412 .15297 Mdot
.16473 .16081 Mdot
.18042 .16865 Mdot
.18434 .16865 Mdot
.18434 .17257 Mdot
.17257 .16865 Mdot
.18434 .18434 Mdot
.17257 .18826 Mdot
.16473 .1961 Mdot
.18042 .21571 Mdot
.18434 .21571 Mdot
.18826 .21179 Mdot
.15297 .16865 Mdot
.09807 .10983 Mdot
.09023 .08631 Mdot
.07846 .07062 Mdot
.07454 .0667 Mdot
.07062 .07062 Mdot
.05886 .07062 Mdot
.05102 .0667 Mdot
.03925 .05886 Mdot
.02357 .04317 Mdot
.01965 .03141 Mdot
.02357 .02749 Mdot
.01572 .0118 Mdot
.03925 .01572 Mdot
.09023 .05102 Mdot
.10983 .06278 Mdot
.09023 .04709 Mdot
.0667 .03141 Mdot
.05102 .01965 Mdot
.03925 .0118 Mdot
.04317 .02357 Mdot
.04317 .02749 Mdot
.05886 .04317 Mdot
.07062 .04317 Mdot
.05886 .03925 Mdot
.06278 .04709 Mdot
.05102 .03925 Mdot
.05886 .05102 Mdot
.09023 .07454 Mdot
.10199 .08239 Mdot
.08631 .07454 Mdot
.09415 .08239 Mdot
.10591 .09023 Mdot
.13336 .10983 Mdot
.16865 .1412 Mdot
.15689 .13728 Mdot
.1216 .10591 Mdot
.09415 .07454 Mdot
.05886 .03533 Mdot
.09807 .07846 Mdot
.1216 .10199 Mdot
.13728 .11376 Mdot
.14513 .1216 Mdot
.14905 .12552 Mdot
.16473 .12944 Mdot
.1765 .1412 Mdot
.1961 .15689 Mdot
.21179 .16865 Mdot
.23924 .18826 Mdot
.25884 .20394 Mdot
.26668 .21571 Mdot
.25884 .21963 Mdot
.25884 .21963 Mdot
.26668 .22747 Mdot
.26668 .22355 Mdot
.26668 .21963 Mdot
.27453 .21963 Mdot
.28629 .22355 Mdot
.28237 .21963 Mdot
.28237 .21179 Mdot
.28237 .21179 Mdot
.28237 .20394 Mdot
.27453 .20394 Mdot
.26668 .20002 Mdot
.26276 .19218 Mdot
.27061 .21179 Mdot
.26668 .21571 Mdot
.26668 .21179 Mdot
.25884 .20787 Mdot
.25884 .20394 Mdot
.25492 .20002 Mdot
.26276 .20787 Mdot
.27453 .22355 Mdot
.27845 .22355 Mdot
.28629 .22747 Mdot
.28629 .22747 Mdot
.29021 .23531 Mdot
.29806 .24316 Mdot
.29806 .24316 Mdot
.29021 .23531 Mdot
.27453 .21963 Mdot
.27845 .21571 Mdot
.26668 .1961 Mdot
.26276 .19218 Mdot
.27061 .20002 Mdot
.27061 .20787 Mdot
.25884 .1961 Mdot
.25884 .20002 Mdot
.251 .1961 Mdot
.23924 .1961 Mdot
.24708 .20394 Mdot
.251 .20787 Mdot
.251 .20787 Mdot
.24316 .1961 Mdot
.23531 .18826 Mdot
.22355 .18042 Mdot
.23924 .18434 Mdot
.21571 .15689 Mdot
.21963 .15297 Mdot
.20787 .1412 Mdot
.1961 .12552 Mdot
.1961 .13336 Mdot
.18826 .13728 Mdot
.18434 .14513 Mdot
.20002 .15297 Mdot
.19218 .14905 Mdot
.1961 .14905 Mdot
.1961 .13728 Mdot
.1961 .13336 Mdot
.1961 .1412 Mdot
.20002 .1412 Mdot
.21179 .14905 Mdot
.21571 .14905 Mdot
.21963 .16081 Mdot
.21179 .16081 Mdot
.20787 .15689 Mdot
.18826 .1412 Mdot
.19218 .13728 Mdot
.19218 .12944 Mdot
.20394 .13336 Mdot
.22355 .14905 Mdot
.21963 .14905 Mdot
.21571 .15689 Mdot
.20002 .1412 Mdot
.18042 .12552 Mdot
.16865 .1216 Mdot
.16865 .11768 Mdot
.16865 .11768 Mdot
.17257 .11768 Mdot
.18042 .1216 Mdot
.16865 .11768 Mdot
.17257 .1216 Mdot
.17257 .12552 Mdot
.1765 .13336 Mdot
.18042 .13728 Mdot
.15689 .11768 Mdot
.14513 .10591 Mdot
.15689 .11768 Mdot
.15689 .12944 Mdot
.14513 .11376 Mdot
.1412 .10983 Mdot
.1412 .10983 Mdot
.13336 .10199 Mdot
.13336 .09415 Mdot
.13336 .09023 Mdot
.12552 .09023 Mdot
.12552 .09415 Mdot
.12944 .09415 Mdot
.09415 .1216 Mdot
.11768 .11376 Mdot
.1412 .1216 Mdot
.16081 .13728 Mdot
.16865 .14905 Mdot
.1765 .16081 Mdot
.18434 .18042 Mdot
.18434 .18826 Mdot
.18826 .20394 Mdot
.18434 .21571 Mdot
.19218 .23139 Mdot
.21571 .24708 Mdot
.18826 .21179 Mdot
.13336 .15297 Mdot
.1216 .13728 Mdot
.11768 .13336 Mdot
.09023 .11376 Mdot
.0667 .10199 Mdot
.05494 .09807 Mdot
.05102 .09415 Mdot
.02357 .0667 Mdot
.01965 .05886 Mdot
.01572 .03925 Mdot
.00788 .01965 Mdot
.0118 .0118 Mdot
.02357 .00788 Mdot
.07062 .03533 Mdot
.10199 .0667 Mdot
.09807 .06278 Mdot
.08631 .05102 Mdot
.0667 .03925 Mdot
.05102 .02749 Mdot
.04709 .03533 Mdot
.05886 .05494 Mdot
.08239 .07846 Mdot
.09415 .08239 Mdot
.08631 .08239 Mdot
.06278 .0667 Mdot
.05102 .05494 Mdot
.06278 .07454 Mdot
.07846 .07846 Mdot
.09415 .09023 Mdot
.07846 .07454 Mdot
.07454 .07062 Mdot
.08239 .07454 Mdot
.08239 .07454 Mdot
.09807 .08239 Mdot
.10983 .09023 Mdot
.08631 .0667 Mdot
.07062 .04709 Mdot
.06278 .03141 Mdot
.05102 .01965 Mdot
.10983 .0667 Mdot
.14513 .10983 Mdot
.14513 .1216 Mdot
.11376 .10199 Mdot
.10591 .09415 Mdot
.10199 .08631 Mdot
.11768 .09415 Mdot
.14513 .11376 Mdot
.18042 .1412 Mdot
.21179 .16865 Mdot
.23139 .18826 Mdot
.24708 .20002 Mdot
.25492 .20394 Mdot
.25884 .20002 Mdot
.26668 .20394 Mdot
.27061 .21179 Mdot
.27061 .20787 Mdot
.28629 .22355 Mdot
.28237 .21963 Mdot
.27845 .21963 Mdot
.28629 .22355 Mdot
.28629 .22355 Mdot
.28237 .21963 Mdot
.27845 .21571 Mdot
.27061 .21179 Mdot
.26668 .21179 Mdot
.26668 .21179 Mdot
.27845 .21963 Mdot
.26668 .21179 Mdot
.27061 .21179 Mdot
.25884 .20394 Mdot
.25884 .21179 Mdot
.26668 .21571 Mdot
.27453 .22355 Mdot
.28237 .22355 Mdot
.28629 .22747 Mdot
.29413 .22747 Mdot
.29413 .22355 Mdot
.30198 .23139 Mdot
.32943 .25884 Mdot
.32158 .25884 Mdot
.30198 .23924 Mdot
.29021 .22747 Mdot
.28629 .22355 Mdot
.27845 .21963 Mdot
.27061 .21963 Mdot
.27061 .21571 Mdot
.27061 .20787 Mdot
.27061 .20787 Mdot
.26276 .1961 Mdot
.26276 .1961 Mdot
.26276 .20002 Mdot
.25884 .20002 Mdot
.25492 .20002 Mdot
.24708 .19218 Mdot
.23924 .18826 Mdot
.23924 .1961 Mdot
.23139 .18434 Mdot
.22355 .17257 Mdot
.21571 .15297 Mdot
.20787 .13336 Mdot
.1961 .13336 Mdot
.19218 .1216 Mdot
.1961 .12944 Mdot
.20002 .14513 Mdot
.20394 .14513 Mdot
.21571 .15297 Mdot
.21179 .16081 Mdot
.20787 .16081 Mdot
.20002 .15689 Mdot
.20394 .14905 Mdot
.21179 .15689 Mdot
.20787 .15297 Mdot
.21963 .16473 Mdot
.21571 .16473 Mdot
.21571 .16865 Mdot
.20787 .16865 Mdot
.20394 .15297 Mdot
.20002 .13336 Mdot
.18042 .11376 Mdot
.18826 .11768 Mdot
.20002 .12552 Mdot
.20002 .12944 Mdot
.20394 .13336 Mdot
.19218 .12552 Mdot
.1765 .11376 Mdot
.17257 .10591 Mdot
.16473 .10199 Mdot
.15689 .09807 Mdot
.16081 .10199 Mdot
.16081 .10983 Mdot
.16865 .1216 Mdot
.18042 .12944 Mdot
.17257 .13336 Mdot
.16473 .12944 Mdot
.17257 .12944 Mdot
.15689 .11376 Mdot
.13728 .10591 Mdot
.14905 .11376 Mdot
.14513 .10591 Mdot
.14513 .10983 Mdot
.1412 .10983 Mdot
.13336 .11376 Mdot
.12944 .11376 Mdot
.13336 .10983 Mdot
.1412 .11376 Mdot
.12944 .10199 Mdot
.13728 .09807 Mdot
.10591 .13336 Mdot
.10591 .11376 Mdot
.09415 .09023 Mdot
.10591 .09023 Mdot
.1216 .11376 Mdot
.14905 .13336 Mdot
.18042 .16865 Mdot
.18826 .18434 Mdot
.1961 .20394 Mdot
.19218 .21179 Mdot
.18042 .21571 Mdot
.18434 .22355 Mdot
.19218 .22355 Mdot
.18042 .20787 Mdot
.15689 .18042 Mdot
.15297 .18434 Mdot
.13336 .18042 Mdot
.12944 .18042 Mdot
.12552 .18042 Mdot
.10591 .16081 Mdot
.08239 .12944 Mdot
.05494 .09807 Mdot
.03533 .07454 Mdot
.02357 .05102 Mdot
.01965 .03533 Mdot
.01965 .01965 Mdot
.0667 .05494 Mdot
.09415 .0667 Mdot
.09023 .06278 Mdot
.08239 .05494 Mdot
.07454 .05102 Mdot
.07846 .05886 Mdot
.07454 .0667 Mdot
.08239 .07454 Mdot
.09807 .09415 Mdot
.11768 .11768 Mdot
.12552 .13728 Mdot
.1216 .12944 Mdot
.09415 .10591 Mdot
.09023 .10983 Mdot
.09807 .10983 Mdot
.07846 .10199 Mdot
.0667 .08239 Mdot
.05886 .0667 Mdot
.05886 .06278 Mdot
.05494 .05494 Mdot
.05886 .04709 Mdot
.07846 .05886 Mdot
.0667 .04317 Mdot
.05886 .03141 Mdot
.05102 .01965 Mdot
.04317 .0118 Mdot
.14513 .09807 Mdot
.18434 .13336 Mdot
.1765 .13728 Mdot
.10591 .08631 Mdot
.09415 .07846 Mdot
.07454 .05494 Mdot
.07454 .05494 Mdot
.07846 .05494 Mdot
.09807 .07062 Mdot
.11768 .08631 Mdot
.14905 .10983 Mdot
.18042 .13336 Mdot
.20394 .14905 Mdot
.23139 .16865 Mdot
.25492 .18826 Mdot
.26668 .20002 Mdot
.27845 .20787 Mdot
.28237 .21963 Mdot
.28629 .22355 Mdot
.28629 .22747 Mdot
.29021 .22747 Mdot
.27845 .20787 Mdot
.27453 .20787 Mdot
.27845 .22355 Mdot
.28237 .22355 Mdot
.27453 .21963 Mdot
.27453 .22355 Mdot
.27061 .21571 Mdot
.27453 .21963 Mdot
.27845 .21963 Mdot
.28237 .22355 Mdot
.28629 .21963 Mdot
.28629 .22355 Mdot
.28629 .23139 Mdot
.28629 .23139 Mdot
.27845 .22355 Mdot
.28629 .23139 Mdot
.29413 .23139 Mdot
.30198 .23924 Mdot
.31374 .23924 Mdot
.31766 .23531 Mdot
.30982 .23139 Mdot
.29806 .23531 Mdot
.29806 .23531 Mdot
.28629 .22747 Mdot
.27061 .22747 Mdot
.27453 .22355 Mdot
.25884 .20394 Mdot
.26276 .20002 Mdot
.251 .18042 Mdot
.25492 .18826 Mdot
.26276 .19218 Mdot
.26276 .20002 Mdot
.26668 .21179 Mdot
.26276 .21179 Mdot
.251 .20394 Mdot
.24708 .20394 Mdot
.23531 .19218 Mdot
.21963 .1765 Mdot
.21571 .15689 Mdot
.20787 .13336 Mdot
.20002 .1216 Mdot
.20002 .12552 Mdot
.19218 .12552 Mdot
.1961 .13336 Mdot
.20394 .14513 Mdot
.21963 .15297 Mdot
.20002 .14513 Mdot
.20394 .15297 Mdot
.1961 .14513 Mdot
.21179 .16081 Mdot
.21179 .16473 Mdot
.21963 .17257 Mdot
.21963 .18042 Mdot
.21963 .18042 Mdot
.20787 .16473 Mdot
.21571 .16473 Mdot
.21571 .16473 Mdot
.21179 .15297 Mdot
.19218 .13728 Mdot
.1765 .11768 Mdot
.17257 .10983 Mdot
.1765 .10983 Mdot
.1765 .10983 Mdot
.19218 .1216 Mdot
.18042 .10983 Mdot
.16865 .09807 Mdot
.16473 .09023 Mdot
.17257 .10591 Mdot
.1765 .1216 Mdot
.16473 .11768 Mdot
.16865 .12944 Mdot
.16473 .13336 Mdot
.16081 .12552 Mdot
.16865 .12552 Mdot
.16473 .12552 Mdot
.16081 .12552 Mdot
.14905 .10983 Mdot
.13728 .09807 Mdot
.12944 .08631 Mdot
.12552 .08631 Mdot
.1412 .09807 Mdot
.1412 .10199 Mdot
.12552 .09807 Mdot
.1216 .09415 Mdot
.13336 .10983 Mdot
.12552 .09807 Mdot
.12552 .09023 Mdot
.12552 .1412 Mdot
.10983 .12552 Mdot
.09807 .10591 Mdot
.09023 .08631 Mdot
.09023 .08239 Mdot
.11376 .09415 Mdot
.12944 .09807 Mdot
.1412 .1216 Mdot
.16473 .15297 Mdot
.1765 .18434 Mdot
.18434 .20002 Mdot
.18826 .21571 Mdot
.21179 .23139 Mdot
.18042 .20394 Mdot
.16865 .19218 Mdot
.17257 .20002 Mdot
.18042 .21179 Mdot
.18826 .21571 Mdot
.18826 .22355 Mdot
.18826 .23139 Mdot
.17257 .21571 Mdot
.14513 .1961 Mdot
.11768 .16473 Mdot
.0667 .11376 Mdot
.04317 .08239 Mdot
.03141 .05494 Mdot
.05102 .05886 Mdot
.07846 .0667 Mdot
.08631 .07062 Mdot
.07846 .0667 Mdot
.07846 .05102 Mdot
.07454 .05494 Mdot
.07846 .05494 Mdot
.09415 .07062 Mdot
.11768 .10199 Mdot
.11376 .10983 Mdot
.13336 .1412 Mdot
.13728 .15297 Mdot
.14513 .15689 Mdot
.1412 .15297 Mdot
.15297 .15689 Mdot
.10199 .11376 Mdot
.07454 .09023 Mdot
.05494 .07062 Mdot
.05494 .06278 Mdot
.05494 .05886 Mdot
.06278 .06278 Mdot
.07062 .0667 Mdot
.0667 .06278 Mdot
.05886 .05102 Mdot
.05494 .04317 Mdot
.04709 .02749 Mdot
.09807 .0667 Mdot
.11376 .07846 Mdot
.12552 .08239 Mdot
.11768 .08239 Mdot
.10983 .07454 Mdot
.09023 .06278 Mdot
.07846 .04709 Mdot
.07846 .05102 Mdot
.08239 .05494 Mdot
.07846 .05102 Mdot
.07846 .05102 Mdot
.09807 .0667 Mdot
.13336 .08631 Mdot
.16865 .11376 Mdot
.21179 .14513 Mdot
.251 .1765 Mdot
.26276 .19218 Mdot
.27453 .20394 Mdot
.27845 .21179 Mdot
.28629 .21179 Mdot
.28629 .20394 Mdot
.28629 .21963 Mdot
.28237 .21963 Mdot
.28629 .22747 Mdot
.29413 .23531 Mdot
.28629 .23139 Mdot
.28629 .23531 Mdot
.28237 .23139 Mdot
.27453 .22355 Mdot
.27061 .21571 Mdot
.27453 .21179 Mdot
.29806 .22747 Mdot
.29413 .23139 Mdot
.29021 .23924 Mdot
.28629 .23139 Mdot
.28629 .22747 Mdot
.28629 .22355 Mdot
.29021 .23139 Mdot
.29021 .22747 Mdot
.30982 .23531 Mdot
.30198 .22355 Mdot
.3059 .22747 Mdot
.30982 .23924 Mdot
.30198 .23531 Mdot
.29806 .23139 Mdot
.27845 .21963 Mdot
.27453 .21963 Mdot
.26668 .20787 Mdot
.27845 .21179 Mdot
.28237 .21963 Mdot
.27061 .21179 Mdot
.26668 .20394 Mdot
.26668 .20787 Mdot
.26668 .21571 Mdot
.26668 .21179 Mdot
.25492 .20787 Mdot
.25492 .20787 Mdot
.23531 .19218 Mdot
.23139 .18042 Mdot
.23531 .16865 Mdot
.21963 .14905 Mdot
.20394 .12552 Mdot
.20394 .12552 Mdot
.20787 .12944 Mdot
.20394 .13336 Mdot
.20787 .13728 Mdot
.21571 .1412 Mdot
.21179 .1412 Mdot
.20787 .14513 Mdot
.21179 .14905 Mdot
.20787 .15297 Mdot
.20394 .15297 Mdot
.21571 .16865 Mdot
.21571 .16473 Mdot
.21571 .16865 Mdot
.21179 .16081 Mdot
.21179 .16081 Mdot
.21571 .16081 Mdot
.20787 .15689 Mdot
.1961 .14905 Mdot
.19218 .1412 Mdot
.18434 .12944 Mdot
.18042 .12552 Mdot
.16865 .11768 Mdot
.1765 .11768 Mdot
.18826 .12552 Mdot
.1765 .1216 Mdot
.16865 .11376 Mdot
.16473 .11768 Mdot
.1765 .13336 Mdot
.17257 .13336 Mdot
.16081 .12944 Mdot
.16081 .12944 Mdot
.16473 .12944 Mdot
.15689 .1216 Mdot
.16081 .11768 Mdot
.15689 .10983 Mdot
.13728 .09023 Mdot
.14513 .09415 Mdot
.14513 .09415 Mdot
.13728 .09023 Mdot
.1412 .09415 Mdot
.1412 .09415 Mdot
.12552 .09023 Mdot
.12552 .09415 Mdot
.1412 .10199 Mdot
.13728 .10199 Mdot
.1216 .09023 Mdot
.11376 .12944 Mdot
.1216 .12944 Mdot
.10983 .11768 Mdot
.09415 .09807 Mdot
.09807 .09023 Mdot
.10591 .08631 Mdot
.10591 .08239 Mdot
.10983 .09415 Mdot
.10983 .09807 Mdot
.1216 .11376 Mdot
.13728 .13336 Mdot
.15297 .16473 Mdot
.18434 .1961 Mdot
.19218 .20002 Mdot
.18826 .19218 Mdot
.18434 .20002 Mdot
.1765 .1961 Mdot
.18042 .20394 Mdot
.1961 .22355 Mdot
.1961 .23531 Mdot
.20394 .251 Mdot
.1961 .251 Mdot
.18042 .23531 Mdot
.15297 .20787 Mdot
.11376 .16473 Mdot
.09415 .12944 Mdot
.07846 .10591 Mdot
.08631 .09023 Mdot
.09807 .09023 Mdot
.08631 .07454 Mdot
.07846 .06278 Mdot
.07846 .05886 Mdot
.09023 .06278 Mdot
.10199 .07846 Mdot
.09023 .07062 Mdot
.07846 .07062 Mdot
.09415 .08631 Mdot
.11768 .11768 Mdot
.15689 .15297 Mdot
.17257 .16473 Mdot
.18434 .1765 Mdot
.17257 .17257 Mdot
.10983 .11376 Mdot
.09415 .09415 Mdot
.08239 .08239 Mdot
.0667 .0667 Mdot
.05886 .0667 Mdot
.06278 .07454 Mdot
.0667 .07454 Mdot
.07454 .08239 Mdot
.06278 .07062 Mdot
.06278 .06278 Mdot
.07062 .05886 Mdot
.09023 .05886 Mdot
.09415 .05102 Mdot
.09415 .04709 Mdot
.09415 .04709 Mdot
.08631 .04317 Mdot
.07846 .03533 Mdot
.07846 .03533 Mdot
.07454 .03533 Mdot
.0667 .03141 Mdot
.0667 .03141 Mdot
.07062 .03533 Mdot
.09807 .05494 Mdot
.09807 .03925 Mdot
.13728 .07454 Mdot
.20394 .12944 Mdot
.23924 .16081 Mdot
.26668 .18826 Mdot
.28237 .20002 Mdot
.29413 .21179 Mdot
.29021 .21571 Mdot
.28237 .22355 Mdot
.28237 .21963 Mdot
.27845 .22355 Mdot
.29021 .23139 Mdot
.29021 .23531 Mdot
.29021 .24316 Mdot
.28629 .24316 Mdot
.28237 .23924 Mdot
.27453 .22747 Mdot
.27845 .22747 Mdot
.27845 .23139 Mdot
.28629 .24708 Mdot
.28629 .24316 Mdot
.27845 .22747 Mdot
.27845 .21963 Mdot
.28237 .21963 Mdot
.29021 .21963 Mdot
.29413 .22355 Mdot
.29806 .21963 Mdot
.30198 .22747 Mdot
.29806 .22747 Mdot
.29413 .23924 Mdot
.29413 .24316 Mdot
.29021 .24316 Mdot
.27845 .23139 Mdot
.26668 .21571 Mdot
.26668 .21179 Mdot
.27061 .21179 Mdot
.27061 .21571 Mdot
.26668 .21179 Mdot
.26668 .21179 Mdot
.27453 .21963 Mdot
.27845 .21963 Mdot
.27061 .21571 Mdot
.27061 .21571 Mdot
.26668 .21179 Mdot
.24708 .20002 Mdot
.23924 .19218 Mdot
.23139 .18042 Mdot
.23139 .16865 Mdot
.21179 .15297 Mdot
.22355 .14905 Mdot
.22355 .1412 Mdot
.21963 .13728 Mdot
.21571 .1412 Mdot
.21963 .14513 Mdot
.22747 .15297 Mdot
.22747 .15689 Mdot
.22355 .16081 Mdot
.21571 .16081 Mdot
.20002 .15297 Mdot
.20002 .14905 Mdot
.18826 .1412 Mdot
.20002 .15297 Mdot
.21179 .16081 Mdot
.21179 .15689 Mdot
.20787 .15689 Mdot
.1961 .14513 Mdot
.20787 .15297 Mdot
.20787 .14513 Mdot
.20787 .14513 Mdot
.20394 .1412 Mdot
.20787 .1412 Mdot
.18434 .1216 Mdot
.18826 .11768 Mdot
.18434 .12944 Mdot
.18434 .13728 Mdot
.18042 .13336 Mdot
.18042 .1412 Mdot
.18042 .14905 Mdot
.1765 .14513 Mdot
.17257 .13336 Mdot
.16865 .1216 Mdot
.15297 .10199 Mdot
.15297 .09415 Mdot
.16473 .10591 Mdot
.15297 .09807 Mdot
.14905 .10199 Mdot
.14905 .10199 Mdot
.14513 .09807 Mdot
.14905 .10199 Mdot
.13728 .09023 Mdot
.13336 .09023 Mdot
.12944 .08239 Mdot
.1216 .07454 Mdot
.13336 .09415 Mdot
.12944 .09415 Mdot
.07454 .09023 Mdot
.15689 .15297 Mdot
.12944 .13728 Mdot
.11376 .1216 Mdot
.09807 .10983 Mdot
.09415 .10199 Mdot
.09415 .09415 Mdot
.09807 .09415 Mdot
.08631 .08239 Mdot
.07846 .07062 Mdot
.07454 .07454 Mdot
.09023 .08631 Mdot
.12552 .1216 Mdot
.14905 .13728 Mdot
.16865 .15297 Mdot
.20002 .18826 Mdot
.19218 .18826 Mdot
.19218 .18826 Mdot
.18434 .19218 Mdot
.18826 .21179 Mdot
.1961 .23531 Mdot
.20394 .251 Mdot
.20394 .251 Mdot
.1961 .24316 Mdot
.18434 .23139 Mdot
.15689 .20394 Mdot
.13336 .16865 Mdot
.12552 .1412 Mdot
.10983 .11768 Mdot
.08631 .09023 Mdot
.09023 .09023 Mdot
.09023 .08239 Mdot
.09023 .07846 Mdot
.09807 .08239 Mdot
.08239 .0667 Mdot
.05886 .04709 Mdot
.05886 .05102 Mdot
.07062 .06278 Mdot
.1216 .10591 Mdot
.15297 .12552 Mdot
.1765 .14905 Mdot
.18826 .16473 Mdot
.18826 .16865 Mdot
.17257 .16473 Mdot
.14905 .15297 Mdot
.11768 .13336 Mdot
.09023 .1216 Mdot
.08239 .11376 Mdot
.0667 .09807 Mdot
.0667 .09023 Mdot
.09023 .10199 Mdot
.10591 .10591 Mdot
.10199 .09415 Mdot
.10199 .07846 Mdot
.09415 .05494 Mdot
.10199 .05494 Mdot
.09023 .04709 Mdot
.07846 .03533 Mdot
.07454 .03533 Mdot
.05886 .02357 Mdot
.05886 .01965 Mdot
.0667 .01965 Mdot
.07062 .02357 Mdot
.07846 .02749 Mdot
.08631 .03925 Mdot
.07062 .02357 Mdot
.08631 .03141 Mdot
.11376 .04317 Mdot
.18042 .09807 Mdot
.21963 .14905 Mdot
.26276 .20002 Mdot
.28237 .22355 Mdot
.28629 .22747 Mdot
.29413 .23924 Mdot
.29413 .23139 Mdot
.29021 .22355 Mdot
.28629 .22355 Mdot
.28629 .22355 Mdot
.28629 .23139 Mdot
.29021 .23531 Mdot
.28629 .23924 Mdot
.27845 .23139 Mdot
.27453 .23924 Mdot
.27453 .23924 Mdot
.28629 .24708 Mdot
.29021 .24316 Mdot
.29021 .23531 Mdot
.27453 .20787 Mdot
.27453 .1961 Mdot
.27845 .20002 Mdot
.27845 .20394 Mdot
.28237 .20787 Mdot
.28629 .20787 Mdot
.27845 .21179 Mdot
.28629 .23531 Mdot
.28237 .24316 Mdot
.27453 .23531 Mdot
.27453 .22747 Mdot
.27453 .21571 Mdot
.27061 .21179 Mdot
.26668 .20787 Mdot
.26668 .20787 Mdot
.26668 .20787 Mdot
.26276 .20394 Mdot
.26276 .20787 Mdot
.27845 .21571 Mdot
.26668 .20002 Mdot
.27061 .21179 Mdot
.27845 .22355 Mdot
.26668 .21963 Mdot
.24316 .21179 Mdot
.23531 .20787 Mdot
.22355 .19218 Mdot
.21179 .1765 Mdot
.21179 .17257 Mdot
.21179 .15689 Mdot
.20787 .1412 Mdot
.21179 .1412 Mdot
.21963 .1412 Mdot
.22747 .15297 Mdot
.21179 .13728 Mdot
.20787 .1412 Mdot
.21571 .14905 Mdot
.20002 .14905 Mdot
.20002 .15297 Mdot
.18826 .15297 Mdot
.18042 .14905 Mdot
.19218 .15297 Mdot
.1961 .14905 Mdot
.1961 .14513 Mdot
.19218 .1412 Mdot
.19218 .13728 Mdot
.19218 .12944 Mdot
.1961 .12944 Mdot
.19218 .12552 Mdot
.19218 .1216 Mdot
.18042 .10983 Mdot
.18042 .10983 Mdot
.18042 .1216 Mdot
.18042 .12944 Mdot
.18042 .13728 Mdot
.1765 .14513 Mdot
.18042 .14513 Mdot
.1765 .13336 Mdot
.18434 .13728 Mdot
.18042 .13336 Mdot
.16473 .11768 Mdot
.14905 .10591 Mdot
.15689 .10983 Mdot
.14905 .09807 Mdot
.14513 .10199 Mdot
.14513 .10199 Mdot
.15689 .10591 Mdot
.15689 .10983 Mdot
.15689 .11768 Mdot
.1412 .10983 Mdot
.12552 .09023 Mdot
.11768 .07846 Mdot
.11768 .07454 Mdot
.1216 .07846 Mdot
.43922 .44314 Mdot
.22355 .21963 Mdot
.18826 .18434 Mdot
.16473 .16865 Mdot
.15297 .16473 Mdot
.13728 .14905 Mdot
.11768 .12552 Mdot
.10983 .11376 Mdot
.09807 .09415 Mdot
.09023 .07846 Mdot
.07454 .0667 Mdot
.07454 .0667 Mdot
.07454 .06278 Mdot
.08239 .06278 Mdot
.13336 .09807 Mdot
.16081 .11768 Mdot
.18434 .16081 Mdot
.20787 .18826 Mdot
.20002 .18826 Mdot
.20002 .20002 Mdot
.20787 .23139 Mdot
.22355 .25492 Mdot
.21963 .26276 Mdot
.20787 .26276 Mdot
.1961 .24708 Mdot
.19218 .23924 Mdot
.1765 .21571 Mdot
.14905 .18434 Mdot
.12552 .15689 Mdot
.11768 .14513 Mdot
.11768 .13336 Mdot
.11768 .11768 Mdot
.10983 .10983 Mdot
.09023 .09807 Mdot
.07454 .08239 Mdot
.05886 .0667 Mdot
.05102 .05102 Mdot
.08631 .08631 Mdot
.1216 .10591 Mdot
.11768 .09807 Mdot
.11376 .08239 Mdot
.11768 .09023 Mdot
.15689 .13728 Mdot
.17257 .16473 Mdot
.18042 .18042 Mdot
.1765 .19218 Mdot
.16081 .18434 Mdot
.11768 .1412 Mdot
.09807 .1216 Mdot
.09023 .11376 Mdot
.10591 .10983 Mdot
.10983 .10983 Mdot
.11376 .10591 Mdot
.10591 .08631 Mdot
.10199 .0667 Mdot
.10591 .06278 Mdot
.10591 .0667 Mdot
.08239 .04317 Mdot
.07454 .04317 Mdot
.0667 .03533 Mdot
.06278 .03925 Mdot
.06278 .03141 Mdot
.07062 .03533 Mdot
.09023 .04709 Mdot
.09023 .05494 Mdot
.08239 .04317 Mdot
.08631 .03533 Mdot
.09023 .01965 Mdot
.11376 .03925 Mdot
.11768 .05102 Mdot
.21179 .14513 Mdot
.24708 .18826 Mdot
.27845 .21179 Mdot
.29413 .21963 Mdot
.3059 .23139 Mdot
.30198 .22355 Mdot
.29413 .22747 Mdot
.29413 .22747 Mdot
.29021 .22747 Mdot
.29021 .23139 Mdot
.29021 .23139 Mdot
.29806 .24316 Mdot
.29021 .23924 Mdot
.27845 .23531 Mdot
.27845 .22355 Mdot
.29021 .22747 Mdot
.28629 .22355 Mdot
.27453 .20787 Mdot
.27845 .20787 Mdot
.27453 .20787 Mdot
.27453 .20787 Mdot
.27845 .21179 Mdot
.27453 .20394 Mdot
.27845 .20787 Mdot
.28629 .21963 Mdot
.28629 .21963 Mdot
.27061 .21963 Mdot
.27061 .21571 Mdot
.27061 .21179 Mdot
.26668 .21179 Mdot
.26668 .20787 Mdot
.26668 .20394 Mdot
.27061 .20394 Mdot
.26668 .20394 Mdot
.27453 .21179 Mdot
.27845 .21179 Mdot
.28237 .21179 Mdot
.27845 .21179 Mdot
.27453 .21963 Mdot
.27061 .22355 Mdot
.25884 .22747 Mdot
.24708 .22747 Mdot
.23531 .21179 Mdot
.22747 .20002 Mdot
.21179 .18042 Mdot
.1961 .16473 Mdot
.20002 .15689 Mdot
.1961 .1412 Mdot
.20787 .1412 Mdot
.20787 .1412 Mdot
.20787 .14513 Mdot
.20002 .15297 Mdot
.20787 .15297 Mdot
.20002 .14905 Mdot
.18434 .13728 Mdot
.18434 .1412 Mdot
.18826 .1412 Mdot
.17257 .12944 Mdot
.18434 .13336 Mdot
.20002 .14513 Mdot
.20002 .14905 Mdot
.19218 .14513 Mdot
.1961 .14513 Mdot
.19218 .1412 Mdot
.18826 .13336 Mdot
.18434 .12552 Mdot
.17257 .11768 Mdot
.17257 .11768 Mdot
.18042 .1216 Mdot
.17257 .1216 Mdot
.16865 .1216 Mdot
.16865 .12552 Mdot
.18042 .13728 Mdot
.17257 .12944 Mdot
.16865 .12552 Mdot
.17257 .12552 Mdot
.16865 .13336 Mdot
.15689 .12552 Mdot
.14513 .11376 Mdot
.13728 .09807 Mdot
.13336 .09023 Mdot
.14513 .09807 Mdot
.16081 .10983 Mdot
.14905 .10983 Mdot
.14905 .11376 Mdot
.14513 .10591 Mdot
.13728 .10199 Mdot
.13728 .10199 Mdot
.12944 .08631 Mdot
.1216 .06278 Mdot
.63528 .64705 Mdot
.3059 .3255 Mdot
.27845 .29413 Mdot
.24708 .25884 Mdot
.21179 .22355 Mdot
.1765 .18042 Mdot
.1412 .12944 Mdot
.1216 .09415 Mdot
.11376 .09023 Mdot
.10983 .09023 Mdot
.11768 .09415 Mdot
.12944 .09415 Mdot
.1216 .08239 Mdot
.12552 .09023 Mdot
.15297 .1412 Mdot
.1765 .17257 Mdot
.18042 .1765 Mdot
.18434 .19218 Mdot
.21179 .22747 Mdot
.22355 .251 Mdot
.22747 .27061 Mdot
.23139 .28237 Mdot
.21963 .27453 Mdot
.20394 .25884 Mdot
.18434 .23139 Mdot
.18434 .22355 Mdot
.16865 .20002 Mdot
.17257 .1961 Mdot
.18826 .20787 Mdot
.16081 .17257 Mdot
.14513 .17257 Mdot
.1216 .14905 Mdot
.08239 .11376 Mdot
.06278 .09023 Mdot
.05494 .08239 Mdot
.09023 .10983 Mdot
.10983 .12944 Mdot
.09415 .10591 Mdot
.07062 .07062 Mdot
.05494 .05102 Mdot
.07454 .07062 Mdot
.09415 .09415 Mdot
.13336 .13728 Mdot
.15689 .16473 Mdot
.16865 .17257 Mdot
.13336 .13728 Mdot
.11768 .1216 Mdot
.1412 .13728 Mdot
.13336 .12944 Mdot
.1216 .11768 Mdot
.11376 .10199 Mdot
.09415 .07846 Mdot
.09023 .06278 Mdot
.10983 .07062 Mdot
.10591 .06278 Mdot
.09807 .04709 Mdot
.07846 .03925 Mdot
.08239 .04317 Mdot
.07454 .04709 Mdot
.06278 .03533 Mdot
.0667 .03925 Mdot
.07062 .04317 Mdot
.07454 .04709 Mdot
.09023 .05886 Mdot
.09415 .05494 Mdot
.12552 .0667 Mdot
.13728 .07062 Mdot
.1412 .08239 Mdot
.16081 .10199 Mdot
.20787 .13336 Mdot
.24708 .16081 Mdot
.27453 .19218 Mdot
.29413 .21963 Mdot
.30982 .23139 Mdot
.30982 .24708 Mdot
.3059 .25492 Mdot
.29413 .25492 Mdot
.29413 .25884 Mdot
.29021 .24316 Mdot
.29021 .23139 Mdot
.29021 .22355 Mdot
.30198 .22747 Mdot
.3059 .22747 Mdot
.29413 .21963 Mdot
.30198 .22355 Mdot
.28629 .21571 Mdot
.28629 .22355 Mdot
.28629 .22747 Mdot
.27845 .21963 Mdot
.28629 .21963 Mdot
.28237 .20787 Mdot
.28629 .21179 Mdot
.27845 .20002 Mdot
.27453 .19218 Mdot
.27061 .1961 Mdot
.27845 .20002 Mdot
.28237 .21571 Mdot
.28237 .22355 Mdot
.28629 .22747 Mdot
.28237 .22355 Mdot
.27845 .22355 Mdot
.27845 .22355 Mdot
.26668 .22355 Mdot
.26276 .21179 Mdot
.27061 .20787 Mdot
.27061 .20002 Mdot
.27845 .20394 Mdot
.26668 .20394 Mdot
.27061 .21179 Mdot
.26276 .21571 Mdot
.24316 .20787 Mdot
.24316 .20787 Mdot
.22355 .18434 Mdot
.20787 .17257 Mdot
.1961 .16081 Mdot
.20002 .15689 Mdot
.1961 .1412 Mdot
.1961 .13728 Mdot
.19218 .13336 Mdot
.20002 .13336 Mdot
.21179 .1412 Mdot
.20394 .13336 Mdot
.1961 .12552 Mdot
.19218 .12552 Mdot
.20787 .14513 Mdot
.20002 .13728 Mdot
.19218 .12944 Mdot
.19218 .13728 Mdot
.1961 .1412 Mdot
.1961 .14513 Mdot
.20002 .15689 Mdot
.19218 .15689 Mdot
.18826 .15297 Mdot
.18042 .14513 Mdot
.18042 .1412 Mdot
.18042 .13728 Mdot
.1765 .13336 Mdot
.17257 .12552 Mdot
.17257 .11768 Mdot
.1765 .12552 Mdot
.17257 .1216 Mdot
.18042 .12944 Mdot
.18042 .12944 Mdot
.18042 .14513 Mdot
.1765 .14905 Mdot
.17257 .14905 Mdot
.15297 .13336 Mdot
.13728 .1216 Mdot
.1412 .11768 Mdot
.1412 .10983 Mdot
.15297 .11376 Mdot
.14513 .11768 Mdot
.13336 .10983 Mdot
.12944 .10983 Mdot
.13336 .10591 Mdot
.13728 .10199 Mdot
.13336 .08631 Mdot
.1216 .0667 Mdot
.86272 .87448 Mdot
.69802 .72155 Mdot
.43922 .48628 Mdot
.37256 .42354 Mdot
.26668 .30982 Mdot
.251 .28237 Mdot
.28237 .29413 Mdot
.29806 .29021 Mdot
.29021 .27061 Mdot
.21571 .20394 Mdot
.1765 .17257 Mdot
.1765 .18826 Mdot
.1765 .1961 Mdot
.16865 .18826 Mdot
.1412 .15297 Mdot
.13728 .1412 Mdot
.16865 .16865 Mdot
.18042 .1961 Mdot
.20787 .23531 Mdot
.21963 .25492 Mdot
.22355 .25884 Mdot
.21179 .25492 Mdot
.18434 .23139 Mdot
.17257 .21963 Mdot
.18042 .21963 Mdot
.1961 .22355 Mdot
.21179 .23924 Mdot
.21179 .23924 Mdot
.22355 .251 Mdot
.20394 .23531 Mdot
.16081 .20394 Mdot
.1216 .17257 Mdot
.10591 .15297 Mdot
.11768 .15689 Mdot
.11768 .14905 Mdot
.07454 .10199 Mdot
.06278 .07454 Mdot
.05886 .05494 Mdot
.05494 .05102 Mdot
.0667 .06278 Mdot
.07846 .07062 Mdot
.09023 .09023 Mdot
.11376 .11768 Mdot
.1216 .13336 Mdot
.15689 .16081 Mdot
.16081 .16473 Mdot
.16081 .16473 Mdot
.14905 .15297 Mdot
.12552 .11376 Mdot
.10983 .08631 Mdot
.10591 .07062 Mdot
.10591 .07062 Mdot
.11376 .07062 Mdot
.10199 .05494 Mdot
.09023 .04317 Mdot
.09023 .05102 Mdot
.08631 .05102 Mdot
.07454 .03925 Mdot
.07454 .04317 Mdot
.07062 .04317 Mdot
.07846 .05102 Mdot
.05886 .04709 Mdot
.07062 .06278 Mdot
.23531 .20787 Mdot
.26668 .23924 Mdot
.28629 .251 Mdot
.26276 .21963 Mdot
.25492 .20002 Mdot
.24708 .17257 Mdot
.24316 .16865 Mdot
.26276 .18434 Mdot
.27453 .20394 Mdot
.29021 .23139 Mdot
.29413 .24708 Mdot
.29413 .25492 Mdot
.29413 .251 Mdot
.29021 .24316 Mdot
.29413 .23139 Mdot
.29021 .22355 Mdot
.3059 .23139 Mdot
.31374 .23531 Mdot
.32158 .24708 Mdot
.31374 .23924 Mdot
.31374 .23531 Mdot
.29806 .23139 Mdot
.29021 .23531 Mdot
.29806 .23139 Mdot
.29413 .22355 Mdot
.29413 .21179 Mdot
.29021 .20787 Mdot
.27845 .20002 Mdot
.27845 .20002 Mdot
.28237 .20787 Mdot
.29021 .20787 Mdot
.29413 .21571 Mdot
.28237 .22355 Mdot
.29806 .23924 Mdot
.29021 .24316 Mdot
.27453 .22355 Mdot
.26668 .21571 Mdot
.26668 .22355 Mdot
.26668 .21571 Mdot
.26668 .20787 Mdot
.26276 .20394 Mdot
.27061 .20787 Mdot
.27061 .20787 Mdot
.27453 .20787 Mdot
.27453 .20787 Mdot
.27453 .21571 Mdot
.27061 .21179 Mdot
.25492 .20002 Mdot
.23531 .19218 Mdot
.22355 .18434 Mdot
.21179 .16865 Mdot
.20394 .15297 Mdot
.20394 .1412 Mdot
.20787 .13728 Mdot
.21179 .14513 Mdot
.21179 .14513 Mdot
.21179 .14513 Mdot
.21179 .14513 Mdot
.21179 .14513 Mdot
.20787 .14905 Mdot
.20394 .14905 Mdot
.20787 .15297 Mdot
.1961 .14513 Mdot
.18434 .13336 Mdot
.18434 .13728 Mdot
.18042 .1412 Mdot
.1765 .14905 Mdot
.18434 .14905 Mdot
.18434 .14905 Mdot
.18434 .15297 Mdot
.18042 .14905 Mdot
.18434 .15297 Mdot
.18042 .14905 Mdot
.18042 .14905 Mdot
.17257 .13728 Mdot
.16865 .12944 Mdot
.17257 .13728 Mdot
.18042 .14513 Mdot
.1765 .14513 Mdot
.16865 .14513 Mdot
.16473 .14513 Mdot
.15689 .14513 Mdot
.14513 .13336 Mdot
.14905 .13336 Mdot
.1412 .11768 Mdot
.14905 .11768 Mdot
.1412 .10983 Mdot
.13728 .10591 Mdot
.13336 .10199 Mdot
.12944 .09807 Mdot
.12944 .09415 Mdot
.12552 .09023 Mdot
.1216 .08631 Mdot
.8784 .89801 Mdot
.6196 .68234 Mdot
.47843 .56078 Mdot
.4902 .55686 Mdot
.50588 .56078 Mdot
.49804 .53725 Mdot
.42354 .45098 Mdot
.37256 .40001 Mdot
.39609 .42746 Mdot
.28237 .3255 Mdot
.15297 .1961 Mdot
.1216 .15297 Mdot
.10199 .11768 Mdot
.09415 .10591 Mdot
.10983 .1216 Mdot
.14905 .15297 Mdot
.1765 .18042 Mdot
.20787 .21571 Mdot
.21571 .23924 Mdot
.21179 .251 Mdot
.19218 .23924 Mdot
.22355 .26668 Mdot
.23531 .27845 Mdot
.24316 .28237 Mdot
.23924 .28629 Mdot
.24316 .29021 Mdot
.23139 .27845 Mdot
.22355 .27453 Mdot
.20002 .26668 Mdot
.18434 .24708 Mdot
.17257 .22747 Mdot
.11376 .17257 Mdot
.08239 .12944 Mdot
.07062 .10199 Mdot
.0667 .07454 Mdot
.07454 .07062 Mdot
.07454 .0667 Mdot
.06278 .05494 Mdot
.06278 .04709 Mdot
.06278 .05886 Mdot
.07846 .07454 Mdot
.15689 .15689 Mdot
.15689 .16081 Mdot
.1765 .17257 Mdot
.15689 .14905 Mdot
.1412 .13728 Mdot
.12552 .11768 Mdot
.11768 .10591 Mdot
.11376 .09807 Mdot
.10983 .09023 Mdot
.09807 .08239 Mdot
.09023 .07062 Mdot
.09023 .0667 Mdot
.08239 .05102 Mdot
.08631 .04709 Mdot
.08239 .04317 Mdot
.09807 .0667 Mdot
.08239 .05886 Mdot
.09415 .07062 Mdot
.11376 .09415 Mdot
.20394 .18042 Mdot
.32158 .29413 Mdot
.34119 .31374 Mdot
.34119 .30982 Mdot
.33335 .28629 Mdot
.29806 .24708 Mdot
.27061 .22355 Mdot
.26668 .20787 Mdot
.26276 .20002 Mdot
.27061 .20787 Mdot
.27845 .21963 Mdot
.29021 .23139 Mdot
.30982 .24708 Mdot
.29806 .23924 Mdot
.30198 .23924 Mdot
.31374 .24316 Mdot
.30982 .24316 Mdot
.30198 .24316 Mdot
.30982 .251 Mdot
.31374 .23924 Mdot
.31374 .23531 Mdot
.3059 .22747 Mdot
.3059 .22355 Mdot
.3059 .22747 Mdot
.3059 .23139 Mdot
.30198 .23139 Mdot
.29413 .23139 Mdot
.30198 .23531 Mdot
.29413 .23531 Mdot
.29021 .22747 Mdot
.28629 .21179 Mdot
.28629 .20787 Mdot
.28629 .21179 Mdot
.28237 .21571 Mdot
.28629 .22355 Mdot
.28237 .21179 Mdot
.27845 .20787 Mdot
.28237 .21571 Mdot
.27845 .21963 Mdot
.27453 .21963 Mdot
.27061 .21571 Mdot
.27845 .21963 Mdot
.27845 .21571 Mdot
.27453 .21179 Mdot
.27453 .21179 Mdot
.27453 .20787 Mdot
.27453 .20394 Mdot
.25884 .19218 Mdot
.25492 .20002 Mdot
.24316 .18826 Mdot
.23139 .18042 Mdot
.22747 .17257 Mdot
.20787 .15297 Mdot
.20394 .15297 Mdot
.20002 .15297 Mdot
.21179 .16473 Mdot
.21179 .16473 Mdot
.20394 .16473 Mdot
.1961 .15689 Mdot
.20002 .15689 Mdot
.1961 .15689 Mdot
.20002 .16473 Mdot
.1961 .15689 Mdot
.19218 .15689 Mdot
.19218 .15297 Mdot
.18826 .14905 Mdot
.19218 .14905 Mdot
.18826 .14513 Mdot
.18434 .14513 Mdot
.18434 .15297 Mdot
.20394 .1765 Mdot
.20002 .18434 Mdot
.18826 .18042 Mdot
.1961 .18434 Mdot
.18434 .16081 Mdot
.1765 .14905 Mdot
.17257 .14513 Mdot
.1765 .14513 Mdot
.16865 .1412 Mdot
.16865 .1412 Mdot
.16081 .13728 Mdot
.16081 .13336 Mdot
.16865 .13728 Mdot
.16473 .13728 Mdot
.15689 .13336 Mdot
.15689 .12552 Mdot
.14513 .10591 Mdot
.13336 .09807 Mdot
.13336 .10199 Mdot
.12944 .10199 Mdot
.14513 .10591 Mdot
.1412 .10591 Mdot
.12944 .10199 Mdot
.76861 .81174 Mdot
.65881 .70979 Mdot
.54117 .59607 Mdot
.54509 .58039 Mdot
.54117 .56862 Mdot
.54902 .57254 Mdot
.43138 .46275 Mdot
.12552 .17257 Mdot
.1216 .15297 Mdot
.10591 .1216 Mdot
.09023 .10199 Mdot
.07846 .08239 Mdot
.08239 .08631 Mdot
.1216 .1216 Mdot
.1412 .1412 Mdot
.16473 .16865 Mdot
.20394 .21963 Mdot
.21179 .23139 Mdot
.26276 .28237 Mdot
.27061 .29413 Mdot
.251 .27845 Mdot
.251 .29021 Mdot
.23531 .28237 Mdot
.23531 .29021 Mdot
.22355 .28629 Mdot
.22355 .28629 Mdot
.22747 .3059 Mdot
.21963 .29413 Mdot
.21179 .27453 Mdot
.14905 .21179 Mdot
.10591 .16081 Mdot
.08631 .12552 Mdot
.07454 .09807 Mdot
.07454 .08631 Mdot
.05494 .06278 Mdot
.0667 .05886 Mdot
.07062 .05886 Mdot
.09807 .08631 Mdot
.16473 .15689 Mdot
.1412 .1412 Mdot
.14513 .1412 Mdot
.15689 .14513 Mdot
.15689 .1412 Mdot
.13728 .12944 Mdot
.13728 .12552 Mdot
.11768 .11376 Mdot
.11768 .1216 Mdot
.1216 .1216 Mdot
.1216 .11768 Mdot
.10983 .09807 Mdot
.10199 .08239 Mdot
.10199 .07846 Mdot
.09807 .07062 Mdot
.11376 .07846 Mdot
.10199 .0667 Mdot
.11376 .08631 Mdot
.16473 .12552 Mdot
.14905 .10983 Mdot
.28629 .24316 Mdot
.33335 .29413 Mdot
.30198 .27453 Mdot
.28629 .26276 Mdot
.3059 .27845 Mdot
.31766 .27453 Mdot
.3059 .251 Mdot
.27845 .21963 Mdot
.27453 .20002 Mdot
.27845 .20394 Mdot
.28237 .20002 Mdot
.29021 .21963 Mdot
.29413 .22747 Mdot
.29021 .22355 Mdot
.29806 .23139 Mdot
.30198 .24316 Mdot
.29021 .23531 Mdot
.30198 .24316 Mdot
.30982 .24708 Mdot
.29413 .23139 Mdot
.30198 .23531 Mdot
.3059 .23139 Mdot
.3059 .23139 Mdot
.3059 .23531 Mdot
.30982 .24316 Mdot
.3059 .251 Mdot
.30198 .251 Mdot
.28629 .24708 Mdot
.28629 .251 Mdot
.28237 .24316 Mdot
.28237 .22355 Mdot
.28237 .21963 Mdot
.27845 .21571 Mdot
.28237 .21571 Mdot
.27845 .20394 Mdot
.28629 .20787 Mdot
.28237 .20787 Mdot
.28237 .21963 Mdot
.27845 .22747 Mdot
.26668 .22355 Mdot
.27453 .23531 Mdot
.26276 .22747 Mdot
.26668 .22747 Mdot
.26276 .21963 Mdot
.25884 .20002 Mdot
.25884 .19218 Mdot
.25492 .19218 Mdot
.25884 .19218 Mdot
.27061 .19218 Mdot
.25884 .19218 Mdot
.24316 .18826 Mdot
.23139 .18826 Mdot
.21963 .18434 Mdot
.20394 .16473 Mdot
.20002 .16865 Mdot
.19218 .17257 Mdot
.18826 .17257 Mdot
.18826 .16473 Mdot
.18434 .14905 Mdot
.19218 .14905 Mdot
.1961 .14905 Mdot
.20394 .14905 Mdot
.1961 .14513 Mdot
.1961 .14905 Mdot
.20394 .14905 Mdot
.1961 .14513 Mdot
.1961 .14905 Mdot
.18826 .1412 Mdot
.18826 .14513 Mdot
.18434 .14513 Mdot
.18434 .16081 Mdot
.19218 .1765 Mdot
.18434 .16865 Mdot
.18042 .15689 Mdot
.1765 .14513 Mdot
.16473 .13336 Mdot
.16081 .12944 Mdot
.16081 .12944 Mdot
.16473 .12944 Mdot
.17257 .13336 Mdot
.1765 .12944 Mdot
.16865 .1216 Mdot
.18434 .13728 Mdot
.17257 .13728 Mdot
.16081 .1216 Mdot
.14905 .10591 Mdot
.13336 .09415 Mdot
.13336 .10199 Mdot
.12944 .10983 Mdot
.14513 .1216 Mdot
.13728 .11768 Mdot
.12944 .11376 Mdot
.78037 .79606 Mdot
.56862 .59215 Mdot
.57254 .58823 Mdot
.53725 .55294 Mdot
.31766 .34511 Mdot
.12552 .16081 Mdot
.12944 .14905 Mdot
.10983 .11376 Mdot
.08631 .08631 Mdot
.08631 .08239 Mdot
.08239 .07454 Mdot
.09023 .07846 Mdot
.10983 .09807 Mdot
.13336 .12944 Mdot
.15297 .15689 Mdot
.1961 .20002 Mdot
.22355 .23139 Mdot
.23924 .23924 Mdot
.24316 .25492 Mdot
.24708 .27845 Mdot
.24316 .28629 Mdot
.24316 .29021 Mdot
.24316 .29413 Mdot
.251 .3059 Mdot
.24708 .29806 Mdot
.24316 .3059 Mdot
.24708 .30982 Mdot
.22747 .28237 Mdot
.19218 .23924 Mdot
.13728 .16473 Mdot
.11376 .13336 Mdot
.10199 .1216 Mdot
.08631 .10591 Mdot
.0667 .08239 Mdot
.13336 .14513 Mdot
.13336 .14513 Mdot
.11376 .1216 Mdot
.10591 .10591 Mdot
.13336 .1216 Mdot
.15297 .13336 Mdot
.14513 .11768 Mdot
.13336 .10591 Mdot
.13728 .1216 Mdot
.13336 .12552 Mdot
.1412 .13336 Mdot
.13336 .11768 Mdot
.13728 .1216 Mdot
.12552 .11376 Mdot
.12552 .10591 Mdot
.12552 .09807 Mdot
.10591 .08239 Mdot
.10199 .07846 Mdot
.08631 .07454 Mdot
.10591 .09023 Mdot
.10983 .09023 Mdot
.36472 .32158 Mdot
.36864 .33727 Mdot
.26668 .24708 Mdot
.18434 .17257 Mdot
.19218 .1765 Mdot
.20787 .1765 Mdot
.30982 .25884 Mdot
.30982 .24708 Mdot
.31766 .24316 Mdot
.30982 .23139 Mdot
.28237 .21179 Mdot
.27845 .21571 Mdot
.29021 .22747 Mdot
.29021 .23924 Mdot
.28237 .23531 Mdot
.27453 .22747 Mdot
.27453 .23139 Mdot
.28629 .23924 Mdot
.3059 .251 Mdot
.29413 .23924 Mdot
.30198 .24708 Mdot
.29806 .24316 Mdot
.30198 .23531 Mdot
.29806 .23924 Mdot
.28629 .23139 Mdot
.29021 .24316 Mdot
.29413 .251 Mdot
.29021 .25492 Mdot
.28629 .251 Mdot
.27845 .24708 Mdot
.27845 .24316 Mdot
.27453 .23531 Mdot
.27845 .22747 Mdot
.29021 .22355 Mdot
.28237 .20787 Mdot
.27845 .20394 Mdot
.28629 .21179 Mdot
.28237 .21571 Mdot
.27845 .21571 Mdot
.27845 .22747 Mdot
.27453 .23531 Mdot
.27061 .22747 Mdot
.27453 .23139 Mdot
.26668 .21963 Mdot
.25884 .20787 Mdot
.25884 .1961 Mdot
.26276 .1961 Mdot
.27453 .20002 Mdot
.27061 .1961 Mdot
.26276 .19218 Mdot
.26668 .20002 Mdot
.25884 .20002 Mdot
.24316 .20002 Mdot
.21963 .18042 Mdot
.20002 .17257 Mdot
.18042 .15689 Mdot
.19218 .16865 Mdot
.18826 .15689 Mdot
.19218 .14905 Mdot
.1961 .13728 Mdot
.19218 .12552 Mdot
.1961 .12944 Mdot
.20394 .1412 Mdot
.20002 .14513 Mdot
.20002 .14513 Mdot
.18826 .13336 Mdot
.1961 .13728 Mdot
.1961 .1412 Mdot
.19218 .14513 Mdot
.17257 .13336 Mdot
.1765 .13728 Mdot
.19218 .14905 Mdot
.18826 .14905 Mdot
.18826 .16081 Mdot
.19218 .14513 Mdot
.17257 .12552 Mdot
.1765 .12944 Mdot
.16081 .11376 Mdot
.16081 .11768 Mdot
.15689 .11768 Mdot
.15689 .11376 Mdot
.16473 .11376 Mdot
.1765 .12552 Mdot
.1765 .13336 Mdot
.16473 .12552 Mdot
.14513 .11768 Mdot
.12944 .10199 Mdot
.11768 .09023 Mdot
.13728 .10199 Mdot
.1412 .11768 Mdot
.12944 .11768 Mdot
.12552 .11768 Mdot
.89409 .89801 Mdot
.79213 .79998 Mdot
.48628 .49804 Mdot
.25492 .27845 Mdot
.18042 .18826 Mdot
.15297 .15689 Mdot
.11376 .1216 Mdot
.10199 .10591 Mdot
.09023 .08631 Mdot
.08631 .07846 Mdot
.09023 .08239 Mdot
.09807 .08239 Mdot
.09023 .07846 Mdot
.11376 .10199 Mdot
.13728 .12552 Mdot
.18826 .17257 Mdot
.23531 .22355 Mdot
.251 .251 Mdot
.26276 .26668 Mdot
.27061 .29021 Mdot
.27061 .30198 Mdot
.27845 .31766 Mdot
.26668 .32158 Mdot
.25884 .31374 Mdot
.25492 .3059 Mdot
.251 .29413 Mdot
.25492 .28629 Mdot
.24316 .26668 Mdot
.22355 .24708 Mdot
.20787 .23531 Mdot
.15689 .19218 Mdot
.12944 .16473 Mdot
.16865 .18434 Mdot
.12944 .14905 Mdot
.07846 .10199 Mdot
.07454 .09023 Mdot
.09415 .09023 Mdot
.09415 .08631 Mdot
.10983 .09807 Mdot
.1216 .10591 Mdot
.12552 .10983 Mdot
.12944 .10983 Mdot
.1216 .10199 Mdot
.12552 .09807 Mdot
.13336 .10199 Mdot
.13728 .10199 Mdot
.1412 .10591 Mdot
.13336 .09807 Mdot
.1216 .09023 Mdot
.10983 .09415 Mdot
.10199 .09807 Mdot
.1216 .1216 Mdot
.10591 .11376 Mdot
.21179 .20787 Mdot
.23531 .22355 Mdot
.15297 .14513 Mdot
.17257 .15689 Mdot
.14513 .12552 Mdot
.11376 .08631 Mdot
.14513 .10983 Mdot
.23924 .19218 Mdot
.33335 .27845 Mdot
.34903 .29806 Mdot
.33727 .29413 Mdot
.31374 .27061 Mdot
.29021 .24708 Mdot
.28629 .24708 Mdot
.27453 .24316 Mdot
.251 .22747 Mdot
.24708 .22747 Mdot
.25884 .23531 Mdot
.27845 .24708 Mdot
.29021 .25884 Mdot
.29806 .26276 Mdot
.29806 .25884 Mdot
.29413 .251 Mdot
.28629 .23139 Mdot
.29021 .23139 Mdot
.30198 .23139 Mdot
.29021 .22355 Mdot
.28629 .22747 Mdot
.29413 .23531 Mdot
.28237 .23924 Mdot
.27845 .24708 Mdot
.28629 .24708 Mdot
.28629 .23531 Mdot
.28629 .23139 Mdot
.27453 .20787 Mdot
.27845 .20787 Mdot
.27845 .20787 Mdot
.28237 .21179 Mdot
.27453 .21179 Mdot
.27845 .21179 Mdot
.28629 .22355 Mdot
.27453 .21963 Mdot
.27453 .23139 Mdot
.27061 .22747 Mdot
.27061 .21963 Mdot
.27061 .21963 Mdot
.25884 .20394 Mdot
.26276 .20394 Mdot
.26276 .20002 Mdot
.26276 .19218 Mdot
.25492 .18042 Mdot
.25884 .19218 Mdot
.251 .19218 Mdot
.23924 .19218 Mdot
.23139 .18826 Mdot
.22355 .18826 Mdot
.20394 .1765 Mdot
.20394 .16473 Mdot
.1961 .15297 Mdot
.19218 .14905 Mdot
.20002 .14513 Mdot
.20002 .1412 Mdot
.1961 .1412 Mdot
.18042 .12944 Mdot
.17257 .13336 Mdot
.1765 .13336 Mdot
.1765 .13336 Mdot
.19218 .14513 Mdot
.18042 .13728 Mdot
.18826 .14513 Mdot
.18042 .13728 Mdot
.18042 .13728 Mdot
.18434 .1412 Mdot
.18434 .14513 Mdot
.1961 .14905 Mdot
.1961 .1412 Mdot
.18826 .13336 Mdot
.1765 .12552 Mdot
.16865 .12552 Mdot
.15689 .1216 Mdot
.15689 .13336 Mdot
.16473 .13336 Mdot
.16865 .12944 Mdot
.16473 .12944 Mdot
.15689 .1216 Mdot
.14513 .11376 Mdot
.13336 .10983 Mdot
.13336 .10591 Mdot
.1412 .10199 Mdot
.13728 .09807 Mdot
.13336 .10199 Mdot
.12552 .10591 Mdot
.73332 .749 Mdot
.51765 .54509 Mdot
.24708 .27453 Mdot
.18434 .21179 Mdot
.14905 .17257 Mdot
.13336 .14905 Mdot
.12552 .12552 Mdot
.10983 .09807 Mdot
.10591 .08631 Mdot
.09807 .07846 Mdot
.09415 .07846 Mdot
.09415 .08239 Mdot
.09023 .07062 Mdot
.15689 .12552 Mdot
.18434 .16081 Mdot
.22355 .20787 Mdot
.24708 .24708 Mdot
.25884 .27061 Mdot
.27061 .29806 Mdot
.27453 .31766 Mdot
.251 .29806 Mdot
.24316 .29021 Mdot
.25492 .29413 Mdot
.25884 .30198 Mdot
.26668 .30198 Mdot
.27453 .3059 Mdot
.26668 .30198 Mdot
.25492 .28629 Mdot
.23531 .27845 Mdot
.21571 .25884 Mdot
.13728 .18434 Mdot
.09023 .13336 Mdot
.0667 .10591 Mdot
.06278 .09023 Mdot
.05494 .07846 Mdot
.05886 .07454 Mdot
.07062 .07454 Mdot
.10199 .09807 Mdot
.11376 .10199 Mdot
.1216 .10591 Mdot
.11768 .09415 Mdot
.12552 .09807 Mdot
.13728 .10199 Mdot
.14905 .11376 Mdot
.1412 .10591 Mdot
.14513 .1216 Mdot
.14905 .13336 Mdot
.15297 .15689 Mdot
.14905 .16473 Mdot
.12552 .15297 Mdot
.09807 .1216 Mdot
.09807 .11768 Mdot
.10199 .11376 Mdot
.12944 .1216 Mdot
.1216 .10983 Mdot
.10983 .10199 Mdot
.09807 .09415 Mdot
.09807 .09415 Mdot
.19218 .17257 Mdot
.25492 .23139 Mdot
.30982 .28237 Mdot
.34511 .30982 Mdot
.34903 .31374 Mdot
.29413 .26276 Mdot
.21179 .19218 Mdot
.18434 .16865 Mdot
.18042 .16473 Mdot
.1961 .18042 Mdot
.21179 .1961 Mdot
.25492 .22747 Mdot
.26668 .23531 Mdot
.29021 .251 Mdot
.28237 .24316 Mdot
.28629 .24708 Mdot
.29413 .23531 Mdot
.3059 .23139 Mdot
.29021 .21179 Mdot
.29806 .21179 Mdot
.29413 .21571 Mdot
.28629 .22355 Mdot
.28629 .23531 Mdot
.28237 .22747 Mdot
.27453 .21963 Mdot
.28237 .22747 Mdot
.27845 .21571 Mdot
.27453 .21179 Mdot
.27845 .21179 Mdot
.27453 .20394 Mdot
.27845 .20787 Mdot
.27845 .20787 Mdot
.27845 .20002 Mdot
.27453 .20002 Mdot
.27453 .20394 Mdot
.28629 .22355 Mdot
.27845 .21963 Mdot
.28237 .21963 Mdot
.27845 .21571 Mdot
.27061 .20787 Mdot
.27061 .20394 Mdot
.26668 .20002 Mdot
.24708 .18434 Mdot
.251 .19218 Mdot
.24708 .19218 Mdot
.25884 .20394 Mdot
.25884 .20394 Mdot
.23924 .18826 Mdot
.22747 .18434 Mdot
.21963 .1765 Mdot
.20394 .16081 Mdot
.20002 .16473 Mdot
.20394 .16473 Mdot
.21179 .16865 Mdot
.21179 .16473 Mdot
.20394 .16473 Mdot
.1765 .14905 Mdot
.16473 .13336 Mdot
.1765 .12944 Mdot
.18042 .12552 Mdot
.18042 .12552 Mdot
.18434 .12944 Mdot
.18042 .12552 Mdot
.18042 .12552 Mdot
.18826 .13728 Mdot
.1961 .13728 Mdot
.19218 .13336 Mdot
.18826 .13336 Mdot
.18434 .12944 Mdot
.18042 .13728 Mdot
.1765 .13728 Mdot
.16473 .12944 Mdot
.15689 .13336 Mdot
.14905 .12552 Mdot
.16081 .12944 Mdot
.14905 .11768 Mdot
.1412 .10983 Mdot
.15297 .11768 Mdot
.13336 .10199 Mdot
.11376 .08631 Mdot
.1216 .08631 Mdot
.13336 .08239 Mdot
.13728 .08631 Mdot
.12944 .08631 Mdot
.64705 .66273 Mdot
.41177 .43138 Mdot
.19218 .21179 Mdot
.17257 .17257 Mdot
.1412 .12944 Mdot
.11768 .10591 Mdot
.10983 .09807 Mdot
.10199 .09023 Mdot
.09023 .07454 Mdot
.09023 .0667 Mdot
.09023 .0667 Mdot
.09415 .07062 Mdot
.13336 .10591 Mdot
.20002 .17257 Mdot
.24708 .23531 Mdot
.24708 .25492 Mdot
.26276 .28629 Mdot
.26276 .29413 Mdot
.26668 .30198 Mdot
.25492 .29806 Mdot
.26276 .3059 Mdot
.27061 .30198 Mdot
.26668 .29806 Mdot
.26668 .29413 Mdot
.28629 .31374 Mdot
.28629 .3255 Mdot
.27453 .3255 Mdot
.23531 .29021 Mdot
.19218 .251 Mdot
.1216 .1765 Mdot
.07454 .12552 Mdot
.07454 .10983 Mdot
.0667 .09023 Mdot
.0667 .08239 Mdot
.07846 .08631 Mdot
.10199 .10591 Mdot
.11768 .11768 Mdot
.1216 .1216 Mdot
.12552 .10983 Mdot
.13728 .1216 Mdot
.14905 .1216 Mdot
.14905 .1216 Mdot
.14513 .1216 Mdot
.20394 .18826 Mdot
.20394 .20787 Mdot
.19218 .21571 Mdot
.13728 .16473 Mdot
.11768 .1412 Mdot
.09023 .11376 Mdot
.09023 .10983 Mdot
.10591 .11376 Mdot
.10983 .10983 Mdot
.10199 .09807 Mdot
.10591 .10591 Mdot
.10591 .10591 Mdot
.09415 .09415 Mdot
.1216 .10199 Mdot
.1412 .11376 Mdot
.19218 .16081 Mdot
.32943 .29021 Mdot
.31374 .27845 Mdot
.16865 .14513 Mdot
.13728 .11768 Mdot
.10983 .09023 Mdot
.10199 .08239 Mdot
.10199 .07846 Mdot
.18434 .14513 Mdot
.22355 .1765 Mdot
.26668 .21179 Mdot
.28629 .23531 Mdot
.29021 .251 Mdot
.29021 .24708 Mdot
.29806 .24316 Mdot
.29413 .23139 Mdot
.29413 .22747 Mdot
.28629 .21963 Mdot
.28237 .21571 Mdot
.29413 .21963 Mdot
.29413 .21571 Mdot
.28237 .21179 Mdot
.27453 .21571 Mdot
.28629 .22355 Mdot
.27061 .21571 Mdot
.26668 .21179 Mdot
.26668 .21179 Mdot
.27061 .21963 Mdot
.26668 .20394 Mdot
.26668 .18826 Mdot
.25884 .18434 Mdot
.27061 .1961 Mdot
.27453 .20002 Mdot
.27453 .1961 Mdot
.28237 .20787 Mdot
.27845 .20787 Mdot
.28237 .21963 Mdot
.27845 .22747 Mdot
.26668 .21963 Mdot
.25492 .21179 Mdot
.24708 .20394 Mdot
.23924 .1961 Mdot
.24316 .19218 Mdot
.24708 .19218 Mdot
.24708 .18826 Mdot
.24708 .18826 Mdot
.24708 .18826 Mdot
.23531 .1765 Mdot
.23139 .16865 Mdot
.21963 .16865 Mdot
.21179 .16865 Mdot
.20394 .17257 Mdot
.1961 .16865 Mdot
.18042 .15297 Mdot
.1765 .1412 Mdot
.1765 .13336 Mdot
.17257 .11768 Mdot
.1765 .11376 Mdot
.1765 .11376 Mdot
.16473 .10591 Mdot
.15689 .09807 Mdot
.17257 .10591 Mdot
.18434 .11768 Mdot
.1765 .11768 Mdot
.18826 .13336 Mdot
.18042 .13336 Mdot
.1765 .14905 Mdot
.17257 .16081 Mdot
.14513 .13728 Mdot
.13728 .13336 Mdot
.13728 .12552 Mdot
.14513 .12944 Mdot
.14905 .12944 Mdot
.15297 .1216 Mdot
.14513 .11376 Mdot
.13728 .09807 Mdot
.12552 .08631 Mdot
.13336 .08631 Mdot
.13336 .07454 Mdot
.12944 .07062 Mdot
.12552 .0667 Mdot
.80782 .81174 Mdot
.62352 .6196 Mdot
.22747 .21571 Mdot
.15297 .1412 Mdot
.13336 .1216 Mdot
.10591 .09807 Mdot
.09807 .09023 Mdot
.09415 .07454 Mdot
.10199 .07454 Mdot
.09415 .0667 Mdot
.10199 .07846 Mdot
.11768 .09023 Mdot
.14513 .12552 Mdot
.18042 .1765 Mdot
.21179 .21963 Mdot
.23924 .251 Mdot
.251 .27061 Mdot
.26668 .29021 Mdot
.27845 .30198 Mdot
.28629 .30198 Mdot
.27845 .29413 Mdot
.27845 .29021 Mdot
.27845 .29413 Mdot
.27061 .30198 Mdot
.27061 .31374 Mdot
.27061 .32158 Mdot
.27061 .32943 Mdot
.251 .3059 Mdot
.19218 .24316 Mdot
.11376 .16081 Mdot
.10591 .14513 Mdot
.08631 .11768 Mdot
.0667 .09807 Mdot
.08239 .11768 Mdot
.11376 .1412 Mdot
.12552 .14513 Mdot
.12944 .1412 Mdot
.13728 .14513 Mdot
.1412 .14513 Mdot
.1412 .13728 Mdot
.13336 .12552 Mdot
.20394 .18826 Mdot
.24708 .23924 Mdot
.25884 .26276 Mdot
.21179 .21963 Mdot
.16865 .18434 Mdot
.13336 .14905 Mdot
.10591 .1216 Mdot
.10983 .12552 Mdot
.10199 .1216 Mdot
.10199 .10983 Mdot
.10199 .10591 Mdot
.08631 .09023 Mdot
.07454 .07454 Mdot
.09415 .07454 Mdot
.11376 .08239 Mdot
.09415 .05886 Mdot
.14513 .11376 Mdot
.16473 .13336 Mdot
.12944 .10199 Mdot
.10591 .07846 Mdot
.10591 .07846 Mdot
.10591 .07846 Mdot
.09023 .0667 Mdot
.13728 .10591 Mdot
.16865 .12552 Mdot
.23531 .18434 Mdot
.251 .1961 Mdot
.26668 .21571 Mdot
.26668 .22355 Mdot
.29806 .24316 Mdot
.29806 .23924 Mdot
.30198 .23531 Mdot
.29806 .22355 Mdot
.28629 .21571 Mdot
.3059 .22355 Mdot
.29413 .20787 Mdot
.28629 .21179 Mdot
.29021 .21963 Mdot
.28237 .21963 Mdot
.27453 .22355 Mdot
.27061 .22355 Mdot
.27061 .22747 Mdot
.27453 .23139 Mdot
.27453 .23139 Mdot
.27061 .20787 Mdot
.25884 .19218 Mdot
.23924 .1765 Mdot
.24316 .16865 Mdot
.24708 .16473 Mdot
.25884 .18042 Mdot
.27061 .20002 Mdot
.27061 .20787 Mdot
.27845 .21963 Mdot
.27845 .22747 Mdot
.26668 .22355 Mdot
.251 .22355 Mdot
.251 .21963 Mdot
.24316 .20394 Mdot
.23924 .18826 Mdot
.23531 .18434 Mdot
.23924 .18826 Mdot
.23924 .18042 Mdot
.25492 .18434 Mdot
.23924 .17257 Mdot
.23139 .18042 Mdot
.23531 .18826 Mdot
.21571 .18434 Mdot
.20002 .18042 Mdot
.19218 .17257 Mdot
.1961 .16865 Mdot
.18042 .1412 Mdot
.17257 .12944 Mdot
.18042 .13336 Mdot
.18434 .12944 Mdot
.18434 .11768 Mdot
.17257 .11768 Mdot
.17257 .11376 Mdot
.1765 .1216 Mdot
.16865 .11376 Mdot
.18434 .12944 Mdot
.1765 .13728 Mdot
.1765 .15297 Mdot
.1765 .16473 Mdot
.16473 .15297 Mdot
.14513 .13728 Mdot
.14905 .1412 Mdot
.13728 .1216 Mdot
.1412 .11768 Mdot
.14905 .1216 Mdot
.14905 .11376 Mdot
.1412 .09415 Mdot
.14513 .09023 Mdot
.15297 .08631 Mdot
.15297 .07454 Mdot
.13336 .05886 Mdot
.12552 .05886 Mdot
.80782 .80782 Mdot
.59215 .59607 Mdot
.16081 .16473 Mdot
.13728 .14905 Mdot
.1216 .12552 Mdot
.10983 .09807 Mdot
.11376 .09807 Mdot
.11376 .10199 Mdot
.11376 .10199 Mdot
.1216 .10591 Mdot
.1216 .10591 Mdot
.12944 .12552 Mdot
.14905 .14513 Mdot
.18826 .18826 Mdot
.24708 .24708 Mdot
.27845 .27845 Mdot
.29806 .30198 Mdot
.30198 .31766 Mdot
.29806 .32158 Mdot
.28629 .31766 Mdot
.27453 .31766 Mdot
.27061 .31766 Mdot
.25492 .31766 Mdot
.29413 .35687 Mdot
.25884 .32158 Mdot
.28237 .3255 Mdot
.23924 .27061 Mdot
.22747 .251 Mdot
.19218 .22355 Mdot
.1216 .16865 Mdot
.10199 .15297 Mdot
.16081 .20787 Mdot
.15297 .20002 Mdot
.12944 .16865 Mdot
.1216 .14905 Mdot
.12552 .14513 Mdot
.1216 .13336 Mdot
.12552 .12552 Mdot
.12552 .11768 Mdot
.1765 .16865 Mdot
.21963 .22355 Mdot
.23924 .24316 Mdot
.23531 .23924 Mdot
.22355 .23139 Mdot
.19218 .1961 Mdot
.14905 .16865 Mdot
.12552 .14905 Mdot
.10983 .12944 Mdot
.09023 .10199 Mdot
.07062 .07454 Mdot
.05494 .05886 Mdot
.09023 .07846 Mdot
.10199 .08239 Mdot
.10199 .07454 Mdot
.11376 .08631 Mdot
.13728 .10983 Mdot
.14905 .12552 Mdot
.11376 .09415 Mdot
.10591 .08239 Mdot
.10983 .09023 Mdot
.11768 .09807 Mdot
.16081 .1412 Mdot
.20002 .16473 Mdot
.21963 .18042 Mdot
.24316 .19218 Mdot
.25884 .18826 Mdot
.26276 .18826 Mdot
.28629 .20787 Mdot
.28629 .20002 Mdot
.29021 .20787 Mdot
.30198 .22355 Mdot
.30198 .22355 Mdot
.30982 .23139 Mdot
.29413 .22355 Mdot
.29413 .22355 Mdot
.29021 .22355 Mdot
.28629 .21571 Mdot
.29021 .22355 Mdot
.28629 .22747 Mdot
.29021 .22747 Mdot
.29413 .23139 Mdot
.30198 .24316 Mdot
.3059 .23924 Mdot
.29021 .22747 Mdot
.27453 .21963 Mdot
.26276 .20787 Mdot
.25492 .19218 Mdot
.251 .18826 Mdot
.251 .18826 Mdot
.251 .18826 Mdot
.25492 .19218 Mdot
.26668 .20394 Mdot
.25884 .20394 Mdot
.25884 .20787 Mdot
.25884 .21571 Mdot
.251 .21179 Mdot
.23531 .20002 Mdot
.24708 .21179 Mdot
.24708 .21179 Mdot
.23531 .1961 Mdot
.24316 .19218 Mdot
.23531 .18826 Mdot
.23139 .19218 Mdot
.23531 .1961 Mdot
.22747 .19218 Mdot
.22355 .19218 Mdot
.22355 .18434 Mdot
.22747 .18042 Mdot
.21179 .16473 Mdot
.20394 .15297 Mdot
.21179 .16081 Mdot
.21179 .16081 Mdot
.20002 .14905 Mdot
.1961 .15297 Mdot
.18826 .15689 Mdot
.17257 .15297 Mdot
.16473 .14513 Mdot
.16081 .1412 Mdot
.16473 .1412 Mdot
.16473 .1412 Mdot
.16865 .14513 Mdot
.18042 .15689 Mdot
.16865 .14513 Mdot
.16081 .13728 Mdot
.16865 .13336 Mdot
.16081 .11768 Mdot
.16865 .1216 Mdot
.16473 .11768 Mdot
.17257 .11376 Mdot
.16865 .10199 Mdot
.16865 .09415 Mdot
.15689 .08631 Mdot
.15689 .09023 Mdot
.14905 .08239 Mdot
.62352 .63136 Mdot
.38432 .40393 Mdot
.16473 .19218 Mdot
.1765 .20002 Mdot
.1961 .21571 Mdot
.16865 .1765 Mdot
.15297 .15689 Mdot
.14513 .14513 Mdot
.13336 .12944 Mdot
.1412 .13336 Mdot
.14905 .13728 Mdot
.18826 .1765 Mdot
.20394 .1961 Mdot
.25492 .23924 Mdot
.28629 .27453 Mdot
.30982 .30982 Mdot
.30982 .3255 Mdot
.3059 .34511 Mdot
.29021 .34119 Mdot
.26276 .32158 Mdot
.25492 .30982 Mdot
.25884 .3059 Mdot
.27453 .3059 Mdot
.29413 .3255 Mdot
.29021 .32158 Mdot
.28629 .3255 Mdot
.26668 .30982 Mdot
.21963 .27453 Mdot
.20787 .26668 Mdot
.12944 .19218 Mdot
.10591 .15689 Mdot
.08631 .12552 Mdot
.07846 .10983 Mdot
.08631 .09415 Mdot
.09023 .09023 Mdot
.07846 .07846 Mdot
.09023 .09415 Mdot
.12944 .13336 Mdot
.20394 .20002 Mdot
.23531 .23531 Mdot
.251 .24708 Mdot
.25492 .251 Mdot
.24316 .251 Mdot
.18042 .20002 Mdot
.14513 .1765 Mdot
.11768 .14905 Mdot
.09023 .10983 Mdot
.06278 .07062 Mdot
.06278 .0667 Mdot
.07846 .07062 Mdot
.08239 .07062 Mdot
.12944 .11376 Mdot
.14513 .1216 Mdot
.16473 .13728 Mdot
.14513 .11768 Mdot
.1412 .10983 Mdot
.13336 .10199 Mdot
.11768 .08631 Mdot
.14905 .1216 Mdot
.16865 .12944 Mdot
.1961 .14513 Mdot
.20787 .15297 Mdot
.23531 .16081 Mdot
.23924 .16081 Mdot
.26668 .18826 Mdot
.28237 .20002 Mdot
.28237 .20002 Mdot
.28629 .20002 Mdot
.29806 .21179 Mdot
.29806 .22355 Mdot
.30198 .22747 Mdot
.29413 .22747 Mdot
.28629 .22355 Mdot
.28629 .21963 Mdot
.29413 .22355 Mdot
.28629 .21963 Mdot
.28629 .21963 Mdot
.29021 .23139 Mdot
.29806 .24708 Mdot
.3059 .25492 Mdot
.30198 .24708 Mdot
.29021 .23924 Mdot
.27453 .22747 Mdot
.26276 .21179 Mdot
.25884 .20394 Mdot
.26276 .20787 Mdot
.24708 .20002 Mdot
.24708 .20394 Mdot
.24316 .19218 Mdot
.23924 .18434 Mdot
.24316 .18826 Mdot
.24708 .19218 Mdot
.24316 .19218 Mdot
.22747 .18826 Mdot
.23531 .1961 Mdot
.23531 .1961 Mdot
.22355 .18434 Mdot
.21571 .18042 Mdot
.21179 .1765 Mdot
.21571 .18434 Mdot
.21179 .1765 Mdot
.21963 .18042 Mdot
.20787 .1765 Mdot
.22355 .18042 Mdot
.21963 .1765 Mdot
.21571 .16865 Mdot
.21179 .16865 Mdot
.21963 .1765 Mdot
.21963 .18042 Mdot
.21963 .1765 Mdot
.21179 .1765 Mdot
.1961 .18042 Mdot
.18826 .18042 Mdot
.18434 .1765 Mdot
.16865 .16473 Mdot
.16473 .15297 Mdot
.15689 .13728 Mdot
.15297 .12552 Mdot
.15689 .12552 Mdot
.16081 .12552 Mdot
.16865 .1216 Mdot
.17257 .12552 Mdot
.16865 .10983 Mdot
.16473 .09807 Mdot
.16473 .10199 Mdot
.14905 .10199 Mdot
.15689 .10591 Mdot
.15297 .09807 Mdot
.14513 .09023 Mdot
.15689 .10591 Mdot
.15297 .10591 Mdot
.67842 .6941 Mdot
.53333 .55294 Mdot
.30982 .34119 Mdot
.29806 .32158 Mdot
.26668 .26668 Mdot
.21963 .21179 Mdot
.20394 .18042 Mdot
.19218 .16473 Mdot
.18826 .16081 Mdot
.18826 .17257 Mdot
.20787 .19218 Mdot
.21963 .20394 Mdot
.26276 .251 Mdot
.28237 .28237 Mdot
.30198 .31766 Mdot
.30982 .33727 Mdot
.29806 .33335 Mdot
.28629 .31374 Mdot
.27845 .29806 Mdot
.27845 .30198 Mdot
.3059 .33335 Mdot
.3059 .34119 Mdot
.3059 .35687 Mdot
.30198 .36864 Mdot
.29806 .36472 Mdot
.27845 .34511 Mdot
.20394 .27845 Mdot
.17257 .23924 Mdot
.10199 .16081 Mdot
.10983 .1412 Mdot
.09023 .10591 Mdot
.07454 .09023 Mdot
.0667 .07846 Mdot
.10199 .09415 Mdot
.10199 .07846 Mdot
.23531 .1961 Mdot
.23139 .20394 Mdot
.22355 .20787 Mdot
.21571 .21179 Mdot
.22747 .23139 Mdot
.24708 .25492 Mdot
.24316 .26276 Mdot
.22355 .24708 Mdot
.15297 .1765 Mdot
.07062 .08631 Mdot
.07062 .07454 Mdot
.06278 .06278 Mdot
.07062 .05886 Mdot
.14905 .12552 Mdot
.14905 .1216 Mdot
.16081 .1216 Mdot
.16473 .11376 Mdot
.16081 .11376 Mdot
.16081 .11768 Mdot
.16865 .11768 Mdot
.15297 .10199 Mdot
.13728 .09023 Mdot
.13336 .08239 Mdot
.1216 .07062 Mdot
.14905 .09415 Mdot
.18434 .1216 Mdot
.24708 .17257 Mdot
.27845 .20002 Mdot
.27845 .21179 Mdot
.29021 .21571 Mdot
.28629 .20787 Mdot
.28629 .21571 Mdot
.28237 .21571 Mdot
.27845 .21179 Mdot
.27845 .21571 Mdot
.28629 .22747 Mdot
.28237 .22355 Mdot
.27845 .21963 Mdot
.27845 .22355 Mdot
.28629 .24316 Mdot
.28629 .24708 Mdot
.30198 .25884 Mdot
.28629 .24316 Mdot
.27453 .22747 Mdot
.27061 .21963 Mdot
.26668 .21179 Mdot
.26668 .21179 Mdot
.26276 .20787 Mdot
.26276 .21571 Mdot
.25492 .20787 Mdot
.24708 .20002 Mdot
.23924 .19218 Mdot
.23531 .18826 Mdot
.23924 .18042 Mdot
.23924 .18434 Mdot
.23924 .18434 Mdot
.23139 .18042 Mdot
.22747 .18826 Mdot
.23139 .19218 Mdot
.22355 .18826 Mdot
.21571 .18042 Mdot
.22355 .18826 Mdot
.22747 .19218 Mdot
.21571 .18042 Mdot
.20394 .16865 Mdot
.20394 .16865 Mdot
.20787 .16473 Mdot
.20787 .16865 Mdot
.20394 .16865 Mdot
.21963 .1765 Mdot
.21963 .16865 Mdot
.22355 .17257 Mdot
.21571 .1765 Mdot
.20787 .17257 Mdot
.20394 .1765 Mdot
.20002 .1765 Mdot
.19218 .1765 Mdot
.18434 .16865 Mdot
.17257 .15297 Mdot
.15689 .12944 Mdot
.16081 .12944 Mdot
.16865 .12944 Mdot
.17257 .12944 Mdot
.17257 .12552 Mdot
.16865 .11768 Mdot
.16865 .10983 Mdot
.17257 .11768 Mdot
.16473 .10591 Mdot
.16081 .09807 Mdot
.15689 .09415 Mdot
.14905 .09023 Mdot
.15689 .10591 Mdot
.15689 .10983 Mdot
.89017 .89409 Mdot
.77253 .77645 Mdot
.54509 .54902 Mdot
.32943 .34903 Mdot
.29413 .29806 Mdot
.27845 .27453 Mdot
.26668 .251 Mdot
.26276 .24316 Mdot
.24708 .22747 Mdot
.21179 .1961 Mdot
.20394 .1961 Mdot
.21571 .21571 Mdot
.25492 .25884 Mdot
.29021 .30198 Mdot
.29021 .30982 Mdot
.3059 .31374 Mdot
.30982 .3059 Mdot
.3255 .32158 Mdot
.3255 .33335 Mdot
.30982 .33727 Mdot
.29413 .34511 Mdot
.30198 .36472 Mdot
.31374 .3804 Mdot
.30982 .38824 Mdot
.29806 .3804 Mdot
.28629 .3608 Mdot
.23924 .30198 Mdot
.21179 .25492 Mdot
.14513 .18042 Mdot
.13728 .15297 Mdot
.11376 .11376 Mdot
.11768 .10199 Mdot
.15297 .12944 Mdot
.27453 .23924 Mdot
.17257 .15689 Mdot
.15689 .15297 Mdot
.13728 .13728 Mdot
.13728 .13728 Mdot
.18434 .18826 Mdot
.21571 .22747 Mdot
.23531 .24708 Mdot
.23924 .24708 Mdot
.13728 .14513 Mdot
.08239 .08239 Mdot
.0667 .05102 Mdot
.05102 .02749 Mdot
.07846 .05494 Mdot
.08631 .05886 Mdot
.09807 .05102 Mdot
.12944 .07454 Mdot
.1412 .09415 Mdot
.15689 .11768 Mdot
.15297 .10983 Mdot
.1412 .10591 Mdot
.12944 .09807 Mdot
.15689 .12552 Mdot
.12944 .10199 Mdot
.1216 .09415 Mdot
.11768 .08631 Mdot
.23924 .19218 Mdot
.3608 .29806 Mdot
.34511 .28237 Mdot
.34511 .27845 Mdot
.3255 .26276 Mdot
.3059 .24708 Mdot
.28629 .23924 Mdot
.27845 .22747 Mdot
.27061 .21963 Mdot
.27061 .21963 Mdot
.25884 .21179 Mdot
.25884 .21571 Mdot
.26668 .21963 Mdot
.27061 .23531 Mdot
.27845 .23924 Mdot
.28237 .23139 Mdot
.28629 .23531 Mdot
.28237 .23139 Mdot
.27061 .21571 Mdot
.26276 .20787 Mdot
.25492 .20394 Mdot
.25884 .20787 Mdot
.26276 .21179 Mdot
.25492 .20394 Mdot
.26668 .20394 Mdot
.251 .19218 Mdot
.24708 .18826 Mdot
.24316 .18042 Mdot
.251 .19218 Mdot
.25492 .19218 Mdot
.23924 .19218 Mdot
.23924 .20394 Mdot
.23139 .20394 Mdot
.22355 .1961 Mdot
.22747 .1961 Mdot
.23139 .20002 Mdot
.21571 .18042 Mdot
.21571 .18042 Mdot
.21571 .17257 Mdot
.21571 .16473 Mdot
.21571 .15689 Mdot
.21963 .15689 Mdot
.21179 .15297 Mdot
.21179 .15297 Mdot
.21179 .15689 Mdot
.21571 .16473 Mdot
.21179 .16865 Mdot
.20787 .1765 Mdot
.20394 .16865 Mdot
.20002 .16473 Mdot
.18042 .15297 Mdot
.18042 .15689 Mdot
.1765 .15297 Mdot
.16473 .1412 Mdot
.16473 .13336 Mdot
.16081 .12944 Mdot
.16865 .12552 Mdot
.17257 .1216 Mdot
.17257 .11768 Mdot
.16865 .11376 Mdot
.16865 .11376 Mdot
.16081 .10199 Mdot
.14513 .08631 Mdot
.13728 .08631 Mdot
.15297 .10199 Mdot
.14905 .09807 Mdot
.14905 .10199 Mdot
.87056 .8784 Mdot
.73724 .75292 Mdot
.44706 .47451 Mdot
.4902 .49412 Mdot
.52549 .49804 Mdot
.27453 .25884 Mdot
.27061 .251 Mdot
.25492 .23139 Mdot
.23924 .21963 Mdot
.24316 .22747 Mdot
.23531 .22747 Mdot
.24316 .24708 Mdot
.25884 .25884 Mdot
.29413 .28629 Mdot
.31374 .3059 Mdot
.3255 .32158 Mdot
.3255 .33727 Mdot
.3059 .33335 Mdot
.3059 .34511 Mdot
.32943 .36472 Mdot
.32158 .36864 Mdot
.30198 .36864 Mdot
.3059 .37648 Mdot
.30198 .37256 Mdot
.30198 .36472 Mdot
.28237 .32943 Mdot
.251 .29021 Mdot
.20002 .21179 Mdot
.15689 .15689 Mdot
.22355 .20787 Mdot
.24708 .22355 Mdot
.14513 .13728 Mdot
.13728 .1412 Mdot
.10591 .11768 Mdot
.08631 .09807 Mdot
.08631 .09415 Mdot
.10591 .11376 Mdot
.13728 .13728 Mdot
.16081 .15689 Mdot
.15297 .14513 Mdot
.10199 .09807 Mdot
.09023 .07062 Mdot
.09023 .0667 Mdot
.07062 .04709 Mdot
.07846 .05102 Mdot
.07846 .05102 Mdot
.07846 .04709 Mdot
.09415 .06278 Mdot
.10199 .07454 Mdot
.10983 .07846 Mdot
.09023 .07454 Mdot
.07454 .0667 Mdot
.12944 .11768 Mdot
.14513 .12552 Mdot
.15689 .13336 Mdot
.15689 .12944 Mdot
.19218 .15297 Mdot
.30198 .251 Mdot
.37256 .32158 Mdot
.38432 .33727 Mdot
.38824 .34903 Mdot
.3608 .3255 Mdot
.31374 .28237 Mdot
.28629 .24708 Mdot
.25884 .20787 Mdot
.23924 .19218 Mdot
.22747 .18826 Mdot
.23139 .18826 Mdot
.24316 .20002 Mdot
.25492 .21179 Mdot
.26668 .21963 Mdot
.27845 .23139 Mdot
.28237 .24316 Mdot
.27061 .24316 Mdot
.26668 .23924 Mdot
.24708 .21963 Mdot
.25492 .21571 Mdot
.251 .20394 Mdot
.25492 .1961 Mdot
.25492 .1961 Mdot
.25884 .18826 Mdot
.25884 .1961 Mdot
.25884 .19218 Mdot
.26668 .1961 Mdot
.25492 .1961 Mdot
.25884 .20787 Mdot
.24316 .20787 Mdot
.23924 .21571 Mdot
.23531 .22355 Mdot
.21963 .20787 Mdot
.21571 .18826 Mdot
.22355 .18826 Mdot
.21571 .1765 Mdot
.21963 .17257 Mdot
.21571 .16473 Mdot
.23139 .17257 Mdot
.22747 .16473 Mdot
.21963 .16473 Mdot
.21571 .16865 Mdot
.1961 .15689 Mdot
.18826 .15297 Mdot
.18826 .15297 Mdot
.1961 .15689 Mdot
.19218 .16081 Mdot
.19218 .15689 Mdot
.19218 .15297 Mdot
.18826 .14513 Mdot
.18434 .13728 Mdot
.18042 .12944 Mdot
.17257 .1216 Mdot
.16865 .11376 Mdot
.16081 .10983 Mdot
.16865 .11768 Mdot
.1765 .1216 Mdot
.17257 .11376 Mdot
.1765 .11768 Mdot
.1765 .1216 Mdot
.16865 .11376 Mdot
.15689 .10591 Mdot
.15297 .10591 Mdot
.15689 .11376 Mdot
.15689 .11768 Mdot
.14513 .11768 Mdot
.81566 .81958 Mdot
.72547 .71763 Mdot
.5098 .4902 Mdot
.45883 .42746 Mdot
.3255 .30198 Mdot
.33727 .3059 Mdot
.31766 .28629 Mdot
.29413 .27061 Mdot
.27061 .25492 Mdot
.251 .23139 Mdot
.24316 .22355 Mdot
.25492 .23139 Mdot
.28237 .26276 Mdot
.30198 .29021 Mdot
.32158 .3255 Mdot
.32943 .34511 Mdot
.34511 .36864 Mdot
.33727 .36864 Mdot
.32158 .36472 Mdot
.31374 .36472 Mdot
.3059 .35687 Mdot
.29413 .35295 Mdot
.3059 .3608 Mdot
.32158 .35687 Mdot
.32158 .34119 Mdot
.29806 .30982 Mdot
.28629 .29413 Mdot
.23139 .23924 Mdot
.13336 .16081 Mdot
.11768 .15689 Mdot
.10199 .1412 Mdot
.07846 .10983 Mdot
.07846 .10199 Mdot
.07062 .09023 Mdot
.0667 .07454 Mdot
.07454 .07454 Mdot
.07846 .07454 Mdot
.07454 .07454 Mdot
.07846 .0667 Mdot
.09807 .07062 Mdot
.10983 .07454 Mdot
.10199 .07062 Mdot
.09415 .05886 Mdot
.09807 .05886 Mdot
.08631 .05494 Mdot
.09807 .0667 Mdot
.08239 .04709 Mdot
.0667 .03533 Mdot
.06278 .03925 Mdot
.0667 .05102 Mdot
.08631 .07062 Mdot
.09807 .07062 Mdot
.10591 .08239 Mdot
.16473 .13728 Mdot
.1961 .17257 Mdot
.28237 .25492 Mdot
.32158 .29413 Mdot
.36472 .34119 Mdot
.38432 .36864 Mdot
.40001 .37648 Mdot
.34511 .31766 Mdot
.24316 .20787 Mdot
.18042 .13336 Mdot
.15297 .10591 Mdot
.15297 .10199 Mdot
.18826 .12944 Mdot
.20787 .15689 Mdot
.22355 .16865 Mdot
.251 .1961 Mdot
.26668 .21571 Mdot
.26276 .23139 Mdot
.26276 .23924 Mdot
.24708 .21963 Mdot
.24708 .20394 Mdot
.251 .18826 Mdot
.25492 .1765 Mdot
.25492 .1765 Mdot
.26276 .17257 Mdot
.251 .16081 Mdot
.25492 .16473 Mdot
.25884 .18434 Mdot
.26276 .20002 Mdot
.24708 .20787 Mdot
.24708 .21571 Mdot
.23139 .20787 Mdot
.23139 .21571 Mdot
.21963 .20787 Mdot
.21179 .18826 Mdot
.20787 .17257 Mdot
.20787 .16081 Mdot
.20787 .15297 Mdot
.22747 .15689 Mdot
.22355 .15689 Mdot
.23139 .16081 Mdot
.21963 .15689 Mdot
.22747 .16865 Mdot
.21963 .1765 Mdot
.21179 .18042 Mdot
.1961 .17257 Mdot
.19218 .18042 Mdot
.1765 .16473 Mdot
.16865 .15689 Mdot
.17257 .1412 Mdot
.18042 .13728 Mdot
.18434 .12944 Mdot
.18434 .1216 Mdot
.18042 .11376 Mdot
.17257 .10983 Mdot
.1765 .10983 Mdot
.1765 .10983 Mdot
.18434 .11376 Mdot
.18434 .1216 Mdot
.19218 .12944 Mdot
.18434 .1216 Mdot
.18042 .12552 Mdot
.17257 .12944 Mdot
.16865 .1412 Mdot
.16865 .14513 Mdot
.14513 .12552 Mdot
.13336 .11768 Mdot
.81566 .79213 Mdot
.67057 .64313 Mdot
.56862 .53725 Mdot
.52157 .49412 Mdot
.48235 .45098 Mdot
.40001 .36864 Mdot
.3059 .26276 Mdot
.27453 .22747 Mdot
.251 .20787 Mdot
.22747 .19218 Mdot
.23924 .21179 Mdot
.24316 .23139 Mdot
.27453 .27453 Mdot
.3059 .32158 Mdot
.32943 .35687 Mdot
.32943 .36864 Mdot
.32158 .3608 Mdot
.3059 .34903 Mdot
.29806 .34119 Mdot
.29413 .33727 Mdot
.32158 .35687 Mdot
.34511 .36472 Mdot
.3608 .37256 Mdot
.34903 .37256 Mdot
.33335 .37648 Mdot
.21963 .27845 Mdot
.1765 .24708 Mdot
.13336 .1961 Mdot
.09415 .15297 Mdot
.08239 .13728 Mdot
.07454 .10983 Mdot
.06278 .09023 Mdot
.05102 .06278 Mdot
.04317 .04317 Mdot
.07062 .05886 Mdot
.10199 .07454 Mdot
.1216 .07846 Mdot
.13728 .09023 Mdot
.13728 .09023 Mdot
.12944 .07846 Mdot
.1216 .07454 Mdot
.11768 .07454 Mdot
.10199 .05494 Mdot
.08631 .03533 Mdot
.0667 .01965 Mdot
.0667 .02749 Mdot
.07846 .05102 Mdot
.08631 .06278 Mdot
.09807 .08239 Mdot
.08631 .07454 Mdot
.07846 .08631 Mdot
.09415 .10199 Mdot
.14905 .14905 Mdot
.19218 .1961 Mdot
.25492 .25884 Mdot
.30982 .30198 Mdot
.35295 .3255 Mdot
.31374 .28237 Mdot
.35295 .29413 Mdot
.25492 .1961 Mdot
.21571 .15689 Mdot
.18434 .13728 Mdot
.18042 .14905 Mdot
.15297 .13336 Mdot
.16865 .14513 Mdot
.20002 .16473 Mdot
.22355 .1961 Mdot
.23924 .21179 Mdot
.24708 .20394 Mdot
.23531 .18826 Mdot
.23531 .17257 Mdot
.23139 .15689 Mdot
.251 .16473 Mdot
.24316 .16473 Mdot
.23924 .16081 Mdot
.23531 .15297 Mdot
.23531 .15689 Mdot
.23531 .1765 Mdot
.23139 .18434 Mdot
.22355 .18826 Mdot
.22355 .20002 Mdot
.21571 .20002 Mdot
.20394 .18826 Mdot
.21179 .18434 Mdot
.21963 .1765 Mdot
.21963 .16473 Mdot
.21571 .15297 Mdot
.22747 .15297 Mdot
.24316 .16473 Mdot
.23924 .16865 Mdot
.23924 .17257 Mdot
.23924 .1765 Mdot
.22355 .16865 Mdot
.21571 .17257 Mdot
.21179 .18434 Mdot
.20394 .18826 Mdot
.19218 .1765 Mdot
.17257 .15689 Mdot
.17257 .15689 Mdot
.16865 .14905 Mdot
.16865 .13728 Mdot
.17257 .13728 Mdot
.18042 .12944 Mdot
.18434 .13336 Mdot
.18042 .12944 Mdot
.17257 .1216 Mdot
.17257 .1216 Mdot
.18434 .12552 Mdot
.1765 .1216 Mdot
.16865 .11768 Mdot
.16473 .1216 Mdot
.16865 .12944 Mdot
.16473 .13728 Mdot
.15689 .13728 Mdot
.15689 .13728 Mdot
.14513 .1216 Mdot
.13336 .10983 Mdot
.92154 .91761 Mdot
.83135 .81958 Mdot
.64705 .63528 Mdot
.5647 .54902 Mdot
.52549 .49412 Mdot
.31766 .28629 Mdot
.23924 .21571 Mdot
.21179 .1961 Mdot
.18434 .16865 Mdot
.17257 .15689 Mdot
.17257 .16081 Mdot
.21179 .20002 Mdot
.29413 .28629 Mdot
.3059 .31374 Mdot
.3255 .34903 Mdot
.33727 .3608 Mdot
.32943 .3608 Mdot
.31374 .35687 Mdot
.31374 .35687 Mdot
.32943 .3608 Mdot
.34903 .36864 Mdot
.35295 .36472 Mdot
.36472 .38432 Mdot
.3608 .38824 Mdot
.33335 .37648 Mdot
.24316 .29413 Mdot
.20002 .251 Mdot
.14513 .20002 Mdot
.09807 .1412 Mdot
.0667 .10199 Mdot
.04709 .07062 Mdot
.03925 .04317 Mdot
.07062 .05494 Mdot
.10591 .0667 Mdot
.14513 .09415 Mdot
.1765 .12944 Mdot
.18434 .13336 Mdot
.16865 .10983 Mdot
.12944 .07846 Mdot
.11376 .05886 Mdot
.09807 .03925 Mdot
.07846 .02357 Mdot
.07454 .01965 Mdot
.07062 .02749 Mdot
.08631 .04317 Mdot
.10591 .05886 Mdot
.1216 .07062 Mdot
.12552 .09415 Mdot
.12944 .10983 Mdot
.13336 .10983 Mdot
.11768 .10591 Mdot
.13728 .13336 Mdot
.20002 .19218 Mdot
.251 .23924 Mdot
.31766 .28629 Mdot
.13728 .11768 Mdot
.15297 .12552 Mdot
.16473 .13728 Mdot
.26668 .22355 Mdot
.34903 .29413 Mdot
.34119 .28237 Mdot
.32158 .27061 Mdot
.28629 .23531 Mdot
.24708 .20394 Mdot
.23139 .20002 Mdot
.23924 .20787 Mdot
.24708 .21179 Mdot
.24708 .20394 Mdot
.23531 .18434 Mdot
.23531 .16865 Mdot
.23531 .15689 Mdot
.23531 .16081 Mdot
.22355 .15689 Mdot
.21963 .15297 Mdot
.21963 .16081 Mdot
.21571 .16081 Mdot
.20787 .15689 Mdot
.21179 .16081 Mdot
.21963 .18042 Mdot
.21963 .18826 Mdot
.20787 .18042 Mdot
.20394 .16865 Mdot
.20394 .16081 Mdot
.22355 .16865 Mdot
.23139 .18434 Mdot
.22355 .1765 Mdot
.21963 .17257 Mdot
.22355 .1765 Mdot
.22355 .1765 Mdot
.21963 .18042 Mdot
.21963 .16865 Mdot
.21179 .15689 Mdot
.21179 .16081 Mdot
.21179 .16473 Mdot
.19218 .15297 Mdot
.1765 .14905 Mdot
.1765 .14905 Mdot
.17257 .14513 Mdot
.17257 .14513 Mdot
.16865 .14905 Mdot
.16865 .15297 Mdot
.16865 .15297 Mdot
.16865 .14905 Mdot
.17257 .1412 Mdot
.17257 .13728 Mdot
.17257 .12944 Mdot
.16081 .11768 Mdot
.16473 .1216 Mdot
.16473 .11376 Mdot
.16473 .10983 Mdot
.15297 .10199 Mdot
.16473 .11376 Mdot
.16865 .1216 Mdot
.16473 .10983 Mdot
.15297 .10591 Mdot
.91761 .91761 Mdot
.81566 .81566 Mdot
.48235 .48628 Mdot
.27845 .30198 Mdot
.24316 .24708 Mdot
.21571 .20394 Mdot
.18826 .16473 Mdot
.17257 .13728 Mdot
.16473 .12552 Mdot
.17257 .13728 Mdot
.23139 .20394 Mdot
.26276 .251 Mdot
.29021 .29413 Mdot
.31374 .3255 Mdot
.32943 .35295 Mdot
.34511 .36472 Mdot
.36472 .3804 Mdot
.34903 .3608 Mdot
.33727 .34119 Mdot
.35295 .35295 Mdot
.34511 .35295 Mdot
.34903 .36864 Mdot
.34119 .37256 Mdot
.3255 .3608 Mdot
.29021 .33335 Mdot
.21571 .25884 Mdot
.11768 .15297 Mdot
.07846 .09415 Mdot
.05886 .05886 Mdot
.09023 .0667 Mdot
.11376 .08631 Mdot
.13336 .09415 Mdot
.15689 .10591 Mdot
.18042 .12944 Mdot
.16865 .11376 Mdot
.1412 .08239 Mdot
.11376 .05886 Mdot
.08631 .03925 Mdot
.06278 .02357 Mdot
.05494 .02749 Mdot
.0667 .03925 Mdot
.07454 .05494 Mdot
.15689 .12552 Mdot
.12944 .09415 Mdot
.11376 .07062 Mdot
.31374 .23924 Mdot
.27845 .20394 Mdot
.15689 .12552 Mdot
.26668 .251 Mdot
.23924 .22355 Mdot
.21179 .20394 Mdot
.18434 .1765 Mdot
.14905 .12944 Mdot
.09415 .07454 Mdot
.07454 .05102 Mdot
.05886 .03533 Mdot
.22747 .18826 Mdot
.49804 .43922 Mdot
.50588 .45098 Mdot
.4902 .44706 Mdot
.33727 .31766 Mdot
.31766 .3059 Mdot
.30198 .29021 Mdot
.28629 .26276 Mdot
.27845 .24316 Mdot
.25884 .21963 Mdot
.25492 .1961 Mdot
.23924 .1765 Mdot
.24316 .17257 Mdot
.23924 .16865 Mdot
.23531 .16473 Mdot
.22747 .16081 Mdot
.21571 .14513 Mdot
.21571 .14905 Mdot
.20787 .15297 Mdot
.21179 .15689 Mdot
.22355 .16865 Mdot
.21571 .17257 Mdot
.1961 .16081 Mdot
.20394 .16081 Mdot
.20787 .16865 Mdot
.20394 .17257 Mdot
.20394 .18042 Mdot
.20394 .18042 Mdot
.20787 .18826 Mdot
.20002 .18042 Mdot
.1961 .16865 Mdot
.20002 .15689 Mdot
.20002 .14905 Mdot
.1961 .1412 Mdot
.19218 .13336 Mdot
.18042 .1216 Mdot
.18042 .12944 Mdot
.18042 .13336 Mdot
.1765 .12944 Mdot
.1765 .13336 Mdot
.16473 .1412 Mdot
.16081 .14905 Mdot
.15689 .15297 Mdot
.16473 .15689 Mdot
.16473 .14513 Mdot
.16473 .1412 Mdot
.16865 .12944 Mdot
.16865 .1216 Mdot
.16081 .11768 Mdot
.16081 .10983 Mdot
.16473 .09415 Mdot
.16081 .09023 Mdot
.16081 .09415 Mdot
.15689 .09807 Mdot
.16081 .09807 Mdot
.15689 .09807 Mdot
.73724 .74116 Mdot
.54117 .54117 Mdot
.27845 .27845 Mdot
.21963 .20394 Mdot
.21179 .17257 Mdot
.19218 .14905 Mdot
.20787 .16473 Mdot
.1961 .16865 Mdot
.1961 .18434 Mdot
.1961 .18826 Mdot
.20394 .20002 Mdot
.26276 .25884 Mdot
.30982 .3059 Mdot
.34119 .33335 Mdot
.34903 .34119 Mdot
.35687 .34119 Mdot
.34511 .33335 Mdot
.32943 .3255 Mdot
.33335 .33335 Mdot
.34511 .34903 Mdot
.33727 .35687 Mdot
.32158 .35687 Mdot
.33335 .3608 Mdot
.22747 .251 Mdot
.10199 .1216 Mdot
.10199 .10199 Mdot
.09415 .08239 Mdot
.09415 .07846 Mdot
.10199 .07062 Mdot
.10983 .07062 Mdot
.11768 .07454 Mdot
.12944 .08631 Mdot
.1412 .09415 Mdot
.11768 .07454 Mdot
.07846 .05102 Mdot
.07454 .05494 Mdot
.0667 .05886 Mdot
.05886 .05494 Mdot
.07062 .06278 Mdot
.13728 .1216 Mdot
.08239 .07454 Mdot
.18434 .18042 Mdot
.67057 .6196 Mdot
.65881 .62744 Mdot
.41569 .41569 Mdot
.27845 .28629 Mdot
.27453 .27061 Mdot
.12944 .12552 Mdot
.11768 .10591 Mdot
.08631 .07454 Mdot
.09415 .07454 Mdot
.07454 .05886 Mdot
.07062 .05494 Mdot
.07846 .0667 Mdot
.47059 .42746 Mdot
.58431 .54117 Mdot
.54509 .5098 Mdot
.51765 .49804 Mdot
.41961 .42354 Mdot
.40393 .40785 Mdot
.39217 .3804 Mdot
.38432 .3608 Mdot
.3608 .33727 Mdot
.33335 .30198 Mdot
.31766 .27453 Mdot
.30198 .251 Mdot
.27845 .22747 Mdot
.27061 .21963 Mdot
.26276 .21179 Mdot
.24708 .1961 Mdot
.23924 .18434 Mdot
.22747 .16865 Mdot
.22355 .16865 Mdot
.22355 .17257 Mdot
.21571 .16473 Mdot
.20394 .16865 Mdot
.20002 .16473 Mdot
.1961 .16081 Mdot
.20002 .16473 Mdot
.19218 .15689 Mdot
.18434 .16081 Mdot
.18434 .16081 Mdot
.17257 .15297 Mdot
.16081 .1412 Mdot
.1765 .14905 Mdot
.16865 .1412 Mdot
.17257 .1412 Mdot
.1765 .1412 Mdot
.1765 .12944 Mdot
.17257 .1216 Mdot
.16865 .11768 Mdot
.16865 .1216 Mdot
.16473 .12552 Mdot
.16473 .12944 Mdot
.16081 .12944 Mdot
.16473 .14513 Mdot
.16865 .14513 Mdot
.16865 .1412 Mdot
.16081 .12552 Mdot
.16865 .12552 Mdot
.16473 .10983 Mdot
.16081 .11376 Mdot
.16081 .10591 Mdot
.16865 .10199 Mdot
.15297 .09415 Mdot
.15297 .09023 Mdot
.14905 .10199 Mdot
.14905 .11376 Mdot
.1412 .10591 Mdot
.63528 .63136 Mdot
.51765 .49804 Mdot
.36472 .34119 Mdot
.29413 .27453 Mdot
.251 .23924 Mdot
.23924 .22355 Mdot
.21179 .19218 Mdot
.18042 .15689 Mdot
.16081 .13728 Mdot
.17257 .14513 Mdot
.251 .21571 Mdot
.28629 .25492 Mdot
.34903 .3059 Mdot
.35295 .31766 Mdot
.35295 .3255 Mdot
.29806 .28629 Mdot
.33727 .31374 Mdot
.3059 .28237 Mdot
.29021 .28237 Mdot
.28237 .28237 Mdot
.30198 .29806 Mdot
.21963 .21571 Mdot
.14513 .12944 Mdot
.1216 .09415 Mdot
.11376 .07846 Mdot
.09415 .05494 Mdot
.09807 .05494 Mdot
.09807 .05102 Mdot
.11376 .07062 Mdot
.12552 .09415 Mdot
.1216 .09023 Mdot
.09415 .07062 Mdot
.07846 .05102 Mdot
.07846 .05102 Mdot
.07846 .06278 Mdot
.07062 .05886 Mdot
.08631 .07846 Mdot
.10983 .10591 Mdot
.11376 .1216 Mdot
.38824 .37648 Mdot
.48235 .47059 Mdot
.6941 .66665 Mdot
.41177 .39609 Mdot
.20002 .17257 Mdot
.14905 .11376 Mdot
.11768 .08239 Mdot
.08631 .05102 Mdot
.07062 .04317 Mdot
.07846 .05494 Mdot
.07846 .06278 Mdot
.06278 .05494 Mdot
.21179 .20002 Mdot
.58431 .55686 Mdot
.53333 .5098 Mdot
.52549 .50588 Mdot
.47843 .45883 Mdot
.32943 .3255 Mdot
.35295 .33335 Mdot
.37648 .35687 Mdot
.42746 .40785 Mdot
.4902 .47451 Mdot
.50196 .48235 Mdot
.4902 .46275 Mdot
.46667 .42746 Mdot
.40785 .3608 Mdot
.37648 .3255 Mdot
.35687 .31766 Mdot
.33727 .31766 Mdot
.30982 .29021 Mdot
.27845 .26276 Mdot
.24316 .21963 Mdot
.22747 .20787 Mdot
.22355 .20394 Mdot
.21179 .19218 Mdot
.20787 .18826 Mdot
.21571 .18042 Mdot
.20002 .16865 Mdot
.1961 .16081 Mdot
.19218 .15689 Mdot
.18434 .16081 Mdot
.1765 .16081 Mdot
.17257 .15689 Mdot
.18042 .16081 Mdot
.17257 .15297 Mdot
.16473 .14513 Mdot
.1765 .13728 Mdot
.1765 .1216 Mdot
.16473 .10199 Mdot
.18042 .11376 Mdot
.16865 .10983 Mdot
.16473 .11768 Mdot
.16081 .1216 Mdot
.15689 .1216 Mdot
.15689 .13336 Mdot
.14905 .1216 Mdot
.15689 .1216 Mdot
.14905 .10591 Mdot
.15689 .10591 Mdot
.14905 .09807 Mdot
.15297 .10199 Mdot
.14905 .10591 Mdot
.1412 .09807 Mdot
.12944 .09415 Mdot
.1412 .11768 Mdot
.13728 .12552 Mdot
.12944 .11768 Mdot
.90977 .90193 Mdot
.73724 .72939 Mdot
.40393 .38432 Mdot
.34903 .32943 Mdot
.21571 .1961 Mdot
.20787 .18042 Mdot
.18042 .15689 Mdot
.15689 .13336 Mdot
.16473 .13336 Mdot
.18826 .15297 Mdot
.22355 .18042 Mdot
.27845 .22747 Mdot
.27453 .22747 Mdot
.20787 .18042 Mdot
.21963 .18826 Mdot
.1961 .16473 Mdot
.17257 .14513 Mdot
.18826 .15689 Mdot
.23139 .19218 Mdot
.25884 .20394 Mdot
.16865 .12552 Mdot
.1765 .12944 Mdot
.1412 .09807 Mdot
.1216 .08239 Mdot
.09807 .06278 Mdot
.09415 .05886 Mdot
.11376 .08239 Mdot
.13336 .10983 Mdot
.12552 .10983 Mdot
.08631 .07454 Mdot
.07454 .06278 Mdot
.07454 .06278 Mdot
.07454 .06278 Mdot
.07846 .06278 Mdot
.11768 .10591 Mdot
.12552 .12944 Mdot
.13728 .13728 Mdot
.13336 .1412 Mdot
.19218 .20002 Mdot
.40393 .39217 Mdot
.39609 .3804 Mdot
.24316 .22355 Mdot
.11768 .09023 Mdot
.14513 .10199 Mdot
.07454 .04317 Mdot
.0667 .03925 Mdot
.05886 .04317 Mdot
.05494 .04709 Mdot
.05886 .0667 Mdot
.27845 .28237 Mdot
.50588 .50588 Mdot
.53333 .53725 Mdot
.49804 .49804 Mdot
.52549 .50196 Mdot
.47451 .44706 Mdot
.41961 .38824 Mdot
.35687 .33335 Mdot
.36472 .34511 Mdot
.54117 .5098 Mdot
.52549 .49412 Mdot
.54117 .50196 Mdot
.57254 .52157 Mdot
.52157 .47059 Mdot
.36864 .33335 Mdot
.39217 .36864 Mdot
.42354 .41177 Mdot
.42746 .42354 Mdot
.40785 .40785 Mdot
.38432 .37256 Mdot
.35687 .34511 Mdot
.3255 .32158 Mdot
.28629 .29021 Mdot
.27061 .27845 Mdot
.251 .24708 Mdot
.24316 .23139 Mdot
.23924 .21963 Mdot
.23139 .20787 Mdot
.21963 .20394 Mdot
.1961 .19218 Mdot
.18434 .17257 Mdot
.18042 .16473 Mdot
.1765 .15297 Mdot
.17257 .13728 Mdot
.17257 .11768 Mdot
.1765 .11376 Mdot
.18042 .10591 Mdot
.19218 .10983 Mdot
.19218 .11376 Mdot
.18042 .1216 Mdot
.15297 .10591 Mdot
.1216 .08631 Mdot
.10199 .07454 Mdot
.09023 .06278 Mdot
.09807 .07062 Mdot
.10591 .07846 Mdot
.11768 .08239 Mdot
.1412 .09807 Mdot
.15689 .10983 Mdot
.15297 .11376 Mdot
.1412 .10591 Mdot
.14513 .11376 Mdot
.13336 .11376 Mdot
.12552 .11768 Mdot
.12944 .1216 Mdot
.85095 .84703 Mdot
.6196 .61176 Mdot
.22747 .20394 Mdot
.23139 .20002 Mdot
.21571 .18042 Mdot
.20394 .16473 Mdot
.20787 .15689 Mdot
.20394 .14905 Mdot
.18826 .12944 Mdot
.18042 .11768 Mdot
.16865 .10983 Mdot
.14513 .09807 Mdot
.12552 .08239 Mdot
.13336 .08631 Mdot
.14513 .09415 Mdot
.18826 .12552 Mdot
.21571 .14905 Mdot
.19218 .13728 Mdot
.17257 .12552 Mdot
.1412 .10983 Mdot
.11768 .09807 Mdot
.10591 .09415 Mdot
.10199 .09023 Mdot
.1216 .11376 Mdot
.1412 .13336 Mdot
.11768 .11376 Mdot
.10591 .09807 Mdot
.09023 .08239 Mdot
.09415 .07846 Mdot
.09415 .07062 Mdot
.07846 .06278 Mdot
.07846 .0667 Mdot
.13336 .11376 Mdot
.17257 .14905 Mdot
.20394 .1765 Mdot
.21571 .1961 Mdot
.26276 .23531 Mdot
.28237 .251 Mdot
.26276 .22747 Mdot
.11376 .09023 Mdot
.12944 .10983 Mdot
.10591 .09023 Mdot
.09023 .07846 Mdot
.07846 .07846 Mdot
.0667 .07454 Mdot
.05886 .07454 Mdot
.21963 .22747 Mdot
.42746 .43138 Mdot
.44314 .45491 Mdot
.48628 .48235 Mdot
.5098 .48628 Mdot
.53725 .49804 Mdot
.54117 .49804 Mdot
.50196 .47059 Mdot
.48628 .45098 Mdot
.4902 .45883 Mdot
.5098 .47451 Mdot
.52157 .48235 Mdot
.51765 .47843 Mdot
.57646 .54117 Mdot
.51765 .49804 Mdot
.33335 .34119 Mdot
.34511 .34511 Mdot
.31766 .31766 Mdot
.45491 .43138 Mdot
.52157 .4902 Mdot
.36864 .36472 Mdot
.34903 .35687 Mdot
.35295 .36864 Mdot
.3804 .39217 Mdot
.38824 .40001 Mdot
.39217 .40001 Mdot
.3804 .3804 Mdot
.36864 .34903 Mdot
.34903 .32158 Mdot
.30982 .28237 Mdot
.27061 .24708 Mdot
.22355 .1961 Mdot
.20394 .17257 Mdot
.20394 .16081 Mdot
.19218 .13728 Mdot
.1765 .11768 Mdot
.18826 .11768 Mdot
.1961 .1216 Mdot
.18434 .1216 Mdot
.17257 .12552 Mdot
.13336 .09415 Mdot
.09807 .06278 Mdot
.05886 .03141 Mdot
.03533 .01572 Mdot
.02357 .00788 Mdot
.03533 .01965 Mdot
.03533 .01965 Mdot
.09023 .05886 Mdot
.11376 .07846 Mdot
.13336 .09415 Mdot
.1412 .09807 Mdot
.1412 .10983 Mdot
.1412 .11376 Mdot
.12552 .10591 Mdot
.11768 .09807 Mdot
.65097 .63528 Mdot
.54902 .50588 Mdot
.30198 .251 Mdot
.28629 .23139 Mdot
.26668 .20787 Mdot
.24708 .18434 Mdot
.1961 .13728 Mdot
.18434 .13336 Mdot
.16473 .11768 Mdot
.15689 .10591 Mdot
.14905 .09415 Mdot
.15297 .09807 Mdot
.18434 .12552 Mdot
.23139 .17257 Mdot
.22355 .1765 Mdot
.19218 .15689 Mdot
.15689 .13336 Mdot
.13336 .11768 Mdot
.11376 .10199 Mdot
.11768 .10983 Mdot
.14513 .1412 Mdot
.15689 .15297 Mdot
.14513 .13336 Mdot
.13336 .12552 Mdot
.11768 .10983 Mdot
.10591 .10199 Mdot
.10591 .09023 Mdot
.07062 .05494 Mdot
.0667 .05102 Mdot
.07846 .05494 Mdot
.09807 .07062 Mdot
.15297 .1216 Mdot
.20394 .16081 Mdot
.27845 .22747 Mdot
.27061 .21571 Mdot
.21571 .16473 Mdot
.17257 .13336 Mdot
.14513 .11376 Mdot
.12552 .10591 Mdot
.11376 .09807 Mdot
.10983 .10591 Mdot
.09807 .09415 Mdot
.10199 .10199 Mdot
.09415 .09807 Mdot
.16081 .16081 Mdot
.251 .23924 Mdot
.29806 .28237 Mdot
.36472 .32943 Mdot
.60391 .55294 Mdot
.57646 .53725 Mdot
.57646 .53725 Mdot
.57254 .52941 Mdot
.56078 .51372 Mdot
.55294 .5098 Mdot
.54902 .51372 Mdot
.53725 .5098 Mdot
.53333 .51765 Mdot
.53725 .52549 Mdot
.47451 .47451 Mdot
.43138 .42746 Mdot
.39609 .38432 Mdot
.38824 .37256 Mdot
.62744 .59215 Mdot
.55686 .53725 Mdot
.35687 .3608 Mdot
.35687 .36472 Mdot
.32943 .33727 Mdot
.3255 .32943 Mdot
.43138 .42746 Mdot
.47059 .46275 Mdot
.48628 .47059 Mdot
.4902 .47059 Mdot
.47451 .45098 Mdot
.42354 .40001 Mdot
.38824 .3608 Mdot
.36864 .33727 Mdot
.33335 .29413 Mdot
.30198 .25492 Mdot
.28237 .23139 Mdot
.26668 .20394 Mdot
.23924 .17257 Mdot
.20787 .16473 Mdot
.18826 .16473 Mdot
.15689 .13728 Mdot
.09415 .07062 Mdot
.05102 .03533 Mdot
.03533 .01965 Mdot
.01965 .00396 Mdot
.01965 .00788 Mdot
.0118 .00396 Mdot
.00788 .00396 Mdot
.03533 .01965 Mdot
.05494 .02357 Mdot
.08631 .04317 Mdot
.11768 .07454 Mdot
.13728 .09023 Mdot
.13728 .09807 Mdot
.14513 .11376 Mdot
.749 .72939 Mdot
.59607 .56078 Mdot
.34903 .29806 Mdot
.26276 .20394 Mdot
.25884 .1961 Mdot
.23139 .16865 Mdot
.23531 .16473 Mdot
.21571 .13728 Mdot
.21179 .13336 Mdot
.20787 .14905 Mdot
.23531 .1765 Mdot
.24316 .18826 Mdot
.21963 .1765 Mdot
.1765 .14513 Mdot
.14905 .1216 Mdot
.1216 .09807 Mdot
.1216 .09807 Mdot
.13728 .11768 Mdot
.15689 .13336 Mdot
.16865 .15689 Mdot
.18042 .16473 Mdot
.16865 .16473 Mdot
.12552 .13728 Mdot
.10591 .10591 Mdot
.0667 .06278 Mdot
.05886 .05494 Mdot
.05494 .05102 Mdot
.07062 .05886 Mdot
.08631 .07454 Mdot
.14513 .11376 Mdot
.15689 .1216 Mdot
.16473 .1216 Mdot
.1765 .12552 Mdot
.14905 .09807 Mdot
.12944 .08239 Mdot
.11768 .09415 Mdot
.10591 .09807 Mdot
.1216 .12552 Mdot
.10591 .11768 Mdot
.23139 .23924 Mdot
.21963 .22747 Mdot
.24708 .251 Mdot
.27061 .27061 Mdot
.28629 .27453 Mdot
.251 .23531 Mdot
.38432 .3608 Mdot
.60391 .57254 Mdot
.53333 .51372 Mdot
.57254 .54509 Mdot
.53725 .5098 Mdot
.5647 .53725 Mdot
.55686 .53725 Mdot
.54902 .53725 Mdot
.55294 .54509 Mdot
.54902 .54117 Mdot
.52549 .52157 Mdot
.52157 .50196 Mdot
.50196 .47451 Mdot
.48628 .46275 Mdot
.47843 .45098 Mdot
.49804 .47059 Mdot
.48235 .46667 Mdot
.47843 .45883 Mdot
.43922 .42354 Mdot
.42746 .41569 Mdot
.42354 .41961 Mdot
.45098 .44706 Mdot
.46667 .46275 Mdot
.47843 .47059 Mdot
.48235 .47059 Mdot
.48628 .46667 Mdot
.48235 .46275 Mdot
.49412 .46275 Mdot
.4902 .45491 Mdot
.46667 .44314 Mdot
.44314 .42746 Mdot
.42746 .41569 Mdot
.39609 .38824 Mdot
.35687 .35687 Mdot
.29413 .29413 Mdot
.15297 .16081 Mdot
.11768 .11376 Mdot
.09023 .07846 Mdot
.04317 .02749 Mdot
.02749 .0118 Mdot
.01572 .00788 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.01572 .00396 Mdot
.08631 .03533 Mdot
.12944 .07062 Mdot
.1412 .08239 Mdot
.14513 .09807 Mdot
.88232 .87056 Mdot
.62744 .6196 Mdot
.37256 .33727 Mdot
.4353 .3804 Mdot
.43922 .37648 Mdot
.35687 .29806 Mdot
.31766 .26276 Mdot
.27845 .23531 Mdot
.27061 .22747 Mdot
.26276 .21571 Mdot
.21571 .17257 Mdot
.19218 .15297 Mdot
.16865 .12944 Mdot
.14905 .11768 Mdot
.12552 .09807 Mdot
.12552 .09807 Mdot
.1412 .10983 Mdot
.15297 .12552 Mdot
.16865 .14513 Mdot
.17257 .15689 Mdot
.13728 .13336 Mdot
.11768 .11376 Mdot
.09023 .09023 Mdot
.07846 .07846 Mdot
.07062 .07454 Mdot
.07062 .07454 Mdot
.09023 .09023 Mdot
.10983 .10199 Mdot
.13728 .1216 Mdot
.15689 .12552 Mdot
.16081 .1216 Mdot
.12944 .08631 Mdot
.11768 .07846 Mdot
.10983 .08631 Mdot
.10199 .09023 Mdot
.09415 .09807 Mdot
.12552 .14513 Mdot
.24316 .26668 Mdot
.40393 .41961 Mdot
.39217 .41177 Mdot
.39609 .40785 Mdot
.41177 .39609 Mdot
.36472 .34511 Mdot
.27061 .25884 Mdot
.75292 .70587 Mdot
.46667 .46275 Mdot
.46667 .47059 Mdot
.35687 .36472 Mdot
.37256 .36864 Mdot
.48628 .47451 Mdot
.52157 .50196 Mdot
.53725 .51765 Mdot
.54902 .54117 Mdot
.53333 .52941 Mdot
.54902 .53725 Mdot
.33335 .34119 Mdot
.39609 .38432 Mdot
.5098 .47059 Mdot
.47059 .43922 Mdot
.47059 .45491 Mdot
.48628 .48235 Mdot
.50196 .50196 Mdot
.50196 .50196 Mdot
.49804 .4902 Mdot
.46667 .45491 Mdot
.46667 .45883 Mdot
.45883 .45883 Mdot
.46275 .46275 Mdot
.45098 .46275 Mdot
.45491 .45883 Mdot
.45883 .45098 Mdot
.47059 .45098 Mdot
.46667 .45098 Mdot
.47059 .44706 Mdot
.46667 .45098 Mdot
.46667 .45491 Mdot
.46667 .45098 Mdot
.48235 .46667 Mdot
.22747 .23924 Mdot
.07454 .09415 Mdot
.05102 .05102 Mdot
.00788 .00788 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.0118 .00396 Mdot
.04317 .0118 Mdot
.06278 .01965 Mdot
.09415 .04317 Mdot
.1412 .08239 Mdot
.15297 .09415 Mdot
.90585 .89409 Mdot
.75292 .70194 Mdot
.6196 .56078 Mdot
.54117 .48628 Mdot
.46667 .41177 Mdot
.34119 .29806 Mdot
.32158 .27061 Mdot
.27453 .21571 Mdot
.22355 .17257 Mdot
.20002 .16081 Mdot
.16473 .13336 Mdot
.14905 .1216 Mdot
.15689 .11768 Mdot
.16473 .12944 Mdot
.16473 .13728 Mdot
.15689 .12944 Mdot
.13336 .11768 Mdot
.11768 .10591 Mdot
.10199 .09807 Mdot
.10199 .10199 Mdot
.07846 .09023 Mdot
.09023 .09807 Mdot
.11376 .10983 Mdot
.13728 .12552 Mdot
.14513 .12944 Mdot
.16865 .14513 Mdot
.17257 .14905 Mdot
.18042 .15689 Mdot
.16865 .12552 Mdot
.14513 .10591 Mdot
.1412 .11768 Mdot
.12552 .10983 Mdot
.11768 .10983 Mdot
.10199 .11376 Mdot
.31766 .32943 Mdot
.65489 .63528 Mdot
.46275 .45098 Mdot
.33335 .3255 Mdot
.33335 .3059 Mdot
.251 .23139 Mdot
.27453 .25884 Mdot
.53333 .50588 Mdot
.44314 .43922 Mdot
.45883 .45883 Mdot
.37648 .37648 Mdot
.35687 .34511 Mdot
.44706 .42354 Mdot
.49804 .47843 Mdot
.51372 .49804 Mdot
.52549 .51765 Mdot
.53333 .52549 Mdot
.55294 .54117 Mdot
.251 .26276 Mdot
.29806 .29806 Mdot
.64313 .59999 Mdot
.23924 .23531 Mdot
.3608 .36864 Mdot
.59607 .58823 Mdot
.43922 .45098 Mdot
.42354 .44314 Mdot
.45098 .46667 Mdot
.47451 .47843 Mdot
.45883 .46275 Mdot
.44706 .45491 Mdot
.45491 .47059 Mdot
.44706 .47451 Mdot
.45491 .47843 Mdot
.45491 .46667 Mdot
.45491 .45491 Mdot
.45491 .44314 Mdot
.45491 .4353 Mdot
.4353 .40785 Mdot
.4353 .40393 Mdot
.43138 .39609 Mdot
.42354 .39217 Mdot
.20002 .1961 Mdot
.05886 .0667 Mdot
.02749 .02357 Mdot
.01965 .01572 Mdot
.0118 .00788 Mdot
.00788 .0118 Mdot
.00396 .00788 Mdot
.00396 .00396 Mdot
.00788 .00396 Mdot
.03533 .0118 Mdot
.10199 .05886 Mdot
.11768 .07062 Mdot
.13336 .09023 Mdot
.13728 .09023 Mdot
.1412 .09023 Mdot
.8588 .81174 Mdot
.75292 .67842 Mdot
.56862 .48235 Mdot
.51765 .44706 Mdot
.33335 .28237 Mdot
.27453 .21179 Mdot
.24708 .18434 Mdot
.21571 .16865 Mdot
.18826 .14905 Mdot
.18826 .1412 Mdot
.18434 .12944 Mdot
.17257 .12552 Mdot
.15689 .11768 Mdot
.13336 .10591 Mdot
.1216 .10199 Mdot
.10983 .09415 Mdot
.10199 .09415 Mdot
.09807 .09415 Mdot
.11376 .10983 Mdot
.13728 .12944 Mdot
.1765 .15297 Mdot
.18042 .15297 Mdot
.18826 .16081 Mdot
.18826 .16473 Mdot
.18826 .15689 Mdot
.18826 .15689 Mdot
.18042 .14905 Mdot
.1765 .14905 Mdot
.15297 .12552 Mdot
.10591 .08239 Mdot
.09807 .07454 Mdot
.08631 .0667 Mdot
.24316 .21179 Mdot
.33335 .29021 Mdot
.21963 .18434 Mdot
.22355 .18434 Mdot
.18042 .15689 Mdot
.17257 .15297 Mdot
.16865 .15689 Mdot
.14513 .13728 Mdot
.44706 .41569 Mdot
.39217 .3608 Mdot
.39217 .3608 Mdot
.43138 .40393 Mdot
.45883 .4353 Mdot
.46667 .45098 Mdot
.47451 .47059 Mdot
.48628 .4902 Mdot
.50196 .50588 Mdot
.41961 .42354 Mdot
.44706 .43138 Mdot
.58431 .54902 Mdot
.23531 .24708 Mdot
.29021 .30982 Mdot
.62744 .62352 Mdot
.54509 .54117 Mdot
.40785 .41569 Mdot
.51765 .5098 Mdot
.46667 .46275 Mdot
.26668 .27453 Mdot
.34119 .35295 Mdot
.47843 .4902 Mdot
.44314 .47059 Mdot
.42354 .45098 Mdot
.4353 .45098 Mdot
.44314 .44314 Mdot
.44706 .4353 Mdot
.45883 .43138 Mdot
.4353 .40785 Mdot
.42746 .39609 Mdot
.39217 .35687 Mdot
.3059 .28237 Mdot
.18434 .1765 Mdot
.07454 .07454 Mdot
.05494 .05102 Mdot
.04317 .03925 Mdot
.02749 .02357 Mdot
.02749 .01965 Mdot
.0118 .00788 Mdot
.0118 .00788 Mdot
.03533 .02749 Mdot
.06278 .05102 Mdot
.13336 .09807 Mdot
.15689 .11376 Mdot
.16081 .12552 Mdot
.16473 .12944 Mdot
.16473 .12944 Mdot
.83527 .78429 Mdot
.58039 .48235 Mdot
.31766 .22747 Mdot
.34119 .251 Mdot
.30982 .23531 Mdot
.28629 .22747 Mdot
.27453 .21571 Mdot
.251 .1961 Mdot
.22355 .1765 Mdot
.18826 .14513 Mdot
.15297 .11768 Mdot
.13728 .10983 Mdot
.12944 .10199 Mdot
.11768 .09807 Mdot
.11768 .09415 Mdot
.13336 .10591 Mdot
.15689 .12944 Mdot
.19218 .15689 Mdot
.21571 .16865 Mdot
.22355 .18042 Mdot
.21179 .17257 Mdot
.21571 .1765 Mdot
.20002 .16473 Mdot
.18434 .14905 Mdot
.17257 .1412 Mdot
.18434 .16081 Mdot
.15297 .12944 Mdot
.11768 .09807 Mdot
.10591 .09023 Mdot
.09023 .07846 Mdot
.09023 .07454 Mdot
.11376 .09023 Mdot
.10983 .08631 Mdot
.10591 .09023 Mdot
.12552 .11376 Mdot
.13336 .1216 Mdot
.10199 .09807 Mdot
.23139 .21179 Mdot
.3608 .31374 Mdot
.39609 .34903 Mdot
.52549 .47059 Mdot
.41961 .38432 Mdot
.33335 .3059 Mdot
.27453 .27061 Mdot
.33727 .35687 Mdot
.38824 .41961 Mdot
.44314 .46667 Mdot
.44706 .45883 Mdot
.47059 .47451 Mdot
.41569 .43922 Mdot
.41177 .43922 Mdot
.47843 .4902 Mdot
.58039 .57254 Mdot
.53725 .52157 Mdot
.53725 .51765 Mdot
.40001 .38824 Mdot
.15689 .18042 Mdot
.18042 .21963 Mdot
.56862 .57254 Mdot
.3255 .3608 Mdot
.25492 .29021 Mdot
.38824 .40393 Mdot
.45883 .45491 Mdot
.34119 .33727 Mdot
.31374 .29806 Mdot
.3804 .34903 Mdot
.40393 .37648 Mdot
.39217 .36472 Mdot
.29806 .28237 Mdot
.15297 .15297 Mdot
.09807 .10199 Mdot
.0667 .06278 Mdot
.03925 .03925 Mdot
.03141 .03141 Mdot
.02749 .01965 Mdot
.01965 .0118 Mdot
.0118 .00788 Mdot
.11376 .09023 Mdot
.16081 .12944 Mdot
.16865 .12944 Mdot
.17257 .12944 Mdot
.16865 .13728 Mdot
.15689 .12944 Mdot
.15297 .12552 Mdot
.87448 .85095 Mdot
.72939 .68234 Mdot
.5647 .47059 Mdot
.58039 .48235 Mdot
.49804 .40785 Mdot
.36472 .29413 Mdot
.26668 .21963 Mdot
.23531 .1961 Mdot
.18042 .14513 Mdot
.16473 .12944 Mdot
.15689 .1216 Mdot
.15297 .1216 Mdot
.15689 .11376 Mdot
.16081 .11768 Mdot
.16865 .1412 Mdot
.20787 .17257 Mdot
.24316 .1961 Mdot
.25492 .21179 Mdot
.23924 .20787 Mdot
.21571 .1961 Mdot
.18826 .16865 Mdot
.17257 .15689 Mdot
.15689 .14513 Mdot
.1412 .13336 Mdot
.14905 .13336 Mdot
.13336 .11376 Mdot
.1216 .09807 Mdot
.09807 .07846 Mdot
.11768 .09415 Mdot
.10199 .07846 Mdot
.08631 .06278 Mdot
.10591 .07846 Mdot
.1216 .09415 Mdot
.13336 .11376 Mdot
.1216 .11376 Mdot
.09415 .09023 Mdot
.1412 .12944 Mdot
.16865 .15689 Mdot
.26276 .23531 Mdot
.26668 .23139 Mdot
.26668 .23139 Mdot
.18826 .15689 Mdot
.1765 .14905 Mdot
.1765 .16473 Mdot
.27845 .27453 Mdot
.34119 .32943 Mdot
.39217 .37648 Mdot
.3255 .31766 Mdot
.29021 .29806 Mdot
.44314 .43922 Mdot
.45098 .45098 Mdot
.47059 .46667 Mdot
.48628 .48628 Mdot
.45098 .45098 Mdot
.18042 .21179 Mdot
.20394 .24316 Mdot
.45883 .47451 Mdot
.48628 .49412 Mdot
.25884 .27845 Mdot
.41569 .40785 Mdot
.44706 .43138 Mdot
.24708 .23924 Mdot
.08631 .08631 Mdot
.19218 .18042 Mdot
.43138 .40393 Mdot
.3059 .29021 Mdot
.20787 .21179 Mdot
.18826 .18826 Mdot
.10983 .10983 Mdot
.09415 .09415 Mdot
.05102 .05102 Mdot
.02749 .02749 Mdot
.02749 .01965 Mdot
.01965 .00788 Mdot
.02357 .0118 Mdot
.16473 .12944 Mdot
.251 .20787 Mdot
.24708 .20394 Mdot
.1961 .16081 Mdot
.17257 .1412 Mdot
.15689 .12552 Mdot
.14905 .1216 Mdot
.93722 .91369 Mdot
.78429 .72155 Mdot
.60783 .52549 Mdot
.27061 .23139 Mdot
.30982 .27061 Mdot
.25884 .22747 Mdot
.23924 .20002 Mdot
.22747 .18434 Mdot
.23139 .18434 Mdot
.23531 .18826 Mdot
.23531 .18826 Mdot
.22355 .18434 Mdot
.23531 .20002 Mdot
.28629 .24316 Mdot
.30198 .25884 Mdot
.23924 .21963 Mdot
.22747 .21571 Mdot
.21571 .20787 Mdot
.18042 .1765 Mdot
.16473 .16865 Mdot
.15689 .15689 Mdot
.16473 .15689 Mdot
.16081 .14513 Mdot
.14513 .12944 Mdot
.13336 .11376 Mdot
.1412 .11768 Mdot
.1216 .10199 Mdot
.09415 .07062 Mdot
.12944 .09415 Mdot
.1412 .10983 Mdot
.15297 .12552 Mdot
.13336 .10983 Mdot
.11768 .10591 Mdot
.10199 .09415 Mdot
.09415 .08631 Mdot
.12944 .11376 Mdot
.15297 .12552 Mdot
.15689 .12552 Mdot
.14905 .1216 Mdot
.1412 .10983 Mdot
.13336 .10199 Mdot
.14513 .11376 Mdot
.16081 .13728 Mdot
.41177 .36864 Mdot
.29806 .25884 Mdot
.20787 .17257 Mdot
.16473 .14905 Mdot
.31374 .29021 Mdot
.3255 .31766 Mdot
.3608 .37256 Mdot
.45883 .47059 Mdot
.47451 .49412 Mdot
.34903 .3804 Mdot
.36864 .38432 Mdot
.41177 .41177 Mdot
.42746 .41569 Mdot
.43922 .42354 Mdot
.43138 .42746 Mdot
.31766 .32943 Mdot
.17257 .1961 Mdot
.30982 .3059 Mdot
.34119 .33335 Mdot
.34511 .34119 Mdot
.25492 .25492 Mdot
.10591 .1216 Mdot
.10983 .11376 Mdot
.08239 .07454 Mdot
.05494 .04709 Mdot
.03925 .03141 Mdot
.02749 .01965 Mdot
.03533 .02749 Mdot
.05494 .03925 Mdot
.07454 .05102 Mdot
.251 .20787 Mdot
.28629 .251 Mdot
.23531 .21179 Mdot
.20787 .20002 Mdot
.16865 .15689 Mdot
.13336 .12552 Mdot
.8039 .76076 Mdot
.59999 .55294 Mdot
.54902 .48628 Mdot
.47059 .40785 Mdot
.41177 .35295 Mdot
.39609 .33335 Mdot
.37256 .31374 Mdot
.35295 .30198 Mdot
.3059 .26668 Mdot
.27845 .24708 Mdot
.27453 .23531 Mdot
.26668 .22747 Mdot
.251 .21963 Mdot
.23531 .21179 Mdot
.21963 .21179 Mdot
.21179 .20787 Mdot
.20787 .20394 Mdot
.21179 .21179 Mdot
.19218 .1961 Mdot
.18042 .1765 Mdot
.18434 .1765 Mdot
.1765 .16865 Mdot
.16865 .16081 Mdot
.13336 .11768 Mdot
.10591 .09023 Mdot
.10983 .09415 Mdot
.12552 .10199 Mdot
.13728 .10591 Mdot
.12552 .10591 Mdot
.10983 .09415 Mdot
.08631 .07454 Mdot
.12944 .10983 Mdot
.18826 .16473 Mdot
.18042 .15297 Mdot
.16081 .13728 Mdot
.12552 .10199 Mdot
.11768 .09023 Mdot
.10983 .08239 Mdot
.11768 .09415 Mdot
.10983 .08239 Mdot
.15689 .11768 Mdot
.1961 .15297 Mdot
.20787 .15689 Mdot
.18826 .13728 Mdot
.15689 .11768 Mdot
.13728 .10983 Mdot
.13336 .12552 Mdot
.18826 .18434 Mdot
.38432 .37256 Mdot
.27453 .28237 Mdot
.24316 .25492 Mdot
.28237 .28237 Mdot
.36472 .35295 Mdot
.40001 .40001 Mdot
.41177 .42746 Mdot
.41569 .42746 Mdot
.38824 .39609 Mdot
.41569 .41569 Mdot
.33335 .33727 Mdot
.27453 .29021 Mdot
.30982 .30982 Mdot
.10591 .11768 Mdot
.09415 .10199 Mdot
.05494 .05102 Mdot
.04317 .02749 Mdot
.03533 .01572 Mdot
.03925 .02357 Mdot
.07062 .05886 Mdot
.0667 .05886 Mdot
.05494 .05886 Mdot
.07846 .08631 Mdot
.09415 .09807 Mdot
.1216 .11768 Mdot
.21571 .20394 Mdot
.20002 .19218 Mdot
.15689 .15297 Mdot
.81958 .78821 Mdot
.65097 .57254 Mdot
.53333 .45883 Mdot
.4902 .41569 Mdot
.39609 .33335 Mdot
.34511 .29806 Mdot
.3255 .27845 Mdot
.29413 .25492 Mdot
.28237 .23924 Mdot
.25884 .21963 Mdot
.251 .21963 Mdot
.23924 .20787 Mdot
.30198 .26668 Mdot
.30198 .28237 Mdot
.28237 .26668 Mdot
.25492 .23531 Mdot
.21571 .1961 Mdot
.1961 .18042 Mdot
.1765 .16081 Mdot
.17257 .16081 Mdot
.15297 .14513 Mdot
.12552 .10983 Mdot
.10983 .08631 Mdot
.12944 .10199 Mdot
.1412 .10983 Mdot
.13728 .10591 Mdot
.11768 .09023 Mdot
.10199 .07846 Mdot
.14905 .12944 Mdot
.16865 .14905 Mdot
.16865 .14513 Mdot
.16473 .13728 Mdot
.15297 .12944 Mdot
.12944 .10983 Mdot
.12552 .10199 Mdot
.10591 .08239 Mdot
.10591 .07454 Mdot
.07846 .04317 Mdot
.09415 .05494 Mdot
.10983 .07062 Mdot
.13728 .09023 Mdot
.12552 .08239 Mdot
.09807 .06278 Mdot
.08631 .0667 Mdot
.08239 .0667 Mdot
.22355 .20002 Mdot
.3255 .3059 Mdot
.12552 .13336 Mdot
.14513 .15689 Mdot
.14513 .16865 Mdot
.18434 .20394 Mdot
.32158 .32943 Mdot
.3804 .37648 Mdot
.39217 .38432 Mdot
.38824 .38824 Mdot
.37256 .38432 Mdot
.20394 .22747 Mdot
.22355 .23139 Mdot
.21571 .20787 Mdot
.10199 .09807 Mdot
.0667 .06278 Mdot
.07062 .05886 Mdot
.07062 .04709 Mdot
.07062 .04709 Mdot
.07062 .05494 Mdot
.0667 .05494 Mdot
.05102 .04709 Mdot
.04709 .04317 Mdot
.04317 .04317 Mdot
.04317 .04709 Mdot
.09023 .09023 Mdot
.11376 .10983 Mdot
.14905 .1412 Mdot
.91761 .89409 Mdot
.80782 .77253 Mdot
.58431 .51372 Mdot
.45098 .3804 Mdot
.4353 .36472 Mdot
.38824 .33727 Mdot
.34119 .3059 Mdot
.3059 .27845 Mdot
.29021 .26668 Mdot
.25884 .23139 Mdot
.35295 .31766 Mdot
.40785 .37256 Mdot
.41177 .36864 Mdot
.39217 .33727 Mdot
.20002 .15689 Mdot
.17257 .13728 Mdot
.15297 .1216 Mdot
.13336 .11376 Mdot
.13728 .12944 Mdot
.13728 .12944 Mdot
.13336 .12944 Mdot
.14905 .13728 Mdot
.14905 .13336 Mdot
.13336 .13336 Mdot
.11768 .1216 Mdot
.12552 .12944 Mdot
.21571 .21179 Mdot
.21963 .20787 Mdot
.18434 .16473 Mdot
.17257 .14513 Mdot
.15297 .12552 Mdot
.15689 .1216 Mdot
.16473 .13728 Mdot
.14513 .11768 Mdot
.10591 .07846 Mdot
.08239 .04317 Mdot
.0667 .02357 Mdot
.10199 .05102 Mdot
.12552 .06278 Mdot
.10199 .04709 Mdot
.07062 .03141 Mdot
.05494 .03141 Mdot
.05102 .03141 Mdot
.10199 .08239 Mdot
.33335 .29806 Mdot
.16081 .15297 Mdot
.15689 .16473 Mdot
.1216 .13728 Mdot
.10199 .11768 Mdot
.09023 .10199 Mdot
.17257 .16473 Mdot
.21179 .18042 Mdot
.1765 .1412 Mdot
.21179 .18042 Mdot
.251 .22747 Mdot
.31374 .29413 Mdot
.27845 .24708 Mdot
.05102 .03533 Mdot
.08631 .07062 Mdot
.10591 .09023 Mdot
.09415 .08239 Mdot
.10591 .09023 Mdot
.09023 .07846 Mdot
.0667 .0667 Mdot
.04317 .05102 Mdot
.04709 .05494 Mdot
.04317 .04317 Mdot
.05102 .05102 Mdot
.05102 .0667 Mdot
.05494 .07062 Mdot
.10591 .11376 Mdot
.91761 .89801 Mdot
.70979 .65881 Mdot
.62352 .55686 Mdot
.42354 .3804 Mdot
.37256 .34511 Mdot
.34511 .31374 Mdot
.3255 .29021 Mdot
.27061 .23924 Mdot
.27453 .23924 Mdot
.32158 .27453 Mdot
.27061 .23924 Mdot
.20394 .1765 Mdot
.18042 .15689 Mdot
.16473 .14513 Mdot
.13728 .1216 Mdot
.12944 .12552 Mdot
.13728 .13728 Mdot
.16473 .16473 Mdot
.16865 .17257 Mdot
.16865 .1765 Mdot
.16865 .1765 Mdot
.13728 .15297 Mdot
.14513 .16473 Mdot
.29413 .29806 Mdot
.25884 .26668 Mdot
.21179 .21571 Mdot
.1961 .18826 Mdot
.19218 .17257 Mdot
.18434 .16473 Mdot
.18434 .16473 Mdot
.1412 .12552 Mdot
.10199 .09023 Mdot
.0667 .05102 Mdot
.07062 .03533 Mdot
.09807 .05494 Mdot
.11768 .0667 Mdot
.11376 .07062 Mdot
.08631 .05102 Mdot
.0667 .04317 Mdot
.04709 .03533 Mdot
.04317 .03533 Mdot
.09023 .07454 Mdot
.09807 .09415 Mdot
.09415 .09415 Mdot
.07846 .09023 Mdot
.07454 .08631 Mdot
.07846 .09023 Mdot
.10983 .10983 Mdot
.10983 .09023 Mdot
.10199 .07062 Mdot
.09807 .05886 Mdot
.08631 .05494 Mdot
.14513 .10199 Mdot
.16081 .11768 Mdot
.11768 .08631 Mdot
.1412 .10983 Mdot
.13336 .11376 Mdot
.12944 .10591 Mdot
.21179 .1765 Mdot
.16865 .1412 Mdot
.14905 .12944 Mdot
.12552 .11376 Mdot
.12552 .10983 Mdot
.10983 .09415 Mdot
.09415 .08239 Mdot
.07454 .07454 Mdot
.06278 .07846 Mdot
.07454 .09023 Mdot
.83527 .80782 Mdot
.63528 .60391 Mdot
.40393 .37256 Mdot
.40393 .36864 Mdot
.32158 .29021 Mdot
.30198 .27453 Mdot
.28237 .24708 Mdot
.24708 .21963 Mdot
.21963 .20002 Mdot
.18434 .1765 Mdot
.16081 .15297 Mdot
.15297 .14905 Mdot
.13336 .13728 Mdot
.15297 .15689 Mdot
.1765 .17257 Mdot
.19218 .18434 Mdot
.18434 .17257 Mdot
.18042 .16473 Mdot
.1765 .16473 Mdot
.1765 .17257 Mdot
.20394 .20394 Mdot
.20394 .20787 Mdot
.20002 .19218 Mdot
.1961 .18826 Mdot
.19218 .18042 Mdot
.20002 .18826 Mdot
.18434 .18042 Mdot
.14513 .14513 Mdot
.13336 .13336 Mdot
.10983 .10199 Mdot
.09807 .08631 Mdot
.10983 .09023 Mdot
.1216 .09415 Mdot
.10591 .07846 Mdot
.09023 .0667 Mdot
.06278 .04709 Mdot
.0667 .04317 Mdot
.05886 .03141 Mdot
.07454 .05102 Mdot
.09023 .07062 Mdot
.09807 .09415 Mdot
.08239 .08631 Mdot
.0667 .0667 Mdot
.07062 .06278 Mdot
.09023 .07846 Mdot
.09023 .06278 Mdot
.08239 .05494 Mdot
.08631 .05494 Mdot
.08631 .05494 Mdot
.07454 .04709 Mdot
.09807 .07454 Mdot
.09807 .08239 Mdot
.10983 .09807 Mdot
.09807 .09415 Mdot
.10199 .09415 Mdot
.14513 .1216 Mdot
.20394 .15689 Mdot
.20394 .14513 Mdot
.16081 .09807 Mdot
.20394 .12944 Mdot
.23139 .16081 Mdot
.18434 .12944 Mdot
.17257 .13336 Mdot
.15297 .13336 Mdot
.11768 .10983 Mdot
.79998 .77253 Mdot
.51372 .46667 Mdot
.41569 .37648 Mdot
.3804 .34119 Mdot
.31374 .27845 Mdot
.28629 .251 Mdot
.22355 .20394 Mdot
.20394 .18826 Mdot
.18826 .18042 Mdot
.16473 .16865 Mdot
.16081 .16473 Mdot
.16473 .16865 Mdot
.18434 .18434 Mdot
.18826 .18042 Mdot
.18434 .17257 Mdot
.19218 .16865 Mdot
.1961 .16865 Mdot
.16865 .14513 Mdot
.16081 .1412 Mdot
.14513 .13336 Mdot
.15297 .13728 Mdot
.1765 .15297 Mdot
.19218 .17257 Mdot
.17257 .15689 Mdot
.16865 .15689 Mdot
.16081 .15689 Mdot
.13728 .13336 Mdot
.15297 .1412 Mdot
.17257 .15689 Mdot
.13728 .12944 Mdot
.10983 .09807 Mdot
.08239 .07062 Mdot
.0667 .05494 Mdot
.05102 .04317 Mdot
.04709 .03925 Mdot
.07846 .07062 Mdot
.08631 .07846 Mdot
.10199 .09807 Mdot
.08631 .08239 Mdot
.07062 .0667 Mdot
.0667 .05886 Mdot
.08631 .07062 Mdot
.08239 .05886 Mdot
.07062 .04709 Mdot
.06278 .04317 Mdot
.05494 .03925 Mdot
.05494 .03925 Mdot
.05102 .03141 Mdot
.06278 .04317 Mdot
.08239 .06278 Mdot
.07454 .05886 Mdot
.10983 .09415 Mdot
.13336 .10591 Mdot
.15689 .11376 Mdot
.17257 .10199 Mdot
.11376 .03533 Mdot
.21179 .1216 Mdot
.12944 .07062 Mdot
.20787 .16865 Mdot
.16081 .1412 Mdot
.18434 .16865 Mdot
.1961 .18434 Mdot
.91761 .90585 Mdot
.74116 .72547 Mdot
.49804 .47451 Mdot
.41569 .39217 Mdot
.29021 .27453 Mdot
.29021 .27061 Mdot
.23139 .21963 Mdot
.20787 .1961 Mdot
.20002 .18434 Mdot
.19218 .1765 Mdot
.18434 .1765 Mdot
.18826 .18042 Mdot
.1765 .16473 Mdot
.17257 .15297 Mdot
.18434 .16473 Mdot
.17257 .14905 Mdot
.15297 .13336 Mdot
.14513 .12552 Mdot
.13336 .1216 Mdot
.13728 .1216 Mdot
.13336 .11768 Mdot
.1412 .12552 Mdot
.1412 .13728 Mdot
.15689 .14905 Mdot
.14513 .1412 Mdot
.15297 .14905 Mdot
.21963 .19218 Mdot
.14513 .1216 Mdot
.10591 .09023 Mdot
.07454 .07062 Mdot
.0667 .05886 Mdot
.06278 .05102 Mdot
.06278 .05102 Mdot
.07846 .06278 Mdot
.10199 .08631 Mdot
.10591 .09415 Mdot
.10199 .08631 Mdot
.09415 .07062 Mdot
.09807 .07846 Mdot
.11376 .08631 Mdot
.09807 .07062 Mdot
.09415 .0667 Mdot
.0667 .05494 Mdot
.05886 .05494 Mdot
.05886 .05886 Mdot
.05102 .04317 Mdot
.03141 .01572 Mdot
.04317 .02357 Mdot
.04317 .02357 Mdot
.05102 .01965 Mdot
.05886 .02749 Mdot
.08239 .04317 Mdot
.11376 .07062 Mdot
.10199 .05886 Mdot
.29806 .23139 Mdot
.0667 .04317 Mdot
.40393 .36472 Mdot
.36472 .33335 Mdot
.06278 .06278 Mdot
.11768 .10983 Mdot
.90585 .89409 Mdot
.61568 .58823 Mdot
.48235 .4353 Mdot
.34119 .29021 Mdot
.32158 .26276 Mdot
.29413 .23139 Mdot
.26668 .20787 Mdot
.24708 .20002 Mdot
.24708 .20002 Mdot
.18042 .15689 Mdot
.18042 .15297 Mdot
.1765 .14513 Mdot
.16865 .1412 Mdot
.14905 .12552 Mdot
.14905 .12944 Mdot
.15689 .1412 Mdot
.14513 .13336 Mdot
.12552 .10983 Mdot
.1216 .10983 Mdot
.13728 .1216 Mdot
.12944 .1216 Mdot
.13336 .11768 Mdot
.1412 .11376 Mdot
.13728 .11376 Mdot
.1412 .11376 Mdot
.11768 .08631 Mdot
.09415 .07062 Mdot
.09023 .06278 Mdot
.08239 .05494 Mdot
.08239 .05494 Mdot
.09807 .0667 Mdot
.09415 .06278 Mdot
.10591 .07846 Mdot
.10983 .08631 Mdot
.09807 .07846 Mdot
.10591 .09415 Mdot
.11376 .09807 Mdot
.11376 .09415 Mdot
.10983 .09415 Mdot
.07062 .0667 Mdot
.05102 .05102 Mdot
.05886 .05886 Mdot
.04709 .04709 Mdot
.03925 .02357 Mdot
.03533 .01572 Mdot
.03533 .01965 Mdot
.03141 .01572 Mdot
.03925 .02749 Mdot
.03533 .01965 Mdot
.03925 .01965 Mdot
.03533 .0118 Mdot
.05102 .01572 Mdot
.08631 .04317 Mdot
.10591 .05886 Mdot
.13728 .08239 Mdot
.12944 .07846 Mdot
.09807 .05494 Mdot
.76861 .73724 Mdot
.59607 .55294 Mdot
.41569 .3608 Mdot
.34119 .28629 Mdot
.32158 .25884 Mdot
.29413 .23924 Mdot
.26668 .21571 Mdot
.23139 .18434 Mdot
.20002 .16473 Mdot
.16473 .13728 Mdot
.1412 .11768 Mdot
.13728 .1216 Mdot
.12944 .12552 Mdot
.13336 .12944 Mdot
.12944 .11768 Mdot
.11376 .09807 Mdot
.09807 .08239 Mdot
.09807 .07846 Mdot
.12944 .10591 Mdot
.10199 .07062 Mdot
.10983 .0667 Mdot
.1216 .07846 Mdot
.1216 .08239 Mdot
.1216 .08631 Mdot
.11768 .09023 Mdot
.10983 .09023 Mdot
.10199 .09023 Mdot
.09807 .08239 Mdot
.08631 .0667 Mdot
.09807 .07846 Mdot
.10591 .08239 Mdot
.11376 .09023 Mdot
.1216 .09807 Mdot
.11768 .09807 Mdot
.10983 .09415 Mdot
.10199 .09415 Mdot
.09415 .08239 Mdot
.08239 .06278 Mdot
.0667 .05102 Mdot
.05886 .03925 Mdot
.05102 .02749 Mdot
.04709 .01965 Mdot
.05102 .02749 Mdot
.04709 .01965 Mdot
.04317 .01965 Mdot
.03141 .01572 Mdot
.02749 .01572 Mdot
.02749 .0118 Mdot
.02749 .00396 Mdot
.04709 .00788 Mdot
.0667 .02357 Mdot
.09415 .03925 Mdot
.07062 .01965 Mdot
.05102 .0118 Mdot
.73724 .71371 Mdot
.42354 .37648 Mdot
.35687 .3059 Mdot
.31766 .26668 Mdot
.29021 .24316 Mdot
.24316 .21571 Mdot
.21571 .1961 Mdot
.20787 .18434 Mdot
.1961 .17257 Mdot
.17257 .16473 Mdot
.14905 .15297 Mdot
.13728 .14513 Mdot
.1216 .12944 Mdot
.10983 .11376 Mdot
.09807 .09415 Mdot
.11376 .10199 Mdot
.10199 .09023 Mdot
.10199 .07846 Mdot
.12552 .09807 Mdot
.13728 .11376 Mdot
.13336 .10983 Mdot
.12552 .11376 Mdot
.12552 .11376 Mdot
.13336 .1216 Mdot
.1216 .10591 Mdot
.10983 .09023 Mdot
.1216 .09023 Mdot
.13336 .09023 Mdot
.13728 .09415 Mdot
.15297 .10199 Mdot
.12944 .08239 Mdot
.13336 .08239 Mdot
.1216 .08239 Mdot
.1216 .09023 Mdot
.10983 .07846 Mdot
.10983 .07454 Mdot
.10591 .06278 Mdot
.08631 .05102 Mdot
.09415 .05102 Mdot
.07846 .04317 Mdot
.07454 .03533 Mdot
.07846 .04709 Mdot
.0667 .04709 Mdot
.05102 .03533 Mdot
.04709 .03141 Mdot
.04709 .02749 Mdot
.04709 .02357 Mdot
.04709 .02749 Mdot
.07062 .03925 Mdot
.06278 .03533 Mdot
.04709 .01965 Mdot
.87056 .86272 Mdot
.71763 .70587 Mdot
.40001 .38824 Mdot
.30982 .29806 Mdot
.28237 .27061 Mdot
.25884 .23531 Mdot
.23139 .20002 Mdot
.1961 .17257 Mdot
.16865 .16081 Mdot
.14513 .15297 Mdot
.12944 .13728 Mdot
.10983 .12552 Mdot
.11768 .12944 Mdot
.10983 .11376 Mdot
.09023 .09023 Mdot
.07454 .07062 Mdot
.07062 .07062 Mdot
.07846 .07454 Mdot
.08631 .08239 Mdot
.08239 .07454 Mdot
.09023 .07846 Mdot
.09807 .08239 Mdot
.09807 .07846 Mdot
.10591 .08631 Mdot
.09415 .06278 Mdot
.09023 .05102 Mdot
.10199 .05886 Mdot
.10983 .06278 Mdot
.10591 .05886 Mdot
.10591 .05886 Mdot
.09807 .05102 Mdot
.09807 .05494 Mdot
.09807 .05886 Mdot
.09415 .04709 Mdot
.09023 .04317 Mdot
.10199 .05494 Mdot
.10199 .05494 Mdot
.09807 .05886 Mdot
.08631 .05102 Mdot
.08239 .05102 Mdot
.06278 .04317 Mdot
.05494 .04317 Mdot
.04317 .04709 Mdot
.04709 .04709 Mdot
.05102 .04709 Mdot
.04709 .04317 Mdot
.05102 .04709 Mdot
.05494 .04709 Mdot
.04317 .03141 Mdot
.8784 .87056 Mdot
.59607 .56862 Mdot
.44314 .39217 Mdot
.24316 .20394 Mdot
.23531 .21179 Mdot
.1961 .18826 Mdot
.15297 .15689 Mdot
.12944 .14513 Mdot
.1216 .1412 Mdot
.12552 .14513 Mdot
.12552 .14513 Mdot
.11376 .13336 Mdot
.07846 .09807 Mdot
.05886 .08239 Mdot
.05886 .07454 Mdot
.05102 .05494 Mdot
.04317 .03141 Mdot
.06278 .04709 Mdot
.06278 .04317 Mdot
.05102 .03533 Mdot
.05494 .04317 Mdot
.05494 .02749 Mdot
.07062 .03533 Mdot
.07846 .03141 Mdot
.08239 .03533 Mdot
.07454 .01965 Mdot
.07062 .00788 Mdot
.09023 .01965 Mdot
.10199 .03141 Mdot
.08631 .02749 Mdot
.07454 .01965 Mdot
.06278 .0118 Mdot
.07062 .02749 Mdot
.07454 .03533 Mdot
.07062 .03925 Mdot
.0667 .05102 Mdot
.0667 .06278 Mdot
.05102 .05102 Mdot
.03925 .04317 Mdot
.02749 .02749 Mdot
.04317 .03925 Mdot
.05494 .05102 Mdot
.04709 .05102 Mdot
.04709 .05102 Mdot
.05494 .04709 Mdot
.04709 .03533 Mdot
.69018 .68234 Mdot
.45098 .45491 Mdot
.28629 .3059 Mdot
.18434 .21963 Mdot
.15689 .18826 Mdot
.13336 .16081 Mdot
.12552 .1412 Mdot
.10983 .12552 Mdot
.09023 .11376 Mdot
.09023 .10983 Mdot
.07846 .10199 Mdot
.06278 .08239 Mdot
.05886 .0667 Mdot
.0667 .06278 Mdot
.0667 .05886 Mdot
.06278 .05494 Mdot
.05102 .04709 Mdot
.03925 .03533 Mdot
.02749 .02357 Mdot
.0667 .05102 Mdot
.09023 .05102 Mdot
.07454 .03141 Mdot
.08239 .02357 Mdot
.07846 .0118 Mdot
.08631 .01965 Mdot
.09415 .02749 Mdot
.07846 .01965 Mdot
.08239 .02357 Mdot
.07062 .02357 Mdot
.07454 .02749 Mdot
.06278 .02749 Mdot
.06278 .03925 Mdot
.07454 .05102 Mdot
.07454 .05886 Mdot
.06278 .04709 Mdot
.04709 .03925 Mdot
.04317 .03141 Mdot
.03925 .03141 Mdot
.0667 .05886 Mdot
.04709 .05102 Mdot
.04709 .05102 Mdot
.05886 .05886 Mdot
.05886 .04709 Mdot
.57646 .60783 Mdot
.21179 .24316 Mdot
.21179 .21571 Mdot
.17257 .15689 Mdot
.13728 .1216 Mdot
.11768 .10591 Mdot
.11376 .10199 Mdot
.09807 .09415 Mdot
.09415 .10199 Mdot
.09415 .09807 Mdot
.08631 .09023 Mdot
.0667 .07454 Mdot
.07846 .08631 Mdot
.05494 .06278 Mdot
.04317 .05102 Mdot
.04317 .04709 Mdot
.05102 .04709 Mdot
.07454 .05102 Mdot
.07846 .04709 Mdot
.08239 .05102 Mdot
.0667 .03533 Mdot
.06278 .02357 Mdot
.07454 .02749 Mdot
.08631 .03925 Mdot
.08239 .03925 Mdot
.08631 .05494 Mdot
.09415 .05886 Mdot
.08631 .04317 Mdot
.07846 .04709 Mdot
.07454 .04317 Mdot
.07454 .04709 Mdot
.07846 .04709 Mdot
.05886 .03141 Mdot
.05494 .03141 Mdot
.05494 .02749 Mdot
.05886 .04317 Mdot
.0667 .05494 Mdot
.07062 .0667 Mdot
.07062 .0667 Mdot
.0667 .05886 Mdot
.81174 .8039 Mdot
.60783 .58823 Mdot
.19218 .15689 Mdot
.16473 .13336 Mdot
.1412 .11768 Mdot
.11768 .09807 Mdot
.10983 .09415 Mdot
.10983 .09415 Mdot
.10591 .09415 Mdot
.09415 .09023 Mdot
.07846 .07846 Mdot
.08239 .08239 Mdot
.07454 .07062 Mdot
.05102 .04709 Mdot
.07062 .0667 Mdot
.09415 .09023 Mdot
.09807 .08239 Mdot
.08631 .0667 Mdot
.08631 .0667 Mdot
.08239 .05494 Mdot
.09023 .05102 Mdot
.08239 .04317 Mdot
.08239 .05102 Mdot
.08239 .05494 Mdot
.08239 .05886 Mdot
.07846 .05102 Mdot
.07846 .05102 Mdot
.07062 .05102 Mdot
.0667 .05494 Mdot
.07454 .05494 Mdot
.07846 .04709 Mdot
.05886 .02357 Mdot
.04317 .0118 Mdot
.04709 .01572 Mdot
.05886 .03141 Mdot
.05494 .03141 Mdot
.05102 .03141 Mdot
.05494 .03141 Mdot
.59215 .57646 Mdot
.37256 .34511 Mdot
.14513 .10983 Mdot
.1412 .11768 Mdot
.12552 .10983 Mdot
.11376 .09415 Mdot
.10199 .08239 Mdot
.09415 .07846 Mdot
.09023 .09023 Mdot
.08631 .07846 Mdot
.06278 .05494 Mdot
.05494 .04317 Mdot
.07454 .05102 Mdot
.09023 .06278 Mdot
.10199 .07454 Mdot
.10983 .07846 Mdot
.10983 .07454 Mdot
.10983 .0667 Mdot
.09023 .05494 Mdot
.08631 .05886 Mdot
.08239 .05886 Mdot
.08239 .05886 Mdot
.07846 .05494 Mdot
.0667 .05102 Mdot
.05494 .03925 Mdot
.06278 .05494 Mdot
.07062 .06278 Mdot
.0667 .04317 Mdot
.06278 .03533 Mdot
.05886 .02749 Mdot
.06278 .02357 Mdot
.05494 .01572 Mdot
.05494 .0118 Mdot
.07062 .03141 Mdot
.06278 .03141 Mdot
.58431 .57646 Mdot
.35687 .3608 Mdot
.1216 .13336 Mdot
.13336 .14513 Mdot
.13728 .14905 Mdot
.10591 .12944 Mdot
.08239 .10199 Mdot
.06278 .0667 Mdot
.04709 .04709 Mdot
.05494 .05102 Mdot
.07062 .05886 Mdot
.09023 .07846 Mdot
.10199 .08631 Mdot
.11768 .09023 Mdot
.10983 .08239 Mdot
.09023 .07062 Mdot
.09023 .07454 Mdot
.08239 .07846 Mdot
.06278 .06278 Mdot
.05886 .05102 Mdot
.06278 .05494 Mdot
.0667 .05886 Mdot
.07846 .0667 Mdot
.0667 .05886 Mdot
.05494 .03925 Mdot
.05494 .03533 Mdot
.05494 .03533 Mdot
.05886 .03925 Mdot
.05886 .03533 Mdot
.0667 .03533 Mdot
.05494 .01965 Mdot
.03141 .00788 Mdot
.77645 .78429 Mdot
.62352 .63528 Mdot
.15689 .18826 Mdot
.1216 .16081 Mdot
.10199 .13728 Mdot
.07846 .09807 Mdot
.06278 .0667 Mdot
.05494 .05886 Mdot
.0667 .06278 Mdot
.08239 .07454 Mdot
.10199 .10199 Mdot
.1216 .11376 Mdot
.10983 .09415 Mdot
.09807 .07454 Mdot
.09807 .07454 Mdot
.10199 .09415 Mdot
.07846 .07846 Mdot
.07846 .07454 Mdot
.07846 .07062 Mdot
.08239 .0667 Mdot
.08239 .0667 Mdot
.08631 .07454 Mdot
.07062 .05886 Mdot
.05886 .04709 Mdot
.05886 .05102 Mdot
.05886 .05886 Mdot
.07062 .06278 Mdot
.05494 .04317 Mdot
.03141 .01965 Mdot
.02357 .00788 Mdot
.78037 .78821 Mdot
.56078 .57254 Mdot
.11768 .10983 Mdot
.13336 .10983 Mdot
.10591 .08239 Mdot
.10199 .07062 Mdot
.09023 .06278 Mdot
.10199 .08239 Mdot
.11376 .09415 Mdot
.11768 .09415 Mdot
.11376 .09415 Mdot
.12552 .11376 Mdot
.1216 .11376 Mdot
.10983 .10591 Mdot
.10591 .09415 Mdot
.09807 .09023 Mdot
.07454 .0667 Mdot
.09415 .07846 Mdot
.09023 .07846 Mdot
.07846 .07454 Mdot
.06278 .0667 Mdot
.04709 .05494 Mdot
.0667 .07454 Mdot
.07062 .07846 Mdot
.05494 .05494 Mdot
.03141 .02749 Mdot
.00788 .00788 Mdot
.59215 .56862 Mdot
.34903 .31374 Mdot
.12944 .08239 Mdot
.1216 .08239 Mdot
.10983 .08631 Mdot
.10983 .08631 Mdot
.11768 .09023 Mdot
.12552 .10591 Mdot
.12552 .10983 Mdot
.12552 .11768 Mdot
.11376 .11376 Mdot
.11376 .10983 Mdot
.10591 .10591 Mdot
.09415 .09023 Mdot
.09807 .09023 Mdot
.09807 .09023 Mdot
.08239 .07454 Mdot
.07846 .07062 Mdot
.06278 .06278 Mdot
.04709 .05102 Mdot
.04709 .04709 Mdot
.03925 .03533 Mdot
.02357 .01965 Mdot
.00788 .00396 Mdot
.57254 .56078 Mdot
.34903 .34119 Mdot
.10591 .10199 Mdot
.11376 .10591 Mdot
.12552 .11376 Mdot
.13728 .11768 Mdot
.13336 .11768 Mdot
.1216 .11768 Mdot
.11768 .11376 Mdot
.09807 .09807 Mdot
.09415 .09415 Mdot
.09807 .09415 Mdot
.10199 .09023 Mdot
.09807 .08631 Mdot
.07454 .07062 Mdot
.05494 .04709 Mdot
.03141 .03141 Mdot
.03141 .03141 Mdot
.02357 .01572 Mdot
.01965 .00788 Mdot
.01572 .00396 Mdot
.77253 .77645 Mdot
.54117 .54902 Mdot
.08239 .09023 Mdot
.08239 .07454 Mdot
.09807 .08239 Mdot
.09415 .08631 Mdot
.07846 .07846 Mdot
.08239 .08239 Mdot
.08239 .07846 Mdot
.09023 .07846 Mdot
.08239 .06278 Mdot
.07454 .04709 Mdot
.05494 .03141 Mdot
.03141 .01572 Mdot
.04317 .03141 Mdot
.05494 .03925 Mdot
.03533 .02357 Mdot
.03141 .01572 Mdot
.03141 .0118 Mdot
.76469 .76861 Mdot
.53333 .53333 Mdot
.08239 .07454 Mdot
.09807 .08631 Mdot
.08631 .07454 Mdot
.07846 .05886 Mdot
.08239 .05102 Mdot
.08631 .05102 Mdot
.07454 .04317 Mdot
.04709 .02749 Mdot
.04317 .01965 Mdot
.04709 .02357 Mdot
.05886 .03141 Mdot
.04709 .01965 Mdot
.03533 .0118 Mdot
.03533 .01572 Mdot
.58039 .57646 Mdot
.34903 .33727 Mdot
.11768 .10591 Mdot
.08631 .06278 Mdot
.08239 .05494 Mdot
.08239 .07454 Mdot
.07454 .07062 Mdot
.05494 .05886 Mdot
.05494 .05494 Mdot
.05886 .05102 Mdot
.05886 .03925 Mdot
.03141 .0118 Mdot
.03141 .00396 Mdot
.55686 .55686 Mdot
.33335 .33727 Mdot
.12944 .13728 Mdot
.10591 .11768 Mdot
.08239 .10983 Mdot
.05886 .08631 Mdot
.04317 .05886 Mdot
.03533 .03925 Mdot
.02749 .01572 Mdot
.02357 .00788 Mdot
.76469 .77253 Mdot
.54509 .55686 Mdot
.0667 .09415 Mdot
.03141 .0667 Mdot
.01572 .04317 Mdot
.0118 .01965 Mdot
.00788 .00788 Mdot
.01572 .0118 Mdot
.76469 .77645 Mdot
.51372 .53725 Mdot
.01965 .04317 Mdot
.01572 .02357 Mdot
.0118 .0118 Mdot
.50588 .51765 Mdot
.25492 .26668 Mdot
0 0 1 r
.83919 .84703 Mdot
.43138 .47451 Mdot
.40785 .44314 Mdot
.69802 .72155 Mdot
.4902 .53725 Mdot
.51372 .5647 Mdot
.51765 .5647 Mdot
.50196 .54902 Mdot
.63528 .67057 Mdot
.749 .77645 Mdot
.51372 .54902 Mdot
.52941 .57646 Mdot
.54509 .60391 Mdot
.54509 .61568 Mdot
.53725 .61568 Mdot
.52549 .60391 Mdot
.52549 .59607 Mdot
.65097 .70194 Mdot
.88232 .90193 Mdot
.5098 .56078 Mdot
.54117 .59215 Mdot
.54902 .61568 Mdot
.55294 .62744 Mdot
.55686 .6392 Mdot
.54902 .64313 Mdot
.54117 .6196 Mdot
.54509 .6196 Mdot
.54509 .6196 Mdot
.54902 .6196 Mdot
.77253 .81566 Mdot
.89017 .90977 Mdot
.49804 .55294 Mdot
.53725 .60391 Mdot
.54117 .61568 Mdot
.55294 .63136 Mdot
.5647 .64705 Mdot
.55686 .64705 Mdot
.55294 .62744 Mdot
.55686 .6196 Mdot
.55294 .61568 Mdot
.55686 .62352 Mdot
.55686 .62352 Mdot
.55294 .61568 Mdot
.55686 .60783 Mdot
.78429 .79998 Mdot
.52157 .57254 Mdot
.54117 .60783 Mdot
.55294 .62352 Mdot
.55294 .63136 Mdot
.55294 .62744 Mdot
.55294 .62744 Mdot
.55294 .62352 Mdot
.55686 .61568 Mdot
.54902 .60783 Mdot
.55294 .61176 Mdot
.55686 .60391 Mdot
.56078 .60783 Mdot
.5647 .60783 Mdot
.5647 .60783 Mdot
.58039 .61568 Mdot
.68626 .70194 Mdot
.79213 .8039 Mdot
.5098 .56078 Mdot
.53725 .59607 Mdot
.54117 .60391 Mdot
.54117 .60783 Mdot
.54117 .60783 Mdot
.54509 .60783 Mdot
.53725 .59607 Mdot
.54117 .58431 Mdot
.55294 .59607 Mdot
.56862 .61176 Mdot
.57254 .61568 Mdot
.57646 .62352 Mdot
.57646 .61568 Mdot
.57646 .61176 Mdot
.58431 .61568 Mdot
.58039 .61176 Mdot
.59215 .6196 Mdot
.5647 .59215 Mdot
.77253 .79213 Mdot
.88232 .88624 Mdot
.52157 .57646 Mdot
.52941 .59607 Mdot
.52941 .59999 Mdot
.52549 .60391 Mdot
.52941 .59215 Mdot
.54117 .59215 Mdot
.54509 .59215 Mdot
.55294 .59999 Mdot
.55294 .60391 Mdot
.56078 .61568 Mdot
.5647 .61568 Mdot
.57254 .61568 Mdot
.58039 .6196 Mdot
.58431 .6196 Mdot
.58823 .62352 Mdot
.59999 .63136 Mdot
.59215 .62352 Mdot
.58823 .6196 Mdot
.58039 .60783 Mdot
.58039 .60391 Mdot
.46275 .49804 Mdot
.72155 .73724 Mdot
.81958 .83135 Mdot
.50588 .55294 Mdot
.53725 .58823 Mdot
.54509 .60783 Mdot
.54509 .61176 Mdot
.53725 .61176 Mdot
.52549 .59999 Mdot
.53725 .60783 Mdot
.54902 .6196 Mdot
.55686 .62352 Mdot
.55686 .62744 Mdot
.5647 .62744 Mdot
.5647 .61568 Mdot
.57254 .6196 Mdot
.58823 .62352 Mdot
.58431 .6196 Mdot
.59999 .63528 Mdot
.59215 .62744 Mdot
.59999 .63136 Mdot
.59215 .6196 Mdot
.58431 .6196 Mdot
.59215 .62744 Mdot
.55686 .58431 Mdot
.44706 .46667 Mdot
.51372 .52549 Mdot
.66665 .66665 Mdot
.5098 .53725 Mdot
.54509 .59607 Mdot
.54902 .61568 Mdot
.53333 .61568 Mdot
.53333 .6196 Mdot
.52941 .62744 Mdot
.53333 .62744 Mdot
.53725 .62744 Mdot
.55294 .62744 Mdot
.56078 .63136 Mdot
.56862 .6392 Mdot
.57646 .64313 Mdot
.58039 .64313 Mdot
.59215 .6392 Mdot
.59215 .63136 Mdot
.59607 .62744 Mdot
.59607 .62744 Mdot
.59607 .63136 Mdot
.60783 .64313 Mdot
.60391 .6392 Mdot
.59607 .63528 Mdot
.58823 .63136 Mdot
.58431 .6196 Mdot
.54902 .58431 Mdot
.49412 .51765 Mdot
.41569 .42354 Mdot
.47059 .47843 Mdot
.63528 .63528 Mdot
.52941 .56862 Mdot
.55686 .61568 Mdot
.55686 .6392 Mdot
.54509 .64313 Mdot
.54117 .65097 Mdot
.54509 .64705 Mdot
.53725 .63136 Mdot
.53333 .62744 Mdot
.54509 .62744 Mdot
.55294 .63528 Mdot
.57254 .64313 Mdot
.57646 .64313 Mdot
.57646 .6392 Mdot
.58039 .6392 Mdot
.58823 .63136 Mdot
.58823 .62744 Mdot
.59999 .63136 Mdot
.60783 .6392 Mdot
.60391 .65097 Mdot
.59999 .65489 Mdot
.59999 .65489 Mdot
.59607 .64313 Mdot
.59607 .64313 Mdot
.59999 .64705 Mdot
.59215 .6392 Mdot
.58431 .61568 Mdot
.54902 .5647 Mdot
.38824 .40785 Mdot
.3608 .37648 Mdot
.72155 .72939 Mdot
.81174 .8235 Mdot
.53333 .58823 Mdot
.55294 .6196 Mdot
.55686 .64313 Mdot
.55294 .65097 Mdot
.55294 .65489 Mdot
.54902 .65489 Mdot
.54509 .65097 Mdot
.54117 .6392 Mdot
.54902 .63528 Mdot
.55686 .6392 Mdot
.5647 .64313 Mdot
.56862 .6392 Mdot
.57646 .63528 Mdot
.58431 .63528 Mdot
.58823 .63528 Mdot
.58039 .62744 Mdot
.59607 .6392 Mdot
.60783 .65097 Mdot
.60783 .66665 Mdot
.60391 .67057 Mdot
.59999 .66665 Mdot
.60783 .6745 Mdot
.59999 .66665 Mdot
.59999 .66665 Mdot
.60391 .66665 Mdot
.60391 .65489 Mdot
.61176 .65097 Mdot
.59607 .62352 Mdot
.52941 .55686 Mdot
.47059 .50196 Mdot
.36472 .40785 Mdot
.32158 .36864 Mdot
.75292 .76076 Mdot
.8784 .8784 Mdot
.51765 .57646 Mdot
.54509 .60783 Mdot
.54509 .6196 Mdot
.54902 .62744 Mdot
.53725 .62744 Mdot
.54117 .6392 Mdot
.54902 .64705 Mdot
.54509 .6392 Mdot
.54902 .6392 Mdot
.55294 .63528 Mdot
.56078 .64705 Mdot
.56862 .65489 Mdot
.57254 .64705 Mdot
.58431 .64705 Mdot
.58823 .6392 Mdot
.58431 .64705 Mdot
.59607 .66273 Mdot
.59215 .66273 Mdot
.59607 .65881 Mdot
.60391 .67057 Mdot
.60391 .67057 Mdot
.60391 .67057 Mdot
.60783 .6745 Mdot
.61176 .67842 Mdot
.62744 .68234 Mdot
.62744 .67842 Mdot
.62352 .65489 Mdot
.62744 .65097 Mdot
.48628 .51372 Mdot
.38432 .41569 Mdot
.40001 .43138 Mdot
.44706 .47451 Mdot
.59999 .60783 Mdot
.58039 .59215 Mdot
.6941 .70587 Mdot
.81174 .81958 Mdot
.52549 .58431 Mdot
.54902 .62352 Mdot
.55686 .64705 Mdot
.54509 .64705 Mdot
.53333 .63528 Mdot
.53333 .63136 Mdot
.54509 .63528 Mdot
.54902 .63136 Mdot
.54902 .62744 Mdot
.5647 .64313 Mdot
.5647 .65489 Mdot
.5647 .66665 Mdot
.57646 .6745 Mdot
.57254 .66273 Mdot
.57646 .65097 Mdot
.59215 .65881 Mdot
.60391 .67842 Mdot
.59607 .67842 Mdot
.59999 .6745 Mdot
.60783 .6745 Mdot
.61176 .67057 Mdot
.61176 .66665 Mdot
.62744 .68626 Mdot
.63528 .69018 Mdot
.63136 .67842 Mdot
.62744 .67057 Mdot
.63136 .67057 Mdot
.63528 .6745 Mdot
.53725 .57254 Mdot
.39609 .4353 Mdot
.40001 .43138 Mdot
.56078 .58039 Mdot
.60783 .62744 Mdot
.62352 .6392 Mdot
.64313 .65489 Mdot
.65097 .66273 Mdot
.65489 .67057 Mdot
.72155 .73724 Mdot
.79998 .81566 Mdot
.53333 .59999 Mdot
.55294 .64705 Mdot
.56078 .66665 Mdot
.54902 .65881 Mdot
.54509 .65489 Mdot
.55294 .65881 Mdot
.56078 .65489 Mdot
.56078 .6392 Mdot
.5647 .64313 Mdot
.56862 .65097 Mdot
.5647 .65881 Mdot
.56862 .66273 Mdot
.56862 .66273 Mdot
.56862 .66273 Mdot
.56862 .65881 Mdot
.58039 .66273 Mdot
.59607 .68234 Mdot
.58823 .68626 Mdot
.59215 .67842 Mdot
.60783 .67842 Mdot
.6196 .6745 Mdot
.6196 .6745 Mdot
.62352 .68626 Mdot
.63136 .69018 Mdot
.6392 .69802 Mdot
.6392 .69802 Mdot
.64705 .68626 Mdot
.64705 .68626 Mdot
.61176 .65881 Mdot
.58431 .62744 Mdot
.56078 .59215 Mdot
.59215 .6196 Mdot
.6392 .65489 Mdot
.64705 .66665 Mdot
.65489 .68234 Mdot
.66665 .68626 Mdot
.66665 .69018 Mdot
.67057 .69018 Mdot
.65881 .67842 Mdot
.66273 .6745 Mdot
.83135 .83527 Mdot
.91761 .92154 Mdot
.51765 .59215 Mdot
.53725 .63528 Mdot
.55294 .66665 Mdot
.55294 .67057 Mdot
.54509 .66273 Mdot
.54902 .65097 Mdot
.55294 .65097 Mdot
.55686 .64313 Mdot
.56862 .65489 Mdot
.57254 .65881 Mdot
.56078 .65097 Mdot
.57646 .65881 Mdot
.57646 .66273 Mdot
.57254 .65881 Mdot
.57254 .66273 Mdot
.58039 .66273 Mdot
.60391 .68626 Mdot
.61176 .6941 Mdot
.60391 .67842 Mdot
.60391 .68234 Mdot
.60391 .67842 Mdot
.61176 .67842 Mdot
.6196 .6745 Mdot
.62744 .68234 Mdot
.63136 .68626 Mdot
.63528 .68626 Mdot
.63136 .6745 Mdot
.64705 .68234 Mdot
.64705 .67842 Mdot
.64313 .66665 Mdot
.63136 .65489 Mdot
.6392 .66273 Mdot
.65097 .67057 Mdot
.65881 .67842 Mdot
.65881 .69018 Mdot
.6745 .70587 Mdot
.67842 .70194 Mdot
.68626 .71371 Mdot
.68234 .70194 Mdot
.67842 .69802 Mdot
.66665 .6745 Mdot
.6745 .67057 Mdot
.67057 .64313 Mdot
.83527 .81958 Mdot
.91761 .90585 Mdot
.50588 .59999 Mdot
.53333 .62744 Mdot
.54509 .64705 Mdot
.54902 .65881 Mdot
.54509 .65881 Mdot
.54509 .64313 Mdot
.54902 .6392 Mdot
.54902 .6392 Mdot
.55686 .64705 Mdot
.5647 .65489 Mdot
.5647 .65489 Mdot
.57254 .64705 Mdot
.57254 .65097 Mdot
.57646 .66273 Mdot
.57254 .66665 Mdot
.57646 .66273 Mdot
.59215 .67057 Mdot
.59607 .6745 Mdot
.61176 .68234 Mdot
.60391 .68234 Mdot
.61568 .69018 Mdot
.60391 .68234 Mdot
.6196 .69018 Mdot
.62744 .70194 Mdot
.63528 .70979 Mdot
.63528 .70587 Mdot
.63136 .6941 Mdot
.64313 .69802 Mdot
.65097 .69018 Mdot
.65097 .68234 Mdot
.65097 .68234 Mdot
.64705 .67842 Mdot
.64705 .68234 Mdot
.65881 .68234 Mdot
.66665 .6941 Mdot
.67057 .70194 Mdot
.6745 .70587 Mdot
.67842 .71371 Mdot
.67842 .70979 Mdot
.68234 .70979 Mdot
.6745 .69018 Mdot
.66665 .6745 Mdot
.68234 .67057 Mdot
.67842 .66665 Mdot
.67842 .65881 Mdot
.76076 .749 Mdot
.84703 .83919 Mdot
.50196 .59215 Mdot
.53333 .63528 Mdot
.54902 .65881 Mdot
.54902 .66273 Mdot
.53333 .65097 Mdot
.54117 .64705 Mdot
.54902 .64705 Mdot
.55686 .65881 Mdot
.55686 .66273 Mdot
.55686 .65881 Mdot
.5647 .66273 Mdot
.57646 .67057 Mdot
.57254 .66665 Mdot
.57646 .67842 Mdot
.58039 .67842 Mdot
.58039 .6745 Mdot
.58431 .67057 Mdot
.58823 .6745 Mdot
.59999 .68626 Mdot
.60391 .6941 Mdot
.61176 .69802 Mdot
.61568 .70587 Mdot
.62352 .70979 Mdot
.63528 .72155 Mdot
.63528 .71763 Mdot
.63528 .70979 Mdot
.63528 .70979 Mdot
.63528 .70587 Mdot
.65097 .71371 Mdot
.65097 .70194 Mdot
.65881 .70979 Mdot
.66665 .71371 Mdot
.66273 .70587 Mdot
.66273 .69018 Mdot
.66665 .69018 Mdot
.6745 .70979 Mdot
.68626 .72155 Mdot
.68234 .72155 Mdot
.67842 .71371 Mdot
.67842 .70587 Mdot
.67842 .6941 Mdot
.67842 .67842 Mdot
.6941 .67842 Mdot
.6941 .67842 Mdot
.6941 .68234 Mdot
.69802 .68626 Mdot
.69018 .68626 Mdot
.69802 .6941 Mdot
.76076 .76076 Mdot
.84311 .84703 Mdot
.51372 .59999 Mdot
.53725 .6392 Mdot
.55294 .66273 Mdot
.54509 .66273 Mdot
.53725 .65489 Mdot
.54117 .65097 Mdot
.54509 .64313 Mdot
.55294 .65097 Mdot
.56078 .66273 Mdot
.55294 .65489 Mdot
.57646 .67057 Mdot
.57646 .67057 Mdot
.58039 .67842 Mdot
.57646 .6745 Mdot
.58039 .67842 Mdot
.58039 .6745 Mdot
.58431 .6745 Mdot
.58431 .6745 Mdot
.58431 .6745 Mdot
.58823 .67842 Mdot
.60391 .69018 Mdot
.60783 .69018 Mdot
.6196 .70194 Mdot
.63528 .71763 Mdot
.6392 .72155 Mdot
.64313 .71371 Mdot
.64313 .70979 Mdot
.65097 .71371 Mdot
.64313 .70979 Mdot
.65489 .70587 Mdot
.65881 .70194 Mdot
.65881 .70194 Mdot
.66273 .69802 Mdot
.67842 .70587 Mdot
.6745 .71371 Mdot
.6745 .71371 Mdot
.68234 .71763 Mdot
.68626 .72155 Mdot
.67842 .71763 Mdot
.68234 .70979 Mdot
.68234 .70194 Mdot
.68234 .68626 Mdot
.6941 .69018 Mdot
.70194 .69018 Mdot
.69802 .68234 Mdot
.70194 .68234 Mdot
.70194 .68234 Mdot
.71371 .6941 Mdot
.70587 .69018 Mdot
.6941 .69018 Mdot
.67842 .67842 Mdot
.8235 .81958 Mdot
.89801 .89801 Mdot
.46275 .54902 Mdot
.54902 .63136 Mdot
.53725 .64313 Mdot
.52157 .64313 Mdot
.51765 .6392 Mdot
.52549 .64313 Mdot
.53333 .6392 Mdot
.55294 .65097 Mdot
.55686 .65881 Mdot
.56078 .66273 Mdot
.55686 .65489 Mdot
.56862 .66273 Mdot
.57254 .67057 Mdot
.57254 .67057 Mdot
.57646 .67057 Mdot
.57646 .66665 Mdot
.58823 .67842 Mdot
.59999 .68234 Mdot
.59999 .68626 Mdot
.59215 .68234 Mdot
.59215 .68234 Mdot
.60391 .68626 Mdot
.60391 .68626 Mdot
.60783 .68626 Mdot
.61568 .68626 Mdot
.63136 .68234 Mdot
.6392 .68234 Mdot
.65489 .70194 Mdot
.65097 .70979 Mdot
.65097 .70587 Mdot
.65097 .6941 Mdot
.65489 .68626 Mdot
.66273 .69018 Mdot
.6745 .70587 Mdot
.67842 .71763 Mdot
.66273 .70194 Mdot
.66665 .71371 Mdot
.67057 .71371 Mdot
.67057 .70587 Mdot
.67057 .69802 Mdot
.67057 .69018 Mdot
.69018 .69802 Mdot
.69018 .69018 Mdot
.69018 .67842 Mdot
.69018 .6745 Mdot
.70194 .67842 Mdot
.70194 .67842 Mdot
.70979 .6745 Mdot
.70587 .6745 Mdot
.70979 .68626 Mdot
.70587 .69018 Mdot
.6941 .67842 Mdot
.68626 .66665 Mdot
.59215 .56862 Mdot
.74508 .72939 Mdot
.86272 .85487 Mdot
.48628 .5647 Mdot
.51372 .59999 Mdot
.52941 .63136 Mdot
.52941 .64313 Mdot
.51765 .6392 Mdot
.51765 .64313 Mdot
.51765 .6392 Mdot
.54509 .65489 Mdot
.55686 .67057 Mdot
.55686 .6745 Mdot
.55294 .66273 Mdot
.54902 .65881 Mdot
.56078 .67057 Mdot
.55294 .65881 Mdot
.5647 .65881 Mdot
.56862 .65881 Mdot
.58039 .66665 Mdot
.58431 .67057 Mdot
.58823 .66665 Mdot
.58823 .66665 Mdot
.59607 .67057 Mdot
.59607 .6745 Mdot
.59607 .67057 Mdot
.61176 .68234 Mdot
.61568 .68234 Mdot
.62352 .6745 Mdot
.6392 .68234 Mdot
.64313 .67842 Mdot
.65489 .69018 Mdot
.66273 .6941 Mdot
.66665 .6941 Mdot
.66273 .6941 Mdot
.66273 .68626 Mdot
.65881 .68626 Mdot
.66665 .70194 Mdot
.65881 .70194 Mdot
.66273 .71371 Mdot
.66273 .70979 Mdot
.66665 .70194 Mdot
.6745 .70587 Mdot
.68626 .70979 Mdot
.68234 .6941 Mdot
.69018 .6941 Mdot
.69802 .6941 Mdot
.6941 .68626 Mdot
.69802 .68234 Mdot
.70194 .6745 Mdot
.70979 .6745 Mdot
.70587 .6745 Mdot
.71371 .68626 Mdot
.70979 .69018 Mdot
.70979 .68626 Mdot
.71371 .68234 Mdot
.70587 .6745 Mdot
.67057 .6392 Mdot
.65489 .6196 Mdot
.74116 .71763 Mdot
.79606 .78429 Mdot
.50588 .56862 Mdot
.53725 .60391 Mdot
.54509 .63528 Mdot
.53333 .6392 Mdot
.51765 .63528 Mdot
.52157 .63528 Mdot
.52941 .6392 Mdot
.54117 .63528 Mdot
.54902 .6392 Mdot
.54902 .64705 Mdot
.55294 .65097 Mdot
.55294 .65097 Mdot
.55294 .65881 Mdot
.55686 .65881 Mdot
.56078 .64705 Mdot
.5647 .65097 Mdot
.57254 .66273 Mdot
.56862 .65489 Mdot
.5647 .65097 Mdot
.57646 .65489 Mdot
.58431 .65489 Mdot
.59215 .66273 Mdot
.60391 .67057 Mdot
.61568 .6745 Mdot
.61568 .67057 Mdot
.62352 .6745 Mdot
.63528 .68626 Mdot
.6392 .69018 Mdot
.64313 .68626 Mdot
.65489 .68626 Mdot
.65489 .68626 Mdot
.66273 .6941 Mdot
.66665 .6941 Mdot
.66665 .69018 Mdot
.66273 .6941 Mdot
.66665 .70587 Mdot
.65881 .70587 Mdot
.66665 .70587 Mdot
.66273 .69018 Mdot
.6745 .69802 Mdot
.68626 .69802 Mdot
.68234 .68626 Mdot
.69018 .6941 Mdot
.70194 .69802 Mdot
.70194 .69802 Mdot
.70194 .6941 Mdot
.70979 .69018 Mdot
.70587 .67842 Mdot
.70979 .67842 Mdot
.71763 .68626 Mdot
.72155 .6941 Mdot
.71371 .69018 Mdot
.71763 .68234 Mdot
.71371 .67057 Mdot
.71371 .6745 Mdot
.70979 .6745 Mdot
.70587 .66665 Mdot
.70194 .65881 Mdot
.6745 .63528 Mdot
.74508 .71763 Mdot
.64313 .6392 Mdot
.46275 .52549 Mdot
.52549 .60391 Mdot
.53333 .63136 Mdot
.52941 .6392 Mdot
.52941 .64313 Mdot
.52549 .65097 Mdot
.53333 .65881 Mdot
.53725 .65097 Mdot
.54509 .65097 Mdot
.54902 .64705 Mdot
.54902 .64705 Mdot
.54509 .64705 Mdot
.54117 .65097 Mdot
.55294 .65097 Mdot
.56078 .64705 Mdot
.57254 .65489 Mdot
.56862 .65881 Mdot
.57254 .6745 Mdot
.5647 .65881 Mdot
.58039 .66273 Mdot
.58431 .65097 Mdot
.59999 .65881 Mdot
.60783 .66273 Mdot
.62352 .6745 Mdot
.63136 .68234 Mdot
.63528 .68234 Mdot
.65097 .69802 Mdot
.65881 .69802 Mdot
.64705 .69018 Mdot
.66273 .69802 Mdot
.66273 .69018 Mdot
.67057 .69802 Mdot
.66665 .69018 Mdot
.67057 .69802 Mdot
.67057 .69802 Mdot
.67842 .70979 Mdot
.67842 .70587 Mdot
.67057 .6941 Mdot
.67842 .69802 Mdot
.68234 .69802 Mdot
.68234 .69802 Mdot
.68626 .69018 Mdot
.6941 .69802 Mdot
.69802 .69802 Mdot
.70194 .70194 Mdot
.70979 .70194 Mdot
.70587 .69018 Mdot
.71371 .68626 Mdot
.71371 .67842 Mdot
.72155 .68234 Mdot
.71763 .68234 Mdot
.71763 .68234 Mdot
.71371 .68626 Mdot
.70979 .68234 Mdot
.72939 .6941 Mdot
.72547 .68234 Mdot
.72547 .67842 Mdot
.72939 .67842 Mdot
.72939 .6745 Mdot
.74116 .67842 Mdot
.4902 .45098 Mdot
.28629 .26276 Mdot
.65881 .6392 Mdot
.88624 .87056 Mdot
.45491 .52549 Mdot
.50196 .59215 Mdot
.52549 .63136 Mdot
.53333 .65489 Mdot
.53333 .65881 Mdot
.53725 .66665 Mdot
.53333 .66273 Mdot
.53725 .66665 Mdot
.54509 .66665 Mdot
.54117 .65489 Mdot
.55294 .65881 Mdot
.5647 .66273 Mdot
.56078 .66273 Mdot
.56862 .67057 Mdot
.56862 .66665 Mdot
.56862 .65881 Mdot
.57646 .66665 Mdot
.58823 .68234 Mdot
.58039 .67842 Mdot
.58431 .68234 Mdot
.59999 .68626 Mdot
.60391 .68234 Mdot
.61176 .68234 Mdot
.6196 .68234 Mdot
.6196 .68626 Mdot
.63136 .69018 Mdot
.64313 .69802 Mdot
.65489 .69802 Mdot
.64705 .6941 Mdot
.64705 .69802 Mdot
.65881 .70587 Mdot
.66273 .69802 Mdot
.67057 .70587 Mdot
.6745 .71763 Mdot
.6745 .72155 Mdot
.67842 .72547 Mdot
.68626 .72155 Mdot
.69018 .71763 Mdot
.6941 .71371 Mdot
.6941 .71763 Mdot
.69802 .71371 Mdot
.6941 .70979 Mdot
.70194 .71763 Mdot
.70194 .71763 Mdot
.70587 .70979 Mdot
.70194 .70194 Mdot
.70979 .70194 Mdot
.71371 .69018 Mdot
.72155 .68234 Mdot
.72547 .67842 Mdot
.74116 .6941 Mdot
.73332 .69802 Mdot
.73332 .70587 Mdot
.73332 .71371 Mdot
.73332 .70979 Mdot
.74116 .71371 Mdot
.74508 .70587 Mdot
.74116 .6941 Mdot
.73724 .67842 Mdot
.74508 .6745 Mdot
.71763 .64313 Mdot
.4902 .4353 Mdot
.36864 .33335 Mdot
.6941 .63136 Mdot
.59607 .54902 Mdot
.83135 .80782 Mdot
.90977 .89801 Mdot
.44314 .52157 Mdot
.5098 .60783 Mdot
.52157 .6392 Mdot
.52549 .65097 Mdot
.51765 .64705 Mdot
.52157 .64705 Mdot
.52157 .64705 Mdot
.52549 .64705 Mdot
.53333 .65097 Mdot
.54509 .65881 Mdot
.55294 .65489 Mdot
.54902 .65489 Mdot
.54902 .66273 Mdot
.55686 .67057 Mdot
.56078 .67057 Mdot
.54509 .65097 Mdot
.55294 .65097 Mdot
.56862 .66273 Mdot
.58431 .68234 Mdot
.58823 .6941 Mdot
.59215 .70194 Mdot
.59215 .69802 Mdot
.60783 .69802 Mdot
.61176 .69018 Mdot
.60783 .68626 Mdot
.6196 .6941 Mdot
.61568 .69018 Mdot
.62352 .6941 Mdot
.62744 .69802 Mdot
.6392 .70194 Mdot
.65097 .70587 Mdot
.65097 .70587 Mdot
.65881 .71763 Mdot
.65489 .71763 Mdot
.65881 .71371 Mdot
.67057 .72155 Mdot
.6745 .72939 Mdot
.6745 .72155 Mdot
.68234 .71763 Mdot
.6745 .70587 Mdot
.68626 .70979 Mdot
.69018 .70979 Mdot
.6941 .72547 Mdot
.69018 .72155 Mdot
.70194 .72155 Mdot
.69802 .70979 Mdot
.70194 .70979 Mdot
.70979 .69802 Mdot
.71371 .70194 Mdot
.71763 .69802 Mdot
.72939 .6941 Mdot
.72939 .70587 Mdot
.73724 .72155 Mdot
.72939 .72547 Mdot
.72547 .71763 Mdot
.72547 .70587 Mdot
.72547 .70587 Mdot
.73332 .69802 Mdot
.72939 .6745 Mdot
.72155 .66273 Mdot
.72155 .66665 Mdot
.70979 .66273 Mdot
.68626 .6392 Mdot
.70587 .65489 Mdot
.71371 .67057 Mdot
.70979 .66665 Mdot
.69802 .65097 Mdot
.76861 .72939 Mdot
.69018 .68234 Mdot
.47451 .54902 Mdot
.50588 .61568 Mdot
.50196 .63136 Mdot
.50196 .63528 Mdot
.50588 .63528 Mdot
.52157 .6392 Mdot
.52157 .63528 Mdot
.51765 .63136 Mdot
.52941 .64313 Mdot
.53725 .64705 Mdot
.54509 .65881 Mdot
.54117 .65881 Mdot
.54509 .66273 Mdot
.54509 .65489 Mdot
.54117 .65881 Mdot
.54509 .65881 Mdot
.54902 .65097 Mdot
.5647 .66273 Mdot
.58431 .68234 Mdot
.58039 .69018 Mdot
.58431 .69802 Mdot
.59215 .69802 Mdot
.59607 .68626 Mdot
.60391 .6941 Mdot
.61176 .69802 Mdot
.61176 .6941 Mdot
.61176 .69802 Mdot
.61568 .70194 Mdot
.62744 .70587 Mdot
.6392 .70194 Mdot
.64313 .70194 Mdot
.64313 .70587 Mdot
.67057 .72155 Mdot
.66665 .71763 Mdot
.66273 .71763 Mdot
.66665 .72547 Mdot
.6745 .73332 Mdot
.6745 .72547 Mdot
.67842 .72155 Mdot
.67842 .71371 Mdot
.68626 .70587 Mdot
.68626 .70194 Mdot
.69802 .71371 Mdot
.69802 .71763 Mdot
.70194 .71371 Mdot
.70194 .71371 Mdot
.70587 .70587 Mdot
.70194 .69802 Mdot
.69802 .69018 Mdot
.70587 .69018 Mdot
.70979 .69018 Mdot
.71371 .69802 Mdot
.72547 .71371 Mdot
.72155 .71371 Mdot
.71763 .71371 Mdot
.70979 .70979 Mdot
.70979 .69802 Mdot
.71371 .68626 Mdot
.71763 .68234 Mdot
.72547 .68234 Mdot
.72939 .67842 Mdot
.73724 .68234 Mdot
.72939 .67057 Mdot
.73332 .67842 Mdot
.72547 .6745 Mdot
.73332 .67842 Mdot
.74116 .67057 Mdot
.72939 .66273 Mdot
.6745 .61568 Mdot
.66273 .60391 Mdot
.75684 .70979 Mdot
.92938 .90977 Mdot
.48235 .5647 Mdot
.50588 .6196 Mdot
.51765 .64313 Mdot
.51372 .6392 Mdot
.5098 .63528 Mdot
.51372 .63136 Mdot
.51765 .63528 Mdot
.52549 .64313 Mdot
.52549 .65097 Mdot
.52941 .65097 Mdot
.54509 .67057 Mdot
.54117 .66273 Mdot
.54509 .65881 Mdot
.55686 .66273 Mdot
.54902 .65881 Mdot
.54902 .65881 Mdot
.55686 .66273 Mdot
.5647 .66665 Mdot
.57646 .6745 Mdot
.58039 .67842 Mdot
.58431 .68234 Mdot
.58823 .6941 Mdot
.60391 .70587 Mdot
.60391 .70979 Mdot
.61176 .71371 Mdot
.62352 .70587 Mdot
.62352 .70979 Mdot
.62744 .71763 Mdot
.6392 .72547 Mdot
.64313 .71763 Mdot
.65097 .71371 Mdot
.65097 .70587 Mdot
.65881 .70194 Mdot
.65881 .70194 Mdot
.65881 .70587 Mdot
.6745 .71763 Mdot
.68234 .72547 Mdot
.69018 .72547 Mdot
.69018 .72155 Mdot
.69018 .71763 Mdot
.69018 .70194 Mdot
.6941 .70194 Mdot
.70587 .70979 Mdot
.70587 .70587 Mdot
.70979 .70979 Mdot
.70587 .70194 Mdot
.70587 .69802 Mdot
.70194 .68626 Mdot
.70587 .68626 Mdot
.70587 .68626 Mdot
.70587 .68234 Mdot
.70979 .69018 Mdot
.71371 .69018 Mdot
.70587 .69018 Mdot
.71371 .69802 Mdot
.72155 .70587 Mdot
.72155 .70194 Mdot
.72939 .70194 Mdot
.72547 .70194 Mdot
.72939 .69802 Mdot
.72547 .67842 Mdot
.72939 .6745 Mdot
.74116 .6745 Mdot
.749 .67842 Mdot
.749 .6745 Mdot
.74508 .6745 Mdot
.74508 .66273 Mdot
.74508 .66273 Mdot
.749 .66273 Mdot
.73724 .65881 Mdot
.73332 .65097 Mdot
.73332 .64705 Mdot
.72939 .6392 Mdot
.86664 .8235 Mdot
.9333 .90585 Mdot
.46275 .54902 Mdot
.50196 .60391 Mdot
.51372 .6196 Mdot
.51765 .62744 Mdot
.51372 .62744 Mdot
.52549 .64313 Mdot
.52157 .6392 Mdot
.52157 .65097 Mdot
.52549 .65097 Mdot
.53725 .65489 Mdot
.53725 .64705 Mdot
.54902 .66665 Mdot
.54902 .66665 Mdot
.55686 .65881 Mdot
.56078 .66273 Mdot
.56862 .66665 Mdot
.56078 .66273 Mdot
.5647 .66665 Mdot
.5647 .68234 Mdot
.58039 .69018 Mdot
.59607 .69018 Mdot
.59215 .6941 Mdot
.59607 .70194 Mdot
.60783 .70979 Mdot
.61176 .71371 Mdot
.61176 .70587 Mdot
.61176 .70194 Mdot
.6196 .71371 Mdot
.62744 .71763 Mdot
.62744 .70587 Mdot
.63136 .69802 Mdot
.64313 .69802 Mdot
.65489 .6941 Mdot
.66273 .6941 Mdot
.67057 .70587 Mdot
.6745 .71371 Mdot
.6745 .71371 Mdot
.67842 .71763 Mdot
.67842 .71371 Mdot
.68234 .71371 Mdot
.68234 .70587 Mdot
.68626 .69802 Mdot
.69018 .6941 Mdot
.69802 .6941 Mdot
.70194 .70194 Mdot
.69802 .69802 Mdot
.69802 .70194 Mdot
.70194 .70194 Mdot
.69802 .6941 Mdot
.72155 .70587 Mdot
.72155 .70194 Mdot
.72155 .70194 Mdot
.72547 .70194 Mdot
.72547 .69018 Mdot
.72547 .6941 Mdot
.72939 .69802 Mdot
.73724 .70587 Mdot
.73332 .70587 Mdot
.73724 .71763 Mdot
.73332 .71371 Mdot
.73724 .70587 Mdot
.72155 .68234 Mdot
.72939 .67842 Mdot
.74116 .6745 Mdot
.749 .67057 Mdot
.749 .66665 Mdot
.75292 .65881 Mdot
.75684 .65489 Mdot
.74508 .65097 Mdot
.749 .65881 Mdot
.749 .65097 Mdot
.75292 .64705 Mdot
.74508 .6392 Mdot
.73332 .63136 Mdot
.72939 .6196 Mdot
.71371 .60391 Mdot
.86272 .80782 Mdot
.43922 .53333 Mdot
.49412 .59607 Mdot
.51372 .6196 Mdot
.52157 .62352 Mdot
.51765 .6196 Mdot
.52157 .62744 Mdot
.52549 .63136 Mdot
.52941 .63528 Mdot
.52549 .63528 Mdot
.52549 .62744 Mdot
.53333 .63528 Mdot
.54902 .64705 Mdot
.54902 .65489 Mdot
.55294 .66665 Mdot
.56078 .67057 Mdot
.56078 .65881 Mdot
.5647 .66665 Mdot
.58039 .6745 Mdot
.58431 .68234 Mdot
.58431 .68234 Mdot
.58823 .68234 Mdot
.60783 .6941 Mdot
.60783 .70194 Mdot
.60391 .69802 Mdot
.60391 .70194 Mdot
.61176 .70194 Mdot
.61176 .69802 Mdot
.60783 .69802 Mdot
.61176 .70194 Mdot
.6196 .70194 Mdot
.63528 .70587 Mdot
.64313 .70194 Mdot
.65097 .6941 Mdot
.65881 .69018 Mdot
.67057 .69802 Mdot
.6745 .71371 Mdot
.6745 .72155 Mdot
.6745 .71763 Mdot
.6745 .72155 Mdot
.67842 .71763 Mdot
.67842 .70979 Mdot
.69018 .70587 Mdot
.69018 .70194 Mdot
.69018 .69802 Mdot
.70587 .70194 Mdot
.70587 .70587 Mdot
.70587 .70979 Mdot
.71371 .70979 Mdot
.72155 .70979 Mdot
.72547 .70587 Mdot
.73332 .70979 Mdot
.73332 .71371 Mdot
.72547 .70979 Mdot
.72939 .70587 Mdot
.72155 .68626 Mdot
.72939 .68626 Mdot
.74116 .70194 Mdot
.74116 .70979 Mdot
.72939 .70587 Mdot
.74508 .71371 Mdot
.74508 .70194 Mdot
.74116 .69018 Mdot
.73724 .68234 Mdot
.74508 .67842 Mdot
.74508 .67057 Mdot
.74116 .65097 Mdot
.749 .64313 Mdot
.75684 .64705 Mdot
.74508 .64705 Mdot
.75684 .65881 Mdot
.749 .65097 Mdot
.75292 .64705 Mdot
.75684 .64705 Mdot
.74508 .6392 Mdot
.73724 .63528 Mdot
.73332 .63136 Mdot
.73724 .62744 Mdot
.73724 .62352 Mdot
.75292 .67842 Mdot
.81566 .76469 Mdot
.45098 .54902 Mdot
.50196 .60391 Mdot
.51372 .62744 Mdot
.52157 .63136 Mdot
.51765 .62744 Mdot
.51765 .6392 Mdot
.51372 .63528 Mdot
.52941 .64313 Mdot
.52941 .63528 Mdot
.52941 .63136 Mdot
.54902 .64705 Mdot
.55294 .65489 Mdot
.55686 .66273 Mdot
.55686 .65881 Mdot
.5647 .67842 Mdot
.57646 .68626 Mdot
.58431 .68234 Mdot
.58823 .68626 Mdot
.59215 .68626 Mdot
.58823 .68234 Mdot
.59999 .68234 Mdot
.60391 .68234 Mdot
.60391 .6941 Mdot
.61176 .70979 Mdot
.60783 .70979 Mdot
.61568 .70587 Mdot
.61568 .70979 Mdot
.62744 .71763 Mdot
.6196 .70587 Mdot
.61568 .6941 Mdot
.63136 .6941 Mdot
.63528 .69018 Mdot
.64705 .69018 Mdot
.66665 .69802 Mdot
.66273 .69018 Mdot
.67842 .70194 Mdot
.67057 .70587 Mdot
.67842 .72155 Mdot
.68234 .73332 Mdot
.68234 .73332 Mdot
.68626 .73332 Mdot
.69018 .72939 Mdot
.69018 .71763 Mdot
.69802 .72155 Mdot
.70587 .71371 Mdot
.70587 .70194 Mdot
.70587 .70194 Mdot
.71371 .72155 Mdot
.72939 .73332 Mdot
.72939 .71763 Mdot
.74116 .72547 Mdot
.72939 .71763 Mdot
.72939 .70587 Mdot
.72547 .70194 Mdot
.72939 .70194 Mdot
.72939 .6941 Mdot
.749 .70587 Mdot
.749 .70587 Mdot
.74508 .70587 Mdot
.75684 .70979 Mdot
.75684 .69802 Mdot
.749 .68234 Mdot
.75292 .69018 Mdot
.749 .68626 Mdot
.74508 .67057 Mdot
.74508 .65881 Mdot
.75292 .65489 Mdot
.75684 .65489 Mdot
.74116 .64705 Mdot
.749 .65881 Mdot
.74508 .65489 Mdot
.74508 .65489 Mdot
.75292 .66273 Mdot
.75292 .65097 Mdot
.74116 .63528 Mdot
.75684 .64705 Mdot
.75684 .64705 Mdot
.749 .64313 Mdot
.74508 .63528 Mdot
.74116 .63528 Mdot
.72547 .62744 Mdot
.80782 .73724 Mdot
.93722 .91369 Mdot
.47843 .55686 Mdot
.52549 .61176 Mdot
.53725 .6392 Mdot
.53333 .64313 Mdot
.52157 .6392 Mdot
.52549 .65489 Mdot
.52157 .65489 Mdot
.52549 .65489 Mdot
.52941 .65881 Mdot
.52941 .64313 Mdot
.53333 .64313 Mdot
.55294 .65881 Mdot
.55294 .67057 Mdot
.55686 .67057 Mdot
.55294 .67842 Mdot
.56078 .67842 Mdot
.5647 .67842 Mdot
.57646 .68626 Mdot
.58039 .67842 Mdot
.57646 .6745 Mdot
.59215 .68234 Mdot
.59999 .68626 Mdot
.60391 .69018 Mdot
.60783 .70194 Mdot
.62352 .70587 Mdot
.6196 .69802 Mdot
.62352 .70194 Mdot
.62352 .70194 Mdot
.62744 .70587 Mdot
.63136 .6941 Mdot
.63136 .6941 Mdot
.6392 .70587 Mdot
.6392 .69802 Mdot
.64705 .69018 Mdot
.65097 .68626 Mdot
.66665 .69018 Mdot
.68234 .70587 Mdot
.68626 .71371 Mdot
.68234 .71763 Mdot
.68626 .71763 Mdot
.68626 .71763 Mdot
.68234 .70979 Mdot
.69018 .71763 Mdot
.69018 .71763 Mdot
.69018 .71763 Mdot
.69018 .71371 Mdot
.69802 .71371 Mdot
.70979 .72155 Mdot
.72155 .73332 Mdot
.71371 .72155 Mdot
.71763 .72939 Mdot
.73332 .73332 Mdot
.73332 .72155 Mdot
.72547 .71371 Mdot
.72547 .70587 Mdot
.72939 .70194 Mdot
.73332 .70194 Mdot
.74508 .70979 Mdot
.75292 .71763 Mdot
.73724 .69802 Mdot
.74116 .69018 Mdot
.75684 .69802 Mdot
.75292 .69018 Mdot
.749 .68626 Mdot
.73332 .67057 Mdot
.73332 .66665 Mdot
.749 .66665 Mdot
.74508 .66273 Mdot
.73724 .65881 Mdot
.74116 .65881 Mdot
.74116 .65489 Mdot
.74508 .65881 Mdot
.75684 .66273 Mdot
.75684 .65881 Mdot
.75684 .65097 Mdot
.76076 .65881 Mdot
.75684 .65097 Mdot
.75292 .65097 Mdot
.74508 .6392 Mdot
.75292 .64705 Mdot
.749 .65489 Mdot
.74508 .65489 Mdot
.74116 .65097 Mdot
.72939 .64313 Mdot
.84311 .79998 Mdot
.90193 .88232 Mdot
.4902 .57254 Mdot
.51765 .6196 Mdot
.52941 .6392 Mdot
.52941 .64313 Mdot
.52941 .65489 Mdot
.53725 .6745 Mdot
.53725 .68234 Mdot
.52941 .6745 Mdot
.53725 .66273 Mdot
.53333 .64313 Mdot
.53725 .6392 Mdot
.54117 .64313 Mdot
.54117 .65489 Mdot
.54902 .65881 Mdot
.55294 .66273 Mdot
.55686 .66665 Mdot
.56862 .6745 Mdot
.56862 .68234 Mdot
.57254 .67842 Mdot
.57254 .6745 Mdot
.58823 .68626 Mdot
.59215 .68234 Mdot
.60391 .68626 Mdot
.60391 .6941 Mdot
.59999 .69018 Mdot
.61568 .69802 Mdot
.6196 .6941 Mdot
.62744 .69802 Mdot
.63136 .6941 Mdot
.62352 .68626 Mdot
.63136 .6941 Mdot
.64313 .70587 Mdot
.64705 .70587 Mdot
.64313 .70587 Mdot
.64705 .69802 Mdot
.65881 .69802 Mdot
.67057 .70979 Mdot
.6745 .71371 Mdot
.67842 .71371 Mdot
.68234 .71371 Mdot
.6745 .70979 Mdot
.67057 .70587 Mdot
.68234 .71371 Mdot
.6941 .72939 Mdot
.69018 .72547 Mdot
.69018 .72155 Mdot
.6941 .71763 Mdot
.70194 .72939 Mdot
.70194 .72547 Mdot
.70979 .72547 Mdot
.71371 .72547 Mdot
.72939 .72547 Mdot
.73332 .72547 Mdot
.72939 .71371 Mdot
.72939 .72155 Mdot
.73332 .72155 Mdot
.73332 .72155 Mdot
.73332 .72155 Mdot
.72547 .71763 Mdot
.72939 .71371 Mdot
.73332 .70194 Mdot
.74116 .70194 Mdot
.74116 .6941 Mdot
.74508 .6941 Mdot
.74508 .68626 Mdot
.74508 .67842 Mdot
.749 .68234 Mdot
.749 .67842 Mdot
.749 .68234 Mdot
.749 .68626 Mdot
.75684 .69018 Mdot
.75292 .67842 Mdot
.74508 .67057 Mdot
.75292 .66665 Mdot
.75292 .66665 Mdot
.75684 .65881 Mdot
.75684 .65489 Mdot
.75292 .65881 Mdot
.74508 .65489 Mdot
.749 .66273 Mdot
.74508 .66665 Mdot
.749 .66665 Mdot
.75292 .66273 Mdot
.74116 .65881 Mdot
.73332 .65489 Mdot
.71371 .64313 Mdot
.72155 .65097 Mdot
.86272 .82743 Mdot
.5098 .58431 Mdot
.52549 .62744 Mdot
.53725 .65881 Mdot
.52941 .66665 Mdot
.53333 .6745 Mdot
.52549 .6745 Mdot
.51372 .66273 Mdot
.51372 .66273 Mdot
.52941 .66273 Mdot
.53725 .65881 Mdot
.54117 .65489 Mdot
.54902 .66273 Mdot
.55294 .66665 Mdot
.55686 .67057 Mdot
.55686 .6745 Mdot
.57254 .67842 Mdot
.56862 .67057 Mdot
.58039 .68234 Mdot
.58039 .69018 Mdot
.58823 .69802 Mdot
.58431 .68234 Mdot
.60391 .68626 Mdot
.59999 .67842 Mdot
.60783 .67842 Mdot
.59999 .68234 Mdot
.59215 .67842 Mdot
.61176 .69018 Mdot
.6196 .6941 Mdot
.63136 .6941 Mdot
.63528 .70194 Mdot
.63136 .6941 Mdot
.6392 .70194 Mdot
.6392 .69018 Mdot
.64313 .69802 Mdot
.65097 .69802 Mdot
.65489 .69802 Mdot
.66273 .70587 Mdot
.66665 .70587 Mdot
.66665 .70194 Mdot
.68234 .71371 Mdot
.69018 .73332 Mdot
.68626 .72939 Mdot
.68234 .72155 Mdot
.67842 .71763 Mdot
.68234 .72547 Mdot
.6941 .73332 Mdot
.70194 .73724 Mdot
.70979 .73724 Mdot
.70979 .74116 Mdot
.71763 .74116 Mdot
.72155 .73724 Mdot
.73332 .74116 Mdot
.73332 .74116 Mdot
.73724 .73724 Mdot
.73332 .72939 Mdot
.73724 .73332 Mdot
.72939 .72939 Mdot
.73724 .73724 Mdot
.73724 .72939 Mdot
.73332 .71763 Mdot
.72547 .69802 Mdot
.73332 .70194 Mdot
.73724 .69802 Mdot
.74116 .70194 Mdot
.74116 .70194 Mdot
.75292 .71371 Mdot
.75684 .70979 Mdot
.75292 .70587 Mdot
.749 .70587 Mdot
.74508 .69802 Mdot
.75684 .69802 Mdot
.76469 .69802 Mdot
.76469 .69018 Mdot
.76469 .69018 Mdot
.75684 .6745 Mdot
.76469 .67842 Mdot
.75684 .66273 Mdot
.76076 .6745 Mdot
.76076 .68234 Mdot
.75684 .68626 Mdot
.75292 .67842 Mdot
.75292 .6745 Mdot
.749 .66665 Mdot
.75684 .6745 Mdot
.75292 .6745 Mdot
.74116 .66665 Mdot
.73332 .65881 Mdot
.73332 .65881 Mdot
.72155 .65097 Mdot
.78429 .72547 Mdot
.84311 .81174 Mdot
.49412 .58431 Mdot
.51765 .63136 Mdot
.52549 .65489 Mdot
.51765 .66665 Mdot
.51372 .6745 Mdot
.51765 .67057 Mdot
.51372 .66665 Mdot
.52157 .66273 Mdot
.52549 .66665 Mdot
.52549 .65881 Mdot
.53333 .65881 Mdot
.54509 .66665 Mdot
.55686 .6745 Mdot
.57254 .68626 Mdot
.56862 .67842 Mdot
.57254 .67842 Mdot
.58039 .67842 Mdot
.59215 .6941 Mdot
.59999 .70194 Mdot
.59607 .70194 Mdot
.59607 .70194 Mdot
.59607 .69018 Mdot
.60391 .68626 Mdot
.60391 .68234 Mdot
.6196 .6941 Mdot
.61176 .69018 Mdot
.60783 .68626 Mdot
.61568 .69018 Mdot
.62744 .69802 Mdot
.62744 .69802 Mdot
.62352 .69802 Mdot
.62744 .70194 Mdot
.6392 .70979 Mdot
.64313 .70979 Mdot
.65489 .71371 Mdot
.65881 .70979 Mdot
.66665 .71763 Mdot
.67057 .71763 Mdot
.66665 .70979 Mdot
.67842 .71371 Mdot
.67842 .71763 Mdot
.69018 .72939 Mdot
.6941 .74508 Mdot
.69018 .73724 Mdot
.68626 .71763 Mdot
.6941 .72155 Mdot
.70979 .73332 Mdot
.71763 .73724 Mdot
.71763 .73332 Mdot
.72939 .74508 Mdot
.73332 .75684 Mdot
.74116 .76469 Mdot
.73724 .76469 Mdot
.73724 .75684 Mdot
.73724 .75292 Mdot
.73724 .749 Mdot
.72939 .73724 Mdot
.73332 .74116 Mdot
.72939 .73332 Mdot
.74116 .72939 Mdot
.749 .72547 Mdot
.74508 .71371 Mdot
.74508 .70979 Mdot
.75292 .71763 Mdot
.75292 .71763 Mdot
.749 .71371 Mdot
.75292 .71763 Mdot
.75684 .72155 Mdot
.75684 .72547 Mdot
.749 .72155 Mdot
.75292 .71763 Mdot
.75684 .71371 Mdot
.76469 .70587 Mdot
.77253 .70587 Mdot
.76469 .6941 Mdot
.77253 .68626 Mdot
.76076 .67842 Mdot
.76076 .68626 Mdot
.76469 .6941 Mdot
.76469 .6941 Mdot
.76469 .69802 Mdot
.75684 .68626 Mdot
.75684 .67842 Mdot
.75684 .67842 Mdot
.75684 .68234 Mdot
.75684 .69018 Mdot
.75292 .68626 Mdot
.74508 .6745 Mdot
.74508 .67842 Mdot
.73724 .67057 Mdot
.73332 .66665 Mdot
.71763 .65097 Mdot
.77645 .72547 Mdot
.92546 .90977 Mdot
.47843 .58039 Mdot
.5098 .63136 Mdot
.52941 .66273 Mdot
.52549 .66273 Mdot
.51372 .67057 Mdot
.5098 .66665 Mdot
.51765 .66665 Mdot
.52549 .67057 Mdot
.52549 .6745 Mdot
.53333 .67842 Mdot
.54117 .68626 Mdot
.55294 .68626 Mdot
.55686 .69018 Mdot
.56862 .68626 Mdot
.57254 .68234 Mdot
.58431 .68626 Mdot
.58039 .68626 Mdot
.58823 .6941 Mdot
.58823 .6941 Mdot
.58823 .6941 Mdot
.59999 .69802 Mdot
.59607 .68626 Mdot
.59999 .68626 Mdot
.60783 .68626 Mdot
.6196 .6941 Mdot
.61176 .69018 Mdot
.62744 .69802 Mdot
.6196 .6941 Mdot
.63528 .70587 Mdot
.6392 .71371 Mdot
.65097 .71763 Mdot
.6392 .71763 Mdot
.64313 .73332 Mdot
.64705 .74116 Mdot
.64705 .72939 Mdot
.64313 .71763 Mdot
.65097 .72155 Mdot
.65489 .72155 Mdot
.66273 .72547 Mdot
.67057 .72939 Mdot
.6745 .72155 Mdot
.68626 .72939 Mdot
.67842 .72939 Mdot
.69018 .74508 Mdot
.69018 .73724 Mdot
.6941 .73724 Mdot
.70587 .74116 Mdot
.71371 .74508 Mdot
.71371 .74116 Mdot
.71763 .74508 Mdot
.72155 .75684 Mdot
.73332 .76076 Mdot
.74116 .76076 Mdot
.73332 .75292 Mdot
.73332 .75292 Mdot
.72939 .74508 Mdot
.72939 .73724 Mdot
.74116 .73724 Mdot
.73724 .72547 Mdot
.749 .72547 Mdot
.76076 .72939 Mdot
.74116 .70979 Mdot
.74508 .70194 Mdot
.74508 .70194 Mdot
.74116 .69802 Mdot
.74508 .70587 Mdot
.74508 .71371 Mdot
.75292 .72155 Mdot
.75292 .72547 Mdot
.75684 .72547 Mdot
.75684 .71371 Mdot
.74508 .70194 Mdot
.75684 .70194 Mdot
.77253 .69802 Mdot
.77253 .68626 Mdot
.76861 .6745 Mdot
.76861 .6745 Mdot
.77253 .69018 Mdot
.76861 .6941 Mdot
.77253 .70194 Mdot
.76861 .69802 Mdot
.76469 .69018 Mdot
.76076 .68234 Mdot
.76469 .67842 Mdot
.76861 .68234 Mdot
.76469 .68234 Mdot
.76469 .68626 Mdot
.74508 .68234 Mdot
.74116 .67842 Mdot
.749 .68234 Mdot
.74508 .6745 Mdot
.74116 .66665 Mdot
.73332 .66665 Mdot
.72939 .65881 Mdot
.72547 .65097 Mdot
.8588 .8235 Mdot
.92546 .90977 Mdot
.4902 .56862 Mdot
.50588 .60783 Mdot
.52157 .6392 Mdot
.52549 .65489 Mdot
.51372 .65097 Mdot
.53333 .66665 Mdot
.53333 .66665 Mdot
.53725 .68234 Mdot
.52157 .68234 Mdot
.52549 .68234 Mdot
.53333 .69018 Mdot
.54117 .69802 Mdot
.54902 .68626 Mdot
.56862 .69018 Mdot
.57254 .68626 Mdot
.57254 .68234 Mdot
.58039 .69018 Mdot
.58039 .69802 Mdot
.58039 .6941 Mdot
.58431 .69802 Mdot
.59215 .70194 Mdot
.60783 .70979 Mdot
.61568 .71371 Mdot
.61568 .71763 Mdot
.60783 .70979 Mdot
.61176 .70587 Mdot
.62744 .69802 Mdot
.63136 .69802 Mdot
.63528 .70194 Mdot
.6392 .70587 Mdot
.6392 .71371 Mdot
.6392 .71763 Mdot
.63528 .72547 Mdot
.64313 .74116 Mdot
.64313 .74116 Mdot
.64705 .73724 Mdot
.65097 .73724 Mdot
.65881 .74116 Mdot
.65489 .73724 Mdot
.66273 .74116 Mdot
.6745 .74116 Mdot
.67842 .74116 Mdot
.68234 .74508 Mdot
.67842 .74508 Mdot
.69018 .75684 Mdot
.6941 .75292 Mdot
.70194 .74508 Mdot
.70979 .749 Mdot
.70979 .75292 Mdot
.72155 .76076 Mdot
.71371 .76076 Mdot
.72155 .75684 Mdot
.70587 .74116 Mdot
.71371 .749 Mdot
.72939 .75684 Mdot
.72547 .749 Mdot
.72155 .74116 Mdot
.74116 .74508 Mdot
.72547 .72547 Mdot
.73332 .72155 Mdot
.74508 .72155 Mdot
.74508 .71763 Mdot
.749 .72155 Mdot
.75684 .71371 Mdot
.749 .70587 Mdot
.75292 .71371 Mdot
.74508 .71371 Mdot
.749 .71763 Mdot
.75292 .72155 Mdot
.75684 .72939 Mdot
.75684 .72939 Mdot
.76076 .71371 Mdot
.76861 .69802 Mdot
.76861 .69018 Mdot
.77253 .68626 Mdot
.77253 .67842 Mdot
.77645 .68234 Mdot
.76469 .67842 Mdot
.77253 .6941 Mdot
.77645 .70979 Mdot
.77253 .70979 Mdot
.77645 .70587 Mdot
.77253 .6941 Mdot
.76861 .68626 Mdot
.77253 .68626 Mdot
.77645 .6941 Mdot
.77645 .70194 Mdot
.76469 .70194 Mdot
.76076 .70587 Mdot
.75292 .6941 Mdot
.75292 .69018 Mdot
.749 .67842 Mdot
.74508 .66273 Mdot
.74508 .66273 Mdot
.74508 .65489 Mdot
.72939 .65097 Mdot
.71371 .65097 Mdot
.65881 .60391 Mdot
.84311 .81566 Mdot
.47843 .56078 Mdot
.5098 .60783 Mdot
.51372 .63136 Mdot
.52157 .65097 Mdot
.52157 .64705 Mdot
.52941 .65097 Mdot
.53725 .65489 Mdot
.52941 .65881 Mdot
.52157 .66665 Mdot
.52549 .67057 Mdot
.53725 .68234 Mdot
.54117 .68626 Mdot
.54509 .67842 Mdot
.54902 .67842 Mdot
.55294 .67842 Mdot
.56078 .68234 Mdot
.5647 .68234 Mdot
.56862 .69802 Mdot
.56862 .6941 Mdot
.56862 .6941 Mdot
.59607 .70587 Mdot
.60391 .70979 Mdot
.59999 .70979 Mdot
.60391 .71371 Mdot
.60391 .72155 Mdot
.61568 .72155 Mdot
.6196 .71371 Mdot
.62744 .70979 Mdot
.63136 .70587 Mdot
.62744 .71371 Mdot
.62744 .71371 Mdot
.63528 .70979 Mdot
.6392 .72155 Mdot
.65097 .74116 Mdot
.65097 .74116 Mdot
.64705 .74508 Mdot
.64705 .749 Mdot
.65097 .749 Mdot
.65097 .749 Mdot
.66665 .75292 Mdot
.6745 .749 Mdot
.68626 .75292 Mdot
.68626 .75292 Mdot
.69802 .76076 Mdot
.69018 .76076 Mdot
.69802 .76469 Mdot
.69018 .75292 Mdot
.70194 .75684 Mdot
.70979 .76076 Mdot
.71371 .76076 Mdot
.70979 .75684 Mdot
.71371 .75292 Mdot
.72155 .749 Mdot
.71371 .73724 Mdot
.70587 .72939 Mdot
.71371 .73724 Mdot
.70979 .73332 Mdot
.72155 .74116 Mdot
.72547 .73332 Mdot
.73332 .72547 Mdot
.74508 .72547 Mdot
.74508 .72547 Mdot
.75292 .74116 Mdot
.75684 .74508 Mdot
.74508 .72939 Mdot
.749 .72547 Mdot
.74508 .72939 Mdot
.74508 .72547 Mdot
.75684 .73332 Mdot
.75292 .72939 Mdot
.75292 .72939 Mdot
.76469 .72547 Mdot
.78037 .72547 Mdot
.76861 .70194 Mdot
.76076 .69018 Mdot
.77253 .68626 Mdot
.77253 .6745 Mdot
.77645 .68234 Mdot
.77253 .6941 Mdot
.77253 .69802 Mdot
.77253 .69802 Mdot
.76076 .69802 Mdot
.77645 .70587 Mdot
.76469 .69802 Mdot
.76469 .69802 Mdot
.76076 .6941 Mdot
.76861 .6941 Mdot
.76469 .69802 Mdot
.77253 .71371 Mdot
.76076 .70194 Mdot
.76076 .69018 Mdot
.75684 .68234 Mdot
.75292 .6745 Mdot
.749 .66273 Mdot
.75292 .66273 Mdot
.74116 .66273 Mdot
.73332 .66665 Mdot
.72547 .66273 Mdot
.70979 .65489 Mdot
.70194 .65881 Mdot
.77253 .74116 Mdot
.79998 .78429 Mdot
.47059 .57254 Mdot
.51372 .62744 Mdot
.52549 .65489 Mdot
.51765 .65489 Mdot
.52157 .65881 Mdot
.52157 .65097 Mdot
.52549 .65097 Mdot
.52549 .65881 Mdot
.51765 .66665 Mdot
.52941 .6745 Mdot
.53333 .67057 Mdot
.53725 .67057 Mdot
.53725 .6745 Mdot
.54117 .6745 Mdot
.54117 .66665 Mdot
.54509 .66665 Mdot
.55294 .6745 Mdot
.5647 .6941 Mdot
.56862 .70194 Mdot
.57646 .71371 Mdot
.58823 .71371 Mdot
.59607 .71371 Mdot
.60783 .71763 Mdot
.59999 .70979 Mdot
.60783 .71763 Mdot
.61176 .71763 Mdot
.61176 .71371 Mdot
.61568 .71371 Mdot
.6196 .71763 Mdot
.6196 .71763 Mdot
.62744 .72155 Mdot
.63528 .72155 Mdot
.65097 .72939 Mdot
.65489 .73332 Mdot
.65097 .73332 Mdot
.64705 .72939 Mdot
.65097 .74116 Mdot
.64705 .74116 Mdot
.65489 .74116 Mdot
.66273 .74508 Mdot
.66665 .74508 Mdot
.67842 .75292 Mdot
.68234 .749 Mdot
.68234 .74508 Mdot
.68234 .74508 Mdot
.68626 .75292 Mdot
.68234 .74508 Mdot
.68626 .749 Mdot
.69018 .75292 Mdot
.6941 .75292 Mdot
.70194 .75292 Mdot
.70587 .74508 Mdot
.70979 .749 Mdot
.71371 .749 Mdot
.71371 .749 Mdot
.71371 .74508 Mdot
.71371 .74116 Mdot
.72155 .73332 Mdot
.72547 .73332 Mdot
.73332 .72939 Mdot
.73332 .72547 Mdot
.73332 .72939 Mdot
.74508 .74116 Mdot
.749 .74508 Mdot
.75292 .74508 Mdot
.75684 .74508 Mdot
.75292 .74508 Mdot
.74508 .74116 Mdot
.74116 .73332 Mdot
.75292 .73724 Mdot
.749 .72547 Mdot
.749 .71371 Mdot
.74116 .6941 Mdot
.75292 .69802 Mdot
.75292 .69802 Mdot
.75292 .69018 Mdot
.76469 .68626 Mdot
.76469 .68626 Mdot
.76861 .6941 Mdot
.75684 .6941 Mdot
.76469 .70194 Mdot
.75684 .70194 Mdot
.76076 .70587 Mdot
.76469 .70194 Mdot
.75684 .70194 Mdot
.76076 .69802 Mdot
.76861 .70587 Mdot
.75684 .70194 Mdot
.76861 .71371 Mdot
.76469 .70587 Mdot
.75684 .6941 Mdot
.76076 .6941 Mdot
.75292 .6941 Mdot
.74508 .67842 Mdot
.74508 .6745 Mdot
.74116 .66665 Mdot
.74508 .68234 Mdot
.73724 .67842 Mdot
.71371 .65881 Mdot
.70979 .66273 Mdot
.71371 .66273 Mdot
.70979 .65881 Mdot
.70194 .65097 Mdot
.749 .71763 Mdot
.91761 .90585 Mdot
.49804 .59999 Mdot
.51372 .62744 Mdot
.52549 .65097 Mdot
.52157 .65881 Mdot
.52941 .67057 Mdot
.52941 .67057 Mdot
.51372 .65881 Mdot
.52157 .67057 Mdot
.52549 .66665 Mdot
.52549 .66273 Mdot
.52549 .65489 Mdot
.52941 .65881 Mdot
.54117 .6745 Mdot
.54902 .67842 Mdot
.55686 .68626 Mdot
.56078 .68626 Mdot
.56862 .6941 Mdot
.56862 .69802 Mdot
.57646 .70979 Mdot
.58431 .71763 Mdot
.58431 .71371 Mdot
.58823 .70979 Mdot
.59607 .70979 Mdot
.61176 .72939 Mdot
.60391 .72155 Mdot
.60783 .71763 Mdot
.61176 .71371 Mdot
.6196 .71371 Mdot
.63528 .71763 Mdot
.63528 .71371 Mdot
.6392 .72547 Mdot
.64313 .72939 Mdot
.64705 .73332 Mdot
.65881 .73332 Mdot
.66273 .73332 Mdot
.65881 .73332 Mdot
.65881 .73332 Mdot
.65881 .73724 Mdot
.65489 .73724 Mdot
.6745 .749 Mdot
.6745 .74508 Mdot
.67842 .749 Mdot
.6745 .76469 Mdot
.6745 .76076 Mdot
.67842 .749 Mdot
.67842 .74508 Mdot
.68626 .75292 Mdot
.6941 .76076 Mdot
.69802 .75292 Mdot
.6941 .749 Mdot
.70587 .75292 Mdot
.70979 .75292 Mdot
.71371 .75684 Mdot
.71371 .76076 Mdot
.70587 .75684 Mdot
.70587 .75292 Mdot
.71371 .75292 Mdot
.72939 .76076 Mdot
.72939 .75292 Mdot
.73332 .749 Mdot
.73724 .749 Mdot
.73724 .74116 Mdot
.74116 .74116 Mdot
.73724 .73724 Mdot
.73332 .73724 Mdot
.73332 .73724 Mdot
.72547 .73724 Mdot
.74508 .75292 Mdot
.74508 .74508 Mdot
.74116 .74116 Mdot
.73724 .73724 Mdot
.749 .73724 Mdot
.749 .72155 Mdot
.74508 .70979 Mdot
.74116 .70979 Mdot
.75292 .71371 Mdot
.75292 .6941 Mdot
.76076 .70194 Mdot
.75684 .6941 Mdot
.75292 .6941 Mdot
.76076 .70194 Mdot
.76469 .70194 Mdot
.76076 .70194 Mdot
.76861 .70587 Mdot
.77645 .71371 Mdot
.77253 .71371 Mdot
.75684 .70587 Mdot
.76076 .70587 Mdot
.76861 .70979 Mdot
.76861 .71371 Mdot
.76076 .70587 Mdot
.75684 .70587 Mdot
.749 .69802 Mdot
.75684 .69018 Mdot
.749 .69018 Mdot
.749 .68626 Mdot
.74508 .68234 Mdot
.74508 .68234 Mdot
.74116 .67842 Mdot
.73332 .67057 Mdot
.73332 .67057 Mdot
.73332 .67057 Mdot
.72939 .6745 Mdot
.70979 .66273 Mdot
.70979 .66665 Mdot
.6941 .64313 Mdot
.83135 .80782 Mdot
.90193 .89017 Mdot
.47843 .59215 Mdot
.51372 .63136 Mdot
.52157 .65881 Mdot
.52157 .67842 Mdot
.52549 .67842 Mdot
.52549 .68234 Mdot
.52549 .67842 Mdot
.53333 .6745 Mdot
.52157 .65881 Mdot
.53725 .67057 Mdot
.53725 .67842 Mdot
.53725 .67057 Mdot
.54509 .6745 Mdot
.55686 .67842 Mdot
.5647 .69018 Mdot
.56078 .68626 Mdot
.5647 .6941 Mdot
.57646 .70587 Mdot
.58039 .71763 Mdot
.58039 .72155 Mdot
.58039 .71371 Mdot
.59215 .71371 Mdot
.59215 .70979 Mdot
.60391 .72155 Mdot
.61176 .72547 Mdot
.61568 .71763 Mdot
.62352 .72155 Mdot
.62352 .71763 Mdot
.6392 .72155 Mdot
.65097 .72939 Mdot
.65097 .73332 Mdot
.64313 .72939 Mdot
.65489 .73724 Mdot
.66273 .74116 Mdot
.66273 .73332 Mdot
.66665 .74116 Mdot
.67057 .75292 Mdot
.67057 .75292 Mdot
.66665 .749 Mdot
.67057 .75292 Mdot
.6745 .75292 Mdot
.67842 .76076 Mdot
.66665 .749 Mdot
.67842 .76861 Mdot
.68626 .76861 Mdot
.68234 .76076 Mdot
.68626 .75292 Mdot
.69802 .76469 Mdot
.70194 .75684 Mdot
.70587 .75292 Mdot
.70979 .76076 Mdot
.71371 .76076 Mdot
.72547 .77253 Mdot
.71763 .77253 Mdot
.71763 .77253 Mdot
.72547 .78037 Mdot
.72547 .76861 Mdot
.73724 .76861 Mdot
.72547 .75292 Mdot
.72155 .75292 Mdot
.72155 .74508 Mdot
.72939 .74116 Mdot
.73332 .74116 Mdot
.73332 .73724 Mdot
.73332 .72939 Mdot
.73332 .73724 Mdot
.74116 .74116 Mdot
.749 .75292 Mdot
.75292 .76076 Mdot
.75684 .76076 Mdot
.75684 .76076 Mdot
.76469 .77253 Mdot
.749 .749 Mdot
.75684 .74116 Mdot
.76469 .74508 Mdot
.76076 .74508 Mdot
.75684 .72547 Mdot
.76469 .72939 Mdot
.76469 .71371 Mdot
.76861 .70979 Mdot
.77253 .71371 Mdot
.76861 .70979 Mdot
.76469 .70979 Mdot
.76076 .71371 Mdot
.76076 .71763 Mdot
.76469 .72939 Mdot
.75684 .72547 Mdot
.76076 .72547 Mdot
.76076 .72155 Mdot
.76076 .72547 Mdot
.749 .71763 Mdot
.75684 .71763 Mdot
.75292 .71371 Mdot
.76469 .70979 Mdot
.76469 .70979 Mdot
.76076 .70979 Mdot
.75684 .71371 Mdot
.75292 .70194 Mdot
.76076 .69802 Mdot
.76076 .6941 Mdot
.75684 .6941 Mdot
.749 .68626 Mdot
.749 .68626 Mdot
.74508 .68234 Mdot
.74116 .6941 Mdot
.73332 .69018 Mdot
.71763 .67842 Mdot
.70587 .66665 Mdot
.66665 .62352 Mdot
.82743 .81174 Mdot
.47059 .58823 Mdot
.50196 .63528 Mdot
.51765 .66665 Mdot
.51765 .67842 Mdot
.51372 .68234 Mdot
.52941 .6941 Mdot
.52157 .6745 Mdot
.52549 .66273 Mdot
.52157 .65489 Mdot
.52941 .65881 Mdot
.54902 .6745 Mdot
.54902 .67057 Mdot
.54902 .66665 Mdot
.55686 .67057 Mdot
.57254 .69018 Mdot
.56862 .69018 Mdot
.56078 .69018 Mdot
.56078 .69802 Mdot
.56078 .70194 Mdot
.56862 .70587 Mdot
.57646 .70194 Mdot
.58431 .69802 Mdot
.59607 .70587 Mdot
.59607 .69802 Mdot
.60783 .71371 Mdot
.60783 .71371 Mdot
.61176 .70979 Mdot
.62352 .70979 Mdot
.63136 .71763 Mdot
.63528 .72939 Mdot
.65097 .73332 Mdot
.63528 .71763 Mdot
.64705 .72547 Mdot
.65881 .73332 Mdot
.66273 .73332 Mdot
.66665 .73724 Mdot
.66665 .74116 Mdot
.6745 .749 Mdot
.6745 .75292 Mdot
.67057 .75684 Mdot
.6745 .749 Mdot
.66665 .73724 Mdot
.66665 .74116 Mdot
.67842 .749 Mdot
.6941 .75684 Mdot
.69802 .76469 Mdot
.70587 .76861 Mdot
.70979 .76469 Mdot
.70587 .76469 Mdot
.70979 .76469 Mdot
.71763 .76469 Mdot
.71763 .76076 Mdot
.72155 .76861 Mdot
.71371 .76469 Mdot
.72155 .76861 Mdot
.72939 .76469 Mdot
.72939 .76469 Mdot
.73332 .76076 Mdot
.73332 .75292 Mdot
.73332 .75292 Mdot
.73332 .75684 Mdot
.73332 .75684 Mdot
.73724 .75684 Mdot
.74116 .75292 Mdot
.72939 .72939 Mdot
.749 .73332 Mdot
.74116 .72547 Mdot
.75292 .74116 Mdot
.749 .74116 Mdot
.749 .74116 Mdot
.749 .749 Mdot
.75292 .75684 Mdot
.749 .749 Mdot
.76469 .74508 Mdot
.75684 .73724 Mdot
.75292 .72939 Mdot
.75684 .72939 Mdot
.75292 .71371 Mdot
.75684 .70979 Mdot
.76861 .70587 Mdot
.77253 .71371 Mdot
.77645 .72547 Mdot
.76469 .72155 Mdot
.76076 .72155 Mdot
.75684 .72939 Mdot
.75684 .73724 Mdot
.75684 .74116 Mdot
.75684 .73724 Mdot
.75684 .72939 Mdot
.76469 .72939 Mdot
.75684 .72155 Mdot
.75684 .71371 Mdot
.76469 .70194 Mdot
.76861 .70194 Mdot
.77253 .71371 Mdot
.77253 .71763 Mdot
.76469 .72155 Mdot
.76469 .71763 Mdot
.76861 .70979 Mdot
.76076 .69802 Mdot
.75684 .69802 Mdot
.75292 .69018 Mdot
.75292 .69018 Mdot
.749 .6941 Mdot
.74508 .70194 Mdot
.73724 .6941 Mdot
.73332 .69018 Mdot
.72155 .68234 Mdot
.71371 .68234 Mdot
.70979 .67842 Mdot
.65881 .62744 Mdot
.72155 .69802 Mdot
.77645 .76861 Mdot
.47451 .58823 Mdot
.50588 .63528 Mdot
.52549 .65881 Mdot
.52549 .67842 Mdot
.50196 .66665 Mdot
.50588 .66665 Mdot
.50196 .65097 Mdot
.51372 .65097 Mdot
.52549 .64705 Mdot
.53725 .65097 Mdot
.53725 .65489 Mdot
.53725 .65881 Mdot
.53725 .66273 Mdot
.54117 .67057 Mdot
.55294 .6745 Mdot
.56078 .67842 Mdot
.57646 .69018 Mdot
.56078 .69018 Mdot
.5647 .69802 Mdot
.5647 .70194 Mdot
.57646 .70587 Mdot
.58431 .69802 Mdot
.58431 .69018 Mdot
.59607 .70587 Mdot
.59607 .71763 Mdot
.59215 .70979 Mdot
.60783 .71371 Mdot
.62352 .71763 Mdot
.62744 .72155 Mdot
.62744 .71763 Mdot
.63136 .72155 Mdot
.63136 .71763 Mdot
.64313 .72155 Mdot
.65097 .72547 Mdot
.65881 .72939 Mdot
.66273 .72939 Mdot
.65881 .73724 Mdot
.65489 .74508 Mdot
.65489 .74116 Mdot
.66665 .749 Mdot
.66665 .749 Mdot
.67057 .749 Mdot
.67842 .749 Mdot
.68234 .74116 Mdot
.6941 .74116 Mdot
.6941 .73724 Mdot
.70194 .75684 Mdot
.70587 .76076 Mdot
.70194 .75684 Mdot
.70587 .76076 Mdot
.71371 .76076 Mdot
.71763 .75292 Mdot
.72155 .76469 Mdot
.71371 .76076 Mdot
.70979 .75292 Mdot
.70979 .74508 Mdot
.71763 .749 Mdot
.72155 .749 Mdot
.72155 .74508 Mdot
.72547 .749 Mdot
.71763 .74116 Mdot
.71763 .74508 Mdot
.72939 .75684 Mdot
.72939 .74508 Mdot
.72939 .73724 Mdot
.73332 .73332 Mdot
.73724 .73332 Mdot
.74116 .73332 Mdot
.74508 .74116 Mdot
.75292 .749 Mdot
.749 .749 Mdot
.75684 .74508 Mdot
.76469 .749 Mdot
.76076 .74116 Mdot
.75684 .73332 Mdot
.76469 .74116 Mdot
.75684 .73332 Mdot
.75684 .72155 Mdot
.76076 .71371 Mdot
.76076 .70194 Mdot
.76469 .70979 Mdot
.76469 .71371 Mdot
.75292 .70587 Mdot
.75684 .72155 Mdot
.74508 .72155 Mdot
.74508 .72939 Mdot
.74508 .72547 Mdot
.75292 .72547 Mdot
.75684 .72547 Mdot
.749 .71763 Mdot
.75292 .71763 Mdot
.749 .70979 Mdot
.749 .69802 Mdot
.76469 .69802 Mdot
.76469 .69018 Mdot
.76076 .6941 Mdot
.76076 .69802 Mdot
.75684 .6941 Mdot
.75684 .69018 Mdot
.75684 .69018 Mdot
.75292 .69802 Mdot
.73724 .69018 Mdot
.74116 .6941 Mdot
.72547 .68626 Mdot
.72155 .68234 Mdot
.73724 .6941 Mdot
.72939 .6941 Mdot
.72939 .69802 Mdot
.72547 .69802 Mdot
.72155 .69018 Mdot
.71371 .6745 Mdot
.70194 .66665 Mdot
.6941 .66665 Mdot
.62744 .59999 Mdot
.70587 .68626 Mdot
.90585 .89801 Mdot
.45883 .57254 Mdot
.49412 .61568 Mdot
.5098 .6392 Mdot
.51372 .65489 Mdot
.5098 .66665 Mdot
.49804 .66273 Mdot
.50196 .66665 Mdot
.49804 .65489 Mdot
.51765 .65097 Mdot
.51765 .65489 Mdot
.52941 .67057 Mdot
.53333 .6745 Mdot
.52941 .67057 Mdot
.53333 .67057 Mdot
.54117 .66665 Mdot
.54902 .66273 Mdot
.55686 .67842 Mdot
.56078 .68234 Mdot
.56862 .69802 Mdot
.55686 .6941 Mdot
.56078 .70587 Mdot
.57254 .70979 Mdot
.57254 .70194 Mdot
.58823 .70979 Mdot
.58823 .70979 Mdot
.59215 .70587 Mdot
.60391 .71371 Mdot
.61568 .72155 Mdot
.62352 .71763 Mdot
.62744 .72155 Mdot
.63136 .72547 Mdot
.63528 .72547 Mdot
.63528 .71763 Mdot
.63528 .70587 Mdot
.65097 .70979 Mdot
.65881 .72155 Mdot
.66273 .73332 Mdot
.66273 .74508 Mdot
.66665 .75292 Mdot
.67057 .75684 Mdot
.6745 .76861 Mdot
.66665 .75684 Mdot
.6745 .76076 Mdot
.67842 .76469 Mdot
.69802 .76469 Mdot
.69018 .749 Mdot
.70194 .75684 Mdot
.70194 .76076 Mdot
.70194 .76076 Mdot
.70587 .76469 Mdot
.70587 .75684 Mdot
.70979 .75684 Mdot
.72155 .77253 Mdot
.72155 .77645 Mdot
.71371 .76861 Mdot
.70587 .75292 Mdot
.70587 .75684 Mdot
.70979 .75684 Mdot
.71371 .75684 Mdot
.70979 .75292 Mdot
.70979 .75292 Mdot
.71371 .749 Mdot
.71763 .74508 Mdot
.72939 .75292 Mdot
.73724 .76076 Mdot
.72547 .74116 Mdot
.72939 .73724 Mdot
.73724 .74508 Mdot
.74508 .74508 Mdot
.749 .75684 Mdot
.749 .75684 Mdot
.749 .75292 Mdot
.749 .749 Mdot
.76076 .75292 Mdot
.75292 .749 Mdot
.75684 .749 Mdot
.75292 .749 Mdot
.74508 .74116 Mdot
.75292 .74508 Mdot
.76469 .74116 Mdot
.75684 .73724 Mdot
.75684 .73724 Mdot
.74508 .72547 Mdot
.74508 .72547 Mdot
.74508 .72547 Mdot
.74508 .72155 Mdot
.749 .71371 Mdot
.75292 .71371 Mdot
.76861 .72155 Mdot
.76469 .72155 Mdot
.75684 .71371 Mdot
.749 .70587 Mdot
.749 .70194 Mdot
.749 .69802 Mdot
.76861 .70194 Mdot
.76469 .70194 Mdot
.75684 .70587 Mdot
.75684 .72155 Mdot
.74508 .70979 Mdot
.74116 .70979 Mdot
.73332 .70587 Mdot
.72939 .70587 Mdot
.74508 .70979 Mdot
.73332 .69802 Mdot
.72939 .6941 Mdot
.72939 .6941 Mdot
.73332 .70194 Mdot
.73332 .70979 Mdot
.72155 .69802 Mdot
.72155 .6941 Mdot
.71371 .68626 Mdot
.70587 .68234 Mdot
.70587 .69018 Mdot
.6941 .69018 Mdot
.68234 .67057 Mdot
.67057 .65881 Mdot
.65489 .63528 Mdot
.8235 .81566 Mdot
.84311 .84703 Mdot
.47059 .57646 Mdot
.48628 .60783 Mdot
.5098 .63136 Mdot
.5098 .64313 Mdot
.50196 .64705 Mdot
.50196 .65881 Mdot
.50196 .66273 Mdot
.51372 .67057 Mdot
.51372 .66665 Mdot
.52157 .66665 Mdot
.53333 .68234 Mdot
.54902 .69802 Mdot
.54509 .6941 Mdot
.55294 .6941 Mdot
.54509 .67842 Mdot
.55294 .68234 Mdot
.56078 .69018 Mdot
.56862 .69018 Mdot
.57254 .6941 Mdot
.57646 .70587 Mdot
.58431 .71371 Mdot
.58431 .71763 Mdot
.59215 .71371 Mdot
.58431 .70587 Mdot
.58431 .70587 Mdot
.58823 .70587 Mdot
.60391 .72155 Mdot
.61568 .72547 Mdot
.62352 .72939 Mdot
.62744 .72939 Mdot
.62744 .73332 Mdot
.6392 .73332 Mdot
.64313 .72547 Mdot
.64705 .72547 Mdot
.64313 .71371 Mdot
.66665 .73332 Mdot
.6745 .749 Mdot
.6745 .75684 Mdot
.67057 .75292 Mdot
.67057 .76076 Mdot
.67842 .76469 Mdot
.67842 .76076 Mdot
.67842 .77253 Mdot
.6941 .78037 Mdot
.68626 .77253 Mdot
.6941 .76861 Mdot
.70194 .76469 Mdot
.70587 .76469 Mdot
.70587 .76861 Mdot
.70587 .76861 Mdot
.70979 .76469 Mdot
.71763 .76469 Mdot
.71371 .75684 Mdot
.72547 .77645 Mdot
.71371 .77253 Mdot
.70979 .76469 Mdot
.71371 .77253 Mdot
.70587 .76076 Mdot
.71763 .76469 Mdot
.72155 .77645 Mdot
.72547 .78429 Mdot
.71371 .76861 Mdot
.71763 .76469 Mdot
.71763 .75684 Mdot
.72939 .76076 Mdot
.73724 .76469 Mdot
.73332 .75684 Mdot
.73724 .749 Mdot
.74116 .74116 Mdot
.749 .749 Mdot
.75684 .76076 Mdot
.75292 .76076 Mdot
.75292 .76469 Mdot
.76076 .76076 Mdot
.76076 .76861 Mdot
.75684 .76469 Mdot
.76076 .76469 Mdot
.75684 .75684 Mdot
.749 .75292 Mdot
.75292 .76076 Mdot
.75684 .76076 Mdot
.75292 .75292 Mdot
.74116 .74116 Mdot
.74508 .74116 Mdot
.74508 .72547 Mdot
.75684 .72547 Mdot
.75292 .71763 Mdot
.75684 .71763 Mdot
.76469 .71763 Mdot
.76861 .72155 Mdot
.76469 .71371 Mdot
.76076 .70979 Mdot
.76469 .71371 Mdot
.76076 .70979 Mdot
.76469 .71371 Mdot
.76469 .70979 Mdot
.76076 .71763 Mdot
.75684 .72939 Mdot
.74116 .73332 Mdot
.74116 .73332 Mdot
.74116 .73332 Mdot
.73724 .72155 Mdot
.73332 .71371 Mdot
.73332 .70194 Mdot
.73724 .70587 Mdot
.72939 .69802 Mdot
.72939 .69018 Mdot
.72547 .68626 Mdot
.72939 .69802 Mdot
.72547 .6941 Mdot
.72155 .6941 Mdot
.70979 .68626 Mdot
.70587 .69018 Mdot
.70979 .6941 Mdot
.70194 .69018 Mdot
.69018 .67842 Mdot
.68234 .6745 Mdot
.68234 .68626 Mdot
.57254 .59215 Mdot
.56862 .58431 Mdot
.61176 .63528 Mdot
.45883 .58039 Mdot
.50196 .62744 Mdot
.50588 .6392 Mdot
.51372 .65489 Mdot
.49804 .6392 Mdot
.50196 .6392 Mdot
.50196 .64705 Mdot
.51372 .65881 Mdot
.51765 .66665 Mdot
.51372 .67057 Mdot
.52941 .68234 Mdot
.53725 .69018 Mdot
.53725 .68626 Mdot
.54902 .69018 Mdot
.54902 .6941 Mdot
.54902 .69018 Mdot
.55686 .69018 Mdot
.5647 .6941 Mdot
.57254 .70194 Mdot
.58431 .70587 Mdot
.59215 .71371 Mdot
.58823 .70979 Mdot
.59215 .71371 Mdot
.59215 .70979 Mdot
.59999 .70979 Mdot
.60391 .70979 Mdot
.60783 .71763 Mdot
.60783 .71371 Mdot
.60783 .71371 Mdot
.61568 .72547 Mdot
.61568 .72547 Mdot
.63528 .73332 Mdot
.64705 .74116 Mdot
.65097 .73724 Mdot
.65489 .74508 Mdot
.66273 .749 Mdot
.67057 .75292 Mdot
.6745 .76076 Mdot
.67842 .76469 Mdot
.69018 .76861 Mdot
.68626 .76469 Mdot
.68626 .76469 Mdot
.69018 .77645 Mdot
.69802 .78037 Mdot
.69018 .76861 Mdot
.6941 .76469 Mdot
.6941 .76076 Mdot
.70194 .76076 Mdot
.70587 .75292 Mdot
.70587 .75292 Mdot
.70979 .76076 Mdot
.70587 .75292 Mdot
.70979 .75292 Mdot
.70979 .75684 Mdot
.71371 .75684 Mdot
.70587 .75684 Mdot
.71371 .76076 Mdot
.72547 .76469 Mdot
.71763 .75684 Mdot
.72547 .76469 Mdot
.72939 .76861 Mdot
.72939 .76469 Mdot
.72547 .76076 Mdot
.72547 .76076 Mdot
.72547 .749 Mdot
.72939 .749 Mdot
.73724 .74508 Mdot
.73724 .73724 Mdot
.73724 .73332 Mdot
.74508 .73332 Mdot
.74508 .72939 Mdot
.749 .73332 Mdot
.74508 .73332 Mdot
.73332 .71763 Mdot
.75292 .73724 Mdot
.75684 .74508 Mdot
.75292 .74116 Mdot
.749 .74116 Mdot
.75292 .74508 Mdot
.75292 .75684 Mdot
.749 .749 Mdot
.74116 .74508 Mdot
.74116 .73724 Mdot
.74116 .72939 Mdot
.74508 .72155 Mdot
.73724 .70587 Mdot
.75292 .71371 Mdot
.76076 .71371 Mdot
.75684 .71371 Mdot
.75292 .71371 Mdot
.75292 .71371 Mdot
.75292 .70979 Mdot
.75684 .70194 Mdot
.75292 .6941 Mdot
.75292 .69018 Mdot
.749 .68234 Mdot
.74508 .69018 Mdot
.749 .70194 Mdot
.74116 .70979 Mdot
.72939 .71763 Mdot
.72939 .72155 Mdot
.73332 .72155 Mdot
.74116 .71763 Mdot
.73332 .69802 Mdot
.73332 .6941 Mdot
.72939 .68626 Mdot
.72939 .67842 Mdot
.72939 .6745 Mdot
.73332 .68234 Mdot
.73332 .6745 Mdot
.73332 .67842 Mdot
.72547 .68626 Mdot
.72155 .69018 Mdot
.71763 .68626 Mdot
.70979 .6745 Mdot
.70587 .67057 Mdot
.69802 .67842 Mdot
.68626 .67842 Mdot
.6745 .66665 Mdot
.66665 .65489 Mdot
.56862 .55294 Mdot
.3608 .34511 Mdot
.52157 .4902 Mdot
.58039 .5647 Mdot
.45883 .57254 Mdot
.48235 .6196 Mdot
.49412 .6392 Mdot
.49412 .65097 Mdot
.4902 .64705 Mdot
.48628 .6392 Mdot
.49804 .65489 Mdot
.50196 .65881 Mdot
.5098 .66665 Mdot
.51372 .67842 Mdot
.52549 .68626 Mdot
.53333 .69018 Mdot
.53333 .6941 Mdot
.55294 .70587 Mdot
.54902 .69802 Mdot
.55686 .70979 Mdot
.56078 .70979 Mdot
.56862 .70979 Mdot
.57254 .71371 Mdot
.57254 .71763 Mdot
.58431 .72155 Mdot
.58823 .72155 Mdot
.59607 .72939 Mdot
.58823 .72547 Mdot
.59999 .72547 Mdot
.60391 .72155 Mdot
.60391 .71763 Mdot
.59607 .70587 Mdot
.60783 .71763 Mdot
.61568 .72547 Mdot
.62744 .73724 Mdot
.63136 .74508 Mdot
.64313 .749 Mdot
.65097 .749 Mdot
.65881 .76076 Mdot
.65097 .75684 Mdot
.65097 .75684 Mdot
.65881 .75684 Mdot
.66273 .76076 Mdot
.66665 .76076 Mdot
.66665 .76076 Mdot
.6745 .76861 Mdot
.68234 .76861 Mdot
.68626 .77253 Mdot
.69018 .78037 Mdot
.68626 .76861 Mdot
.68626 .76076 Mdot
.68626 .76076 Mdot
.6941 .76469 Mdot
.69802 .76076 Mdot
.69802 .75684 Mdot
.69802 .75684 Mdot
.69802 .75292 Mdot
.70587 .75684 Mdot
.70587 .75292 Mdot
.70194 .75684 Mdot
.70979 .76861 Mdot
.71763 .76469 Mdot
.72155 .76469 Mdot
.72547 .76469 Mdot
.72939 .76861 Mdot
.72547 .76076 Mdot
.72939 .76469 Mdot
.72155 .75292 Mdot
.72547 .749 Mdot
.72939 .75292 Mdot
.72939 .749 Mdot
.72939 .73332 Mdot
.72939 .72547 Mdot
.73332 .72939 Mdot
.73332 .72547 Mdot
.74116 .72547 Mdot
.73332 .72939 Mdot
.74116 .73724 Mdot
.74116 .73724 Mdot
.74508 .749 Mdot
.73724 .73724 Mdot
.74116 .73332 Mdot
.74116 .74116 Mdot
.74508 .75292 Mdot
.74116 .75684 Mdot
.74116 .75292 Mdot
.74116 .74508 Mdot
.72939 .72547 Mdot
.73724 .72939 Mdot
.74508 .72939 Mdot
.75292 .72939 Mdot
.75292 .72939 Mdot
.75684 .73332 Mdot
.76076 .74116 Mdot
.73724 .72547 Mdot
.74508 .72939 Mdot
.74116 .71763 Mdot
.75292 .71371 Mdot
.75684 .70979 Mdot
.749 .70194 Mdot
.74508 .70587 Mdot
.74116 .71371 Mdot
.74508 .73332 Mdot
.74508 .74116 Mdot
.72939 .73332 Mdot
.72547 .72155 Mdot
.72547 .72155 Mdot
.72155 .71371 Mdot
.72547 .71371 Mdot
.72155 .70587 Mdot
.71763 .6941 Mdot
.71371 .69018 Mdot
.72155 .68626 Mdot
.72155 .68626 Mdot
.71763 .68234 Mdot
.71763 .6941 Mdot
.71763 .70194 Mdot
.70979 .6941 Mdot
.70587 .68626 Mdot
.70587 .68626 Mdot
.70194 .6941 Mdot
.69802 .6941 Mdot
.68626 .68626 Mdot
.6745 .67057 Mdot
.67842 .65881 Mdot
.65881 .63528 Mdot
.57254 .53725 Mdot
.19218 .16865 Mdot
.22747 .1961 Mdot
.59999 .58431 Mdot
.79606 .79213 Mdot
.47843 .59607 Mdot
.50196 .6392 Mdot
.50196 .66273 Mdot
.50196 .66665 Mdot
.49412 .66273 Mdot
.48628 .65097 Mdot
.50588 .66273 Mdot
.50588 .65881 Mdot
.5098 .65881 Mdot
.5098 .66665 Mdot
.52549 .67842 Mdot
.52549 .67842 Mdot
.54117 .68626 Mdot
.54509 .69018 Mdot
.53333 .67842 Mdot
.54902 .6941 Mdot
.56078 .70194 Mdot
.56862 .70979 Mdot
.5647 .70979 Mdot
.5647 .70979 Mdot
.5647 .71371 Mdot
.57646 .72155 Mdot
.58039 .72547 Mdot
.58039 .72155 Mdot
.58039 .72155 Mdot
.58823 .72155 Mdot
.59215 .71763 Mdot
.59607 .71371 Mdot
.60783 .72155 Mdot
.60783 .72155 Mdot
.60391 .72547 Mdot
.61176 .72939 Mdot
.63136 .74116 Mdot
.63528 .73724 Mdot
.64705 .74116 Mdot
.65097 .75292 Mdot
.65097 .76076 Mdot
.65489 .75684 Mdot
.65097 .75292 Mdot
.65881 .76076 Mdot
.65881 .76076 Mdot
.66273 .76076 Mdot
.67057 .76861 Mdot
.68234 .77645 Mdot
.6745 .76861 Mdot
.6745 .76861 Mdot
.6745 .75684 Mdot
.68626 .77253 Mdot
.69802 .77645 Mdot
.69802 .76861 Mdot
.6941 .749 Mdot
.70194 .749 Mdot
.70587 .75292 Mdot
.70587 .75292 Mdot
.70194 .75292 Mdot
.6941 .75292 Mdot
.69802 .749 Mdot
.70194 .76469 Mdot
.70587 .76469 Mdot
.71371 .76861 Mdot
.71763 .76861 Mdot
.71371 .76469 Mdot
.72155 .76469 Mdot
.72547 .76861 Mdot
.71371 .76076 Mdot
.70587 .74508 Mdot
.72155 .75292 Mdot
.71763 .73724 Mdot
.71371 .73332 Mdot
.71371 .72939 Mdot
.71763 .73332 Mdot
.71763 .73724 Mdot
.71763 .73724 Mdot
.72547 .73724 Mdot
.72939 .74116 Mdot
.72939 .74508 Mdot
.73332 .74508 Mdot
.73332 .74116 Mdot
.73332 .74116 Mdot
.73332 .75292 Mdot
.73724 .76469 Mdot
.72939 .76076 Mdot
.72939 .749 Mdot
.72155 .73724 Mdot
.72547 .73332 Mdot
.72939 .72939 Mdot
.73332 .73332 Mdot
.73332 .73332 Mdot
.749 .749 Mdot
.74116 .75292 Mdot
.73724 .76076 Mdot
.73332 .75292 Mdot
.73332 .74116 Mdot
.73332 .72939 Mdot
.72939 .72155 Mdot
.72939 .72155 Mdot
.73332 .72155 Mdot
.73332 .73724 Mdot
.73332 .73724 Mdot
.73332 .74508 Mdot
.73332 .749 Mdot
.73332 .74508 Mdot
.72155 .72939 Mdot
.72155 .72547 Mdot
.72547 .72155 Mdot
.72547 .72155 Mdot
.72547 .72155 Mdot
.72155 .71763 Mdot
.71763 .70587 Mdot
.71763 .70587 Mdot
.70979 .69802 Mdot
.70587 .69802 Mdot
.70979 .71371 Mdot
.70587 .70979 Mdot
.69802 .70194 Mdot
.69802 .69802 Mdot
.68234 .6941 Mdot
.6745 .69018 Mdot
.67057 .68626 Mdot
.66273 .6745 Mdot
.65881 .66665 Mdot
.65489 .65881 Mdot
.66273 .65489 Mdot
.44314 .4353 Mdot
.30198 .29413 Mdot
.21963 .20002 Mdot
.20787 .18042 Mdot
.19218 .17257 Mdot
.59215 .58823 Mdot
.78821 .78821 Mdot
.47059 .59999 Mdot
.4902 .6392 Mdot
.4902 .65881 Mdot
.49804 .6745 Mdot
.49412 .67057 Mdot
.48628 .67057 Mdot
.49412 .66273 Mdot
.50588 .67057 Mdot
.50196 .66273 Mdot
.51372 .66273 Mdot
.52941 .67842 Mdot
.54902 .6941 Mdot
.54117 .69018 Mdot
.54902 .6941 Mdot
.54902 .69018 Mdot
.55294 .68626 Mdot
.55686 .6941 Mdot
.56078 .70587 Mdot
.5647 .71371 Mdot
.57254 .71763 Mdot
.5647 .70979 Mdot
.57646 .71763 Mdot
.58431 .72547 Mdot
.58431 .72547 Mdot
.58431 .73332 Mdot
.58039 .72939 Mdot
.58431 .72155 Mdot
.59215 .71763 Mdot
.60391 .72547 Mdot
.61176 .73332 Mdot
.59999 .72939 Mdot
.59607 .72939 Mdot
.61176 .73332 Mdot
.62352 .73332 Mdot
.63136 .72939 Mdot
.6392 .74508 Mdot
.64705 .75684 Mdot
.65097 .76861 Mdot
.65097 .77645 Mdot
.64313 .76861 Mdot
.65097 .75684 Mdot
.64705 .75292 Mdot
.65489 .75292 Mdot
.66665 .76076 Mdot
.66665 .76076 Mdot
.67057 .76469 Mdot
.67057 .76861 Mdot
.67842 .76469 Mdot
.6745 .749 Mdot
.68626 .75684 Mdot
.6941 .75292 Mdot
.70194 .749 Mdot
.70979 .749 Mdot
.70194 .749 Mdot
.69802 .749 Mdot
.6941 .76076 Mdot
.69018 .76469 Mdot
.69802 .77253 Mdot
.6941 .76076 Mdot
.70194 .76469 Mdot
.70194 .77253 Mdot
.6941 .77253 Mdot
.69802 .76076 Mdot
.70587 .76076 Mdot
.71371 .77253 Mdot
.70979 .76861 Mdot
.71371 .76469 Mdot
.71371 .75684 Mdot
.71371 .75292 Mdot
.71763 .75684 Mdot
.72939 .76469 Mdot
.72547 .76861 Mdot
.71763 .76076 Mdot
.72155 .749 Mdot
.72547 .74508 Mdot
.72547 .73724 Mdot
.72939 .73724 Mdot
.73332 .74508 Mdot
.72939 .74116 Mdot
.73724 .73724 Mdot
.73724 .749 Mdot
.73724 .75684 Mdot
.72547 .75684 Mdot
.72547 .75292 Mdot
.72155 .74116 Mdot
.72155 .74116 Mdot
.72547 .74116 Mdot
.72939 .74508 Mdot
.72939 .749 Mdot
.73332 .749 Mdot
.73724 .75292 Mdot
.72939 .74508 Mdot
.72939 .749 Mdot
.72939 .74116 Mdot
.73332 .74508 Mdot
.72155 .72547 Mdot
.73332 .72939 Mdot
.73724 .73724 Mdot
.72547 .73724 Mdot
.72155 .74508 Mdot
.71763 .74116 Mdot
.72155 .73724 Mdot
.72939 .73724 Mdot
.72547 .72155 Mdot
.72155 .71371 Mdot
.72547 .70979 Mdot
.71371 .70194 Mdot
.70194 .6941 Mdot
.70587 .70194 Mdot
.70979 .71371 Mdot
.69802 .70587 Mdot
.69802 .70194 Mdot
.6941 .69802 Mdot
.6941 .69802 Mdot
.6941 .70587 Mdot
.70587 .71763 Mdot
.6941 .70194 Mdot
.68234 .69018 Mdot
.6745 .67842 Mdot
.67057 .68626 Mdot
.66665 .68626 Mdot
.66273 .68626 Mdot
.66273 .68234 Mdot
.64313 .65881 Mdot
.55294 .56078 Mdot
.31766 .32158 Mdot
.27845 .26668 Mdot
.26668 .25492 Mdot
.23139 .23139 Mdot
.20002 .21571 Mdot
.3608 .38432 Mdot
.58431 .59999 Mdot
.45491 .60783 Mdot
.47843 .64705 Mdot
.4902 .67057 Mdot
.49804 .68234 Mdot
.49804 .67842 Mdot
.49804 .67842 Mdot
.49412 .66273 Mdot
.49412 .64705 Mdot
.50196 .64705 Mdot
.5098 .64705 Mdot
.52157 .65489 Mdot
.54509 .68234 Mdot
.54117 .68234 Mdot
.52941 .66665 Mdot
.54509 .67057 Mdot
.5647 .68626 Mdot
.57254 .69018 Mdot
.56078 .6941 Mdot
.55686 .70979 Mdot
.5647 .71763 Mdot
.5647 .71371 Mdot
.5647 .70587 Mdot
.57254 .70587 Mdot
.58039 .71371 Mdot
.58823 .72547 Mdot
.58431 .72155 Mdot
.59215 .71763 Mdot
.59607 .71371 Mdot
.61176 .71763 Mdot
.59999 .71763 Mdot
.61176 .72939 Mdot
.62352 .74116 Mdot
.62744 .74116 Mdot
.62352 .72939 Mdot
.6392 .73332 Mdot
.63528 .73332 Mdot
.64705 .749 Mdot
.65489 .76469 Mdot
.64313 .76469 Mdot
.64313 .76076 Mdot
.64705 .76469 Mdot
.64313 .749 Mdot
.65489 .75292 Mdot
.65881 .75292 Mdot
.66665 .76076 Mdot
.66665 .75292 Mdot
.67057 .749 Mdot
.68234 .75292 Mdot
.68626 .749 Mdot
.69802 .75684 Mdot
.6941 .75292 Mdot
.69802 .74508 Mdot
.69802 .73724 Mdot
.70587 .749 Mdot
.70979 .75684 Mdot
.70587 .76076 Mdot
.69802 .76469 Mdot
.70194 .76469 Mdot
.70979 .76861 Mdot
.70979 .76861 Mdot
.70979 .77253 Mdot
.70194 .77253 Mdot
.6941 .77253 Mdot
.6941 .75292 Mdot
.69802 .75684 Mdot
.70194 .76076 Mdot
.70587 .76469 Mdot
.70587 .76076 Mdot
.70587 .75292 Mdot
.71371 .75684 Mdot
.70979 .75684 Mdot
.70979 .75292 Mdot
.70979 .74116 Mdot
.71763 .72939 Mdot
.72547 .72547 Mdot
.73332 .72155 Mdot
.73724 .72547 Mdot
.73332 .73724 Mdot
.73332 .73332 Mdot
.73724 .73332 Mdot
.73332 .73332 Mdot
.72939 .74508 Mdot
.73332 .75684 Mdot
.72155 .74116 Mdot
.71371 .72547 Mdot
.71763 .72939 Mdot
.71763 .73332 Mdot
.72547 .74508 Mdot
.72939 .749 Mdot
.73332 .749 Mdot
.72939 .74116 Mdot
.73332 .749 Mdot
.72155 .73332 Mdot
.72939 .73332 Mdot
.73332 .73332 Mdot
.72547 .72155 Mdot
.72939 .72155 Mdot
.72547 .71763 Mdot
.72939 .72155 Mdot
.72547 .72547 Mdot
.72547 .72547 Mdot
.72547 .72939 Mdot
.71763 .72155 Mdot
.71763 .71371 Mdot
.71371 .70587 Mdot
.70979 .69802 Mdot
.70194 .69802 Mdot
.6941 .69018 Mdot
.69802 .6941 Mdot
.70194 .70587 Mdot
.70194 .70194 Mdot
.70194 .6941 Mdot
.70194 .69018 Mdot
.6941 .68234 Mdot
.6941 .68234 Mdot
.69802 .69018 Mdot
.6941 .69018 Mdot
.69018 .69018 Mdot
.68234 .68234 Mdot
.67057 .6745 Mdot
.66665 .68234 Mdot
.65881 .67842 Mdot
.65881 .67057 Mdot
.65489 .66273 Mdot
.65881 .66665 Mdot
.59607 .60783 Mdot
.48235 .5098 Mdot
.48628 .51372 Mdot
.45098 .47843 Mdot
.21963 .26276 Mdot
.18434 .21963 Mdot
.14513 .1765 Mdot
.13728 .16865 Mdot
.34511 .36472 Mdot
.56078 .56862 Mdot
.45491 .59999 Mdot
.47843 .64313 Mdot
.4902 .65881 Mdot
.48235 .66665 Mdot
.49412 .6745 Mdot
.49412 .6745 Mdot
.4902 .66273 Mdot
.49804 .65489 Mdot
.49412 .64313 Mdot
.49804 .6392 Mdot
.51765 .64313 Mdot
.52549 .64705 Mdot
.53333 .66273 Mdot
.53333 .65881 Mdot
.53333 .65489 Mdot
.54117 .6745 Mdot
.54509 .67842 Mdot
.53725 .69018 Mdot
.54902 .70194 Mdot
.55686 .70587 Mdot
.56078 .70194 Mdot
.56862 .70587 Mdot
.58039 .70587 Mdot
.58039 .70194 Mdot
.59607 .71763 Mdot
.60391 .72939 Mdot
.60783 .72547 Mdot
.60783 .71371 Mdot
.60391 .70979 Mdot
.60391 .71371 Mdot
.60391 .72547 Mdot
.6196 .74116 Mdot
.61568 .73332 Mdot
.6196 .73332 Mdot
.62744 .73332 Mdot
.64313 .73724 Mdot
.6392 .74508 Mdot
.63528 .749 Mdot
.63136 .75292 Mdot
.63528 .76076 Mdot
.63136 .75684 Mdot
.64705 .75684 Mdot
.64705 .75292 Mdot
.64705 .75292 Mdot
.65489 .75684 Mdot
.65489 .74116 Mdot
.66273 .74508 Mdot
.6745 .75292 Mdot
.68234 .75292 Mdot
.69018 .75292 Mdot
.6941 .75292 Mdot
.70194 .75292 Mdot
.70194 .75292 Mdot
.71371 .75684 Mdot
.70587 .75292 Mdot
.70194 .75292 Mdot
.70194 .75292 Mdot
.70194 .75684 Mdot
.70979 .76076 Mdot
.71763 .76861 Mdot
.72155 .77253 Mdot
.70587 .76861 Mdot
.70194 .77645 Mdot
.69018 .76861 Mdot
.6941 .76861 Mdot
.6941 .76076 Mdot
.70194 .76469 Mdot
.70194 .76469 Mdot
.70587 .76076 Mdot
.70587 .749 Mdot
.70979 .75292 Mdot
.71371 .75292 Mdot
.71763 .74508 Mdot
.71763 .73724 Mdot
.72155 .73724 Mdot
.72939 .74508 Mdot
.72939 .749 Mdot
.72155 .749 Mdot
.72939 .749 Mdot
.74116 .749 Mdot
.73332 .74116 Mdot
.72547 .74116 Mdot
.72155 .74116 Mdot
.72155 .73724 Mdot
.70979 .73332 Mdot
.70587 .73724 Mdot
.70979 .74508 Mdot
.70979 .74508 Mdot
.71371 .75292 Mdot
.71763 .75292 Mdot
.72547 .75292 Mdot
.72155 .74508 Mdot
.72547 .74116 Mdot
.71763 .73724 Mdot
.71371 .73332 Mdot
.71763 .72547 Mdot
.72155 .72939 Mdot
.72155 .72155 Mdot
.72547 .72155 Mdot
.72939 .72547 Mdot
.72547 .72547 Mdot
.72547 .72547 Mdot
.71371 .70979 Mdot
.71371 .70979 Mdot
.70979 .70979 Mdot
.71371 .72155 Mdot
.70194 .71371 Mdot
.6941 .70587 Mdot
.69802 .70587 Mdot
.69018 .69802 Mdot
.69018 .69802 Mdot
.69802 .6941 Mdot
.69018 .68626 Mdot
.69018 .67842 Mdot
.69018 .67842 Mdot
.6941 .70194 Mdot
.68626 .70979 Mdot
.68234 .70194 Mdot
.67842 .6941 Mdot
.6745 .69018 Mdot
.67057 .69018 Mdot
.65881 .68234 Mdot
.65489 .68626 Mdot
.65097 .6745 Mdot
.64705 .6745 Mdot
.64705 .67842 Mdot
.64705 .69018 Mdot
.63136 .68234 Mdot
.61176 .66273 Mdot
.50588 .56078 Mdot
.15297 .22355 Mdot
.16081 .21571 Mdot
.14513 .18434 Mdot
.12552 .16081 Mdot
.11768 .13728 Mdot
.12552 .10591 Mdot
.57254 .54902 Mdot
.78429 .77253 Mdot
.45491 .58823 Mdot
.47843 .6392 Mdot
.48628 .65881 Mdot
.47843 .66273 Mdot
.4902 .66665 Mdot
.48628 .65881 Mdot
.4902 .65881 Mdot
.4902 .65489 Mdot
.50196 .66665 Mdot
.5098 .66665 Mdot
.51765 .65881 Mdot
.52157 .65881 Mdot
.52157 .65489 Mdot
.53333 .66273 Mdot
.53725 .67057 Mdot
.53725 .67057 Mdot
.53333 .67057 Mdot
.54117 .68234 Mdot
.55294 .69018 Mdot
.56078 .6941 Mdot
.55686 .6941 Mdot
.56078 .69018 Mdot
.5647 .6941 Mdot
.58039 .70587 Mdot
.59215 .71763 Mdot
.60391 .72155 Mdot
.59999 .71763 Mdot
.59999 .72155 Mdot
.61176 .72939 Mdot
.61568 .73724 Mdot
.59999 .73724 Mdot
.60783 .73724 Mdot
.60783 .73332 Mdot
.60783 .72939 Mdot
.62352 .72939 Mdot
.63136 .73332 Mdot
.63136 .74116 Mdot
.62744 .749 Mdot
.63136 .749 Mdot
.6392 .76076 Mdot
.65097 .76469 Mdot
.64705 .76076 Mdot
.65489 .76469 Mdot
.66665 .77645 Mdot
.67057 .77253 Mdot
.6745 .76861 Mdot
.66665 .76076 Mdot
.67057 .75684 Mdot
.67057 .75684 Mdot
.68234 .76469 Mdot
.69018 .76076 Mdot
.6941 .75684 Mdot
.6941 .75292 Mdot
.69018 .75292 Mdot
.68626 .749 Mdot
.6941 .75292 Mdot
.70194 .749 Mdot
.69802 .74508 Mdot
.70194 .75684 Mdot
.70979 .75292 Mdot
.70587 .749 Mdot
.69802 .75292 Mdot
.69802 .749 Mdot
.69802 .749 Mdot
.68234 .74116 Mdot
.68234 .749 Mdot
.69018 .75292 Mdot
.6941 .749 Mdot
.69802 .75292 Mdot
.70194 .74508 Mdot
.70194 .73724 Mdot
.70979 .75292 Mdot
.71763 .75684 Mdot
.71763 .75292 Mdot
.71371 .74508 Mdot
.71763 .749 Mdot
.71371 .749 Mdot
.70587 .749 Mdot
.70979 .74508 Mdot
.72155 .749 Mdot
.72155 .74508 Mdot
.71763 .749 Mdot
.70979 .749 Mdot
.71371 .74508 Mdot
.70979 .74508 Mdot
.70587 .74116 Mdot
.71371 .749 Mdot
.72155 .75292 Mdot
.72547 .74508 Mdot
.71763 .74116 Mdot
.72155 .74508 Mdot
.71371 .74116 Mdot
.70587 .73332 Mdot
.70194 .73332 Mdot
.69802 .72547 Mdot
.70587 .72939 Mdot
.71371 .73724 Mdot
.72939 .74116 Mdot
.72939 .73724 Mdot
.73332 .74116 Mdot
.72939 .72939 Mdot
.72155 .72547 Mdot
.71763 .71763 Mdot
.70587 .71371 Mdot
.70587 .71763 Mdot
.70587 .72155 Mdot
.70194 .72939 Mdot
.6941 .72155 Mdot
.69018 .71763 Mdot
.69018 .71371 Mdot
.68234 .70587 Mdot
.68234 .70194 Mdot
.68626 .70587 Mdot
.68626 .70194 Mdot
.68626 .6941 Mdot
.69018 .71371 Mdot
.68234 .70979 Mdot
.68626 .71763 Mdot
.66665 .70587 Mdot
.66665 .70587 Mdot
.66273 .70587 Mdot
.65489 .70194 Mdot
.65097 .69802 Mdot
.64705 .68234 Mdot
.64705 .67842 Mdot
.6392 .6745 Mdot
.64705 .68234 Mdot
.62744 .6745 Mdot
.6196 .6745 Mdot
.61176 .67057 Mdot
.42746 .49412 Mdot
.31374 .38432 Mdot
.21963 .28629 Mdot
.18826 .251 Mdot
.15297 .20394 Mdot
.16473 .19218 Mdot
.20394 .20787 Mdot
.28237 .26276 Mdot
.15689 .14513 Mdot
.58431 .58823 Mdot
.78429 .78821 Mdot
.46275 .59607 Mdot
.48235 .6392 Mdot
.49412 .66273 Mdot
.49412 .66273 Mdot
.48628 .65881 Mdot
.4902 .65489 Mdot
.50196 .65881 Mdot
.51372 .66665 Mdot
.51765 .6745 Mdot
.51765 .67842 Mdot
.52157 .68234 Mdot
.51372 .66665 Mdot
.51765 .65881 Mdot
.52941 .66273 Mdot
.53333 .67842 Mdot
.54117 .68626 Mdot
.54117 .68626 Mdot
.53725 .68626 Mdot
.53725 .68626 Mdot
.54902 .69018 Mdot
.55686 .70194 Mdot
.55294 .70587 Mdot
.56078 .70979 Mdot
.5647 .71371 Mdot
.57254 .70979 Mdot
.58431 .71763 Mdot
.59215 .72547 Mdot
.58823 .72547 Mdot
.59999 .73724 Mdot
.59607 .73724 Mdot
.59607 .73724 Mdot
.59999 .73724 Mdot
.59999 .72939 Mdot
.60783 .72939 Mdot
.6196 .72547 Mdot
.62744 .72939 Mdot
.63136 .73332 Mdot
.62744 .72939 Mdot
.63136 .73724 Mdot
.6392 .75684 Mdot
.64705 .76861 Mdot
.65097 .77645 Mdot
.64705 .77253 Mdot
.65097 .77253 Mdot
.65881 .76861 Mdot
.66273 .76861 Mdot
.66273 .76861 Mdot
.67057 .77253 Mdot
.6745 .77253 Mdot
.67057 .76469 Mdot
.67842 .76861 Mdot
.68626 .76469 Mdot
.68626 .76861 Mdot
.68626 .76861 Mdot
.68234 .749 Mdot
.68626 .74116 Mdot
.6941 .74116 Mdot
.6941 .73724 Mdot
.70194 .749 Mdot
.69802 .75292 Mdot
.69802 .749 Mdot
.6941 .73724 Mdot
.68626 .73724 Mdot
.6941 .74508 Mdot
.6941 .75292 Mdot
.6941 .75684 Mdot
.69018 .75684 Mdot
.6941 .76076 Mdot
.6941 .75684 Mdot
.69802 .75684 Mdot
.70194 .75684 Mdot
.6941 .74508 Mdot
.69802 .74116 Mdot
.70194 .74508 Mdot
.69802 .749 Mdot
.6941 .74116 Mdot
.6941 .749 Mdot
.69802 .749 Mdot
.70587 .749 Mdot
.71371 .75684 Mdot
.71371 .76076 Mdot
.71371 .76469 Mdot
.70587 .75292 Mdot
.70587 .75292 Mdot
.70979 .74508 Mdot
.71763 .749 Mdot
.71371 .74508 Mdot
.70979 .73724 Mdot
.70979 .73724 Mdot
.70979 .74116 Mdot
.70979 .74508 Mdot
.71371 .749 Mdot
.70194 .72939 Mdot
.6941 .71763 Mdot
.70194 .72155 Mdot
.70979 .72939 Mdot
.71763 .74116 Mdot
.71763 .73724 Mdot
.72155 .74508 Mdot
.71371 .749 Mdot
.70587 .73724 Mdot
.71763 .73724 Mdot
.70979 .72939 Mdot
.70979 .72939 Mdot
.70587 .73724 Mdot
.6941 .72939 Mdot
.69018 .72939 Mdot
.6941 .73332 Mdot
.69018 .72547 Mdot
.68234 .71763 Mdot
.69018 .72155 Mdot
.69018 .72547 Mdot
.69018 .72155 Mdot
.69018 .72547 Mdot
.68626 .71763 Mdot
.67842 .70587 Mdot
.67057 .69802 Mdot
.66665 .6941 Mdot
.66273 .69802 Mdot
.65489 .69018 Mdot
.65489 .69802 Mdot
.65097 .69802 Mdot
.65489 .69802 Mdot
.65881 .69802 Mdot
.64313 .68626 Mdot
.63136 .6745 Mdot
.63528 .6745 Mdot
.63136 .6745 Mdot
.62352 .67842 Mdot
.61176 .66665 Mdot
.60391 .65489 Mdot
.59607 .6392 Mdot
.44706 .50196 Mdot
.3804 .44706 Mdot
.28237 .36472 Mdot
.29021 .36864 Mdot
.57646 .61568 Mdot
.51765 .54509 Mdot
.31766 .35687 Mdot
.31766 .34119 Mdot
.11376 .13728 Mdot
.32943 .34119 Mdot
.55294 .56078 Mdot
.45491 .59215 Mdot
.48235 .6392 Mdot
.49412 .65881 Mdot
.4902 .66665 Mdot
.4902 .66665 Mdot
.48628 .65881 Mdot
.50588 .66273 Mdot
.51372 .67057 Mdot
.51765 .67842 Mdot
.51372 .6745 Mdot
.51372 .67842 Mdot
.50588 .66665 Mdot
.51372 .66273 Mdot
.52157 .67842 Mdot
.52549 .6941 Mdot
.52549 .69802 Mdot
.53333 .70587 Mdot
.53333 .70587 Mdot
.53725 .69802 Mdot
.55294 .70194 Mdot
.55686 .70979 Mdot
.54902 .71371 Mdot
.56078 .72155 Mdot
.56078 .71763 Mdot
.5647 .71371 Mdot
.56862 .71371 Mdot
.58039 .71371 Mdot
.59607 .73332 Mdot
.59215 .74508 Mdot
.59607 .74508 Mdot
.59999 .74508 Mdot
.60783 .74508 Mdot
.60391 .73332 Mdot
.60783 .72547 Mdot
.61176 .73724 Mdot
.62352 .73724 Mdot
.63136 .73724 Mdot
.63136 .749 Mdot
.63528 .749 Mdot
.63528 .76076 Mdot
.63136 .76861 Mdot
.6392 .78037 Mdot
.6392 .77645 Mdot
.64313 .76861 Mdot
.6392 .76076 Mdot
.65489 .76861 Mdot
.65097 .77253 Mdot
.66665 .77645 Mdot
.65489 .77253 Mdot
.65489 .77253 Mdot
.67057 .78037 Mdot
.67842 .77645 Mdot
.68626 .77645 Mdot
.68626 .76861 Mdot
.68234 .75684 Mdot
.68626 .749 Mdot
.67842 .73332 Mdot
.68626 .749 Mdot
.68234 .749 Mdot
.69018 .75292 Mdot
.68626 .749 Mdot
.67842 .74508 Mdot
.69018 .74508 Mdot
.6941 .75292 Mdot
.69802 .76469 Mdot
.69802 .75684 Mdot
.6941 .75292 Mdot
.70194 .749 Mdot
.69802 .74508 Mdot
.70587 .749 Mdot
.70587 .75292 Mdot
.69802 .74508 Mdot
.69018 .74508 Mdot
.69018 .74116 Mdot
.6941 .749 Mdot
.6941 .74116 Mdot
.6941 .74116 Mdot
.69018 .73724 Mdot
.69802 .74508 Mdot
.71371 .75292 Mdot
.70979 .75292 Mdot
.70979 .76076 Mdot
.70587 .75292 Mdot
.70194 .75292 Mdot
.71371 .75292 Mdot
.70587 .74116 Mdot
.71371 .74508 Mdot
.70979 .74116 Mdot
.71371 .74116 Mdot
.71371 .73724 Mdot
.71763 .73724 Mdot
.71763 .73332 Mdot
.70979 .73724 Mdot
.71371 .74116 Mdot
.71763 .73332 Mdot
.71371 .72939 Mdot
.71371 .73724 Mdot
.71371 .749 Mdot
.70587 .74116 Mdot
.70979 .74508 Mdot
.70587 .73724 Mdot
.71371 .73332 Mdot
.70979 .73332 Mdot
.70979 .73724 Mdot
.70979 .74116 Mdot
.70587 .74116 Mdot
.69018 .73724 Mdot
.68234 .73332 Mdot
.67842 .72939 Mdot
.68234 .72547 Mdot
.69018 .71763 Mdot
.69802 .71763 Mdot
.69802 .71763 Mdot
.6941 .70587 Mdot
.69018 .70587 Mdot
.6745 .69802 Mdot
.65489 .68626 Mdot
.66273 .6941 Mdot
.66665 .70587 Mdot
.66273 .70979 Mdot
.65881 .70979 Mdot
.66273 .70979 Mdot
.66665 .70979 Mdot
.65097 .70194 Mdot
.64313 .69802 Mdot
.63528 .68626 Mdot
.63136 .68234 Mdot
.63528 .6941 Mdot
.63136 .6941 Mdot
.62352 .68626 Mdot
.61568 .6745 Mdot
.61176 .6745 Mdot
.60783 .67057 Mdot
.59607 .65881 Mdot
.55686 .6196 Mdot
.54509 .60391 Mdot
.56078 .61176 Mdot
.57254 .61176 Mdot
.55686 .59607 Mdot
.57646 .58823 Mdot
.29806 .31766 Mdot
.08631 .1216 Mdot
.10591 .13728 Mdot
.09415 .11376 Mdot
.31374 .3255 Mdot
.52549 .53333 Mdot
.42354 .56862 Mdot
.48235 .64705 Mdot
.4902 .66273 Mdot
.48628 .66665 Mdot
.48628 .67057 Mdot
.48628 .66273 Mdot
.50196 .66665 Mdot
.50588 .66273 Mdot
.5098 .66665 Mdot
.51372 .66665 Mdot
.5098 .66273 Mdot
.51372 .66665 Mdot
.52157 .67057 Mdot
.52157 .67057 Mdot
.52549 .67842 Mdot
.52549 .68234 Mdot
.52941 .69802 Mdot
.52941 .69802 Mdot
.52549 .68626 Mdot
.53333 .69018 Mdot
.54902 .70194 Mdot
.55294 .70194 Mdot
.56078 .70587 Mdot
.5647 .70194 Mdot
.56862 .70587 Mdot
.57254 .71371 Mdot
.57646 .72547 Mdot
.58431 .73332 Mdot
.58823 .74508 Mdot
.59215 .74508 Mdot
.59999 .749 Mdot
.61176 .749 Mdot
.60783 .74508 Mdot
.61176 .74116 Mdot
.6196 .73724 Mdot
.61568 .72547 Mdot
.63528 .74508 Mdot
.63528 .75292 Mdot
.63528 .75684 Mdot
.64705 .77253 Mdot
.6392 .76861 Mdot
.63528 .76861 Mdot
.64313 .77253 Mdot
.6392 .76861 Mdot
.64705 .76076 Mdot
.65097 .75684 Mdot
.65097 .75684 Mdot
.66273 .76861 Mdot
.65881 .76469 Mdot
.66273 .76076 Mdot
.67057 .76469 Mdot
.67057 .75684 Mdot
.6745 .75292 Mdot
.67057 .74508 Mdot
.67842 .749 Mdot
.6745 .74116 Mdot
.6745 .74508 Mdot
.68234 .749 Mdot
.6745 .74508 Mdot
.6745 .74508 Mdot
.68234 .749 Mdot
.69018 .749 Mdot
.69802 .75292 Mdot
.69802 .76469 Mdot
.69018 .76469 Mdot
.6941 .76469 Mdot
.69018 .76076 Mdot
.6941 .75292 Mdot
.69802 .749 Mdot
.70194 .74508 Mdot
.71371 .75292 Mdot
.69018 .73332 Mdot
.6941 .74116 Mdot
.70587 .75292 Mdot
.70587 .75292 Mdot
.70194 .74508 Mdot
.69802 .74116 Mdot
.6941 .73332 Mdot
.70194 .74116 Mdot
.70194 .74508 Mdot
.70587 .74508 Mdot
.70194 .73332 Mdot
.70194 .74508 Mdot
.6941 .74116 Mdot
.6941 .74116 Mdot
.70194 .74116 Mdot
.70194 .74116 Mdot
.70979 .74116 Mdot
.70587 .72939 Mdot
.70979 .72939 Mdot
.70194 .72547 Mdot
.70194 .73332 Mdot
.70587 .73724 Mdot
.70587 .74116 Mdot
.71371 .74116 Mdot
.70979 .74116 Mdot
.71371 .74116 Mdot
.71371 .73724 Mdot
.70979 .73724 Mdot
.70194 .74116 Mdot
.70587 .74116 Mdot
.70194 .73724 Mdot
.70979 .74116 Mdot
.70587 .73724 Mdot
.70194 .74116 Mdot
.69802 .73332 Mdot
.6941 .72939 Mdot
.69802 .72939 Mdot
.6941 .72547 Mdot
.68626 .71763 Mdot
.68234 .70194 Mdot
.67842 .69018 Mdot
.68234 .68626 Mdot
.68234 .68234 Mdot
.68626 .6941 Mdot
.68234 .69802 Mdot
.67057 .70587 Mdot
.66273 .69802 Mdot
.66273 .69802 Mdot
.66665 .70979 Mdot
.65881 .70979 Mdot
.65881 .71371 Mdot
.65489 .70587 Mdot
.65881 .70587 Mdot
.65489 .70194 Mdot
.64705 .69802 Mdot
.63528 .69018 Mdot
.63528 .70194 Mdot
.62352 .6941 Mdot
.61568 .68234 Mdot
.60783 .6745 Mdot
.61568 .68234 Mdot
.61568 .67842 Mdot
.62352 .68234 Mdot
.60783 .66665 Mdot
.59999 .65881 Mdot
.59607 .65097 Mdot
.59215 .64313 Mdot
.58823 .63528 Mdot
.56078 .61176 Mdot
.52941 .56078 Mdot
.29413 .33335 Mdot
.18434 .21571 Mdot
.14513 .16865 Mdot
.11376 .13336 Mdot
.08631 .10199 Mdot
.11768 .12552 Mdot
.60391 .59999 Mdot
.78821 .78821 Mdot
.43922 .57254 Mdot
.47843 .63136 Mdot
.49804 .66273 Mdot
.49804 .6745 Mdot
.48628 .67057 Mdot
.48235 .66273 Mdot
.4902 .65489 Mdot
.50196 .65097 Mdot
.51765 .65489 Mdot
.5098 .64705 Mdot
.5098 .65881 Mdot
.50588 .65881 Mdot
.5098 .67057 Mdot
.51765 .6745 Mdot
.51765 .6745 Mdot
.52549 .68234 Mdot
.52941 .69018 Mdot
.51372 .68234 Mdot
.51765 .68626 Mdot
.52549 .68234 Mdot
.52549 .6745 Mdot
.54117 .68234 Mdot
.54902 .67842 Mdot
.56078 .68234 Mdot
.56078 .69018 Mdot
.5647 .70194 Mdot
.56862 .71763 Mdot
.57254 .71371 Mdot
.58431 .72155 Mdot
.59999 .73724 Mdot
.59607 .73332 Mdot
.59999 .73332 Mdot
.60391 .72155 Mdot
.60391 .70979 Mdot
.61176 .70979 Mdot
.61568 .71763 Mdot
.62744 .72939 Mdot
.62744 .73724 Mdot
.6196 .74116 Mdot
.62744 .749 Mdot
.63528 .749 Mdot
.63136 .75292 Mdot
.6392 .76076 Mdot
.6392 .76076 Mdot
.6392 .75292 Mdot
.63528 .73724 Mdot
.65489 .74508 Mdot
.65489 .74116 Mdot
.66665 .749 Mdot
.65881 .749 Mdot
.65881 .74508 Mdot
.66273 .73724 Mdot
.66273 .72547 Mdot
.6745 .73332 Mdot
.66665 .73332 Mdot
.67057 .74116 Mdot
.66665 .73724 Mdot
.67057 .74508 Mdot
.67842 .73724 Mdot
.67842 .73724 Mdot
.68626 .74508 Mdot
.68234 .74508 Mdot
.6941 .75684 Mdot
.69018 .75684 Mdot
.68234 .75684 Mdot
.67842 .75292 Mdot
.69018 .75684 Mdot
.68626 .75292 Mdot
.67842 .74508 Mdot
.68234 .74116 Mdot
.69018 .73724 Mdot
.70194 .74116 Mdot
.69802 .74508 Mdot
.69018 .74116 Mdot
.6941 .74116 Mdot
.6941 .74116 Mdot
.6941 .74116 Mdot
.69018 .74116 Mdot
.70194 .74508 Mdot
.69802 .74116 Mdot
.6941 .73724 Mdot
.6941 .73724 Mdot
.69018 .73332 Mdot
.69018 .74116 Mdot
.68626 .73724 Mdot
.69802 .74508 Mdot
.70194 .74508 Mdot
.70587 .74116 Mdot
.70587 .73332 Mdot
.70979 .73724 Mdot
.70194 .73724 Mdot
.70194 .73332 Mdot
.69802 .73332 Mdot
.69802 .73332 Mdot
.6941 .72939 Mdot
.6941 .73332 Mdot
.69802 .74116 Mdot
.69018 .73724 Mdot
.69802 .73724 Mdot
.69802 .73332 Mdot
.6941 .73332 Mdot
.68234 .72939 Mdot
.67842 .72155 Mdot
.67842 .72155 Mdot
.68234 .72939 Mdot
.68234 .72939 Mdot
.67842 .72547 Mdot
.67842 .71763 Mdot
.67057 .70587 Mdot
.6745 .70587 Mdot
.68234 .70587 Mdot
.6745 .68626 Mdot
.67842 .68234 Mdot
.67057 .68626 Mdot
.68234 .69802 Mdot
.67842 .70194 Mdot
.66665 .70587 Mdot
.65489 .69802 Mdot
.65489 .6941 Mdot
.64705 .68626 Mdot
.65489 .70194 Mdot
.65881 .70587 Mdot
.65097 .70587 Mdot
.65489 .70587 Mdot
.65489 .69802 Mdot
.65097 .69802 Mdot
.65489 .70979 Mdot
.6392 .70587 Mdot
.62744 .70587 Mdot
.6196 .70194 Mdot
.62352 .69018 Mdot
.61176 .67842 Mdot
.61176 .6745 Mdot
.60783 .67057 Mdot
.59607 .66273 Mdot
.59607 .66273 Mdot
.59215 .65881 Mdot
.59607 .65881 Mdot
.59215 .65881 Mdot
.57646 .6392 Mdot
.5647 .62352 Mdot
.54509 .58823 Mdot
.52549 .54902 Mdot
.40785 .43138 Mdot
.20787 .24316 Mdot
.20002 .22747 Mdot
.16081 .18042 Mdot
.20002 .20787 Mdot
.21179 .21963 Mdot
.17257 .19218 Mdot
.57254 .58823 Mdot
.78429 .79213 Mdot
.45491 .5647 Mdot
.47059 .61176 Mdot
.48628 .64705 Mdot
.4902 .65881 Mdot
.49412 .66273 Mdot
.47843 .64705 Mdot
.48235 .6392 Mdot
.50196 .6392 Mdot
.50196 .63136 Mdot
.49804 .63528 Mdot
.4902 .63136 Mdot
.4902 .64705 Mdot
.4902 .65097 Mdot
.49804 .65881 Mdot
.50588 .66665 Mdot
.51372 .6745 Mdot
.52157 .68626 Mdot
.52157 .67842 Mdot
.52549 .67842 Mdot
.52941 .67842 Mdot
.52941 .67057 Mdot
.53333 .67057 Mdot
.55294 .68234 Mdot
.56078 .69018 Mdot
.56078 .6941 Mdot
.55294 .68626 Mdot
.55294 .68626 Mdot
.5647 .69802 Mdot
.58039 .70587 Mdot
.59215 .71371 Mdot
.59215 .70979 Mdot
.59999 .71763 Mdot
.58823 .70587 Mdot
.59999 .70587 Mdot
.61568 .71371 Mdot
.61176 .71371 Mdot
.60391 .71763 Mdot
.60783 .72155 Mdot
.60783 .72547 Mdot
.62744 .73724 Mdot
.61568 .72939 Mdot
.62352 .73724 Mdot
.62352 .749 Mdot
.62352 .74508 Mdot
.64313 .749 Mdot
.6392 .74116 Mdot
.64705 .72939 Mdot
.65489 .73724 Mdot
.65489 .73724 Mdot
.65097 .73332 Mdot
.64705 .72547 Mdot
.65881 .72939 Mdot
.66665 .72547 Mdot
.6745 .72939 Mdot
.6745 .72939 Mdot
.66665 .73332 Mdot
.65881 .73332 Mdot
.65881 .74116 Mdot
.66273 .73724 Mdot
.66665 .73724 Mdot
.67057 .73724 Mdot
.67057 .74116 Mdot
.66665 .74116 Mdot
.67057 .749 Mdot
.66665 .73332 Mdot
.67057 .74116 Mdot
.67842 .74508 Mdot
.67842 .74116 Mdot
.68626 .749 Mdot
.68626 .749 Mdot
.67842 .73724 Mdot
.67842 .73724 Mdot
.67842 .73724 Mdot
.6745 .72939 Mdot
.67842 .72939 Mdot
.68626 .72939 Mdot
.68626 .72155 Mdot
.68234 .72547 Mdot
.68234 .72547 Mdot
.6941 .73332 Mdot
.69018 .73724 Mdot
.6941 .73724 Mdot
.68626 .72939 Mdot
.67842 .72547 Mdot
.69018 .72939 Mdot
.68626 .72939 Mdot
.69018 .73332 Mdot
.68626 .72155 Mdot
.68626 .72155 Mdot
.69018 .72547 Mdot
.69802 .72939 Mdot
.69802 .72547 Mdot
.68234 .71763 Mdot
.69018 .72939 Mdot
.69018 .72939 Mdot
.69018 .73724 Mdot
.67842 .73332 Mdot
.68234 .74116 Mdot
.68234 .73724 Mdot
.67842 .72547 Mdot
.6745 .71763 Mdot
.67057 .71371 Mdot
.67057 .71371 Mdot
.67057 .71763 Mdot
.67057 .72155 Mdot
.6745 .72547 Mdot
.68234 .73332 Mdot
.67057 .71763 Mdot
.6745 .71763 Mdot
.67842 .71763 Mdot
.67057 .70587 Mdot
.67057 .70194 Mdot
.6745 .69802 Mdot
.66665 .69018 Mdot
.66273 .68234 Mdot
.65097 .6745 Mdot
.65489 .68626 Mdot
.65097 .68626 Mdot
.64313 .68234 Mdot
.6392 .68234 Mdot
.64705 .6941 Mdot
.64705 .6941 Mdot
.65097 .69802 Mdot
.65097 .6941 Mdot
.63528 .67842 Mdot
.6392 .68626 Mdot
.63528 .68626 Mdot
.63136 .69018 Mdot
.6196 .68626 Mdot
.6196 .6745 Mdot
.60391 .65881 Mdot
.59607 .65881 Mdot
.59607 .65881 Mdot
.59215 .65489 Mdot
.59215 .65489 Mdot
.59215 .65097 Mdot
.58823 .64313 Mdot
.58039 .62744 Mdot
.5647 .62352 Mdot
.56078 .62744 Mdot
.56078 .62352 Mdot
.54509 .60391 Mdot
.54509 .59607 Mdot
.54509 .58823 Mdot
.48235 .52941 Mdot
.45491 .50196 Mdot
.40393 .45491 Mdot
.36472 .41569 Mdot
.251 .30198 Mdot
.20002 .26276 Mdot
.24316 .30198 Mdot
.31766 .35687 Mdot
.41569 .43922 Mdot
.53725 .55686 Mdot
.41961 .52549 Mdot
.47451 .60391 Mdot
.48628 .6392 Mdot
.4902 .65097 Mdot
.47843 .64705 Mdot
.48628 .64705 Mdot
.47843 .63528 Mdot
.48235 .63136 Mdot
.48628 .63136 Mdot
.50196 .65097 Mdot
.49804 .65489 Mdot
.4902 .65489 Mdot
.48628 .65489 Mdot
.49412 .65489 Mdot
.50196 .65881 Mdot
.5098 .66665 Mdot
.52157 .67842 Mdot
.52157 .68234 Mdot
.52549 .68234 Mdot
.52157 .6745 Mdot
.53333 .6745 Mdot
.54117 .67842 Mdot
.55686 .6941 Mdot
.55294 .69018 Mdot
.55686 .6941 Mdot
.55294 .6941 Mdot
.55686 .70194 Mdot
.55294 .69802 Mdot
.56078 .70194 Mdot
.58039 .70979 Mdot
.58431 .71371 Mdot
.59215 .71763 Mdot
.59215 .71371 Mdot
.58039 .70587 Mdot
.58039 .70587 Mdot
.58431 .70979 Mdot
.58823 .71371 Mdot
.59607 .71763 Mdot
.60391 .72939 Mdot
.60783 .72939 Mdot
.61176 .72939 Mdot
.61176 .73332 Mdot
.62352 .74116 Mdot
.61176 .74508 Mdot
.6196 .749 Mdot
.63528 .75292 Mdot
.6392 .74508 Mdot
.64705 .74116 Mdot
.65489 .74508 Mdot
.65489 .74508 Mdot
.64705 .73724 Mdot
.65097 .73724 Mdot
.64705 .72939 Mdot
.65097 .72547 Mdot
.65489 .73724 Mdot
.65881 .749 Mdot
.65489 .74508 Mdot
.65489 .74508 Mdot
.65489 .73724 Mdot
.66273 .74116 Mdot
.65881 .74116 Mdot
.65489 .73724 Mdot
.65097 .74116 Mdot
.66273 .749 Mdot
.66273 .749 Mdot
.66665 .75292 Mdot
.67057 .749 Mdot
.67057 .749 Mdot
.66273 .74508 Mdot
.67057 .74116 Mdot
.66665 .73724 Mdot
.66665 .74116 Mdot
.66273 .73332 Mdot
.67057 .72939 Mdot
.67057 .72939 Mdot
.67842 .73724 Mdot
.68234 .73724 Mdot
.68234 .73724 Mdot
.6745 .72939 Mdot
.67842 .72939 Mdot
.67842 .73332 Mdot
.68234 .73724 Mdot
.67842 .73332 Mdot
.68234 .72939 Mdot
.68234 .72939 Mdot
.67842 .72547 Mdot
.68234 .72939 Mdot
.67842 .73724 Mdot
.67842 .73724 Mdot
.68234 .73332 Mdot
.69018 .73724 Mdot
.67842 .72939 Mdot
.67057 .72155 Mdot
.67057 .72547 Mdot
.67842 .73724 Mdot
.69018 .749 Mdot
.67842 .74116 Mdot
.67842 .75292 Mdot
.67842 .74508 Mdot
.66273 .72939 Mdot
.66273 .71763 Mdot
.67057 .72155 Mdot
.6745 .72939 Mdot
.67057 .73332 Mdot
.66273 .73332 Mdot
.66665 .73332 Mdot
.66665 .72547 Mdot
.66273 .71371 Mdot
.66273 .70979 Mdot
.66665 .70979 Mdot
.6745 .72155 Mdot
.67057 .71763 Mdot
.66273 .70194 Mdot
.67057 .70587 Mdot
.66273 .70194 Mdot
.64705 .69802 Mdot
.64313 .69802 Mdot
.65489 .69802 Mdot
.65097 .68626 Mdot
.64313 .68626 Mdot
.64313 .69018 Mdot
.63528 .69018 Mdot
.6392 .69802 Mdot
.63528 .6941 Mdot
.62744 .69018 Mdot
.63136 .6941 Mdot
.62352 .6941 Mdot
.60783 .67842 Mdot
.60783 .6745 Mdot
.60783 .6745 Mdot
.60783 .6745 Mdot
.59607 .66665 Mdot
.59607 .66665 Mdot
.59607 .66665 Mdot
.59607 .66273 Mdot
.59215 .65489 Mdot
.58431 .64705 Mdot
.58431 .64705 Mdot
.57646 .63528 Mdot
.58039 .62744 Mdot
.57254 .6196 Mdot
.56078 .61176 Mdot
.56078 .61176 Mdot
.54902 .60783 Mdot
.54117 .60391 Mdot
.52941 .58823 Mdot
.51765 .58039 Mdot
.50588 .57254 Mdot
.47451 .54902 Mdot
.47059 .54902 Mdot
.47059 .55686 Mdot
.47843 .56078 Mdot
.40785 .47843 Mdot
.14513 .22747 Mdot
.20394 .25884 Mdot
.27845 .32943 Mdot
.51372 .54117 Mdot
.42354 .52549 Mdot
.45491 .58431 Mdot
.47451 .61568 Mdot
.48628 .6392 Mdot
.47451 .64705 Mdot
.47843 .65489 Mdot
.48235 .65489 Mdot
.48235 .65489 Mdot
.48235 .65097 Mdot
.48235 .64705 Mdot
.48628 .64705 Mdot
.48235 .65097 Mdot
.48628 .65881 Mdot
.4902 .65489 Mdot
.49804 .65881 Mdot
.50196 .65881 Mdot
.51372 .66665 Mdot
.52549 .6745 Mdot
.51765 .67842 Mdot
.51372 .6745 Mdot
.52157 .6745 Mdot
.52941 .6745 Mdot
.53725 .68234 Mdot
.54117 .68234 Mdot
.53725 .69018 Mdot
.53725 .6941 Mdot
.54117 .70194 Mdot
.53725 .70587 Mdot
.54902 .70587 Mdot
.55686 .70979 Mdot
.5647 .70979 Mdot
.56862 .72547 Mdot
.57254 .72547 Mdot
.56078 .71763 Mdot
.5647 .72547 Mdot
.56862 .71763 Mdot
.5647 .71371 Mdot
.57646 .72155 Mdot
.58039 .72939 Mdot
.58431 .74116 Mdot
.58823 .74116 Mdot
.58431 .73332 Mdot
.60391 .74116 Mdot
.60783 .74508 Mdot
.60783 .749 Mdot
.61568 .74508 Mdot
.63136 .749 Mdot
.63136 .72939 Mdot
.6392 .74116 Mdot
.64705 .749 Mdot
.64705 .749 Mdot
.64313 .74508 Mdot
.64313 .74116 Mdot
.64705 .74508 Mdot
.65097 .749 Mdot
.64313 .74508 Mdot
.64705 .749 Mdot
.64705 .74508 Mdot
.64313 .74508 Mdot
.64705 .74116 Mdot
.65097 .74508 Mdot
.65097 .75292 Mdot
.65097 .75684 Mdot
.65881 .76076 Mdot
.65881 .76076 Mdot
.65881 .75684 Mdot
.65489 .75684 Mdot
.65489 .749 Mdot
.65881 .749 Mdot
.66665 .749 Mdot
.6745 .74116 Mdot
.66665 .72939 Mdot
.66273 .72547 Mdot
.66665 .72939 Mdot
.68234 .74116 Mdot
.67842 .74116 Mdot
.67842 .74508 Mdot
.6745 .749 Mdot
.6745 .76076 Mdot
.67057 .76076 Mdot
.67057 .75684 Mdot
.67057 .75292 Mdot
.65881 .73332 Mdot
.65881 .72547 Mdot
.66665 .73332 Mdot
.66273 .72939 Mdot
.66273 .72547 Mdot
.66665 .73724 Mdot
.66273 .74116 Mdot
.67057 .749 Mdot
.6745 .75684 Mdot
.67057 .75292 Mdot
.67057 .749 Mdot
.66273 .73724 Mdot
.65489 .72939 Mdot
.66273 .73332 Mdot
.66273 .73332 Mdot
.66665 .73724 Mdot
.6745 .73724 Mdot
.66665 .73332 Mdot
.66273 .73332 Mdot
.66273 .73332 Mdot
.66665 .74116 Mdot
.66665 .74116 Mdot
.66665 .749 Mdot
.65489 .73332 Mdot
.65881 .72939 Mdot
.65881 .72155 Mdot
.65097 .70979 Mdot
.65881 .70979 Mdot
.65489 .71371 Mdot
.66273 .71763 Mdot
.66273 .71763 Mdot
.66273 .72155 Mdot
.65489 .72155 Mdot
.64705 .70979 Mdot
.64313 .70587 Mdot
.6392 .70194 Mdot
.6392 .69802 Mdot
.6392 .6941 Mdot
.63136 .69802 Mdot
.6392 .71371 Mdot
.6392 .71763 Mdot
.62744 .71371 Mdot
.62744 .71371 Mdot
.62352 .70979 Mdot
.60783 .70194 Mdot
.59607 .69018 Mdot
.59999 .68626 Mdot
.59999 .67842 Mdot
.59215 .6745 Mdot
.58823 .6745 Mdot
.58039 .66273 Mdot
.57646 .66273 Mdot
.57646 .65881 Mdot
.57646 .66665 Mdot
.57254 .65881 Mdot
.57254 .65097 Mdot
.56862 .64705 Mdot
.5647 .63528 Mdot
.55686 .6196 Mdot
.55686 .61176 Mdot
.56078 .6196 Mdot
.55294 .61568 Mdot
.54509 .60391 Mdot
.52549 .58431 Mdot
.51372 .57646 Mdot
.5098 .57646 Mdot
.50588 .57254 Mdot
.49412 .57254 Mdot
.4902 .58039 Mdot
.48235 .57254 Mdot
.47843 .56862 Mdot
.4353 .52157 Mdot
.43138 .50588 Mdot
.20002 .28237 Mdot
.07454 .15297 Mdot
.04709 .09807 Mdot
.50196 .52157 Mdot
.75292 .75684 Mdot
.41569 .51372 Mdot
.47059 .58431 Mdot
.48235 .61176 Mdot
.48235 .62744 Mdot
.47451 .64705 Mdot
.47059 .65097 Mdot
.45098 .64313 Mdot
.45098 .65097 Mdot
.45883 .65489 Mdot
.47451 .65489 Mdot
.47451 .64313 Mdot
.48235 .64705 Mdot
.48235 .65489 Mdot
.4902 .65489 Mdot
.49412 .65097 Mdot
.49804 .64313 Mdot
.51372 .6392 Mdot
.52157 .64313 Mdot
.51765 .64705 Mdot
.51765 .67057 Mdot
.5098 .67057 Mdot
.51765 .6745 Mdot
.52941 .67842 Mdot
.53333 .68234 Mdot
.53725 .69018 Mdot
.53725 .70194 Mdot
.52941 .70194 Mdot
.53725 .70979 Mdot
.53725 .69802 Mdot
.54117 .69802 Mdot
.55686 .70587 Mdot
.56078 .71371 Mdot
.5647 .72547 Mdot
.56078 .72547 Mdot
.5647 .73332 Mdot
.56862 .72939 Mdot
.5647 .70979 Mdot
.56862 .71371 Mdot
.58039 .72547 Mdot
.57646 .72939 Mdot
.57254 .72547 Mdot
.57254 .72547 Mdot
.58823 .72939 Mdot
.60783 .74508 Mdot
.60783 .74116 Mdot
.61568 .74116 Mdot
.62744 .74116 Mdot
.63528 .74116 Mdot
.63528 .73724 Mdot
.6392 .73724 Mdot
.64313 .74508 Mdot
.64705 .75292 Mdot
.6392 .749 Mdot
.64313 .75292 Mdot
.65097 .75684 Mdot
.63528 .74508 Mdot
.64705 .75684 Mdot
.65097 .75684 Mdot
.64705 .75684 Mdot
.6392 .749 Mdot
.6392 .73724 Mdot
.6392 .74508 Mdot
.64313 .749 Mdot
.64313 .75292 Mdot
.65097 .749 Mdot
.65097 .74508 Mdot
.65097 .73724 Mdot
.65489 .749 Mdot
.65097 .74116 Mdot
.65489 .73724 Mdot
.66273 .73332 Mdot
.65881 .72547 Mdot
.66273 .72155 Mdot
.66665 .73332 Mdot
.65881 .72155 Mdot
.66273 .73724 Mdot
.66665 .75684 Mdot
.6745 .76861 Mdot
.67057 .76469 Mdot
.67057 .76469 Mdot
.66273 .75684 Mdot
.65489 .75292 Mdot
.64705 .74508 Mdot
.65097 .73332 Mdot
.65489 .73332 Mdot
.66273 .73724 Mdot
.66273 .72547 Mdot
.65881 .72547 Mdot
.66665 .72939 Mdot
.66273 .73332 Mdot
.66273 .74508 Mdot
.66665 .74116 Mdot
.66273 .73724 Mdot
.65489 .73332 Mdot
.65097 .72547 Mdot
.65489 .72939 Mdot
.65881 .73332 Mdot
.65489 .72547 Mdot
.66273 .72939 Mdot
.65881 .73332 Mdot
.64313 .71763 Mdot
.65489 .72547 Mdot
.65881 .72939 Mdot
.65489 .72939 Mdot
.65097 .72547 Mdot
.64705 .72155 Mdot
.65489 .72155 Mdot
.65097 .71371 Mdot
.65097 .71371 Mdot
.65489 .70979 Mdot
.64705 .70979 Mdot
.6392 .71371 Mdot
.63528 .71371 Mdot
.63528 .70194 Mdot
.64705 .70979 Mdot
.64313 .71371 Mdot
.62744 .70587 Mdot
.62352 .70194 Mdot
.62352 .68626 Mdot
.62352 .68234 Mdot
.62352 .68234 Mdot
.63136 .70194 Mdot
.63136 .71763 Mdot
.61176 .70979 Mdot
.61568 .71371 Mdot
.59999 .69802 Mdot
.59607 .68626 Mdot
.61176 .70587 Mdot
.59999 .69802 Mdot
.59215 .6941 Mdot
.58823 .68626 Mdot
.58039 .67057 Mdot
.57646 .65881 Mdot
.57646 .65489 Mdot
.58039 .66273 Mdot
.57646 .66273 Mdot
.56078 .65489 Mdot
.56078 .64313 Mdot
.56078 .62744 Mdot
.55294 .61176 Mdot
.54902 .60783 Mdot
.55686 .6196 Mdot
.54902 .62744 Mdot
.54117 .61568 Mdot
.53725 .60783 Mdot
.5098 .57646 Mdot
.51372 .58431 Mdot
.51372 .58431 Mdot
.51765 .59215 Mdot
.5098 .58823 Mdot
.5098 .58431 Mdot
.49804 .57646 Mdot
.48628 .55686 Mdot
.47843 .54509 Mdot
.45883 .52157 Mdot
.48235 .53333 Mdot
.21571 .27845 Mdot
.03925 .09415 Mdot
.03141 .0667 Mdot
.02357 .04709 Mdot
.41961 .53333 Mdot
.47451 .59607 Mdot
.48628 .62352 Mdot
.48235 .64705 Mdot
.47843 .66665 Mdot
.46667 .66273 Mdot
.45491 .65097 Mdot
.45491 .64705 Mdot
.45883 .64313 Mdot
.46275 .6392 Mdot
.48235 .64705 Mdot
.4902 .65097 Mdot
.48628 .66273 Mdot
.49412 .67057 Mdot
.5098 .6745 Mdot
.50196 .65097 Mdot
.5098 .65097 Mdot
.51372 .64705 Mdot
.51372 .65489 Mdot
.51765 .67842 Mdot
.51372 .69018 Mdot
.51372 .69018 Mdot
.52157 .68626 Mdot
.52157 .6745 Mdot
.53333 .69018 Mdot
.52941 .70194 Mdot
.53333 .71371 Mdot
.52941 .70979 Mdot
.53725 .69802 Mdot
.55294 .6941 Mdot
.57254 .70979 Mdot
.55686 .6941 Mdot
.56862 .71763 Mdot
.56862 .72547 Mdot
.56862 .72547 Mdot
.57254 .72155 Mdot
.57254 .70587 Mdot
.57646 .70587 Mdot
.58039 .70587 Mdot
.57646 .70194 Mdot
.58431 .70979 Mdot
.58823 .71371 Mdot
.59215 .71763 Mdot
.60783 .72547 Mdot
.61176 .73332 Mdot
.60783 .72547 Mdot
.6196 .73724 Mdot
.62744 .72939 Mdot
.63528 .72547 Mdot
.64313 .73332 Mdot
.63528 .73724 Mdot
.6392 .74508 Mdot
.64705 .75684 Mdot
.64705 .75292 Mdot
.62744 .74116 Mdot
.62744 .74116 Mdot
.63528 .73724 Mdot
.64705 .75292 Mdot
.64705 .76076 Mdot
.64313 .75684 Mdot
.64313 .749 Mdot
.65097 .74508 Mdot
.64705 .749 Mdot
.65489 .75292 Mdot
.65097 .74116 Mdot
.64313 .73332 Mdot
.65489 .73724 Mdot
.65489 .73724 Mdot
.65489 .73724 Mdot
.65097 .72939 Mdot
.65097 .71763 Mdot
.65097 .70979 Mdot
.65489 .71371 Mdot
.65097 .71763 Mdot
.65489 .72939 Mdot
.65881 .74508 Mdot
.65881 .75684 Mdot
.65097 .75292 Mdot
.65489 .75684 Mdot
.65881 .76469 Mdot
.65097 .75684 Mdot
.65097 .75684 Mdot
.65881 .75292 Mdot
.65489 .73724 Mdot
.66273 .73724 Mdot
.66273 .72939 Mdot
.65881 .72547 Mdot
.65489 .72155 Mdot
.66273 .72547 Mdot
.66273 .72547 Mdot
.66665 .73724 Mdot
.65881 .72939 Mdot
.65881 .72939 Mdot
.65881 .73332 Mdot
.65097 .72939 Mdot
.65097 .72939 Mdot
.65489 .72547 Mdot
.65489 .72547 Mdot
.65097 .72939 Mdot
.65881 .73332 Mdot
.65881 .72939 Mdot
.65881 .72547 Mdot
.65489 .71763 Mdot
.66273 .71763 Mdot
.65881 .72547 Mdot
.65881 .72547 Mdot
.66273 .72155 Mdot
.65881 .71763 Mdot
.66273 .71763 Mdot
.65489 .70979 Mdot
.64705 .71371 Mdot
.63528 .70587 Mdot
.63528 .70587 Mdot
.62744 .70587 Mdot
.62744 .70587 Mdot
.62352 .70979 Mdot
.62352 .70587 Mdot
.62352 .70587 Mdot
.63136 .70587 Mdot
.6196 .6941 Mdot
.6196 .69018 Mdot
.63136 .70194 Mdot
.6196 .70979 Mdot
.62352 .72547 Mdot
.61176 .71763 Mdot
.60391 .70194 Mdot
.60391 .6941 Mdot
.60783 .69802 Mdot
.60783 .70194 Mdot
.59215 .68234 Mdot
.58431 .68234 Mdot
.58039 .67842 Mdot
.56862 .66665 Mdot
.57646 .6745 Mdot
.57646 .67057 Mdot
.56862 .6745 Mdot
.55294 .66273 Mdot
.54902 .64705 Mdot
.54509 .63136 Mdot
.54117 .62352 Mdot
.54117 .61568 Mdot
.54902 .62352 Mdot
.53333 .6196 Mdot
.52941 .6196 Mdot
.52941 .61568 Mdot
.5098 .58431 Mdot
.51372 .57646 Mdot
.52157 .58431 Mdot
.51765 .59215 Mdot
.5098 .59215 Mdot
.50588 .58823 Mdot
.48628 .5647 Mdot
.47843 .54117 Mdot
.48235 .54117 Mdot
.47451 .52549 Mdot
.47843 .52941 Mdot
.46667 .51765 Mdot
.18434 .26668 Mdot
.14513 .21963 Mdot
.12552 .18434 Mdot
.41569 .54509 Mdot
.47451 .6196 Mdot
.49412 .64705 Mdot
.48628 .65097 Mdot
.48235 .66273 Mdot
.47059 .66273 Mdot
.46667 .65881 Mdot
.47059 .65489 Mdot
.47843 .65097 Mdot
.4902 .64705 Mdot
.4902 .65097 Mdot
.49412 .65881 Mdot
.49804 .66273 Mdot
.50196 .67057 Mdot
.50588 .66665 Mdot
.5098 .65881 Mdot
.51372 .65489 Mdot
.52157 .66665 Mdot
.52157 .67057 Mdot
.52157 .68234 Mdot
.52157 .6941 Mdot
.51372 .6941 Mdot
.51372 .68626 Mdot
.52549 .68234 Mdot
.53333 .68234 Mdot
.54117 .69802 Mdot
.53725 .69802 Mdot
.53333 .69018 Mdot
.54509 .69018 Mdot
.56078 .6941 Mdot
.5647 .68626 Mdot
.56862 .68626 Mdot
.57254 .70194 Mdot
.57254 .70979 Mdot
.57646 .71763 Mdot
.56862 .70587 Mdot
.58823 .70979 Mdot
.58431 .70979 Mdot
.58823 .70979 Mdot
.58431 .71371 Mdot
.59215 .71763 Mdot
.59215 .70194 Mdot
.60783 .70194 Mdot
.61176 .71371 Mdot
.6196 .73332 Mdot
.6196 .74508 Mdot
.6196 .74116 Mdot
.6196 .73332 Mdot
.63136 .73724 Mdot
.64705 .75292 Mdot
.64313 .74508 Mdot
.64313 .75292 Mdot
.64705 .749 Mdot
.64313 .749 Mdot
.64313 .75292 Mdot
.6392 .749 Mdot
.65097 .75292 Mdot
.64705 .75684 Mdot
.64313 .76076 Mdot
.6392 .75684 Mdot
.64705 .75292 Mdot
.64705 .74116 Mdot
.64313 .73332 Mdot
.65489 .73724 Mdot
.65881 .749 Mdot
.65097 .74116 Mdot
.64705 .73724 Mdot
.65489 .74116 Mdot
.65489 .74508 Mdot
.6392 .73332 Mdot
.64313 .72939 Mdot
.64313 .72155 Mdot
.65097 .72155 Mdot
.64313 .71763 Mdot
.65097 .72547 Mdot
.65881 .74508 Mdot
.65881 .75684 Mdot
.65097 .75292 Mdot
.65097 .75684 Mdot
.64705 .75292 Mdot
.65489 .75684 Mdot
.65881 .76861 Mdot
.65489 .76469 Mdot
.65881 .75292 Mdot
.65881 .74116 Mdot
.66273 .74508 Mdot
.67057 .749 Mdot
.6745 .75292 Mdot
.6745 .75292 Mdot
.67057 .749 Mdot
.66665 .74116 Mdot
.67057 .73332 Mdot
.66665 .72939 Mdot
.66273 .72939 Mdot
.66273 .73332 Mdot
.65489 .73332 Mdot
.65489 .72939 Mdot
.65097 .72939 Mdot
.65881 .74508 Mdot
.65097 .73332 Mdot
.65097 .72939 Mdot
.65489 .73332 Mdot
.67057 .749 Mdot
.6745 .74508 Mdot
.67842 .74508 Mdot
.66665 .74116 Mdot
.66273 .73724 Mdot
.66273 .72939 Mdot
.65489 .71371 Mdot
.64705 .70979 Mdot
.65097 .71763 Mdot
.64313 .71763 Mdot
.63528 .70979 Mdot
.63136 .71371 Mdot
.62352 .70587 Mdot
.61176 .69802 Mdot
.61568 .70194 Mdot
.6196 .70587 Mdot
.62352 .70587 Mdot
.62352 .70587 Mdot
.6196 .69802 Mdot
.62744 .70979 Mdot
.61176 .70979 Mdot
.61176 .72155 Mdot
.59999 .70979 Mdot
.60391 .70587 Mdot
.60783 .70587 Mdot
.60391 .6941 Mdot
.60391 .69802 Mdot
.59607 .70587 Mdot
.58039 .6941 Mdot
.57646 .68626 Mdot
.57646 .67842 Mdot
.57254 .67057 Mdot
.57646 .6745 Mdot
.57254 .67842 Mdot
.5647 .6745 Mdot
.54902 .65881 Mdot
.54117 .63528 Mdot
.54509 .62744 Mdot
.54117 .60783 Mdot
.55294 .61568 Mdot
.54509 .6196 Mdot
.53725 .61568 Mdot
.54117 .60391 Mdot
.52549 .58431 Mdot
.52549 .58039 Mdot
.52941 .58431 Mdot
.52549 .58823 Mdot
.52941 .60391 Mdot
.51372 .60391 Mdot
.49412 .59607 Mdot
.48235 .58431 Mdot
.4902 .57646 Mdot
.49412 .56078 Mdot
.4902 .54902 Mdot
.47843 .54117 Mdot
.45491 .52941 Mdot
.40001 .48235 Mdot
.3804 .45491 Mdot
.40785 .54509 Mdot
.46275 .6196 Mdot
.48235 .64313 Mdot
.47451 .64313 Mdot
.48628 .65881 Mdot
.47843 .65881 Mdot
.46667 .65097 Mdot
.47059 .64313 Mdot
.46275 .6392 Mdot
.47843 .64705 Mdot
.4902 .65097 Mdot
.49412 .65097 Mdot
.49412 .65881 Mdot
.49804 .66273 Mdot
.50196 .66273 Mdot
.50588 .65097 Mdot
.52157 .65881 Mdot
.52549 .67057 Mdot
.52157 .6745 Mdot
.51372 .6745 Mdot
.5098 .6745 Mdot
.51372 .67842 Mdot
.52549 .69802 Mdot
.52941 .70194 Mdot
.52941 .69802 Mdot
.53725 .70194 Mdot
.53333 .69802 Mdot
.54902 .69802 Mdot
.56078 .70194 Mdot
.55686 .6941 Mdot
.55686 .6941 Mdot
.56078 .70194 Mdot
.56862 .70194 Mdot
.56862 .70587 Mdot
.57254 .70979 Mdot
.58039 .70979 Mdot
.59607 .71763 Mdot
.58823 .71763 Mdot
.58039 .71371 Mdot
.58039 .70979 Mdot
.58431 .70587 Mdot
.58823 .70194 Mdot
.59999 .70587 Mdot
.60783 .70587 Mdot
.61176 .72547 Mdot
.60391 .73332 Mdot
.60783 .73724 Mdot
.62352 .74116 Mdot
.61568 .73332 Mdot
.61176 .73332 Mdot
.61176 .73724 Mdot
.62352 .74508 Mdot
.62744 .749 Mdot
.62744 .75292 Mdot
.62744 .75292 Mdot
.62744 .76076 Mdot
.62744 .76861 Mdot
.63528 .77253 Mdot
.63136 .77253 Mdot
.63528 .76469 Mdot
.6392 .76469 Mdot
.64313 .75292 Mdot
.64313 .749 Mdot
.65097 .75292 Mdot
.64313 .73724 Mdot
.64705 .73724 Mdot
.65097 .74116 Mdot
.64705 .749 Mdot
.64705 .75684 Mdot
.63528 .75292 Mdot
.63136 .749 Mdot
.63528 .74508 Mdot
.64313 .73724 Mdot
.64705 .73724 Mdot
.64313 .72547 Mdot
.64313 .73724 Mdot
.6392 .74116 Mdot
.6392 .749 Mdot
.64313 .749 Mdot
.64705 .749 Mdot
.65097 .749 Mdot
.65489 .76076 Mdot
.65881 .77253 Mdot
.65881 .76469 Mdot
.65489 .75292 Mdot
.64705 .75292 Mdot
.64705 .75292 Mdot
.65881 .75684 Mdot
.66273 .76076 Mdot
.65881 .76076 Mdot
.66273 .75684 Mdot
.65881 .74116 Mdot
.65489 .73724 Mdot
.64705 .74116 Mdot
.65097 .74116 Mdot
.64705 .73724 Mdot
.65489 .74116 Mdot
.64705 .73724 Mdot
.65489 .75292 Mdot
.65489 .75684 Mdot
.65489 .75292 Mdot
.65097 .74508 Mdot
.65097 .74116 Mdot
.65097 .749 Mdot
.65489 .749 Mdot
.64705 .749 Mdot
.64705 .74508 Mdot
.6392 .72939 Mdot
.64705 .72547 Mdot
.64705 .72939 Mdot
.6392 .73332 Mdot
.6392 .73332 Mdot
.63136 .72155 Mdot
.62744 .71371 Mdot
.62744 .71763 Mdot
.62744 .71763 Mdot
.62352 .71371 Mdot
.62352 .71763 Mdot
.6196 .70979 Mdot
.61176 .70194 Mdot
.61176 .70194 Mdot
.61176 .70587 Mdot
.60783 .69802 Mdot
.59999 .6941 Mdot
.59215 .70194 Mdot
.58431 .69802 Mdot
.59607 .70194 Mdot
.59215 .70194 Mdot
.58039 .69018 Mdot
.59215 .70587 Mdot
.59215 .70587 Mdot
.57646 .69802 Mdot
.5647 .68234 Mdot
.56862 .67842 Mdot
.56078 .65489 Mdot
.55294 .65097 Mdot
.55686 .65489 Mdot
.55294 .65489 Mdot
.55294 .65097 Mdot
.54509 .63528 Mdot
.54117 .61568 Mdot
.54509 .60783 Mdot
.53725 .61176 Mdot
.52157 .60391 Mdot
.52157 .59607 Mdot
.52157 .59215 Mdot
.51765 .58823 Mdot
.51765 .58431 Mdot
.5098 .58431 Mdot
.51372 .59607 Mdot
.50588 .59999 Mdot
.50196 .59999 Mdot
.49412 .59215 Mdot
.49412 .58431 Mdot
.49804 .59215 Mdot
.48235 .57254 Mdot
.47059 .54902 Mdot
.46275 .54117 Mdot
.44706 .52157 Mdot
.41569 .48235 Mdot
.38432 .53725 Mdot
.45883 .63136 Mdot
.46275 .65097 Mdot
.46667 .64705 Mdot
.47059 .65489 Mdot
.47451 .65097 Mdot
.47059 .65097 Mdot
.46667 .64705 Mdot
.45883 .64705 Mdot
.47059 .65097 Mdot
.48628 .65881 Mdot
.48235 .65097 Mdot
.48628 .65097 Mdot
.50196 .66273 Mdot
.51765 .66665 Mdot
.51765 .66273 Mdot
.52549 .66665 Mdot
.53725 .67842 Mdot
.52157 .66665 Mdot
.51765 .66665 Mdot
.51765 .66665 Mdot
.51765 .66665 Mdot
.51765 .68234 Mdot
.52941 .70194 Mdot
.52941 .70194 Mdot
.53333 .70587 Mdot
.53333 .70194 Mdot
.53725 .70587 Mdot
.54509 .70979 Mdot
.54117 .69802 Mdot
.55294 .69802 Mdot
.56078 .70587 Mdot
.56078 .69802 Mdot
.56862 .70979 Mdot
.57254 .71371 Mdot
.57646 .72155 Mdot
.57646 .71371 Mdot
.57254 .71371 Mdot
.56862 .71371 Mdot
.57646 .71371 Mdot
.57646 .71371 Mdot
.58431 .71371 Mdot
.58431 .70979 Mdot
.58039 .70587 Mdot
.59607 .72547 Mdot
.59215 .72939 Mdot
.59607 .73724 Mdot
.60391 .749 Mdot
.60783 .73724 Mdot
.61176 .73332 Mdot
.62352 .749 Mdot
.6196 .75684 Mdot
.61568 .75684 Mdot
.6196 .75292 Mdot
.6196 .75292 Mdot
.63136 .76076 Mdot
.62352 .76469 Mdot
.6196 .76469 Mdot
.6196 .76469 Mdot
.62744 .76469 Mdot
.63136 .76861 Mdot
.62352 .75292 Mdot
.64313 .75684 Mdot
.64705 .75292 Mdot
.64313 .74116 Mdot
.64705 .73724 Mdot
.64705 .74116 Mdot
.63528 .74116 Mdot
.64313 .76076 Mdot
.64313 .76861 Mdot
.62744 .76469 Mdot
.62352 .76076 Mdot
.63528 .75292 Mdot
.6392 .749 Mdot
.63528 .74508 Mdot
.63528 .749 Mdot
.63528 .74508 Mdot
.63136 .74508 Mdot
.63528 .749 Mdot
.65097 .75684 Mdot
.65097 .75292 Mdot
.65489 .75684 Mdot
.64705 .76469 Mdot
.64705 .76469 Mdot
.65097 .76861 Mdot
.64313 .76469 Mdot
.64313 .76469 Mdot
.65097 .77253 Mdot
.65489 .77645 Mdot
.64705 .77645 Mdot
.65097 .77645 Mdot
.64313 .76469 Mdot
.64705 .76469 Mdot
.64705 .76469 Mdot
.64705 .76469 Mdot
.63528 .75684 Mdot
.6392 .75292 Mdot
.64313 .75292 Mdot
.64313 .75292 Mdot
.64313 .75684 Mdot
.64313 .76076 Mdot
.64705 .76076 Mdot
.63528 .74508 Mdot
.6392 .74508 Mdot
.64313 .74116 Mdot
.6392 .74116 Mdot
.63528 .74116 Mdot
.63528 .74116 Mdot
.6392 .74116 Mdot
.6392 .73724 Mdot
.6392 .73332 Mdot
.6392 .73332 Mdot
.63528 .73724 Mdot
.63136 .72547 Mdot
.62744 .71763 Mdot
.63136 .72547 Mdot
.62744 .72547 Mdot
.6196 .72155 Mdot
.61568 .71763 Mdot
.59999 .70194 Mdot
.60391 .70194 Mdot
.61176 .70587 Mdot
.60783 .70194 Mdot
.59607 .6941 Mdot
.59215 .6941 Mdot
.59607 .6941 Mdot
.59215 .6941 Mdot
.59607 .70194 Mdot
.59215 .69018 Mdot
.58039 .68234 Mdot
.58039 .68626 Mdot
.56862 .67842 Mdot
.56862 .68234 Mdot
.56862 .67842 Mdot
.56078 .66665 Mdot
.54902 .65097 Mdot
.54509 .64705 Mdot
.54902 .64705 Mdot
.54902 .6392 Mdot
.54509 .63136 Mdot
.54509 .62744 Mdot
.53725 .6196 Mdot
.52941 .61568 Mdot
.51765 .61176 Mdot
.51765 .61568 Mdot
.51765 .60783 Mdot
.51372 .59607 Mdot
.51372 .58823 Mdot
.50588 .58823 Mdot
.50588 .59999 Mdot
.50588 .59999 Mdot
.4902 .58823 Mdot
.48628 .58039 Mdot
.48235 .58039 Mdot
.47451 .57254 Mdot
.47059 .55686 Mdot
.45883 .54902 Mdot
.45491 .53725 Mdot
.44314 .5098 Mdot
.43138 .4902 Mdot
.40785 .54509 Mdot
.44706 .62352 Mdot
.45883 .65489 Mdot
.47059 .6745 Mdot
.46667 .6745 Mdot
.46667 .67057 Mdot
.45098 .65489 Mdot
.45491 .65489 Mdot
.45883 .65489 Mdot
.47843 .65881 Mdot
.47451 .64705 Mdot
.48628 .65097 Mdot
.49412 .65489 Mdot
.4902 .65097 Mdot
.5098 .65881 Mdot
.51765 .65881 Mdot
.52157 .66273 Mdot
.53333 .68234 Mdot
.5098 .67057 Mdot
.51765 .67057 Mdot
.52157 .67057 Mdot
.52157 .67057 Mdot
.51765 .67057 Mdot
.53725 .69018 Mdot
.53333 .6941 Mdot
.54117 .69802 Mdot
.54117 .70194 Mdot
.53333 .69802 Mdot
.54902 .70194 Mdot
.55686 .70194 Mdot
.56862 .70587 Mdot
.57254 .71371 Mdot
.58039 .72547 Mdot
.56862 .71763 Mdot
.57254 .72547 Mdot
.57254 .72547 Mdot
.57254 .71763 Mdot
.57254 .71371 Mdot
.57254 .72547 Mdot
.57254 .72155 Mdot
.57646 .72155 Mdot
.56862 .71763 Mdot
.58039 .71371 Mdot
.58039 .70979 Mdot
.58039 .71371 Mdot
.58823 .72155 Mdot
.59215 .73724 Mdot
.59607 .74508 Mdot
.58823 .73332 Mdot
.61568 .749 Mdot
.61568 .74116 Mdot
.61568 .74508 Mdot
.61176 .75292 Mdot
.61568 .75684 Mdot
.60783 .75684 Mdot
.61568 .76076 Mdot
.6196 .76076 Mdot
.62744 .75684 Mdot
.62352 .75292 Mdot
.6196 .75292 Mdot
.62352 .75684 Mdot
.62352 .749 Mdot
.63136 .749 Mdot
.6392 .74508 Mdot
.6392 .74508 Mdot
.6392 .74508 Mdot
.63528 .74116 Mdot
.63528 .74116 Mdot
.63528 .74508 Mdot
.6392 .749 Mdot
.64313 .76076 Mdot
.64313 .75684 Mdot
.6392 .75292 Mdot
.63528 .75292 Mdot
.63528 .749 Mdot
.63528 .75292 Mdot
.63136 .75684 Mdot
.63528 .76469 Mdot
.63528 .75684 Mdot
.65097 .76469 Mdot
.64313 .75292 Mdot
.6392 .75292 Mdot
.64705 .75684 Mdot
.64313 .75292 Mdot
.64313 .76469 Mdot
.65097 .77645 Mdot
.65489 .78429 Mdot
.65489 .77645 Mdot
.65489 .77645 Mdot
.64705 .77253 Mdot
.64705 .76469 Mdot
.64705 .76469 Mdot
.64313 .76469 Mdot
.65489 .77253 Mdot
.64705 .76469 Mdot
.6392 .76469 Mdot
.63528 .76861 Mdot
.63136 .76469 Mdot
.6392 .76469 Mdot
.6392 .75684 Mdot
.64313 .75292 Mdot
.64313 .75292 Mdot
.63136 .74508 Mdot
.6392 .74116 Mdot
.64313 .73724 Mdot
.6392 .74116 Mdot
.63528 .73724 Mdot
.64313 .749 Mdot
.64313 .74508 Mdot
.63528 .73724 Mdot
.63528 .72939 Mdot
.63528 .73332 Mdot
.63528 .73332 Mdot
.63136 .72155 Mdot
.6196 .71371 Mdot
.62352 .71763 Mdot
.6196 .70979 Mdot
.62744 .71763 Mdot
.61176 .70979 Mdot
.60783 .70979 Mdot
.60783 .70587 Mdot
.60783 .70587 Mdot
.60391 .70587 Mdot
.59607 .70194 Mdot
.59215 .69018 Mdot
.59607 .68626 Mdot
.59999 .6941 Mdot
.59215 .6941 Mdot
.59999 .70194 Mdot
.59215 .69018 Mdot
.58431 .67842 Mdot
.57646 .6745 Mdot
.56862 .67842 Mdot
.56078 .67057 Mdot
.56862 .6745 Mdot
.57254 .67057 Mdot
.56078 .65489 Mdot
.55686 .65489 Mdot
.54509 .64313 Mdot
.54509 .64313 Mdot
.54902 .64705 Mdot
.54509 .6392 Mdot
.53333 .62744 Mdot
.52549 .63136 Mdot
.52549 .62744 Mdot
.52157 .61568 Mdot
.52549 .61176 Mdot
.52549 .61176 Mdot
.52157 .61568 Mdot
.50588 .6196 Mdot
.4902 .61568 Mdot
.47843 .60391 Mdot
.47451 .59215 Mdot
.47059 .58431 Mdot
.47451 .57646 Mdot
.47059 .56862 Mdot
.46667 .55686 Mdot
.45491 .54117 Mdot
.45098 .51765 Mdot
.43138 .48628 Mdot
.39609 .54117 Mdot
.44706 .61568 Mdot
.45098 .64313 Mdot
.45883 .65881 Mdot
.45491 .66273 Mdot
.44314 .65881 Mdot
.4353 .65097 Mdot
.45491 .66665 Mdot
.45098 .65881 Mdot
.45883 .65881 Mdot
.46667 .65489 Mdot
.46667 .65097 Mdot
.47059 .64313 Mdot
.4902 .65489 Mdot
.4902 .65881 Mdot
.50588 .67057 Mdot
.5098 .67057 Mdot
.51765 .6745 Mdot
.51765 .6745 Mdot
.51765 .67057 Mdot
.52549 .67057 Mdot
.52941 .67842 Mdot
.52941 .67842 Mdot
.53333 .6745 Mdot
.53333 .67057 Mdot
.53725 .67842 Mdot
.52941 .67842 Mdot
.53725 .68626 Mdot
.54117 .68626 Mdot
.54902 .68626 Mdot
.55686 .69018 Mdot
.55686 .69802 Mdot
.56862 .71371 Mdot
.56862 .72155 Mdot
.5647 .72155 Mdot
.5647 .72547 Mdot
.56078 .72155 Mdot
.56862 .71371 Mdot
.5647 .70587 Mdot
.56862 .71371 Mdot
.57646 .72547 Mdot
.57254 .72155 Mdot
.57646 .71763 Mdot
.57646 .70587 Mdot
.57254 .70194 Mdot
.58039 .70979 Mdot
.59607 .72939 Mdot
.59607 .73724 Mdot
.59215 .72939 Mdot
.59215 .73724 Mdot
.59999 .74508 Mdot
.59607 .74116 Mdot
.59607 .74508 Mdot
.60391 .76076 Mdot
.60783 .76469 Mdot
.60391 .76076 Mdot
.59999 .75292 Mdot
.61176 .75292 Mdot
.60391 .74508 Mdot
.61568 .749 Mdot
.61176 .74116 Mdot
.62352 .74508 Mdot
.62744 .74116 Mdot
.62744 .73332 Mdot
.6196 .72939 Mdot
.62352 .73724 Mdot
.63136 .74116 Mdot
.62352 .73724 Mdot
.63136 .74116 Mdot
.62744 .73724 Mdot
.63136 .74508 Mdot
.62744 .74116 Mdot
.63528 .75292 Mdot
.63136 .749 Mdot
.62352 .74116 Mdot
.62352 .74508 Mdot
.6196 .749 Mdot
.62352 .75684 Mdot
.63136 .77253 Mdot
.63528 .77253 Mdot
.63528 .76076 Mdot
.63528 .75684 Mdot
.63136 .75292 Mdot
.62744 .75292 Mdot
.63528 .75292 Mdot
.6392 .76469 Mdot
.64705 .77253 Mdot
.6392 .76469 Mdot
.64313 .75684 Mdot
.63528 .749 Mdot
.63528 .75684 Mdot
.63136 .75292 Mdot
.62744 .749 Mdot
.6392 .75292 Mdot
.63528 .76076 Mdot
.64313 .76469 Mdot
.6392 .76469 Mdot
.63136 .76076 Mdot
.63136 .75684 Mdot
.62352 .75292 Mdot
.63136 .749 Mdot
.63136 .74508 Mdot
.63136 .74508 Mdot
.62352 .73332 Mdot
.62352 .73332 Mdot
.62352 .73332 Mdot
.62744 .74116 Mdot
.64313 .75292 Mdot
.64313 .75684 Mdot
.63528 .74508 Mdot
.62352 .73332 Mdot
.61568 .72547 Mdot
.61568 .72155 Mdot
.62744 .72155 Mdot
.6196 .70979 Mdot
.61568 .70979 Mdot
.62352 .71763 Mdot
.61568 .72547 Mdot
.60391 .71763 Mdot
.60391 .71371 Mdot
.60391 .70979 Mdot
.59999 .6941 Mdot
.59607 .69018 Mdot
.58823 .68626 Mdot
.58823 .68626 Mdot
.59215 .68626 Mdot
.59607 .69018 Mdot
.58431 .69018 Mdot
.58823 .69018 Mdot
.57646 .69018 Mdot
.57646 .6941 Mdot
.57254 .68626 Mdot
.5647 .6745 Mdot
.55294 .65881 Mdot
.54902 .65489 Mdot
.56078 .66665 Mdot
.55294 .65489 Mdot
.56078 .65489 Mdot
.55294 .65097 Mdot
.54117 .64313 Mdot
.54117 .64313 Mdot
.52941 .63136 Mdot
.52157 .62352 Mdot
.52157 .62352 Mdot
.51765 .61568 Mdot
.5098 .60391 Mdot
.50588 .59999 Mdot
.50588 .59607 Mdot
.5098 .59999 Mdot
.51372 .61568 Mdot
.5098 .62744 Mdot
.48628 .61568 Mdot
.47059 .59999 Mdot
.46667 .58823 Mdot
.46275 .57646 Mdot
.45491 .55294 Mdot
.45491 .54117 Mdot
.44706 .52549 Mdot
.4353 .50196 Mdot
.4353 .48628 Mdot
.41177 .54902 Mdot
.4353 .60783 Mdot
.4353 .63136 Mdot
.43922 .6392 Mdot
.44706 .65097 Mdot
.45491 .65881 Mdot
.44706 .65489 Mdot
.44314 .65881 Mdot
.43138 .64705 Mdot
.44706 .65881 Mdot
.45883 .66273 Mdot
.45883 .65097 Mdot
.47451 .65881 Mdot
.48628 .65881 Mdot
.48628 .65881 Mdot
.50196 .66273 Mdot
.50196 .65881 Mdot
.50588 .66273 Mdot
.49804 .65881 Mdot
.49804 .65881 Mdot
.49804 .65881 Mdot
.50588 .66665 Mdot
.5098 .66665 Mdot
.5098 .66273 Mdot
.51372 .66273 Mdot
.52157 .67057 Mdot
.53333 .67842 Mdot
.53725 .68626 Mdot
.54117 .6941 Mdot
.54509 .6941 Mdot
.53725 .68234 Mdot
.53725 .69018 Mdot
.55294 .70194 Mdot
.5647 .71371 Mdot
.56078 .72155 Mdot
.55294 .71763 Mdot
.5647 .72155 Mdot
.56078 .70194 Mdot
.56862 .70194 Mdot
.55686 .69802 Mdot
.55686 .71763 Mdot
.55686 .71763 Mdot
.55294 .70587 Mdot
.56078 .70587 Mdot
.5647 .70587 Mdot
.57646 .70979 Mdot
.58039 .71371 Mdot
.58431 .71763 Mdot
.59215 .72547 Mdot
.57646 .72155 Mdot
.58039 .73332 Mdot
.58431 .72939 Mdot
.58431 .72939 Mdot
.58823 .73332 Mdot
.58431 .73332 Mdot
.58039 .73724 Mdot
.57646 .74116 Mdot
.58431 .74116 Mdot
.58431 .72939 Mdot
.58039 .72939 Mdot
.59999 .749 Mdot
.59215 .74116 Mdot
.59607 .72939 Mdot
.61176 .73332 Mdot
.61176 .72939 Mdot
.61176 .72939 Mdot
.61176 .73332 Mdot
.61568 .74116 Mdot
.61176 .72939 Mdot
.61176 .72939 Mdot
.60783 .72547 Mdot
.61568 .72939 Mdot
.61568 .73724 Mdot
.6196 .73724 Mdot
.61176 .72547 Mdot
.61568 .73332 Mdot
.62352 .749 Mdot
.62352 .75684 Mdot
.6196 .75292 Mdot
.62352 .76469 Mdot
.62352 .76469 Mdot
.63136 .76469 Mdot
.6196 .75292 Mdot
.62744 .75292 Mdot
.62352 .74508 Mdot
.6196 .749 Mdot
.62352 .74508 Mdot
.6196 .73724 Mdot
.6196 .73724 Mdot
.61568 .73332 Mdot
.62352 .74508 Mdot
.6196 .74116 Mdot
.61176 .72939 Mdot
.6196 .74116 Mdot
.62744 .75292 Mdot
.6196 .75292 Mdot
.62352 .75292 Mdot
.61568 .749 Mdot
.61568 .749 Mdot
.61568 .74116 Mdot
.61176 .72939 Mdot
.6196 .72547 Mdot
.62744 .72939 Mdot
.6196 .73332 Mdot
.61568 .72939 Mdot
.61176 .72155 Mdot
.61176 .72155 Mdot
.61568 .72939 Mdot
.61568 .72547 Mdot
.6196 .72939 Mdot
.6196 .72939 Mdot
.61176 .71763 Mdot
.60783 .71371 Mdot
.60783 .71763 Mdot
.60783 .71371 Mdot
.60783 .72155 Mdot
.60783 .72155 Mdot
.59999 .72155 Mdot
.58823 .71371 Mdot
.58431 .70587 Mdot
.59215 .70587 Mdot
.58823 .6941 Mdot
.58823 .68626 Mdot
.58039 .67842 Mdot
.57646 .67842 Mdot
.58039 .67842 Mdot
.56862 .67842 Mdot
.5647 .67842 Mdot
.55686 .66665 Mdot
.55686 .66665 Mdot
.56078 .6745 Mdot
.5647 .68626 Mdot
.55686 .67842 Mdot
.55686 .67057 Mdot
.54902 .66273 Mdot
.54117 .65097 Mdot
.53725 .64313 Mdot
.54117 .64705 Mdot
.53725 .64705 Mdot
.52941 .6392 Mdot
.52549 .63528 Mdot
.52157 .63528 Mdot
.50588 .62352 Mdot
.50196 .62352 Mdot
.50588 .62744 Mdot
.49804 .6196 Mdot
.4902 .60783 Mdot
.49804 .60783 Mdot
.50196 .61176 Mdot
.49412 .59607 Mdot
.4902 .59607 Mdot
.47451 .59215 Mdot
.46275 .58823 Mdot
.47059 .59215 Mdot
.45098 .56862 Mdot
.44706 .55294 Mdot
.44314 .53725 Mdot
.43922 .51372 Mdot
.43138 .49804 Mdot
.41177 .46667 Mdot
.40001 .5647 Mdot
.41961 .61568 Mdot
.43138 .64705 Mdot
.4353 .65097 Mdot
.44314 .65097 Mdot
.46275 .66273 Mdot
.45491 .66273 Mdot
.45098 .67057 Mdot
.44706 .66665 Mdot
.45491 .66665 Mdot
.45883 .65881 Mdot
.47059 .65881 Mdot
.47059 .65881 Mdot
.47843 .65881 Mdot
.48235 .65881 Mdot
.49412 .66273 Mdot
.49804 .66273 Mdot
.50196 .66273 Mdot
.5098 .66273 Mdot
.49412 .65489 Mdot
.49804 .65881 Mdot
.50588 .66665 Mdot
.50588 .67057 Mdot
.5098 .67057 Mdot
.50588 .66665 Mdot
.5098 .65881 Mdot
.52941 .67842 Mdot
.53333 .6941 Mdot
.52941 .69802 Mdot
.53333 .6941 Mdot
.54902 .6941 Mdot
.54902 .6941 Mdot
.54902 .69018 Mdot
.55294 .70194 Mdot
.55686 .72155 Mdot
.54902 .72155 Mdot
.54509 .72155 Mdot
.55294 .72547 Mdot
.56078 .71763 Mdot
.5647 .72547 Mdot
.56078 .73332 Mdot
.55294 .72939 Mdot
.55294 .71763 Mdot
.55686 .70979 Mdot
.56078 .70979 Mdot
.56862 .70979 Mdot
.58039 .71763 Mdot
.58039 .72547 Mdot
.59215 .73332 Mdot
.58823 .73332 Mdot
.58431 .72939 Mdot
.58431 .73332 Mdot
.58823 .73332 Mdot
.57646 .72547 Mdot
.58039 .73724 Mdot
.58431 .74116 Mdot
.58039 .74116 Mdot
.59215 .74508 Mdot
.60391 .75292 Mdot
.59607 .749 Mdot
.59607 .749 Mdot
.59215 .74116 Mdot
.60391 .74116 Mdot
.59999 .73724 Mdot
.60391 .749 Mdot
.61568 .75684 Mdot
.6196 .75292 Mdot
.61176 .74508 Mdot
.60391 .73724 Mdot
.61568 .73724 Mdot
.61568 .73332 Mdot
.61176 .72547 Mdot
.61568 .73332 Mdot
.6196 .74508 Mdot
.6196 .73724 Mdot
.61176 .72547 Mdot
.62352 .74116 Mdot
.6196 .76076 Mdot
.62352 .76469 Mdot
.62744 .76861 Mdot
.62744 .76861 Mdot
.63136 .76861 Mdot
.63136 .76861 Mdot
.63136 .76861 Mdot
.62352 .76861 Mdot
.62352 .76469 Mdot
.62744 .76076 Mdot
.62744 .75684 Mdot
.6196 .749 Mdot
.61176 .74116 Mdot
.60783 .749 Mdot
.61568 .75684 Mdot
.61176 .749 Mdot
.61176 .74116 Mdot
.61568 .74116 Mdot
.61568 .75292 Mdot
.60783 .75292 Mdot
.6196 .76076 Mdot
.61568 .75684 Mdot
.6196 .749 Mdot
.6196 .73724 Mdot
.62352 .73332 Mdot
.62744 .72547 Mdot
.63136 .72547 Mdot
.63528 .72547 Mdot
.63136 .72939 Mdot
.63136 .73724 Mdot
.62744 .74116 Mdot
.62744 .74508 Mdot
.63136 .74508 Mdot
.62352 .73724 Mdot
.61568 .72939 Mdot
.62352 .72939 Mdot
.61568 .72939 Mdot
.62352 .74508 Mdot
.6196 .73724 Mdot
.6196 .73724 Mdot
.61176 .72547 Mdot
.60783 .72939 Mdot
.60391 .72155 Mdot
.60391 .72155 Mdot
.59215 .71371 Mdot
.59215 .71371 Mdot
.58823 .71371 Mdot
.58431 .70979 Mdot
.57254 .69802 Mdot
.56862 .69802 Mdot
.56862 .6941 Mdot
.56862 .68234 Mdot
.57254 .68626 Mdot
.57254 .67842 Mdot
.57254 .69018 Mdot
.5647 .6941 Mdot
.55686 .68234 Mdot
.55294 .67842 Mdot
.55686 .68234 Mdot
.54902 .66665 Mdot
.55686 .6745 Mdot
.54509 .66273 Mdot
.53333 .65097 Mdot
.52941 .65097 Mdot
.52549 .65097 Mdot
.51372 .6392 Mdot
.51765 .65489 Mdot
.51765 .65881 Mdot
.51765 .65489 Mdot
.49804 .6392 Mdot
.4902 .63528 Mdot
.48628 .63136 Mdot
.4902 .6196 Mdot
.4902 .61176 Mdot
.47451 .60783 Mdot
.47059 .61176 Mdot
.47843 .61568 Mdot
.46275 .58823 Mdot
.46275 .57646 Mdot
.45491 .55294 Mdot
.44706 .52549 Mdot
.44314 .50588 Mdot
.43922 .48235 Mdot
.41569 .58039 Mdot
.45883 .65489 Mdot
.46275 .67057 Mdot
.45883 .66665 Mdot
.45098 .65489 Mdot
.45883 .66273 Mdot
.46667 .67842 Mdot
.46667 .68234 Mdot
.45883 .67057 Mdot
.45098 .66273 Mdot
.46667 .65881 Mdot
.48235 .66665 Mdot
.47843 .66273 Mdot
.4902 .66665 Mdot
.49412 .66665 Mdot
.49804 .66273 Mdot
.50196 .65489 Mdot
.5098 .65489 Mdot
.51765 .66273 Mdot
.52549 .6745 Mdot
.52157 .67842 Mdot
.51765 .68626 Mdot
.51765 .69018 Mdot
.51765 .69018 Mdot
.52549 .69802 Mdot
.52549 .69802 Mdot
.52941 .69802 Mdot
.53333 .69802 Mdot
.53725 .69018 Mdot
.54117 .6941 Mdot
.54117 .69018 Mdot
.54902 .69802 Mdot
.5647 .70587 Mdot
.55294 .70194 Mdot
.56078 .72547 Mdot
.56078 .73724 Mdot
.55294 .72939 Mdot
.54902 .71371 Mdot
.54902 .71371 Mdot
.5647 .73332 Mdot
.56862 .73332 Mdot
.56078 .73332 Mdot
.55294 .72155 Mdot
.5647 .70979 Mdot
.57646 .70979 Mdot
.58039 .70587 Mdot
.58823 .71371 Mdot
.59607 .71763 Mdot
.59607 .71371 Mdot
.59215 .70587 Mdot
.59607 .71371 Mdot
.59215 .71763 Mdot
.60783 .72547 Mdot
.59215 .72155 Mdot
.59607 .72547 Mdot
.60391 .73724 Mdot
.60391 .73724 Mdot
.59607 .73332 Mdot
.60391 .74116 Mdot
.61176 .74508 Mdot
.61176 .73724 Mdot
.60391 .73332 Mdot
.61176 .73332 Mdot
.61176 .74116 Mdot
.61176 .74508 Mdot
.6196 .75292 Mdot
.6196 .75684 Mdot
.6196 .75292 Mdot
.62352 .76076 Mdot
.6196 .75292 Mdot
.62744 .74508 Mdot
.61568 .72939 Mdot
.60783 .71763 Mdot
.62352 .73332 Mdot
.63136 .74116 Mdot
.6196 .72939 Mdot
.62744 .73332 Mdot
.63528 .749 Mdot
.63136 .76076 Mdot
.63136 .76861 Mdot
.63136 .76861 Mdot
.6392 .76469 Mdot
.6392 .76469 Mdot
.63528 .76469 Mdot
.62352 .76076 Mdot
.62352 .76076 Mdot
.62352 .76469 Mdot
.61568 .75684 Mdot
.6196 .75292 Mdot
.61568 .75292 Mdot
.61568 .76076 Mdot
.6196 .76076 Mdot
.61176 .749 Mdot
.63136 .74116 Mdot
.63136 .73724 Mdot
.62744 .73724 Mdot
.61568 .74116 Mdot
.61568 .749 Mdot
.61568 .74508 Mdot
.62352 .749 Mdot
.62744 .749 Mdot
.63136 .74508 Mdot
.6196 .72547 Mdot
.62352 .72155 Mdot
.62744 .71763 Mdot
.62744 .71763 Mdot
.62744 .72547 Mdot
.62744 .72547 Mdot
.63136 .73724 Mdot
.62352 .73724 Mdot
.62744 .73332 Mdot
.62744 .72939 Mdot
.61568 .71371 Mdot
.61568 .70979 Mdot
.61176 .71371 Mdot
.6196 .72155 Mdot
.6196 .72155 Mdot
.61176 .70979 Mdot
.60391 .70979 Mdot
.59999 .70587 Mdot
.59999 .70979 Mdot
.60391 .70979 Mdot
.59999 .70979 Mdot
.59215 .71371 Mdot
.58431 .71371 Mdot
.57646 .70979 Mdot
.57646 .69802 Mdot
.58039 .6941 Mdot
.58039 .68626 Mdot
.57646 .69018 Mdot
.56862 .68234 Mdot
.56078 .67057 Mdot
.56078 .67057 Mdot
.56078 .6745 Mdot
.54509 .66273 Mdot
.54902 .67057 Mdot
.54509 .65489 Mdot
.54509 .65489 Mdot
.54117 .64705 Mdot
.53333 .63528 Mdot
.52549 .63528 Mdot
.52549 .64705 Mdot
.51765 .64313 Mdot
.51765 .64705 Mdot
.52157 .66273 Mdot
.50196 .65097 Mdot
.48235 .63136 Mdot
.48628 .63136 Mdot
.48235 .62352 Mdot
.47843 .60783 Mdot
.47059 .59607 Mdot
.47059 .59215 Mdot
.47451 .59999 Mdot
.46667 .59607 Mdot
.45883 .57646 Mdot
.46667 .56862 Mdot
.45883 .55686 Mdot
.45491 .53333 Mdot
.43922 .50196 Mdot
.41569 .46667 Mdot
.39609 .54117 Mdot
.43922 .61568 Mdot
.44706 .64705 Mdot
.43922 .64313 Mdot
.45491 .65489 Mdot
.45098 .65881 Mdot
.45098 .65881 Mdot
.46275 .66273 Mdot
.46667 .66273 Mdot
.46667 .66273 Mdot
.46667 .65881 Mdot
.47451 .66273 Mdot
.48235 .66273 Mdot
.48628 .66273 Mdot
.48628 .65489 Mdot
.49412 .65097 Mdot
.50196 .65097 Mdot
.51765 .66665 Mdot
.5098 .65881 Mdot
.52549 .6745 Mdot
.51765 .68234 Mdot
.51765 .6941 Mdot
.51765 .70979 Mdot
.5098 .70587 Mdot
.5098 .70587 Mdot
.51765 .70194 Mdot
.52157 .70194 Mdot
.52549 .69802 Mdot
.53333 .6941 Mdot
.53725 .69802 Mdot
.54509 .70194 Mdot
.54902 .70587 Mdot
.55294 .71371 Mdot
.54902 .71763 Mdot
.55686 .72547 Mdot
.5647 .72939 Mdot
.54902 .71371 Mdot
.54509 .71763 Mdot
.55294 .72155 Mdot
.56862 .72547 Mdot
.56078 .71371 Mdot
.55294 .70194 Mdot
.56078 .70587 Mdot
.56078 .70587 Mdot
.57254 .70979 Mdot
.57646 .70979 Mdot
.57646 .70587 Mdot
.58039 .70587 Mdot
.58431 .70194 Mdot
.58823 .69802 Mdot
.59999 .70587 Mdot
.59215 .70587 Mdot
.59999 .71371 Mdot
.59607 .70979 Mdot
.59607 .71763 Mdot
.59607 .72155 Mdot
.59607 .72547 Mdot
.60391 .73332 Mdot
.61176 .74508 Mdot
.60783 .74508 Mdot
.60391 .72939 Mdot
.60783 .73332 Mdot
.61568 .73724 Mdot
.6196 .74116 Mdot
.6196 .749 Mdot
.6196 .75292 Mdot
.61176 .749 Mdot
.60783 .74508 Mdot
.61568 .75292 Mdot
.61176 .74508 Mdot
.61176 .73332 Mdot
.6196 .72939 Mdot
.6196 .72939 Mdot
.6196 .72939 Mdot
.62744 .72155 Mdot
.63136 .72547 Mdot
.63136 .72939 Mdot
.63136 .72939 Mdot
.6196 .72547 Mdot
.62352 .73724 Mdot
.62744 .749 Mdot
.63528 .75292 Mdot
.62744 .74508 Mdot
.63136 .75684 Mdot
.63136 .76076 Mdot
.63136 .76469 Mdot
.62744 .76076 Mdot
.63136 .76469 Mdot
.62744 .75292 Mdot
.62744 .75292 Mdot
.63136 .75292 Mdot
.63136 .74508 Mdot
.63528 .73724 Mdot
.63528 .72939 Mdot
.62352 .71763 Mdot
.6196 .72155 Mdot
.63136 .73724 Mdot
.62744 .74116 Mdot
.61176 .73724 Mdot
.61568 .74116 Mdot
.62744 .749 Mdot
.63136 .74508 Mdot
.6196 .72547 Mdot
.62352 .72547 Mdot
.62744 .72547 Mdot
.62352 .71763 Mdot
.63528 .72547 Mdot
.63136 .72155 Mdot
.6196 .71763 Mdot
.61568 .71763 Mdot
.60783 .71763 Mdot
.61568 .72155 Mdot
.61568 .71371 Mdot
.59999 .69802 Mdot
.60783 .70587 Mdot
.60783 .71371 Mdot
.60391 .71371 Mdot
.59999 .70979 Mdot
.59999 .71371 Mdot
.59607 .70587 Mdot
.59607 .6941 Mdot
.59999 .68626 Mdot
.59999 .68626 Mdot
.60391 .70194 Mdot
.58431 .70194 Mdot
.58039 .6941 Mdot
.57646 .69018 Mdot
.5647 .67842 Mdot
.58039 .69018 Mdot
.58431 .6941 Mdot
.57254 .67842 Mdot
.55686 .66273 Mdot
.5647 .66273 Mdot
.55686 .65489 Mdot
.55686 .66665 Mdot
.54902 .65881 Mdot
.53333 .64313 Mdot
.53725 .6392 Mdot
.52941 .6196 Mdot
.52549 .61568 Mdot
.52941 .62352 Mdot
.51372 .6196 Mdot
.52157 .62744 Mdot
.51765 .63136 Mdot
.51765 .64313 Mdot
.50588 .64313 Mdot
.4902 .6392 Mdot
.49412 .63136 Mdot
.50588 .62744 Mdot
.48628 .60783 Mdot
.48235 .60391 Mdot
.46667 .58823 Mdot
.45883 .57646 Mdot
.47059 .58823 Mdot
.46667 .58431 Mdot
.45883 .57254 Mdot
.45098 .56078 Mdot
.44314 .53725 Mdot
.4353 .50588 Mdot
.41177 .46275 Mdot
.39609 .54509 Mdot
.4353 .60783 Mdot
.45098 .64313 Mdot
.45491 .65881 Mdot
.44706 .65097 Mdot
.45491 .65097 Mdot
.45098 .65097 Mdot
.47059 .66665 Mdot
.47451 .67057 Mdot
.48235 .6745 Mdot
.47451 .66665 Mdot
.47451 .65881 Mdot
.47843 .65097 Mdot
.48628 .64705 Mdot
.4902 .64313 Mdot
.49804 .65097 Mdot
.50196 .65489 Mdot
.5098 .66665 Mdot
.49804 .66273 Mdot
.50588 .67842 Mdot
.51372 .68626 Mdot
.51765 .69018 Mdot
.5098 .69018 Mdot
.5098 .69802 Mdot
.50588 .69018 Mdot
.50196 .68234 Mdot
.50588 .67842 Mdot
.51372 .67842 Mdot
.52549 .68234 Mdot
.52941 .68234 Mdot
.52941 .69018 Mdot
.54117 .70194 Mdot
.53725 .70194 Mdot
.53725 .70194 Mdot
.54117 .69802 Mdot
.54509 .6941 Mdot
.56078 .71371 Mdot
.56078 .71763 Mdot
.55686 .71371 Mdot
.56862 .72155 Mdot
.5647 .70194 Mdot
.5647 .70194 Mdot
.55686 .69802 Mdot
.5647 .70979 Mdot
.5647 .70587 Mdot
.57254 .70979 Mdot
.5647 .70194 Mdot
.56862 .70194 Mdot
.56078 .69802 Mdot
.58039 .70587 Mdot
.59215 .70979 Mdot
.59215 .71371 Mdot
.58823 .72155 Mdot
.58823 .72547 Mdot
.59215 .72547 Mdot
.59999 .72939 Mdot
.59999 .72547 Mdot
.59215 .72547 Mdot
.60391 .73724 Mdot
.61176 .74508 Mdot
.61176 .74116 Mdot
.61176 .73332 Mdot
.61176 .72547 Mdot
.60783 .72939 Mdot
.61176 .74508 Mdot
.60783 .74116 Mdot
.60391 .73724 Mdot
.59999 .72939 Mdot
.60783 .72939 Mdot
.60783 .72547 Mdot
.60391 .71371 Mdot
.60783 .71763 Mdot
.60391 .71371 Mdot
.60391 .70587 Mdot
.60783 .69802 Mdot
.62352 .70979 Mdot
.62744 .72547 Mdot
.62744 .72547 Mdot
.6196 .71763 Mdot
.63136 .72547 Mdot
.62744 .72939 Mdot
.63528 .74508 Mdot
.63528 .74508 Mdot
.63136 .75292 Mdot
.63136 .76469 Mdot
.62744 .76076 Mdot
.63528 .76861 Mdot
.62744 .76076 Mdot
.62352 .75684 Mdot
.6196 .749 Mdot
.6196 .74116 Mdot
.61176 .72155 Mdot
.61568 .71371 Mdot
.61568 .71763 Mdot
.61568 .71371 Mdot
.61568 .71371 Mdot
.61568 .72939 Mdot
.61568 .74116 Mdot
.61568 .74116 Mdot
.6196 .73724 Mdot
.61568 .72155 Mdot
.62352 .72155 Mdot
.62352 .72155 Mdot
.61176 .71371 Mdot
.62352 .72547 Mdot
.62352 .72547 Mdot
.62352 .72155 Mdot
.62744 .72939 Mdot
.6196 .72547 Mdot
.61176 .72547 Mdot
.59607 .70979 Mdot
.59607 .70979 Mdot
.60391 .71763 Mdot
.59999 .70587 Mdot
.59999 .70194 Mdot
.59999 .70979 Mdot
.59999 .71763 Mdot
.58823 .71371 Mdot
.58039 .70587 Mdot
.58431 .70194 Mdot
.59215 .70194 Mdot
.59215 .6941 Mdot
.58431 .68626 Mdot
.58431 .69018 Mdot
.58431 .70194 Mdot
.57254 .6941 Mdot
.5647 .68626 Mdot
.55686 .66665 Mdot
.5647 .6745 Mdot
.5647 .67057 Mdot
.56078 .66273 Mdot
.55294 .65097 Mdot
.54902 .65489 Mdot
.53333 .64313 Mdot
.53333 .6392 Mdot
.53725 .6392 Mdot
.52941 .63528 Mdot
.52941 .64313 Mdot
.52157 .63136 Mdot
.51765 .6196 Mdot
.51372 .60783 Mdot
.50196 .60391 Mdot
.51372 .62352 Mdot
.50196 .62352 Mdot
.5098 .62744 Mdot
.50588 .63528 Mdot
.49804 .63136 Mdot
.4902 .62352 Mdot
.4902 .61568 Mdot
.48235 .59999 Mdot
.47843 .58431 Mdot
.47451 .57646 Mdot
.45883 .57254 Mdot
.45883 .58039 Mdot
.46275 .59215 Mdot
.44314 .56862 Mdot
.4353 .54902 Mdot
.43138 .52941 Mdot
.41569 .49804 Mdot
.40393 .46275 Mdot
.38824 .54117 Mdot
.4353 .60783 Mdot
.45491 .6392 Mdot
.45491 .65097 Mdot
.45098 .65097 Mdot
.45098 .64313 Mdot
.46275 .64313 Mdot
.47843 .65881 Mdot
.48628 .67057 Mdot
.47843 .67057 Mdot
.47451 .66665 Mdot
.47059 .65097 Mdot
.46275 .64705 Mdot
.47451 .64705 Mdot
.48235 .64313 Mdot
.49804 .64705 Mdot
.5098 .66273 Mdot
.5098 .67842 Mdot
.50196 .67842 Mdot
.50588 .67842 Mdot
.50196 .65881 Mdot
.51765 .67057 Mdot
.52157 .68234 Mdot
.51372 .68626 Mdot
.50588 .68626 Mdot
.50588 .67842 Mdot
.50196 .66665 Mdot
.5098 .66273 Mdot
.51372 .65881 Mdot
.51765 .67057 Mdot
.52157 .69018 Mdot
.53333 .70587 Mdot
.54902 .71371 Mdot
.55294 .70194 Mdot
.55686 .6941 Mdot
.55686 .69018 Mdot
.5647 .70587 Mdot
.56078 .71763 Mdot
.5647 .72939 Mdot
.55686 .72155 Mdot
.55686 .71371 Mdot
.55294 .69802 Mdot
.5647 .6941 Mdot
.5647 .69018 Mdot
.57254 .69802 Mdot
.5647 .6941 Mdot
.55294 .69018 Mdot
.56078 .6941 Mdot
.56862 .70194 Mdot
.57254 .70194 Mdot
.58039 .71763 Mdot
.58823 .72547 Mdot
.57646 .72155 Mdot
.58431 .72939 Mdot
.58823 .72939 Mdot
.59607 .72939 Mdot
.59607 .73332 Mdot
.59215 .73724 Mdot
.59999 .73724 Mdot
.59607 .72547 Mdot
.59999 .71763 Mdot
.59607 .70979 Mdot
.60783 .71371 Mdot
.61568 .72155 Mdot
.61176 .72547 Mdot
.60783 .73332 Mdot
.60783 .73724 Mdot
.59215 .71763 Mdot
.59607 .70979 Mdot
.60391 .70587 Mdot
.60783 .70194 Mdot
.60783 .70194 Mdot
.59607 .69802 Mdot
.59999 .70194 Mdot
.60391 .70194 Mdot
.60391 .70194 Mdot
.61568 .71371 Mdot
.62352 .72547 Mdot
.62744 .73332 Mdot
.62744 .72155 Mdot
.62352 .70979 Mdot
.62352 .70979 Mdot
.62352 .71371 Mdot
.63136 .72547 Mdot
.62744 .73724 Mdot
.62744 .74116 Mdot
.62744 .74508 Mdot
.61568 .73332 Mdot
.61176 .73332 Mdot
.61568 .74116 Mdot
.61176 .74116 Mdot
.59999 .72155 Mdot
.60783 .71763 Mdot
.61176 .71763 Mdot
.61568 .72155 Mdot
.6196 .72939 Mdot
.61176 .72939 Mdot
.60391 .73332 Mdot
.61176 .73332 Mdot
.61568 .72547 Mdot
.60783 .71371 Mdot
.6196 .70979 Mdot
.62352 .71763 Mdot
.62352 .72547 Mdot
.61176 .71371 Mdot
.60783 .70587 Mdot
.60391 .69802 Mdot
.61568 .70587 Mdot
.62352 .71371 Mdot
.61176 .70587 Mdot
.59607 .70194 Mdot
.59215 .70979 Mdot
.59215 .70587 Mdot
.59607 .6941 Mdot
.59215 .69018 Mdot
.58431 .6941 Mdot
.58823 .70979 Mdot
.58823 .70979 Mdot
.57646 .70194 Mdot
.57646 .70194 Mdot
.57646 .6941 Mdot
.58039 .6941 Mdot
.56862 .68626 Mdot
.5647 .6941 Mdot
.55294 .68234 Mdot
.55294 .66273 Mdot
.54902 .65489 Mdot
.55686 .65489 Mdot
.55686 .65097 Mdot
.55294 .65097 Mdot
.55686 .64705 Mdot
.54902 .64313 Mdot
.54117 .63136 Mdot
.54509 .6392 Mdot
.53333 .63136 Mdot
.54117 .63136 Mdot
.54117 .6392 Mdot
.53333 .63528 Mdot
.52157 .63528 Mdot
.5098 .61568 Mdot
.50196 .60391 Mdot
.50196 .59999 Mdot
.50588 .61176 Mdot
.50588 .61568 Mdot
.5098 .62744 Mdot
.50196 .62352 Mdot
.49412 .62352 Mdot
.48628 .63136 Mdot
.4902 .62352 Mdot
.48235 .59999 Mdot
.47451 .57646 Mdot
.47843 .58431 Mdot
.46667 .58823 Mdot
.45491 .58823 Mdot
.45098 .59607 Mdot
.43138 .56862 Mdot
.43922 .54902 Mdot
.41569 .5098 Mdot
.41961 .49412 Mdot
.40785 .46667 Mdot
.38432 .52157 Mdot
.43138 .59607 Mdot
.44706 .62352 Mdot
.45098 .64313 Mdot
.44314 .6392 Mdot
.45098 .64313 Mdot
.46275 .63528 Mdot
.45883 .6392 Mdot
.47059 .65489 Mdot
.47843 .66665 Mdot
.47451 .65881 Mdot
.47451 .65489 Mdot
.47059 .65489 Mdot
.47451 .65097 Mdot
.47451 .64705 Mdot
.48235 .64705 Mdot
.4902 .65097 Mdot
.49804 .65881 Mdot
.50196 .66665 Mdot
.50196 .66273 Mdot
.50196 .64705 Mdot
.50196 .6392 Mdot
.51765 .65097 Mdot
.51765 .65881 Mdot
.52157 .67057 Mdot
.51372 .67057 Mdot
.51372 .66665 Mdot
.51765 .66273 Mdot
.52549 .66273 Mdot
.52157 .66273 Mdot
.52549 .6745 Mdot
.52549 .68234 Mdot
.53333 .68234 Mdot
.54509 .68234 Mdot
.54117 .67057 Mdot
.55294 .67842 Mdot
.5647 .69018 Mdot
.57254 .70587 Mdot
.5647 .71371 Mdot
.56862 .71763 Mdot
.5647 .70587 Mdot
.56078 .6941 Mdot
.57254 .6941 Mdot
.56862 .6941 Mdot
.56862 .68234 Mdot
.57254 .68626 Mdot
.57646 .69802 Mdot
.57254 .69018 Mdot
.56078 .6745 Mdot
.57646 .69018 Mdot
.57646 .6941 Mdot
.57646 .70587 Mdot
.58039 .72939 Mdot
.57254 .73332 Mdot
.57646 .72547 Mdot
.58039 .71371 Mdot
.58039 .71371 Mdot
.58039 .71371 Mdot
.58039 .71763 Mdot
.58823 .72547 Mdot
.59607 .72155 Mdot
.59607 .70979 Mdot
.59999 .70194 Mdot
.59999 .70587 Mdot
.59999 .71763 Mdot
.58823 .72155 Mdot
.59215 .71763 Mdot
.59215 .70587 Mdot
.59607 .69018 Mdot
.59999 .68626 Mdot
.60783 .68626 Mdot
.60391 .6941 Mdot
.59999 .69802 Mdot
.59999 .69802 Mdot
.59215 .68626 Mdot
.59999 .69018 Mdot
.59607 .69018 Mdot
.59999 .70979 Mdot
.59999 .71763 Mdot
.59607 .71371 Mdot
.59607 .69802 Mdot
.60783 .6941 Mdot
.6196 .6941 Mdot
.62744 .70194 Mdot
.62352 .70979 Mdot
.62352 .71763 Mdot
.62744 .72547 Mdot
.6196 .71763 Mdot
.61176 .71371 Mdot
.60391 .70979 Mdot
.60391 .72155 Mdot
.59215 .70587 Mdot
.58823 .70587 Mdot
.59215 .70979 Mdot
.59999 .70979 Mdot
.61568 .72547 Mdot
.6196 .73332 Mdot
.59999 .71763 Mdot
.60391 .72547 Mdot
.60391 .71763 Mdot
.59607 .70194 Mdot
.60391 .70194 Mdot
.61176 .69802 Mdot
.6196 .71371 Mdot
.6196 .71371 Mdot
.61176 .70587 Mdot
.60391 .69802 Mdot
.59999 .6941 Mdot
.61176 .70587 Mdot
.60391 .69802 Mdot
.60783 .70979 Mdot
.59607 .71371 Mdot
.58823 .70194 Mdot
.58823 .68626 Mdot
.58039 .67842 Mdot
.58431 .68626 Mdot
.57646 .69018 Mdot
.58039 .70194 Mdot
.58431 .69802 Mdot
.58431 .6941 Mdot
.57254 .67842 Mdot
.56078 .66665 Mdot
.5647 .67842 Mdot
.5647 .68626 Mdot
.54509 .6745 Mdot
.54117 .65097 Mdot
.54902 .64313 Mdot
.56078 .6392 Mdot
.5647 .63136 Mdot
.55686 .63136 Mdot
.55686 .6392 Mdot
.54902 .63528 Mdot
.54902 .6392 Mdot
.54509 .63136 Mdot
.53333 .6196 Mdot
.53333 .61568 Mdot
.53725 .6196 Mdot
.54117 .6392 Mdot
.52157 .63136 Mdot
.50588 .6196 Mdot
.49412 .60783 Mdot
.4902 .59215 Mdot
.50588 .60391 Mdot
.50196 .60391 Mdot
.5098 .61568 Mdot
.51372 .6196 Mdot
.50196 .62352 Mdot
.48628 .6196 Mdot
.48235 .6196 Mdot
.48235 .60783 Mdot
.47843 .59607 Mdot
.47451 .59215 Mdot
.47059 .59999 Mdot
.46275 .59607 Mdot
.45098 .58823 Mdot
.43138 .5647 Mdot
.42354 .52941 Mdot
.42354 .51372 Mdot
.42354 .49412 Mdot
.41569 .46667 Mdot
.38432 .53725 Mdot
.42746 .59999 Mdot
.44314 .62352 Mdot
.45098 .63136 Mdot
.44706 .6392 Mdot
.45098 .64313 Mdot
.45883 .65097 Mdot
.45098 .64313 Mdot
.46667 .65881 Mdot
.47059 .66273 Mdot
.46275 .65489 Mdot
.46667 .65881 Mdot
.47843 .66273 Mdot
.48628 .66665 Mdot
.48628 .66665 Mdot
.48628 .66273 Mdot
.4902 .65881 Mdot
.49804 .66273 Mdot
.50196 .65881 Mdot
.49804 .65097 Mdot
.5098 .65489 Mdot
.51372 .65097 Mdot
.51372 .65489 Mdot
.51372 .66273 Mdot
.5098 .65881 Mdot
.5098 .65881 Mdot
.50588 .65881 Mdot
.5098 .66665 Mdot
.51372 .66273 Mdot
.52157 .67057 Mdot
.52157 .6745 Mdot
.53333 .68234 Mdot
.53333 .67842 Mdot
.54117 .6745 Mdot
.54509 .66665 Mdot
.56078 .67842 Mdot
.56078 .67842 Mdot
.56078 .6745 Mdot
.55686 .68234 Mdot
.56078 .68626 Mdot
.56862 .6941 Mdot
.56078 .69018 Mdot
.55686 .69018 Mdot
.5647 .70194 Mdot
.5647 .69018 Mdot
.56862 .69018 Mdot
.57254 .68626 Mdot
.57254 .69018 Mdot
.57646 .69018 Mdot
.57646 .69802 Mdot
.58039 .70587 Mdot
.58431 .71371 Mdot
.58039 .72939 Mdot
.58039 .73332 Mdot
.58431 .73724 Mdot
.58039 .72939 Mdot
.57254 .72547 Mdot
.57646 .72547 Mdot
.57254 .71763 Mdot
.58039 .71371 Mdot
.59215 .71371 Mdot
.59215 .70587 Mdot
.58823 .70194 Mdot
.60391 .71371 Mdot
.59999 .71371 Mdot
.58431 .71763 Mdot
.59215 .72547 Mdot
.59607 .71763 Mdot
.59607 .70587 Mdot
.60391 .70979 Mdot
.61176 .71371 Mdot
.60391 .70194 Mdot
.60391 .6941 Mdot
.59999 .69018 Mdot
.59999 .68626 Mdot
.59607 .68234 Mdot
.58823 .68234 Mdot
.58823 .69802 Mdot
.58431 .70587 Mdot
.59215 .70979 Mdot
.58823 .70194 Mdot
.60783 .70587 Mdot
.60391 .69802 Mdot
.61568 .70979 Mdot
.61568 .70979 Mdot
.6196 .72155 Mdot
.6196 .72547 Mdot
.61568 .72155 Mdot
.61568 .72939 Mdot
.61176 .72547 Mdot
.60783 .71763 Mdot
.60783 .72155 Mdot
.60783 .72155 Mdot
.59999 .71763 Mdot
.59607 .70979 Mdot
.59607 .70979 Mdot
.59607 .71371 Mdot
.59607 .71763 Mdot
.59215 .71763 Mdot
.59999 .72155 Mdot
.59215 .70979 Mdot
.60391 .71371 Mdot
.60783 .70979 Mdot
.60783 .71371 Mdot
.60783 .70979 Mdot
.60783 .70587 Mdot
.61176 .70587 Mdot
.61568 .70587 Mdot
.61176 .70979 Mdot
.60783 .71371 Mdot
.60391 .71371 Mdot
.59999 .70979 Mdot
.59607 .69018 Mdot
.59215 .68234 Mdot
.58431 .6745 Mdot
.58431 .6745 Mdot
.58431 .68234 Mdot
.57646 .68234 Mdot
.57646 .68234 Mdot
.57254 .68234 Mdot
.57254 .68626 Mdot
.57254 .68234 Mdot
.55686 .67057 Mdot
.55294 .66665 Mdot
.55294 .66665 Mdot
.54509 .64705 Mdot
.55686 .64705 Mdot
.55686 .63528 Mdot
.55686 .62744 Mdot
.5647 .6392 Mdot
.54117 .62744 Mdot
.54117 .62352 Mdot
.54117 .62352 Mdot
.54902 .62744 Mdot
.52941 .61176 Mdot
.52549 .6196 Mdot
.52549 .62352 Mdot
.53333 .63136 Mdot
.52549 .63136 Mdot
.51372 .62744 Mdot
.51372 .62744 Mdot
.5098 .6196 Mdot
.50196 .61176 Mdot
.50196 .61176 Mdot
.5098 .6196 Mdot
.50588 .6196 Mdot
.49804 .61568 Mdot
.48628 .61568 Mdot
.48628 .6196 Mdot
.48235 .61568 Mdot
.47059 .60391 Mdot
.47059 .60783 Mdot
.45883 .60391 Mdot
.45883 .59999 Mdot
.45098 .58039 Mdot
.42354 .54902 Mdot
.42354 .54117 Mdot
.41569 .51372 Mdot
.40393 .4902 Mdot
.40001 .47059 Mdot
.39609 .53333 Mdot
.4353 .60783 Mdot
.44314 .62352 Mdot
.45491 .63528 Mdot
.45491 .63136 Mdot
.45098 .63528 Mdot
.45491 .64313 Mdot
.45491 .64705 Mdot
.46275 .65489 Mdot
.46275 .64705 Mdot
.47059 .65489 Mdot
.4902 .67057 Mdot
.48235 .67057 Mdot
.4902 .6745 Mdot
.48235 .66665 Mdot
.48628 .67057 Mdot
.4902 .67057 Mdot
.5098 .68234 Mdot
.50196 .66665 Mdot
.50196 .67057 Mdot
.50588 .66665 Mdot
.51765 .66665 Mdot
.5098 .66273 Mdot
.50588 .66273 Mdot
.50588 .66665 Mdot
.51372 .66665 Mdot
.51372 .66273 Mdot
.51372 .66273 Mdot
.52157 .67057 Mdot
.51765 .66273 Mdot
.52549 .67057 Mdot
.52941 .6745 Mdot
.53333 .6745 Mdot
.54509 .67842 Mdot
.55294 .68626 Mdot
.54509 .66665 Mdot
.55294 .67057 Mdot
.55294 .66273 Mdot
.54902 .6745 Mdot
.54902 .67842 Mdot
.54902 .67842 Mdot
.56078 .69802 Mdot
.56078 .69802 Mdot
.56078 .69802 Mdot
.55294 .68234 Mdot
.55686 .68626 Mdot
.5647 .69018 Mdot
.5647 .68626 Mdot
.56078 .68626 Mdot
.56862 .70194 Mdot
.57254 .70979 Mdot
.5647 .70979 Mdot
.56862 .71371 Mdot
.57254 .71763 Mdot
.58431 .73332 Mdot
.57646 .73332 Mdot
.57646 .73332 Mdot
.57646 .72939 Mdot
.58039 .72939 Mdot
.58039 .72155 Mdot
.59215 .71763 Mdot
.59607 .71371 Mdot
.59215 .70587 Mdot
.58823 .69802 Mdot
.58823 .70194 Mdot
.58431 .70587 Mdot
.58431 .71371 Mdot
.58431 .71763 Mdot
.59607 .72547 Mdot
.59215 .72155 Mdot
.58823 .70979 Mdot
.59999 .70979 Mdot
.59607 .70194 Mdot
.59215 .69018 Mdot
.58431 .67842 Mdot
.58431 .67842 Mdot
.58431 .68626 Mdot
.58039 .69018 Mdot
.59607 .71371 Mdot
.60391 .72155 Mdot
.59999 .72155 Mdot
.59999 .71763 Mdot
.59999 .70979 Mdot
.61176 .71371 Mdot
.61176 .70979 Mdot
.60783 .71763 Mdot
.61176 .72155 Mdot
.6196 .74116 Mdot
.6196 .74116 Mdot
.6196 .73724 Mdot
.62744 .72939 Mdot
.61568 .70587 Mdot
.61568 .70194 Mdot
.60783 .69802 Mdot
.60391 .70587 Mdot
.60391 .71371 Mdot
.59999 .71371 Mdot
.59999 .71763 Mdot
.59999 .71763 Mdot
.60391 .72939 Mdot
.59999 .72547 Mdot
.59999 .71763 Mdot
.61176 .72155 Mdot
.60391 .71763 Mdot
.60391 .72155 Mdot
.59999 .71371 Mdot
.60391 .70587 Mdot
.61176 .70979 Mdot
.61568 .70979 Mdot
.60783 .71371 Mdot
.60391 .71371 Mdot
.58823 .69018 Mdot
.58431 .67842 Mdot
.58823 .68626 Mdot
.58431 .68626 Mdot
.57254 .6745 Mdot
.57254 .6745 Mdot
.57254 .67842 Mdot
.56078 .67057 Mdot
.56862 .67842 Mdot
.55294 .67057 Mdot
.55294 .66665 Mdot
.55686 .66665 Mdot
.55686 .67057 Mdot
.55686 .67057 Mdot
.55686 .65489 Mdot
.55294 .64313 Mdot
.55294 .64313 Mdot
.54902 .63528 Mdot
.54117 .63528 Mdot
.54902 .64313 Mdot
.52549 .62352 Mdot
.53333 .61568 Mdot
.52549 .60391 Mdot
.53333 .6196 Mdot
.52941 .62352 Mdot
.51372 .6196 Mdot
.51372 .6196 Mdot
.52549 .63136 Mdot
.51372 .62352 Mdot
.5098 .62352 Mdot
.50588 .6196 Mdot
.49804 .62352 Mdot
.50196 .62352 Mdot
.50196 .62744 Mdot
.50196 .63136 Mdot
.48235 .62352 Mdot
.47843 .6196 Mdot
.47451 .61568 Mdot
.46275 .60783 Mdot
.45883 .59607 Mdot
.44706 .58431 Mdot
.45098 .58823 Mdot
.45491 .58823 Mdot
.44706 .5647 Mdot
.4353 .54902 Mdot
.42746 .54117 Mdot
.41569 .52941 Mdot
.40785 .5098 Mdot
.39217 .48235 Mdot
.38824 .52941 Mdot
.41961 .58823 Mdot
.43138 .61568 Mdot
.43922 .63136 Mdot
.45098 .64313 Mdot
.45098 .6392 Mdot
.45098 .6392 Mdot
.45098 .6392 Mdot
.45883 .64705 Mdot
.45883 .6392 Mdot
.47059 .64705 Mdot
.48628 .66273 Mdot
.4902 .66665 Mdot
.48235 .65489 Mdot
.48628 .65489 Mdot
.49804 .66273 Mdot
.49804 .65881 Mdot
.5098 .6745 Mdot
.50588 .67842 Mdot
.49412 .68234 Mdot
.49804 .6745 Mdot
.49412 .66273 Mdot
.51765 .67842 Mdot
.51372 .6745 Mdot
.52157 .68234 Mdot
.51765 .68234 Mdot
.51765 .6745 Mdot
.52157 .6745 Mdot
.52157 .68234 Mdot
.52157 .6745 Mdot
.52549 .68234 Mdot
.53725 .6941 Mdot
.52941 .68234 Mdot
.53333 .68626 Mdot
.52941 .67842 Mdot
.53333 .67842 Mdot
.54117 .68234 Mdot
.54117 .67842 Mdot
.54902 .68234 Mdot
.54117 .6745 Mdot
.54509 .67842 Mdot
.54509 .68626 Mdot
.55294 .6941 Mdot
.54902 .68234 Mdot
.56078 .69018 Mdot
.5647 .69802 Mdot
.5647 .69802 Mdot
.5647 .69802 Mdot
.56862 .69802 Mdot
.57646 .6941 Mdot
.58039 .69802 Mdot
.58431 .70587 Mdot
.57646 .70587 Mdot
.58039 .70979 Mdot
.58039 .71763 Mdot
.57646 .72155 Mdot
.57646 .72547 Mdot
.58039 .72547 Mdot
.57646 .71763 Mdot
.58431 .72155 Mdot
.59607 .72155 Mdot
.58823 .71371 Mdot
.58431 .70979 Mdot
.57646 .70194 Mdot
.59215 .70587 Mdot
.58823 .70587 Mdot
.59215 .71371 Mdot
.59607 .72155 Mdot
.59607 .72547 Mdot
.59607 .70979 Mdot
.60783 .70587 Mdot
.60391 .6941 Mdot
.59607 .69802 Mdot
.59999 .70194 Mdot
.59215 .69802 Mdot
.58823 .6941 Mdot
.59215 .6941 Mdot
.58431 .6941 Mdot
.58823 .70194 Mdot
.59607 .71371 Mdot
.59999 .72547 Mdot
.60391 .72547 Mdot
.59999 .72547 Mdot
.60391 .72155 Mdot
.60783 .71763 Mdot
.61176 .71763 Mdot
.60783 .72155 Mdot
.59999 .72155 Mdot
.60391 .72155 Mdot
.60783 .71371 Mdot
.61176 .70587 Mdot
.60783 .69802 Mdot
.61176 .6941 Mdot
.6196 .70587 Mdot
.61568 .72155 Mdot
.61176 .72155 Mdot
.61176 .72155 Mdot
.59999 .71763 Mdot
.60391 .72155 Mdot
.61176 .72547 Mdot
.59999 .71371 Mdot
.60391 .71763 Mdot
.60391 .72547 Mdot
.60391 .72155 Mdot
.60783 .71763 Mdot
.59999 .70979 Mdot
.59607 .70194 Mdot
.59999 .69802 Mdot
.60783 .70194 Mdot
.59215 .69802 Mdot
.58823 .69802 Mdot
.58039 .68626 Mdot
.58431 .68234 Mdot
.58039 .69018 Mdot
.58039 .69802 Mdot
.57254 .69018 Mdot
.5647 .69018 Mdot
.5647 .68626 Mdot
.57254 .67842 Mdot
.56862 .6745 Mdot
.56078 .66665 Mdot
.55686 .6745 Mdot
.56078 .68234 Mdot
.54902 .65881 Mdot
.56078 .66665 Mdot
.5647 .66273 Mdot
.55294 .65881 Mdot
.54117 .64705 Mdot
.54509 .65097 Mdot
.53725 .64313 Mdot
.52941 .6392 Mdot
.52549 .6392 Mdot
.52157 .63528 Mdot
.51372 .62352 Mdot
.53333 .6392 Mdot
.52549 .63136 Mdot
.52157 .63136 Mdot
.52157 .6392 Mdot
.51372 .63528 Mdot
.50588 .63528 Mdot
.50196 .63136 Mdot
.49412 .62352 Mdot
.49804 .62352 Mdot
.48628 .61176 Mdot
.4902 .6196 Mdot
.48235 .61568 Mdot
.48628 .6196 Mdot
.47451 .60391 Mdot
.46667 .59215 Mdot
.45883 .58431 Mdot
.45098 .57254 Mdot
.43922 .55686 Mdot
.43922 .55686 Mdot
.44314 .5647 Mdot
.44706 .5647 Mdot
.43922 .56078 Mdot
.42746 .54902 Mdot
.41569 .53333 Mdot
.40393 .5098 Mdot
.38432 .47843 Mdot
.39609 .54509 Mdot
.42746 .59607 Mdot
.43922 .62352 Mdot
.44314 .6392 Mdot
.45098 .64705 Mdot
.44706 .64313 Mdot
.44706 .6392 Mdot
.45098 .64313 Mdot
.46667 .65097 Mdot
.47059 .64313 Mdot
.47059 .63528 Mdot
.47451 .65097 Mdot
.47451 .65881 Mdot
.47843 .65881 Mdot
.48235 .65097 Mdot
.48235 .65097 Mdot
.49804 .66273 Mdot
.49804 .65881 Mdot
.49412 .6745 Mdot
.49804 .68626 Mdot
.50588 .68626 Mdot
.49804 .66273 Mdot
.5098 .65881 Mdot
.5098 .65489 Mdot
.51372 .65881 Mdot
.51372 .66665 Mdot
.51765 .6745 Mdot
.51765 .6745 Mdot
.52157 .68234 Mdot
.52157 .67057 Mdot
.51372 .66273 Mdot
.52549 .67842 Mdot
.52941 .68234 Mdot
.52549 .6745 Mdot
.51765 .66665 Mdot
.52941 .6745 Mdot
.53333 .67842 Mdot
.54117 .67842 Mdot
.55294 .68626 Mdot
.55686 .69018 Mdot
.55294 .69018 Mdot
.55686 .70979 Mdot
.54509 .69018 Mdot
.55294 .6941 Mdot
.54902 .68234 Mdot
.56862 .6941 Mdot
.5647 .6941 Mdot
.57254 .70587 Mdot
.56862 .69802 Mdot
.58039 .69802 Mdot
.58823 .6941 Mdot
.58431 .69018 Mdot
.57646 .69018 Mdot
.58431 .70587 Mdot
.57646 .70979 Mdot
.57646 .71371 Mdot
.57254 .71371 Mdot
.57646 .70979 Mdot
.58039 .70979 Mdot
.58039 .70194 Mdot
.58823 .70587 Mdot
.58431 .70587 Mdot
.57254 .70194 Mdot
.57646 .70979 Mdot
.57646 .70587 Mdot
.58431 .70979 Mdot
.58823 .71371 Mdot
.58431 .71763 Mdot
.58823 .72155 Mdot
.59607 .70979 Mdot
.60391 .70979 Mdot
.59607 .70194 Mdot
.60391 .70587 Mdot
.59215 .69802 Mdot
.58823 .70194 Mdot
.58039 .69018 Mdot
.57646 .69018 Mdot
.57646 .68626 Mdot
.58823 .69018 Mdot
.58823 .69802 Mdot
.59607 .70979 Mdot
.59215 .70979 Mdot
.59215 .71371 Mdot
.60391 .71371 Mdot
.59215 .70194 Mdot
.59215 .69802 Mdot
.60391 .70979 Mdot
.60783 .71763 Mdot
.59999 .70979 Mdot
.59607 .70194 Mdot
.59215 .69018 Mdot
.59999 .6941 Mdot
.60391 .70587 Mdot
.61568 .70979 Mdot
.60783 .71371 Mdot
.61176 .72155 Mdot
.59999 .71371 Mdot
.59607 .70979 Mdot
.60783 .71371 Mdot
.60783 .70587 Mdot
.59999 .6941 Mdot
.59999 .69802 Mdot
.59999 .70194 Mdot
.59215 .69802 Mdot
.59607 .69802 Mdot
.59607 .69802 Mdot
.59215 .6941 Mdot
.59607 .70194 Mdot
.59607 .70194 Mdot
.58431 .70194 Mdot
.58039 .70194 Mdot
.57254 .69018 Mdot
.57646 .67842 Mdot
.57646 .68234 Mdot
.58039 .6941 Mdot
.56078 .6941 Mdot
.54902 .68626 Mdot
.54902 .67842 Mdot
.54509 .65881 Mdot
.55686 .66273 Mdot
.55686 .65881 Mdot
.5647 .6745 Mdot
.56078 .68234 Mdot
.55294 .6745 Mdot
.54509 .66665 Mdot
.52941 .64313 Mdot
.54902 .65097 Mdot
.54902 .65097 Mdot
.54117 .65097 Mdot
.54509 .65881 Mdot
.54509 .66665 Mdot
.53333 .65881 Mdot
.52941 .65489 Mdot
.51765 .6392 Mdot
.51372 .63136 Mdot
.51765 .63136 Mdot
.51765 .63528 Mdot
.52157 .64313 Mdot
.51372 .64313 Mdot
.5098 .65097 Mdot
.48628 .63136 Mdot
.47451 .61176 Mdot
.4902 .60783 Mdot
.4902 .60391 Mdot
.48628 .60783 Mdot
.47843 .61176 Mdot
.47451 .60783 Mdot
.46667 .60783 Mdot
.44706 .59215 Mdot
.44706 .58431 Mdot
.45098 .58431 Mdot
.44314 .57646 Mdot
.43922 .5647 Mdot
.4353 .5647 Mdot
.42746 .55686 Mdot
.41569 .55294 Mdot
.40785 .54509 Mdot
.40393 .52941 Mdot
.39609 .50588 Mdot
.38432 .47451 Mdot
.38824 .53725 Mdot
.41961 .58039 Mdot
.44314 .61568 Mdot
.45491 .64705 Mdot
.45491 .64705 Mdot
.45883 .64705 Mdot
.45491 .6392 Mdot
.46275 .6392 Mdot
.47451 .64313 Mdot
.48235 .64313 Mdot
.47843 .6392 Mdot
.48628 .65881 Mdot
.47843 .65097 Mdot
.47843 .65489 Mdot
.48628 .65881 Mdot
.4902 .65881 Mdot
.48235 .65097 Mdot
.49412 .65881 Mdot
.4902 .65489 Mdot
.49412 .65881 Mdot
.50196 .66273 Mdot
.50588 .65489 Mdot
.49804 .6392 Mdot
.49412 .63528 Mdot
.51765 .64313 Mdot
.52157 .64313 Mdot
.53725 .65881 Mdot
.53333 .65489 Mdot
.52549 .65881 Mdot
.52941 .67057 Mdot
.52157 .66273 Mdot
.52941 .65881 Mdot
.53725 .67057 Mdot
.53333 .67057 Mdot
.52941 .67842 Mdot
.53725 .68626 Mdot
.53725 .68626 Mdot
.54509 .68626 Mdot
.56078 .69802 Mdot
.55686 .70587 Mdot
.55686 .70979 Mdot
.54902 .69802 Mdot
.54902 .69802 Mdot
.55294 .70587 Mdot
.55294 .70194 Mdot
.54902 .68626 Mdot
.55686 .6941 Mdot
.55686 .69802 Mdot
.55294 .69018 Mdot
.56862 .69018 Mdot
.57646 .69018 Mdot
.56862 .67842 Mdot
.57254 .67842 Mdot
.57646 .69018 Mdot
.57646 .69802 Mdot
.57646 .70587 Mdot
.57646 .69802 Mdot
.57646 .69018 Mdot
.58431 .69802 Mdot
.57646 .69802 Mdot
.58039 .70194 Mdot
.56862 .69018 Mdot
.5647 .6941 Mdot
.5647 .70587 Mdot
.5647 .70194 Mdot
.56862 .70587 Mdot
.57646 .71763 Mdot
.57254 .72155 Mdot
.58039 .70979 Mdot
.58039 .70194 Mdot
.58431 .70194 Mdot
.58431 .69802 Mdot
.58823 .70587 Mdot
.59607 .71371 Mdot
.58431 .70587 Mdot
.58039 .6941 Mdot
.58431 .68626 Mdot
.58431 .68234 Mdot
.58823 .68234 Mdot
.58823 .6941 Mdot
.58823 .70587 Mdot
.58039 .70587 Mdot
.59607 .71371 Mdot
.59215 .70979 Mdot
.59607 .70194 Mdot
.59215 .68626 Mdot
.59999 .70194 Mdot
.60783 .71763 Mdot
.59607 .70587 Mdot
.59215 .70194 Mdot
.58823 .6941 Mdot
.58823 .68234 Mdot
.59607 .6941 Mdot
.59999 .69802 Mdot
.59607 .69802 Mdot
.59999 .71763 Mdot
.59215 .70979 Mdot
.58431 .70194 Mdot
.58823 .69018 Mdot
.58039 .6745 Mdot
.58823 .67842 Mdot
.59215 .6745 Mdot
.58823 .68234 Mdot
.58039 .69018 Mdot
.58039 .6941 Mdot
.57646 .6941 Mdot
.58039 .6941 Mdot
.58039 .70194 Mdot
.58039 .70587 Mdot
.57646 .70194 Mdot
.56862 .6941 Mdot
.57254 .69018 Mdot
.57646 .69018 Mdot
.56862 .6745 Mdot
.56862 .67842 Mdot
.5647 .67842 Mdot
.55686 .68234 Mdot
.54509 .67057 Mdot
.54509 .67057 Mdot
.54902 .66665 Mdot
.54117 .65097 Mdot
.54509 .66273 Mdot
.54902 .66665 Mdot
.54509 .66273 Mdot
.54902 .66665 Mdot
.53725 .65097 Mdot
.53725 .63528 Mdot
.54117 .62352 Mdot
.54117 .63136 Mdot
.54117 .64705 Mdot
.53333 .64705 Mdot
.52941 .65489 Mdot
.51372 .64705 Mdot
.49804 .6196 Mdot
.50196 .61568 Mdot
.49804 .60391 Mdot
.50588 .61568 Mdot
.50588 .62352 Mdot
.49804 .62352 Mdot
.49804 .6392 Mdot
.48628 .62744 Mdot
.47451 .61176 Mdot
.47451 .59999 Mdot
.47059 .58823 Mdot
.47451 .59607 Mdot
.47451 .59999 Mdot
.46667 .60391 Mdot
.45883 .61176 Mdot
.44706 .59999 Mdot
.43922 .58823 Mdot
.43138 .57254 Mdot
.43138 .56862 Mdot
.42746 .56078 Mdot
.41569 .56078 Mdot
.41569 .5647 Mdot
.41177 .55294 Mdot
.38824 .53333 Mdot
.39609 .53333 Mdot
.38432 .50588 Mdot
.37256 .45883 Mdot
.40001 .52157 Mdot
.41177 .57254 Mdot
.4353 .60783 Mdot
.44706 .62352 Mdot
.45883 .63136 Mdot
.46667 .63528 Mdot
.46275 .6392 Mdot
.46275 .63528 Mdot
.47843 .64705 Mdot
.47059 .6392 Mdot
.47843 .64313 Mdot
.4902 .64313 Mdot
.48628 .6392 Mdot
.48628 .6392 Mdot
.49412 .6392 Mdot
.49804 .64313 Mdot
.49804 .65489 Mdot
.50196 .65881 Mdot
.50196 .65097 Mdot
.49804 .64313 Mdot
.50588 .64313 Mdot
.4902 .63136 Mdot
.49804 .63528 Mdot
.49412 .63528 Mdot
.5098 .64313 Mdot
.5098 .63136 Mdot
.52549 .63528 Mdot
.51765 .63136 Mdot
.52941 .65489 Mdot
.53333 .67057 Mdot
.53725 .68234 Mdot
.54117 .68234 Mdot
.54117 .67842 Mdot
.53725 .67057 Mdot
.54117 .67842 Mdot
.54117 .68234 Mdot
.55686 .70587 Mdot
.54509 .69802 Mdot
.54902 .69802 Mdot
.56078 .70194 Mdot
.54902 .67842 Mdot
.53333 .67057 Mdot
.55686 .68626 Mdot
.55686 .6941 Mdot
.55294 .69802 Mdot
.53725 .68234 Mdot
.53333 .68234 Mdot
.52941 .67842 Mdot
.53333 .6745 Mdot
.55294 .67057 Mdot
.56862 .6745 Mdot
.56078 .67057 Mdot
.56862 .6745 Mdot
.56862 .67057 Mdot
.56862 .6745 Mdot
.57254 .6745 Mdot
.56862 .66665 Mdot
.57646 .6745 Mdot
.57646 .6745 Mdot
.58431 .67842 Mdot
.57254 .68234 Mdot
.57254 .68626 Mdot
.58039 .6941 Mdot
.57646 .68626 Mdot
.57646 .68626 Mdot
.57646 .69018 Mdot
.56078 .68626 Mdot
.5647 .6941 Mdot
.56862 .69018 Mdot
.56862 .68234 Mdot
.56862 .67057 Mdot
.57254 .66665 Mdot
.57254 .66273 Mdot
.57646 .6745 Mdot
.57646 .68234 Mdot
.57646 .67842 Mdot
.58039 .6745 Mdot
.57254 .65881 Mdot
.58039 .66665 Mdot
.58039 .6745 Mdot
.58431 .68626 Mdot
.58039 .69018 Mdot
.58431 .6941 Mdot
.59215 .6941 Mdot
.58823 .68626 Mdot
.59215 .69018 Mdot
.59215 .69018 Mdot
.59215 .6941 Mdot
.58823 .69018 Mdot
.58039 .68234 Mdot
.58823 .6745 Mdot
.58431 .65881 Mdot
.58431 .65881 Mdot
.59607 .68626 Mdot
.59607 .69802 Mdot
.59607 .70194 Mdot
.59215 .69018 Mdot
.58431 .67842 Mdot
.58823 .67842 Mdot
.58431 .67057 Mdot
.58823 .66665 Mdot
.58431 .66665 Mdot
.58823 .66665 Mdot
.58039 .67057 Mdot
.58039 .68234 Mdot
.58039 .69018 Mdot
.58823 .70194 Mdot
.58431 .70194 Mdot
.57646 .69802 Mdot
.57646 .69802 Mdot
.58039 .69018 Mdot
.58039 .69018 Mdot
.57254 .68234 Mdot
.57254 .68234 Mdot
.56862 .67842 Mdot
.55686 .66665 Mdot
.55294 .66273 Mdot
.55686 .6745 Mdot
.55294 .66665 Mdot
.53725 .64705 Mdot
.54509 .65097 Mdot
.53725 .64705 Mdot
.54117 .65881 Mdot
.54117 .64705 Mdot
.54117 .6392 Mdot
.54902 .64313 Mdot
.54117 .63136 Mdot
.53725 .62352 Mdot
.54509 .62744 Mdot
.54509 .63528 Mdot
.53333 .63136 Mdot
.52549 .64313 Mdot
.52549 .65097 Mdot
.5098 .63136 Mdot
.50196 .62352 Mdot
.4902 .60391 Mdot
.4902 .59607 Mdot
.48628 .59607 Mdot
.49412 .60391 Mdot
.49412 .60783 Mdot
.48628 .59999 Mdot
.47451 .59999 Mdot
.46667 .59999 Mdot
.45883 .58823 Mdot
.46275 .59215 Mdot
.46667 .59607 Mdot
.45883 .59607 Mdot
.44706 .59607 Mdot
.43922 .59215 Mdot
.43922 .58823 Mdot
.43138 .57646 Mdot
.42354 .57254 Mdot
.42354 .58039 Mdot
.40785 .56078 Mdot
.40001 .54509 Mdot
.40001 .54509 Mdot
.39609 .54117 Mdot
.38824 .52157 Mdot
.3804 .50196 Mdot
.36864 .46275 Mdot
.41177 .5098 Mdot
.4353 .5647 Mdot
.45491 .59607 Mdot
.45883 .60391 Mdot
.46667 .61568 Mdot
.46667 .61568 Mdot
.46667 .63136 Mdot
.47059 .64313 Mdot
.48235 .65097 Mdot
.4902 .64705 Mdot
.49412 .6392 Mdot
.48628 .63136 Mdot
.48235 .62744 Mdot
.4902 .63136 Mdot
.48628 .62744 Mdot
.48628 .62744 Mdot
.49804 .64705 Mdot
.50196 .65097 Mdot
.5098 .64313 Mdot
.5098 .63528 Mdot
.50196 .6392 Mdot
.5098 .65097 Mdot
.51372 .65489 Mdot
.49804 .65097 Mdot
.51372 .65881 Mdot
.52549 .65097 Mdot
.53333 .64705 Mdot
.53333 .64705 Mdot
.53725 .65881 Mdot
.54902 .68234 Mdot
.55294 .6941 Mdot
.54117 .68234 Mdot
.54117 .67842 Mdot
.54117 .67057 Mdot
.54117 .67842 Mdot
.55294 .69018 Mdot
.5647 .70587 Mdot
.55686 .70587 Mdot
.54509 .68626 Mdot
.54509 .68626 Mdot
.54509 .6745 Mdot
.55686 .67057 Mdot
.54902 .66665 Mdot
.54902 .66273 Mdot
.54117 .67057 Mdot
.53333 .66273 Mdot
.51765 .65489 Mdot
.51765 .65097 Mdot
.51765 .63528 Mdot
.51765 .62352 Mdot
.53333 .6392 Mdot
.54509 .65097 Mdot
.54902 .65097 Mdot
.54509 .64705 Mdot
.53725 .64313 Mdot
.54902 .64313 Mdot
.55686 .64313 Mdot
.56078 .64313 Mdot
.5647 .65097 Mdot
.57254 .65881 Mdot
.58039 .6745 Mdot
.5647 .66273 Mdot
.57254 .67057 Mdot
.57254 .67057 Mdot
.58039 .67057 Mdot
.58039 .67057 Mdot
.57646 .67842 Mdot
.58039 .69018 Mdot
.5647 .6745 Mdot
.56862 .66273 Mdot
.57646 .66665 Mdot
.57646 .65489 Mdot
.58039 .65881 Mdot
.58431 .66665 Mdot
.59607 .67842 Mdot
.58431 .66665 Mdot
.58039 .65881 Mdot
.58823 .66273 Mdot
.58823 .66665 Mdot
.58823 .67057 Mdot
.59215 .68234 Mdot
.58431 .67842 Mdot
.58823 .69018 Mdot
.58039 .68234 Mdot
.58431 .68626 Mdot
.58823 .68626 Mdot
.59607 .69018 Mdot
.59999 .69802 Mdot
.60391 .69802 Mdot
.58823 .68234 Mdot
.58823 .6745 Mdot
.58823 .66273 Mdot
.58823 .65881 Mdot
.59607 .66665 Mdot
.59215 .67057 Mdot
.59215 .68234 Mdot
.58823 .67842 Mdot
.59215 .68234 Mdot
.58431 .67057 Mdot
.58823 .66665 Mdot
.58823 .67057 Mdot
.58823 .66665 Mdot
.58431 .67057 Mdot
.57254 .66665 Mdot
.57646 .6745 Mdot
.58039 .68234 Mdot
.57254 .6745 Mdot
.57254 .68234 Mdot
.58431 .69018 Mdot
.58431 .69018 Mdot
.57254 .67842 Mdot
.57646 .68234 Mdot
.57254 .67842 Mdot
.5647 .66273 Mdot
.56862 .66273 Mdot
.56862 .65097 Mdot
.5647 .64705 Mdot
.55294 .64705 Mdot
.54902 .64313 Mdot
.54509 .63528 Mdot
.54902 .63528 Mdot
.55294 .64313 Mdot
.52941 .63136 Mdot
.52941 .63528 Mdot
.53725 .6392 Mdot
.53725 .6392 Mdot
.53333 .63136 Mdot
.52941 .61568 Mdot
.53333 .61568 Mdot
.54509 .62352 Mdot
.53333 .6196 Mdot
.52549 .63136 Mdot
.51765 .6392 Mdot
.50196 .63528 Mdot
.49412 .62352 Mdot
.4902 .60391 Mdot
.4902 .59215 Mdot
.49412 .58823 Mdot
.49412 .59215 Mdot
.50196 .59999 Mdot
.4902 .59215 Mdot
.48628 .59999 Mdot
.48235 .60391 Mdot
.47451 .59999 Mdot
.47059 .58823 Mdot
.46667 .58039 Mdot
.45491 .57646 Mdot
.45098 .58431 Mdot
.44314 .59215 Mdot
.42746 .59215 Mdot
.41569 .58039 Mdot
.42354 .57646 Mdot
.42354 .56862 Mdot
.42354 .56078 Mdot
.40785 .54117 Mdot
.40785 .54117 Mdot
.40785 .53333 Mdot
.39609 .51372 Mdot
.37648 .48628 Mdot
.37256 .46275 Mdot
.41961 .5098 Mdot
.46275 .57646 Mdot
.47843 .60783 Mdot
.47843 .61568 Mdot
.48628 .6196 Mdot
.47843 .61176 Mdot
.47843 .6196 Mdot
.4902 .6392 Mdot
.4902 .64705 Mdot
.4902 .64313 Mdot
.49804 .63136 Mdot
.50588 .6196 Mdot
.49804 .61176 Mdot
.5098 .62744 Mdot
.5098 .63528 Mdot
.50196 .6392 Mdot
.49804 .64313 Mdot
.5098 .64313 Mdot
.5098 .63528 Mdot
.51765 .63136 Mdot
.51765 .62744 Mdot
.52549 .6392 Mdot
.52157 .65097 Mdot
.50588 .64705 Mdot
.50588 .64313 Mdot
.51765 .6392 Mdot
.52941 .63528 Mdot
.53725 .63528 Mdot
.54117 .64705 Mdot
.55294 .67057 Mdot
.54509 .68234 Mdot
.54509 .68234 Mdot
.54509 .68234 Mdot
.54117 .67057 Mdot
.54902 .67057 Mdot
.54902 .67057 Mdot
.56078 .68234 Mdot
.55294 .69018 Mdot
.54902 .67842 Mdot
.54509 .67057 Mdot
.55686 .66273 Mdot
.5647 .66273 Mdot
.55686 .65097 Mdot
.55294 .64705 Mdot
.54509 .65097 Mdot
.54117 .66273 Mdot
.53333 .66273 Mdot
.52157 .64313 Mdot
.51765 .6196 Mdot
.51765 .60783 Mdot
.52549 .61568 Mdot
.52157 .61568 Mdot
.52157 .62352 Mdot
.5098 .61568 Mdot
.49412 .59999 Mdot
.49804 .59999 Mdot
.49804 .58431 Mdot
.51372 .58823 Mdot
.52157 .59607 Mdot
.53333 .60783 Mdot
.54117 .6196 Mdot
.53333 .62352 Mdot
.54902 .63528 Mdot
.56078 .65097 Mdot
.57254 .65881 Mdot
.56862 .65489 Mdot
.58039 .66273 Mdot
.57646 .67057 Mdot
.56078 .66273 Mdot
.57254 .66665 Mdot
.57646 .65489 Mdot
.57646 .64705 Mdot
.58431 .65097 Mdot
.58823 .66273 Mdot
.59215 .6745 Mdot
.58823 .67842 Mdot
.57254 .65881 Mdot
.58431 .65881 Mdot
.59215 .65489 Mdot
.58823 .65489 Mdot
.58823 .66273 Mdot
.59215 .67842 Mdot
.58823 .68234 Mdot
.57646 .67842 Mdot
.56862 .67057 Mdot
.58431 .67842 Mdot
.59215 .68234 Mdot
.58823 .67057 Mdot
.58823 .67842 Mdot
.58039 .6745 Mdot
.58431 .67057 Mdot
.58431 .66273 Mdot
.58431 .66273 Mdot
.59607 .67057 Mdot
.59607 .66273 Mdot
.59215 .67057 Mdot
.58823 .67057 Mdot
.58431 .67057 Mdot
.58039 .66273 Mdot
.57646 .65489 Mdot
.59215 .66665 Mdot
.59215 .67057 Mdot
.59215 .68626 Mdot
.57254 .67057 Mdot
.56862 .65881 Mdot
.57254 .65489 Mdot
.57254 .65881 Mdot
.57646 .65881 Mdot
.58431 .66273 Mdot
.58039 .66665 Mdot
.57254 .67057 Mdot
.58431 .67842 Mdot
.57646 .65881 Mdot
.57254 .64705 Mdot
.56862 .64705 Mdot
.56078 .6392 Mdot
.56078 .6392 Mdot
.54902 .63136 Mdot
.54117 .62744 Mdot
.54902 .62744 Mdot
.54902 .62352 Mdot
.55686 .62744 Mdot
.55686 .63136 Mdot
.54902 .63528 Mdot
.54117 .6392 Mdot
.52549 .62352 Mdot
.53333 .63136 Mdot
.52941 .62352 Mdot
.53333 .62352 Mdot
.54117 .61568 Mdot
.53725 .61568 Mdot
.53333 .62352 Mdot
.52549 .63136 Mdot
.5098 .63136 Mdot
.49804 .6196 Mdot
.48235 .59215 Mdot
.4902 .58431 Mdot
.4902 .58431 Mdot
.4902 .58431 Mdot
.49804 .59607 Mdot
.49804 .60391 Mdot
.48628 .59999 Mdot
.47843 .58823 Mdot
.47451 .58431 Mdot
.47451 .57254 Mdot
.47843 .57254 Mdot
.47451 .57254 Mdot
.46275 .57254 Mdot
.45491 .58039 Mdot
.43922 .58039 Mdot
.41961 .57254 Mdot
.41569 .56078 Mdot
.41961 .54509 Mdot
.41177 .52549 Mdot
.41177 .52157 Mdot
.41569 .52157 Mdot
.40001 .50588 Mdot
.40393 .51372 Mdot
.39609 .4902 Mdot
.3608 .43922 Mdot
.41961 .5098 Mdot
.46667 .56862 Mdot
.46667 .58431 Mdot
.47059 .58823 Mdot
.47451 .58823 Mdot
.48235 .59607 Mdot
.48235 .59999 Mdot
.48628 .61176 Mdot
.4902 .6196 Mdot
.49804 .62352 Mdot
.50196 .62352 Mdot
.50196 .60391 Mdot
.50588 .60783 Mdot
.50588 .6196 Mdot
.51765 .63528 Mdot
.5098 .63136 Mdot
.5098 .63136 Mdot
.51372 .63136 Mdot
.51765 .61568 Mdot
.52157 .61568 Mdot
.51765 .61568 Mdot
.53333 .63528 Mdot
.52157 .63136 Mdot
.52549 .6392 Mdot
.52549 .63528 Mdot
.54117 .63136 Mdot
.54509 .63528 Mdot
.54509 .64313 Mdot
.54509 .65097 Mdot
.54902 .65881 Mdot
.54902 .65881 Mdot
.54902 .66273 Mdot
.54509 .65881 Mdot
.54509 .65881 Mdot
.54117 .65097 Mdot
.55294 .65489 Mdot
.56078 .65881 Mdot
.55294 .66665 Mdot
.55294 .6745 Mdot
.55686 .66665 Mdot
.56078 .66273 Mdot
.56078 .64705 Mdot
.56862 .64313 Mdot
.56078 .6392 Mdot
.5647 .65097 Mdot
.56078 .65881 Mdot
.56078 .65881 Mdot
.56078 .65881 Mdot
.55294 .64705 Mdot
.55686 .64313 Mdot
.54902 .63136 Mdot
.54509 .63528 Mdot
.52941 .62352 Mdot
.52549 .61568 Mdot
.5098 .59999 Mdot
.50196 .58039 Mdot
.49804 .56078 Mdot
.50196 .55686 Mdot
.50196 .56078 Mdot
.49412 .5647 Mdot
.48628 .5647 Mdot
.47059 .55686 Mdot
.47451 .56078 Mdot
.47451 .56078 Mdot
.47451 .56078 Mdot
.50588 .57646 Mdot
.52941 .58823 Mdot
.54509 .60783 Mdot
.55294 .61568 Mdot
.5647 .62744 Mdot
.57254 .62352 Mdot
.57646 .62352 Mdot
.57254 .63136 Mdot
.57646 .64705 Mdot
.56862 .64705 Mdot
.57646 .65097 Mdot
.5647 .6392 Mdot
.57646 .65097 Mdot
.57254 .63528 Mdot
.58039 .63136 Mdot
.58823 .6392 Mdot
.59607 .65097 Mdot
.58039 .64705 Mdot
.57254 .64705 Mdot
.58039 .65097 Mdot
.58431 .66273 Mdot
.58823 .66273 Mdot
.59607 .66273 Mdot
.58823 .66273 Mdot
.57646 .65489 Mdot
.57254 .65097 Mdot
.57254 .64705 Mdot
.58039 .64705 Mdot
.58039 .64313 Mdot
.57254 .63528 Mdot
.58823 .65097 Mdot
.58823 .65881 Mdot
.57646 .65489 Mdot
.58039 .65881 Mdot
.58431 .65881 Mdot
.58823 .65881 Mdot
.58039 .65489 Mdot
.58823 .67057 Mdot
.58039 .67057 Mdot
.56862 .65489 Mdot
.56862 .65097 Mdot
.58431 .65489 Mdot
.57646 .6392 Mdot
.58431 .6392 Mdot
.57254 .63528 Mdot
.58431 .64705 Mdot
.56862 .63528 Mdot
.56862 .62352 Mdot
.56862 .61568 Mdot
.56862 .61568 Mdot
.55686 .61176 Mdot
.54902 .60783 Mdot
.54902 .61568 Mdot
.54117 .61568 Mdot
.54117 .60783 Mdot
.53333 .59607 Mdot
.54509 .59215 Mdot
.55294 .59607 Mdot
.54509 .59999 Mdot
.54117 .61568 Mdot
.53725 .62744 Mdot
.52941 .61568 Mdot
.53725 .61568 Mdot
.54509 .61568 Mdot
.53725 .59999 Mdot
.53725 .59607 Mdot
.53725 .60783 Mdot
.51372 .59999 Mdot
.50588 .60391 Mdot
.50588 .61176 Mdot
.49412 .59607 Mdot
.48235 .58039 Mdot
.48628 .57254 Mdot
.4902 .57254 Mdot
.49412 .58039 Mdot
.49804 .58431 Mdot
.48628 .57646 Mdot
.47059 .55686 Mdot
.47451 .56078 Mdot
.47059 .55686 Mdot
.46667 .54509 Mdot
.46667 .54509 Mdot
.46275 .55294 Mdot
.44706 .55294 Mdot
.44706 .55686 Mdot
.42746 .54902 Mdot
.40785 .52941 Mdot
.40785 .51765 Mdot
.41177 .51372 Mdot
.41569 .50588 Mdot
.41569 .49412 Mdot
.40001 .48235 Mdot
.39609 .47843 Mdot
.39217 .46667 Mdot
.37648 .44314 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo3`00o`2Vo`0000_ooooo000:ooooo`03o`00003oogl0oomo0400oomo00?o000007oo
o`1oool0KP1oool00ol0003oooooooooo`0?oooooa000?l0Y?ooool00ol0003oooooooooo`09oooo
o`002_ooool00ol00000oomo0?ooO`110?ooO`03o`00001oool0Oooo06d0Oooo00?o0000oooooooo
ool03oooool@003o0:Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0
@P3oogl00ol00000Oooo07ooo`1/07ooo`03o`000?oooooooooo00oooooo4P00o`2Rooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0480oomo00?o000007ooo`1oool0K01o
ool00ol0003oooooooooo`0?oooooa<00?l0XOooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`130?ooO`03o`00001oool0Oooo06/0Oooo00?o0000ooooooooool03ooooolF
003o09kooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0@`3oogl00ol0
0000Oooo07ooo`1[07ooo`03o`000?oooooooooo00oooooo5P00o`2Nooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`00003oogl0oomo04@0oomo00?o000007ooo`1oool0JP1oool00ol0003o
ooooooooo`0?ooooo`<00?l00`000?lB003o09cooooo00?o0000ooooooooool02Oooool000[ooooo
00?o00000?ooO`3oogl0A@3oogl00ol00000Oooo07ooo`1Y07ooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`00o`000`000?lB003o09cooooo00?o0000ooooooooool02Oooool000[ooooo00?o
00000?ooO`3oogl0A@3oogl00ol00000Oooo07ooo`1Y07ooo`03o`000?oooooooooo00oooooo00?o
0000ooooo`00o`000`000?lB003o09cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0AP3oogl00ol00000Oooo07ooo`1X07ooo`03o`000?oooooooooo00oooooo00?o0000
ooooo`00o`005`00o`2Jooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo
04H0oomo00?o000007ooo`1oool0J01oool00ol0003oooooooooo`0?ooooo`03o`000?ooool00?l0
00800?l00`000?lB003o09[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3o
ogl0AP3oogl00ol00000Oooo07ooo`1X07ooo`03o`000?oooooooooo00oooooo00?o0000ooooo`00
o`000P00o`030000oaD00?l0Uoooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo
0?ooO`170?ooO`03o`00001oool0Oooo06L0Oooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02003o00<0003o5@00o`2Gooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003o
ogl0oomo04P0oomo00?o000007ooo`1oool0IP1oool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00;ooooo7@00o`2Booooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo04P0oomo00?o000007ooo`1oool0IP1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Cooooo7P00o`2?ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo
04T0oomo00?o000007ooo`1oool0I@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00?ooooo0`000?lL003o08oooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3o
ogl0BP3oogl00ol00000Oooo07ooo`1T07ooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool40000o`@00?l00`000?lF003o08gooooo00?o0000ooooooooool02Oooool000[ooooo
00?o00000?ooO`3oogl0BP3oogl00ol00000Oooo07ooo`1T07ooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00oooool40000o`@00?l00`000?l4003o00<0003o3`00o`2=ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo04/0oomo00?o000007ooo`1oool0H`1o
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo0`000?l4003o00D0003o0P00
o`030000o`l00?l0SOooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1;
0?ooO`03o`00001oool0Oooo06<0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08
ooooo`D00?l00`000?l2003o00<0003o4000o`2<ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`00003oogl0oomo04/0oomo00?o000007ooo`1oool0H`1oool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Sooooo0`00o`050000oaD00?l0S?ooool00ol0003oooooooooo`09oooo
o`002_ooool00ol00000oomo0?ooO`1<0?ooO`03o`00001oool0Oooo0680Oooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`09ooooo`800?l00`000?l3003o00<0003o4P00o`2;ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo04d0oomo00?o000007ooo`1oool0
H@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo0P00o`030000o`800?l0
10000?lB003o08_ooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0C@3o
ogl00ol00000Oooo07ooo`1Q07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Ooo
ool6003o00D0003o5000o`29ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo04h0oomo00?o000007ooo`1oool0H01oool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00_ooooo1000o`050000o`@00?l00`000?l?003o08Oooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o00000?ooO`3oogl0CP3oogl00ol00000Oooo07ooo`1P07ooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool02oooool4003o00D0003o1000o`030000oa000?l0Q_ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1>0?ooO`03o`00001oool0Oooo0600
Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`<0003o00?ooooo003o0000
o`002@00o`030000oa000?l0Q_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo
0?ooO`1?0?ooO`03o`00001oool0Oooo05l0Oooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`09ooooo`<0003o00?ooooo003o0000o`000`00o`030000oaL00?l0QOooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1@0?ooO`03o`00001oool0Oooo05h0Oooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`<0003o00?ooooo003o0000o`000`00
o`070000o`H00?l00`000?l<003o08?ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0D03oogl00ol00000Oooo07ooo`1N07ooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03_ooool4003o00L0003o1P00o`030000o``00?l0Poooool00ol0003oooooooooo`09
ooooo`002_ooool2o`000580oomo00?o000007ooo`1oool0G@1oool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo013ooooo1@00o`070000o`<00?l01@000?l<003o087ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o000007ooool00000DP3oogl00ol00000Oooo07ooo`1L07ooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool2003o00<0003o00<00?l00000o`00
0?l010000?l3003o00D0003o3000o`21ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
001oool0Ooooo`000540oomo00?o000007ooo`1oool0G01oool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01;ooooo0`000?l00`00o`00003o0000o`040000o`D00?l00`000?l<003o087o
oooo00?o0000ooooooooool02Oooool000[ooooo00Go000007ooo`1oool0Ooooo`00001A0?ooO`03
o`00001oool0Oooo05/0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`<0
003o00D00?l00000o`000?l0003o003o00040000o`L00?l00`000?l9003o083ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o000007ooo`1oool00P1oool2o`0004l0oomo00?o000007ooo`1o
ool0F`1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo1`00o`040000o`D0
0?l01@000?l:003o07oooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0
101oool00ol00000oomo0?ooO`1<0?ooO`03o`00001oool0Oooo05/0Oooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Cooooo`@00?l01`000?l2003o00P0003o3000o`1mooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo00D0Oooo0ol0001<0?ooO`03o`00001o
ool0Oooo05X0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`04003o0000
0?l0003o0000o`H00?l01P000?l?003o07cooooo00?o0000ooooooooool02Oooool000[ooooo00?o
000007ooo`1oool0201oool00ol00000oomo0?ooO`1:0?ooO`03o`00001oool0Oooo05T0Oooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Gooooo`D0003o00<00?l00000o`000?l01@00
0?lA003o07cooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool02@1oool0
0ol00000oomo0?ooO`190?ooO`03o`00001oool0Oooo05T0Oooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Fooooo`H0003o00<00?l00000o`000?l01P000?lA003o07_ooooo00?o0000
ooooooooool02Oooool000[ooooo00?o000007ooo`1oool02P1oool00ol00000oomo0?ooO`190?oo
O`03o`00001oool0Oooo05P0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Foooo
o`H0003o00<00?l00000o`000?l01P000?lC003o07Wooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool02`1oool00ol00000oomo0?ooO`180?ooO`03o`00001oool0Oooo05P0
Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`@0003o00?ooooo003o0000
o`0020000?l01000o`00003o0000o`000?l?003o07Wooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool0301oool00ol00000oomo0?ooO`170?ooO`03o`00001oool0Oooo05P0
Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`<0003o0_ooool5003o00<0
003o0`00o`030000o`l00?l0NOooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`0=07ooo`;o0000B03oogl00ol00000Oooo07ooo`1G07ooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool06oooool6003o00<0003o0P00o`030000oa000?l0N?ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0?07ooo`03o`00003oogl0oomo04D0oomo00?o
000007ooo`1oool0E`1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo0`00
o`060000oaP00?l0MOooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0@
07ooo`;o0000AP3oogl00ol00000Oooo07ooo`1F07ooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool07?ooool2003o00H0003o2000o`030000o`d00?l0MOooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000Oooo07ooo`0B07ooo`03o`00003oogl0oomo04<0oomo00?o000007oo
o`1oool0EP1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo20000?l6003o
00H0003o2P00o`1eooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo01<0
Oooo0_l000140?ooO`03o`00001oool0Oooo05D0Oooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Mooooo`T0003o00<00?l0ooooo`00o`000`00o`060000o`P00?l0Moooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0E07ooo`03o`00003oogl0oomo0480oomo
00?o000007ooo`1oool0E01oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo
2@000?l8003o00@0003o2000o`1gooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001o
ool0Oooo01H0Oooo0_l000120?ooO`03o`00001oool0Oooo05@0Oooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Mooooo`<0003o0`00o`030000o`P00?l00`000?l<003o07Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0601oool00ol00000oomo0?ooO`10
0?ooO`03o`00001oool0Oooo05<0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0P
ooooo`H0003o5`00o`1dooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo
01T0Oooo0_l000100?ooO`03o`00001oool0Oooo05<0Oooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Pooooo`H0003o5`00o`1dooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`00001oool0Oooo01/0Oooo00?o00000?ooO`3oogl0?@3oogl00ol00000Oooo07ooo`1C07ooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool60000o``00?l00`000?l<003o073o
oooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0701oool2o`0003h0oomo
00?o000007ooo`1oool0DP1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo
0`000?l2003o00@0003o1P00o`030000o``00?l0L?ooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol00000Oooo07ooo`0N07ooo`;o0000?03oogl00ol00000Oooo07ooo`1B07ooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool08oooool5003o00@0003o1P00o`030000o``00?l0L?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0P07ooo`03o`00003oogl0
oomo03X0oomo00?o000007ooo`1oool0D@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02Gooooo0`00o`040000oaH00?l0Koooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
0000Oooo07ooo`0Q07ooo`;o0000>P3oogl00ol00000Oooo07ooo`1A07ooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool09Oooool=003o00<0003o3@00o`1_ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`00001oool0Oooo02<0Oooo00?o00000?ooO`3oogl0>03oogl00ol00000
Oooo07ooo`1@07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?ooool:003o00H0
003o2P00o`1_ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo02@0Oooo
0_l0000h0?ooO`03o`00001oool0Oooo0500Oooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Zooooo`@00?l00`000?l00`00o`00003o0000o`040000o`/00?l0K_ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0V07ooo`03o`00003oogl0oomo03D0oomo00?o
000007ooo`1oool0D01oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02_ooooo0`00
o`0:0000o`H00?l00`000?l5003o06_ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
07ooo`1oool09`1oool2o`0003H0oomo00?o000007ooo`1oool0C`1oool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02gooooo00<00?l00000o`000?l02P000?l4003o00<0003o1@00o`1[
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo02T0Oooo00?o00000?oo
O`3oogl0<`3oogl00ol00000Oooo07ooo`1?07ooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0;_ooool3003o00<0003o00<00?l00000o`000?l00`000?l3003o00@0003o1@00o`1[oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo02X0Oooo00?o00000?ooO`3o
ogl0<`3oogl00ol00000Oooo07ooo`1>07ooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0;_ooool7003o00D0003o0`00o`030000o`H00?l0Joooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol00000Oooo07ooo`0[07ooo`03o`00003oogl0oomo0380oomo00?o000007ooo`1oool0
CP1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02kooooo1`00o`030000o`D00?l0
0`000?l9003o06Sooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0;01o
ool2o`0003<0oomo00?o000007ooo`1oool0C@1oool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02oooooo1P00o`030000oa800?l0Ioooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000Oooo07ooo`0^07ooo`03o`00003oogl0oomo0300oomo00?o000007ooo`1oool0C@1oool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo10000?l2003o00@0003o00@00?l0
0000o`000?l0003o4000o`1Tooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0
Oooo02l0Oooo0_l0000a0?ooO`03o`00001oool0Oooo04`0Oooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0_ooooo`@0003o0`00o`030000o`04003o00000?l0003o0000oa000?l0I?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0a07ooo`03o`00003oogl0
oomo02h0oomo00?o000007ooo`1oool0C01oool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02oooooo10000?l3003o00<0003o00<00?l00000o`000?l010000?l>003o06?ooooo00?o0000
ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0<P1oool2o`0002h0oomo00?o000007oo
o`1oool0C01oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03;ooooo0P00o`030000
o`03ooooo`00o`000?l000<00?l00`000?l@003o067ooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool0=01oool00ol00000oomo0?ooO`0/0?ooO`03o`00001oool0Oooo04/0
Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0booooo`800?l00`000?l00oooool0
0?l0003o0003003o00<0003o4000o`1Qooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
001oool0Oooo03D0Oooo0ol0000[0?ooO`03o`00001oool0Oooo04/0Oooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0booooo`800?l00`000?l4ooooo`800?l00`000?l@003o067ooooo
00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0>01oool00ol00000oomo0?oo
O`0X0?ooO`03o`00001oool0Oooo04/0Oooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0dooooo`<00?l01_oooolB003o06;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
07ooo`1oool0>@1oool00ol00000oomo0?ooO`0X0?ooO`03o`00001oool0Oooo04X0Oooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0nooooo`<0003o00@00?l00000o`000?l0003o2P00
o`02ooooo`<00?l00_ooool3003o05Sooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
07ooo`1oool0>P1oool2o`0002P0oomo00?o000007ooo`1oool0BP1oool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03kooooo0`000?l01000o`00003o0000o`000?l8003o00?ooooo1000
o`02ooooo`<00?l0F?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0l
07ooo`03o`00003oogl0oomo02H0oomo00?o000007ooo`1oool0B@1oool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03kooooo1`000?l:003o0003ooooo`00o`000?l000L00?l0F?ooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0m07ooo`;o00009P3oogl00ol0
0000Oooo07ooo`1907ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?_ooool60000
o`<00?l00`000?l5003o0005ooooo`00o`000?l0003o0?ooool00`00o`1Jooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`00001oool0Oooo03l0Oooo00?o00000?ooO`3oogl08`3oogl00ol0
0000Oooo07ooo`1907ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?_ooool60000
o`<00?l00`000?l=003o05[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1o
ool0@01oool2000002<0oomo00?o000007ooo`1oool0B@1oool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03oooooo1000o`070000o`800?l00`000?l5003o00<0003oF_ooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`1207ooo`03o`00003oogl0oomo0240oomo
B`1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo0`000?l3ooooo`L0003o
0P00o`030000o`D00?l00`000?l2003o05Sooooo00?o0000ooooooooool02Oooool000[ooooo00?o
000007ooo`1oool0@`1oool200000240oomoB`1oool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03gooooo3@000?l2003o00<0003o1@00o`030000o`800?l0F?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000Oooo07ooo`1507ooo`03o`0000000000000001h0oomoB`1oool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo1P000?l2ooooo`D0003o2P00o`03
0000o`D00?l0EOooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`1807oo
o`800000703oogm;07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@?ooool30000
o`;ooooo0`000?l<003o00<0003o1@00o`1Eooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`00001oool0Oooo04X0Oooo00?o00000?ooO`3oogl06@3oogm;07ooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0?_ooool50000o`;ooooo10000?l;003o00<0003o2000o`1Booooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo04/0Oooo0P00000I0?ooOd/0Oooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0nooooo``0003o0P00o`030000o``00?l0
00Cooooo003o0000o`000?l0D_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`1=07ooo`03o`00003oogl0oomo01H0oomo00?o000007ooo`1oool0B01oool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03kooooo4@000?l@003o00?ooooo0`00o`1<ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo04h0Oooo0P00000F0?ooO`03o`00001o
ool0Oooo04P0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`11ooooo`l0003o00@0
0?l00000o`000?l0003o2P00o`04ooooo`<00?l0C?ooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol00000Oooo07ooo`1@07ooo`80000000?o00000?ooO`3oogl04@3oogl00ol00000Oooo07oo
o`1807ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@Oooool?0000o`04003o0000
0?l0003o0000o`X00?l01?ooool5003o04[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o
000007ooo`1oool0D`1oool200000140oomo00?o000007ooo`1oool0B01oool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo043ooooo40000?l01000o`00003o0000o`000?l6003o00<0003o
2P00o`1:ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo05D0Oooo00?o
00000?ooO`3oogl03P3oogl00ol00000Oooo07ooo`1807ooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0@?ooool>0000o`?ooooo2@00o`030000o`X00?l0B_ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000Oooo07ooo`1F07ooo`@000002`3oogl00ol00000Oooo07ooo`19
07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@?oooolD0000o`H00?l00`000?l5
003o04oooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0FP1oool00ol0
00000000000000060?ooO`?o0000B`1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
043ooooo50000?l>003o04oooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1o
ool0G@1oool7o`0004d0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`10oooooaH0
003o3@00o`1>ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`11oooooaL0003o3000o`001?ooool00?l0
003o0000o`19ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`11oooooaP0003o3`00o`19ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`11oooooaX0003o3@00o`001?ooool00?l0003o0000o`15ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`11oooooad0003o0P00o`03ooooo`<00?l00oooool3003o04Gooooo00?o
0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo047ooooo5P000?l00`00o`00003o0000o`040000o`D00?l00`000?l2
003o0004ooooo`00o`000?l0003o04Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
07ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo047ooooo5P000?l0
0`00o`00003o0000o`040000o`D00?l00`000?l2003o04Wooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
047ooooo7@000?l5003o00<0003o00@00?l00000o`000?l0003oAoooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0@ooooolM0000o`800?l010000?l01000o`00003o0000o`000?l5003o04;ooooo00?o0000
ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo04Gooooo8@000?l01000o`00003o0000o`000?l5003o04;ooooo00?o0000
ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo04Cooooo9P000?l5003o04;ooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Co
oooo9P000?l5003o00;ooooo0`00o`0mooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`14ooooobH0003o
0P00o`05ooooo`<00?l0?Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07oo
o`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0A_oooolO0000o`<00?l00`00
0?l00`00o`3oooooooooo`03ooooo`<00?l0?Oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0AooooolT
0000o`<00?l0@oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0AooooolT0000o`D00?l0@Oooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0AooooolU0000o`04003o00000?l0003o0000o`<00?l0?_ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0BOoooolS0000o`04ooooo`000?l0003o0000o`<00?l00`000?l6oooo
o`<0003o<_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0BOoooolS0000o`04003o00000?l0003o0000
o`<00?l00`000?l6ooooo`<0003o<_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000
Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0AooooolT0000o`03
ooooo`00o`000?l000<00?l00_ooool50000o`Cooooo0`000?lbooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`17ooooob<0003o1P00o`02ooooo`H0003o1oooool50000obgooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo04Oooooo9@000?l4003o00;ooooo1P000?l7ooooo`D0003o;Oooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0B_oooolS0000o`05003o00000?l0003o0000o`00o`001P000?l01?ooool0003o0000
o`000?l3ooooo`H0003o;?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07oo
o`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0B_oooolb0000o`?ooooo1P00
0?l/ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1:oooooc`0003o:oooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0B_oooolm0000ob[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1o
ool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04[ooooo;P000?l00oooool0
003o0000o`0<0000ob[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0
/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04[ooooo;`000?l00oooool0003o
0000o`0<0000obWooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1o
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04cooooo?0000?lYooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1<oooooc`0003o:Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
0000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C?ooooln0000
obOooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo04gooooo?P000?lVooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1@oooooc/0003o9_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07oo
o`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0D?ooool30000o`;ooooo=P00
0?lVooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1FooooocD0003o9_ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0F?oooolc0000obKooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1o
ool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Sooooo<`000?lVooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1Hoooooc<0003o9_ooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0FOoo
oolb0000o`03003o0?oooooooooo02?ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
07ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05cooooo<0000?lU
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1Nooooobh0003o9Oooool00ol0003oooooooooo`09oooo
o`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0H?ooool/0000o`04ooooo`000?l0003o0000ob7ooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo067o
oooo:@000?l3ooooo`<0003o8Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0HOoooolY0000o`?ooooo
0`000?lQooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1TooooobH0003o9oooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0IooooolR0000o`Cooooo0`00o`0Qooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Xoooo
ob<0003o0_ooool2003o00<0003o7oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000
Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0JOoooolS0000o`<0
0?l00`000?lOooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Yooooob<0003o0`00o`030000oaoooooo
00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo06kooooo50000?l00oooool0003o0000o`0:0000o`03003o0?oo
oooooooo00<00?l07?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a
07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Koooool>0000o`03ooooo`000?l0
003o0080003o00Cooooo0000o`000?l0003o0`00o`060000o`03ooooo`00o`000?l000<00?l07?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Koooool>0000o`;ooooo0`000?l5ooooo`P0003o1P00o`0L
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`27ooooo`L0003o00?ooooo003o0000o`000P00o`001?oo
ool0003o0000o`000?lJooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo
0;40Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`27ooooo`L0003o1000o`02oooo
o`<0003o6_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Q_ooool3003o00D0003o0`00o`090000oaOo
oooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo08Kooooo00D00?l00000o`000?l0003oooooo`040000o`03
003o00000?l0003o00P0003o5oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Q_ooool01000o`00003o
0000o`000?l2ooooo`l0003o5_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Qoooool30000o`;ooooo
3`000?lFooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2>ooooo`L0003o0_ooool40000oaKooooo00?o
0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo093ooooo2P000?lGooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2@oooo
o`P0003o6Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Toooool50000o`04ooooo`00o`000?l0003o
01Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo09?ooooo1`000?l2003o01Gooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo09?ooooo1`000?l2003o01Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o
000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Oooooo0`00
0?l2003o01Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Wooooo0`00o`030000oa;ooooo00?o0000
ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo09Oooooo0`00o`050000oa;ooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Oo
oooo0`00o`070000oa3ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0
/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Oooooo0`00o`070000oa3ooooo
00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo09_ooooo1P000?l3003o00gooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo09[ooooo00<00?l00000o`000?l01P000?l00`00o`3oooooooooo`0;ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2Jooooo`03003o00000?l0003o00X0003o2_ooool00ol0003oooooooooo`09oooo
o`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0V_ooool00`00o`00003o0000o`0:0000o`[ooooo00?o0000ooooooooool02Oooool000[ooooo
00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09cooooo
0`000?l2ooooo`L0003o2Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07oo
o`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0W?ooool30000o`;ooooo1`00
0?l9ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2Qooooo`<0003o00@00?l00000o`000?l0003o2Ooo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0XOooool30000o`gooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo
00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo
00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
07ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000
ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1o
ool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1o
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7o
oooo00?o0000ooooooooool02Oooool000[ooooo]Ol0000AoooookGo00002oooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0557921, \
-0.0252998, 0.00554406, 0.00554406}, {{10.0625, 190.438}, {184.875, 4.5}} -> \
{-14.4348, -6.64788, 1.41581, 1.41581}, {{10.0625, 190.438}, {184.875, 4.5}} -> \
{-14.4348, -6.64788, 1.41581, 1.41581}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-295.282, -6.60135, 1.41532, 1.41532}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RB plane", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(decGB = 
        ShowTwoClassificationRegions[p1gb, p2gb, pr, x, y, classColors, 
          False, Axes \[Rule] False, Frame \[Rule] True, \ 
          FrameTicks \[Rule] None, nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{decGB, distGB}}], 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
4e-05 4e-05 m
.0196 4e-05 L
.04093 4e-05 L
.06096 4e-05 L
.08023 4e-05 L
.10073 4e-05 L
.12047 4e-05 L
.14146 4e-05 L
.16167 4e-05 L
.18112 4e-05 L
.2018 4e-05 L
.22173 4e-05 L
.24088 4e-05 L
.26127 4e-05 L
.2809 4e-05 L
.30177 4e-05 L
.32187 4e-05 L
.34121 4e-05 L
.36178 4e-05 L
.38159 4e-05 L
.40264 4e-05 L
.42293 4e-05 L
.44244 4e-05 L
.4632 4e-05 L
.48217 4e-05 L
s
4e-05 .19329 m
.0196 .20521 L
.04093 .21816 L
.06096 .23028 L
.08023 .24189 L
.10073 .2542 L
.12047 .266 L
.14146 .27847 L
.16167 .29043 L
.18112 .30186 L
.2018 .31396 L
.22173 .32553 L
.24088 .33657 L
.26127 .34824 L
.2809 .35937 L
.30177 .37108 L
.32187 .38225 L
.34121 .39286 L
.36178 .404 L
.38159 .41456 L
.40264 .42558 L
.42293 .43598 L
.44244 .44576 L
.4632 .45587 L
.48217 .46481 L
s
1 1 .5 r
4e-05 4e-05 m
.0196 4e-05 L
.04093 4e-05 L
.06096 4e-05 L
.08023 4e-05 L
.10073 4e-05 L
.12047 4e-05 L
.14146 4e-05 L
.16167 4e-05 L
.18112 4e-05 L
.2018 4e-05 L
.22173 4e-05 L
.24088 4e-05 L
.26127 4e-05 L
.2809 4e-05 L
.30177 4e-05 L
.32187 4e-05 L
.34121 4e-05 L
.36178 4e-05 L
.38159 4e-05 L
.40264 4e-05 L
.42293 4e-05 L
.44244 4e-05 L
.4632 4e-05 L
.48217 4e-05 L
.48217 .46481 L
.4632 .45587 L
.44244 .44576 L
.42293 .43598 L
.40264 .42558 L
.38159 .41456 L
.36178 .404 L
.34121 .39286 L
.32187 .38225 L
.30177 .37108 L
.2809 .35937 L
.26127 .34824 L
.24088 .33657 L
.22173 .32553 L
.2018 .31396 L
.18112 .30186 L
.16167 .29043 L
.14146 .27847 L
.12047 .266 L
.10073 .2542 L
.08023 .24189 L
.06096 .23028 L
.04093 .21816 L
.0196 .20521 L
4e-05 .19329 L
F
0 g
4e-05 4e-05 m
.0196 4e-05 L
.04093 4e-05 L
.06096 4e-05 L
.08023 4e-05 L
.10073 4e-05 L
.12047 4e-05 L
.14146 4e-05 L
.16167 4e-05 L
.18112 4e-05 L
.2018 4e-05 L
.22173 4e-05 L
.24088 4e-05 L
.26127 4e-05 L
.2809 4e-05 L
.30177 4e-05 L
.32187 4e-05 L
.34121 4e-05 L
.36178 4e-05 L
.38159 4e-05 L
.40264 4e-05 L
.42293 4e-05 L
.44244 4e-05 L
.4632 4e-05 L
.48217 4e-05 L
s
4e-05 .19329 m
.0196 .20521 L
.04093 .21816 L
.06096 .23028 L
.08023 .24189 L
.10073 .2542 L
.12047 .266 L
.14146 .27847 L
.16167 .29043 L
.18112 .30186 L
.2018 .31396 L
.22173 .32553 L
.24088 .33657 L
.26127 .34824 L
.2809 .35937 L
.30177 .37108 L
.32187 .38225 L
.34121 .39286 L
.36178 .404 L
.38159 .41456 L
.40264 .42558 L
.42293 .43598 L
.44244 .44576 L
.4632 .45587 L
.48217 .46481 L
s
.48217 4e-05 m
.49066 .01496 L
.49992 .03132 L
.50862 .04676 L
.51698 .0617 L
.52588 .0777 L
.53445 .0932 L
.54355 .1098 L
.55233 .12593 L
.56077 .14158 L
.56975 .15839 L
.57839 .17476 L
.58671 .19068 L
.59556 .20787 L
.60408 .22466 L
.61313 .24283 L
.62186 .26071 L
.63025 .27832 L
.63918 .29761 L
.64778 .31687 L
.65692 .33833 L
.66572 .3604 L
.67419 .38369 L
.67849 .39676 L
.6832 .41286 L
.68526 .42084 L
.68746 .43056 L
.68853 .43601 L
.68954 .44197 L
.69045 .44862 L
.6907 .45087 L
.69096 .45368 L
.69119 .45672 L
.69143 .46429 L
s
.48217 .46481 m
.49066 .4687 L
.49992 .47287 L
.50862 .47669 L
.51698 .48029 L
.52588 .48402 L
.53445 .4875 L
.54355 .49109 L
.55233 .49441 L
.56077 .49746 L
.56975 .50055 L
.57839 .50335 L
.58671 .50585 L
.59556 .50829 L
.60408 .51038 L
.61313 .51229 L
.62186 .51375 L
.62626 .51432 L
.63025 .51474 L
.63233 .51491 L
.63457 .51506 L
.63581 .51513 L
.63695 .51518 L
.63803 .51521 L
.63862 .51523 L
.63918 .51524 L
.6397 .51525 L
.64 .51525 L
.64027 .51526 L
.6405 .51526 L
.64075 .51526 L
.64102 .51526 L
.64126 .51526 L
.64154 .51526 L
.64183 .51526 L
.64207 .51526 L
.64234 .51525 L
.64263 .51525 L
.64294 .51524 L
.6435 .51523 L
.64402 .51522 L
.64458 .5152 L
.64561 .51516 L
.64753 .51505 L
.6486 .51497 L
.64961 .51489 L
.65189 .51464 L
.65412 .51433 L
.65652 .5139 L
.66117 .5128 L
Mistroke
.66559 .51132 L
.66995 .50934 L
.67399 .5069 L
.67851 .50318 L
.6826 .49842 L
.68481 .49495 L
.68684 .49083 L
.6879 .48811 L
.68906 .48437 L
.68965 .48201 L
.69028 .47886 L
.69058 .47695 L
.69087 .47473 L
.69113 .47208 L
.69141 .46644 L
.69143 .46438 L
Mfstroke
1 1 .5 r
.48217 4e-05 m
.49066 .01496 L
.49992 .03132 L
.50862 .04676 L
.51698 .0617 L
.52588 .0777 L
.53445 .0932 L
.54355 .1098 L
.55233 .12593 L
.56077 .14158 L
.56975 .15839 L
.57839 .17476 L
.58671 .19068 L
.59556 .20787 L
.60408 .22466 L
.61313 .24283 L
.62186 .26071 L
.63025 .27832 L
.63918 .29761 L
.64778 .31687 L
.65692 .33833 L
.66572 .3604 L
.67419 .38369 L
.67849 .39676 L
.6832 .41286 L
.68526 .42084 L
.68746 .43056 L
.68853 .43601 L
.68954 .44197 L
.69045 .44862 L
.6907 .45087 L
.69096 .45368 L
.69119 .45672 L
.69143 .46429 L
.69143 .46438 L
.69141 .46644 L
.69113 .47208 L
.69087 .47473 L
.69058 .47695 L
.69028 .47886 L
.68965 .48201 L
.68906 .48437 L
.6879 .48811 L
.68684 .49083 L
.68481 .49495 L
.6826 .49842 L
.67851 .50318 L
.67399 .5069 L
.66995 .50934 L
.66559 .51132 L
.66117 .5128 L
.65652 .5139 L
.65412 .51433 L
.65189 .51464 L
.64961 .51489 L
.6486 .51497 L
.64753 .51505 L
.64561 .51516 L
.64458 .5152 L
.64402 .51522 L
.6435 .51523 L
.64294 .51524 L
.64263 .51525 L
.64234 .51525 L
.64207 .51526 L
.64183 .51526 L
.64154 .51526 L
.64126 .51526 L
.64102 .51526 L
.64075 .51526 L
.6405 .51526 L
.64027 .51526 L
.64 .51525 L
.6397 .51525 L
.63918 .51524 L
.63862 .51523 L
.63803 .51521 L
.63695 .51518 L
.63581 .51513 L
.63457 .51506 L
.63233 .51491 L
.63025 .51474 L
.62626 .51432 L
.62186 .51375 L
.61313 .51229 L
.60408 .51038 L
.59556 .50829 L
.58671 .50585 L
.57839 .50335 L
.56975 .50055 L
.56077 .49746 L
.55233 .49441 L
.54355 .49109 L
.53445 .4875 L
.52588 .48402 L
.51698 .48029 L
.50862 .47669 L
.49992 .47287 L
.49066 .4687 L
.48217 .46481 L
F
0 g
.48217 4e-05 m
.49066 .01496 L
.49992 .03132 L
.50862 .04676 L
.51698 .0617 L
.52588 .0777 L
.53445 .0932 L
.54355 .1098 L
.55233 .12593 L
.56077 .14158 L
.56975 .15839 L
.57839 .17476 L
.58671 .19068 L
.59556 .20787 L
.60408 .22466 L
.61313 .24283 L
.62186 .26071 L
.63025 .27832 L
.63918 .29761 L
.64778 .31687 L
.65692 .33833 L
.66572 .3604 L
.67419 .38369 L
.67849 .39676 L
.6832 .41286 L
.68526 .42084 L
.68746 .43056 L
.68853 .43601 L
.68954 .44197 L
.69045 .44862 L
.6907 .45087 L
.69096 .45368 L
.69119 .45672 L
.69143 .46429 L
s
.48217 .46481 m
.49066 .4687 L
.49992 .47287 L
.50862 .47669 L
.51698 .48029 L
.52588 .48402 L
.53445 .4875 L
.54355 .49109 L
.55233 .49441 L
.56077 .49746 L
.56975 .50055 L
.57839 .50335 L
.58671 .50585 L
.59556 .50829 L
.60408 .51038 L
.61313 .51229 L
.62186 .51375 L
.62626 .51432 L
.63025 .51474 L
.63233 .51491 L
.63457 .51506 L
.63581 .51513 L
.63695 .51518 L
.63803 .51521 L
.63862 .51523 L
.63918 .51524 L
.6397 .51525 L
.64 .51525 L
.64027 .51526 L
.6405 .51526 L
.64075 .51526 L
.64102 .51526 L
.64126 .51526 L
.64154 .51526 L
.64183 .51526 L
.64207 .51526 L
.64234 .51525 L
.64263 .51525 L
.64294 .51524 L
.6435 .51523 L
.64402 .51522 L
.64458 .5152 L
.64561 .51516 L
.64753 .51505 L
.6486 .51497 L
.64961 .51489 L
.65189 .51464 L
.65412 .51433 L
.65652 .5139 L
.66117 .5128 L
Mistroke
.66559 .51132 L
.66995 .50934 L
.67399 .5069 L
.67851 .50318 L
.6826 .49842 L
.68481 .49495 L
.68684 .49083 L
.6879 .48811 L
.68906 .48437 L
.68965 .48201 L
.69028 .47886 L
.69058 .47695 L
.69087 .47473 L
.69113 .47208 L
.69141 .46644 L
.69143 .46438 L
Mfstroke
4e-05 .19329 m
.0196 .20521 L
.04093 .21816 L
.06096 .23028 L
.08023 .24189 L
.10073 .2542 L
.12047 .266 L
.14146 .27847 L
.16167 .29043 L
.18112 .30186 L
.2018 .31396 L
.22173 .32553 L
.24088 .33657 L
.26127 .34824 L
.2809 .35937 L
.30177 .37108 L
.32187 .38225 L
.34121 .39286 L
.36178 .404 L
.38159 .41456 L
.40264 .42558 L
.42293 .43598 L
.44244 .44576 L
.4632 .45587 L
.48217 .46481 L
s
4e-05 .99996 m
.0196 .99996 L
.04093 .99996 L
.06096 .99996 L
.08023 .99996 L
.10073 .99996 L
.12047 .99996 L
.14146 .99996 L
.16167 .99996 L
.18112 .99996 L
.2018 .99996 L
.22173 .99996 L
.24088 .99996 L
.26127 .99996 L
.2809 .99996 L
.30177 .99996 L
.32187 .99996 L
.34121 .99996 L
.36178 .99996 L
.38159 .99996 L
.40264 .99996 L
.42293 .99996 L
.44244 .99996 L
.4632 .99996 L
.48217 .99996 L
s
.5 1 1 r
4e-05 .19329 m
.0196 .20521 L
.04093 .21816 L
.06096 .23028 L
.08023 .24189 L
.10073 .2542 L
.12047 .266 L
.14146 .27847 L
.16167 .29043 L
.18112 .30186 L
.2018 .31396 L
.22173 .32553 L
.24088 .33657 L
.26127 .34824 L
.2809 .35937 L
.30177 .37108 L
.32187 .38225 L
.34121 .39286 L
.36178 .404 L
.38159 .41456 L
.40264 .42558 L
.42293 .43598 L
.44244 .44576 L
.4632 .45587 L
.48217 .46481 L
.48217 .99996 L
.4632 .99996 L
.44244 .99996 L
.42293 .99996 L
.40264 .99996 L
.38159 .99996 L
.36178 .99996 L
.34121 .99996 L
.32187 .99996 L
.30177 .99996 L
.2809 .99996 L
.26127 .99996 L
.24088 .99996 L
.22173 .99996 L
.2018 .99996 L
.18112 .99996 L
.16167 .99996 L
.14146 .99996 L
.12047 .99996 L
.10073 .99996 L
.08023 .99996 L
.06096 .99996 L
.04093 .99996 L
.0196 .99996 L
4e-05 .99996 L
F
0 g
4e-05 .19329 m
.0196 .20521 L
.04093 .21816 L
.06096 .23028 L
.08023 .24189 L
.10073 .2542 L
.12047 .266 L
.14146 .27847 L
.16167 .29043 L
.18112 .30186 L
.2018 .31396 L
.22173 .32553 L
.24088 .33657 L
.26127 .34824 L
.2809 .35937 L
.30177 .37108 L
.32187 .38225 L
.34121 .39286 L
.36178 .404 L
.38159 .41456 L
.40264 .42558 L
.42293 .43598 L
.44244 .44576 L
.4632 .45587 L
.48217 .46481 L
s
4e-05 .99996 m
.0196 .99996 L
.04093 .99996 L
.06096 .99996 L
.08023 .99996 L
.10073 .99996 L
.12047 .99996 L
.14146 .99996 L
.16167 .99996 L
.18112 .99996 L
.2018 .99996 L
.22173 .99996 L
.24088 .99996 L
.26127 .99996 L
.2809 .99996 L
.30177 .99996 L
.32187 .99996 L
.34121 .99996 L
.36178 .99996 L
.38159 .99996 L
.40264 .99996 L
.42293 .99996 L
.44244 .99996 L
.4632 .99996 L
.48217 .99996 L
s
.48217 4e-05 m
.49066 4e-05 L
.49992 4e-05 L
.50862 4e-05 L
.51698 4e-05 L
.52588 4e-05 L
.53445 4e-05 L
.54355 4e-05 L
.55233 4e-05 L
.56077 4e-05 L
.56975 4e-05 L
.57839 4e-05 L
.58671 4e-05 L
.59556 4e-05 L
.60408 4e-05 L
.61313 4e-05 L
.62186 4e-05 L
.63025 4e-05 L
.63918 4e-05 L
.64778 4e-05 L
.65692 4e-05 L
.66572 4e-05 L
.67419 4e-05 L
.6832 4e-05 L
.69143 4e-05 L
s
.48217 4e-05 m
.49066 .01496 L
.49992 .03132 L
.50862 .04676 L
.51698 .0617 L
.52588 .0777 L
.53445 .0932 L
.54355 .1098 L
.55233 .12593 L
.56077 .14158 L
.56975 .15839 L
.57839 .17476 L
.58671 .19068 L
.59556 .20787 L
.60408 .22466 L
.61313 .24283 L
.62186 .26071 L
.63025 .27832 L
.63918 .29761 L
.64778 .31687 L
.65692 .33833 L
.66572 .3604 L
.67419 .38369 L
.67849 .39676 L
.6832 .41286 L
.68526 .42084 L
.68746 .43056 L
.68853 .43601 L
.68954 .44197 L
.69045 .44862 L
.6907 .45087 L
.69096 .45368 L
.69119 .45672 L
.69143 .46429 L
s
.5 1 1 r
.48217 4e-05 m
.49066 4e-05 L
.49992 4e-05 L
.50862 4e-05 L
.51698 4e-05 L
.52588 4e-05 L
.53445 4e-05 L
.54355 4e-05 L
.55233 4e-05 L
.56077 4e-05 L
.56975 4e-05 L
.57839 4e-05 L
.58671 4e-05 L
.59556 4e-05 L
.60408 4e-05 L
.61313 4e-05 L
.62186 4e-05 L
.63025 4e-05 L
.63918 4e-05 L
.64778 4e-05 L
.65692 4e-05 L
.66572 4e-05 L
.67419 4e-05 L
.6832 4e-05 L
.69143 4e-05 L
.69143 .46429 L
.69119 .45672 L
.69096 .45368 L
.6907 .45087 L
.69045 .44862 L
.68954 .44197 L
.68853 .43601 L
.68746 .43056 L
.68526 .42084 L
.6832 .41286 L
.67849 .39676 L
.67419 .38369 L
.66572 .3604 L
.65692 .33833 L
.64778 .31687 L
.63918 .29761 L
.63025 .27832 L
.62186 .26071 L
.61313 .24283 L
.60408 .22466 L
.59556 .20787 L
.58671 .19068 L
.57839 .17476 L
.56975 .15839 L
.56077 .14158 L
.55233 .12593 L
.54355 .1098 L
.53445 .0932 L
.52588 .0777 L
.51698 .0617 L
.50862 .04676 L
.49992 .03132 L
.49066 .01496 L
.48217 4e-05 L
F
0 g
.48217 4e-05 m
.49066 4e-05 L
.49992 4e-05 L
.50862 4e-05 L
.51698 4e-05 L
.52588 4e-05 L
.53445 4e-05 L
.54355 4e-05 L
.55233 4e-05 L
.56077 4e-05 L
.56975 4e-05 L
.57839 4e-05 L
.58671 4e-05 L
.59556 4e-05 L
.60408 4e-05 L
.61313 4e-05 L
.62186 4e-05 L
.63025 4e-05 L
.63918 4e-05 L
.64778 4e-05 L
.65692 4e-05 L
.66572 4e-05 L
.67419 4e-05 L
.6832 4e-05 L
.69143 4e-05 L
s
.48217 4e-05 m
.49066 .01496 L
.49992 .03132 L
.50862 .04676 L
.51698 .0617 L
.52588 .0777 L
.53445 .0932 L
.54355 .1098 L
.55233 .12593 L
.56077 .14158 L
.56975 .15839 L
.57839 .17476 L
.58671 .19068 L
.59556 .20787 L
.60408 .22466 L
.61313 .24283 L
.62186 .26071 L
.63025 .27832 L
.63918 .29761 L
.64778 .31687 L
.65692 .33833 L
.66572 .3604 L
.67419 .38369 L
.67849 .39676 L
.6832 .41286 L
.68526 .42084 L
.68746 .43056 L
.68853 .43601 L
.68954 .44197 L
.69045 .44862 L
.6907 .45087 L
.69096 .45368 L
.69119 .45672 L
.69143 .46429 L
s
.69143 4e-05 m
.70395 4e-05 L
.7176 4e-05 L
.73042 4e-05 L
.74275 4e-05 L
.75587 4e-05 L
.7685 4e-05 L
.78193 4e-05 L
.79486 4e-05 L
.80731 4e-05 L
.82055 4e-05 L
.8333 4e-05 L
.84555 4e-05 L
.8586 4e-05 L
.87116 4e-05 L
.88452 4e-05 L
.89738 4e-05 L
.90976 4e-05 L
.92292 4e-05 L
.9356 4e-05 L
.94907 4e-05 L
.96205 4e-05 L
.97454 4e-05 L
.98782 4e-05 L
.99996 4e-05 L
s
.69143 .99996 m
.70395 .99996 L
.7176 .99996 L
.73042 .99996 L
.74275 .99996 L
.75587 .99996 L
.7685 .99996 L
.78193 .99996 L
.79486 .99996 L
.80731 .99996 L
.82055 .99996 L
.8333 .99996 L
.84555 .99996 L
.8586 .99996 L
.87116 .99996 L
.88452 .99996 L
.89738 .99996 L
.90976 .99996 L
.92292 .99996 L
.9356 .99996 L
.94907 .99996 L
.96205 .99996 L
.97454 .99996 L
.98782 .99996 L
.99996 .99996 L
s
.5 1 1 r
.69143 4e-05 m
.70395 4e-05 L
.7176 4e-05 L
.73042 4e-05 L
.74275 4e-05 L
.75587 4e-05 L
.7685 4e-05 L
.78193 4e-05 L
.79486 4e-05 L
.80731 4e-05 L
.82055 4e-05 L
.8333 4e-05 L
.84555 4e-05 L
.8586 4e-05 L
.87116 4e-05 L
.88452 4e-05 L
.89738 4e-05 L
.90976 4e-05 L
.92292 4e-05 L
.9356 4e-05 L
.94907 4e-05 L
.96205 4e-05 L
.97454 4e-05 L
.98782 4e-05 L
.99996 4e-05 L
.99996 .99996 L
.98782 .99996 L
.97454 .99996 L
.96205 .99996 L
.94907 .99996 L
.9356 .99996 L
.92292 .99996 L
.90976 .99996 L
.89738 .99996 L
.88452 .99996 L
.87116 .99996 L
.8586 .99996 L
.84555 .99996 L
.8333 .99996 L
.82055 .99996 L
.80731 .99996 L
.79486 .99996 L
.78193 .99996 L
.7685 .99996 L
.75587 .99996 L
.74275 .99996 L
.73042 .99996 L
.7176 .99996 L
.70395 .99996 L
.69143 .99996 L
F
0 g
.69143 4e-05 m
.70395 4e-05 L
.7176 4e-05 L
.73042 4e-05 L
.74275 4e-05 L
.75587 4e-05 L
.7685 4e-05 L
.78193 4e-05 L
.79486 4e-05 L
.80731 4e-05 L
.82055 4e-05 L
.8333 4e-05 L
.84555 4e-05 L
.8586 4e-05 L
.87116 4e-05 L
.88452 4e-05 L
.89738 4e-05 L
.90976 4e-05 L
.92292 4e-05 L
.9356 4e-05 L
.94907 4e-05 L
.96205 4e-05 L
.97454 4e-05 L
.98782 4e-05 L
.99996 4e-05 L
s
.69143 .99996 m
.70395 .99996 L
.7176 .99996 L
.73042 .99996 L
.74275 .99996 L
.75587 .99996 L
.7685 .99996 L
.78193 .99996 L
.79486 .99996 L
.80731 .99996 L
.82055 .99996 L
.8333 .99996 L
.84555 .99996 L
.8586 .99996 L
.87116 .99996 L
.88452 .99996 L
.89738 .99996 L
.90976 .99996 L
.92292 .99996 L
.9356 .99996 L
.94907 .99996 L
.96205 .99996 L
.97454 .99996 L
.98782 .99996 L
.99996 .99996 L
s
.48217 .46481 m
.49066 .4687 L
.49992 .47287 L
.50862 .47669 L
.51698 .48029 L
.52588 .48402 L
.53445 .4875 L
.54355 .49109 L
.55233 .49441 L
.56077 .49746 L
.56975 .50055 L
.57839 .50335 L
.58671 .50585 L
.59556 .50829 L
.60408 .51038 L
.61313 .51229 L
.62186 .51375 L
.62626 .51432 L
.63025 .51474 L
.63233 .51491 L
.63457 .51506 L
.63581 .51513 L
.63695 .51518 L
.63803 .51521 L
.63862 .51523 L
.63918 .51524 L
.6397 .51525 L
.64 .51525 L
.64027 .51526 L
.6405 .51526 L
.64075 .51526 L
.64102 .51526 L
.64126 .51526 L
.64154 .51526 L
.64183 .51526 L
.64207 .51526 L
.64234 .51525 L
.64263 .51525 L
.64294 .51524 L
.6435 .51523 L
.64402 .51522 L
.64458 .5152 L
.64561 .51516 L
.64753 .51505 L
.6486 .51497 L
.64961 .51489 L
.65189 .51464 L
.65412 .51433 L
.65652 .5139 L
.66117 .5128 L
Mistroke
.66559 .51132 L
.66995 .50934 L
.67399 .5069 L
.67851 .50318 L
.6826 .49842 L
.68481 .49495 L
.68684 .49083 L
.6879 .48811 L
.68906 .48437 L
.68965 .48201 L
.69028 .47886 L
.69058 .47695 L
.69087 .47473 L
.69113 .47208 L
.69141 .46644 L
.69143 .46438 L
Mfstroke
.48217 .99996 m
.49066 .99996 L
.49992 .99996 L
.50862 .99996 L
.51698 .99996 L
.52588 .99996 L
.53445 .99996 L
.54355 .99996 L
.55233 .99996 L
.56077 .99996 L
.56975 .99996 L
.57839 .99996 L
.58671 .99996 L
.59556 .99996 L
.60408 .99996 L
.61313 .99996 L
.62186 .99996 L
.63025 .99996 L
.63918 .99996 L
.64778 .99996 L
.65692 .99996 L
.66572 .99996 L
.67419 .99996 L
.6832 .99996 L
.69143 .99996 L
s
.5 1 1 r
.48217 .46481 m
.49066 .4687 L
.49992 .47287 L
.50862 .47669 L
.51698 .48029 L
.52588 .48402 L
.53445 .4875 L
.54355 .49109 L
.55233 .49441 L
.56077 .49746 L
.56975 .50055 L
.57839 .50335 L
.58671 .50585 L
.59556 .50829 L
.60408 .51038 L
.61313 .51229 L
.62186 .51375 L
.62626 .51432 L
.63025 .51474 L
.63233 .51491 L
.63457 .51506 L
.63581 .51513 L
.63695 .51518 L
.63803 .51521 L
.63862 .51523 L
.63918 .51524 L
.6397 .51525 L
.64 .51525 L
.64027 .51526 L
.6405 .51526 L
.64075 .51526 L
.64102 .51526 L
.64126 .51526 L
.64154 .51526 L
.64183 .51526 L
.64207 .51526 L
.64234 .51525 L
.64263 .51525 L
.64294 .51524 L
.6435 .51523 L
.64402 .51522 L
.64458 .5152 L
.64561 .51516 L
.64753 .51505 L
.6486 .51497 L
.64961 .51489 L
.65189 .51464 L
.65412 .51433 L
.65652 .5139 L
.66117 .5128 L
.66559 .51132 L
.66995 .50934 L
.67399 .5069 L
.67851 .50318 L
.6826 .49842 L
.68481 .49495 L
.68684 .49083 L
.6879 .48811 L
.68906 .48437 L
.68965 .48201 L
.69028 .47886 L
.69058 .47695 L
.69087 .47473 L
.69113 .47208 L
.69141 .46644 L
.69143 .46438 L
.69143 .99996 L
.6832 .99996 L
.67419 .99996 L
.66572 .99996 L
.65692 .99996 L
.64778 .99996 L
.63918 .99996 L
.63025 .99996 L
.62186 .99996 L
.61313 .99996 L
.60408 .99996 L
.59556 .99996 L
.58671 .99996 L
.57839 .99996 L
.56975 .99996 L
.56077 .99996 L
.55233 .99996 L
.54355 .99996 L
.53445 .99996 L
.52588 .99996 L
.51698 .99996 L
.50862 .99996 L
.49992 .99996 L
.49066 .99996 L
.48217 .99996 L
F
0 g
.48217 .46481 m
.49066 .4687 L
.49992 .47287 L
.50862 .47669 L
.51698 .48029 L
.52588 .48402 L
.53445 .4875 L
.54355 .49109 L
.55233 .49441 L
.56077 .49746 L
.56975 .50055 L
.57839 .50335 L
.58671 .50585 L
.59556 .50829 L
.60408 .51038 L
.61313 .51229 L
.62186 .51375 L
.62626 .51432 L
.63025 .51474 L
.63233 .51491 L
.63457 .51506 L
.63581 .51513 L
.63695 .51518 L
.63803 .51521 L
.63862 .51523 L
.63918 .51524 L
.6397 .51525 L
.64 .51525 L
.64027 .51526 L
.6405 .51526 L
.64075 .51526 L
.64102 .51526 L
.64126 .51526 L
.64154 .51526 L
.64183 .51526 L
.64207 .51526 L
.64234 .51525 L
.64263 .51525 L
.64294 .51524 L
.6435 .51523 L
.64402 .51522 L
.64458 .5152 L
.64561 .51516 L
.64753 .51505 L
.6486 .51497 L
.64961 .51489 L
.65189 .51464 L
.65412 .51433 L
.65652 .5139 L
.66117 .5128 L
Mistroke
.66559 .51132 L
.66995 .50934 L
.67399 .5069 L
.67851 .50318 L
.6826 .49842 L
.68481 .49495 L
.68684 .49083 L
.6879 .48811 L
.68906 .48437 L
.68965 .48201 L
.69028 .47886 L
.69058 .47695 L
.69087 .47473 L
.69113 .47208 L
.69141 .46644 L
.69143 .46438 L
Mfstroke
.48217 .99996 m
.49066 .99996 L
.49992 .99996 L
.50862 .99996 L
.51698 .99996 L
.52588 .99996 L
.53445 .99996 L
.54355 .99996 L
.55233 .99996 L
.56077 .99996 L
.56975 .99996 L
.57839 .99996 L
.58671 .99996 L
.59556 .99996 L
.60408 .99996 L
.61313 .99996 L
.62186 .99996 L
.63025 .99996 L
.63918 .99996 L
.64778 .99996 L
.65692 .99996 L
.66572 .99996 L
.67419 .99996 L
.6832 .99996 L
.69143 .99996 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 0 r
.02 w
.06278 .03141 Mdot
.05886 .02749 Mdot
.05886 .03533 Mdot
.06278 .04317 Mdot
.06278 .05102 Mdot
.0667 .05494 Mdot
.0667 .05102 Mdot
.07454 .05102 Mdot
.07454 .04709 Mdot
.07846 .05102 Mdot
.07454 .05494 Mdot
.07062 .05102 Mdot
.07454 .04709 Mdot
.07846 .04709 Mdot
.07062 .04317 Mdot
.07062 .05102 Mdot
.07454 .04709 Mdot
.07846 .05102 Mdot
.08239 .05102 Mdot
.07062 .04317 Mdot
.07062 .04317 Mdot
.07062 .04317 Mdot
.06278 .03925 Mdot
.06278 .04317 Mdot
.07454 .05102 Mdot
.07846 .05886 Mdot
.07454 .05886 Mdot
.07062 .05886 Mdot
.07846 .05886 Mdot
.07846 .05886 Mdot
.07846 .05886 Mdot
.07846 .05494 Mdot
.07846 .05102 Mdot
.07454 .04709 Mdot
.08631 .05886 Mdot
.09023 .06278 Mdot
.09023 .06278 Mdot
.08631 .05494 Mdot
.08631 .05102 Mdot
.09415 .05886 Mdot
.08631 .05494 Mdot
.08239 .05102 Mdot
.07846 .05494 Mdot
.08631 .0667 Mdot
.09023 .06278 Mdot
.08631 .05886 Mdot
.08239 .05102 Mdot
.07846 .04709 Mdot
.08239 .05102 Mdot
.08239 .05102 Mdot
.09023 .05886 Mdot
.09023 .05886 Mdot
.08631 .06278 Mdot
.09415 .07846 Mdot
.09023 .07454 Mdot
.09807 .08239 Mdot
.09807 .07846 Mdot
.09023 .07454 Mdot
.08239 .07062 Mdot
.08631 .07062 Mdot
.08631 .07062 Mdot
.07846 .06278 Mdot
.07846 .05494 Mdot
.08239 .05102 Mdot
.08239 .05102 Mdot
.07454 .04709 Mdot
.08239 .05494 Mdot
.08631 .06278 Mdot
.09023 .0667 Mdot
.09023 .07454 Mdot
.09023 .07454 Mdot
.09807 .07846 Mdot
.09807 .07846 Mdot
.08239 .06278 Mdot
.08239 .0667 Mdot
.07454 .06278 Mdot
.07846 .0667 Mdot
.09023 .07454 Mdot
.09807 .07454 Mdot
.09807 .0667 Mdot
.09023 .05886 Mdot
.09415 .07062 Mdot
.09415 .0667 Mdot
.09415 .0667 Mdot
.09415 .07062 Mdot
.09415 .0667 Mdot
.09807 .0667 Mdot
.08239 .05494 Mdot
.08631 .05886 Mdot
.08631 .0667 Mdot
.08239 .06278 Mdot
.08631 .06278 Mdot
.08631 .06278 Mdot
.08631 .07062 Mdot
.08631 .07062 Mdot
.09023 .07846 Mdot
.08239 .07454 Mdot
.08239 .07454 Mdot
.07846 .0667 Mdot
.07062 .06278 Mdot
.08239 .0667 Mdot
.07846 .05886 Mdot
.07454 .05102 Mdot
.07454 .05494 Mdot
.07062 .04709 Mdot
.07454 .05102 Mdot
.0667 .05102 Mdot
.07062 .05886 Mdot
.07454 .05102 Mdot
.07062 .05102 Mdot
.07454 .05886 Mdot
.07454 .05886 Mdot
.07062 .05494 Mdot
.0667 .05102 Mdot
.07062 .05886 Mdot
.0667 .05494 Mdot
.05886 .04709 Mdot
.04709 .03533 Mdot
.05494 .03533 Mdot
.05494 .03925 Mdot
.05886 .03925 Mdot
.0667 .03925 Mdot
.07454 .04709 Mdot
.07062 .04709 Mdot
.06278 .04317 Mdot
.05886 .03533 Mdot
.05102 .02749 Mdot
.05102 .02357 Mdot
.05494 .03141 Mdot
.05102 .03141 Mdot
.04317 .02357 Mdot
.03925 .02749 Mdot
.05886 .04317 Mdot
.05494 .05102 Mdot
.05494 .0667 Mdot
.04709 .0667 Mdot
.04317 .0667 Mdot
.03533 .05494 Mdot
.03925 .03925 Mdot
.05102 .03925 Mdot
.03925 .03925 Mdot
.04317 .04317 Mdot
.04709 .05102 Mdot
.05886 .07062 Mdot
.00788 .02749 Mdot
.00788 .01572 Mdot
.00788 .0118 Mdot
.00788 .01572 Mdot
.00396 .02357 Mdot
.00396 .02749 Mdot
.00396 .03141 Mdot
.00788 .03141 Mdot
.00788 .02357 Mdot
.00788 .01965 Mdot
.00396 .02357 Mdot
.00396 .01965 Mdot
.00396 .01572 Mdot
.00788 .01572 Mdot
.00788 .01572 Mdot
.00788 .0118 Mdot
.09807 .08631 Mdot
.1216 .10591 Mdot
.12944 .11768 Mdot
.12944 .1216 Mdot
.1216 .12944 Mdot
.13336 .14513 Mdot
.1412 .12944 Mdot
.13728 .10983 Mdot
.12552 .09023 Mdot
.1216 .08239 Mdot
.12944 .07846 Mdot
.1412 .08239 Mdot
.14513 .08631 Mdot
.1412 .08239 Mdot
.13728 .07846 Mdot
.12944 .07454 Mdot
.13336 .07846 Mdot
.12552 .07846 Mdot
.13336 .07846 Mdot
.1412 .08239 Mdot
.1412 .08631 Mdot
.1412 .08239 Mdot
.1216 .07454 Mdot
.12944 .08239 Mdot
.12944 .07846 Mdot
.12944 .07846 Mdot
.12944 .08239 Mdot
.13728 .09415 Mdot
.1412 .10199 Mdot
.1412 .10983 Mdot
.13728 .10591 Mdot
.14513 .10591 Mdot
.14905 .10199 Mdot
.15297 .09807 Mdot
.14905 .09807 Mdot
.1412 .09807 Mdot
.14905 .10199 Mdot
.16473 .10591 Mdot
.17257 .10199 Mdot
.1765 .10983 Mdot
.16865 .10199 Mdot
.16473 .10591 Mdot
.14905 .09807 Mdot
.15297 .10591 Mdot
.16473 .10983 Mdot
.16473 .10199 Mdot
.15689 .10199 Mdot
.16865 .10591 Mdot
.17257 .10983 Mdot
.1765 .10983 Mdot
.18434 .11768 Mdot
.17257 .11768 Mdot
.16865 .12944 Mdot
.15297 .1216 Mdot
.16081 .1216 Mdot
.17257 .12944 Mdot
.16865 .11376 Mdot
.18434 .1216 Mdot
.18042 .11376 Mdot
.1765 .11376 Mdot
.18434 .1216 Mdot
.16865 .11768 Mdot
.17257 .1216 Mdot
.16865 .11376 Mdot
.16865 .10983 Mdot
.16865 .10591 Mdot
.1765 .10983 Mdot
.17257 .11376 Mdot
.1765 .11768 Mdot
.18042 .12944 Mdot
.16473 .11376 Mdot
.16865 .10591 Mdot
.1765 .10983 Mdot
.17257 .10983 Mdot
.18434 .11768 Mdot
.17257 .10983 Mdot
.16865 .10983 Mdot
.1961 .12552 Mdot
.17257 .10591 Mdot
.1765 .10199 Mdot
.18434 .11376 Mdot
.19218 .12944 Mdot
.16081 .09807 Mdot
.18042 .11376 Mdot
.16473 .10983 Mdot
.17257 .11768 Mdot
.18042 .1216 Mdot
.19218 .12552 Mdot
.19218 .12944 Mdot
.18434 .12552 Mdot
.18434 .13336 Mdot
.18434 .12944 Mdot
.19218 .14513 Mdot
.1765 .12944 Mdot
.16865 .11376 Mdot
.16473 .10199 Mdot
.17257 .10591 Mdot
.17257 .10983 Mdot
.1765 .11376 Mdot
.18434 .11376 Mdot
.18434 .11376 Mdot
.18042 .11768 Mdot
.16865 .1216 Mdot
.16473 .1216 Mdot
.1765 .12552 Mdot
.1765 .13728 Mdot
.14513 .11768 Mdot
.1412 .10983 Mdot
.13728 .09415 Mdot
.12944 .09023 Mdot
.13336 .09415 Mdot
.1412 .10199 Mdot
.12944 .10591 Mdot
.13336 .10591 Mdot
.13728 .10591 Mdot
.13728 .09807 Mdot
.12552 .08631 Mdot
.11376 .07062 Mdot
.15297 .09415 Mdot
.13728 .08631 Mdot
.1412 .08631 Mdot
.14513 .08631 Mdot
.1412 .07846 Mdot
.12552 .07062 Mdot
.12552 .0667 Mdot
.12552 .0667 Mdot
.12552 .0667 Mdot
.11768 .06278 Mdot
.11376 .0667 Mdot
.11768 .07062 Mdot
.10983 .0667 Mdot
.11768 .07062 Mdot
.1216 .07454 Mdot
.11768 .08239 Mdot
.1216 .08631 Mdot
.15297 .12944 Mdot
.05494 .08631 Mdot
.04709 .07454 Mdot
.05102 .05102 Mdot
.04317 .03141 Mdot
.04317 .02749 Mdot
.10199 .06278 Mdot
.0667 .04317 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.01572 .00396 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.00788 .0118 Mdot
.00788 .01572 Mdot
.00788 .01572 Mdot
.01572 .01572 Mdot
.01572 .0118 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.01572 .00396 Mdot
.01572 .00396 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.68234 .59607 Mdot
.70587 .62352 Mdot
.72547 .63528 Mdot
.72939 .63136 Mdot
.56862 .49804 Mdot
.1412 .16865 Mdot
.10591 .1216 Mdot
.11376 .10591 Mdot
.07846 .0667 Mdot
.07062 .04709 Mdot
.07062 .03533 Mdot
.09415 .04317 Mdot
.10983 .05494 Mdot
.11376 .05494 Mdot
.11768 .05886 Mdot
.11376 .05494 Mdot
.1216 .05886 Mdot
.1216 .05886 Mdot
.12552 .05886 Mdot
.12552 .06278 Mdot
.11376 .06278 Mdot
.12552 .07454 Mdot
.12552 .07846 Mdot
.13336 .08631 Mdot
.13728 .09023 Mdot
.13728 .09023 Mdot
.14513 .10199 Mdot
.13728 .09807 Mdot
.13728 .09807 Mdot
.1412 .10591 Mdot
.1412 .10591 Mdot
.14513 .10591 Mdot
.14513 .09807 Mdot
.15297 .09415 Mdot
.14513 .09023 Mdot
.13336 .08239 Mdot
.14513 .09023 Mdot
.1412 .08239 Mdot
.14905 .07846 Mdot
.15297 .08631 Mdot
.15297 .09415 Mdot
.15297 .09415 Mdot
.1412 .08631 Mdot
.14905 .09415 Mdot
.14905 .09807 Mdot
.12944 .07846 Mdot
.13336 .08239 Mdot
.1412 .08631 Mdot
.15689 .09807 Mdot
.15297 .09807 Mdot
.16473 .10199 Mdot
.16473 .11768 Mdot
.16081 .12944 Mdot
.14905 .12552 Mdot
.16081 .13336 Mdot
.16473 .12552 Mdot
.16865 .11376 Mdot
.1765 .10983 Mdot
.18042 .10591 Mdot
.18042 .09807 Mdot
.1765 .09807 Mdot
.18042 .1216 Mdot
.16473 .1216 Mdot
.17257 .11768 Mdot
.1765 .11376 Mdot
.18042 .11376 Mdot
.17257 .10591 Mdot
.18826 .11376 Mdot
.18434 .11376 Mdot
.1765 .11376 Mdot
.1765 .11376 Mdot
.18042 .11376 Mdot
.18434 .11376 Mdot
.18434 .10591 Mdot
.18826 .11768 Mdot
.16865 .10199 Mdot
.1765 .10199 Mdot
.18042 .09807 Mdot
.18826 .10199 Mdot
.18434 .09807 Mdot
.18042 .09415 Mdot
.17257 .09807 Mdot
.16473 .09023 Mdot
.16865 .09807 Mdot
.16865 .10591 Mdot
.15689 .10199 Mdot
.16081 .10591 Mdot
.16473 .11768 Mdot
.18042 .13336 Mdot
.18434 .13336 Mdot
.19218 .13336 Mdot
.1961 .13728 Mdot
.19218 .13728 Mdot
.18434 .12552 Mdot
.18826 .12552 Mdot
.1961 .12552 Mdot
.1961 .11768 Mdot
.21179 .12944 Mdot
.21179 .13728 Mdot
.20787 .13728 Mdot
.1961 .13336 Mdot
.21179 .14905 Mdot
.20787 .15689 Mdot
.1961 .1412 Mdot
.20394 .14513 Mdot
.1961 .14905 Mdot
.18434 .14513 Mdot
.18042 .13728 Mdot
.16865 .12552 Mdot
.18434 .13336 Mdot
.18042 .13336 Mdot
.18826 .1412 Mdot
.18434 .14513 Mdot
.16865 .12552 Mdot
.16473 .11768 Mdot
.15689 .10983 Mdot
.14905 .10199 Mdot
.16081 .10983 Mdot
.16081 .10199 Mdot
.15297 .09023 Mdot
.15297 .08239 Mdot
.16081 .09415 Mdot
.15689 .09023 Mdot
.16473 .09023 Mdot
.15689 .08631 Mdot
.14905 .08239 Mdot
.16081 .09415 Mdot
.15689 .09415 Mdot
.14905 .09023 Mdot
.15689 .09807 Mdot
.13728 .08631 Mdot
.1412 .08631 Mdot
.1412 .08239 Mdot
.1412 .07846 Mdot
.1216 .05886 Mdot
.13336 .06278 Mdot
.12552 .05102 Mdot
.10591 .04709 Mdot
.10983 .07062 Mdot
.10591 .07846 Mdot
.09807 .07846 Mdot
.11768 .08239 Mdot
.1216 .07846 Mdot
.10591 .05102 Mdot
.09807 .04709 Mdot
.09807 .05494 Mdot
.08631 .05102 Mdot
.08239 .05102 Mdot
.10199 .05886 Mdot
.10591 .06278 Mdot
.10591 .07062 Mdot
.09023 .0667 Mdot
.09807 .07062 Mdot
.09023 .06278 Mdot
.09415 .07454 Mdot
.09415 .07846 Mdot
.10199 .07454 Mdot
.10983 .07062 Mdot
.10199 .0667 Mdot
.10199 .07062 Mdot
.68234 .61176 Mdot
.71763 .64705 Mdot
.73332 .64705 Mdot
.72547 .63136 Mdot
.69802 .60391 Mdot
.29413 .28629 Mdot
.07846 .09415 Mdot
.11768 .10591 Mdot
.10199 .09023 Mdot
.09023 .07062 Mdot
.10199 .06278 Mdot
.10983 .05494 Mdot
.12552 .05886 Mdot
.12944 .05494 Mdot
.1216 .05494 Mdot
.11768 .05494 Mdot
.12944 .05886 Mdot
.1412 .07062 Mdot
.13728 .0667 Mdot
.13336 .0667 Mdot
.12944 .07846 Mdot
.1216 .08239 Mdot
.12944 .09807 Mdot
.13336 .10591 Mdot
.13728 .10591 Mdot
.1412 .10591 Mdot
.1412 .10983 Mdot
.12552 .09415 Mdot
.1412 .10199 Mdot
.14513 .10591 Mdot
.14905 .10591 Mdot
.15297 .10199 Mdot
.14905 .09415 Mdot
.15297 .09415 Mdot
.14513 .08239 Mdot
.14905 .08631 Mdot
.16473 .10199 Mdot
.16865 .09807 Mdot
.16081 .09023 Mdot
.16081 .09023 Mdot
.16473 .09023 Mdot
.16473 .09415 Mdot
.16081 .09023 Mdot
.14905 .09415 Mdot
.15297 .09807 Mdot
.14905 .09415 Mdot
.1412 .09023 Mdot
.15297 .09807 Mdot
.14905 .10591 Mdot
.15689 .10199 Mdot
.16473 .10591 Mdot
.1765 .12944 Mdot
.16865 .13336 Mdot
.15689 .12552 Mdot
.15689 .11768 Mdot
.17257 .11768 Mdot
.18042 .10591 Mdot
.18042 .09415 Mdot
.18826 .09415 Mdot
.1765 .09023 Mdot
.18826 .10591 Mdot
.20394 .13336 Mdot
.18826 .12944 Mdot
.18042 .12944 Mdot
.1961 .1412 Mdot
.19218 .13336 Mdot
.18826 .12552 Mdot
.18826 .12552 Mdot
.16473 .11376 Mdot
.15297 .10983 Mdot
.16081 .10983 Mdot
.16865 .10983 Mdot
.22355 .13728 Mdot
.20002 .11768 Mdot
.18434 .10199 Mdot
.1765 .10199 Mdot
.18042 .09415 Mdot
.18434 .09807 Mdot
.1765 .09023 Mdot
.1765 .09023 Mdot
.1765 .09415 Mdot
.18042 .10199 Mdot
.16865 .09023 Mdot
.15689 .09023 Mdot
.16081 .10591 Mdot
.16081 .11376 Mdot
.15689 .11376 Mdot
.16081 .12944 Mdot
.16081 .12944 Mdot
.18042 .1412 Mdot
.18826 .14513 Mdot
.1961 .14513 Mdot
.1961 .13728 Mdot
.1961 .12944 Mdot
.18042 .10983 Mdot
.19218 .10983 Mdot
.20002 .10983 Mdot
.20002 .11376 Mdot
.20394 .11768 Mdot
.20787 .1216 Mdot
.19218 .11768 Mdot
.20394 .13336 Mdot
.20394 .13728 Mdot
.1961 .12944 Mdot
.1961 .13728 Mdot
.20787 .14905 Mdot
.20394 .14513 Mdot
.18826 .13728 Mdot
.18434 .14513 Mdot
.18434 .14513 Mdot
.18434 .13728 Mdot
.19218 .13728 Mdot
.19218 .13728 Mdot
.18042 .12944 Mdot
.17257 .10983 Mdot
.16865 .10591 Mdot
.16081 .10591 Mdot
.16081 .10199 Mdot
.16865 .10199 Mdot
.17257 .10199 Mdot
.16865 .10199 Mdot
.16473 .10199 Mdot
.16081 .10199 Mdot
.14905 .09415 Mdot
.15297 .09415 Mdot
.16081 .10591 Mdot
.15297 .10591 Mdot
.1412 .10591 Mdot
.1412 .10199 Mdot
.14513 .10199 Mdot
.1412 .09807 Mdot
.1412 .09023 Mdot
.1412 .09023 Mdot
.14905 .09415 Mdot
.14905 .09023 Mdot
.14513 .09023 Mdot
.14905 .09415 Mdot
.13336 .08239 Mdot
.11376 .07062 Mdot
.1216 .08239 Mdot
.10983 .08239 Mdot
.10591 .07846 Mdot
.09807 .07062 Mdot
.10591 .06278 Mdot
.10983 .06278 Mdot
.10591 .0667 Mdot
.09415 .05494 Mdot
.10199 .06278 Mdot
.10199 .07062 Mdot
.10199 .07846 Mdot
.09807 .08239 Mdot
.09023 .08239 Mdot
.09023 .07846 Mdot
.09415 .08239 Mdot
.10199 .08631 Mdot
.09807 .08239 Mdot
.10591 .08239 Mdot
.11376 .08631 Mdot
.10983 .08239 Mdot
.09807 .07062 Mdot
.67842 .60783 Mdot
.73332 .65881 Mdot
.75292 .66273 Mdot
.72939 .63528 Mdot
.72547 .62744 Mdot
.50588 .44706 Mdot
.1412 .15297 Mdot
.12944 .12552 Mdot
.10591 .09415 Mdot
.09415 .07454 Mdot
.09807 .0667 Mdot
.10591 .06278 Mdot
.11376 .06278 Mdot
.12944 .0667 Mdot
.1412 .07062 Mdot
.1412 .08239 Mdot
.12944 .07454 Mdot
.1412 .08631 Mdot
.14513 .08631 Mdot
.13728 .08631 Mdot
.13728 .09807 Mdot
.13728 .10983 Mdot
.13336 .10983 Mdot
.12552 .10591 Mdot
.12552 .09807 Mdot
.12552 .09807 Mdot
.14513 .11376 Mdot
.13728 .10199 Mdot
.14513 .09807 Mdot
.14513 .09415 Mdot
.14905 .09415 Mdot
.15689 .09415 Mdot
.15297 .08239 Mdot
.15297 .07846 Mdot
.14905 .07454 Mdot
.16081 .08631 Mdot
.16473 .09023 Mdot
.15297 .07846 Mdot
.16081 .08239 Mdot
.16865 .09807 Mdot
.16081 .10199 Mdot
.15689 .09807 Mdot
.15689 .09807 Mdot
.16473 .10199 Mdot
.17257 .10983 Mdot
.17257 .10591 Mdot
.16473 .09807 Mdot
.16473 .10199 Mdot
.16081 .09807 Mdot
.16081 .10199 Mdot
.16081 .10199 Mdot
.16865 .1216 Mdot
.16473 .12552 Mdot
.15689 .1216 Mdot
.15297 .11376 Mdot
.18042 .11768 Mdot
.20002 .11376 Mdot
.20394 .10199 Mdot
.19218 .10199 Mdot
.18826 .10983 Mdot
.18434 .11376 Mdot
.18042 .11768 Mdot
.19218 .13728 Mdot
.18434 .13336 Mdot
.19218 .13728 Mdot
.19218 .1412 Mdot
.19218 .13728 Mdot
.20002 .1412 Mdot
.18434 .12944 Mdot
.17257 .12552 Mdot
.1765 .13336 Mdot
.17257 .1216 Mdot
.17257 .10199 Mdot
.18434 .10199 Mdot
.18434 .10199 Mdot
.17257 .09023 Mdot
.18826 .09415 Mdot
.18042 .09415 Mdot
.18434 .09807 Mdot
.19218 .10199 Mdot
.18434 .10983 Mdot
.18042 .11768 Mdot
.16865 .10983 Mdot
.17257 .10983 Mdot
.16081 .10983 Mdot
.15689 .1216 Mdot
.15297 .1216 Mdot
.1765 .1412 Mdot
.16865 .13336 Mdot
.1765 .1412 Mdot
.1961 .14513 Mdot
.20002 .14513 Mdot
.19218 .13336 Mdot
.1961 .12944 Mdot
.20002 .1216 Mdot
.20394 .11376 Mdot
.20787 .11376 Mdot
.21571 .12552 Mdot
.20394 .12552 Mdot
.18434 .11768 Mdot
.1961 .13336 Mdot
.1961 .13728 Mdot
.20002 .14905 Mdot
.20394 .15297 Mdot
.20002 .14513 Mdot
.20002 .1412 Mdot
.20787 .14905 Mdot
.20787 .14905 Mdot
.20394 .14905 Mdot
.20787 .15297 Mdot
.20394 .1412 Mdot
.20002 .13336 Mdot
.1961 .1216 Mdot
.20394 .12552 Mdot
.20002 .1216 Mdot
.19218 .1216 Mdot
.18042 .11768 Mdot
.17257 .11376 Mdot
.18042 .11376 Mdot
.18434 .1216 Mdot
.18042 .1216 Mdot
.17257 .12552 Mdot
.16081 .11768 Mdot
.16865 .11768 Mdot
.16081 .10983 Mdot
.15297 .10591 Mdot
.14905 .10983 Mdot
.1412 .10591 Mdot
.14513 .10591 Mdot
.15297 .10591 Mdot
.15297 .09415 Mdot
.15297 .09415 Mdot
.15297 .09023 Mdot
.16473 .09415 Mdot
.15689 .07846 Mdot
.15689 .09023 Mdot
.14513 .09023 Mdot
.13728 .08631 Mdot
.13336 .08631 Mdot
.1216 .08631 Mdot
.11376 .07846 Mdot
.11376 .07454 Mdot
.1216 .07454 Mdot
.12552 .06278 Mdot
.1216 .05886 Mdot
.11376 .05886 Mdot
.10199 .06278 Mdot
.10591 .0667 Mdot
.1216 .08239 Mdot
.11768 .07846 Mdot
.11376 .09023 Mdot
.11376 .09807 Mdot
.10591 .09023 Mdot
.10591 .08631 Mdot
.11376 .09023 Mdot
.10591 .08239 Mdot
.11376 .08239 Mdot
.12552 .07846 Mdot
.10591 .06278 Mdot
.10199 .05886 Mdot
.5098 .43922 Mdot
.68234 .57254 Mdot
.70979 .59999 Mdot
.73332 .62352 Mdot
.73724 .62352 Mdot
.6745 .55686 Mdot
.31766 .27453 Mdot
.08631 .08239 Mdot
.11768 .09807 Mdot
.07846 .05886 Mdot
.07454 .04709 Mdot
.08631 .05102 Mdot
.09807 .06278 Mdot
.11768 .0667 Mdot
.12944 .07454 Mdot
.13336 .08631 Mdot
.13336 .08631 Mdot
.14513 .10199 Mdot
.14905 .10591 Mdot
.16473 .10983 Mdot
.15297 .10199 Mdot
.14513 .10983 Mdot
.1412 .10199 Mdot
.1412 .09807 Mdot
.1412 .09415 Mdot
.13728 .08239 Mdot
.13336 .08239 Mdot
.13728 .08631 Mdot
.14513 .09023 Mdot
.13728 .07846 Mdot
.14905 .08239 Mdot
.15297 .08239 Mdot
.16081 .09415 Mdot
.16865 .10199 Mdot
.16473 .10199 Mdot
.15297 .09415 Mdot
.17257 .10983 Mdot
.16473 .10199 Mdot
.16473 .10199 Mdot
.1765 .11768 Mdot
.17257 .11376 Mdot
.17257 .10983 Mdot
.17257 .10983 Mdot
.17257 .10983 Mdot
.16081 .10199 Mdot
.17257 .10199 Mdot
.17257 .09807 Mdot
.16473 .10591 Mdot
.14905 .09023 Mdot
.14905 .09023 Mdot
.14513 .09415 Mdot
.14905 .10591 Mdot
.15297 .11768 Mdot
.16081 .12552 Mdot
.16865 .12944 Mdot
.18434 .13336 Mdot
.18434 .11768 Mdot
.18826 .10983 Mdot
.20002 .11768 Mdot
.20394 .1216 Mdot
.20002 .12944 Mdot
.18826 .12552 Mdot
.20002 .13336 Mdot
.18826 .12552 Mdot
.20394 .13728 Mdot
.20394 .14905 Mdot
.20002 .1412 Mdot
.20002 .13336 Mdot
.19218 .12552 Mdot
.18826 .1216 Mdot
.18826 .12944 Mdot
.17257 .11376 Mdot
.18042 .10591 Mdot
.18434 .10591 Mdot
.1765 .09415 Mdot
.17257 .08631 Mdot
.1765 .09023 Mdot
.18826 .10591 Mdot
.19218 .10983 Mdot
.20002 .11768 Mdot
.18826 .11768 Mdot
.18042 .11768 Mdot
.1765 .12552 Mdot
.1765 .1216 Mdot
.16865 .10983 Mdot
.16865 .10591 Mdot
.16081 .09415 Mdot
.1765 .11768 Mdot
.18434 .12552 Mdot
.18042 .12944 Mdot
.18826 .12944 Mdot
.18826 .12552 Mdot
.18826 .12552 Mdot
.20787 .13728 Mdot
.20394 .13336 Mdot
.21571 .1412 Mdot
.22747 .14905 Mdot
.21571 .14905 Mdot
.20787 .15689 Mdot
.1961 .16081 Mdot
.20394 .16865 Mdot
.19218 .15689 Mdot
.20002 .15689 Mdot
.20002 .14905 Mdot
.20394 .14905 Mdot
.20787 .15297 Mdot
.20394 .14905 Mdot
.20394 .13728 Mdot
.20394 .13336 Mdot
.20394 .13336 Mdot
.20002 .12552 Mdot
.21179 .12552 Mdot
.21179 .1216 Mdot
.20787 .12944 Mdot
.20002 .13336 Mdot
.1961 .1412 Mdot
.1961 .14905 Mdot
.18826 .14513 Mdot
.18042 .13728 Mdot
.1765 .12944 Mdot
.18826 .13728 Mdot
.1765 .12552 Mdot
.18042 .12552 Mdot
.18042 .11376 Mdot
.1765 .10983 Mdot
.16865 .10983 Mdot
.15297 .09807 Mdot
.14905 .09415 Mdot
.14905 .09415 Mdot
.14905 .09415 Mdot
.14513 .08631 Mdot
.15689 .08239 Mdot
.15689 .07846 Mdot
.15689 .07454 Mdot
.14513 .07454 Mdot
.12944 .07846 Mdot
.13336 .09023 Mdot
.12552 .09023 Mdot
.1216 .09023 Mdot
.12552 .09023 Mdot
.1216 .07454 Mdot
.11376 .0667 Mdot
.11376 .06278 Mdot
.11768 .04709 Mdot
.11376 .03925 Mdot
.11376 .04317 Mdot
.10983 .05102 Mdot
.10983 .05886 Mdot
.12552 .07846 Mdot
.12552 .08239 Mdot
.1216 .07846 Mdot
.12944 .08239 Mdot
.12944 .08631 Mdot
.12552 .08239 Mdot
.1216 .08239 Mdot
.11768 .07454 Mdot
.11768 .06278 Mdot
.11768 .06278 Mdot
.11376 .06278 Mdot
.09415 .04709 Mdot
.1765 .13336 Mdot
.29806 .23139 Mdot
.39217 .30982 Mdot
.55686 .42746 Mdot
.62352 .47843 Mdot
.70587 .54117 Mdot
.47451 .35295 Mdot
.07062 .05102 Mdot
.08631 .05886 Mdot
.07846 .04709 Mdot
.06278 .04709 Mdot
.06278 .05102 Mdot
.09023 .06278 Mdot
.10983 .06278 Mdot
.11768 .07062 Mdot
.12944 .07454 Mdot
.13336 .08239 Mdot
.14905 .09023 Mdot
.15297 .09807 Mdot
.15297 .09023 Mdot
.14905 .08631 Mdot
.14513 .08631 Mdot
.14513 .09807 Mdot
.16081 .10591 Mdot
.15689 .10591 Mdot
.16081 .10591 Mdot
.14513 .09023 Mdot
.14905 .09023 Mdot
.15689 .09415 Mdot
.15297 .08631 Mdot
.15689 .08631 Mdot
.15689 .09023 Mdot
.16081 .10199 Mdot
.14905 .10199 Mdot
.15297 .10983 Mdot
.16081 .11376 Mdot
.16081 .10591 Mdot
.16081 .10199 Mdot
.16865 .10591 Mdot
.16473 .10591 Mdot
.16473 .10591 Mdot
.17257 .10591 Mdot
.18434 .11376 Mdot
.18826 .10983 Mdot
.1765 .10199 Mdot
.16081 .09807 Mdot
.16473 .10591 Mdot
.16081 .10199 Mdot
.15689 .10199 Mdot
.16081 .10199 Mdot
.16081 .11376 Mdot
.16081 .11376 Mdot
.18042 .13336 Mdot
.16473 .11768 Mdot
.17257 .11376 Mdot
.17257 .11768 Mdot
.18826 .1216 Mdot
.1961 .10983 Mdot
.18826 .09807 Mdot
.20002 .10591 Mdot
.20002 .10983 Mdot
.19218 .11768 Mdot
.20002 .12552 Mdot
.1961 .12552 Mdot
.20787 .13728 Mdot
.20002 .1412 Mdot
.21571 .16081 Mdot
.21179 .15297 Mdot
.20394 .13336 Mdot
.20002 .12944 Mdot
.18042 .10983 Mdot
.1961 .11768 Mdot
.19218 .11768 Mdot
.18434 .10983 Mdot
.17257 .09807 Mdot
.1765 .09807 Mdot
.18042 .10199 Mdot
.17257 .10591 Mdot
.18434 .10983 Mdot
.18042 .09807 Mdot
.19218 .10983 Mdot
.18042 .11376 Mdot
.18042 .11768 Mdot
.1765 .11376 Mdot
.18042 .10983 Mdot
.17257 .10199 Mdot
.15689 .09023 Mdot
.17257 .10591 Mdot
.18434 .11768 Mdot
.1765 .11376 Mdot
.18042 .12552 Mdot
.18826 .12944 Mdot
.18434 .12552 Mdot
.1961 .13336 Mdot
.20002 .13336 Mdot
.20394 .13336 Mdot
.21571 .1412 Mdot
.21179 .14513 Mdot
.21571 .16081 Mdot
.20787 .16473 Mdot
.21179 .16865 Mdot
.20394 .16081 Mdot
.19218 .14513 Mdot
.19218 .13336 Mdot
.20002 .13728 Mdot
.1961 .13728 Mdot
.20002 .14513 Mdot
.21963 .14905 Mdot
.21571 .1412 Mdot
.20787 .13336 Mdot
.19218 .1216 Mdot
.21179 .13336 Mdot
.21179 .13336 Mdot
.20787 .12944 Mdot
.20394 .13336 Mdot
.19218 .12944 Mdot
.18042 .11768 Mdot
.1961 .12944 Mdot
.17257 .11376 Mdot
.1765 .11376 Mdot
.18042 .11376 Mdot
.17257 .10983 Mdot
.1765 .10591 Mdot
.16865 .09023 Mdot
.16865 .08631 Mdot
.1765 .09415 Mdot
.16865 .10199 Mdot
.15297 .09415 Mdot
.14905 .09023 Mdot
.15689 .09807 Mdot
.14905 .08631 Mdot
.15689 .08631 Mdot
.14905 .08239 Mdot
.14513 .07454 Mdot
.13336 .06278 Mdot
.13728 .07846 Mdot
.13728 .08631 Mdot
.12552 .08631 Mdot
.12552 .09023 Mdot
.12552 .08239 Mdot
.11376 .0667 Mdot
.10983 .06278 Mdot
.09023 .04709 Mdot
.11376 .05886 Mdot
.09807 .03925 Mdot
.09415 .03533 Mdot
.08631 .03141 Mdot
.10591 .05102 Mdot
.11376 .06278 Mdot
.11768 .0667 Mdot
.1216 .0667 Mdot
.1412 .08631 Mdot
.13336 .08239 Mdot
.12944 .07846 Mdot
.1216 .07062 Mdot
.11768 .0667 Mdot
.10591 .04317 Mdot
.09807 .03141 Mdot
.09807 .03925 Mdot
.08631 .03925 Mdot
.1216 .07454 Mdot
.14905 .10199 Mdot
.1412 .09415 Mdot
.16081 .10199 Mdot
.26276 .16473 Mdot
.39609 .26276 Mdot
.36472 .24316 Mdot
.14905 .09415 Mdot
.15689 .11376 Mdot
.13336 .09415 Mdot
.10983 .07846 Mdot
.09415 .06278 Mdot
.11768 .07454 Mdot
.11768 .07062 Mdot
.1216 .07846 Mdot
.13728 .08631 Mdot
.15297 .09023 Mdot
.14905 .09415 Mdot
.15689 .10199 Mdot
.15689 .10199 Mdot
.15689 .10199 Mdot
.14905 .10199 Mdot
.14513 .11376 Mdot
.15297 .11768 Mdot
.16081 .11768 Mdot
.16473 .11768 Mdot
.16081 .10591 Mdot
.14905 .09807 Mdot
.14513 .08631 Mdot
.1412 .07454 Mdot
.15297 .07846 Mdot
.14905 .08239 Mdot
.14905 .09023 Mdot
.16081 .10591 Mdot
.15689 .10983 Mdot
.16473 .12944 Mdot
.16865 .12552 Mdot
.16081 .11768 Mdot
.17257 .12552 Mdot
.18042 .12944 Mdot
.18042 .12552 Mdot
.18042 .11768 Mdot
.18042 .10591 Mdot
.18826 .10983 Mdot
.18434 .10591 Mdot
.16865 .09807 Mdot
.16865 .10591 Mdot
.18434 .1216 Mdot
.1765 .12552 Mdot
.18042 .12552 Mdot
.18434 .12552 Mdot
.18826 .12552 Mdot
.18042 .11768 Mdot
.18042 .10983 Mdot
.18434 .09807 Mdot
.18434 .09415 Mdot
.18826 .10591 Mdot
.17257 .09023 Mdot
.18826 .09807 Mdot
.1961 .10591 Mdot
.18826 .10199 Mdot
.18826 .10591 Mdot
.1961 .11376 Mdot
.20002 .1216 Mdot
.1961 .12944 Mdot
.20394 .13728 Mdot
.21179 .15297 Mdot
.1961 .1412 Mdot
.20002 .1412 Mdot
.19218 .13336 Mdot
.19218 .12552 Mdot
.19218 .11768 Mdot
.18042 .10591 Mdot
.18826 .10591 Mdot
.19218 .10983 Mdot
.18434 .11376 Mdot
.1765 .10591 Mdot
.15689 .09415 Mdot
.15689 .09023 Mdot
.17257 .09807 Mdot
.17257 .10983 Mdot
.18434 .11768 Mdot
.1765 .11376 Mdot
.1765 .11768 Mdot
.17257 .11376 Mdot
.16865 .10983 Mdot
.16473 .10199 Mdot
.18042 .10591 Mdot
.19218 .11376 Mdot
.18826 .10983 Mdot
.18042 .11376 Mdot
.18826 .1216 Mdot
.18826 .1216 Mdot
.1961 .1216 Mdot
.20002 .1216 Mdot
.20002 .12944 Mdot
.20002 .12944 Mdot
.21571 .14513 Mdot
.22747 .16473 Mdot
.21179 .16473 Mdot
.21179 .16865 Mdot
.21571 .16081 Mdot
.21179 .14513 Mdot
.20394 .12944 Mdot
.20394 .12944 Mdot
.21179 .13728 Mdot
.22355 .14905 Mdot
.21963 .14513 Mdot
.21571 .1412 Mdot
.22355 .14513 Mdot
.20787 .1412 Mdot
.20002 .13336 Mdot
.21179 .13336 Mdot
.21571 .13728 Mdot
.20394 .12944 Mdot
.1961 .11768 Mdot
.18826 .10983 Mdot
.18826 .10591 Mdot
.18434 .10199 Mdot
.19218 .11376 Mdot
.19218 .11376 Mdot
.18042 .11376 Mdot
.18434 .11768 Mdot
.18434 .11376 Mdot
.1765 .10199 Mdot
.18042 .10199 Mdot
.19218 .11768 Mdot
.18042 .11376 Mdot
.18434 .11768 Mdot
.16473 .10591 Mdot
.15689 .09807 Mdot
.16081 .09415 Mdot
.14513 .08239 Mdot
.12944 .07846 Mdot
.1412 .08239 Mdot
.14513 .08239 Mdot
.13336 .07454 Mdot
.13336 .08239 Mdot
.12944 .08239 Mdot
.12552 .07454 Mdot
.1216 .05886 Mdot
.1216 .05494 Mdot
.10591 .04709 Mdot
.10591 .05886 Mdot
.10591 .05886 Mdot
.10199 .05102 Mdot
.09807 .04709 Mdot
.10591 .04709 Mdot
.1216 .0667 Mdot
.1216 .06278 Mdot
.10591 .05886 Mdot
.1216 .07062 Mdot
.12552 .07846 Mdot
.1216 .07846 Mdot
.10591 .0667 Mdot
.09807 .05886 Mdot
.09807 .05102 Mdot
.09415 .03925 Mdot
.08239 .03533 Mdot
.06278 .01965 Mdot
.07454 .04317 Mdot
.09415 .0667 Mdot
.09807 .0667 Mdot
.09807 .07454 Mdot
.12944 .09415 Mdot
.15297 .10591 Mdot
.16081 .10591 Mdot
.13728 .09023 Mdot
.13728 .08239 Mdot
.12944 .07062 Mdot
.12552 .06278 Mdot
.11768 .05102 Mdot
.11376 .04709 Mdot
.1216 .06278 Mdot
.12552 .07454 Mdot
.11376 .0667 Mdot
.13336 .07846 Mdot
.14513 .08631 Mdot
.15297 .09415 Mdot
.16473 .10199 Mdot
.16081 .10199 Mdot
.14905 .09415 Mdot
.14905 .09807 Mdot
.16473 .10983 Mdot
.16865 .11376 Mdot
.16473 .11376 Mdot
.16473 .10983 Mdot
.15689 .09807 Mdot
.16865 .10199 Mdot
.16865 .09807 Mdot
.15689 .09023 Mdot
.14905 .09415 Mdot
.15689 .09807 Mdot
.16865 .10591 Mdot
.15689 .11376 Mdot
.16473 .12552 Mdot
.17257 .12944 Mdot
.17257 .12944 Mdot
.1765 .13336 Mdot
.17257 .12944 Mdot
.16473 .1216 Mdot
.15689 .10983 Mdot
.1765 .11376 Mdot
.18434 .10983 Mdot
.19218 .11376 Mdot
.18042 .10983 Mdot
.18042 .11768 Mdot
.17257 .12944 Mdot
.18434 .1412 Mdot
.1765 .13728 Mdot
.1765 .13336 Mdot
.18826 .13336 Mdot
.18826 .12944 Mdot
.18826 .11768 Mdot
.18042 .09415 Mdot
.16865 .09023 Mdot
.18042 .10199 Mdot
.18826 .11376 Mdot
.19218 .10591 Mdot
.20787 .11768 Mdot
.20394 .1216 Mdot
.20394 .12552 Mdot
.20002 .12944 Mdot
.18826 .1216 Mdot
.19218 .12944 Mdot
.20787 .14513 Mdot
.21571 .15689 Mdot
.20394 .14513 Mdot
.21571 .15297 Mdot
.19218 .13336 Mdot
.18434 .12552 Mdot
.20002 .13336 Mdot
.1961 .12552 Mdot
.1961 .1216 Mdot
.1961 .11768 Mdot
.1961 .11768 Mdot
.1961 .11768 Mdot
.18042 .10591 Mdot
.17257 .10199 Mdot
.17257 .10199 Mdot
.18042 .11376 Mdot
.16865 .10591 Mdot
.17257 .10983 Mdot
.18042 .11768 Mdot
.18434 .12552 Mdot
.17257 .11768 Mdot
.16081 .10591 Mdot
.1765 .10591 Mdot
.1961 .11376 Mdot
.18434 .10591 Mdot
.19218 .1216 Mdot
.1961 .12552 Mdot
.1961 .12944 Mdot
.20002 .12552 Mdot
.19218 .1216 Mdot
.20002 .12552 Mdot
.20394 .12944 Mdot
.21571 .13336 Mdot
.21571 .1412 Mdot
.21963 .15689 Mdot
.22747 .17257 Mdot
.22355 .16473 Mdot
.20394 .14513 Mdot
.1961 .12552 Mdot
.20394 .1216 Mdot
.21179 .12944 Mdot
.21179 .13728 Mdot
.21571 .14513 Mdot
.21963 .14905 Mdot
.21571 .14905 Mdot
.20787 .14905 Mdot
.1961 .13728 Mdot
.1961 .13336 Mdot
.20394 .13336 Mdot
.1961 .12944 Mdot
.20002 .12552 Mdot
.20787 .12944 Mdot
.18826 .11376 Mdot
.18434 .11376 Mdot
.18826 .1216 Mdot
.18826 .11768 Mdot
.18826 .11768 Mdot
.18042 .11376 Mdot
.1765 .10983 Mdot
.19218 .11768 Mdot
.18826 .10591 Mdot
.18434 .10983 Mdot
.18826 .12552 Mdot
.1961 .13336 Mdot
.18042 .11768 Mdot
.16865 .10591 Mdot
.15689 .09415 Mdot
.16081 .09415 Mdot
.14513 .08631 Mdot
.1412 .09023 Mdot
.13728 .08631 Mdot
.1412 .08631 Mdot
.13728 .08631 Mdot
.13728 .08239 Mdot
.12944 .07846 Mdot
.12944 .07454 Mdot
.12552 .06278 Mdot
.13336 .06278 Mdot
.10983 .05102 Mdot
.10199 .05102 Mdot
.10199 .05102 Mdot
.09807 .05102 Mdot
.10199 .05102 Mdot
.11376 .05494 Mdot
.11376 .05102 Mdot
.10983 .05102 Mdot
.1216 .07062 Mdot
.10983 .05886 Mdot
.10591 .05886 Mdot
.10199 .06278 Mdot
.10199 .06278 Mdot
.09415 .05494 Mdot
.08631 .03925 Mdot
.0667 .02357 Mdot
.07454 .02749 Mdot
.07062 .04317 Mdot
.07846 .04709 Mdot
.07062 .03925 Mdot
.09415 .05886 Mdot
.09807 .07062 Mdot
.12552 .09415 Mdot
.13336 .09415 Mdot
.13336 .09023 Mdot
.12944 .08239 Mdot
.12944 .07846 Mdot
.13336 .07846 Mdot
.12944 .07454 Mdot
.12552 .07062 Mdot
.12944 .0667 Mdot
.1216 .07062 Mdot
.11768 .05886 Mdot
.13728 .0667 Mdot
.1412 .07062 Mdot
.14513 .07454 Mdot
.14905 .08631 Mdot
.1412 .07846 Mdot
.14905 .09023 Mdot
.14905 .09415 Mdot
.14905 .09415 Mdot
.15297 .09415 Mdot
.15689 .09807 Mdot
.16473 .10983 Mdot
.16081 .10591 Mdot
.1765 .11768 Mdot
.17257 .1216 Mdot
.17257 .11376 Mdot
.16865 .10983 Mdot
.16081 .10983 Mdot
.15689 .10983 Mdot
.16865 .12552 Mdot
.16081 .1216 Mdot
.1765 .12552 Mdot
.16865 .1216 Mdot
.16473 .10983 Mdot
.1765 .11768 Mdot
.17257 .10983 Mdot
.16473 .10983 Mdot
.18042 .1216 Mdot
.18042 .1216 Mdot
.19218 .12552 Mdot
.18826 .11768 Mdot
.19218 .12552 Mdot
.18434 .1216 Mdot
.18434 .1216 Mdot
.18826 .12944 Mdot
.1961 .13336 Mdot
.18042 .11768 Mdot
.18042 .11768 Mdot
.18826 .12552 Mdot
.18042 .11768 Mdot
.18042 .10983 Mdot
.18826 .11768 Mdot
.1961 .11376 Mdot
.19218 .1216 Mdot
.20002 .1216 Mdot
.20002 .12552 Mdot
.20787 .12944 Mdot
.18434 .11768 Mdot
.19218 .12552 Mdot
.20002 .13336 Mdot
.21571 .15297 Mdot
.21571 .15297 Mdot
.21571 .15297 Mdot
.22355 .16865 Mdot
.22355 .16081 Mdot
.21179 .15297 Mdot
.20787 .14513 Mdot
.20787 .13728 Mdot
.20394 .13336 Mdot
.21179 .12552 Mdot
.20787 .11376 Mdot
.20394 .11376 Mdot
.1961 .10591 Mdot
.20394 .11768 Mdot
.20787 .12552 Mdot
.1961 .11376 Mdot
.18434 .10983 Mdot
.1765 .10591 Mdot
.18826 .10983 Mdot
.18826 .1216 Mdot
.18826 .12552 Mdot
.19218 .1216 Mdot
.20002 .10983 Mdot
.20394 .10591 Mdot
.18826 .09415 Mdot
.19218 .10591 Mdot
.20394 .11768 Mdot
.20394 .12944 Mdot
.20394 .13336 Mdot
.20002 .12944 Mdot
.20787 .13728 Mdot
.20394 .12944 Mdot
.20394 .1216 Mdot
.19218 .1216 Mdot
.21179 .14513 Mdot
.21963 .15689 Mdot
.23139 .16473 Mdot
.22747 .15689 Mdot
.22355 .14905 Mdot
.21571 .13336 Mdot
.21179 .1216 Mdot
.21571 .12552 Mdot
.21963 .13336 Mdot
.23139 .14905 Mdot
.22747 .15297 Mdot
.21571 .1412 Mdot
.21179 .13728 Mdot
.21571 .1412 Mdot
.1961 .12944 Mdot
.18434 .12944 Mdot
.18042 .1216 Mdot
.1961 .12944 Mdot
.19218 .12552 Mdot
.18826 .12944 Mdot
.19218 .12944 Mdot
.19218 .12944 Mdot
.20002 .13336 Mdot
.20002 .12944 Mdot
.20002 .13336 Mdot
.18826 .13336 Mdot
.18434 .1216 Mdot
.19218 .12944 Mdot
.19218 .13728 Mdot
.18434 .13336 Mdot
.1961 .13336 Mdot
.18826 .12552 Mdot
.16473 .10199 Mdot
.16473 .09807 Mdot
.15297 .08631 Mdot
.15297 .08631 Mdot
.15297 .09023 Mdot
.16081 .09807 Mdot
.1412 .09023 Mdot
.14513 .09023 Mdot
.13728 .08631 Mdot
.12944 .08239 Mdot
.13336 .08239 Mdot
.1412 .07846 Mdot
.12944 .06278 Mdot
.11376 .05886 Mdot
.11768 .06278 Mdot
.11768 .07062 Mdot
.11768 .0667 Mdot
.10983 .05102 Mdot
.11376 .05102 Mdot
.1216 .05886 Mdot
.11768 .0667 Mdot
.10983 .05886 Mdot
.10591 .05886 Mdot
.10591 .05886 Mdot
.11768 .0667 Mdot
.08239 .03533 Mdot
.08239 .03533 Mdot
.07846 .03141 Mdot
.08631 .03533 Mdot
.03925 .01572 Mdot
.05494 .01965 Mdot
.05886 .01965 Mdot
.08239 .04317 Mdot
.10199 .07454 Mdot
.10983 .08631 Mdot
.11376 .08239 Mdot
.11376 .07846 Mdot
.12944 .10199 Mdot
.13728 .10199 Mdot
.12944 .08239 Mdot
.13728 .08631 Mdot
.12944 .07846 Mdot
.1216 .07062 Mdot
.11376 .06278 Mdot
.12552 .07062 Mdot
.13728 .0667 Mdot
.14905 .07062 Mdot
.15297 .07062 Mdot
.16081 .08631 Mdot
.15297 .08239 Mdot
.15689 .09023 Mdot
.16473 .10591 Mdot
.15689 .09807 Mdot
.16473 .10591 Mdot
.16081 .10591 Mdot
.17257 .11376 Mdot
.1765 .12552 Mdot
.1765 .13336 Mdot
.17257 .12944 Mdot
.1765 .12944 Mdot
.18434 .12944 Mdot
.18042 .13728 Mdot
.16865 .12552 Mdot
.1765 .12944 Mdot
.1765 .1216 Mdot
.18434 .1216 Mdot
.17257 .10983 Mdot
.16081 .10591 Mdot
.16865 .10591 Mdot
.16865 .10591 Mdot
.16473 .10983 Mdot
.18042 .11768 Mdot
.18042 .11768 Mdot
.18826 .12552 Mdot
.18826 .1216 Mdot
.20394 .12944 Mdot
.21179 .13728 Mdot
.20787 .13336 Mdot
.18826 .12552 Mdot
.18826 .1216 Mdot
.18826 .12944 Mdot
.18826 .12552 Mdot
.19218 .12552 Mdot
.1961 .13728 Mdot
.1961 .13336 Mdot
.19218 .1216 Mdot
.19218 .1216 Mdot
.18434 .11376 Mdot
.1961 .1216 Mdot
.19218 .11768 Mdot
.19218 .12552 Mdot
.1961 .12944 Mdot
.18826 .12944 Mdot
.19218 .13728 Mdot
.20787 .14513 Mdot
.22355 .15689 Mdot
.22355 .15689 Mdot
.22355 .16473 Mdot
.21963 .16473 Mdot
.21179 .16473 Mdot
.21963 .17257 Mdot
.20002 .14905 Mdot
.1961 .13728 Mdot
.1961 .1216 Mdot
.20394 .1216 Mdot
.20394 .10983 Mdot
.20394 .10591 Mdot
.20394 .10199 Mdot
.21963 .1216 Mdot
.21179 .12552 Mdot
.21179 .13336 Mdot
.20002 .12944 Mdot
.18434 .1216 Mdot
.18434 .12552 Mdot
.18826 .12552 Mdot
.19218 .1216 Mdot
.1961 .11376 Mdot
.20002 .10199 Mdot
.20002 .09807 Mdot
.20002 .10591 Mdot
.20394 .11768 Mdot
.20002 .12944 Mdot
.20787 .13728 Mdot
.21179 .1412 Mdot
.22355 .14905 Mdot
.21963 .14513 Mdot
.21179 .13336 Mdot
.21179 .12552 Mdot
.20787 .11768 Mdot
.20787 .12552 Mdot
.22355 .1412 Mdot
.21179 .13336 Mdot
.20394 .13728 Mdot
.21571 .1412 Mdot
.21179 .12944 Mdot
.21963 .12944 Mdot
.21179 .1216 Mdot
.21963 .13336 Mdot
.21179 .12944 Mdot
.21179 .13728 Mdot
.21571 .1412 Mdot
.21571 .1412 Mdot
.20787 .13728 Mdot
.19218 .13728 Mdot
.18434 .12944 Mdot
.1765 .11768 Mdot
.18042 .1216 Mdot
.17257 .11376 Mdot
.18042 .11768 Mdot
.18434 .1216 Mdot
.18042 .12552 Mdot
.19218 .13336 Mdot
.1961 .12944 Mdot
.18434 .12552 Mdot
.18042 .12552 Mdot
.17257 .13336 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.18042 .12944 Mdot
.18826 .1216 Mdot
.14905 .08631 Mdot
.15689 .08631 Mdot
.15297 .07454 Mdot
.14905 .0667 Mdot
.15297 .07062 Mdot
.15689 .08631 Mdot
.16473 .09807 Mdot
.15297 .08631 Mdot
.13336 .07846 Mdot
.1216 .07454 Mdot
.12552 .07846 Mdot
.1412 .08631 Mdot
.12552 .07454 Mdot
.1216 .07454 Mdot
.12944 .08239 Mdot
.1216 .08239 Mdot
.1216 .08239 Mdot
.12552 .07846 Mdot
.12552 .07062 Mdot
.1216 .05886 Mdot
.11376 .05494 Mdot
.1216 .05886 Mdot
.10983 .05494 Mdot
.11376 .05494 Mdot
.11768 .05886 Mdot
.10983 .05494 Mdot
.10199 .04709 Mdot
.09807 .05494 Mdot
.09023 .05102 Mdot
.03925 .0118 Mdot
.05102 .01572 Mdot
.08631 .03533 Mdot
.10983 .05886 Mdot
.13728 .08239 Mdot
.1216 .07846 Mdot
.08631 .05886 Mdot
.08239 .0667 Mdot
.10591 .07846 Mdot
.09415 .0667 Mdot
.10199 .07062 Mdot
.11768 .07454 Mdot
.12552 .07846 Mdot
.13728 .08239 Mdot
.13728 .07454 Mdot
.1412 .0667 Mdot
.13728 .05886 Mdot
.15297 .0667 Mdot
.15689 .0667 Mdot
.15689 .07454 Mdot
.15297 .08239 Mdot
.15297 .09415 Mdot
.16473 .10199 Mdot
.16473 .10199 Mdot
.16081 .10199 Mdot
.17257 .10983 Mdot
.18434 .1216 Mdot
.18042 .12552 Mdot
.18434 .13728 Mdot
.17257 .13336 Mdot
.18042 .13728 Mdot
.18434 .1412 Mdot
.18826 .14905 Mdot
.18826 .14513 Mdot
.18434 .13336 Mdot
.17257 .11376 Mdot
.18434 .11768 Mdot
.1765 .10983 Mdot
.1765 .10591 Mdot
.18434 .10591 Mdot
.18434 .10591 Mdot
.17257 .09807 Mdot
.18042 .10591 Mdot
.19218 .1216 Mdot
.20394 .12552 Mdot
.1961 .11768 Mdot
.19218 .11376 Mdot
.20002 .12552 Mdot
.19218 .12552 Mdot
.19218 .12944 Mdot
.18826 .13336 Mdot
.19218 .1412 Mdot
.1961 .14513 Mdot
.19218 .1412 Mdot
.18434 .13728 Mdot
.19218 .13336 Mdot
.20002 .13336 Mdot
.21179 .13728 Mdot
.20394 .12944 Mdot
.20002 .12944 Mdot
.18826 .11768 Mdot
.1961 .1216 Mdot
.20394 .12552 Mdot
.20002 .1216 Mdot
.20002 .12552 Mdot
.20394 .12552 Mdot
.21963 .1412 Mdot
.21963 .14905 Mdot
.22747 .15689 Mdot
.22355 .15297 Mdot
.23139 .16865 Mdot
.22747 .17257 Mdot
.22747 .16865 Mdot
.21963 .15297 Mdot
.21571 .1412 Mdot
.21179 .12944 Mdot
.20787 .11376 Mdot
.20787 .10199 Mdot
.21571 .10591 Mdot
.21179 .11376 Mdot
.20787 .1216 Mdot
.21179 .12944 Mdot
.20787 .12944 Mdot
.20002 .12944 Mdot
.19218 .12552 Mdot
.1961 .12944 Mdot
.20394 .13336 Mdot
.20002 .12552 Mdot
.20394 .1216 Mdot
.20394 .11768 Mdot
.1961 .11768 Mdot
.1961 .1216 Mdot
.21179 .13336 Mdot
.21179 .13728 Mdot
.21571 .14513 Mdot
.21179 .13728 Mdot
.21963 .13336 Mdot
.21571 .1216 Mdot
.21179 .11768 Mdot
.21963 .12552 Mdot
.21179 .12944 Mdot
.21963 .13336 Mdot
.22355 .13728 Mdot
.21963 .1412 Mdot
.22355 .14905 Mdot
.21571 .1412 Mdot
.20787 .13336 Mdot
.20787 .13336 Mdot
.21571 .13336 Mdot
.21179 .1412 Mdot
.21963 .14905 Mdot
.22355 .14905 Mdot
.22355 .14513 Mdot
.21179 .13728 Mdot
.20394 .13728 Mdot
.18826 .12944 Mdot
.17257 .11768 Mdot
.1765 .12944 Mdot
.1765 .12944 Mdot
.18434 .13336 Mdot
.18042 .12552 Mdot
.18826 .12552 Mdot
.1961 .12944 Mdot
.1961 .12944 Mdot
.18434 .1216 Mdot
.18826 .13336 Mdot
.18826 .13728 Mdot
.1765 .12552 Mdot
.18826 .12552 Mdot
.18826 .1216 Mdot
.18434 .11768 Mdot
.1765 .10199 Mdot
.18434 .10199 Mdot
.16865 .08631 Mdot
.16081 .07846 Mdot
.15297 .07454 Mdot
.16473 .09415 Mdot
.16473 .10199 Mdot
.15689 .09023 Mdot
.15689 .09415 Mdot
.14905 .08631 Mdot
.1412 .07846 Mdot
.1412 .07846 Mdot
.12552 .07062 Mdot
.1216 .07062 Mdot
.11376 .07454 Mdot
.10983 .07846 Mdot
.10199 .07062 Mdot
.11376 .07454 Mdot
.1412 .08631 Mdot
.1216 .07454 Mdot
.10199 .06278 Mdot
.09807 .05102 Mdot
.10983 .05102 Mdot
.10983 .04709 Mdot
.10983 .04317 Mdot
.11768 .05494 Mdot
.09807 .04317 Mdot
.09807 .04317 Mdot
.08631 .03533 Mdot
.04317 .01572 Mdot
.06278 .02357 Mdot
.0667 .02357 Mdot
.07062 .03141 Mdot
.09023 .03925 Mdot
.09807 .04317 Mdot
.09415 .03925 Mdot
.07846 .04317 Mdot
.0667 .04317 Mdot
.04317 .02749 Mdot
.0667 .03533 Mdot
.09023 .05102 Mdot
.11768 .06278 Mdot
.11376 .06278 Mdot
.12552 .0667 Mdot
.1412 .07062 Mdot
.14513 .07062 Mdot
.14513 .07062 Mdot
.15297 .07846 Mdot
.14905 .08631 Mdot
.15689 .09807 Mdot
.15689 .09807 Mdot
.16473 .10591 Mdot
.16865 .10591 Mdot
.16473 .09807 Mdot
.18826 .10983 Mdot
.20002 .11376 Mdot
.1961 .11768 Mdot
.19218 .1216 Mdot
.18826 .12552 Mdot
.17257 .12552 Mdot
.18434 .13336 Mdot
.18042 .13336 Mdot
.1765 .12944 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.1961 .13728 Mdot
.19218 .12552 Mdot
.20394 .13336 Mdot
.18826 .1216 Mdot
.18434 .11768 Mdot
.18042 .11376 Mdot
.18042 .11376 Mdot
.18826 .11376 Mdot
.20002 .11768 Mdot
.1961 .11376 Mdot
.20787 .1216 Mdot
.20394 .11768 Mdot
.1961 .10983 Mdot
.20002 .11376 Mdot
.18434 .11768 Mdot
.17257 .11768 Mdot
.18434 .12552 Mdot
.1961 .13728 Mdot
.1961 .14513 Mdot
.1961 .14905 Mdot
.18826 .1412 Mdot
.20002 .14513 Mdot
.20787 .14905 Mdot
.20394 .1412 Mdot
.19218 .1216 Mdot
.18434 .10983 Mdot
.19218 .11376 Mdot
.20002 .11376 Mdot
.21571 .11768 Mdot
.21179 .11768 Mdot
.22355 .13336 Mdot
.22747 .14513 Mdot
.22747 .14513 Mdot
.21963 .13728 Mdot
.23139 .14905 Mdot
.23531 .15297 Mdot
.23531 .15689 Mdot
.23139 .14905 Mdot
.23531 .15297 Mdot
.23924 .14905 Mdot
.22355 .12944 Mdot
.22747 .12944 Mdot
.23531 .12944 Mdot
.22355 .12552 Mdot
.22747 .12944 Mdot
.21179 .11768 Mdot
.21571 .1216 Mdot
.20787 .13336 Mdot
.20787 .14513 Mdot
.20787 .14905 Mdot
.20394 .14905 Mdot
.20394 .1412 Mdot
.21571 .1412 Mdot
.20787 .1216 Mdot
.20394 .11376 Mdot
.20787 .11376 Mdot
.20002 .10983 Mdot
.20002 .11768 Mdot
.21571 .13336 Mdot
.22355 .13336 Mdot
.21571 .1216 Mdot
.21963 .11768 Mdot
.20394 .10199 Mdot
.21963 .1216 Mdot
.22355 .13336 Mdot
.21963 .13336 Mdot
.21963 .13336 Mdot
.21571 .13336 Mdot
.22355 .1412 Mdot
.21963 .13336 Mdot
.21571 .13336 Mdot
.20394 .12552 Mdot
.21963 .13336 Mdot
.21963 .14513 Mdot
.22355 .15297 Mdot
.22355 .14905 Mdot
.22355 .14905 Mdot
.21571 .14513 Mdot
.21179 .1412 Mdot
.20002 .13728 Mdot
.18042 .13336 Mdot
.1765 .13728 Mdot
.16865 .13336 Mdot
.18042 .13336 Mdot
.18826 .13728 Mdot
.18826 .13728 Mdot
.18826 .12944 Mdot
.18434 .12552 Mdot
.19218 .13336 Mdot
.19218 .13728 Mdot
.1961 .1412 Mdot
.18434 .12944 Mdot
.1765 .11376 Mdot
.18434 .11376 Mdot
.1765 .09807 Mdot
.18042 .09807 Mdot
.18042 .09415 Mdot
.18042 .09415 Mdot
.16865 .08631 Mdot
.15297 .07454 Mdot
.15689 .08631 Mdot
.15689 .08631 Mdot
.15297 .09415 Mdot
.16081 .10591 Mdot
.16473 .10983 Mdot
.15689 .10199 Mdot
.14905 .09415 Mdot
.13336 .08239 Mdot
.12552 .07454 Mdot
.11376 .06278 Mdot
.1216 .07454 Mdot
.11768 .07062 Mdot
.12944 .08631 Mdot
.13336 .09023 Mdot
.12552 .08631 Mdot
.10983 .0667 Mdot
.10591 .06278 Mdot
.10983 .05886 Mdot
.11376 .04709 Mdot
.10983 .03925 Mdot
.10983 .03925 Mdot
.10591 .03533 Mdot
.09807 .03533 Mdot
.08239 .03141 Mdot
.03141 .01572 Mdot
.03533 .01572 Mdot
.03533 .00788 Mdot
.05102 .0118 Mdot
.05886 .01572 Mdot
.07454 .01965 Mdot
.10591 .03925 Mdot
.09415 .03533 Mdot
.07454 .02749 Mdot
.04709 .01572 Mdot
.05886 .02357 Mdot
.07846 .03533 Mdot
.06278 .02749 Mdot
.06278 .02357 Mdot
.09415 .04709 Mdot
.1216 .07062 Mdot
.1412 .08239 Mdot
.1412 .08239 Mdot
.16473 .09807 Mdot
.16081 .10591 Mdot
.16081 .10983 Mdot
.16865 .11376 Mdot
.16865 .10591 Mdot
.16865 .10591 Mdot
.16473 .09415 Mdot
.1765 .09415 Mdot
.18826 .09807 Mdot
.18434 .09807 Mdot
.19218 .10591 Mdot
.1961 .11768 Mdot
.18826 .1216 Mdot
.1765 .11768 Mdot
.18434 .12552 Mdot
.18042 .12552 Mdot
.20394 .1412 Mdot
.19218 .12944 Mdot
.20002 .13336 Mdot
.20002 .13336 Mdot
.1961 .12552 Mdot
.1961 .12944 Mdot
.20002 .13336 Mdot
.20787 .13728 Mdot
.20002 .12944 Mdot
.1961 .12944 Mdot
.20787 .12944 Mdot
.21179 .13336 Mdot
.21571 .13728 Mdot
.21179 .12944 Mdot
.20787 .12552 Mdot
.20787 .12944 Mdot
.19218 .12552 Mdot
.18042 .11768 Mdot
.1765 .11768 Mdot
.18434 .12944 Mdot
.18434 .12944 Mdot
.1961 .1412 Mdot
.20002 .14513 Mdot
.20002 .14905 Mdot
.20394 .14905 Mdot
.20787 .1412 Mdot
.21179 .1412 Mdot
.21571 .1412 Mdot
.20787 .12944 Mdot
.20394 .11768 Mdot
.19218 .10199 Mdot
.20394 .11376 Mdot
.20787 .12552 Mdot
.21571 .13336 Mdot
.21963 .13728 Mdot
.22747 .13728 Mdot
.23531 .14513 Mdot
.23531 .14513 Mdot
.23531 .14513 Mdot
.23924 .15297 Mdot
.24316 .15297 Mdot
.23531 .14513 Mdot
.23924 .1412 Mdot
.22747 .12944 Mdot
.23139 .13728 Mdot
.22747 .13336 Mdot
.21571 .13728 Mdot
.21963 .13336 Mdot
.22747 .13336 Mdot
.21571 .12944 Mdot
.21179 .13336 Mdot
.21179 .1412 Mdot
.20787 .14513 Mdot
.20394 .13728 Mdot
.21179 .13728 Mdot
.21179 .13728 Mdot
.20787 .1216 Mdot
.20002 .11376 Mdot
.20002 .10983 Mdot
.20394 .11376 Mdot
.21963 .12552 Mdot
.21571 .1216 Mdot
.21571 .1216 Mdot
.21571 .11768 Mdot
.21963 .11768 Mdot
.23139 .13336 Mdot
.24316 .15297 Mdot
.23139 .15297 Mdot
.20787 .13728 Mdot
.20787 .12552 Mdot
.21571 .12944 Mdot
.21571 .12944 Mdot
.21963 .13336 Mdot
.22355 .13728 Mdot
.22355 .13728 Mdot
.23139 .1412 Mdot
.21963 .13728 Mdot
.21179 .12944 Mdot
.20002 .1216 Mdot
.20787 .13336 Mdot
.20394 .12944 Mdot
.21179 .13728 Mdot
.1961 .13336 Mdot
.18042 .13336 Mdot
.18434 .1412 Mdot
.19218 .14513 Mdot
.19218 .1412 Mdot
.1961 .1412 Mdot
.19218 .13728 Mdot
.18826 .13336 Mdot
.18826 .12944 Mdot
.18826 .12944 Mdot
.19218 .13336 Mdot
.19218 .12552 Mdot
.19218 .1216 Mdot
.19218 .11768 Mdot
.17257 .08631 Mdot
.1765 .08631 Mdot
.1765 .08631 Mdot
.18042 .10199 Mdot
.18042 .10591 Mdot
.14905 .08239 Mdot
.15297 .09415 Mdot
.15297 .09415 Mdot
.15297 .09807 Mdot
.15297 .09807 Mdot
.15689 .10199 Mdot
.16473 .10591 Mdot
.14905 .09807 Mdot
.14513 .09023 Mdot
.13336 .08239 Mdot
.13728 .08631 Mdot
.14905 .09023 Mdot
.12552 .07062 Mdot
.13336 .07062 Mdot
.14513 .08239 Mdot
.12944 .07846 Mdot
.12944 .07454 Mdot
.12944 .07454 Mdot
.11376 .06278 Mdot
.11376 .05886 Mdot
.11376 .06278 Mdot
.11768 .06278 Mdot
.11768 .06278 Mdot
.09807 .05494 Mdot
.08631 .04317 Mdot
.02357 .02357 Mdot
.03141 .01965 Mdot
.02749 .00788 Mdot
.03533 .00396 Mdot
.03533 .00396 Mdot
.06278 .0118 Mdot
.07454 .0118 Mdot
.07846 .01572 Mdot
.08239 .0118 Mdot
.0667 .0118 Mdot
.0667 .01965 Mdot
.07062 .02749 Mdot
.07062 .03533 Mdot
.05494 .02357 Mdot
.05494 .02749 Mdot
.05886 .02749 Mdot
.09415 .05102 Mdot
.11768 .06278 Mdot
.13728 .06278 Mdot
.15297 .08631 Mdot
.16473 .09807 Mdot
.1765 .10199 Mdot
.18042 .10199 Mdot
.17257 .09415 Mdot
.16865 .09807 Mdot
.17257 .09807 Mdot
.17257 .09023 Mdot
.18434 .09807 Mdot
.18826 .10591 Mdot
.19218 .11768 Mdot
.18826 .1216 Mdot
.19218 .11768 Mdot
.20002 .1216 Mdot
.1961 .1216 Mdot
.20002 .13336 Mdot
.20002 .13336 Mdot
.20002 .13728 Mdot
.20394 .1412 Mdot
.20787 .14513 Mdot
.21571 .14513 Mdot
.21179 .1412 Mdot
.21179 .1412 Mdot
.21179 .1412 Mdot
.20394 .13728 Mdot
.20787 .13336 Mdot
.21571 .1412 Mdot
.21571 .13728 Mdot
.20787 .13336 Mdot
.21179 .13728 Mdot
.21571 .1412 Mdot
.20394 .13728 Mdot
.1961 .12552 Mdot
.18042 .10983 Mdot
.18826 .1216 Mdot
.1765 .1216 Mdot
.18826 .12552 Mdot
.19218 .12552 Mdot
.20394 .1412 Mdot
.21179 .14905 Mdot
.21571 .15297 Mdot
.20787 .14513 Mdot
.20787 .13728 Mdot
.20787 .13728 Mdot
.21179 .1412 Mdot
.20002 .12552 Mdot
.21571 .12944 Mdot
.21179 .12552 Mdot
.21571 .12552 Mdot
.21963 .12552 Mdot
.22747 .1412 Mdot
.23531 .13728 Mdot
.23531 .13336 Mdot
.24316 .13728 Mdot
.24316 .1412 Mdot
.24316 .14905 Mdot
.23139 .1412 Mdot
.22747 .13728 Mdot
.23139 .1412 Mdot
.22747 .1412 Mdot
.22747 .15297 Mdot
.23531 .15689 Mdot
.23139 .15689 Mdot
.23531 .15689 Mdot
.21963 .1412 Mdot
.21571 .13336 Mdot
.21179 .13336 Mdot
.20787 .13728 Mdot
.20787 .13336 Mdot
.20787 .13728 Mdot
.20787 .13336 Mdot
.1961 .12552 Mdot
.20002 .11768 Mdot
.20002 .11376 Mdot
.20002 .11376 Mdot
.21963 .1216 Mdot
.21571 .1216 Mdot
.22355 .13728 Mdot
.22355 .13728 Mdot
.23139 .13336 Mdot
.23531 .13336 Mdot
.24316 .14905 Mdot
.23924 .15297 Mdot
.24316 .15297 Mdot
.22355 .13728 Mdot
.20787 .12552 Mdot
.21571 .13336 Mdot
.23531 .14513 Mdot
.23924 .14513 Mdot
.23139 .13728 Mdot
.23139 .13728 Mdot
.21179 .12552 Mdot
.21571 .12552 Mdot
.21179 .11768 Mdot
.20002 .10983 Mdot
.20787 .1216 Mdot
.21571 .12944 Mdot
.20002 .12552 Mdot
.20002 .12944 Mdot
.19218 .13728 Mdot
.1961 .14513 Mdot
.1961 .14513 Mdot
.20002 .13728 Mdot
.1961 .13336 Mdot
.18826 .13728 Mdot
.18434 .1412 Mdot
.19218 .1412 Mdot
.1961 .13336 Mdot
.1961 .12552 Mdot
.18826 .11376 Mdot
.1765 .09415 Mdot
.16865 .07846 Mdot
.1765 .07846 Mdot
.16081 .07454 Mdot
.16473 .09023 Mdot
.18042 .11376 Mdot
.17257 .11376 Mdot
.15689 .10591 Mdot
.15689 .10983 Mdot
.15297 .10199 Mdot
.14513 .09415 Mdot
.14905 .09807 Mdot
.15689 .10199 Mdot
.15297 .09807 Mdot
.13336 .08239 Mdot
.13336 .08239 Mdot
.13336 .07846 Mdot
.14513 .08631 Mdot
.13336 .07454 Mdot
.12552 .05494 Mdot
.13728 .06278 Mdot
.13728 .07062 Mdot
.13728 .07062 Mdot
.12552 .0667 Mdot
.10591 .05886 Mdot
.09807 .05494 Mdot
.11768 .07454 Mdot
.10983 .07062 Mdot
.11376 .07454 Mdot
.09415 .06278 Mdot
.09023 .05494 Mdot
.03533 .02749 Mdot
.04317 .01965 Mdot
.03925 .00788 Mdot
.03925 .00788 Mdot
.02749 .00396 Mdot
.03141 .00396 Mdot
.03533 .00396 Mdot
.03141 .00396 Mdot
.03533 .00396 Mdot
.0667 .0118 Mdot
.08239 .03925 Mdot
.10591 .05494 Mdot
.09023 .04709 Mdot
.07062 .03533 Mdot
.05886 .02357 Mdot
.04709 .01965 Mdot
.04709 .01572 Mdot
.07454 .02357 Mdot
.09415 .02749 Mdot
.12944 .05102 Mdot
.14905 .0667 Mdot
.17257 .08631 Mdot
.19218 .10983 Mdot
.18826 .10199 Mdot
.19218 .11768 Mdot
.18434 .11768 Mdot
.19218 .11768 Mdot
.1961 .11768 Mdot
.18434 .11376 Mdot
.18042 .10199 Mdot
.19218 .10199 Mdot
.20002 .10591 Mdot
.19218 .09807 Mdot
.1961 .10591 Mdot
.21179 .12552 Mdot
.19218 .1216 Mdot
.20002 .13336 Mdot
.20002 .13728 Mdot
.20787 .15297 Mdot
.22355 .16473 Mdot
.21963 .15689 Mdot
.22355 .15689 Mdot
.21571 .15297 Mdot
.20787 .1412 Mdot
.21179 .14513 Mdot
.21963 .1412 Mdot
.21963 .1412 Mdot
.22747 .14513 Mdot
.22747 .1412 Mdot
.21963 .14513 Mdot
.21963 .14513 Mdot
.20002 .12552 Mdot
.18042 .10983 Mdot
.18434 .11376 Mdot
.1961 .12944 Mdot
.1961 .13336 Mdot
.20787 .13728 Mdot
.21179 .1412 Mdot
.21963 .14513 Mdot
.22355 .14905 Mdot
.21963 .14513 Mdot
.21179 .1412 Mdot
.21963 .1412 Mdot
.22355 .14513 Mdot
.22747 .1412 Mdot
.21963 .12552 Mdot
.23139 .12944 Mdot
.21179 .1216 Mdot
.20787 .11376 Mdot
.20787 .12552 Mdot
.21179 .12944 Mdot
.21963 .13336 Mdot
.23531 .1412 Mdot
.23924 .1412 Mdot
.23139 .1412 Mdot
.22355 .13336 Mdot
.21963 .12944 Mdot
.22747 .13728 Mdot
.21963 .12944 Mdot
.23139 .14513 Mdot
.23531 .15689 Mdot
.23924 .16473 Mdot
.23531 .16081 Mdot
.22747 .14905 Mdot
.22747 .1412 Mdot
.22747 .1412 Mdot
.21571 .14513 Mdot
.20787 .1412 Mdot
.21571 .14905 Mdot
.20394 .13728 Mdot
.1961 .12552 Mdot
.20002 .11376 Mdot
.20002 .11376 Mdot
.20787 .11768 Mdot
.21179 .1216 Mdot
.23139 .12944 Mdot
.22747 .12552 Mdot
.21571 .1216 Mdot
.22747 .12944 Mdot
.23139 .13336 Mdot
.22355 .13728 Mdot
.23531 .14513 Mdot
.23924 .15689 Mdot
.22355 .14513 Mdot
.21179 .1412 Mdot
.1961 .12552 Mdot
.20394 .12944 Mdot
.22355 .14905 Mdot
.24316 .16081 Mdot
.22747 .14905 Mdot
.23531 .15297 Mdot
.23531 .14513 Mdot
.22747 .13336 Mdot
.22355 .12944 Mdot
.22747 .12552 Mdot
.23139 .12944 Mdot
.20787 .11376 Mdot
.20394 .11768 Mdot
.20787 .12944 Mdot
.20394 .13728 Mdot
.21179 .14905 Mdot
.21179 .15297 Mdot
.20394 .15297 Mdot
.20002 .15297 Mdot
.19218 .15297 Mdot
.18826 .14905 Mdot
.18434 .13728 Mdot
.18826 .13336 Mdot
.18434 .11376 Mdot
.18826 .09807 Mdot
.18434 .09023 Mdot
.17257 .07846 Mdot
.16865 .08631 Mdot
.16865 .09415 Mdot
.18042 .11376 Mdot
.1765 .11768 Mdot
.18042 .12552 Mdot
.16865 .1216 Mdot
.15689 .10983 Mdot
.16081 .11768 Mdot
.13728 .10199 Mdot
.12944 .09807 Mdot
.12944 .09415 Mdot
.14513 .09023 Mdot
.14905 .08631 Mdot
.14513 .09023 Mdot
.14905 .09023 Mdot
.1412 .09023 Mdot
.13336 .08239 Mdot
.1216 .0667 Mdot
.12552 .06278 Mdot
.13336 .07454 Mdot
.12944 .07062 Mdot
.12944 .07062 Mdot
.1216 .06278 Mdot
.11768 .0667 Mdot
.11376 .07454 Mdot
.11768 .07454 Mdot
.10199 .05886 Mdot
.08631 .04317 Mdot
.03925 .02357 Mdot
.03533 .0118 Mdot
.04317 .00788 Mdot
.04709 .00788 Mdot
.04317 .00396 Mdot
.02749 .00396 Mdot
.01965 .00396 Mdot
.02749 .00396 Mdot
.03533 .00396 Mdot
.02749 .00396 Mdot
.07846 .02357 Mdot
.10199 .04317 Mdot
.09807 .04317 Mdot
.08239 .03533 Mdot
.05494 .01572 Mdot
.05102 .00788 Mdot
.04709 .00788 Mdot
.03533 .00396 Mdot
.04709 .00788 Mdot
.08239 .02357 Mdot
.12552 .05886 Mdot
.15297 .09023 Mdot
.17257 .11376 Mdot
.18826 .12944 Mdot
.20787 .15297 Mdot
.20787 .15689 Mdot
.21571 .15297 Mdot
.20002 .13336 Mdot
.20002 .1216 Mdot
.19218 .10199 Mdot
.18434 .08631 Mdot
.19218 .08239 Mdot
.20394 .09415 Mdot
.20394 .10199 Mdot
.20394 .11376 Mdot
.20787 .12944 Mdot
.20787 .1412 Mdot
.21179 .15689 Mdot
.20394 .16473 Mdot
.20787 .1765 Mdot
.20787 .17257 Mdot
.21571 .1765 Mdot
.21571 .16865 Mdot
.21571 .16473 Mdot
.22355 .15297 Mdot
.23139 .14905 Mdot
.23531 .15297 Mdot
.22747 .14513 Mdot
.23531 .14513 Mdot
.22355 .13336 Mdot
.21963 .13336 Mdot
.21179 .12552 Mdot
.21179 .12944 Mdot
.22355 .14513 Mdot
.21963 .14905 Mdot
.21179 .15689 Mdot
.21179 .16473 Mdot
.22355 .16865 Mdot
.21179 .15297 Mdot
.22355 .14905 Mdot
.22747 .14905 Mdot
.21179 .1412 Mdot
.21179 .13336 Mdot
.21571 .13728 Mdot
.22747 .13728 Mdot
.23531 .13336 Mdot
.22747 .12552 Mdot
.22355 .12552 Mdot
.22355 .12944 Mdot
.21571 .13336 Mdot
.21571 .13336 Mdot
.21571 .13336 Mdot
.21963 .14513 Mdot
.22355 .14513 Mdot
.21963 .1412 Mdot
.23531 .15297 Mdot
.24316 .15689 Mdot
.23139 .1412 Mdot
.24708 .14513 Mdot
.23924 .1412 Mdot
.25492 .16473 Mdot
.24316 .15689 Mdot
.26276 .16473 Mdot
.24708 .14905 Mdot
.22747 .1412 Mdot
.22355 .14513 Mdot
.21963 .14905 Mdot
.21571 .14513 Mdot
.20787 .14513 Mdot
.21179 .14905 Mdot
.20002 .13728 Mdot
.20394 .12552 Mdot
.20002 .1216 Mdot
.20787 .12944 Mdot
.20787 .11768 Mdot
.23531 .12944 Mdot
.23531 .11768 Mdot
.23139 .11376 Mdot
.21571 .10591 Mdot
.22747 .11768 Mdot
.22747 .12552 Mdot
.23531 .1412 Mdot
.24708 .14905 Mdot
.23531 .15297 Mdot
.21963 .14905 Mdot
.22747 .16865 Mdot
.21179 .16081 Mdot
.21179 .16081 Mdot
.22747 .16473 Mdot
.23924 .17257 Mdot
.24316 .16081 Mdot
.24316 .16081 Mdot
.24316 .15689 Mdot
.23924 .1412 Mdot
.23139 .12944 Mdot
.22355 .12552 Mdot
.21963 .1216 Mdot
.21179 .12552 Mdot
.21571 .13728 Mdot
.21179 .1412 Mdot
.20787 .14513 Mdot
.20787 .15689 Mdot
.21179 .16473 Mdot
.20787 .16081 Mdot
.20002 .16081 Mdot
.18826 .15297 Mdot
.1961 .15297 Mdot
.1765 .12944 Mdot
.18826 .1216 Mdot
.19218 .11376 Mdot
.19218 .10591 Mdot
.18826 .10199 Mdot
.18434 .09807 Mdot
.18826 .10983 Mdot
.19218 .11376 Mdot
.18826 .11376 Mdot
.1765 .11768 Mdot
.17257 .11376 Mdot
.18042 .12552 Mdot
.16473 .11768 Mdot
.1412 .09807 Mdot
.13336 .09415 Mdot
.13336 .09023 Mdot
.13728 .09415 Mdot
.14513 .10199 Mdot
.14905 .10591 Mdot
.15297 .10983 Mdot
.15689 .1216 Mdot
.15689 .11768 Mdot
.15297 .10199 Mdot
.1412 .08631 Mdot
.14513 .08631 Mdot
.13336 .07062 Mdot
.13336 .06278 Mdot
.13336 .06278 Mdot
.1216 .05494 Mdot
.12552 .06278 Mdot
.10983 .05102 Mdot
.09807 .03925 Mdot
.08631 .02749 Mdot
.04709 .0118 Mdot
.04709 .01965 Mdot
.05494 .01965 Mdot
.06278 .01572 Mdot
.05102 .0118 Mdot
.04709 .00396 Mdot
.03925 .00396 Mdot
.05102 .00788 Mdot
.04317 .00396 Mdot
.03533 .00396 Mdot
.05102 .00396 Mdot
.05102 .00788 Mdot
.06278 .01572 Mdot
.05886 .00788 Mdot
.06278 .00788 Mdot
.05494 .00788 Mdot
.04317 .00788 Mdot
.03141 .00788 Mdot
.01965 .00396 Mdot
.02749 .00788 Mdot
.05494 .03533 Mdot
.11376 .09023 Mdot
.16081 .13728 Mdot
.18826 .16081 Mdot
.20394 .1765 Mdot
.20787 .1765 Mdot
.21963 .17257 Mdot
.21963 .14905 Mdot
.21571 .13336 Mdot
.20394 .11376 Mdot
.21179 .10199 Mdot
.20787 .08631 Mdot
.21571 .08631 Mdot
.20787 .09023 Mdot
.19218 .09415 Mdot
.1961 .11376 Mdot
.21179 .14513 Mdot
.20787 .15297 Mdot
.21179 .16473 Mdot
.20394 .17257 Mdot
.20787 .18434 Mdot
.20787 .18434 Mdot
.21571 .18042 Mdot
.21571 .17257 Mdot
.23139 .16473 Mdot
.23924 .15689 Mdot
.23924 .15297 Mdot
.23139 .13728 Mdot
.23139 .13336 Mdot
.22747 .12944 Mdot
.24316 .14513 Mdot
.23531 .14905 Mdot
.23531 .15297 Mdot
.23531 .16473 Mdot
.22747 .18042 Mdot
.21179 .18042 Mdot
.21179 .18042 Mdot
.22355 .18434 Mdot
.23139 .17257 Mdot
.23924 .16081 Mdot
.23924 .14905 Mdot
.23139 .1412 Mdot
.21571 .12944 Mdot
.22747 .12944 Mdot
.23531 .13336 Mdot
.24316 .13728 Mdot
.23924 .13728 Mdot
.24708 .15297 Mdot
.24316 .16081 Mdot
.23139 .16081 Mdot
.23139 .16473 Mdot
.22355 .17257 Mdot
.21963 .16865 Mdot
.24708 .18042 Mdot
.24316 .16865 Mdot
.24708 .16473 Mdot
.25492 .16865 Mdot
.25492 .15689 Mdot
.24708 .14513 Mdot
.23531 .13336 Mdot
.24316 .1412 Mdot
.251 .14513 Mdot
.25492 .14905 Mdot
.25492 .16081 Mdot
.23531 .16473 Mdot
.23531 .17257 Mdot
.21571 .16081 Mdot
.20787 .16081 Mdot
.20787 .16081 Mdot
.21571 .15689 Mdot
.20394 .14513 Mdot
.21179 .14513 Mdot
.21179 .1412 Mdot
.20787 .12944 Mdot
.21179 .11376 Mdot
.22355 .10983 Mdot
.23531 .10199 Mdot
.24316 .09807 Mdot
.23924 .08631 Mdot
.23531 .09807 Mdot
.24708 .13336 Mdot
.23531 .13728 Mdot
.24708 .15297 Mdot
.25492 .1765 Mdot
.24708 .18434 Mdot
.24316 .18826 Mdot
.23531 .18434 Mdot
.22355 .18042 Mdot
.20787 .15689 Mdot
.21963 .14905 Mdot
.23139 .14905 Mdot
.24316 .14513 Mdot
.251 .14513 Mdot
.24316 .13336 Mdot
.23531 .12552 Mdot
.22355 .1216 Mdot
.23139 .13336 Mdot
.22355 .13728 Mdot
.22747 .14513 Mdot
.21179 .14905 Mdot
.21963 .16865 Mdot
.21571 .1765 Mdot
.20787 .1765 Mdot
.21571 .18042 Mdot
.20787 .17257 Mdot
.1961 .15689 Mdot
.1961 .15297 Mdot
.1961 .1412 Mdot
.20002 .13336 Mdot
.20002 .12944 Mdot
.1961 .11376 Mdot
.20394 .11376 Mdot
.1961 .10591 Mdot
.18434 .10983 Mdot
.18434 .10983 Mdot
.18826 .11376 Mdot
.17257 .10983 Mdot
.18042 .12552 Mdot
.18042 .13336 Mdot
.16865 .12944 Mdot
.15689 .12552 Mdot
.14513 .11768 Mdot
.1412 .11376 Mdot
.1412 .11376 Mdot
.15297 .11768 Mdot
.14905 .11768 Mdot
.15689 .1216 Mdot
.16081 .1216 Mdot
.16081 .1216 Mdot
.15297 .10591 Mdot
.15297 .09415 Mdot
.14905 .08239 Mdot
.15297 .07454 Mdot
.1412 .05886 Mdot
.14905 .05886 Mdot
.15297 .06278 Mdot
.14905 .05886 Mdot
.14513 .05494 Mdot
.13336 .04709 Mdot
.09415 .03141 Mdot
.04709 .01965 Mdot
.05494 .02357 Mdot
.07062 .03141 Mdot
.0667 .02357 Mdot
.05494 .01965 Mdot
.03925 .0118 Mdot
.03533 .00396 Mdot
.04709 .00788 Mdot
.04317 .00396 Mdot
.05102 .00788 Mdot
.04709 .00396 Mdot
.03141 .00396 Mdot
.03925 .00396 Mdot
.05494 .00788 Mdot
.05494 .01572 Mdot
.05102 .01572 Mdot
.05494 .02357 Mdot
.03925 .02357 Mdot
.02357 .02357 Mdot
.01965 .03141 Mdot
.01572 .03533 Mdot
.07454 .08239 Mdot
.10983 .11376 Mdot
.15689 .15297 Mdot
.18826 .16865 Mdot
.20787 .17257 Mdot
.21179 .15689 Mdot
.22355 .14513 Mdot
.22355 .12552 Mdot
.21571 .10983 Mdot
.21179 .10199 Mdot
.21963 .09415 Mdot
.22747 .09807 Mdot
.21963 .10983 Mdot
.21179 .11768 Mdot
.21571 .13336 Mdot
.21963 .15297 Mdot
.21963 .16865 Mdot
.21963 .16865 Mdot
.21571 .17257 Mdot
.21963 .18434 Mdot
.23139 .18826 Mdot
.23531 .18042 Mdot
.23139 .16865 Mdot
.24708 .16473 Mdot
.23531 .15297 Mdot
.24316 .15297 Mdot
.26276 .16473 Mdot
.25492 .15689 Mdot
.24708 .14905 Mdot
.24316 .15689 Mdot
.24316 .17257 Mdot
.24316 .18434 Mdot
.22747 .18434 Mdot
.23531 .1961 Mdot
.23531 .20002 Mdot
.23924 .20394 Mdot
.24316 .1961 Mdot
.24316 .18434 Mdot
.23924 .17257 Mdot
.24708 .16865 Mdot
.24708 .15689 Mdot
.23531 .1412 Mdot
.24316 .1412 Mdot
.24708 .1412 Mdot
.251 .14905 Mdot
.24316 .15689 Mdot
.24708 .17257 Mdot
.24316 .18434 Mdot
.22747 .18434 Mdot
.22747 .1961 Mdot
.23531 .20002 Mdot
.23924 .1961 Mdot
.23139 .18434 Mdot
.24708 .18434 Mdot
.24708 .17257 Mdot
.26668 .17257 Mdot
.26668 .15689 Mdot
.25884 .15689 Mdot
.251 .14905 Mdot
.24708 .14905 Mdot
.23924 .14513 Mdot
.25492 .16473 Mdot
.24708 .17257 Mdot
.24708 .19218 Mdot
.24708 .20002 Mdot
.23924 .19218 Mdot
.22747 .18042 Mdot
.23924 .1765 Mdot
.23139 .16473 Mdot
.21963 .14905 Mdot
.22747 .14905 Mdot
.21571 .13336 Mdot
.21963 .1216 Mdot
.20787 .10199 Mdot
.20002 .08239 Mdot
.20787 .08239 Mdot
.21571 .08239 Mdot
.22747 .08631 Mdot
.23924 .10199 Mdot
.22747 .12552 Mdot
.23139 .13728 Mdot
.24316 .16081 Mdot
.251 .16865 Mdot
.25492 .18042 Mdot
.25492 .18826 Mdot
.25492 .18434 Mdot
.24708 .17257 Mdot
.23531 .15297 Mdot
.22747 .12944 Mdot
.21963 .10199 Mdot
.22747 .09807 Mdot
.23139 .10199 Mdot
.23139 .10591 Mdot
.23139 .11768 Mdot
.22747 .12944 Mdot
.22747 .14905 Mdot
.21571 .14905 Mdot
.20394 .15689 Mdot
.20002 .16081 Mdot
.1961 .15689 Mdot
.20787 .17257 Mdot
.22355 .19218 Mdot
.20394 .17257 Mdot
.20787 .16473 Mdot
.19218 .14905 Mdot
.20002 .1412 Mdot
.19218 .12944 Mdot
.20394 .13336 Mdot
.21571 .1412 Mdot
.20394 .12944 Mdot
.20394 .1216 Mdot
.20002 .11768 Mdot
.18826 .1216 Mdot
.19218 .12552 Mdot
.19218 .13336 Mdot
.19218 .14513 Mdot
.18434 .14905 Mdot
.16473 .13728 Mdot
.17257 .14513 Mdot
.16865 .14513 Mdot
.16865 .14513 Mdot
.15297 .12944 Mdot
.13728 .11376 Mdot
.14905 .11768 Mdot
.14905 .10983 Mdot
.16081 .11376 Mdot
.16473 .10983 Mdot
.16865 .10983 Mdot
.16473 .09807 Mdot
.15689 .07846 Mdot
.16081 .07454 Mdot
.16081 .07062 Mdot
.15689 .05886 Mdot
.14513 .04317 Mdot
.14905 .04709 Mdot
.1412 .04317 Mdot
.1412 .05102 Mdot
.12944 .05494 Mdot
.10983 .05102 Mdot
.07062 .03925 Mdot
.06278 .03533 Mdot
.0667 .03533 Mdot
.05494 .02357 Mdot
.03533 .0118 Mdot
.02749 .0118 Mdot
.03141 .00788 Mdot
.05494 .01965 Mdot
.0667 .02357 Mdot
.05886 .00788 Mdot
.05886 .00788 Mdot
.04317 .00396 Mdot
.04709 .00396 Mdot
.05494 .0118 Mdot
.0667 .02357 Mdot
.05494 .01965 Mdot
.03925 .01572 Mdot
.02357 .00788 Mdot
.01572 .00788 Mdot
.02749 .03141 Mdot
.03533 .04317 Mdot
.03141 .04709 Mdot
.05886 .07846 Mdot
.10591 .11768 Mdot
.16081 .14905 Mdot
.18434 .15689 Mdot
.20002 .16081 Mdot
.20787 .14513 Mdot
.20787 .13336 Mdot
.21963 .12552 Mdot
.22355 .1216 Mdot
.21963 .11768 Mdot
.21963 .11768 Mdot
.21179 .10983 Mdot
.21571 .12552 Mdot
.20394 .13728 Mdot
.21963 .15689 Mdot
.22747 .1765 Mdot
.21571 .1765 Mdot
.22355 .18434 Mdot
.23531 .20002 Mdot
.23139 .19218 Mdot
.23531 .18042 Mdot
.23139 .16473 Mdot
.23924 .15689 Mdot
.23531 .1412 Mdot
.251 .14513 Mdot
.251 .14905 Mdot
.251 .15297 Mdot
.24708 .15297 Mdot
.23924 .15689 Mdot
.23139 .15689 Mdot
.24708 .1765 Mdot
.23531 .18434 Mdot
.24316 .18826 Mdot
.23924 .18826 Mdot
.23924 .1961 Mdot
.23531 .18826 Mdot
.23139 .18042 Mdot
.24316 .18434 Mdot
.251 .18042 Mdot
.251 .17257 Mdot
.24316 .15689 Mdot
.23924 .14905 Mdot
.23531 .1412 Mdot
.23924 .14513 Mdot
.23924 .15689 Mdot
.23924 .16865 Mdot
.22355 .18042 Mdot
.22355 .18826 Mdot
.23924 .20787 Mdot
.22355 .20787 Mdot
.22355 .20002 Mdot
.24708 .20787 Mdot
.251 .1961 Mdot
.25884 .18042 Mdot
.26668 .16865 Mdot
.27061 .16473 Mdot
.25884 .15297 Mdot
.24708 .14513 Mdot
.24316 .15297 Mdot
.23531 .16081 Mdot
.251 .17257 Mdot
.24708 .18042 Mdot
.25492 .1961 Mdot
.25884 .20002 Mdot
.25492 .20394 Mdot
.24316 .19218 Mdot
.24316 .18434 Mdot
.23924 .16865 Mdot
.24316 .16081 Mdot
.23139 .13728 Mdot
.21963 .12552 Mdot
.21963 .10983 Mdot
.20787 .09415 Mdot
.1961 .09023 Mdot
.1961 .08631 Mdot
.1961 .08631 Mdot
.20394 .08631 Mdot
.21571 .09023 Mdot
.21179 .10983 Mdot
.21179 .11768 Mdot
.22747 .1412 Mdot
.22747 .14905 Mdot
.22355 .16081 Mdot
.23139 .1765 Mdot
.24316 .17257 Mdot
.23531 .15689 Mdot
.23139 .14513 Mdot
.22747 .12552 Mdot
.21571 .10983 Mdot
.21963 .10199 Mdot
.22747 .10591 Mdot
.21963 .10591 Mdot
.22747 .11768 Mdot
.22747 .12944 Mdot
.22355 .1412 Mdot
.22355 .15297 Mdot
.21571 .16865 Mdot
.1961 .15689 Mdot
.19218 .15297 Mdot
.19218 .15689 Mdot
.18434 .15297 Mdot
.1961 .16865 Mdot
.20002 .15689 Mdot
.20394 .14905 Mdot
.21179 .14905 Mdot
.20787 .13728 Mdot
.19218 .1216 Mdot
.20394 .13336 Mdot
.20394 .13728 Mdot
.20002 .12552 Mdot
.20002 .1216 Mdot
.19218 .11768 Mdot
.19218 .12552 Mdot
.18434 .12552 Mdot
.1765 .12944 Mdot
.1961 .15297 Mdot
.18042 .14905 Mdot
.18826 .15689 Mdot
.18042 .16081 Mdot
.16865 .14905 Mdot
.15689 .12944 Mdot
.14905 .11768 Mdot
.15297 .11376 Mdot
.14513 .10591 Mdot
.15689 .10591 Mdot
.16081 .09807 Mdot
.15689 .09023 Mdot
.16473 .09023 Mdot
.16081 .09023 Mdot
.15297 .07846 Mdot
.15297 .07062 Mdot
.14513 .05886 Mdot
.12552 .04317 Mdot
.1412 .04709 Mdot
.1412 .05886 Mdot
.13336 .05886 Mdot
.12944 .05494 Mdot
.1216 .05494 Mdot
.08239 .05494 Mdot
.06278 .05102 Mdot
.05102 .03925 Mdot
.04709 .03141 Mdot
.05102 .03925 Mdot
.03925 .02357 Mdot
.03141 .0118 Mdot
.03533 .00788 Mdot
.05102 .01572 Mdot
.03533 .00788 Mdot
.03533 .00788 Mdot
.03925 .00396 Mdot
.04317 .00396 Mdot
.05102 .00788 Mdot
.03925 .00788 Mdot
.03533 .00788 Mdot
.03141 .00788 Mdot
.01965 .00396 Mdot
.00788 .00396 Mdot
.05494 .03141 Mdot
.08631 .07062 Mdot
.09023 .08631 Mdot
.08631 .10199 Mdot
.09807 .11768 Mdot
.11768 .14513 Mdot
.14905 .16473 Mdot
.18042 .1765 Mdot
.1961 .1765 Mdot
.20002 .16473 Mdot
.20787 .15689 Mdot
.20787 .14513 Mdot
.21963 .13728 Mdot
.21963 .12944 Mdot
.21571 .12552 Mdot
.21963 .12944 Mdot
.21963 .13728 Mdot
.22355 .14905 Mdot
.23139 .17257 Mdot
.23139 .18042 Mdot
.22355 .18042 Mdot
.22747 .18826 Mdot
.22355 .18826 Mdot
.23139 .18434 Mdot
.24316 .18826 Mdot
.23924 .16865 Mdot
.24316 .16473 Mdot
.25492 .16473 Mdot
.25492 .15297 Mdot
.26276 .15689 Mdot
.25884 .15297 Mdot
.25492 .14905 Mdot
.24708 .14513 Mdot
.251 .15689 Mdot
.24708 .16473 Mdot
.251 .1765 Mdot
.25492 .19218 Mdot
.24316 .1961 Mdot
.24708 .20002 Mdot
.24316 .20002 Mdot
.24316 .1961 Mdot
.23924 .19218 Mdot
.25492 .1961 Mdot
.25492 .18434 Mdot
.24316 .15689 Mdot
.23531 .13728 Mdot
.24316 .1412 Mdot
.24316 .1412 Mdot
.23531 .14513 Mdot
.23924 .15689 Mdot
.23531 .16865 Mdot
.23531 .18434 Mdot
.23531 .1961 Mdot
.22355 .19218 Mdot
.22747 .19218 Mdot
.23924 .19218 Mdot
.26276 .18826 Mdot
.26668 .18434 Mdot
.27845 .18042 Mdot
.28629 .17257 Mdot
.28237 .16473 Mdot
.27453 .16865 Mdot
.26276 .16865 Mdot
.25884 .17257 Mdot
.26668 .18434 Mdot
.25884 .18042 Mdot
.25884 .19218 Mdot
.26276 .20002 Mdot
.251 .20002 Mdot
.26276 .20002 Mdot
.25492 .18826 Mdot
.251 .18042 Mdot
.23924 .16473 Mdot
.21963 .1412 Mdot
.20787 .12552 Mdot
.1961 .10983 Mdot
.18434 .09807 Mdot
.1961 .10591 Mdot
.20002 .10591 Mdot
.19218 .09807 Mdot
.20394 .10199 Mdot
.20002 .10199 Mdot
.20787 .1216 Mdot
.21179 .13336 Mdot
.22747 .14513 Mdot
.23531 .15689 Mdot
.23139 .16081 Mdot
.23924 .16865 Mdot
.22747 .15297 Mdot
.22747 .14905 Mdot
.22355 .14513 Mdot
.23531 .14513 Mdot
.23531 .13336 Mdot
.22355 .11768 Mdot
.22355 .11376 Mdot
.22747 .11768 Mdot
.23139 .1216 Mdot
.23139 .12944 Mdot
.23531 .14513 Mdot
.23531 .15689 Mdot
.21179 .14905 Mdot
.20002 .14513 Mdot
.20002 .15689 Mdot
.18826 .15689 Mdot
.18434 .15297 Mdot
.19218 .15297 Mdot
.20394 .15297 Mdot
.20787 .14513 Mdot
.20787 .14513 Mdot
.20394 .13728 Mdot
.21179 .14513 Mdot
.20787 .13728 Mdot
.21179 .13728 Mdot
.20002 .12552 Mdot
.1961 .1216 Mdot
.1961 .1216 Mdot
.20002 .12944 Mdot
.18042 .12552 Mdot
.1765 .13336 Mdot
.18434 .13728 Mdot
.1765 .13728 Mdot
.18042 .13728 Mdot
.18434 .1412 Mdot
.17257 .12944 Mdot
.15689 .11768 Mdot
.16081 .11376 Mdot
.14513 .10591 Mdot
.14513 .10199 Mdot
.15297 .10199 Mdot
.14513 .09807 Mdot
.14905 .09415 Mdot
.16081 .09807 Mdot
.15297 .09807 Mdot
.15297 .09415 Mdot
.14905 .08631 Mdot
.1412 .07454 Mdot
.13728 .0667 Mdot
.13728 .0667 Mdot
.13336 .0667 Mdot
.12944 .07062 Mdot
.1216 .07062 Mdot
.0667 .04317 Mdot
.05886 .04709 Mdot
.04709 .03141 Mdot
.05102 .03141 Mdot
.05494 .03141 Mdot
.03925 .02357 Mdot
.03533 .01572 Mdot
.03925 .01965 Mdot
.02749 .0118 Mdot
.03533 .01572 Mdot
.04317 .01572 Mdot
.03925 .0118 Mdot
.03925 .00788 Mdot
.04317 .00788 Mdot
.03533 .00396 Mdot
.03141 .00396 Mdot
.02749 .00396 Mdot
.01965 .00396 Mdot
.0118 .00396 Mdot
.01965 .00396 Mdot
.07454 .04709 Mdot
.13336 .10199 Mdot
.1961 .16865 Mdot
.21571 .1961 Mdot
.20002 .20002 Mdot
.18826 .18826 Mdot
.19218 .19218 Mdot
.20394 .1961 Mdot
.21963 .20002 Mdot
.20002 .18042 Mdot
.1961 .15689 Mdot
.19218 .13728 Mdot
.19218 .12552 Mdot
.18826 .1216 Mdot
.19218 .11768 Mdot
.19218 .11376 Mdot
.20394 .12552 Mdot
.21571 .13728 Mdot
.21963 .15689 Mdot
.21571 .16865 Mdot
.21963 .1765 Mdot
.22747 .18042 Mdot
.21963 .1765 Mdot
.23924 .18826 Mdot
.21963 .16473 Mdot
.22747 .16473 Mdot
.23139 .14905 Mdot
.24708 .15689 Mdot
.23531 .14905 Mdot
.24316 .14513 Mdot
.23924 .1412 Mdot
.23531 .13336 Mdot
.24316 .14513 Mdot
.24316 .14905 Mdot
.251 .16865 Mdot
.25884 .1765 Mdot
.24316 .16865 Mdot
.23531 .16865 Mdot
.24708 .18434 Mdot
.23924 .18826 Mdot
.25492 .1961 Mdot
.251 .1961 Mdot
.25492 .19218 Mdot
.251 .18042 Mdot
.251 .16865 Mdot
.24708 .15297 Mdot
.24708 .14905 Mdot
.23531 .13728 Mdot
.23924 .1412 Mdot
.23531 .13728 Mdot
.24316 .15297 Mdot
.24708 .16473 Mdot
.24316 .17257 Mdot
.23924 .17257 Mdot
.23924 .16865 Mdot
.24708 .17257 Mdot
.27453 .18826 Mdot
.28237 .18042 Mdot
.27845 .17257 Mdot
.27061 .16473 Mdot
.27453 .17257 Mdot
.26276 .16865 Mdot
.26276 .1765 Mdot
.24316 .16081 Mdot
.251 .16865 Mdot
.25492 .17257 Mdot
.25884 .18042 Mdot
.26276 .19218 Mdot
.26276 .20002 Mdot
.25884 .1961 Mdot
.25884 .19218 Mdot
.24316 .17257 Mdot
.21179 .1412 Mdot
.20394 .12944 Mdot
.19218 .1216 Mdot
.19218 .11768 Mdot
.19218 .11768 Mdot
.19218 .11376 Mdot
.19218 .11376 Mdot
.20394 .11768 Mdot
.18826 .11376 Mdot
.18434 .10591 Mdot
.1961 .10983 Mdot
.20002 .11768 Mdot
.20394 .12944 Mdot
.21571 .13336 Mdot
.21571 .13336 Mdot
.22355 .1412 Mdot
.22747 .14513 Mdot
.23531 .14905 Mdot
.24316 .15689 Mdot
.25884 .16081 Mdot
.251 .15297 Mdot
.24316 .13336 Mdot
.23531 .12552 Mdot
.22747 .1216 Mdot
.20787 .10983 Mdot
.21963 .11768 Mdot
.24316 .1412 Mdot
.23531 .14905 Mdot
.21963 .14513 Mdot
.21179 .15297 Mdot
.20002 .15689 Mdot
.18434 .14513 Mdot
.18826 .14513 Mdot
.1961 .14905 Mdot
.20787 .16081 Mdot
.20787 .15689 Mdot
.20002 .14905 Mdot
.20002 .14905 Mdot
.20002 .1412 Mdot
.20002 .12944 Mdot
.19218 .1216 Mdot
.1961 .1216 Mdot
.20394 .11768 Mdot
.20002 .11768 Mdot
.18434 .11376 Mdot
.16865 .10983 Mdot
.1765 .11768 Mdot
.18042 .11376 Mdot
.18434 .10983 Mdot
.15689 .09415 Mdot
.1765 .10983 Mdot
.17257 .11768 Mdot
.16081 .11768 Mdot
.15297 .1216 Mdot
.14513 .11376 Mdot
.14905 .11376 Mdot
.14513 .1216 Mdot
.1412 .11376 Mdot
.1412 .11376 Mdot
.14513 .10591 Mdot
.14513 .09415 Mdot
.13336 .08631 Mdot
.13336 .08239 Mdot
.1412 .08631 Mdot
.14905 .08631 Mdot
.1412 .07846 Mdot
.12944 .07846 Mdot
.11768 .07454 Mdot
.04709 .01572 Mdot
.04709 .01965 Mdot
.05102 .02357 Mdot
.03925 .01572 Mdot
.03533 .0118 Mdot
.03533 .01572 Mdot
.05102 .02357 Mdot
.0667 .04317 Mdot
.0667 .04317 Mdot
.05494 .03533 Mdot
.0667 .03925 Mdot
.05886 .02357 Mdot
.05494 .0118 Mdot
.04709 .00788 Mdot
.03925 .00396 Mdot
.02749 .00396 Mdot
.02749 .00396 Mdot
.01965 .00396 Mdot
.01965 .00396 Mdot
.01965 .00396 Mdot
.0118 .00396 Mdot
.08631 .05494 Mdot
.27061 .1961 Mdot
.25884 .20002 Mdot
.22747 .19218 Mdot
.23139 .20002 Mdot
.22747 .20002 Mdot
.22355 .1961 Mdot
.25492 .21179 Mdot
.23924 .20002 Mdot
.18434 .15689 Mdot
.15689 .1216 Mdot
.15297 .10591 Mdot
.14513 .08631 Mdot
.14513 .07846 Mdot
.15689 .08239 Mdot
.16473 .08631 Mdot
.16473 .08631 Mdot
.18434 .10199 Mdot
.20394 .13336 Mdot
.21179 .15297 Mdot
.22355 .16473 Mdot
.23924 .17257 Mdot
.25884 .18826 Mdot
.25884 .18434 Mdot
.24708 .16865 Mdot
.251 .16473 Mdot
.251 .16081 Mdot
.23924 .15297 Mdot
.251 .16473 Mdot
.24316 .15689 Mdot
.251 .16473 Mdot
.24708 .16081 Mdot
.24708 .16473 Mdot
.24708 .16081 Mdot
.25492 .16473 Mdot
.25492 .16865 Mdot
.24708 .16473 Mdot
.251 .16865 Mdot
.24708 .16473 Mdot
.24708 .17257 Mdot
.25884 .18826 Mdot
.24708 .19218 Mdot
.251 .18826 Mdot
.25492 .18826 Mdot
.25492 .18042 Mdot
.25492 .17257 Mdot
.23924 .14513 Mdot
.24316 .14513 Mdot
.24708 .1412 Mdot
.251 .1412 Mdot
.25492 .1412 Mdot
.24708 .14513 Mdot
.251 .15689 Mdot
.24708 .16081 Mdot
.24708 .15297 Mdot
.26276 .16081 Mdot
.26276 .15297 Mdot
.26276 .16473 Mdot
.26276 .1765 Mdot
.25884 .18434 Mdot
.26276 .1961 Mdot
.24708 .18434 Mdot
.24316 .17257 Mdot
.24316 .16865 Mdot
.24708 .16865 Mdot
.25492 .16865 Mdot
.25884 .17257 Mdot
.25492 .17257 Mdot
.26276 .1765 Mdot
.27061 .18434 Mdot
.24316 .16081 Mdot
.22355 .14513 Mdot
.20787 .12944 Mdot
.20002 .12552 Mdot
.1961 .12552 Mdot
.19218 .11376 Mdot
.20394 .1216 Mdot
.20002 .1216 Mdot
.1961 .11376 Mdot
.18434 .10591 Mdot
.18042 .10983 Mdot
.18826 .11376 Mdot
.19218 .11376 Mdot
.1961 .11376 Mdot
.20002 .11376 Mdot
.20394 .11376 Mdot
.22355 .12552 Mdot
.23531 .13336 Mdot
.24316 .14513 Mdot
.23924 .15297 Mdot
.251 .16865 Mdot
.25492 .16865 Mdot
.251 .16473 Mdot
.24316 .14905 Mdot
.22355 .13336 Mdot
.20787 .11768 Mdot
.22355 .12552 Mdot
.23139 .13336 Mdot
.21963 .1216 Mdot
.21963 .12944 Mdot
.22355 .13728 Mdot
.20394 .13336 Mdot
.20002 .13336 Mdot
.1961 .12944 Mdot
.18826 .12552 Mdot
.1765 .11768 Mdot
.18826 .12552 Mdot
.20394 .14513 Mdot
.20394 .14905 Mdot
.1961 .14513 Mdot
.20002 .14513 Mdot
.1961 .1412 Mdot
.19218 .12944 Mdot
.20394 .12552 Mdot
.20787 .12944 Mdot
.18826 .11768 Mdot
.18434 .11768 Mdot
.16473 .10591 Mdot
.16081 .09807 Mdot
.1765 .09807 Mdot
.16081 .08239 Mdot
.15689 .07846 Mdot
.15297 .08631 Mdot
.16081 .10199 Mdot
.15297 .10591 Mdot
.13728 .10199 Mdot
.14513 .11376 Mdot
.13728 .11768 Mdot
.14905 .1216 Mdot
.15297 .1216 Mdot
.15297 .11768 Mdot
.13728 .10199 Mdot
.13336 .10199 Mdot
.14513 .10591 Mdot
.13336 .09415 Mdot
.13728 .09807 Mdot
.1412 .10591 Mdot
.13336 .10591 Mdot
.11768 .09023 Mdot
.04317 .0118 Mdot
.03925 .00396 Mdot
.05494 .0118 Mdot
.05494 .01572 Mdot
.03925 .0118 Mdot
.04709 .01965 Mdot
.07454 .03925 Mdot
.09415 .05886 Mdot
.10199 .0667 Mdot
.09023 .0667 Mdot
.10199 .07454 Mdot
.09415 .05494 Mdot
.08631 .03533 Mdot
.05886 .01965 Mdot
.04317 .0118 Mdot
.02749 .00788 Mdot
.03141 .00788 Mdot
.03141 .0118 Mdot
.02357 .00396 Mdot
.01572 .00396 Mdot
.03141 .0118 Mdot
.02749 .00788 Mdot
.10983 .06278 Mdot
.13728 .08239 Mdot
.20394 .1412 Mdot
.32158 .23139 Mdot
.22355 .15689 Mdot
.21571 .15689 Mdot
.25884 .18826 Mdot
.23924 .18042 Mdot
.11768 .09023 Mdot
.10199 .07846 Mdot
.08239 .05494 Mdot
.08631 .04709 Mdot
.09807 .04317 Mdot
.11768 .05102 Mdot
.12944 .05886 Mdot
.12552 .06278 Mdot
.15297 .08239 Mdot
.18826 .11768 Mdot
.21963 .14905 Mdot
.23531 .16865 Mdot
.251 .18042 Mdot
.26276 .18434 Mdot
.25492 .17257 Mdot
.26276 .17257 Mdot
.26276 .16473 Mdot
.27453 .16473 Mdot
.27061 .16081 Mdot
.27453 .17257 Mdot
.27453 .18042 Mdot
.26668 .18042 Mdot
.26276 .18042 Mdot
.25884 .1765 Mdot
.25492 .1765 Mdot
.26276 .1765 Mdot
.26276 .18042 Mdot
.26276 .18826 Mdot
.27453 .18826 Mdot
.25492 .17257 Mdot
.26276 .1765 Mdot
.25884 .18042 Mdot
.25884 .19218 Mdot
.25884 .19218 Mdot
.25884 .1961 Mdot
.26668 .19218 Mdot
.26668 .1765 Mdot
.251 .16473 Mdot
.251 .15689 Mdot
.25884 .15689 Mdot
.27845 .16473 Mdot
.27061 .16081 Mdot
.27453 .16081 Mdot
.26276 .15689 Mdot
.26668 .16081 Mdot
.27061 .16081 Mdot
.27061 .15689 Mdot
.27061 .15689 Mdot
.28237 .16865 Mdot
.28237 .18826 Mdot
.28629 .20002 Mdot
.27845 .21179 Mdot
.26668 .20002 Mdot
.25492 .1961 Mdot
.24316 .18042 Mdot
.23924 .16865 Mdot
.251 .17257 Mdot
.26276 .17257 Mdot
.251 .16081 Mdot
.26668 .17257 Mdot
.26276 .1765 Mdot
.26276 .18042 Mdot
.251 .17257 Mdot
.23531 .15689 Mdot
.20787 .13336 Mdot
.20002 .13336 Mdot
.20394 .12944 Mdot
.20002 .1216 Mdot
.20787 .12552 Mdot
.21963 .13336 Mdot
.20787 .12552 Mdot
.1961 .12552 Mdot
.1961 .12944 Mdot
.20002 .1216 Mdot
.20002 .11376 Mdot
.20002 .1216 Mdot
.1961 .11376 Mdot
.21179 .1216 Mdot
.21179 .12552 Mdot
.21963 .12944 Mdot
.23139 .13728 Mdot
.23924 .14513 Mdot
.23531 .15297 Mdot
.25492 .16865 Mdot
.26276 .16865 Mdot
.25492 .16081 Mdot
.23139 .1412 Mdot
.23531 .1412 Mdot
.21963 .13728 Mdot
.21963 .14513 Mdot
.21571 .1412 Mdot
.23139 .14905 Mdot
.22747 .14905 Mdot
.22747 .14905 Mdot
.20787 .13728 Mdot
.21179 .13336 Mdot
.21571 .12944 Mdot
.20394 .1216 Mdot
.20787 .13728 Mdot
.22355 .15689 Mdot
.22747 .16081 Mdot
.21179 .14905 Mdot
.20787 .1412 Mdot
.18434 .13336 Mdot
.20787 .1412 Mdot
.20394 .13336 Mdot
.20787 .13336 Mdot
.20787 .12944 Mdot
.1961 .12552 Mdot
.18434 .11768 Mdot
.19218 .11376 Mdot
.18042 .10199 Mdot
.1765 .09023 Mdot
.16865 .09415 Mdot
.17257 .10591 Mdot
.16865 .10591 Mdot
.16473 .10591 Mdot
.15297 .10591 Mdot
.16081 .1216 Mdot
.16473 .1216 Mdot
.16081 .11768 Mdot
.14905 .10591 Mdot
.15297 .10591 Mdot
.14513 .10199 Mdot
.1412 .09415 Mdot
.14513 .09415 Mdot
.14905 .09807 Mdot
.1412 .10199 Mdot
.1412 .10199 Mdot
.12552 .09415 Mdot
.03925 .02357 Mdot
.05494 .02749 Mdot
.04709 .01572 Mdot
.03925 .0118 Mdot
.04317 .0118 Mdot
.03925 .0118 Mdot
.05886 .03533 Mdot
.0667 .04709 Mdot
.09807 .06278 Mdot
.11376 .07454 Mdot
.11376 .08239 Mdot
.12552 .08239 Mdot
.10983 .0667 Mdot
.07454 .03533 Mdot
.05494 .01572 Mdot
.03925 .00788 Mdot
.03925 .00788 Mdot
.02357 .00788 Mdot
.03141 .0118 Mdot
.01965 .00788 Mdot
.02357 .00788 Mdot
.04317 .0118 Mdot
.06278 .01965 Mdot
.06278 .0118 Mdot
.07454 .01965 Mdot
.17257 .09807 Mdot
.1765 .10983 Mdot
.18042 .11768 Mdot
.27845 .1961 Mdot
.27845 .20394 Mdot
.18042 .13336 Mdot
.13336 .10591 Mdot
.07846 .0667 Mdot
.06278 .04709 Mdot
.06278 .03925 Mdot
.07062 .03925 Mdot
.08631 .05102 Mdot
.09807 .05886 Mdot
.15297 .09807 Mdot
.18826 .1216 Mdot
.23139 .15297 Mdot
.23924 .16081 Mdot
.26276 .18826 Mdot
.26668 .18434 Mdot
.26668 .1765 Mdot
.25884 .16865 Mdot
.26668 .1765 Mdot
.27061 .16865 Mdot
.27453 .17257 Mdot
.27453 .18042 Mdot
.28237 .19218 Mdot
.27845 .19218 Mdot
.26276 .1765 Mdot
.26668 .18434 Mdot
.25884 .18042 Mdot
.26276 .18434 Mdot
.27845 .1961 Mdot
.27845 .20002 Mdot
.27845 .1961 Mdot
.27453 .18826 Mdot
.27061 .1961 Mdot
.27061 .20002 Mdot
.27061 .19218 Mdot
.27453 .19218 Mdot
.26668 .1961 Mdot
.27061 .19218 Mdot
.25884 .1765 Mdot
.26276 .18042 Mdot
.25492 .1765 Mdot
.27453 .18042 Mdot
.27453 .18042 Mdot
.28237 .18434 Mdot
.27453 .18434 Mdot
.27845 .18042 Mdot
.27845 .16865 Mdot
.27453 .16473 Mdot
.28629 .17257 Mdot
.27845 .16865 Mdot
.29806 .19218 Mdot
.28629 .20002 Mdot
.28237 .20787 Mdot
.29021 .21963 Mdot
.29021 .21963 Mdot
.29021 .21963 Mdot
.26668 .1961 Mdot
.251 .1765 Mdot
.251 .16865 Mdot
.24708 .16081 Mdot
.24708 .15689 Mdot
.25884 .16473 Mdot
.25884 .1765 Mdot
.26668 .1961 Mdot
.27845 .20787 Mdot
.25884 .19218 Mdot
.23139 .17257 Mdot
.22355 .16865 Mdot
.21571 .16081 Mdot
.21571 .14513 Mdot
.22355 .14513 Mdot
.22355 .14513 Mdot
.22355 .13336 Mdot
.21571 .1216 Mdot
.20394 .11376 Mdot
.20394 .10983 Mdot
.20787 .10983 Mdot
.20002 .10591 Mdot
.19218 .10591 Mdot
.19218 .10983 Mdot
.1961 .1216 Mdot
.18826 .1216 Mdot
.20394 .12944 Mdot
.21571 .13728 Mdot
.23139 .14905 Mdot
.23531 .14905 Mdot
.251 .15689 Mdot
.25884 .16473 Mdot
.24316 .14905 Mdot
.24316 .14905 Mdot
.24316 .14905 Mdot
.23924 .15297 Mdot
.22355 .13728 Mdot
.21571 .12944 Mdot
.21571 .13728 Mdot
.23139 .14513 Mdot
.22355 .14513 Mdot
.21571 .13728 Mdot
.21179 .13728 Mdot
.20002 .12944 Mdot
.20002 .13336 Mdot
.21179 .1412 Mdot
.21571 .14513 Mdot
.1961 .12944 Mdot
.1961 .13728 Mdot
.20787 .14513 Mdot
.19218 .13336 Mdot
.18826 .1216 Mdot
.18826 .11768 Mdot
.1961 .1216 Mdot
.20787 .13336 Mdot
.20394 .1216 Mdot
.1961 .10983 Mdot
.18434 .09807 Mdot
.18434 .09415 Mdot
.1765 .09415 Mdot
.1765 .09807 Mdot
.17257 .10983 Mdot
.17257 .11768 Mdot
.15297 .11768 Mdot
.16081 .1216 Mdot
.15689 .11768 Mdot
.16473 .11768 Mdot
.16081 .10983 Mdot
.15689 .09807 Mdot
.14905 .09023 Mdot
.15297 .08631 Mdot
.15297 .09023 Mdot
.16081 .10199 Mdot
.16473 .09807 Mdot
.16081 .10591 Mdot
.1412 .09023 Mdot
.04709 .04317 Mdot
.04317 .03533 Mdot
.05886 .03533 Mdot
.04317 .01965 Mdot
.02749 .00788 Mdot
.01965 .00788 Mdot
.02749 .00788 Mdot
.04709 .03141 Mdot
.05494 .04317 Mdot
.07454 .05886 Mdot
.09415 .07062 Mdot
.10199 .07454 Mdot
.09807 .0667 Mdot
.07454 .04317 Mdot
.05494 .01572 Mdot
.04317 .00396 Mdot
.03141 .00788 Mdot
.02357 .00788 Mdot
.01965 .00788 Mdot
.02357 .0118 Mdot
.02357 .01572 Mdot
.04709 .02749 Mdot
.04709 .01965 Mdot
.04709 .0118 Mdot
.03925 .00788 Mdot
.04317 .0118 Mdot
.06278 .02749 Mdot
.07454 .03925 Mdot
.16865 .10591 Mdot
.22747 .15689 Mdot
.18434 .1216 Mdot
.16081 .10983 Mdot
.13728 .09023 Mdot
.1216 .08239 Mdot
.10199 .07454 Mdot
.08239 .0667 Mdot
.08631 .07062 Mdot
.08631 .0667 Mdot
.13728 .10199 Mdot
.16865 .12944 Mdot
.20787 .15689 Mdot
.22355 .16473 Mdot
.25492 .18826 Mdot
.26276 .19218 Mdot
.25884 .18434 Mdot
.25492 .1765 Mdot
.251 .16865 Mdot
.25884 .17257 Mdot
.26276 .1765 Mdot
.27453 .18434 Mdot
.27061 .18434 Mdot
.28629 .1961 Mdot
.27453 .18434 Mdot
.26276 .18434 Mdot
.27453 .1961 Mdot
.28237 .20394 Mdot
.28629 .20394 Mdot
.29413 .21179 Mdot
.28237 .20002 Mdot
.29021 .20394 Mdot
.29806 .20787 Mdot
.29021 .20787 Mdot
.29021 .20002 Mdot
.27845 .18826 Mdot
.27453 .18826 Mdot
.28237 .19218 Mdot
.26276 .18826 Mdot
.27061 .20002 Mdot
.26668 .20394 Mdot
.27061 .20002 Mdot
.27061 .19218 Mdot
.28629 .1961 Mdot
.29413 .20002 Mdot
.29021 .19218 Mdot
.28237 .17257 Mdot
.29413 .17257 Mdot
.29413 .17257 Mdot
.28237 .17257 Mdot
.27845 .18042 Mdot
.28237 .19218 Mdot
.29021 .21179 Mdot
.28237 .22355 Mdot
.29806 .23924 Mdot
.28629 .22747 Mdot
.29413 .22355 Mdot
.28237 .20787 Mdot
.28629 .21963 Mdot
.26276 .20002 Mdot
.251 .18826 Mdot
.251 .18042 Mdot
.251 .1765 Mdot
.26276 .18434 Mdot
.27845 .1961 Mdot
.27845 .19218 Mdot
.26276 .18434 Mdot
.24316 .1765 Mdot
.24316 .18434 Mdot
.24316 .1765 Mdot
.24316 .17257 Mdot
.23139 .16081 Mdot
.23139 .14905 Mdot
.22747 .13728 Mdot
.21963 .12552 Mdot
.21571 .11768 Mdot
.21571 .11768 Mdot
.20394 .10591 Mdot
.20394 .10983 Mdot
.20787 .11376 Mdot
.20787 .12552 Mdot
.19218 .1216 Mdot
.20002 .1216 Mdot
.20394 .1216 Mdot
.21571 .1412 Mdot
.24316 .15689 Mdot
.23924 .15297 Mdot
.24708 .16473 Mdot
.25884 .16865 Mdot
.251 .16081 Mdot
.24708 .15297 Mdot
.23531 .1412 Mdot
.21963 .12944 Mdot
.21571 .12944 Mdot
.21571 .12944 Mdot
.22747 .13728 Mdot
.23139 .14513 Mdot
.22355 .14513 Mdot
.21963 .14513 Mdot
.20002 .12944 Mdot
.20002 .12944 Mdot
.20002 .12944 Mdot
.1961 .12552 Mdot
.20394 .13336 Mdot
.20394 .13728 Mdot
.20002 .13728 Mdot
.20787 .14513 Mdot
.19218 .1412 Mdot
.1961 .14513 Mdot
.1961 .1412 Mdot
.19218 .13728 Mdot
.20002 .12944 Mdot
.20394 .12944 Mdot
.20002 .1216 Mdot
.1961 .10591 Mdot
.18434 .09807 Mdot
.18826 .10199 Mdot
.18042 .09807 Mdot
.17257 .10983 Mdot
.16473 .10983 Mdot
.17257 .12552 Mdot
.16081 .11768 Mdot
.16081 .11376 Mdot
.16865 .11376 Mdot
.17257 .1216 Mdot
.15689 .10591 Mdot
.14905 .09415 Mdot
.14513 .09023 Mdot
.14905 .09023 Mdot
.14905 .09023 Mdot
.15297 .09807 Mdot
.13728 .09415 Mdot
.09807 .10591 Mdot
.07454 .08239 Mdot
.05494 .05886 Mdot
.03925 .03141 Mdot
.03141 .01572 Mdot
.02749 .00788 Mdot
.01965 .00396 Mdot
.04317 .01572 Mdot
.07846 .03533 Mdot
.08631 .03925 Mdot
.07846 .03141 Mdot
.07846 .03925 Mdot
.07846 .04317 Mdot
.0667 .03141 Mdot
.05494 .02357 Mdot
.05494 .01572 Mdot
.03533 .0118 Mdot
.03533 .0118 Mdot
.02357 .00788 Mdot
.02357 .0118 Mdot
.03533 .02357 Mdot
.04317 .01965 Mdot
.03925 .0118 Mdot
.01965 .00788 Mdot
.02357 .00788 Mdot
.03141 .0118 Mdot
.03141 .01572 Mdot
.04317 .01965 Mdot
.05886 .02749 Mdot
.09023 .04709 Mdot
.09415 .05102 Mdot
.09415 .05886 Mdot
.10199 .05886 Mdot
.10591 .05494 Mdot
.11768 .0667 Mdot
.14905 .09807 Mdot
.14905 .10199 Mdot
.13728 .09023 Mdot
.1412 .10199 Mdot
.16081 .1216 Mdot
.18826 .14905 Mdot
.21571 .16473 Mdot
.23924 .1765 Mdot
.25492 .18434 Mdot
.25884 .1765 Mdot
.251 .16865 Mdot
.26276 .1765 Mdot
.25884 .17257 Mdot
.24708 .17257 Mdot
.251 .18042 Mdot
.27453 .19218 Mdot
.29021 .1961 Mdot
.29413 .20002 Mdot
.28629 .1961 Mdot
.30198 .20394 Mdot
.29021 .1961 Mdot
.28629 .19218 Mdot
.29413 .20394 Mdot
.29806 .20787 Mdot
.3059 .21179 Mdot
.29806 .20787 Mdot
.28629 .20394 Mdot
.28629 .20394 Mdot
.28629 .19218 Mdot
.29021 .1961 Mdot
.29021 .1961 Mdot
.27061 .18434 Mdot
.27453 .18826 Mdot
.27453 .1961 Mdot
.27845 .1961 Mdot
.28629 .1961 Mdot
.29021 .1961 Mdot
.29413 .20002 Mdot
.30198 .21179 Mdot
.29806 .20002 Mdot
.29413 .18826 Mdot
.29806 .18826 Mdot
.30198 .20002 Mdot
.29806 .20394 Mdot
.29413 .20394 Mdot
.29413 .20787 Mdot
.29413 .21179 Mdot
.29413 .21179 Mdot
.29413 .21179 Mdot
.29413 .20787 Mdot
.29021 .20002 Mdot
.27453 .20394 Mdot
.28629 .21963 Mdot
.26668 .20394 Mdot
.26668 .1961 Mdot
.25884 .18042 Mdot
.251 .16865 Mdot
.26668 .17257 Mdot
.26276 .16865 Mdot
.27061 .18042 Mdot
.27453 .19218 Mdot
.27845 .20787 Mdot
.26276 .19218 Mdot
.24316 .1765 Mdot
.23139 .16865 Mdot
.22355 .16081 Mdot
.24316 .16865 Mdot
.23924 .15689 Mdot
.22747 .13336 Mdot
.21963 .12944 Mdot
.21571 .12552 Mdot
.22355 .12944 Mdot
.21571 .12944 Mdot
.20787 .13728 Mdot
.20394 .13728 Mdot
.21179 .13728 Mdot
.1961 .12944 Mdot
.21179 .14513 Mdot
.20787 .1412 Mdot
.21571 .1412 Mdot
.21963 .14513 Mdot
.22747 .14513 Mdot
.23139 .1412 Mdot
.23139 .13728 Mdot
.24708 .14905 Mdot
.23924 .1412 Mdot
.23531 .1412 Mdot
.22355 .13728 Mdot
.21571 .13728 Mdot
.21571 .1412 Mdot
.23139 .15297 Mdot
.21571 .1412 Mdot
.20002 .12944 Mdot
.18434 .11768 Mdot
.20394 .13336 Mdot
.1961 .12552 Mdot
.1961 .13336 Mdot
.19218 .12944 Mdot
.18826 .12552 Mdot
.19218 .13336 Mdot
.20002 .13728 Mdot
.1961 .13728 Mdot
.19218 .14905 Mdot
.18042 .13728 Mdot
.1961 .1412 Mdot
.1961 .13336 Mdot
.1961 .12552 Mdot
.19218 .11768 Mdot
.18826 .10591 Mdot
.18434 .10591 Mdot
.18826 .11376 Mdot
.18042 .11768 Mdot
.16865 .11768 Mdot
.16473 .11376 Mdot
.16081 .11376 Mdot
.15689 .11376 Mdot
.14905 .10591 Mdot
.15689 .10983 Mdot
.15297 .10199 Mdot
.1412 .09023 Mdot
.14905 .09023 Mdot
.14513 .09023 Mdot
.14513 .08631 Mdot
.1412 .09023 Mdot
.13336 .07846 Mdot
.11376 .1412 Mdot
.11376 .13728 Mdot
.10591 .12944 Mdot
.07846 .10591 Mdot
.05886 .07454 Mdot
.05886 .06278 Mdot
.04317 .04709 Mdot
.07062 .05494 Mdot
.08239 .05886 Mdot
.0667 .03141 Mdot
.05494 .01572 Mdot
.06278 .01965 Mdot
.07846 .03533 Mdot
.07846 .04317 Mdot
.07062 .03533 Mdot
.06278 .02749 Mdot
.05102 .01965 Mdot
.03925 .0118 Mdot
.04317 .02357 Mdot
.03533 .01965 Mdot
.03533 .02749 Mdot
.03141 .02749 Mdot
.01965 .01572 Mdot
.01572 .00788 Mdot
.00788 .00788 Mdot
.01572 .0118 Mdot
.03533 .01965 Mdot
.05886 .03141 Mdot
.0667 .03533 Mdot
.05886 .02749 Mdot
.05494 .03141 Mdot
.06278 .03533 Mdot
.06278 .02749 Mdot
.05102 .0118 Mdot
.07062 .02749 Mdot
.11376 .06278 Mdot
.1765 .10591 Mdot
.1961 .11768 Mdot
.21179 .13336 Mdot
.21179 .1412 Mdot
.22355 .16081 Mdot
.23139 .17257 Mdot
.23531 .16865 Mdot
.23139 .15689 Mdot
.24316 .16473 Mdot
.24316 .16473 Mdot
.23531 .15297 Mdot
.23924 .15297 Mdot
.24316 .16473 Mdot
.25492 .16865 Mdot
.26276 .1765 Mdot
.27453 .18042 Mdot
.27453 .1765 Mdot
.28629 .18826 Mdot
.29806 .1961 Mdot
.29413 .20002 Mdot
.30198 .20394 Mdot
.30198 .21571 Mdot
.30198 .22355 Mdot
.30198 .22747 Mdot
.29806 .21571 Mdot
.30198 .21571 Mdot
.3059 .21571 Mdot
.30982 .21571 Mdot
.30982 .21179 Mdot
.3059 .20787 Mdot
.30198 .21179 Mdot
.29806 .21571 Mdot
.28629 .20394 Mdot
.28237 .1961 Mdot
.28237 .19218 Mdot
.30198 .1961 Mdot
.30198 .20394 Mdot
.31374 .21179 Mdot
.3059 .20394 Mdot
.29413 .20394 Mdot
.29806 .20394 Mdot
.29413 .1961 Mdot
.29413 .19218 Mdot
.3059 .20002 Mdot
.30198 .19218 Mdot
.29806 .18434 Mdot
.29021 .18826 Mdot
.29021 .1961 Mdot
.27845 .18826 Mdot
.29021 .1961 Mdot
.28629 .1961 Mdot
.27453 .20002 Mdot
.28237 .20394 Mdot
.28237 .20002 Mdot
.27453 .18434 Mdot
.27453 .17257 Mdot
.27061 .16473 Mdot
.26276 .15689 Mdot
.26668 .15689 Mdot
.28629 .18434 Mdot
.29021 .1961 Mdot
.28237 .20002 Mdot
.27061 .20002 Mdot
.26668 .1961 Mdot
.25884 .18434 Mdot
.25492 .17257 Mdot
.251 .15297 Mdot
.23531 .14513 Mdot
.23531 .1412 Mdot
.22355 .13336 Mdot
.21179 .12944 Mdot
.21963 .1412 Mdot
.21179 .12944 Mdot
.20787 .12552 Mdot
.20787 .1216 Mdot
.20002 .12944 Mdot
.1961 .13336 Mdot
.20002 .14905 Mdot
.21571 .15297 Mdot
.21963 .14513 Mdot
.21963 .14513 Mdot
.22747 .14905 Mdot
.22747 .13336 Mdot
.24316 .13728 Mdot
.25492 .1412 Mdot
.251 .13728 Mdot
.251 .14513 Mdot
.23531 .13728 Mdot
.21963 .13336 Mdot
.21571 .1412 Mdot
.21963 .14905 Mdot
.21571 .14513 Mdot
.20394 .13336 Mdot
.1961 .12552 Mdot
.19218 .1216 Mdot
.20002 .12552 Mdot
.1961 .12944 Mdot
.19218 .12552 Mdot
.18042 .11768 Mdot
.19218 .12944 Mdot
.20002 .13728 Mdot
.19218 .14513 Mdot
.18826 .1412 Mdot
.21179 .15297 Mdot
.1961 .13728 Mdot
.18434 .12552 Mdot
.1961 .1216 Mdot
.18434 .11376 Mdot
.18042 .11768 Mdot
.18434 .1216 Mdot
.16865 .10983 Mdot
.16865 .10983 Mdot
.16473 .10591 Mdot
.16081 .10983 Mdot
.15297 .10983 Mdot
.14513 .10199 Mdot
.1412 .09807 Mdot
.14905 .10983 Mdot
.14513 .10591 Mdot
.1412 .10199 Mdot
.14513 .09807 Mdot
.12552 .07846 Mdot
.13728 .08239 Mdot
.12552 .07454 Mdot
.17257 .19218 Mdot
.16473 .18434 Mdot
.15297 .16865 Mdot
.1412 .16081 Mdot
.12944 .14513 Mdot
.10199 .11768 Mdot
.07846 .09023 Mdot
.08631 .09023 Mdot
.07454 .07062 Mdot
.04317 .04317 Mdot
.05102 .03533 Mdot
.0667 .03533 Mdot
.07846 .03925 Mdot
.07846 .03533 Mdot
.07454 .03925 Mdot
.06278 .02749 Mdot
.05494 .01965 Mdot
.05102 .01965 Mdot
.04709 .02357 Mdot
.05102 .03141 Mdot
.05886 .05102 Mdot
.05886 .06278 Mdot
.04317 .04709 Mdot
.01965 .02357 Mdot
.01572 .01572 Mdot
.02749 .01965 Mdot
.0667 .05494 Mdot
.08631 .06278 Mdot
.07846 .05102 Mdot
.07062 .04317 Mdot
.0667 .03533 Mdot
.05886 .03141 Mdot
.05886 .03925 Mdot
.04317 .02357 Mdot
.04317 .01572 Mdot
.05102 .01965 Mdot
.07846 .03533 Mdot
.12944 .07454 Mdot
.21179 .13728 Mdot
.24708 .16473 Mdot
.27061 .18042 Mdot
.27061 .18826 Mdot
.24708 .18042 Mdot
.24316 .16865 Mdot
.23924 .16473 Mdot
.23139 .16473 Mdot
.22747 .16081 Mdot
.21571 .14905 Mdot
.21571 .16473 Mdot
.21179 .15689 Mdot
.22747 .16473 Mdot
.24316 .16865 Mdot
.25884 .1765 Mdot
.27453 .18434 Mdot
.28237 .19218 Mdot
.28629 .19218 Mdot
.29806 .21179 Mdot
.29806 .22355 Mdot
.29806 .22355 Mdot
.30198 .23531 Mdot
.30982 .23531 Mdot
.32158 .23531 Mdot
.31766 .22747 Mdot
.32943 .23139 Mdot
.31374 .21571 Mdot
.30982 .21571 Mdot
.30982 .21571 Mdot
.30982 .21963 Mdot
.29806 .21179 Mdot
.30198 .20787 Mdot
.29021 .19218 Mdot
.30198 .19218 Mdot
.29806 .20002 Mdot
.30982 .21179 Mdot
.29806 .20787 Mdot
.29021 .20787 Mdot
.29806 .20002 Mdot
.29021 .18042 Mdot
.30198 .18042 Mdot
.30198 .18826 Mdot
.3059 .18826 Mdot
.29806 .18434 Mdot
.29021 .18434 Mdot
.29413 .19218 Mdot
.28237 .19218 Mdot
.29021 .20394 Mdot
.27845 .20787 Mdot
.27845 .20787 Mdot
.27845 .20787 Mdot
.27845 .20394 Mdot
.27845 .18826 Mdot
.27845 .18434 Mdot
.27845 .16865 Mdot
.26276 .14905 Mdot
.27845 .16473 Mdot
.28237 .16865 Mdot
.27453 .1765 Mdot
.28237 .19218 Mdot
.27845 .20002 Mdot
.26668 .20002 Mdot
.27845 .20787 Mdot
.28629 .20002 Mdot
.27061 .18434 Mdot
.25884 .16473 Mdot
.24708 .15297 Mdot
.23531 .14905 Mdot
.22355 .14905 Mdot
.21179 .13728 Mdot
.20002 .12944 Mdot
.21179 .13728 Mdot
.20787 .13336 Mdot
.1961 .11768 Mdot
.20002 .12552 Mdot
.20002 .12944 Mdot
.21963 .14905 Mdot
.21963 .15297 Mdot
.22747 .14905 Mdot
.23531 .16081 Mdot
.22747 .15297 Mdot
.23139 .14513 Mdot
.23924 .13728 Mdot
.251 .1412 Mdot
.251 .14513 Mdot
.23924 .1412 Mdot
.21963 .1412 Mdot
.20394 .13336 Mdot
.20394 .13728 Mdot
.21571 .15297 Mdot
.20787 .1412 Mdot
.20394 .13336 Mdot
.20787 .12552 Mdot
.20002 .1216 Mdot
.1961 .1216 Mdot
.20002 .13336 Mdot
.18042 .12552 Mdot
.18434 .13336 Mdot
.18042 .13336 Mdot
.19218 .14513 Mdot
.1961 .13336 Mdot
.20002 .12944 Mdot
.1961 .13336 Mdot
.18434 .1216 Mdot
.18826 .11768 Mdot
.1961 .11376 Mdot
.18434 .11376 Mdot
.18042 .11376 Mdot
.1765 .11768 Mdot
.17257 .1216 Mdot
.15297 .10199 Mdot
.14513 .09807 Mdot
.15297 .10983 Mdot
.14905 .10983 Mdot
.15689 .11768 Mdot
.14513 .10983 Mdot
.14905 .10591 Mdot
.13728 .09023 Mdot
.13336 .08239 Mdot
.13728 .07846 Mdot
.13728 .07454 Mdot
.1216 .06278 Mdot
.15689 .18434 Mdot
.1765 .18826 Mdot
.16865 .16865 Mdot
.16473 .16081 Mdot
.16473 .16081 Mdot
.16081 .15297 Mdot
.14905 .14513 Mdot
.14513 .14513 Mdot
.09415 .09807 Mdot
.07062 .07454 Mdot
.06278 .06278 Mdot
.07062 .05494 Mdot
.08631 .05494 Mdot
.08631 .04709 Mdot
.08239 .03925 Mdot
.07062 .02357 Mdot
.05494 .01572 Mdot
.04709 .01572 Mdot
.0667 .03141 Mdot
.0667 .03141 Mdot
.07454 .05102 Mdot
.0667 .05494 Mdot
.0667 .06278 Mdot
.05886 .05494 Mdot
.02749 .03141 Mdot
.03141 .03141 Mdot
.07846 .06278 Mdot
.09807 .07846 Mdot
.08631 .0667 Mdot
.05494 .03925 Mdot
.03925 .01965 Mdot
.03925 .01572 Mdot
.03925 .01572 Mdot
.04317 .01572 Mdot
.04709 .01572 Mdot
.04317 .0118 Mdot
.03925 .0118 Mdot
.07846 .03533 Mdot
.11768 .06278 Mdot
.15297 .09023 Mdot
.17257 .10983 Mdot
.21571 .14905 Mdot
.25492 .19218 Mdot
.26668 .20002 Mdot
.26276 .1961 Mdot
.25492 .1961 Mdot
.24316 .19218 Mdot
.21963 .1765 Mdot
.20002 .16473 Mdot
.18434 .14905 Mdot
.16865 .13336 Mdot
.16865 .1216 Mdot
.21571 .15297 Mdot
.24708 .16865 Mdot
.27061 .18042 Mdot
.28629 .18826 Mdot
.30198 .20394 Mdot
.30198 .21571 Mdot
.29806 .21963 Mdot
.29806 .22747 Mdot
.29413 .22355 Mdot
.29021 .21571 Mdot
.30198 .21963 Mdot
.31374 .22355 Mdot
.31766 .22355 Mdot
.31374 .22355 Mdot
.33335 .23531 Mdot
.32943 .22747 Mdot
.31374 .21571 Mdot
.30198 .20394 Mdot
.30198 .20394 Mdot
.29413 .1961 Mdot
.29413 .1961 Mdot
.31374 .21179 Mdot
.30198 .21179 Mdot
.30982 .22355 Mdot
.30982 .21963 Mdot
.3059 .20394 Mdot
.30198 .18826 Mdot
.3059 .18826 Mdot
.30982 .18826 Mdot
.30982 .19218 Mdot
.29021 .18434 Mdot
.29021 .1961 Mdot
.27845 .20002 Mdot
.28237 .21963 Mdot
.28237 .22355 Mdot
.27845 .21963 Mdot
.28237 .21571 Mdot
.28237 .20787 Mdot
.28629 .1961 Mdot
.3059 .20002 Mdot
.30982 .1961 Mdot
.29806 .18434 Mdot
.29806 .18042 Mdot
.29413 .1765 Mdot
.29021 .1765 Mdot
.26668 .17257 Mdot
.26276 .18434 Mdot
.26276 .20394 Mdot
.28237 .21179 Mdot
.27453 .18826 Mdot
.27453 .18042 Mdot
.27845 .1765 Mdot
.27453 .17257 Mdot
.24708 .15689 Mdot
.23139 .14513 Mdot
.20787 .12552 Mdot
.20787 .13728 Mdot
.1961 .12944 Mdot
.20002 .12552 Mdot
.20002 .12552 Mdot
.20002 .12944 Mdot
.20002 .13336 Mdot
.21571 .15297 Mdot
.22747 .16081 Mdot
.21571 .14905 Mdot
.22747 .15689 Mdot
.23139 .16081 Mdot
.23139 .15297 Mdot
.22355 .1412 Mdot
.22747 .13728 Mdot
.24708 .14513 Mdot
.24708 .14513 Mdot
.23924 .14513 Mdot
.22355 .14513 Mdot
.21571 .14905 Mdot
.21571 .14905 Mdot
.21571 .14513 Mdot
.22355 .15297 Mdot
.21963 .14905 Mdot
.21179 .1412 Mdot
.19218 .12552 Mdot
.18434 .12944 Mdot
.18042 .13728 Mdot
.17257 .12944 Mdot
.18434 .13336 Mdot
.1961 .13728 Mdot
.20002 .13728 Mdot
.20002 .12552 Mdot
.18826 .1216 Mdot
.18826 .11376 Mdot
.20002 .10983 Mdot
.20394 .10591 Mdot
.20394 .10591 Mdot
.16865 .09415 Mdot
.16473 .10591 Mdot
.16081 .11768 Mdot
.14905 .10591 Mdot
.15689 .10983 Mdot
.14905 .10983 Mdot
.1412 .10591 Mdot
.16081 .11768 Mdot
.15297 .10983 Mdot
.14905 .10983 Mdot
.14513 .09807 Mdot
.1412 .07846 Mdot
.13728 .07062 Mdot
.12944 .0667 Mdot
.1216 .05102 Mdot
.18434 .1961 Mdot
.18826 .20787 Mdot
.17257 .18042 Mdot
.16473 .16865 Mdot
.16473 .16081 Mdot
.18042 .16865 Mdot
.18042 .1765 Mdot
.16473 .1765 Mdot
.15689 .16473 Mdot
.13336 .14513 Mdot
.10983 .11376 Mdot
.09807 .09023 Mdot
.10199 .07454 Mdot
.09023 .04709 Mdot
.07062 .01965 Mdot
.06278 .00788 Mdot
.05886 .0118 Mdot
.06278 .01965 Mdot
.07846 .02749 Mdot
.08239 .03141 Mdot
.07062 .03533 Mdot
.06278 .04317 Mdot
.05494 .04709 Mdot
.06278 .05494 Mdot
.05494 .04709 Mdot
.0667 .04709 Mdot
.09415 .07062 Mdot
.10199 .0667 Mdot
.08631 .05102 Mdot
.07846 .04317 Mdot
.05886 .01572 Mdot
.03533 .00396 Mdot
.03925 .00396 Mdot
.03925 .00788 Mdot
.03925 .01572 Mdot
.04709 .01572 Mdot
.04317 .01965 Mdot
.04709 .03533 Mdot
.07846 .05886 Mdot
.09023 .07454 Mdot
.10983 .09023 Mdot
.10591 .09023 Mdot
.21179 .16473 Mdot
.28629 .21963 Mdot
.3059 .22747 Mdot
.30198 .22355 Mdot
.29021 .22355 Mdot
.24316 .18826 Mdot
.20787 .15689 Mdot
.16865 .12552 Mdot
.12944 .09807 Mdot
.10199 .08631 Mdot
.1216 .09415 Mdot
.1765 .12944 Mdot
.21179 .15689 Mdot
.25492 .18042 Mdot
.29021 .20002 Mdot
.3059 .21179 Mdot
.29806 .20394 Mdot
.28629 .20394 Mdot
.28629 .21179 Mdot
.28629 .20787 Mdot
.29021 .21179 Mdot
.29021 .21963 Mdot
.30198 .23139 Mdot
.31374 .23924 Mdot
.32158 .23924 Mdot
.32158 .22355 Mdot
.31766 .21571 Mdot
.30982 .20787 Mdot
.31766 .21571 Mdot
.31374 .20394 Mdot
.31374 .20002 Mdot
.3059 .20394 Mdot
.31374 .21179 Mdot
.30982 .21963 Mdot
.30198 .21179 Mdot
.3059 .21571 Mdot
.3059 .21179 Mdot
.3059 .20394 Mdot
.29806 .1961 Mdot
.29806 .1961 Mdot
.29413 .20394 Mdot
.30198 .20787 Mdot
.29806 .21571 Mdot
.29413 .22355 Mdot
.29021 .22355 Mdot
.29413 .22747 Mdot
.30198 .23924 Mdot
.3059 .23139 Mdot
.30982 .22747 Mdot
.3059 .21571 Mdot
.3059 .21571 Mdot
.30982 .21179 Mdot
.30982 .20002 Mdot
.30198 .18826 Mdot
.29806 .19218 Mdot
.27453 .1765 Mdot
.25884 .1765 Mdot
.26276 .18826 Mdot
.25884 .19218 Mdot
.26668 .20394 Mdot
.26668 .19218 Mdot
.28237 .1961 Mdot
.26668 .18434 Mdot
.25492 .1765 Mdot
.26668 .18434 Mdot
.251 .17257 Mdot
.22747 .16081 Mdot
.20394 .1412 Mdot
.20394 .13336 Mdot
.21963 .1412 Mdot
.21571 .13336 Mdot
.21179 .13728 Mdot
.21179 .1412 Mdot
.23139 .15689 Mdot
.21963 .14905 Mdot
.22747 .15297 Mdot
.23924 .15297 Mdot
.24316 .15297 Mdot
.23924 .14513 Mdot
.21963 .12944 Mdot
.22747 .13336 Mdot
.23531 .1412 Mdot
.23531 .14905 Mdot
.23531 .15689 Mdot
.23139 .16081 Mdot
.20787 .1412 Mdot
.20002 .13728 Mdot
.20394 .13728 Mdot
.21963 .14905 Mdot
.21963 .14905 Mdot
.22355 .14905 Mdot
.20394 .13728 Mdot
.20394 .13728 Mdot
.1961 .13336 Mdot
.18826 .12944 Mdot
.20002 .14513 Mdot
.20394 .1412 Mdot
.20787 .13336 Mdot
.19218 .1216 Mdot
.18434 .11376 Mdot
.20394 .12944 Mdot
.1961 .11768 Mdot
.18434 .10983 Mdot
.18434 .10983 Mdot
.18434 .1216 Mdot
.17257 .1216 Mdot
.16473 .12552 Mdot
.15689 .1216 Mdot
.14905 .11376 Mdot
.14513 .10591 Mdot
.15297 .11376 Mdot
.1412 .10199 Mdot
.1412 .09023 Mdot
.13728 .08239 Mdot
.1412 .08239 Mdot
.1412 .07846 Mdot
.1412 .07454 Mdot
.12944 .0667 Mdot
.18042 .17257 Mdot
.18434 .18826 Mdot
.17257 .18434 Mdot
.16865 .16865 Mdot
.16081 .15689 Mdot
.16865 .15689 Mdot
.17257 .16865 Mdot
.18042 .18826 Mdot
.17257 .19218 Mdot
.1765 .18826 Mdot
.17257 .1765 Mdot
.16081 .15297 Mdot
.1412 .1216 Mdot
.10199 .07062 Mdot
.07454 .04317 Mdot
.06278 .03141 Mdot
.07454 .03925 Mdot
.05886 .03533 Mdot
.05102 .03925 Mdot
.05886 .05102 Mdot
.06278 .04709 Mdot
.01965 .01965 Mdot
.02357 .02357 Mdot
.02749 .02749 Mdot
.03141 .02357 Mdot
.0667 .03925 Mdot
.09415 .05102 Mdot
.1216 .06278 Mdot
.11376 .05494 Mdot
.09023 .03925 Mdot
.0667 .01572 Mdot
.05102 .00396 Mdot
.05102 .0118 Mdot
.03925 .0118 Mdot
.05886 .02749 Mdot
.06278 .03925 Mdot
.05494 .03533 Mdot
.04317 .03533 Mdot
.03925 .04317 Mdot
.05494 .06278 Mdot
.07062 .07454 Mdot
.07846 .07846 Mdot
.09807 .08631 Mdot
.15689 .12552 Mdot
.22355 .17257 Mdot
.26668 .20394 Mdot
.30982 .23531 Mdot
.23139 .1765 Mdot
.18434 .13728 Mdot
.15297 .10199 Mdot
.1216 .07846 Mdot
.10591 .07454 Mdot
.09807 .07062 Mdot
.11376 .08239 Mdot
.16081 .1216 Mdot
.21179 .15689 Mdot
.24708 .17257 Mdot
.27453 .18826 Mdot
.28237 .18826 Mdot
.28629 .18826 Mdot
.29021 .1961 Mdot
.28629 .20002 Mdot
.28237 .20394 Mdot
.28629 .21571 Mdot
.28237 .21571 Mdot
.29413 .22355 Mdot
.30198 .22355 Mdot
.30198 .21571 Mdot
.30982 .21571 Mdot
.31374 .21179 Mdot
.30982 .20787 Mdot
.31374 .1961 Mdot
.3059 .18434 Mdot
.30982 .18826 Mdot
.31374 .19218 Mdot
.3059 .1961 Mdot
.3059 .20394 Mdot
.29021 .20002 Mdot
.29021 .20002 Mdot
.29413 .20002 Mdot
.29806 .20002 Mdot
.29413 .1961 Mdot
.29806 .20394 Mdot
.30198 .21571 Mdot
.29806 .21963 Mdot
.29413 .21571 Mdot
.28629 .21571 Mdot
.29413 .23139 Mdot
.29021 .23139 Mdot
.29413 .23924 Mdot
.29806 .22747 Mdot
.28629 .20394 Mdot
.29806 .20787 Mdot
.29806 .1961 Mdot
.3059 .1961 Mdot
.29413 .18434 Mdot
.28629 .1765 Mdot
.28629 .1765 Mdot
.25884 .17257 Mdot
.24708 .16865 Mdot
.24316 .18042 Mdot
.24316 .18826 Mdot
.25884 .1961 Mdot
.26276 .1961 Mdot
.25884 .20002 Mdot
.25884 .19218 Mdot
.25492 .18434 Mdot
.25492 .16865 Mdot
.24708 .16081 Mdot
.22355 .13728 Mdot
.22355 .13336 Mdot
.22747 .13336 Mdot
.21179 .12552 Mdot
.20787 .12944 Mdot
.20787 .13728 Mdot
.21963 .14905 Mdot
.21963 .14513 Mdot
.23139 .14905 Mdot
.23531 .13336 Mdot
.23139 .12944 Mdot
.23531 .12552 Mdot
.23531 .12552 Mdot
.22355 .1216 Mdot
.22747 .12944 Mdot
.23531 .13336 Mdot
.23924 .1412 Mdot
.21571 .1412 Mdot
.21571 .14513 Mdot
.21179 .13728 Mdot
.21179 .12944 Mdot
.21179 .1216 Mdot
.22355 .13728 Mdot
.23531 .14905 Mdot
.22747 .13728 Mdot
.21571 .1412 Mdot
.20787 .13336 Mdot
.1961 .12552 Mdot
.18826 .11768 Mdot
.18042 .10983 Mdot
.19218 .11376 Mdot
.18826 .10591 Mdot
.19218 .10983 Mdot
.1765 .11376 Mdot
.18434 .12944 Mdot
.18434 .12944 Mdot
.18434 .12552 Mdot
.18042 .12944 Mdot
.16473 .12552 Mdot
.15297 .1216 Mdot
.14905 .11768 Mdot
.14513 .10983 Mdot
.13728 .10199 Mdot
.13336 .09023 Mdot
.13336 .08631 Mdot
.13728 .08631 Mdot
.12552 .07454 Mdot
.13728 .07846 Mdot
.14513 .08631 Mdot
.13728 .08631 Mdot
.12944 .07846 Mdot
.17257 .15297 Mdot
.19218 .16081 Mdot
.1961 .16865 Mdot
.1961 .16865 Mdot
.18826 .17257 Mdot
.18042 .16865 Mdot
.19218 .18434 Mdot
.18042 .18826 Mdot
.16865 .1961 Mdot
.18826 .21571 Mdot
.1961 .21571 Mdot
.20394 .21179 Mdot
.17257 .16865 Mdot
.11376 .10983 Mdot
.09415 .08631 Mdot
.07062 .07062 Mdot
.0667 .0667 Mdot
.05886 .07062 Mdot
.04709 .07062 Mdot
.04317 .0667 Mdot
.03533 .05886 Mdot
.02357 .04317 Mdot
.01965 .03141 Mdot
.02749 .02749 Mdot
.01965 .0118 Mdot
.04709 .01572 Mdot
.11376 .05102 Mdot
.13336 .06278 Mdot
.10983 .04709 Mdot
.07846 .03141 Mdot
.05886 .01965 Mdot
.04709 .0118 Mdot
.05102 .02357 Mdot
.05102 .02749 Mdot
.07062 .04317 Mdot
.08239 .04317 Mdot
.06278 .03925 Mdot
.05886 .04709 Mdot
.04709 .03925 Mdot
.05102 .05102 Mdot
.08239 .07454 Mdot
.09415 .08239 Mdot
.08239 .07454 Mdot
.09415 .08239 Mdot
.10591 .09023 Mdot
.13728 .10983 Mdot
.18042 .1412 Mdot
.17257 .13728 Mdot
.13728 .10591 Mdot
.10983 .07454 Mdot
.06278 .03533 Mdot
.11376 .07846 Mdot
.14513 .10199 Mdot
.16473 .11376 Mdot
.1765 .1216 Mdot
.18434 .12552 Mdot
.20394 .12944 Mdot
.22355 .1412 Mdot
.24316 .15689 Mdot
.26276 .16865 Mdot
.28237 .18826 Mdot
.29806 .20394 Mdot
.3059 .21571 Mdot
.29413 .21963 Mdot
.29806 .21963 Mdot
.30982 .22747 Mdot
.31374 .22355 Mdot
.31766 .21963 Mdot
.32943 .21963 Mdot
.33727 .22355 Mdot
.32943 .21963 Mdot
.3255 .21179 Mdot
.3255 .21179 Mdot
.3255 .20394 Mdot
.31766 .20394 Mdot
.3059 .20002 Mdot
.3059 .19218 Mdot
.31374 .21179 Mdot
.31374 .21571 Mdot
.31374 .21179 Mdot
.3059 .20787 Mdot
.3059 .20394 Mdot
.29413 .20002 Mdot
.30198 .20787 Mdot
.30982 .22355 Mdot
.30982 .22355 Mdot
.3059 .22747 Mdot
.3059 .22747 Mdot
.3059 .23531 Mdot
.31374 .24316 Mdot
.32158 .24316 Mdot
.31374 .23531 Mdot
.3059 .21963 Mdot
.30982 .21571 Mdot
.30198 .1961 Mdot
.29806 .19218 Mdot
.3059 .20002 Mdot
.3059 .20787 Mdot
.28629 .1961 Mdot
.27845 .20002 Mdot
.26668 .1961 Mdot
.26276 .1961 Mdot
.27453 .20394 Mdot
.28629 .20787 Mdot
.28629 .20787 Mdot
.27845 .1961 Mdot
.27453 .18826 Mdot
.26668 .18042 Mdot
.29021 .18434 Mdot
.25884 .15689 Mdot
.25884 .15297 Mdot
.24708 .1412 Mdot
.22747 .12552 Mdot
.22747 .13336 Mdot
.21963 .13728 Mdot
.21963 .14513 Mdot
.23139 .15297 Mdot
.23139 .14905 Mdot
.24316 .14905 Mdot
.23924 .13728 Mdot
.23531 .13336 Mdot
.23924 .1412 Mdot
.23531 .1412 Mdot
.24708 .14905 Mdot
.251 .14905 Mdot
.251 .16081 Mdot
.23924 .16081 Mdot
.23139 .15689 Mdot
.21179 .1412 Mdot
.21571 .13728 Mdot
.21963 .12944 Mdot
.22747 .13336 Mdot
.24316 .14905 Mdot
.24708 .14905 Mdot
.24316 .15689 Mdot
.22747 .1412 Mdot
.21179 .12552 Mdot
.20002 .1216 Mdot
.20002 .11768 Mdot
.20002 .11768 Mdot
.1961 .11768 Mdot
.20002 .1216 Mdot
.18826 .11768 Mdot
.18826 .1216 Mdot
.19218 .12552 Mdot
.1961 .13336 Mdot
.20002 .13728 Mdot
.1765 .11768 Mdot
.16081 .10591 Mdot
.17257 .11768 Mdot
.16865 .12944 Mdot
.15689 .11376 Mdot
.15689 .10983 Mdot
.16081 .10983 Mdot
.15297 .10199 Mdot
.15297 .09415 Mdot
.15689 .09023 Mdot
.15297 .09023 Mdot
.14905 .09415 Mdot
.14905 .09415 Mdot
.12552 .1216 Mdot
.14513 .11376 Mdot
.16473 .1216 Mdot
.16865 .13728 Mdot
.1765 .14905 Mdot
.18434 .16081 Mdot
.1961 .18042 Mdot
.19218 .18826 Mdot
.1961 .20394 Mdot
.1961 .21571 Mdot
.21963 .23139 Mdot
.251 .24708 Mdot
.21963 .21179 Mdot
.15297 .15297 Mdot
.13336 .13728 Mdot
.11768 .13336 Mdot
.08239 .11376 Mdot
.0667 .10199 Mdot
.05886 .09807 Mdot
.05494 .09415 Mdot
.02357 .0667 Mdot
.01572 .05886 Mdot
.01572 .03925 Mdot
.01572 .01965 Mdot
.01965 .0118 Mdot
.03141 .00788 Mdot
.09023 .03533 Mdot
.12552 .0667 Mdot
.11376 .06278 Mdot
.08631 .05102 Mdot
.0667 .03925 Mdot
.05102 .02749 Mdot
.05102 .03533 Mdot
.07062 .05494 Mdot
.09023 .07846 Mdot
.10199 .08239 Mdot
.09415 .08239 Mdot
.07062 .0667 Mdot
.05102 .05494 Mdot
.07062 .07454 Mdot
.07454 .07846 Mdot
.09023 .09023 Mdot
.0667 .07454 Mdot
.07062 .07062 Mdot
.07846 .07454 Mdot
.07846 .07454 Mdot
.10199 .08239 Mdot
.1216 .09023 Mdot
.09807 .0667 Mdot
.08239 .04709 Mdot
.06278 .03141 Mdot
.04709 .01965 Mdot
.1216 .0667 Mdot
.16865 .10983 Mdot
.16865 .1216 Mdot
.13728 .10199 Mdot
.13728 .09415 Mdot
.12944 .08631 Mdot
.14905 .09415 Mdot
.18042 .11376 Mdot
.22355 .1412 Mdot
.25884 .16865 Mdot
.28237 .18826 Mdot
.29413 .20002 Mdot
.3059 .20394 Mdot
.3059 .20002 Mdot
.32158 .20394 Mdot
.33335 .21179 Mdot
.32158 .20787 Mdot
.32943 .22355 Mdot
.32158 .21963 Mdot
.31374 .21963 Mdot
.3255 .22355 Mdot
.3255 .22355 Mdot
.3255 .21963 Mdot
.32158 .21571 Mdot
.31374 .21179 Mdot
.30982 .21179 Mdot
.30982 .21179 Mdot
.31766 .21963 Mdot
.3059 .21179 Mdot
.30982 .21179 Mdot
.29413 .20394 Mdot
.29806 .21179 Mdot
.30198 .21571 Mdot
.30198 .22355 Mdot
.3059 .22355 Mdot
.3059 .22747 Mdot
.30982 .22747 Mdot
.30982 .22355 Mdot
.31766 .23139 Mdot
.34511 .25884 Mdot
.33727 .25884 Mdot
.32158 .23924 Mdot
.31374 .22747 Mdot
.30982 .22355 Mdot
.30198 .21963 Mdot
.29806 .21963 Mdot
.29806 .21571 Mdot
.29806 .20787 Mdot
.30198 .20787 Mdot
.28629 .1961 Mdot
.29021 .1961 Mdot
.29806 .20002 Mdot
.29413 .20002 Mdot
.28629 .20002 Mdot
.28237 .19218 Mdot
.27845 .18826 Mdot
.28629 .1961 Mdot
.27845 .18434 Mdot
.27453 .17257 Mdot
.26276 .15297 Mdot
.25492 .13336 Mdot
.24316 .13336 Mdot
.22747 .1216 Mdot
.22747 .12944 Mdot
.24316 .14513 Mdot
.24316 .14513 Mdot
.24708 .15297 Mdot
.24316 .16081 Mdot
.24708 .16081 Mdot
.23924 .15689 Mdot
.23139 .14905 Mdot
.23531 .15689 Mdot
.23139 .15297 Mdot
.24708 .16473 Mdot
.24708 .16473 Mdot
.251 .16865 Mdot
.24316 .16865 Mdot
.23924 .15297 Mdot
.23531 .13336 Mdot
.21179 .11376 Mdot
.20787 .11768 Mdot
.22355 .12552 Mdot
.22747 .12944 Mdot
.23531 .13336 Mdot
.22747 .12552 Mdot
.21179 .11376 Mdot
.20002 .10591 Mdot
.1961 .10199 Mdot
.1765 .09807 Mdot
.18042 .10199 Mdot
.1765 .10983 Mdot
.18434 .1216 Mdot
.1961 .12944 Mdot
.1961 .13336 Mdot
.18434 .12944 Mdot
.19218 .12944 Mdot
.17257 .11376 Mdot
.15689 .10591 Mdot
.16473 .11376 Mdot
.15689 .10591 Mdot
.16081 .10983 Mdot
.15297 .10983 Mdot
.16081 .11376 Mdot
.16081 .11376 Mdot
.16865 .10983 Mdot
.17257 .11376 Mdot
.15689 .10199 Mdot
.15689 .09807 Mdot
.12552 .13336 Mdot
.12552 .11376 Mdot
.11376 .09023 Mdot
.11768 .09023 Mdot
.13336 .11376 Mdot
.15689 .13336 Mdot
.1961 .16865 Mdot
.20002 .18434 Mdot
.21571 .20394 Mdot
.21571 .21179 Mdot
.20787 .21571 Mdot
.21571 .22355 Mdot
.22355 .22355 Mdot
.21179 .20787 Mdot
.18042 .18042 Mdot
.17257 .18434 Mdot
.14905 .18042 Mdot
.1412 .18042 Mdot
.13336 .18042 Mdot
.11768 .16081 Mdot
.09023 .12944 Mdot
.05886 .09807 Mdot
.03925 .07454 Mdot
.02749 .05102 Mdot
.02749 .03533 Mdot
.02357 .01965 Mdot
.08631 .05494 Mdot
.11376 .0667 Mdot
.10983 .06278 Mdot
.08631 .05494 Mdot
.07454 .05102 Mdot
.07454 .05886 Mdot
.07454 .0667 Mdot
.07846 .07454 Mdot
.10591 .09415 Mdot
.13336 .11768 Mdot
.14905 .13728 Mdot
.14513 .12944 Mdot
.10983 .10591 Mdot
.10591 .10983 Mdot
.11376 .10983 Mdot
.09023 .10199 Mdot
.0667 .08239 Mdot
.05886 .0667 Mdot
.06278 .06278 Mdot
.06278 .05494 Mdot
.0667 .04709 Mdot
.09023 .05886 Mdot
.07846 .04317 Mdot
.07454 .03141 Mdot
.06278 .01965 Mdot
.04709 .0118 Mdot
.17257 .09807 Mdot
.21571 .13336 Mdot
.21179 .13728 Mdot
.13336 .08631 Mdot
.1216 .07846 Mdot
.09023 .05494 Mdot
.09415 .05494 Mdot
.09807 .05494 Mdot
.11768 .07062 Mdot
.14513 .08631 Mdot
.18042 .10983 Mdot
.21571 .13336 Mdot
.24708 .14905 Mdot
.27453 .16865 Mdot
.3059 .18826 Mdot
.30982 .20002 Mdot
.3255 .20787 Mdot
.32158 .21963 Mdot
.32158 .22355 Mdot
.32943 .22747 Mdot
.33335 .22747 Mdot
.3255 .20787 Mdot
.32943 .20787 Mdot
.32943 .22355 Mdot
.33335 .22355 Mdot
.32158 .21963 Mdot
.32158 .22355 Mdot
.30982 .21571 Mdot
.31374 .21963 Mdot
.31374 .21963 Mdot
.30982 .22355 Mdot
.31374 .21963 Mdot
.30982 .22355 Mdot
.3059 .23139 Mdot
.30982 .23139 Mdot
.29806 .22355 Mdot
.3059 .23139 Mdot
.30982 .23139 Mdot
.31766 .23924 Mdot
.3255 .23924 Mdot
.32943 .23531 Mdot
.32158 .23139 Mdot
.31766 .23531 Mdot
.31766 .23531 Mdot
.30982 .22747 Mdot
.3059 .22747 Mdot
.31374 .22355 Mdot
.29806 .20394 Mdot
.30198 .20002 Mdot
.28237 .18042 Mdot
.27845 .18826 Mdot
.28629 .19218 Mdot
.28237 .20002 Mdot
.28629 .21179 Mdot
.28629 .21179 Mdot
.28237 .20394 Mdot
.28237 .20394 Mdot
.27061 .19218 Mdot
.25884 .1765 Mdot
.25884 .15689 Mdot
.251 .13336 Mdot
.23924 .1216 Mdot
.23531 .12552 Mdot
.22747 .12552 Mdot
.23139 .13336 Mdot
.251 .14513 Mdot
.26276 .15297 Mdot
.24316 .14513 Mdot
.24708 .15297 Mdot
.23531 .14513 Mdot
.24316 .16081 Mdot
.23531 .16473 Mdot
.23924 .17257 Mdot
.24316 .18042 Mdot
.251 .18042 Mdot
.23531 .16473 Mdot
.24708 .16473 Mdot
.251 .16473 Mdot
.24316 .15297 Mdot
.21963 .13728 Mdot
.20787 .11768 Mdot
.20787 .10983 Mdot
.21179 .10983 Mdot
.20787 .10983 Mdot
.22355 .1216 Mdot
.21179 .10983 Mdot
.1961 .09807 Mdot
.18434 .09023 Mdot
.19218 .10591 Mdot
.20002 .1216 Mdot
.18042 .11768 Mdot
.18826 .12944 Mdot
.18826 .13336 Mdot
.18434 .12552 Mdot
.18826 .12552 Mdot
.19218 .12552 Mdot
.19218 .12552 Mdot
.18042 .10983 Mdot
.16865 .09807 Mdot
.15689 .08631 Mdot
.15297 .08631 Mdot
.16081 .09807 Mdot
.16473 .10199 Mdot
.15689 .09807 Mdot
.14513 .09415 Mdot
.15689 .10983 Mdot
.14513 .09807 Mdot
.14513 .09023 Mdot
.1412 .1412 Mdot
.1216 .12552 Mdot
.11376 .10591 Mdot
.10591 .08631 Mdot
.10983 .08239 Mdot
.12552 .09415 Mdot
.13728 .09807 Mdot
.15297 .1216 Mdot
.1765 .15297 Mdot
.19218 .18434 Mdot
.20787 .20002 Mdot
.21963 .21571 Mdot
.24708 .23139 Mdot
.21571 .20394 Mdot
.20002 .19218 Mdot
.20394 .20002 Mdot
.20394 .21179 Mdot
.20787 .21571 Mdot
.20394 .22355 Mdot
.20002 .23139 Mdot
.18042 .21571 Mdot
.15689 .1961 Mdot
.12944 .16473 Mdot
.07454 .11376 Mdot
.05494 .08239 Mdot
.03533 .05494 Mdot
.06278 .05886 Mdot
.09023 .0667 Mdot
.10591 .07062 Mdot
.09415 .0667 Mdot
.07846 .05102 Mdot
.07454 .05494 Mdot
.07846 .05494 Mdot
.09807 .07062 Mdot
.12944 .10199 Mdot
.12552 .10983 Mdot
.15297 .1412 Mdot
.16473 .15297 Mdot
.17257 .15689 Mdot
.16865 .15297 Mdot
.1765 .15689 Mdot
.11768 .11376 Mdot
.08239 .09023 Mdot
.05886 .07062 Mdot
.05494 .06278 Mdot
.05886 .05886 Mdot
.0667 .06278 Mdot
.07846 .0667 Mdot
.08239 .06278 Mdot
.07062 .05102 Mdot
.0667 .04317 Mdot
.05886 .02749 Mdot
.1216 .0667 Mdot
.14513 .07846 Mdot
.15689 .08239 Mdot
.14905 .08239 Mdot
.13728 .07454 Mdot
.10983 .06278 Mdot
.08631 .04709 Mdot
.08239 .05102 Mdot
.09023 .05494 Mdot
.09023 .05102 Mdot
.09023 .05102 Mdot
.11768 .0667 Mdot
.16081 .08631 Mdot
.20394 .11376 Mdot
.251 .14513 Mdot
.29021 .1765 Mdot
.30198 .19218 Mdot
.31766 .20394 Mdot
.31766 .21179 Mdot
.32158 .21179 Mdot
.32943 .20394 Mdot
.33335 .21963 Mdot
.32943 .21963 Mdot
.33335 .22747 Mdot
.34119 .23531 Mdot
.32943 .23139 Mdot
.32943 .23531 Mdot
.32943 .23139 Mdot
.32158 .22355 Mdot
.3059 .21571 Mdot
.3059 .21179 Mdot
.32158 .22747 Mdot
.32158 .23139 Mdot
.32158 .23924 Mdot
.3059 .23139 Mdot
.3059 .22747 Mdot
.30982 .22355 Mdot
.31374 .23139 Mdot
.30982 .22747 Mdot
.32943 .23531 Mdot
.31766 .22355 Mdot
.32158 .22747 Mdot
.32943 .23924 Mdot
.33335 .23531 Mdot
.3255 .23139 Mdot
.31766 .21963 Mdot
.31766 .21963 Mdot
.30982 .20787 Mdot
.32158 .21179 Mdot
.3255 .21963 Mdot
.30982 .21179 Mdot
.29806 .20394 Mdot
.29806 .20787 Mdot
.29413 .21571 Mdot
.28629 .21179 Mdot
.27845 .20787 Mdot
.28629 .20787 Mdot
.26668 .19218 Mdot
.26276 .18042 Mdot
.27061 .16865 Mdot
.25884 .14905 Mdot
.23924 .12552 Mdot
.23924 .12552 Mdot
.24708 .12944 Mdot
.23924 .13336 Mdot
.24316 .13728 Mdot
.251 .1412 Mdot
.24708 .1412 Mdot
.24316 .14513 Mdot
.24316 .14905 Mdot
.23531 .15297 Mdot
.23139 .15297 Mdot
.24316 .16865 Mdot
.23924 .16473 Mdot
.24708 .16865 Mdot
.23924 .16081 Mdot
.23924 .16081 Mdot
.24316 .16081 Mdot
.23531 .15689 Mdot
.23139 .14905 Mdot
.23531 .1412 Mdot
.22747 .12944 Mdot
.22355 .12552 Mdot
.21179 .11768 Mdot
.21179 .11768 Mdot
.21963 .12552 Mdot
.20002 .1216 Mdot
.19218 .11376 Mdot
.18042 .11768 Mdot
.1961 .13336 Mdot
.19218 .13336 Mdot
.18826 .12944 Mdot
.19218 .12944 Mdot
.19218 .12944 Mdot
.18434 .1216 Mdot
.19218 .11768 Mdot
.19218 .10983 Mdot
.17257 .09023 Mdot
.18042 .09415 Mdot
.18042 .09415 Mdot
.17257 .09023 Mdot
.17257 .09415 Mdot
.17257 .09415 Mdot
.16081 .09023 Mdot
.15689 .09415 Mdot
.16865 .10199 Mdot
.16081 .10199 Mdot
.14513 .09023 Mdot
.13728 .12944 Mdot
.13336 .12944 Mdot
.11376 .11768 Mdot
.10199 .09807 Mdot
.10983 .09023 Mdot
.10983 .08631 Mdot
.10591 .08239 Mdot
.11376 .09415 Mdot
.10983 .09807 Mdot
.1216 .11376 Mdot
.14513 .13336 Mdot
.1765 .16473 Mdot
.21571 .1961 Mdot
.22747 .20002 Mdot
.22355 .19218 Mdot
.21963 .20002 Mdot
.20394 .1961 Mdot
.20002 .20394 Mdot
.20787 .22355 Mdot
.20787 .23531 Mdot
.21571 .251 Mdot
.21571 .251 Mdot
.20394 .23531 Mdot
.1765 .20787 Mdot
.13728 .16473 Mdot
.11376 .12944 Mdot
.09807 .10591 Mdot
.10591 .09023 Mdot
.11768 .09023 Mdot
.10591 .07454 Mdot
.09415 .06278 Mdot
.09415 .05886 Mdot
.09807 .06278 Mdot
.11376 .07846 Mdot
.09807 .07062 Mdot
.09023 .07062 Mdot
.10591 .08631 Mdot
.13728 .11768 Mdot
.18042 .15297 Mdot
.1961 .16473 Mdot
.21179 .1765 Mdot
.20394 .17257 Mdot
.12552 .11376 Mdot
.10199 .09415 Mdot
.07454 .08239 Mdot
.05886 .0667 Mdot
.05102 .0667 Mdot
.06278 .07454 Mdot
.07062 .07454 Mdot
.08631 .08239 Mdot
.07846 .07062 Mdot
.09023 .06278 Mdot
.09807 .05886 Mdot
.1216 .05886 Mdot
.12552 .05102 Mdot
.1216 .04709 Mdot
.1216 .04709 Mdot
.10591 .04317 Mdot
.09415 .03533 Mdot
.09415 .03533 Mdot
.08631 .03533 Mdot
.08239 .03141 Mdot
.08239 .03141 Mdot
.08631 .03533 Mdot
.11768 .05494 Mdot
.10591 .03925 Mdot
.15297 .07454 Mdot
.23139 .12944 Mdot
.27061 .16081 Mdot
.3059 .18826 Mdot
.32158 .20002 Mdot
.32943 .21179 Mdot
.33335 .21571 Mdot
.32943 .22355 Mdot
.3255 .21963 Mdot
.3255 .22355 Mdot
.33727 .23139 Mdot
.33727 .23531 Mdot
.33727 .24316 Mdot
.33335 .24316 Mdot
.33335 .23924 Mdot
.31766 .22747 Mdot
.31374 .22747 Mdot
.31374 .23139 Mdot
.3255 .24708 Mdot
.32943 .24316 Mdot
.31766 .22747 Mdot
.30982 .21963 Mdot
.31374 .21963 Mdot
.30982 .21963 Mdot
.31766 .22355 Mdot
.30982 .21963 Mdot
.31766 .22747 Mdot
.31766 .22747 Mdot
.31766 .23924 Mdot
.32158 .24316 Mdot
.3255 .24316 Mdot
.31766 .23139 Mdot
.30982 .21571 Mdot
.30982 .21179 Mdot
.30982 .21179 Mdot
.30982 .21571 Mdot
.30982 .21179 Mdot
.3059 .21179 Mdot
.31374 .21963 Mdot
.31374 .21963 Mdot
.29413 .21571 Mdot
.29413 .21571 Mdot
.29413 .21179 Mdot
.27453 .20002 Mdot
.26668 .19218 Mdot
.26276 .18042 Mdot
.26668 .16865 Mdot
.24708 .15297 Mdot
.26276 .14905 Mdot
.26668 .1412 Mdot
.25884 .13728 Mdot
.24708 .1412 Mdot
.25492 .14513 Mdot
.25884 .15297 Mdot
.25884 .15689 Mdot
.251 .16081 Mdot
.24316 .16081 Mdot
.22747 .15297 Mdot
.22355 .14905 Mdot
.21179 .1412 Mdot
.22355 .15297 Mdot
.23924 .16081 Mdot
.23924 .15689 Mdot
.23924 .15689 Mdot
.22747 .14513 Mdot
.23924 .15297 Mdot
.23531 .14513 Mdot
.23924 .14513 Mdot
.23924 .1412 Mdot
.23924 .1412 Mdot
.21571 .1216 Mdot
.21179 .11768 Mdot
.20787 .12944 Mdot
.20787 .13728 Mdot
.20002 .13336 Mdot
.20002 .1412 Mdot
.20002 .14905 Mdot
.20002 .14513 Mdot
.1961 .13336 Mdot
.19218 .1216 Mdot
.17257 .10199 Mdot
.1765 .09415 Mdot
.19218 .10591 Mdot
.18434 .09807 Mdot
.18826 .10199 Mdot
.18434 .10199 Mdot
.1765 .09807 Mdot
.18042 .10199 Mdot
.16865 .09023 Mdot
.16473 .09023 Mdot
.16081 .08239 Mdot
.15689 .07454 Mdot
.16081 .09415 Mdot
.14905 .09415 Mdot
.08631 .09023 Mdot
.16865 .15297 Mdot
.12552 .13728 Mdot
.10591 .1216 Mdot
.09023 .10983 Mdot
.09023 .10199 Mdot
.09023 .09415 Mdot
.09415 .09415 Mdot
.08239 .08239 Mdot
.07846 .07062 Mdot
.08631 .07454 Mdot
.10983 .08631 Mdot
.15297 .1216 Mdot
.18042 .13728 Mdot
.20787 .15297 Mdot
.23531 .18826 Mdot
.21963 .18826 Mdot
.21179 .18826 Mdot
.1961 .19218 Mdot
.20002 .21179 Mdot
.20394 .23531 Mdot
.21963 .251 Mdot
.22747 .251 Mdot
.22747 .24316 Mdot
.21571 .23139 Mdot
.19218 .20394 Mdot
.16865 .16865 Mdot
.15297 .1412 Mdot
.13728 .11768 Mdot
.10199 .09023 Mdot
.10591 .09023 Mdot
.10591 .08239 Mdot
.10591 .07846 Mdot
.11376 .08239 Mdot
.09415 .0667 Mdot
.07062 .04709 Mdot
.0667 .05102 Mdot
.08631 .06278 Mdot
.1412 .10591 Mdot
.16865 .12552 Mdot
.1961 .14905 Mdot
.20787 .16473 Mdot
.20787 .16865 Mdot
.18826 .16473 Mdot
.16473 .15297 Mdot
.12552 .13336 Mdot
.09807 .1216 Mdot
.08631 .11376 Mdot
.07846 .09807 Mdot
.07846 .09023 Mdot
.10983 .10199 Mdot
.13336 .10591 Mdot
.12944 .09415 Mdot
.13336 .07846 Mdot
.12552 .05494 Mdot
.12944 .05494 Mdot
.11768 .04709 Mdot
.10199 .03533 Mdot
.09807 .03533 Mdot
.08239 .02357 Mdot
.08239 .01965 Mdot
.07846 .01965 Mdot
.08631 .02357 Mdot
.09023 .02749 Mdot
.09807 .03925 Mdot
.07846 .02357 Mdot
.08631 .03141 Mdot
.11768 .04317 Mdot
.18434 .09807 Mdot
.23531 .14905 Mdot
.29021 .20002 Mdot
.32158 .22355 Mdot
.32943 .22747 Mdot
.34119 .23924 Mdot
.34119 .23139 Mdot
.34511 .22355 Mdot
.34511 .22355 Mdot
.33727 .22355 Mdot
.32943 .23139 Mdot
.33727 .23531 Mdot
.33335 .23924 Mdot
.31766 .23139 Mdot
.31374 .23924 Mdot
.31374 .23924 Mdot
.3255 .24708 Mdot
.32943 .24316 Mdot
.33335 .23531 Mdot
.31374 .20787 Mdot
.31374 .1961 Mdot
.30982 .20002 Mdot
.30198 .20394 Mdot
.30198 .20787 Mdot
.29806 .20787 Mdot
.29413 .21179 Mdot
.30982 .23531 Mdot
.30982 .24316 Mdot
.30982 .23531 Mdot
.31374 .22747 Mdot
.31374 .21571 Mdot
.31374 .21179 Mdot
.3059 .20787 Mdot
.30198 .20787 Mdot
.30198 .20787 Mdot
.29806 .20394 Mdot
.29806 .20787 Mdot
.3059 .21571 Mdot
.28629 .20002 Mdot
.28629 .21179 Mdot
.30198 .22355 Mdot
.29413 .21963 Mdot
.27061 .21179 Mdot
.26276 .20787 Mdot
.25884 .19218 Mdot
.24708 .1765 Mdot
.25492 .17257 Mdot
.25884 .15689 Mdot
.251 .1412 Mdot
.251 .1412 Mdot
.25492 .1412 Mdot
.26276 .15297 Mdot
.23924 .13728 Mdot
.23531 .1412 Mdot
.23531 .14905 Mdot
.22355 .14905 Mdot
.22355 .15297 Mdot
.20787 .15297 Mdot
.20394 .14905 Mdot
.21963 .15297 Mdot
.22747 .14905 Mdot
.22355 .14513 Mdot
.22355 .1412 Mdot
.22747 .13728 Mdot
.21963 .12944 Mdot
.22355 .12944 Mdot
.21963 .12552 Mdot
.21963 .1216 Mdot
.20787 .10983 Mdot
.1961 .10983 Mdot
.20002 .1216 Mdot
.1961 .12944 Mdot
.1961 .13728 Mdot
.18826 .14513 Mdot
.20002 .14513 Mdot
.20002 .13336 Mdot
.20394 .13728 Mdot
.20002 .13336 Mdot
.18042 .11768 Mdot
.17257 .10591 Mdot
.1765 .10983 Mdot
.17257 .09807 Mdot
.17257 .10199 Mdot
.17257 .10199 Mdot
.17257 .10591 Mdot
.18434 .10983 Mdot
.18434 .11768 Mdot
.16865 .10983 Mdot
.15297 .09023 Mdot
.14513 .07846 Mdot
.14513 .07454 Mdot
.13728 .07846 Mdot
.47059 .44314 Mdot
.25492 .21963 Mdot
.20394 .18434 Mdot
.16865 .16865 Mdot
.15689 .16473 Mdot
.13728 .14905 Mdot
.10983 .12552 Mdot
.10199 .11376 Mdot
.09415 .09415 Mdot
.09415 .07846 Mdot
.08631 .0667 Mdot
.09023 .0667 Mdot
.09415 .06278 Mdot
.10199 .06278 Mdot
.15297 .09807 Mdot
.1765 .11768 Mdot
.20002 .16081 Mdot
.21963 .18826 Mdot
.21571 .18826 Mdot
.21179 .20002 Mdot
.21571 .23139 Mdot
.23531 .25492 Mdot
.23531 .26276 Mdot
.23531 .26276 Mdot
.22355 .24708 Mdot
.22747 .23924 Mdot
.20787 .21571 Mdot
.18042 .18434 Mdot
.14905 .15689 Mdot
.13728 .14513 Mdot
.12552 .13336 Mdot
.1216 .11768 Mdot
.11768 .10983 Mdot
.09807 .09807 Mdot
.08239 .08239 Mdot
.06278 .0667 Mdot
.05102 .05102 Mdot
.09807 .08631 Mdot
.13728 .10591 Mdot
.13336 .09807 Mdot
.1216 .08239 Mdot
.12944 .09023 Mdot
.17257 .13728 Mdot
.19218 .16473 Mdot
.20002 .18042 Mdot
.20002 .19218 Mdot
.18434 .18434 Mdot
.13728 .1412 Mdot
.11768 .1216 Mdot
.10983 .11376 Mdot
.12944 .10983 Mdot
.13728 .10983 Mdot
.14513 .10591 Mdot
.12944 .08631 Mdot
.1216 .0667 Mdot
.12944 .06278 Mdot
.1216 .0667 Mdot
.09415 .04317 Mdot
.08239 .04317 Mdot
.07454 .03533 Mdot
.07062 .03925 Mdot
.07062 .03141 Mdot
.07846 .03533 Mdot
.09415 .04709 Mdot
.09415 .05494 Mdot
.08239 .04317 Mdot
.08239 .03533 Mdot
.08239 .01965 Mdot
.10591 .03925 Mdot
.11376 .05102 Mdot
.23139 .14513 Mdot
.27845 .18826 Mdot
.31374 .21179 Mdot
.3255 .21963 Mdot
.34119 .23139 Mdot
.34511 .22355 Mdot
.34511 .22747 Mdot
.34119 .22747 Mdot
.33335 .22747 Mdot
.33727 .23139 Mdot
.33727 .23139 Mdot
.34511 .24316 Mdot
.33335 .23924 Mdot
.32158 .23531 Mdot
.31766 .22355 Mdot
.3255 .22747 Mdot
.3255 .22355 Mdot
.30982 .20787 Mdot
.31766 .20787 Mdot
.31374 .20787 Mdot
.30982 .20787 Mdot
.3059 .21179 Mdot
.29806 .20394 Mdot
.30198 .20787 Mdot
.3059 .21963 Mdot
.31374 .21963 Mdot
.29806 .21963 Mdot
.29806 .21571 Mdot
.3059 .21179 Mdot
.30198 .21179 Mdot
.29806 .20787 Mdot
.30198 .20394 Mdot
.29806 .20394 Mdot
.29413 .20394 Mdot
.29806 .21179 Mdot
.3059 .21179 Mdot
.30982 .21179 Mdot
.30198 .21179 Mdot
.29413 .21963 Mdot
.29021 .22355 Mdot
.28629 .22747 Mdot
.27453 .22747 Mdot
.26276 .21179 Mdot
.25884 .20002 Mdot
.24316 .18042 Mdot
.23924 .16473 Mdot
.24708 .15689 Mdot
.24316 .1412 Mdot
.24708 .1412 Mdot
.24708 .1412 Mdot
.24316 .14513 Mdot
.23531 .15297 Mdot
.23531 .15297 Mdot
.22355 .14905 Mdot
.20787 .13728 Mdot
.20787 .1412 Mdot
.21179 .1412 Mdot
.19218 .12944 Mdot
.21179 .13336 Mdot
.22355 .14513 Mdot
.23139 .14905 Mdot
.22355 .14513 Mdot
.22747 .14513 Mdot
.22355 .1412 Mdot
.21963 .13336 Mdot
.21571 .12552 Mdot
.20394 .11768 Mdot
.20394 .11768 Mdot
.20394 .1216 Mdot
.19218 .1216 Mdot
.18434 .1216 Mdot
.18434 .12552 Mdot
.1961 .13728 Mdot
.19218 .12944 Mdot
.18826 .12552 Mdot
.19218 .12552 Mdot
.1961 .13336 Mdot
.18434 .12552 Mdot
.1765 .11376 Mdot
.16865 .09807 Mdot
.16081 .09023 Mdot
.16473 .09807 Mdot
.18042 .10983 Mdot
.17257 .10983 Mdot
.1765 .11376 Mdot
.16865 .10591 Mdot
.16081 .10199 Mdot
.16473 .10199 Mdot
.15689 .08631 Mdot
.13728 .06278 Mdot
.65489 .64705 Mdot
.35295 .3255 Mdot
.30982 .29413 Mdot
.26668 .25884 Mdot
.22355 .22355 Mdot
.18826 .18042 Mdot
.15297 .12944 Mdot
.13336 .09415 Mdot
.12944 .09023 Mdot
.12552 .09023 Mdot
.12944 .09415 Mdot
.13728 .09415 Mdot
.12552 .08239 Mdot
.11768 .09023 Mdot
.14513 .1412 Mdot
.1765 .17257 Mdot
.18042 .1765 Mdot
.18434 .19218 Mdot
.22355 .22747 Mdot
.23924 .251 Mdot
.24708 .27061 Mdot
.26668 .28237 Mdot
.25492 .27453 Mdot
.24316 .25884 Mdot
.21963 .23139 Mdot
.21963 .22355 Mdot
.19218 .20002 Mdot
.20394 .1961 Mdot
.21963 .20787 Mdot
.17257 .17257 Mdot
.15297 .17257 Mdot
.11768 .14905 Mdot
.07454 .11376 Mdot
.05102 .09023 Mdot
.04709 .08239 Mdot
.09023 .10983 Mdot
.12552 .12944 Mdot
.10591 .10591 Mdot
.07846 .07062 Mdot
.06278 .05102 Mdot
.09023 .07062 Mdot
.10983 .09415 Mdot
.15689 .13728 Mdot
.18434 .16473 Mdot
.20002 .17257 Mdot
.16081 .13728 Mdot
.14905 .1216 Mdot
.17257 .13728 Mdot
.16865 .12944 Mdot
.15689 .11768 Mdot
.14513 .10199 Mdot
.11768 .07846 Mdot
.11376 .06278 Mdot
.12944 .07062 Mdot
.1216 .06278 Mdot
.10199 .04709 Mdot
.08239 .03925 Mdot
.08239 .04317 Mdot
.07454 .04709 Mdot
.06278 .03533 Mdot
.06278 .03925 Mdot
.07062 .04317 Mdot
.07454 .04709 Mdot
.09023 .05886 Mdot
.09415 .05494 Mdot
.12944 .0667 Mdot
.1412 .07062 Mdot
.15297 .08239 Mdot
.18434 .10199 Mdot
.23139 .13336 Mdot
.27061 .16081 Mdot
.29806 .19218 Mdot
.32158 .21963 Mdot
.33727 .23139 Mdot
.34511 .24708 Mdot
.34903 .25492 Mdot
.33727 .25492 Mdot
.34119 .25884 Mdot
.33727 .24316 Mdot
.33335 .23139 Mdot
.32943 .22355 Mdot
.34119 .22747 Mdot
.33335 .22747 Mdot
.31766 .21963 Mdot
.32158 .22355 Mdot
.3059 .21571 Mdot
.3059 .22355 Mdot
.31374 .22747 Mdot
.30982 .21963 Mdot
.31766 .21963 Mdot
.31374 .20787 Mdot
.31766 .21179 Mdot
.30198 .20002 Mdot
.29413 .19218 Mdot
.29021 .1961 Mdot
.29806 .20002 Mdot
.30982 .21571 Mdot
.30982 .22355 Mdot
.30982 .22747 Mdot
.3059 .22355 Mdot
.29413 .22355 Mdot
.29413 .22355 Mdot
.29413 .22355 Mdot
.29413 .21179 Mdot
.30982 .20787 Mdot
.30198 .20002 Mdot
.30982 .20394 Mdot
.29021 .20394 Mdot
.28629 .21179 Mdot
.27845 .21571 Mdot
.26276 .20787 Mdot
.26668 .20787 Mdot
.24316 .18434 Mdot
.23531 .17257 Mdot
.23139 .16081 Mdot
.24708 .15689 Mdot
.24708 .1412 Mdot
.24316 .13728 Mdot
.23924 .13336 Mdot
.23531 .13336 Mdot
.24708 .1412 Mdot
.23139 .13336 Mdot
.22355 .12552 Mdot
.21963 .12552 Mdot
.23924 .14513 Mdot
.22355 .13728 Mdot
.21179 .12944 Mdot
.21179 .13728 Mdot
.21963 .1412 Mdot
.21963 .14513 Mdot
.22355 .15689 Mdot
.22355 .15689 Mdot
.22747 .15297 Mdot
.21963 .14513 Mdot
.21571 .1412 Mdot
.21963 .13728 Mdot
.21571 .13336 Mdot
.21179 .12552 Mdot
.1961 .11768 Mdot
.19218 .12552 Mdot
.18042 .1216 Mdot
.19218 .12944 Mdot
.19218 .12944 Mdot
.1961 .14513 Mdot
.1961 .14905 Mdot
.1961 .14905 Mdot
.18042 .13336 Mdot
.16865 .1216 Mdot
.17257 .11768 Mdot
.16865 .10983 Mdot
.1765 .11376 Mdot
.17257 .11768 Mdot
.16473 .10983 Mdot
.16081 .10983 Mdot
.16081 .10591 Mdot
.16473 .10199 Mdot
.16081 .08631 Mdot
.14905 .0667 Mdot
.87448 .87448 Mdot
.72155 .72155 Mdot
.50196 .48628 Mdot
.43138 .42354 Mdot
.30982 .30982 Mdot
.29021 .28237 Mdot
.31766 .29413 Mdot
.33335 .29021 Mdot
.31766 .27061 Mdot
.22355 .20394 Mdot
.1765 .17257 Mdot
.17257 .18826 Mdot
.17257 .1961 Mdot
.16473 .18826 Mdot
.13336 .15297 Mdot
.12552 .1412 Mdot
.16473 .16865 Mdot
.18826 .1961 Mdot
.22355 .23531 Mdot
.23924 .25492 Mdot
.25492 .25884 Mdot
.24708 .25492 Mdot
.21571 .23139 Mdot
.20394 .21963 Mdot
.21571 .21963 Mdot
.22747 .22355 Mdot
.24708 .23924 Mdot
.24316 .23924 Mdot
.24708 .251 Mdot
.21571 .23531 Mdot
.16081 .20394 Mdot
.11768 .17257 Mdot
.10199 .15297 Mdot
.1216 .15689 Mdot
.12944 .14905 Mdot
.08239 .10199 Mdot
.07062 .07454 Mdot
.05886 .05494 Mdot
.05494 .05102 Mdot
.07062 .06278 Mdot
.08239 .07062 Mdot
.10199 .09023 Mdot
.13336 .11768 Mdot
.15297 .13336 Mdot
.19218 .16081 Mdot
.20394 .16473 Mdot
.20394 .16473 Mdot
.19218 .15297 Mdot
.15689 .11376 Mdot
.1412 .08631 Mdot
.13336 .07062 Mdot
.12944 .07062 Mdot
.12944 .07062 Mdot
.10983 .05494 Mdot
.09023 .04317 Mdot
.09415 .05102 Mdot
.09023 .05102 Mdot
.07454 .03925 Mdot
.07062 .04317 Mdot
.07062 .04317 Mdot
.07846 .05102 Mdot
.05886 .04709 Mdot
.07062 .06278 Mdot
.27453 .20787 Mdot
.32158 .23924 Mdot
.34903 .251 Mdot
.32158 .21963 Mdot
.30198 .20002 Mdot
.28237 .17257 Mdot
.27453 .16865 Mdot
.28629 .18434 Mdot
.29806 .20394 Mdot
.31766 .23139 Mdot
.3255 .24708 Mdot
.33335 .25492 Mdot
.34119 .251 Mdot
.34119 .24316 Mdot
.33335 .23139 Mdot
.32158 .22355 Mdot
.33335 .23139 Mdot
.33727 .23531 Mdot
.35295 .24708 Mdot
.33727 .23924 Mdot
.32943 .23531 Mdot
.31374 .23139 Mdot
.31374 .23531 Mdot
.32158 .23139 Mdot
.32158 .22355 Mdot
.32158 .21179 Mdot
.31766 .20787 Mdot
.3059 .20002 Mdot
.30198 .20002 Mdot
.30198 .20787 Mdot
.3059 .20787 Mdot
.30982 .21571 Mdot
.30198 .22355 Mdot
.31766 .23924 Mdot
.31374 .24316 Mdot
.29806 .22355 Mdot
.29021 .21571 Mdot
.3059 .22355 Mdot
.3059 .21571 Mdot
.3059 .20787 Mdot
.30198 .20394 Mdot
.30982 .20787 Mdot
.30198 .20787 Mdot
.30198 .20787 Mdot
.29413 .20787 Mdot
.29021 .21571 Mdot
.29021 .21179 Mdot
.27453 .20002 Mdot
.251 .19218 Mdot
.24708 .18434 Mdot
.251 .16865 Mdot
.24316 .15297 Mdot
.24316 .1412 Mdot
.24316 .13728 Mdot
.24316 .14513 Mdot
.24316 .14513 Mdot
.24316 .14513 Mdot
.24316 .14513 Mdot
.23924 .14513 Mdot
.23531 .14905 Mdot
.22747 .14905 Mdot
.23531 .15297 Mdot
.21963 .14513 Mdot
.21179 .13336 Mdot
.21179 .13728 Mdot
.21571 .1412 Mdot
.21571 .14905 Mdot
.22355 .14905 Mdot
.22355 .14905 Mdot
.22355 .15297 Mdot
.21963 .14905 Mdot
.22747 .15297 Mdot
.21963 .14905 Mdot
.21179 .14905 Mdot
.19218 .13728 Mdot
.18434 .12944 Mdot
.19218 .13728 Mdot
.1961 .14513 Mdot
.18826 .14513 Mdot
.18434 .14513 Mdot
.18042 .14513 Mdot
.18042 .14513 Mdot
.17257 .13336 Mdot
.1765 .13336 Mdot
.16865 .11768 Mdot
.1765 .11768 Mdot
.16865 .10983 Mdot
.15689 .10591 Mdot
.15297 .10199 Mdot
.15689 .09807 Mdot
.16081 .09415 Mdot
.15297 .09023 Mdot
.14905 .08631 Mdot
.89801 .89801 Mdot
.67057 .68234 Mdot
.54509 .56078 Mdot
.5647 .55686 Mdot
.58431 .56078 Mdot
.57646 .53725 Mdot
.47451 .45098 Mdot
.41569 .40001 Mdot
.44706 .42746 Mdot
.30982 .3255 Mdot
.15297 .1961 Mdot
.11768 .15297 Mdot
.09415 .11768 Mdot
.08631 .10591 Mdot
.10983 .1216 Mdot
.15297 .15297 Mdot
.19218 .18042 Mdot
.22747 .21571 Mdot
.24316 .23924 Mdot
.24708 .251 Mdot
.22355 .23924 Mdot
.26276 .26668 Mdot
.27845 .27845 Mdot
.28237 .28237 Mdot
.27453 .28629 Mdot
.27061 .29021 Mdot
.251 .27845 Mdot
.24316 .27453 Mdot
.22747 .26668 Mdot
.20787 .24708 Mdot
.19218 .22747 Mdot
.12944 .17257 Mdot
.09023 .12944 Mdot
.07454 .10199 Mdot
.06278 .07454 Mdot
.07454 .07062 Mdot
.07454 .0667 Mdot
.05886 .05494 Mdot
.06278 .04709 Mdot
.07062 .05886 Mdot
.09023 .07454 Mdot
.19218 .15689 Mdot
.19218 .16081 Mdot
.21571 .17257 Mdot
.19218 .14905 Mdot
.17257 .13728 Mdot
.15689 .11768 Mdot
.14905 .10591 Mdot
.13728 .09807 Mdot
.12944 .09023 Mdot
.11768 .08239 Mdot
.10591 .07062 Mdot
.10591 .0667 Mdot
.09415 .05102 Mdot
.09023 .04709 Mdot
.08631 .04317 Mdot
.09807 .0667 Mdot
.07846 .05886 Mdot
.09415 .07062 Mdot
.11768 .09415 Mdot
.22355 .18042 Mdot
.37256 .29413 Mdot
.40393 .31374 Mdot
.41177 .30982 Mdot
.40001 .28629 Mdot
.35687 .24708 Mdot
.3255 .22355 Mdot
.30982 .20787 Mdot
.29806 .20002 Mdot
.30982 .20787 Mdot
.31374 .21963 Mdot
.3255 .23139 Mdot
.34119 .24708 Mdot
.33335 .23924 Mdot
.33727 .23924 Mdot
.34903 .24316 Mdot
.34511 .24316 Mdot
.33727 .24316 Mdot
.34511 .251 Mdot
.34119 .23924 Mdot
.34511 .23531 Mdot
.33727 .22747 Mdot
.33335 .22355 Mdot
.32943 .22747 Mdot
.32943 .23139 Mdot
.3255 .23139 Mdot
.32158 .23139 Mdot
.3255 .23531 Mdot
.31766 .23531 Mdot
.30982 .22747 Mdot
.3059 .21179 Mdot
.3059 .20787 Mdot
.3059 .21179 Mdot
.3059 .21571 Mdot
.30982 .22355 Mdot
.3059 .21179 Mdot
.30198 .20787 Mdot
.31374 .21571 Mdot
.30982 .21963 Mdot
.30982 .21963 Mdot
.31374 .21571 Mdot
.32158 .21963 Mdot
.31374 .21571 Mdot
.30198 .21179 Mdot
.30198 .21179 Mdot
.29806 .20787 Mdot
.29413 .20394 Mdot
.27845 .19218 Mdot
.28237 .20002 Mdot
.27061 .18826 Mdot
.25884 .18042 Mdot
.25492 .17257 Mdot
.23139 .15297 Mdot
.23139 .15297 Mdot
.23139 .15297 Mdot
.251 .16473 Mdot
.24708 .16473 Mdot
.24708 .16473 Mdot
.23924 .15689 Mdot
.24316 .15689 Mdot
.23139 .15689 Mdot
.23531 .16473 Mdot
.23924 .15689 Mdot
.23531 .15689 Mdot
.23139 .15297 Mdot
.22355 .14905 Mdot
.23139 .14905 Mdot
.22747 .14513 Mdot
.21963 .14513 Mdot
.21963 .15297 Mdot
.23924 .1765 Mdot
.23531 .18434 Mdot
.22355 .18042 Mdot
.23139 .18434 Mdot
.20787 .16081 Mdot
.1961 .14905 Mdot
.19218 .14513 Mdot
.19218 .14513 Mdot
.18826 .1412 Mdot
.19218 .1412 Mdot
.18826 .13728 Mdot
.18042 .13336 Mdot
.18826 .13728 Mdot
.18434 .13728 Mdot
.17257 .13336 Mdot
.17257 .12552 Mdot
.16081 .10591 Mdot
.14513 .09807 Mdot
.14905 .10199 Mdot
.14905 .10199 Mdot
.16081 .10591 Mdot
.16081 .10591 Mdot
.1412 .10199 Mdot
.81174 .81174 Mdot
.72547 .70979 Mdot
.63528 .59607 Mdot
.63528 .58039 Mdot
.6196 .56862 Mdot
.62744 .57254 Mdot
.48628 .46275 Mdot
.1216 .17257 Mdot
.11768 .15297 Mdot
.09807 .1216 Mdot
.08239 .10199 Mdot
.07062 .08239 Mdot
.07846 .08631 Mdot
.12552 .1216 Mdot
.15297 .1412 Mdot
.18434 .16865 Mdot
.23924 .21963 Mdot
.24708 .23139 Mdot
.30982 .28237 Mdot
.32158 .29413 Mdot
.29413 .27845 Mdot
.29021 .29021 Mdot
.26668 .28237 Mdot
.26668 .29021 Mdot
.25492 .28629 Mdot
.25492 .28629 Mdot
.26276 .3059 Mdot
.25884 .29413 Mdot
.24316 .27453 Mdot
.16865 .21179 Mdot
.11768 .16081 Mdot
.09807 .12552 Mdot
.07454 .09807 Mdot
.07062 .08631 Mdot
.05102 .06278 Mdot
.05886 .05886 Mdot
.06278 .05886 Mdot
.10983 .08631 Mdot
.1961 .15689 Mdot
.17257 .1412 Mdot
.17257 .1412 Mdot
.18434 .14513 Mdot
.18434 .1412 Mdot
.16865 .12944 Mdot
.16081 .12552 Mdot
.13728 .11376 Mdot
.13728 .1216 Mdot
.1412 .1216 Mdot
.14905 .11768 Mdot
.12944 .09807 Mdot
.11768 .08239 Mdot
.11768 .07846 Mdot
.11376 .07062 Mdot
.1216 .07846 Mdot
.09807 .0667 Mdot
.11376 .08631 Mdot
.16473 .12552 Mdot
.1412 .10983 Mdot
.3059 .24316 Mdot
.3804 .29413 Mdot
.3608 .27453 Mdot
.34119 .26276 Mdot
.36864 .27845 Mdot
.38432 .27453 Mdot
.37256 .251 Mdot
.34511 .21963 Mdot
.32943 .20002 Mdot
.32158 .20394 Mdot
.31766 .20002 Mdot
.32158 .21963 Mdot
.32158 .22747 Mdot
.31766 .22355 Mdot
.32943 .23139 Mdot
.35295 .24316 Mdot
.33727 .23531 Mdot
.35295 .24316 Mdot
.3608 .24708 Mdot
.34119 .23139 Mdot
.33727 .23531 Mdot
.33335 .23139 Mdot
.33335 .23139 Mdot
.32158 .23531 Mdot
.3255 .24316 Mdot
.3255 .251 Mdot
.31766 .251 Mdot
.30982 .24708 Mdot
.31374 .251 Mdot
.31766 .24316 Mdot
.31766 .22355 Mdot
.31374 .21963 Mdot
.30982 .21571 Mdot
.31374 .21571 Mdot
.30982 .20394 Mdot
.30982 .20787 Mdot
.29806 .20787 Mdot
.29806 .21963 Mdot
.29806 .22747 Mdot
.29806 .22355 Mdot
.31374 .23531 Mdot
.29806 .22747 Mdot
.30198 .22747 Mdot
.29806 .21963 Mdot
.29021 .20002 Mdot
.28629 .19218 Mdot
.29021 .19218 Mdot
.29021 .19218 Mdot
.29021 .19218 Mdot
.27845 .19218 Mdot
.27061 .18826 Mdot
.25884 .18826 Mdot
.24316 .18434 Mdot
.22747 .16473 Mdot
.23531 .16865 Mdot
.22747 .17257 Mdot
.22747 .17257 Mdot
.23531 .16473 Mdot
.23531 .14905 Mdot
.24316 .14905 Mdot
.24708 .14905 Mdot
.251 .14905 Mdot
.23924 .14513 Mdot
.23139 .14905 Mdot
.23139 .14905 Mdot
.22355 .14513 Mdot
.22355 .14905 Mdot
.21179 .1412 Mdot
.21571 .14513 Mdot
.20787 .14513 Mdot
.21571 .16081 Mdot
.22747 .1765 Mdot
.22747 .16865 Mdot
.21963 .15689 Mdot
.21179 .14513 Mdot
.1961 .13336 Mdot
.19218 .12944 Mdot
.19218 .12944 Mdot
.20002 .12944 Mdot
.20787 .13336 Mdot
.20002 .12944 Mdot
.18042 .1216 Mdot
.19218 .13728 Mdot
.18434 .13728 Mdot
.1765 .1216 Mdot
.16081 .10591 Mdot
.14513 .09415 Mdot
.14513 .10199 Mdot
.13728 .10983 Mdot
.15689 .1216 Mdot
.14513 .11768 Mdot
.13728 .11376 Mdot
.8235 .79606 Mdot
.65489 .59215 Mdot
.65881 .58823 Mdot
.6196 .55294 Mdot
.3608 .34511 Mdot
.12944 .16081 Mdot
.13336 .14905 Mdot
.10983 .11376 Mdot
.08239 .08631 Mdot
.07846 .08239 Mdot
.07454 .07454 Mdot
.08631 .07846 Mdot
.11376 .09807 Mdot
.14513 .12944 Mdot
.17257 .15689 Mdot
.22747 .20002 Mdot
.25884 .23139 Mdot
.26276 .23924 Mdot
.27061 .25492 Mdot
.27061 .27845 Mdot
.27061 .28629 Mdot
.27061 .29021 Mdot
.27845 .29413 Mdot
.27845 .3059 Mdot
.27453 .29806 Mdot
.27453 .3059 Mdot
.28237 .30982 Mdot
.25884 .28237 Mdot
.21963 .23924 Mdot
.14513 .16473 Mdot
.11376 .13336 Mdot
.09807 .1216 Mdot
.07846 .10591 Mdot
.05494 .08239 Mdot
.14513 .14513 Mdot
.15297 .14513 Mdot
.13336 .1216 Mdot
.12552 .10591 Mdot
.16081 .1216 Mdot
.18434 .13336 Mdot
.16865 .11768 Mdot
.14905 .10591 Mdot
.16081 .1216 Mdot
.15689 .12552 Mdot
.16865 .13336 Mdot
.15689 .11768 Mdot
.16473 .1216 Mdot
.15297 .11376 Mdot
.15297 .10591 Mdot
.14513 .09807 Mdot
.11768 .08239 Mdot
.10199 .07846 Mdot
.08631 .07454 Mdot
.10591 .09023 Mdot
.10983 .09023 Mdot
.41961 .32158 Mdot
.4353 .33727 Mdot
.31766 .24708 Mdot
.21963 .17257 Mdot
.22747 .1765 Mdot
.251 .1765 Mdot
.38432 .25884 Mdot
.38432 .24708 Mdot
.38432 .24316 Mdot
.37256 .23139 Mdot
.33335 .21179 Mdot
.31766 .21571 Mdot
.32158 .22747 Mdot
.32158 .23924 Mdot
.32158 .23531 Mdot
.31766 .22747 Mdot
.32943 .23139 Mdot
.34119 .23924 Mdot
.35687 .251 Mdot
.34119 .23924 Mdot
.34119 .24708 Mdot
.33727 .24316 Mdot
.32943 .23531 Mdot
.32158 .23924 Mdot
.30982 .23139 Mdot
.31766 .24316 Mdot
.32158 .251 Mdot
.32158 .25492 Mdot
.31766 .251 Mdot
.31374 .24708 Mdot
.31374 .24316 Mdot
.31374 .23531 Mdot
.31766 .22747 Mdot
.3255 .22355 Mdot
.31374 .20787 Mdot
.3059 .20394 Mdot
.30982 .21179 Mdot
.30198 .21571 Mdot
.3059 .21571 Mdot
.30982 .22747 Mdot
.30198 .23531 Mdot
.30198 .22747 Mdot
.30982 .23139 Mdot
.29806 .21963 Mdot
.29413 .20787 Mdot
.29021 .1961 Mdot
.29413 .1961 Mdot
.3059 .20002 Mdot
.29413 .1961 Mdot
.28237 .19218 Mdot
.28237 .20002 Mdot
.28629 .20002 Mdot
.27061 .20002 Mdot
.24708 .18042 Mdot
.23924 .17257 Mdot
.21963 .15689 Mdot
.23139 .16865 Mdot
.22747 .15689 Mdot
.23924 .14905 Mdot
.24316 .13728 Mdot
.23139 .12552 Mdot
.23139 .12944 Mdot
.23139 .1412 Mdot
.22747 .14513 Mdot
.22747 .14513 Mdot
.21571 .13336 Mdot
.22355 .13728 Mdot
.22355 .1412 Mdot
.21963 .14513 Mdot
.20394 .13336 Mdot
.21571 .13728 Mdot
.22355 .14905 Mdot
.22355 .14905 Mdot
.21963 .16081 Mdot
.21963 .14513 Mdot
.1961 .12552 Mdot
.20002 .12944 Mdot
.18042 .11376 Mdot
.18434 .11768 Mdot
.18826 .11768 Mdot
.18826 .11376 Mdot
.19218 .11376 Mdot
.19218 .12552 Mdot
.19218 .13336 Mdot
.18042 .12552 Mdot
.16081 .11768 Mdot
.14513 .10199 Mdot
.12944 .09023 Mdot
.14513 .10199 Mdot
.15689 .11768 Mdot
.1412 .11768 Mdot
.13728 .11768 Mdot
.91761 .89801 Mdot
.83919 .79998 Mdot
.56078 .49804 Mdot
.29021 .27845 Mdot
.1961 .18826 Mdot
.16081 .15689 Mdot
.10983 .1216 Mdot
.09415 .10591 Mdot
.08631 .08631 Mdot
.08239 .07846 Mdot
.09415 .08239 Mdot
.10199 .08239 Mdot
.10199 .07846 Mdot
.12552 .10199 Mdot
.14905 .12552 Mdot
.20394 .17257 Mdot
.251 .22355 Mdot
.27061 .251 Mdot
.28237 .26668 Mdot
.30198 .29021 Mdot
.30198 .30198 Mdot
.30982 .31766 Mdot
.3059 .32158 Mdot
.29806 .31374 Mdot
.30198 .3059 Mdot
.29021 .29413 Mdot
.28237 .28629 Mdot
.26276 .26668 Mdot
.23531 .24708 Mdot
.21571 .23531 Mdot
.15297 .19218 Mdot
.11768 .16473 Mdot
.17257 .18434 Mdot
.13336 .14905 Mdot
.08239 .10199 Mdot
.08239 .09023 Mdot
.10591 .09023 Mdot
.11376 .08631 Mdot
.12944 .09807 Mdot
.1412 .10591 Mdot
.14513 .10983 Mdot
.15689 .10983 Mdot
.15297 .10199 Mdot
.14905 .09807 Mdot
.16081 .10199 Mdot
.16473 .10199 Mdot
.16473 .10591 Mdot
.14513 .09807 Mdot
.12944 .09023 Mdot
.11376 .09415 Mdot
.10199 .09807 Mdot
.12552 .1216 Mdot
.11768 .11376 Mdot
.251 .20787 Mdot
.27845 .22355 Mdot
.1765 .14513 Mdot
.1961 .15689 Mdot
.16081 .12552 Mdot
.12552 .08631 Mdot
.1765 .10983 Mdot
.29413 .19218 Mdot
.40785 .27845 Mdot
.42746 .29806 Mdot
.40785 .29413 Mdot
.37256 .27061 Mdot
.33727 .24708 Mdot
.32943 .24708 Mdot
.31374 .24316 Mdot
.29413 .22747 Mdot
.29806 .22747 Mdot
.30982 .23531 Mdot
.32943 .24708 Mdot
.34511 .25884 Mdot
.34511 .26276 Mdot
.34119 .25884 Mdot
.33727 .251 Mdot
.33335 .23139 Mdot
.33335 .23139 Mdot
.33727 .23139 Mdot
.33335 .22355 Mdot
.32158 .22747 Mdot
.3255 .23531 Mdot
.31374 .23924 Mdot
.30982 .24708 Mdot
.32158 .24708 Mdot
.32943 .23531 Mdot
.32943 .23139 Mdot
.31374 .20787 Mdot
.31766 .20787 Mdot
.31374 .20787 Mdot
.31374 .21179 Mdot
.30198 .21179 Mdot
.30982 .21179 Mdot
.31374 .22355 Mdot
.30198 .21963 Mdot
.30198 .23139 Mdot
.30198 .22747 Mdot
.3059 .21963 Mdot
.3059 .21963 Mdot
.29021 .20394 Mdot
.29806 .20394 Mdot
.30198 .20002 Mdot
.29806 .19218 Mdot
.28237 .18042 Mdot
.29021 .19218 Mdot
.28237 .19218 Mdot
.27453 .19218 Mdot
.26276 .18826 Mdot
.251 .18826 Mdot
.23139 .1765 Mdot
.22747 .16473 Mdot
.22747 .15297 Mdot
.22747 .14905 Mdot
.23531 .14513 Mdot
.23531 .1412 Mdot
.22747 .1412 Mdot
.21179 .12944 Mdot
.20787 .13336 Mdot
.21571 .13336 Mdot
.21571 .13336 Mdot
.22747 .14513 Mdot
.21179 .13728 Mdot
.21963 .14513 Mdot
.20787 .13728 Mdot
.20787 .13728 Mdot
.21179 .1412 Mdot
.21179 .14513 Mdot
.21963 .14905 Mdot
.22355 .1412 Mdot
.21571 .13336 Mdot
.20394 .12552 Mdot
.1961 .12552 Mdot
.18826 .1216 Mdot
.19218 .13336 Mdot
.1961 .13336 Mdot
.19218 .12944 Mdot
.1961 .12944 Mdot
.18826 .1216 Mdot
.17257 .11376 Mdot
.15689 .10983 Mdot
.15689 .10591 Mdot
.16473 .10199 Mdot
.15297 .09807 Mdot
.14905 .10199 Mdot
.1412 .10591 Mdot
.76861 .749 Mdot
.56078 .54509 Mdot
.27061 .27453 Mdot
.1961 .21179 Mdot
.14513 .17257 Mdot
.12552 .14905 Mdot
.1216 .12552 Mdot
.10591 .09807 Mdot
.10591 .08631 Mdot
.09415 .07846 Mdot
.09415 .07846 Mdot
.09415 .08239 Mdot
.08239 .07062 Mdot
.15689 .12552 Mdot
.18434 .16081 Mdot
.23531 .20787 Mdot
.27061 .24708 Mdot
.28629 .27061 Mdot
.3059 .29806 Mdot
.32158 .31766 Mdot
.29413 .29806 Mdot
.28237 .29021 Mdot
.29806 .29413 Mdot
.29021 .30198 Mdot
.29021 .30198 Mdot
.29806 .3059 Mdot
.28237 .30198 Mdot
.26668 .28629 Mdot
.24316 .27845 Mdot
.22747 .25884 Mdot
.1412 .18434 Mdot
.08631 .13336 Mdot
.0667 .10591 Mdot
.07062 .09023 Mdot
.06278 .07846 Mdot
.0667 .07454 Mdot
.08239 .07454 Mdot
.1216 .09807 Mdot
.13728 .10199 Mdot
.14513 .10591 Mdot
.13728 .09415 Mdot
.15297 .09807 Mdot
.16473 .10199 Mdot
.17257 .11376 Mdot
.15297 .10591 Mdot
.15297 .1216 Mdot
.15689 .13336 Mdot
.16081 .15689 Mdot
.15689 .16473 Mdot
.14513 .15297 Mdot
.10983 .1216 Mdot
.11376 .11768 Mdot
.11376 .11376 Mdot
.13728 .1216 Mdot
.12552 .10983 Mdot
.11768 .10199 Mdot
.10983 .09415 Mdot
.11376 .09415 Mdot
.23139 .17257 Mdot
.30982 .23139 Mdot
.37648 .28237 Mdot
.41961 .30982 Mdot
.42354 .31374 Mdot
.34511 .26276 Mdot
.251 .19218 Mdot
.21963 .16865 Mdot
.21963 .16473 Mdot
.23531 .18042 Mdot
.25492 .1961 Mdot
.30198 .22747 Mdot
.31766 .23531 Mdot
.34119 .251 Mdot
.33727 .24316 Mdot
.34119 .24708 Mdot
.34511 .23531 Mdot
.3608 .23139 Mdot
.33727 .21179 Mdot
.33727 .21179 Mdot
.32943 .21571 Mdot
.31766 .22355 Mdot
.32158 .23531 Mdot
.31374 .22747 Mdot
.31766 .21963 Mdot
.32943 .22747 Mdot
.32158 .21571 Mdot
.31766 .21179 Mdot
.31766 .21179 Mdot
.31766 .20394 Mdot
.31766 .20787 Mdot
.30982 .20787 Mdot
.30198 .20002 Mdot
.29021 .20002 Mdot
.29413 .20394 Mdot
.30982 .22355 Mdot
.3059 .21963 Mdot
.31374 .21963 Mdot
.31374 .21571 Mdot
.30198 .20787 Mdot
.30198 .20394 Mdot
.30198 .20002 Mdot
.28237 .18434 Mdot
.28237 .19218 Mdot
.27845 .19218 Mdot
.29021 .20394 Mdot
.29021 .20394 Mdot
.27061 .18826 Mdot
.25492 .18434 Mdot
.23924 .1765 Mdot
.22747 .16081 Mdot
.22355 .16473 Mdot
.22747 .16473 Mdot
.23924 .16865 Mdot
.24316 .16473 Mdot
.24316 .16473 Mdot
.21571 .14905 Mdot
.20002 .13336 Mdot
.20394 .12944 Mdot
.20002 .12552 Mdot
.20002 .12552 Mdot
.20787 .12944 Mdot
.20394 .12552 Mdot
.20394 .12552 Mdot
.21963 .13728 Mdot
.22355 .13728 Mdot
.21963 .13336 Mdot
.21963 .13336 Mdot
.21571 .12944 Mdot
.21571 .13728 Mdot
.20394 .13728 Mdot
.19218 .12944 Mdot
.18434 .13336 Mdot
.18434 .12552 Mdot
.20002 .12944 Mdot
.18434 .11768 Mdot
.17257 .10983 Mdot
.18434 .11768 Mdot
.16081 .10199 Mdot
.13728 .08631 Mdot
.14905 .08631 Mdot
.14905 .08239 Mdot
.15297 .08631 Mdot
.13728 .08631 Mdot
.65881 .66273 Mdot
.41961 .43138 Mdot
.20002 .21179 Mdot
.18042 .17257 Mdot
.14513 .12944 Mdot
.1216 .10591 Mdot
.10591 .09807 Mdot
.09807 .09023 Mdot
.08239 .07454 Mdot
.07062 .0667 Mdot
.07062 .0667 Mdot
.07846 .07062 Mdot
.1216 .10591 Mdot
.1961 .17257 Mdot
.26276 .23531 Mdot
.27453 .25492 Mdot
.30198 .28629 Mdot
.3059 .29413 Mdot
.3059 .30198 Mdot
.29806 .29806 Mdot
.30198 .3059 Mdot
.30198 .30198 Mdot
.29021 .29806 Mdot
.28629 .29413 Mdot
.29806 .31374 Mdot
.29413 .3255 Mdot
.28237 .3255 Mdot
.24316 .29021 Mdot
.20394 .251 Mdot
.13336 .1765 Mdot
.07454 .12552 Mdot
.07454 .10983 Mdot
.0667 .09023 Mdot
.07062 .08239 Mdot
.08239 .08631 Mdot
.11768 .10591 Mdot
.13728 .11768 Mdot
.1412 .1216 Mdot
.14905 .10983 Mdot
.16473 .1216 Mdot
.16865 .1216 Mdot
.16081 .1216 Mdot
.15297 .1216 Mdot
.21571 .18826 Mdot
.21571 .20787 Mdot
.20394 .21571 Mdot
.1412 .16473 Mdot
.11768 .1412 Mdot
.09023 .11376 Mdot
.09023 .10983 Mdot
.11376 .11376 Mdot
.12552 .10983 Mdot
.11376 .09807 Mdot
.12944 .10591 Mdot
.12944 .10591 Mdot
.1216 .09415 Mdot
.15297 .10199 Mdot
.1765 .11376 Mdot
.23924 .16081 Mdot
.40393 .29021 Mdot
.38432 .27845 Mdot
.20787 .14513 Mdot
.16865 .11768 Mdot
.13336 .09023 Mdot
.12944 .08239 Mdot
.12552 .07846 Mdot
.22355 .14513 Mdot
.26276 .1765 Mdot
.3059 .21179 Mdot
.32943 .23531 Mdot
.33727 .251 Mdot
.33335 .24708 Mdot
.34511 .24316 Mdot
.34119 .23139 Mdot
.34119 .22747 Mdot
.33335 .21963 Mdot
.3255 .21571 Mdot
.33335 .21963 Mdot
.32158 .21571 Mdot
.30982 .21179 Mdot
.3059 .21571 Mdot
.32158 .22355 Mdot
.30982 .21571 Mdot
.3059 .21179 Mdot
.3059 .21179 Mdot
.31374 .21963 Mdot
.30198 .20394 Mdot
.29806 .18826 Mdot
.28629 .18434 Mdot
.29413 .1961 Mdot
.29806 .20002 Mdot
.29413 .1961 Mdot
.30198 .20787 Mdot
.30198 .20787 Mdot
.30198 .21963 Mdot
.29806 .22747 Mdot
.28629 .21963 Mdot
.28237 .21179 Mdot
.27453 .20394 Mdot
.27061 .1961 Mdot
.27453 .19218 Mdot
.28237 .19218 Mdot
.28237 .18826 Mdot
.27845 .18826 Mdot
.27453 .18826 Mdot
.25884 .1765 Mdot
.24316 .16865 Mdot
.22355 .16865 Mdot
.22355 .16865 Mdot
.22355 .17257 Mdot
.22355 .16865 Mdot
.21179 .15297 Mdot
.20787 .1412 Mdot
.20394 .13336 Mdot
.20394 .11768 Mdot
.20394 .11376 Mdot
.20787 .11376 Mdot
.20394 .10591 Mdot
.19218 .09807 Mdot
.20394 .10591 Mdot
.21571 .11768 Mdot
.21179 .11768 Mdot
.21571 .13336 Mdot
.20394 .13336 Mdot
.20394 .14905 Mdot
.20002 .16081 Mdot
.16865 .13728 Mdot
.16473 .13336 Mdot
.16865 .12552 Mdot
.1765 .12944 Mdot
.18042 .12944 Mdot
.18434 .1216 Mdot
.18042 .11376 Mdot
.16865 .09807 Mdot
.15689 .08631 Mdot
.16081 .08631 Mdot
.14905 .07454 Mdot
.1412 .07062 Mdot
.13728 .0667 Mdot
.81174 .81174 Mdot
.63528 .6196 Mdot
.251 .21571 Mdot
.17257 .1412 Mdot
.15297 .1216 Mdot
.11376 .09807 Mdot
.09807 .09023 Mdot
.07846 .07454 Mdot
.07846 .07454 Mdot
.07062 .0667 Mdot
.07846 .07846 Mdot
.09807 .09023 Mdot
.13728 .12552 Mdot
.18826 .1765 Mdot
.23139 .21963 Mdot
.27061 .251 Mdot
.28629 .27061 Mdot
.3059 .29021 Mdot
.31766 .30198 Mdot
.31766 .30198 Mdot
.30982 .29413 Mdot
.29806 .29021 Mdot
.28629 .29413 Mdot
.27453 .30198 Mdot
.27453 .31374 Mdot
.28237 .32158 Mdot
.29021 .32943 Mdot
.27061 .3059 Mdot
.21571 .24316 Mdot
.1216 .16081 Mdot
.11376 .14513 Mdot
.09807 .11768 Mdot
.07062 .09807 Mdot
.09415 .11768 Mdot
.13336 .1412 Mdot
.14905 .14513 Mdot
.15689 .1412 Mdot
.16473 .14513 Mdot
.16865 .14513 Mdot
.16081 .13728 Mdot
.14513 .12552 Mdot
.21571 .18826 Mdot
.27061 .23924 Mdot
.28237 .26276 Mdot
.23139 .21963 Mdot
.18042 .18434 Mdot
.13728 .14905 Mdot
.10199 .1216 Mdot
.11376 .12552 Mdot
.11376 .1216 Mdot
.11376 .10983 Mdot
.11768 .10591 Mdot
.10591 .09023 Mdot
.09023 .07454 Mdot
.11768 .07454 Mdot
.1412 .08239 Mdot
.1216 .05886 Mdot
.18042 .11376 Mdot
.20394 .13336 Mdot
.16081 .10199 Mdot
.13336 .07846 Mdot
.12944 .07846 Mdot
.12944 .07846 Mdot
.11376 .0667 Mdot
.16473 .10591 Mdot
.1961 .12552 Mdot
.27453 .18434 Mdot
.29021 .1961 Mdot
.3059 .21571 Mdot
.3059 .22355 Mdot
.34119 .24316 Mdot
.34903 .23924 Mdot
.34903 .23531 Mdot
.34511 .22355 Mdot
.32943 .21571 Mdot
.34119 .22355 Mdot
.31766 .20787 Mdot
.30982 .21179 Mdot
.31766 .21963 Mdot
.30982 .21963 Mdot
.30982 .22355 Mdot
.3059 .22355 Mdot
.30982 .22747 Mdot
.31374 .23139 Mdot
.31374 .23139 Mdot
.30198 .20787 Mdot
.29021 .19218 Mdot
.26668 .1765 Mdot
.26276 .16865 Mdot
.26276 .16473 Mdot
.27453 .18042 Mdot
.29413 .20002 Mdot
.29021 .20787 Mdot
.29806 .21963 Mdot
.30198 .22747 Mdot
.29021 .22355 Mdot
.27845 .22355 Mdot
.27453 .21963 Mdot
.27453 .20394 Mdot
.27061 .18826 Mdot
.26668 .18434 Mdot
.26668 .18826 Mdot
.26276 .18042 Mdot
.27061 .18434 Mdot
.251 .17257 Mdot
.23924 .18042 Mdot
.24708 .18826 Mdot
.23139 .18434 Mdot
.21963 .18042 Mdot
.21571 .17257 Mdot
.21571 .16865 Mdot
.20787 .1412 Mdot
.20394 .12944 Mdot
.21571 .13336 Mdot
.22355 .12944 Mdot
.21963 .11768 Mdot
.20787 .11768 Mdot
.1961 .11376 Mdot
.20394 .1216 Mdot
.1961 .11376 Mdot
.20787 .12944 Mdot
.20394 .13728 Mdot
.20787 .15297 Mdot
.21179 .16473 Mdot
.19218 .15297 Mdot
.1765 .13728 Mdot
.18434 .1412 Mdot
.16473 .1216 Mdot
.1765 .11768 Mdot
.18434 .1216 Mdot
.18434 .11376 Mdot
.1765 .09415 Mdot
.18042 .09023 Mdot
.18042 .08631 Mdot
.1765 .07454 Mdot
.14905 .05886 Mdot
.1412 .05886 Mdot
.81566 .80782 Mdot
.60391 .59607 Mdot
.16473 .16473 Mdot
.13728 .14905 Mdot
.11376 .12552 Mdot
.09807 .09807 Mdot
.10199 .09807 Mdot
.10591 .10199 Mdot
.10591 .10199 Mdot
.11768 .10591 Mdot
.11376 .10591 Mdot
.12944 .12552 Mdot
.15689 .14513 Mdot
.20002 .18826 Mdot
.27061 .24708 Mdot
.30982 .27845 Mdot
.32943 .30198 Mdot
.33335 .31766 Mdot
.32158 .32158 Mdot
.29806 .31766 Mdot
.28629 .31766 Mdot
.28237 .31766 Mdot
.27453 .31766 Mdot
.33727 .35687 Mdot
.29806 .32158 Mdot
.3255 .3255 Mdot
.27453 .27061 Mdot
.25492 .251 Mdot
.20394 .22355 Mdot
.12552 .16865 Mdot
.10591 .15297 Mdot
.1765 .20787 Mdot
.1765 .20002 Mdot
.15689 .16865 Mdot
.15297 .14905 Mdot
.16081 .14513 Mdot
.15297 .13336 Mdot
.14905 .12552 Mdot
.12944 .11768 Mdot
.18826 .16865 Mdot
.24316 .22355 Mdot
.27061 .24316 Mdot
.26276 .23924 Mdot
.25492 .23139 Mdot
.20787 .1961 Mdot
.16865 .16865 Mdot
.14513 .14905 Mdot
.1216 .12944 Mdot
.10591 .10199 Mdot
.08239 .07454 Mdot
.0667 .05886 Mdot
.10983 .07846 Mdot
.12552 .08239 Mdot
.1216 .07454 Mdot
.13336 .08631 Mdot
.16473 .10983 Mdot
.1765 .12552 Mdot
.1412 .09415 Mdot
.13336 .08239 Mdot
.13728 .09023 Mdot
.14513 .09807 Mdot
.20002 .1412 Mdot
.24316 .16473 Mdot
.27061 .18042 Mdot
.28629 .19218 Mdot
.29806 .18826 Mdot
.29806 .18826 Mdot
.32158 .20787 Mdot
.31766 .20002 Mdot
.3255 .20787 Mdot
.33335 .22355 Mdot
.32943 .22355 Mdot
.34119 .23139 Mdot
.3255 .22355 Mdot
.3255 .22355 Mdot
.32943 .22355 Mdot
.3255 .21571 Mdot
.33335 .22355 Mdot
.32943 .22747 Mdot
.3255 .22747 Mdot
.32943 .23139 Mdot
.32943 .24316 Mdot
.32158 .23924 Mdot
.30982 .22747 Mdot
.29021 .21963 Mdot
.28237 .20787 Mdot
.27453 .19218 Mdot
.27845 .18826 Mdot
.27845 .18826 Mdot
.27845 .18826 Mdot
.27845 .19218 Mdot
.29806 .20394 Mdot
.29413 .20394 Mdot
.28629 .20787 Mdot
.28629 .21571 Mdot
.27845 .21179 Mdot
.26668 .20002 Mdot
.27845 .21179 Mdot
.27845 .21179 Mdot
.27061 .1961 Mdot
.27453 .19218 Mdot
.26668 .18826 Mdot
.25884 .19218 Mdot
.25884 .1961 Mdot
.251 .19218 Mdot
.251 .19218 Mdot
.25492 .18434 Mdot
.25884 .18042 Mdot
.24708 .16473 Mdot
.23531 .15297 Mdot
.23924 .16081 Mdot
.23531 .16081 Mdot
.22747 .14905 Mdot
.22747 .15297 Mdot
.21963 .15689 Mdot
.20787 .15297 Mdot
.1961 .14513 Mdot
.1961 .1412 Mdot
.20002 .1412 Mdot
.20394 .1412 Mdot
.20787 .14513 Mdot
.21963 .15689 Mdot
.20394 .14513 Mdot
.20002 .13728 Mdot
.20394 .13336 Mdot
.18434 .11768 Mdot
.18826 .1216 Mdot
.18826 .11768 Mdot
.1961 .11376 Mdot
.19218 .10199 Mdot
.18826 .09415 Mdot
.18042 .08631 Mdot
.17257 .09023 Mdot
.16081 .08239 Mdot
.63528 .63136 Mdot
.38432 .40393 Mdot
.16865 .19218 Mdot
.18434 .20002 Mdot
.20787 .21571 Mdot
.17257 .1765 Mdot
.15689 .15689 Mdot
.14905 .14513 Mdot
.1412 .12944 Mdot
.14905 .13336 Mdot
.15689 .13728 Mdot
.20394 .1765 Mdot
.21963 .1961 Mdot
.27453 .23924 Mdot
.30198 .27453 Mdot
.31766 .30982 Mdot
.32158 .3255 Mdot
.3255 .34511 Mdot
.31766 .34119 Mdot
.29413 .32158 Mdot
.29806 .30982 Mdot
.3059 .3059 Mdot
.32158 .3059 Mdot
.34119 .3255 Mdot
.32158 .32158 Mdot
.31374 .3255 Mdot
.28237 .30982 Mdot
.23531 .27453 Mdot
.23531 .26668 Mdot
.14513 .19218 Mdot
.12552 .15689 Mdot
.11376 .12552 Mdot
.10591 .10983 Mdot
.10591 .09415 Mdot
.10591 .09023 Mdot
.07846 .07846 Mdot
.08239 .09415 Mdot
.12552 .13336 Mdot
.21571 .20002 Mdot
.25884 .23531 Mdot
.27845 .24708 Mdot
.28629 .251 Mdot
.28237 .251 Mdot
.21179 .20002 Mdot
.17257 .1765 Mdot
.13728 .14905 Mdot
.10983 .10983 Mdot
.07846 .07062 Mdot
.07846 .0667 Mdot
.08631 .07062 Mdot
.09807 .07062 Mdot
.15689 .11376 Mdot
.1765 .1216 Mdot
.1961 .13728 Mdot
.1765 .11768 Mdot
.17257 .10983 Mdot
.16473 .10199 Mdot
.1412 .08631 Mdot
.1765 .1216 Mdot
.19218 .12944 Mdot
.22355 .14513 Mdot
.23531 .15297 Mdot
.26276 .16081 Mdot
.26668 .16081 Mdot
.29021 .18826 Mdot
.30198 .20002 Mdot
.30198 .20002 Mdot
.30982 .20002 Mdot
.31766 .21179 Mdot
.32158 .22355 Mdot
.32943 .22747 Mdot
.3255 .22747 Mdot
.3255 .22355 Mdot
.32943 .21963 Mdot
.33727 .22355 Mdot
.3255 .21963 Mdot
.31766 .21963 Mdot
.31374 .23139 Mdot
.31766 .24708 Mdot
.3255 .25492 Mdot
.31766 .24708 Mdot
.30982 .23924 Mdot
.29413 .22747 Mdot
.29021 .21179 Mdot
.29021 .20394 Mdot
.30198 .20787 Mdot
.28629 .20002 Mdot
.29021 .20394 Mdot
.28237 .19218 Mdot
.27453 .18434 Mdot
.28237 .18826 Mdot
.27845 .19218 Mdot
.27453 .19218 Mdot
.25884 .18826 Mdot
.27061 .1961 Mdot
.27061 .1961 Mdot
.25884 .18434 Mdot
.25492 .18042 Mdot
.251 .1765 Mdot
.25884 .18434 Mdot
.251 .1765 Mdot
.25492 .18042 Mdot
.251 .1765 Mdot
.25884 .18042 Mdot
.25492 .1765 Mdot
.25492 .16865 Mdot
.24708 .16865 Mdot
.251 .1765 Mdot
.25492 .18042 Mdot
.24708 .1765 Mdot
.23531 .1765 Mdot
.23139 .18042 Mdot
.22355 .18042 Mdot
.22355 .1765 Mdot
.20787 .16473 Mdot
.20002 .15297 Mdot
.19218 .13728 Mdot
.18826 .12552 Mdot
.1961 .12552 Mdot
.20002 .12552 Mdot
.20394 .1216 Mdot
.21179 .12552 Mdot
.20002 .10983 Mdot
.18434 .09807 Mdot
.18434 .10199 Mdot
.16473 .10199 Mdot
.17257 .10591 Mdot
.17257 .09807 Mdot
.16473 .09023 Mdot
.16473 .10591 Mdot
.16081 .10591 Mdot
.69802 .6941 Mdot
.56078 .55294 Mdot
.32943 .34119 Mdot
.32943 .32158 Mdot
.29413 .26668 Mdot
.23924 .21179 Mdot
.21571 .18042 Mdot
.19218 .16473 Mdot
.18434 .16081 Mdot
.18042 .17257 Mdot
.20002 .19218 Mdot
.21179 .20394 Mdot
.26276 .251 Mdot
.28629 .28237 Mdot
.32158 .31766 Mdot
.34119 .33727 Mdot
.34511 .33335 Mdot
.33727 .31374 Mdot
.32158 .29806 Mdot
.32158 .30198 Mdot
.34511 .33335 Mdot
.33335 .34119 Mdot
.3255 .35687 Mdot
.33335 .36864 Mdot
.33335 .36472 Mdot
.3255 .34511 Mdot
.24316 .27845 Mdot
.20787 .23924 Mdot
.13728 .16081 Mdot
.13728 .1412 Mdot
.10199 .10591 Mdot
.07454 .09023 Mdot
.05494 .07846 Mdot
.08239 .09415 Mdot
.07846 .07846 Mdot
.23531 .1961 Mdot
.22747 .20394 Mdot
.21963 .20787 Mdot
.22355 .21179 Mdot
.24316 .23139 Mdot
.27061 .25492 Mdot
.27845 .26276 Mdot
.26668 .24708 Mdot
.18826 .1765 Mdot
.09415 .08631 Mdot
.09023 .07454 Mdot
.07846 .06278 Mdot
.08239 .05886 Mdot
.18042 .12552 Mdot
.1765 .1216 Mdot
.18434 .1216 Mdot
.18826 .11376 Mdot
.18826 .11376 Mdot
.1961 .11768 Mdot
.19218 .11768 Mdot
.17257 .10199 Mdot
.14905 .09023 Mdot
.13728 .08239 Mdot
.12552 .07062 Mdot
.16081 .09415 Mdot
.19218 .1216 Mdot
.26276 .17257 Mdot
.3059 .20002 Mdot
.31374 .21179 Mdot
.3255 .21571 Mdot
.32158 .20787 Mdot
.31766 .21571 Mdot
.3059 .21571 Mdot
.30198 .21179 Mdot
.3059 .21571 Mdot
.31766 .22747 Mdot
.32158 .22355 Mdot
.31766 .21963 Mdot
.32158 .22355 Mdot
.3255 .24316 Mdot
.3255 .24708 Mdot
.34119 .25884 Mdot
.32158 .24316 Mdot
.31374 .22747 Mdot
.30982 .21963 Mdot
.3059 .21179 Mdot
.3059 .21179 Mdot
.3059 .20787 Mdot
.30982 .21571 Mdot
.29806 .20787 Mdot
.29413 .20002 Mdot
.28629 .19218 Mdot
.29021 .18826 Mdot
.28237 .18042 Mdot
.27453 .18434 Mdot
.27453 .18434 Mdot
.27061 .18042 Mdot
.26276 .18826 Mdot
.26668 .19218 Mdot
.26276 .18826 Mdot
.25492 .18042 Mdot
.26668 .18826 Mdot
.27061 .19218 Mdot
.25884 .18042 Mdot
.251 .16865 Mdot
.251 .16865 Mdot
.251 .16473 Mdot
.24708 .16865 Mdot
.24708 .16865 Mdot
.25884 .1765 Mdot
.25492 .16865 Mdot
.25492 .17257 Mdot
.24708 .1765 Mdot
.23139 .17257 Mdot
.23531 .1765 Mdot
.23531 .1765 Mdot
.22747 .1765 Mdot
.21963 .16865 Mdot
.21179 .15297 Mdot
.19218 .12944 Mdot
.20002 .12944 Mdot
.20787 .12944 Mdot
.21179 .12944 Mdot
.20394 .12552 Mdot
.20002 .11768 Mdot
.19218 .10983 Mdot
.20002 .11768 Mdot
.18434 .10591 Mdot
.18434 .09807 Mdot
.18042 .09415 Mdot
.16865 .09023 Mdot
.17257 .10591 Mdot
.1765 .10983 Mdot
.90585 .89409 Mdot
.8039 .77645 Mdot
.61568 .54902 Mdot
.37256 .34903 Mdot
.3255 .29806 Mdot
.30198 .27453 Mdot
.26668 .251 Mdot
.25884 .24316 Mdot
.24708 .22747 Mdot
.20787 .1961 Mdot
.20002 .1961 Mdot
.21179 .21571 Mdot
.25492 .25884 Mdot
.30198 .30198 Mdot
.32158 .30982 Mdot
.34511 .31374 Mdot
.35295 .3059 Mdot
.37256 .32158 Mdot
.36472 .33335 Mdot
.34119 .33727 Mdot
.32158 .34511 Mdot
.3255 .36472 Mdot
.34511 .3804 Mdot
.35295 .38824 Mdot
.34511 .3804 Mdot
.33335 .3608 Mdot
.28237 .30198 Mdot
.251 .25492 Mdot
.16473 .18042 Mdot
.13728 .15297 Mdot
.09023 .11376 Mdot
.08631 .10199 Mdot
.13336 .12944 Mdot
.27061 .23924 Mdot
.15297 .15689 Mdot
.14513 .15297 Mdot
.1216 .13728 Mdot
.12552 .13728 Mdot
.1961 .18826 Mdot
.24708 .22747 Mdot
.27845 .24708 Mdot
.29806 .24708 Mdot
.18042 .14513 Mdot
.11376 .08239 Mdot
.09023 .05102 Mdot
.06278 .02749 Mdot
.09415 .05494 Mdot
.10591 .05886 Mdot
.11376 .05102 Mdot
.14513 .07454 Mdot
.16081 .09415 Mdot
.18434 .11768 Mdot
.1765 .10983 Mdot
.16081 .10591 Mdot
.14513 .09807 Mdot
.1765 .12552 Mdot
.14513 .10199 Mdot
.12944 .09415 Mdot
.1216 .08631 Mdot
.27061 .19218 Mdot
.41569 .29806 Mdot
.39609 .28237 Mdot
.39609 .27845 Mdot
.3608 .26276 Mdot
.33335 .24708 Mdot
.31374 .23924 Mdot
.30198 .22747 Mdot
.29806 .21963 Mdot
.29806 .21963 Mdot
.29413 .21179 Mdot
.29413 .21571 Mdot
.30198 .21963 Mdot
.30982 .23531 Mdot
.32158 .23924 Mdot
.32158 .23139 Mdot
.33335 .23531 Mdot
.32158 .23139 Mdot
.30982 .21571 Mdot
.30198 .20787 Mdot
.29806 .20394 Mdot
.3059 .20787 Mdot
.31766 .21179 Mdot
.30982 .20394 Mdot
.31374 .20394 Mdot
.30198 .19218 Mdot
.29021 .18826 Mdot
.28237 .18042 Mdot
.28237 .19218 Mdot
.28237 .19218 Mdot
.26668 .19218 Mdot
.26276 .20394 Mdot
.26276 .20394 Mdot
.25884 .1961 Mdot
.26276 .1961 Mdot
.27845 .20002 Mdot
.25884 .18042 Mdot
.26668 .18042 Mdot
.26668 .17257 Mdot
.26276 .16473 Mdot
.25884 .15689 Mdot
.25492 .15689 Mdot
.24316 .15297 Mdot
.23924 .15297 Mdot
.23531 .15689 Mdot
.24316 .16473 Mdot
.23924 .16865 Mdot
.23924 .1765 Mdot
.23924 .16865 Mdot
.23531 .16473 Mdot
.21571 .15297 Mdot
.21571 .15689 Mdot
.21179 .15297 Mdot
.20394 .1412 Mdot
.20394 .13336 Mdot
.20002 .12944 Mdot
.20002 .12552 Mdot
.1961 .1216 Mdot
.18826 .11768 Mdot
.18434 .11376 Mdot
.18434 .11376 Mdot
.18042 .10199 Mdot
.16473 .08631 Mdot
.15297 .08631 Mdot
.16865 .10199 Mdot
.16473 .09807 Mdot
.17257 .10199 Mdot
.88232 .8784 Mdot
.76469 .75292 Mdot
.47843 .47451 Mdot
.53333 .49412 Mdot
.57646 .49804 Mdot
.28237 .25884 Mdot
.27845 .251 Mdot
.25492 .23139 Mdot
.22747 .21963 Mdot
.22747 .22747 Mdot
.22355 .22747 Mdot
.23924 .24708 Mdot
.26668 .25884 Mdot
.31766 .28629 Mdot
.34903 .3059 Mdot
.36864 .32158 Mdot
.36472 .33727 Mdot
.34119 .33335 Mdot
.32943 .34511 Mdot
.34119 .36472 Mdot
.34119 .36864 Mdot
.3255 .36864 Mdot
.33727 .37648 Mdot
.34511 .37256 Mdot
.35687 .36472 Mdot
.32943 .32943 Mdot
.29021 .29021 Mdot
.20787 .21179 Mdot
.1412 .15689 Mdot
.21571 .20787 Mdot
.24708 .22355 Mdot
.12552 .13728 Mdot
.12552 .1412 Mdot
.09023 .11768 Mdot
.07062 .09807 Mdot
.08239 .09415 Mdot
.11376 .11376 Mdot
.15689 .13728 Mdot
.19218 .15689 Mdot
.19218 .14513 Mdot
.13728 .09807 Mdot
.11376 .07062 Mdot
.11768 .0667 Mdot
.09415 .04709 Mdot
.09807 .05102 Mdot
.09415 .05102 Mdot
.09023 .04709 Mdot
.10983 .06278 Mdot
.1216 .07454 Mdot
.12552 .07846 Mdot
.10983 .07454 Mdot
.08631 .0667 Mdot
.15689 .11768 Mdot
.17257 .12552 Mdot
.1765 .13336 Mdot
.17257 .12944 Mdot
.21179 .15297 Mdot
.34511 .251 Mdot
.41961 .32158 Mdot
.43922 .33727 Mdot
.44314 .34903 Mdot
.41177 .3255 Mdot
.35295 .28237 Mdot
.30982 .24708 Mdot
.27453 .20787 Mdot
.25492 .19218 Mdot
.24708 .18826 Mdot
.25492 .18826 Mdot
.25884 .20002 Mdot
.27845 .21179 Mdot
.29806 .21963 Mdot
.31766 .23139 Mdot
.31766 .24316 Mdot
.30982 .24316 Mdot
.30982 .23924 Mdot
.29413 .21963 Mdot
.3059 .21571 Mdot
.30982 .20394 Mdot
.31374 .1961 Mdot
.30982 .1961 Mdot
.30198 .18826 Mdot
.30198 .1961 Mdot
.29806 .19218 Mdot
.29806 .1961 Mdot
.27845 .1961 Mdot
.28237 .20787 Mdot
.26668 .20787 Mdot
.27061 .21571 Mdot
.27453 .22355 Mdot
.26276 .20787 Mdot
.25884 .18826 Mdot
.27453 .18826 Mdot
.26668 .1765 Mdot
.26668 .17257 Mdot
.26276 .16473 Mdot
.27061 .17257 Mdot
.25884 .16473 Mdot
.24316 .16473 Mdot
.24316 .16865 Mdot
.22355 .15689 Mdot
.21963 .15297 Mdot
.22355 .15297 Mdot
.23139 .15689 Mdot
.23531 .16081 Mdot
.23531 .15689 Mdot
.23531 .15297 Mdot
.23139 .14513 Mdot
.22355 .13728 Mdot
.21571 .12944 Mdot
.20787 .1216 Mdot
.20394 .11376 Mdot
.18826 .10983 Mdot
.18826 .11768 Mdot
.18826 .1216 Mdot
.1765 .11376 Mdot
.18434 .11768 Mdot
.18434 .1216 Mdot
.17257 .11376 Mdot
.16473 .10591 Mdot
.16473 .10591 Mdot
.16865 .11376 Mdot
.17257 .11768 Mdot
.16081 .11768 Mdot
.83527 .81958 Mdot
.76861 .71763 Mdot
.56078 .4902 Mdot
.50588 .42746 Mdot
.34511 .30198 Mdot
.34903 .3059 Mdot
.32158 .28629 Mdot
.29413 .27061 Mdot
.26668 .25492 Mdot
.251 .23139 Mdot
.24708 .22355 Mdot
.26276 .23139 Mdot
.30198 .26276 Mdot
.3255 .29021 Mdot
.34903 .3255 Mdot
.3608 .34511 Mdot
.36472 .36864 Mdot
.35687 .36864 Mdot
.34119 .36472 Mdot
.34119 .36472 Mdot
.33727 .35687 Mdot
.34511 .35295 Mdot
.3608 .3608 Mdot
.37256 .35687 Mdot
.3608 .34119 Mdot
.31374 .30982 Mdot
.29021 .29413 Mdot
.22747 .23924 Mdot
.11768 .16081 Mdot
.11376 .15689 Mdot
.09807 .1412 Mdot
.07062 .10983 Mdot
.07846 .10199 Mdot
.07846 .09023 Mdot
.08239 .07454 Mdot
.09415 .07454 Mdot
.10591 .07454 Mdot
.10983 .07454 Mdot
.10983 .0667 Mdot
.12944 .07062 Mdot
.13728 .07454 Mdot
.1216 .07062 Mdot
.10983 .05886 Mdot
.10591 .05886 Mdot
.09415 .05494 Mdot
.10983 .0667 Mdot
.08239 .04709 Mdot
.07062 .03533 Mdot
.06278 .03925 Mdot
.0667 .05102 Mdot
.09023 .07062 Mdot
.10199 .07062 Mdot
.10983 .08239 Mdot
.18042 .13728 Mdot
.21179 .17257 Mdot
.31766 .25492 Mdot
.36864 .29413 Mdot
.42746 .34119 Mdot
.45491 .36864 Mdot
.47059 .37648 Mdot
.39609 .31766 Mdot
.26668 .20787 Mdot
.18434 .13336 Mdot
.14905 .10591 Mdot
.14513 .10199 Mdot
.18042 .12944 Mdot
.20787 .15689 Mdot
.22355 .16865 Mdot
.26668 .1961 Mdot
.29021 .21571 Mdot
.30198 .23139 Mdot
.30982 .23924 Mdot
.29806 .21963 Mdot
.30198 .20394 Mdot
.31374 .18826 Mdot
.31374 .1765 Mdot
.30982 .1765 Mdot
.30982 .17257 Mdot
.29021 .16081 Mdot
.27845 .16473 Mdot
.28237 .18434 Mdot
.28237 .20002 Mdot
.27061 .20787 Mdot
.27453 .21571 Mdot
.25884 .20787 Mdot
.26668 .21571 Mdot
.26276 .20787 Mdot
.251 .18826 Mdot
.25492 .17257 Mdot
.25884 .16081 Mdot
.25492 .15297 Mdot
.26668 .15689 Mdot
.251 .15689 Mdot
.25492 .16081 Mdot
.23531 .15689 Mdot
.24316 .16865 Mdot
.23531 .1765 Mdot
.23531 .18042 Mdot
.22747 .17257 Mdot
.23139 .18042 Mdot
.21179 .16473 Mdot
.20787 .15689 Mdot
.21571 .1412 Mdot
.22747 .13728 Mdot
.22747 .12944 Mdot
.22747 .1216 Mdot
.22355 .11376 Mdot
.21179 .10983 Mdot
.21179 .10983 Mdot
.20002 .10983 Mdot
.20002 .11376 Mdot
.18826 .1216 Mdot
.1961 .12944 Mdot
.18434 .1216 Mdot
.1765 .12552 Mdot
.17257 .12944 Mdot
.1765 .1412 Mdot
.18042 .14513 Mdot
.16081 .12552 Mdot
.14513 .11768 Mdot
.83919 .79213 Mdot
.6941 .64313 Mdot
.60391 .53725 Mdot
.55294 .49412 Mdot
.5098 .45098 Mdot
.42746 .36864 Mdot
.3255 .26276 Mdot
.28629 .22747 Mdot
.25884 .20787 Mdot
.22747 .19218 Mdot
.24316 .21179 Mdot
.251 .23139 Mdot
.28629 .27453 Mdot
.32158 .32158 Mdot
.35687 .35687 Mdot
.36472 .36864 Mdot
.36472 .3608 Mdot
.35295 .34903 Mdot
.34511 .34119 Mdot
.34119 .33727 Mdot
.36472 .35687 Mdot
.38432 .36472 Mdot
.38432 .37256 Mdot
.36472 .37256 Mdot
.35295 .37648 Mdot
.22355 .27845 Mdot
.18826 .24708 Mdot
.14513 .1961 Mdot
.10591 .15297 Mdot
.09415 .13728 Mdot
.09023 .10983 Mdot
.08631 .09023 Mdot
.07454 .06278 Mdot
.06278 .04317 Mdot
.09807 .05886 Mdot
.13336 .07454 Mdot
.15689 .07846 Mdot
.17257 .09023 Mdot
.16865 .09023 Mdot
.14905 .07846 Mdot
.13728 .07454 Mdot
.13336 .07454 Mdot
.10983 .05494 Mdot
.09415 .03533 Mdot
.05886 .01965 Mdot
.05494 .02749 Mdot
.0667 .05102 Mdot
.07846 .06278 Mdot
.09023 .08239 Mdot
.07454 .07454 Mdot
.07454 .08631 Mdot
.08631 .10199 Mdot
.15689 .14905 Mdot
.21179 .1961 Mdot
.29806 .25884 Mdot
.37256 .30198 Mdot
.42354 .3255 Mdot
.3804 .28237 Mdot
.41961 .29413 Mdot
.28237 .1961 Mdot
.21963 .15689 Mdot
.16865 .13728 Mdot
.15689 .14905 Mdot
.12944 .13336 Mdot
.15689 .14513 Mdot
.20002 .16473 Mdot
.24316 .1961 Mdot
.27061 .21179 Mdot
.28629 .20394 Mdot
.27845 .18826 Mdot
.28237 .17257 Mdot
.28237 .15689 Mdot
.29413 .16473 Mdot
.28237 .16473 Mdot
.27061 .16081 Mdot
.25884 .15297 Mdot
.25884 .15689 Mdot
.26276 .1765 Mdot
.25884 .18434 Mdot
.251 .18826 Mdot
.25492 .20002 Mdot
.251 .20002 Mdot
.24316 .18826 Mdot
.24708 .18434 Mdot
.251 .1765 Mdot
.25492 .16473 Mdot
.25492 .15297 Mdot
.25884 .15297 Mdot
.27061 .16473 Mdot
.26668 .16865 Mdot
.26276 .17257 Mdot
.25884 .1765 Mdot
.23924 .16865 Mdot
.23531 .17257 Mdot
.24316 .18434 Mdot
.23531 .18826 Mdot
.22747 .1765 Mdot
.20787 .15689 Mdot
.20787 .15689 Mdot
.20394 .14905 Mdot
.20787 .13728 Mdot
.21571 .13728 Mdot
.21963 .12944 Mdot
.22747 .13336 Mdot
.22747 .12944 Mdot
.21571 .1216 Mdot
.20787 .1216 Mdot
.21179 .12552 Mdot
.19218 .1216 Mdot
.18042 .11768 Mdot
.1765 .1216 Mdot
.18042 .12944 Mdot
.1765 .13728 Mdot
.17257 .13728 Mdot
.17257 .13728 Mdot
.16081 .1216 Mdot
.14905 .10983 Mdot
.9333 .91761 Mdot
.85095 .81958 Mdot
.6941 .63528 Mdot
.60783 .54902 Mdot
.57646 .49412 Mdot
.33727 .28629 Mdot
.25492 .21571 Mdot
.22747 .1961 Mdot
.19218 .16865 Mdot
.1765 .15689 Mdot
.16865 .16081 Mdot
.21179 .20002 Mdot
.30982 .28629 Mdot
.33335 .31374 Mdot
.3608 .34903 Mdot
.37648 .3608 Mdot
.37256 .3608 Mdot
.35687 .35687 Mdot
.35687 .35687 Mdot
.36472 .3608 Mdot
.3804 .36864 Mdot
.3804 .36472 Mdot
.38824 .38432 Mdot
.38432 .38824 Mdot
.3608 .37648 Mdot
.26668 .29413 Mdot
.22747 .251 Mdot
.16865 .20002 Mdot
.11768 .1412 Mdot
.08631 .10199 Mdot
.07062 .07062 Mdot
.06278 .04317 Mdot
.10199 .05494 Mdot
.13728 .0667 Mdot
.18434 .09415 Mdot
.21571 .12944 Mdot
.22747 .13336 Mdot
.20394 .10983 Mdot
.16081 .07846 Mdot
.13336 .05886 Mdot
.10591 .03925 Mdot
.08631 .02357 Mdot
.07846 .01965 Mdot
.0667 .02749 Mdot
.07454 .04317 Mdot
.09415 .05886 Mdot
.10983 .07062 Mdot
.11376 .09415 Mdot
.1216 .10983 Mdot
.11768 .10983 Mdot
.10983 .10591 Mdot
.13336 .13336 Mdot
.21179 .19218 Mdot
.28237 .23924 Mdot
.36864 .28629 Mdot
.15689 .11768 Mdot
.18434 .12552 Mdot
.20002 .13728 Mdot
.31766 .22355 Mdot
.40001 .29413 Mdot
.36864 .28237 Mdot
.33727 .27061 Mdot
.29413 .23531 Mdot
.251 .20394 Mdot
.24316 .20002 Mdot
.25884 .20787 Mdot
.27061 .21179 Mdot
.27061 .20394 Mdot
.26276 .18434 Mdot
.26668 .16865 Mdot
.26276 .15689 Mdot
.27061 .16081 Mdot
.251 .15689 Mdot
.24708 .15297 Mdot
.24708 .16081 Mdot
.23924 .16081 Mdot
.23531 .15689 Mdot
.23924 .16081 Mdot
.24708 .18042 Mdot
.24708 .18826 Mdot
.23531 .18042 Mdot
.22747 .16865 Mdot
.22747 .16081 Mdot
.24316 .16865 Mdot
.25492 .18434 Mdot
.251 .1765 Mdot
.24708 .17257 Mdot
.25492 .1765 Mdot
.24708 .1765 Mdot
.251 .18042 Mdot
.251 .16865 Mdot
.23924 .15689 Mdot
.24316 .16081 Mdot
.23924 .16473 Mdot
.22355 .15297 Mdot
.20787 .14905 Mdot
.20394 .14905 Mdot
.20002 .14513 Mdot
.20002 .14513 Mdot
.20002 .14905 Mdot
.20394 .15297 Mdot
.20394 .15297 Mdot
.20787 .14905 Mdot
.21179 .1412 Mdot
.20787 .13728 Mdot
.20394 .12944 Mdot
.19218 .11768 Mdot
.18826 .1216 Mdot
.18434 .11376 Mdot
.18826 .10983 Mdot
.17257 .10199 Mdot
.18434 .11376 Mdot
.18434 .1216 Mdot
.18042 .10983 Mdot
.17257 .10591 Mdot
.92938 .91761 Mdot
.84703 .81566 Mdot
.52941 .48628 Mdot
.3059 .30198 Mdot
.26668 .24708 Mdot
.23531 .20394 Mdot
.20002 .16473 Mdot
.1765 .13728 Mdot
.15689 .12552 Mdot
.15689 .13728 Mdot
.23139 .20394 Mdot
.27061 .251 Mdot
.30982 .29413 Mdot
.34511 .3255 Mdot
.36864 .35295 Mdot
.39217 .36472 Mdot
.41177 .3804 Mdot
.38824 .3608 Mdot
.36864 .34119 Mdot
.3804 .35295 Mdot
.37256 .35295 Mdot
.38432 .36864 Mdot
.3804 .37256 Mdot
.37256 .3608 Mdot
.34119 .33335 Mdot
.25884 .25884 Mdot
.1412 .15297 Mdot
.09415 .09415 Mdot
.07454 .05886 Mdot
.11376 .0667 Mdot
.14905 .08631 Mdot
.16865 .09415 Mdot
.1961 .10591 Mdot
.21963 .12944 Mdot
.20394 .11376 Mdot
.16865 .08239 Mdot
.12552 .05886 Mdot
.08631 .03925 Mdot
.06278 .02357 Mdot
.05494 .02749 Mdot
.07062 .03925 Mdot
.07454 .05494 Mdot
.16865 .12552 Mdot
.13336 .09415 Mdot
.10983 .07062 Mdot
.34903 .23924 Mdot
.30198 .20394 Mdot
.15297 .12552 Mdot
.29413 .251 Mdot
.25884 .22355 Mdot
.23139 .20394 Mdot
.20394 .1765 Mdot
.16081 .12944 Mdot
.09807 .07454 Mdot
.07454 .05102 Mdot
.05886 .03533 Mdot
.26276 .18826 Mdot
.58039 .43922 Mdot
.58039 .45098 Mdot
.5647 .44706 Mdot
.37256 .31766 Mdot
.35295 .3059 Mdot
.32943 .29021 Mdot
.30982 .26276 Mdot
.29413 .24316 Mdot
.27845 .21963 Mdot
.27845 .1961 Mdot
.27453 .1765 Mdot
.28629 .17257 Mdot
.27845 .16865 Mdot
.26668 .16473 Mdot
.26276 .16081 Mdot
.24708 .14513 Mdot
.24708 .14905 Mdot
.23531 .15297 Mdot
.23139 .15689 Mdot
.24316 .16865 Mdot
.23531 .17257 Mdot
.21571 .16081 Mdot
.21963 .16081 Mdot
.22355 .16865 Mdot
.21963 .17257 Mdot
.22747 .18042 Mdot
.23139 .18042 Mdot
.23924 .18826 Mdot
.23531 .18042 Mdot
.23531 .16865 Mdot
.23924 .15689 Mdot
.24708 .14905 Mdot
.24316 .1412 Mdot
.23531 .13336 Mdot
.21963 .1216 Mdot
.21179 .12944 Mdot
.20787 .13336 Mdot
.20002 .12944 Mdot
.20002 .13336 Mdot
.1961 .1412 Mdot
.19218 .14905 Mdot
.19218 .15297 Mdot
.20394 .15689 Mdot
.20787 .14513 Mdot
.20787 .1412 Mdot
.21179 .12944 Mdot
.21179 .1216 Mdot
.20002 .11768 Mdot
.1961 .10983 Mdot
.19218 .09415 Mdot
.18826 .09023 Mdot
.18042 .09415 Mdot
.1765 .09807 Mdot
.17257 .09807 Mdot
.16865 .09807 Mdot
.76076 .74116 Mdot
.57254 .54117 Mdot
.3059 .27845 Mdot
.23924 .20394 Mdot
.23139 .17257 Mdot
.20002 .14905 Mdot
.20787 .16473 Mdot
.19218 .16865 Mdot
.18826 .18434 Mdot
.18826 .18826 Mdot
.20002 .20002 Mdot
.28237 .25884 Mdot
.34119 .3059 Mdot
.3804 .33335 Mdot
.38824 .34119 Mdot
.39609 .34119 Mdot
.38432 .33335 Mdot
.36472 .3255 Mdot
.37256 .33335 Mdot
.39609 .34903 Mdot
.38824 .35687 Mdot
.3804 .35687 Mdot
.39609 .3608 Mdot
.27061 .251 Mdot
.1216 .1216 Mdot
.1216 .10199 Mdot
.11376 .08239 Mdot
.11768 .07846 Mdot
.12552 .07062 Mdot
.13336 .07062 Mdot
.1412 .07454 Mdot
.14513 .08631 Mdot
.16081 .09415 Mdot
.13336 .07454 Mdot
.08239 .05102 Mdot
.0667 .05494 Mdot
.06278 .05886 Mdot
.05494 .05494 Mdot
.06278 .06278 Mdot
.1412 .1216 Mdot
.07454 .07454 Mdot
.20002 .18042 Mdot
.78429 .6196 Mdot
.77253 .62744 Mdot
.48628 .41569 Mdot
.32158 .28629 Mdot
.31374 .27061 Mdot
.13728 .12552 Mdot
.1216 .10591 Mdot
.08631 .07454 Mdot
.09415 .07454 Mdot
.07062 .05886 Mdot
.06278 .05494 Mdot
.07062 .0667 Mdot
.54902 .42746 Mdot
.67842 .54117 Mdot
.62744 .5098 Mdot
.59607 .49804 Mdot
.47843 .42354 Mdot
.46275 .40785 Mdot
.44706 .3804 Mdot
.43922 .3608 Mdot
.40393 .33727 Mdot
.3804 .30198 Mdot
.36864 .27453 Mdot
.34511 .251 Mdot
.32158 .22747 Mdot
.30982 .21963 Mdot
.29413 .21179 Mdot
.27845 .1961 Mdot
.26276 .18434 Mdot
.24708 .16865 Mdot
.23531 .16865 Mdot
.23139 .17257 Mdot
.22747 .16473 Mdot
.21571 .16865 Mdot
.21179 .16473 Mdot
.20787 .16081 Mdot
.21571 .16473 Mdot
.20787 .15689 Mdot
.20394 .16081 Mdot
.21179 .16081 Mdot
.20787 .15297 Mdot
.20002 .1412 Mdot
.21571 .14905 Mdot
.20787 .1412 Mdot
.20787 .1412 Mdot
.21963 .1412 Mdot
.21963 .12944 Mdot
.21571 .1216 Mdot
.20394 .11768 Mdot
.20002 .1216 Mdot
.1961 .12552 Mdot
.1961 .12944 Mdot
.19218 .12944 Mdot
.20394 .14513 Mdot
.20394 .14513 Mdot
.20787 .1412 Mdot
.1961 .12552 Mdot
.20394 .12552 Mdot
.1961 .10983 Mdot
.1961 .11376 Mdot
.1961 .10591 Mdot
.1961 .10199 Mdot
.18042 .09415 Mdot
.16865 .09023 Mdot
.17257 .10199 Mdot
.17257 .11376 Mdot
.16473 .10591 Mdot
.6392 .63136 Mdot
.53333 .49804 Mdot
.38824 .34119 Mdot
.3059 .27453 Mdot
.251 .23924 Mdot
.23139 .22355 Mdot
.20002 .19218 Mdot
.16865 .15689 Mdot
.14905 .13728 Mdot
.16473 .14513 Mdot
.26668 .21571 Mdot
.3059 .25492 Mdot
.37648 .3059 Mdot
.38824 .31766 Mdot
.39609 .3255 Mdot
.33727 .28629 Mdot
.38432 .31374 Mdot
.34903 .28237 Mdot
.34119 .28237 Mdot
.34119 .28237 Mdot
.36472 .29806 Mdot
.26668 .21571 Mdot
.17257 .12944 Mdot
.14905 .09415 Mdot
.12944 .07846 Mdot
.10983 .05494 Mdot
.10591 .05494 Mdot
.10199 .05102 Mdot
.11376 .07062 Mdot
.12944 .09415 Mdot
.12552 .09023 Mdot
.09807 .07062 Mdot
.07454 .05102 Mdot
.07454 .05102 Mdot
.07454 .06278 Mdot
.06278 .05886 Mdot
.08239 .07846 Mdot
.10983 .10591 Mdot
.11376 .1216 Mdot
.44314 .37648 Mdot
.56078 .47059 Mdot
.82743 .66665 Mdot
.4902 .39609 Mdot
.22355 .17257 Mdot
.16473 .11376 Mdot
.1216 .08239 Mdot
.08239 .05102 Mdot
.05494 .04317 Mdot
.06278 .05494 Mdot
.06278 .06278 Mdot
.05494 .05494 Mdot
.23924 .20002 Mdot
.6941 .55686 Mdot
.62352 .5098 Mdot
.61176 .50588 Mdot
.55294 .45883 Mdot
.37256 .3255 Mdot
.40001 .33335 Mdot
.42746 .35687 Mdot
.48235 .40785 Mdot
.56078 .47451 Mdot
.58039 .48235 Mdot
.56078 .46275 Mdot
.52941 .42746 Mdot
.45491 .3608 Mdot
.40393 .3255 Mdot
.37648 .31766 Mdot
.35687 .31766 Mdot
.32943 .29021 Mdot
.3059 .26276 Mdot
.26668 .21963 Mdot
.251 .20787 Mdot
.23531 .20394 Mdot
.22355 .19218 Mdot
.22355 .18826 Mdot
.23139 .18042 Mdot
.21963 .16865 Mdot
.21963 .16081 Mdot
.21963 .15689 Mdot
.21571 .16081 Mdot
.20787 .16081 Mdot
.20002 .15689 Mdot
.20787 .16081 Mdot
.20002 .15297 Mdot
.20002 .14513 Mdot
.21179 .13728 Mdot
.21179 .1216 Mdot
.19218 .10199 Mdot
.20394 .11376 Mdot
.19218 .10983 Mdot
.18826 .11768 Mdot
.18826 .1216 Mdot
.18826 .1216 Mdot
.19218 .13336 Mdot
.18042 .1216 Mdot
.18826 .1216 Mdot
.17257 .10591 Mdot
.18042 .10591 Mdot
.16865 .09807 Mdot
.17257 .10199 Mdot
.16473 .10591 Mdot
.16081 .09807 Mdot
.15297 .09415 Mdot
.17257 .11768 Mdot
.16865 .12552 Mdot
.16081 .11768 Mdot
.92154 .90193 Mdot
.749 .72939 Mdot
.41177 .38432 Mdot
.35295 .32943 Mdot
.18826 .1961 Mdot
.18434 .18042 Mdot
.16081 .15689 Mdot
.1412 .13336 Mdot
.15689 .13336 Mdot
.18826 .15297 Mdot
.23531 .18042 Mdot
.29806 .22747 Mdot
.30198 .22747 Mdot
.22747 .18042 Mdot
.24708 .18826 Mdot
.22747 .16473 Mdot
.20787 .14513 Mdot
.22355 .15689 Mdot
.27453 .19218 Mdot
.30198 .20394 Mdot
.19218 .12552 Mdot
.19218 .12944 Mdot
.15689 .09807 Mdot
.12944 .08239 Mdot
.10199 .06278 Mdot
.09415 .05886 Mdot
.11376 .08239 Mdot
.13728 .10983 Mdot
.13336 .10983 Mdot
.08631 .07454 Mdot
.08239 .06278 Mdot
.08631 .06278 Mdot
.08631 .06278 Mdot
.07846 .06278 Mdot
.1216 .10591 Mdot
.13336 .12944 Mdot
.14905 .13728 Mdot
.14905 .1412 Mdot
.21963 .20002 Mdot
.47059 .39217 Mdot
.46275 .3804 Mdot
.27845 .22355 Mdot
.1216 .09023 Mdot
.14513 .10199 Mdot
.05494 .04317 Mdot
.04709 .03925 Mdot
.03141 .04317 Mdot
.02357 .04709 Mdot
.04317 .0667 Mdot
.31374 .28237 Mdot
.59607 .50588 Mdot
.62744 .53725 Mdot
.58823 .49804 Mdot
.61176 .50196 Mdot
.54509 .44706 Mdot
.46667 .38824 Mdot
.38432 .33335 Mdot
.40001 .34511 Mdot
.61176 .5098 Mdot
.59607 .49412 Mdot
.61176 .50196 Mdot
.6392 .52157 Mdot
.58431 .47059 Mdot
.39609 .33335 Mdot
.41569 .36864 Mdot
.45491 .41177 Mdot
.46667 .42354 Mdot
.45098 .40785 Mdot
.42746 .37256 Mdot
.39609 .34511 Mdot
.36472 .32158 Mdot
.32158 .29021 Mdot
.29806 .27845 Mdot
.27845 .24708 Mdot
.27453 .23139 Mdot
.26668 .21963 Mdot
.26276 .20787 Mdot
.251 .20394 Mdot
.22747 .19218 Mdot
.20002 .17257 Mdot
.20002 .16473 Mdot
.1961 .15297 Mdot
.18826 .13728 Mdot
.18826 .11768 Mdot
.1961 .11376 Mdot
.18826 .10591 Mdot
.1961 .10983 Mdot
.20394 .11376 Mdot
.20002 .1216 Mdot
.17257 .10591 Mdot
.15297 .08631 Mdot
.12552 .07454 Mdot
.11376 .06278 Mdot
.1216 .07062 Mdot
.12944 .07846 Mdot
.13728 .08239 Mdot
.16081 .09807 Mdot
.17257 .10983 Mdot
.16473 .11376 Mdot
.15297 .10591 Mdot
.15689 .11376 Mdot
.15689 .11376 Mdot
.15297 .11768 Mdot
.16081 .1216 Mdot
.85095 .84703 Mdot
.60391 .61176 Mdot
.20394 .20394 Mdot
.21571 .20002 Mdot
.20394 .18042 Mdot
.1961 .16473 Mdot
.20394 .15689 Mdot
.20787 .14905 Mdot
.18826 .12944 Mdot
.18042 .11768 Mdot
.16081 .10983 Mdot
.14513 .09807 Mdot
.13336 .08239 Mdot
.14905 .08631 Mdot
.16081 .09415 Mdot
.20787 .12552 Mdot
.23531 .14905 Mdot
.20787 .13728 Mdot
.18434 .12552 Mdot
.14905 .10983 Mdot
.1216 .09807 Mdot
.10983 .09415 Mdot
.10983 .09023 Mdot
.12552 .11376 Mdot
.14513 .13336 Mdot
.12944 .11376 Mdot
.11768 .09807 Mdot
.09807 .08239 Mdot
.10591 .07846 Mdot
.10591 .07062 Mdot
.09023 .06278 Mdot
.08239 .0667 Mdot
.1412 .11376 Mdot
.19218 .14905 Mdot
.22747 .1765 Mdot
.24708 .1961 Mdot
.29806 .23531 Mdot
.32158 .251 Mdot
.29413 .22747 Mdot
.11768 .09023 Mdot
.13728 .10983 Mdot
.09807 .09023 Mdot
.07062 .07846 Mdot
.05494 .07846 Mdot
.04317 .07454 Mdot
.04317 .07454 Mdot
.22355 .22747 Mdot
.48235 .43138 Mdot
.51765 .45491 Mdot
.57254 .48235 Mdot
.59215 .48628 Mdot
.61176 .49804 Mdot
.61176 .49804 Mdot
.56862 .47059 Mdot
.54509 .45098 Mdot
.56078 .45883 Mdot
.58431 .47451 Mdot
.58823 .48235 Mdot
.58039 .47843 Mdot
.64705 .54117 Mdot
.57646 .49804 Mdot
.3608 .34119 Mdot
.37256 .34511 Mdot
.33727 .31766 Mdot
.50196 .43138 Mdot
.58431 .4902 Mdot
.40393 .36472 Mdot
.38432 .35687 Mdot
.39609 .36864 Mdot
.42746 .39217 Mdot
.43922 .40001 Mdot
.44314 .40001 Mdot
.4353 .3804 Mdot
.41177 .34903 Mdot
.38432 .32158 Mdot
.33727 .28237 Mdot
.29021 .24708 Mdot
.22747 .1961 Mdot
.20787 .17257 Mdot
.21179 .16081 Mdot
.20394 .13728 Mdot
.18434 .11768 Mdot
.19218 .11768 Mdot
.1961 .1216 Mdot
.18826 .1216 Mdot
.18434 .12552 Mdot
.14513 .09415 Mdot
.10983 .06278 Mdot
.07454 .03141 Mdot
.04709 .01572 Mdot
.03141 .00788 Mdot
.04317 .01965 Mdot
.04709 .01965 Mdot
.10983 .05886 Mdot
.13728 .07846 Mdot
.15297 .09415 Mdot
.15297 .09807 Mdot
.14905 .10983 Mdot
.15297 .11376 Mdot
.1412 .10591 Mdot
.13728 .09807 Mdot
.65097 .63528 Mdot
.56862 .50588 Mdot
.31374 .251 Mdot
.30198 .23139 Mdot
.27845 .20787 Mdot
.24708 .18434 Mdot
.18826 .13728 Mdot
.1765 .13336 Mdot
.16081 .11768 Mdot
.15297 .10591 Mdot
.15689 .09415 Mdot
.16473 .09807 Mdot
.19218 .12552 Mdot
.23924 .17257 Mdot
.23139 .1765 Mdot
.19218 .15689 Mdot
.15689 .13336 Mdot
.13728 .11768 Mdot
.11768 .10199 Mdot
.12552 .10983 Mdot
.15297 .1412 Mdot
.16865 .15297 Mdot
.15297 .13336 Mdot
.14905 .12552 Mdot
.12944 .10983 Mdot
.11376 .10199 Mdot
.11768 .09023 Mdot
.07846 .05494 Mdot
.0667 .05102 Mdot
.07454 .05494 Mdot
.10591 .07062 Mdot
.1765 .1216 Mdot
.23139 .16081 Mdot
.32158 .22747 Mdot
.30982 .21571 Mdot
.24316 .16473 Mdot
.1961 .13336 Mdot
.15689 .11376 Mdot
.12944 .10591 Mdot
.11376 .09807 Mdot
.10591 .10591 Mdot
.09415 .09415 Mdot
.10199 .10199 Mdot
.09807 .09807 Mdot
.1765 .16081 Mdot
.28237 .23924 Mdot
.33335 .28237 Mdot
.40001 .32943 Mdot
.67842 .55294 Mdot
.64313 .53725 Mdot
.64705 .53725 Mdot
.64313 .52941 Mdot
.62744 .51372 Mdot
.62352 .5098 Mdot
.6196 .51372 Mdot
.59999 .5098 Mdot
.59999 .51765 Mdot
.60783 .52549 Mdot
.53725 .47451 Mdot
.47843 .42746 Mdot
.43138 .38432 Mdot
.42746 .37256 Mdot
.71371 .59215 Mdot
.6392 .53725 Mdot
.40001 .3608 Mdot
.40393 .36472 Mdot
.36864 .33727 Mdot
.3608 .32943 Mdot
.49412 .42746 Mdot
.54117 .46275 Mdot
.56078 .47059 Mdot
.5647 .47059 Mdot
.54509 .45098 Mdot
.47843 .40001 Mdot
.43138 .3608 Mdot
.40393 .33727 Mdot
.3608 .29413 Mdot
.32158 .25492 Mdot
.30198 .23139 Mdot
.27845 .20394 Mdot
.24708 .17257 Mdot
.21963 .16473 Mdot
.20787 .16473 Mdot
.17257 .13728 Mdot
.10591 .07062 Mdot
.0667 .03533 Mdot
.04709 .01965 Mdot
.02749 .00396 Mdot
.02749 .00788 Mdot
.01965 .00396 Mdot
.01572 .00396 Mdot
.04317 .01965 Mdot
.0667 .02357 Mdot
.09807 .04317 Mdot
.12944 .07454 Mdot
.15297 .09023 Mdot
.16081 .09807 Mdot
.1765 .11376 Mdot
.76861 .72939 Mdot
.6196 .56078 Mdot
.3608 .29806 Mdot
.26276 .20394 Mdot
.26668 .1961 Mdot
.24316 .16865 Mdot
.24708 .16473 Mdot
.22747 .13728 Mdot
.22355 .13336 Mdot
.21571 .14905 Mdot
.23139 .1765 Mdot
.23531 .18826 Mdot
.21571 .1765 Mdot
.1765 .14513 Mdot
.14905 .1216 Mdot
.1216 .09807 Mdot
.1216 .09807 Mdot
.1412 .11768 Mdot
.16081 .13336 Mdot
.18042 .15689 Mdot
.19218 .16473 Mdot
.18434 .16473 Mdot
.13728 .13728 Mdot
.11376 .10591 Mdot
.07062 .06278 Mdot
.07062 .05494 Mdot
.0667 .05102 Mdot
.08239 .05886 Mdot
.10199 .07454 Mdot
.16473 .11376 Mdot
.18434 .1216 Mdot
.18826 .1216 Mdot
.1961 .12552 Mdot
.16473 .09807 Mdot
.13336 .08239 Mdot
.11768 .09415 Mdot
.09807 .09807 Mdot
.1216 .12552 Mdot
.10591 .11768 Mdot
.26276 .23924 Mdot
.24316 .22747 Mdot
.28237 .251 Mdot
.30982 .27061 Mdot
.32158 .27453 Mdot
.26276 .23531 Mdot
.40785 .3608 Mdot
.67057 .57254 Mdot
.59215 .51372 Mdot
.6392 .54509 Mdot
.59999 .5098 Mdot
.63136 .53725 Mdot
.63136 .53725 Mdot
.62352 .53725 Mdot
.63136 .54509 Mdot
.62744 .54117 Mdot
.60783 .52157 Mdot
.59607 .50196 Mdot
.57646 .47451 Mdot
.56078 .46275 Mdot
.55294 .45098 Mdot
.57646 .47059 Mdot
.55686 .46667 Mdot
.55294 .45883 Mdot
.5098 .42354 Mdot
.4902 .41569 Mdot
.48628 .41961 Mdot
.52157 .44706 Mdot
.53333 .46275 Mdot
.54902 .47059 Mdot
.55686 .47059 Mdot
.55294 .46667 Mdot
.55294 .46275 Mdot
.56078 .46275 Mdot
.54902 .45491 Mdot
.51372 .44314 Mdot
.4902 .42746 Mdot
.47843 .41569 Mdot
.44706 .38824 Mdot
.40393 .35687 Mdot
.33727 .29413 Mdot
.1765 .16081 Mdot
.13728 .11376 Mdot
.10199 .07846 Mdot
.04709 .02749 Mdot
.03141 .0118 Mdot
.01965 .00788 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.0118 .00396 Mdot
.01572 .00396 Mdot
.09415 .03533 Mdot
.14513 .07062 Mdot
.16081 .08239 Mdot
.16473 .09807 Mdot
.89017 .87056 Mdot
.62352 .6196 Mdot
.3804 .33727 Mdot
.46667 .3804 Mdot
.47451 .37648 Mdot
.3804 .29806 Mdot
.33727 .26276 Mdot
.29413 .23531 Mdot
.27845 .22747 Mdot
.26276 .21571 Mdot
.20394 .17257 Mdot
.18434 .15297 Mdot
.16473 .12944 Mdot
.14513 .11768 Mdot
.12552 .09807 Mdot
.12552 .09807 Mdot
.14513 .10983 Mdot
.15297 .12552 Mdot
.1765 .14513 Mdot
.18434 .15689 Mdot
.14513 .13336 Mdot
.11768 .11376 Mdot
.09023 .09023 Mdot
.07846 .07846 Mdot
.08239 .07454 Mdot
.08631 .07454 Mdot
.10983 .09023 Mdot
.13336 .10199 Mdot
.16865 .1216 Mdot
.18434 .12552 Mdot
.19218 .1216 Mdot
.14905 .08631 Mdot
.12552 .07846 Mdot
.10199 .08631 Mdot
.09415 .09023 Mdot
.08631 .09807 Mdot
.12552 .14513 Mdot
.26668 .26668 Mdot
.46667 .41961 Mdot
.46667 .41177 Mdot
.47059 .40785 Mdot
.47843 .39609 Mdot
.41177 .34511 Mdot
.27845 .25884 Mdot
.85095 .70587 Mdot
.52549 .46275 Mdot
.53333 .47059 Mdot
.40393 .36472 Mdot
.41569 .36864 Mdot
.56078 .47451 Mdot
.59215 .50196 Mdot
.61176 .51765 Mdot
.63136 .54117 Mdot
.61568 .52941 Mdot
.6392 .53725 Mdot
.38824 .34119 Mdot
.46275 .38432 Mdot
.58431 .47059 Mdot
.54509 .43922 Mdot
.54117 .45491 Mdot
.56862 .48235 Mdot
.58823 .50196 Mdot
.59215 .50196 Mdot
.58823 .4902 Mdot
.54509 .45491 Mdot
.53333 .45883 Mdot
.51765 .45883 Mdot
.51372 .46275 Mdot
.5098 .46275 Mdot
.51765 .45883 Mdot
.52549 .45098 Mdot
.52549 .45098 Mdot
.51765 .45098 Mdot
.52157 .44706 Mdot
.52157 .45098 Mdot
.52157 .45491 Mdot
.52549 .45098 Mdot
.55686 .46667 Mdot
.25492 .23924 Mdot
.08239 .09415 Mdot
.05494 .05102 Mdot
.00788 .00788 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.00788 .00396 Mdot
.0118 .00396 Mdot
.02357 .00396 Mdot
.05102 .0118 Mdot
.07454 .01965 Mdot
.10983 .04317 Mdot
.16081 .08239 Mdot
.16865 .09415 Mdot
.91369 .89409 Mdot
.78037 .70194 Mdot
.65097 .56078 Mdot
.56862 .48628 Mdot
.48628 .41177 Mdot
.34119 .29806 Mdot
.31374 .27061 Mdot
.25884 .21571 Mdot
.21179 .17257 Mdot
.20002 .16081 Mdot
.16865 .13336 Mdot
.15297 .1216 Mdot
.15689 .11768 Mdot
.17257 .12944 Mdot
.17257 .13728 Mdot
.16473 .12944 Mdot
.13728 .11768 Mdot
.1216 .10591 Mdot
.09807 .09807 Mdot
.09807 .10199 Mdot
.08239 .09023 Mdot
.10199 .09807 Mdot
.13336 .10983 Mdot
.16473 .12552 Mdot
.17257 .12944 Mdot
.19218 .14513 Mdot
.1961 .14905 Mdot
.21179 .15689 Mdot
.19218 .12552 Mdot
.16081 .10591 Mdot
.14513 .11768 Mdot
.12944 .10983 Mdot
.11376 .10983 Mdot
.09807 .11376 Mdot
.36864 .32943 Mdot
.78037 .63528 Mdot
.55294 .45098 Mdot
.40001 .3255 Mdot
.38824 .3059 Mdot
.27845 .23139 Mdot
.29806 .25884 Mdot
.60783 .50588 Mdot
.51372 .43922 Mdot
.54509 .45883 Mdot
.44314 .37648 Mdot
.41569 .34511 Mdot
.51765 .42354 Mdot
.57646 .47843 Mdot
.59607 .49804 Mdot
.60783 .51765 Mdot
.61176 .52549 Mdot
.64313 .54117 Mdot
.27845 .26276 Mdot
.32943 .29806 Mdot
.74116 .59999 Mdot
.251 .23531 Mdot
.40393 .36864 Mdot
.68626 .58823 Mdot
.5098 .45098 Mdot
.50196 .44314 Mdot
.53725 .46667 Mdot
.54902 .47843 Mdot
.52157 .46275 Mdot
.50196 .45491 Mdot
.50588 .47059 Mdot
.49412 .47451 Mdot
.5098 .47843 Mdot
.51372 .46667 Mdot
.51765 .45491 Mdot
.5098 .44314 Mdot
.5098 .4353 Mdot
.48628 .40785 Mdot
.48235 .40393 Mdot
.48235 .39609 Mdot
.47843 .39217 Mdot
.21179 .1961 Mdot
.04709 .0667 Mdot
.0118 .02357 Mdot
.0118 .01572 Mdot
.00788 .00788 Mdot
.00788 .0118 Mdot
.00396 .00788 Mdot
.00788 .00396 Mdot
.01572 .00396 Mdot
.04317 .0118 Mdot
.10983 .05886 Mdot
.12944 .07062 Mdot
.15297 .09023 Mdot
.16473 .09023 Mdot
.16473 .09023 Mdot
.8784 .81174 Mdot
.77253 .67842 Mdot
.58431 .48235 Mdot
.53333 .44706 Mdot
.32943 .28237 Mdot
.27845 .21179 Mdot
.25884 .18434 Mdot
.23924 .16865 Mdot
.20394 .14905 Mdot
.19218 .1412 Mdot
.18042 .12944 Mdot
.1765 .12552 Mdot
.16081 .11768 Mdot
.13336 .10591 Mdot
.12552 .10199 Mdot
.11768 .09415 Mdot
.10591 .09415 Mdot
.10591 .09415 Mdot
.1216 .10983 Mdot
.14905 .12944 Mdot
.1961 .15297 Mdot
.20002 .15297 Mdot
.21179 .16081 Mdot
.20394 .16473 Mdot
.20394 .15689 Mdot
.20787 .15689 Mdot
.1961 .14905 Mdot
.19218 .14905 Mdot
.16081 .12552 Mdot
.10983 .08239 Mdot
.10199 .07454 Mdot
.09415 .0667 Mdot
.28629 .21179 Mdot
.39609 .29021 Mdot
.24708 .18434 Mdot
.24708 .18434 Mdot
.20002 .15689 Mdot
.19218 .15297 Mdot
.18826 .15689 Mdot
.16473 .13728 Mdot
.53725 .41569 Mdot
.46667 .3608 Mdot
.45883 .3608 Mdot
.49804 .40393 Mdot
.52549 .4353 Mdot
.54117 .45098 Mdot
.55294 .47059 Mdot
.5647 .4902 Mdot
.58823 .50588 Mdot
.48235 .42354 Mdot
.5098 .43138 Mdot
.67057 .54902 Mdot
.251 .24708 Mdot
.31766 .30982 Mdot
.72939 .62352 Mdot
.62744 .54117 Mdot
.46667 .41569 Mdot
.59607 .5098 Mdot
.52549 .46275 Mdot
.27453 .27453 Mdot
.36472 .35295 Mdot
.51765 .4902 Mdot
.48628 .47059 Mdot
.47451 .45098 Mdot
.49412 .45098 Mdot
.50588 .44314 Mdot
.50196 .4353 Mdot
.52157 .43138 Mdot
.50196 .40785 Mdot
.48628 .39609 Mdot
.43922 .35687 Mdot
.34511 .28237 Mdot
.20394 .1765 Mdot
.07062 .07454 Mdot
.04709 .05102 Mdot
.03141 .03925 Mdot
.01572 .02357 Mdot
.01965 .01965 Mdot
.00788 .00788 Mdot
.01572 .00788 Mdot
.04317 .02749 Mdot
.07454 .05102 Mdot
.14905 .09807 Mdot
.18042 .11376 Mdot
.18826 .12552 Mdot
.1961 .12944 Mdot
.20002 .12944 Mdot
.8588 .78429 Mdot
.6196 .48235 Mdot
.31374 .22747 Mdot
.34903 .251 Mdot
.31766 .23531 Mdot
.29413 .22747 Mdot
.27453 .21571 Mdot
.24708 .1961 Mdot
.21571 .1765 Mdot
.18042 .14513 Mdot
.15297 .11768 Mdot
.14513 .10983 Mdot
.13728 .10199 Mdot
.12944 .09807 Mdot
.12552 .09415 Mdot
.13728 .10591 Mdot
.17257 .12944 Mdot
.20787 .15689 Mdot
.22355 .16865 Mdot
.23139 .18042 Mdot
.21963 .17257 Mdot
.21963 .1765 Mdot
.20394 .16473 Mdot
.18826 .14905 Mdot
.1765 .1412 Mdot
.1961 .16081 Mdot
.16081 .12944 Mdot
.12552 .09807 Mdot
.11376 .09023 Mdot
.09415 .07846 Mdot
.09807 .07454 Mdot
.11768 .09023 Mdot
.10983 .08631 Mdot
.10983 .09023 Mdot
.13728 .11376 Mdot
.14905 .1216 Mdot
.11768 .09807 Mdot
.27453 .21179 Mdot
.42354 .31374 Mdot
.45883 .34903 Mdot
.61568 .47059 Mdot
.4902 .38432 Mdot
.38432 .3059 Mdot
.31374 .27061 Mdot
.38824 .35687 Mdot
.45883 .41961 Mdot
.52941 .46667 Mdot
.52941 .45883 Mdot
.55686 .47451 Mdot
.4902 .43922 Mdot
.48628 .43922 Mdot
.56862 .4902 Mdot
.68234 .57254 Mdot
.62744 .52157 Mdot
.61176 .51765 Mdot
.4353 .38824 Mdot
.13728 .18042 Mdot
.1765 .21963 Mdot
.65097 .57254 Mdot
.3608 .3608 Mdot
.27061 .29021 Mdot
.44314 .40393 Mdot
.53725 .45491 Mdot
.38824 .33727 Mdot
.34903 .29806 Mdot
.4353 .34903 Mdot
.46667 .37648 Mdot
.45491 .36472 Mdot
.35295 .28237 Mdot
.1765 .15297 Mdot
.10983 .10199 Mdot
.06278 .06278 Mdot
.03141 .03925 Mdot
.02357 .03141 Mdot
.01965 .01965 Mdot
.01572 .0118 Mdot
.00788 .00788 Mdot
.13728 .09023 Mdot
.18826 .12944 Mdot
.1961 .12944 Mdot
.20002 .12944 Mdot
.19218 .13728 Mdot
.17257 .12944 Mdot
.17257 .12552 Mdot
.8784 .85095 Mdot
.72547 .68234 Mdot
.57646 .47059 Mdot
.61176 .48235 Mdot
.51765 .40785 Mdot
.3608 .29413 Mdot
.251 .21963 Mdot
.23139 .1961 Mdot
.18434 .14513 Mdot
.18042 .12944 Mdot
.17257 .1216 Mdot
.16473 .1216 Mdot
.16081 .11376 Mdot
.15689 .11768 Mdot
.17257 .1412 Mdot
.21571 .17257 Mdot
.25492 .1961 Mdot
.26668 .21179 Mdot
.251 .20787 Mdot
.22747 .1961 Mdot
.20002 .16865 Mdot
.18042 .15689 Mdot
.16473 .14513 Mdot
.14905 .13336 Mdot
.16473 .13336 Mdot
.14905 .11376 Mdot
.13728 .09807 Mdot
.11376 .07846 Mdot
.12552 .09415 Mdot
.10591 .07846 Mdot
.08631 .06278 Mdot
.10983 .07846 Mdot
.12944 .09415 Mdot
.14513 .11376 Mdot
.13336 .11376 Mdot
.10983 .09023 Mdot
.16473 .12944 Mdot
.20002 .15689 Mdot
.31766 .23531 Mdot
.32158 .23139 Mdot
.31766 .23139 Mdot
.20787 .15689 Mdot
.20002 .14905 Mdot
.1961 .16473 Mdot
.32943 .27453 Mdot
.40785 .32943 Mdot
.46667 .37648 Mdot
.38824 .31766 Mdot
.34511 .29806 Mdot
.52941 .43922 Mdot
.53725 .45098 Mdot
.55686 .46667 Mdot
.56862 .48628 Mdot
.5098 .45098 Mdot
.1765 .21179 Mdot
.22355 .24316 Mdot
.54509 .47451 Mdot
.57646 .49412 Mdot
.29806 .27845 Mdot
.47843 .40785 Mdot
.51765 .43138 Mdot
.27453 .23924 Mdot
.07454 .08631 Mdot
.20394 .18042 Mdot
.49804 .40393 Mdot
.35295 .29021 Mdot
.24316 .21179 Mdot
.22355 .18826 Mdot
.12552 .10983 Mdot
.10983 .09415 Mdot
.05886 .05102 Mdot
.03533 .02749 Mdot
.03533 .01965 Mdot
.03141 .00788 Mdot
.03141 .0118 Mdot
.20787 .12944 Mdot
.31374 .20787 Mdot
.29806 .20394 Mdot
.23531 .16081 Mdot
.20787 .1412 Mdot
.18042 .12552 Mdot
.16081 .1216 Mdot
.94898 .91369 Mdot
.81958 .72155 Mdot
.63528 .52549 Mdot
.24708 .23139 Mdot
.30982 .27061 Mdot
.26668 .22747 Mdot
.251 .20002 Mdot
.24708 .18434 Mdot
.251 .18434 Mdot
.24316 .18826 Mdot
.24316 .18826 Mdot
.22747 .18434 Mdot
.251 .20002 Mdot
.30982 .24316 Mdot
.32943 .25884 Mdot
.25884 .21963 Mdot
.24316 .21571 Mdot
.23531 .20787 Mdot
.1961 .1765 Mdot
.1765 .16865 Mdot
.16865 .15689 Mdot
.18042 .15689 Mdot
.1765 .14513 Mdot
.16081 .12944 Mdot
.15297 .11376 Mdot
.15297 .11768 Mdot
.12944 .10199 Mdot
.09415 .07062 Mdot
.1412 .09415 Mdot
.15689 .10983 Mdot
.16473 .12552 Mdot
.1412 .10983 Mdot
.12944 .10591 Mdot
.11376 .09415 Mdot
.10591 .08631 Mdot
.15297 .11376 Mdot
.16865 .12552 Mdot
.16473 .12552 Mdot
.16081 .1216 Mdot
.15297 .10983 Mdot
.14905 .10199 Mdot
.16081 .11376 Mdot
.18826 .13728 Mdot
.49804 .36864 Mdot
.35295 .25884 Mdot
.23139 .17257 Mdot
.18042 .14905 Mdot
.35687 .29021 Mdot
.36864 .31766 Mdot
.41177 .37256 Mdot
.52941 .47059 Mdot
.56078 .49412 Mdot
.41177 .3804 Mdot
.44314 .38432 Mdot
.48628 .41177 Mdot
.50588 .41569 Mdot
.5098 .42354 Mdot
.49804 .42746 Mdot
.35295 .32943 Mdot
.1765 .1961 Mdot
.33727 .3059 Mdot
.37648 .33335 Mdot
.38824 .34119 Mdot
.28629 .25492 Mdot
.1216 .1216 Mdot
.12944 .11376 Mdot
.10199 .07454 Mdot
.0667 .04709 Mdot
.04709 .03141 Mdot
.03533 .01965 Mdot
.04709 .02749 Mdot
.07062 .03925 Mdot
.09807 .05102 Mdot
.31374 .20787 Mdot
.35687 .251 Mdot
.28237 .21179 Mdot
.251 .20002 Mdot
.20002 .15689 Mdot
.16081 .12552 Mdot
.81566 .76076 Mdot
.60391 .55294 Mdot
.57646 .48628 Mdot
.4902 .40785 Mdot
.4353 .35295 Mdot
.41177 .33335 Mdot
.38432 .31374 Mdot
.36472 .30198 Mdot
.31766 .26668 Mdot
.30198 .24708 Mdot
.28237 .23531 Mdot
.27845 .22747 Mdot
.26276 .21963 Mdot
.23924 .21179 Mdot
.22355 .21179 Mdot
.21963 .20787 Mdot
.21963 .20394 Mdot
.21963 .21179 Mdot
.20394 .1961 Mdot
.1961 .1765 Mdot
.20002 .1765 Mdot
.1961 .16865 Mdot
.18826 .16081 Mdot
.14513 .11768 Mdot
.10591 .09023 Mdot
.10983 .09415 Mdot
.13336 .10199 Mdot
.14905 .10591 Mdot
.13336 .10591 Mdot
.11768 .09415 Mdot
.09415 .07454 Mdot
.13728 .10983 Mdot
.20787 .16473 Mdot
.1961 .15297 Mdot
.1765 .13728 Mdot
.12552 .10199 Mdot
.11768 .09023 Mdot
.11768 .08239 Mdot
.1412 .09415 Mdot
.12944 .08239 Mdot
.18434 .11768 Mdot
.23139 .15297 Mdot
.23924 .15689 Mdot
.21179 .13728 Mdot
.1765 .11768 Mdot
.14513 .10983 Mdot
.1412 .12552 Mdot
.20394 .18434 Mdot
.44706 .37256 Mdot
.31766 .28237 Mdot
.28237 .25492 Mdot
.32158 .28237 Mdot
.42354 .35295 Mdot
.47059 .40001 Mdot
.48628 .42746 Mdot
.48628 .42746 Mdot
.44314 .39609 Mdot
.47059 .41569 Mdot
.3608 .33727 Mdot
.30198 .29021 Mdot
.3608 .30982 Mdot
.12552 .11768 Mdot
.11376 .10199 Mdot
.07062 .05102 Mdot
.05494 .02749 Mdot
.04317 .01572 Mdot
.03925 .02357 Mdot
.07454 .05886 Mdot
.07062 .05886 Mdot
.05886 .05886 Mdot
.09023 .08631 Mdot
.11376 .09807 Mdot
.14513 .11768 Mdot
.25884 .20394 Mdot
.23924 .19218 Mdot
.18434 .15297 Mdot
.83919 .78821 Mdot
.69018 .57254 Mdot
.55686 .45883 Mdot
.5098 .41569 Mdot
.40785 .33335 Mdot
.35687 .29806 Mdot
.33335 .27845 Mdot
.29413 .25492 Mdot
.28237 .23924 Mdot
.25884 .21963 Mdot
.251 .21963 Mdot
.23531 .20787 Mdot
.31766 .26668 Mdot
.3255 .28237 Mdot
.3059 .26668 Mdot
.27061 .23531 Mdot
.22747 .1961 Mdot
.21179 .18042 Mdot
.19218 .16081 Mdot
.18826 .16081 Mdot
.16473 .14513 Mdot
.13728 .10983 Mdot
.11376 .08631 Mdot
.1412 .10199 Mdot
.15689 .10983 Mdot
.14905 .10591 Mdot
.12944 .09023 Mdot
.10591 .07846 Mdot
.15689 .12944 Mdot
.18042 .14905 Mdot
.18434 .14513 Mdot
.17257 .13728 Mdot
.15689 .12944 Mdot
.13336 .10983 Mdot
.13336 .10199 Mdot
.11768 .08239 Mdot
.11376 .07454 Mdot
.07846 .04317 Mdot
.09415 .05494 Mdot
.11768 .07062 Mdot
.14513 .09023 Mdot
.13336 .08239 Mdot
.10199 .06278 Mdot
.09415 .0667 Mdot
.08239 .0667 Mdot
.25492 .20002 Mdot
.3804 .3059 Mdot
.1412 .13336 Mdot
.17257 .15689 Mdot
.16865 .16865 Mdot
.22355 .20394 Mdot
.38432 .32943 Mdot
.45098 .37648 Mdot
.45883 .38432 Mdot
.44706 .38824 Mdot
.43922 .38432 Mdot
.24316 .22747 Mdot
.27453 .23139 Mdot
.26668 .20787 Mdot
.12552 .09807 Mdot
.08239 .06278 Mdot
.08631 .05886 Mdot
.07454 .04709 Mdot
.06278 .04709 Mdot
.06278 .05494 Mdot
.05494 .05494 Mdot
.03925 .04709 Mdot
.03533 .04317 Mdot
.03533 .04317 Mdot
.03533 .04709 Mdot
.09023 .09023 Mdot
.11768 .10983 Mdot
.16473 .1412 Mdot
.92938 .89409 Mdot
.83135 .77253 Mdot
.62744 .51372 Mdot
.46667 .3804 Mdot
.45098 .36472 Mdot
.38824 .33727 Mdot
.33335 .3059 Mdot
.30198 .27845 Mdot
.29021 .26668 Mdot
.25884 .23139 Mdot
.39217 .31766 Mdot
.47059 .37256 Mdot
.47843 .36864 Mdot
.44706 .33727 Mdot
.20787 .15689 Mdot
.17257 .13728 Mdot
.14905 .1216 Mdot
.13336 .11376 Mdot
.13728 .12944 Mdot
.13728 .12944 Mdot
.13728 .12944 Mdot
.15689 .13728 Mdot
.16081 .13336 Mdot
.15297 .13336 Mdot
.13336 .1216 Mdot
.13728 .12944 Mdot
.24708 .21179 Mdot
.24708 .20787 Mdot
.20002 .16473 Mdot
.18042 .14513 Mdot
.16081 .12552 Mdot
.15689 .1216 Mdot
.1765 .13728 Mdot
.15297 .11768 Mdot
.10983 .07846 Mdot
.08239 .04317 Mdot
.06278 .02357 Mdot
.10591 .05102 Mdot
.12552 .06278 Mdot
.09807 .04709 Mdot
.06278 .03141 Mdot
.05102 .03141 Mdot
.04709 .03141 Mdot
.10983 .08239 Mdot
.39217 .29806 Mdot
.18826 .15297 Mdot
.18826 .16473 Mdot
.14513 .13728 Mdot
.12552 .11768 Mdot
.10591 .10199 Mdot
.21571 .16473 Mdot
.25492 .18042 Mdot
.20002 .1412 Mdot
.24316 .18042 Mdot
.29806 .22747 Mdot
.37648 .29413 Mdot
.32943 .24708 Mdot
.05494 .03533 Mdot
.09415 .07062 Mdot
.11768 .09023 Mdot
.10591 .08239 Mdot
.10983 .09023 Mdot
.08631 .07846 Mdot
.05494 .0667 Mdot
.02357 .05102 Mdot
.02749 .05494 Mdot
.01965 .04317 Mdot
.02357 .05102 Mdot
.03141 .0667 Mdot
.03925 .07062 Mdot
.10983 .11376 Mdot
.92546 .89801 Mdot
.73332 .65881 Mdot
.65489 .55686 Mdot
.41961 .3804 Mdot
.37256 .34511 Mdot
.34511 .31374 Mdot
.32943 .29021 Mdot
.27453 .23924 Mdot
.29413 .23924 Mdot
.3608 .27453 Mdot
.3059 .23924 Mdot
.22355 .1765 Mdot
.20394 .15689 Mdot
.18042 .14513 Mdot
.1412 .1216 Mdot
.13336 .12552 Mdot
.13728 .13728 Mdot
.1765 .16473 Mdot
.18826 .17257 Mdot
.18826 .1765 Mdot
.18826 .1765 Mdot
.15297 .15297 Mdot
.16081 .16473 Mdot
.34119 .29806 Mdot
.3059 .26668 Mdot
.251 .21571 Mdot
.22747 .18826 Mdot
.21571 .17257 Mdot
.20394 .16473 Mdot
.20394 .16473 Mdot
.14905 .12552 Mdot
.10199 .09023 Mdot
.05886 .05102 Mdot
.07062 .03533 Mdot
.10199 .05494 Mdot
.1216 .0667 Mdot
.1216 .07062 Mdot
.09023 .05102 Mdot
.06278 .04317 Mdot
.04317 .03533 Mdot
.03925 .03533 Mdot
.09415 .07454 Mdot
.10983 .09415 Mdot
.10591 .09415 Mdot
.09415 .09023 Mdot
.09415 .08631 Mdot
.10199 .09023 Mdot
.13728 .10983 Mdot
.13728 .09023 Mdot
.12944 .07062 Mdot
.11768 .05886 Mdot
.10199 .05494 Mdot
.16081 .10199 Mdot
.1765 .11768 Mdot
.12552 .08631 Mdot
.15689 .10983 Mdot
.14905 .11376 Mdot
.1412 .10591 Mdot
.23531 .1765 Mdot
.18434 .1412 Mdot
.15689 .12944 Mdot
.1216 .11376 Mdot
.10983 .10983 Mdot
.09023 .09415 Mdot
.07062 .08239 Mdot
.04709 .07454 Mdot
.03925 .07846 Mdot
.05886 .09023 Mdot
.85487 .80782 Mdot
.64705 .60391 Mdot
.40393 .37256 Mdot
.41177 .36864 Mdot
.32158 .29021 Mdot
.3059 .27453 Mdot
.28629 .24708 Mdot
.25884 .21963 Mdot
.23924 .20002 Mdot
.1961 .1765 Mdot
.16865 .15297 Mdot
.16081 .14905 Mdot
.1412 .13728 Mdot
.16865 .15689 Mdot
.1961 .17257 Mdot
.21571 .18434 Mdot
.20394 .17257 Mdot
.1961 .16473 Mdot
.18042 .16473 Mdot
.1765 .17257 Mdot
.21571 .20394 Mdot
.22355 .20787 Mdot
.22355 .19218 Mdot
.22355 .18826 Mdot
.22355 .18042 Mdot
.23531 .18826 Mdot
.21571 .18042 Mdot
.16865 .14513 Mdot
.1412 .13336 Mdot
.10983 .10199 Mdot
.10199 .08631 Mdot
.1216 .09023 Mdot
.1412 .09415 Mdot
.1216 .07846 Mdot
.10983 .0667 Mdot
.07454 .04709 Mdot
.08239 .04317 Mdot
.0667 .03141 Mdot
.07846 .05102 Mdot
.10199 .07062 Mdot
.11376 .09415 Mdot
.09807 .08631 Mdot
.08239 .0667 Mdot
.08631 .06278 Mdot
.11376 .07846 Mdot
.10983 .06278 Mdot
.10199 .05494 Mdot
.09807 .05494 Mdot
.09807 .05494 Mdot
.08239 .04709 Mdot
.10591 .07454 Mdot
.11376 .08239 Mdot
.12944 .09807 Mdot
.11376 .09415 Mdot
.11376 .09415 Mdot
.16865 .1216 Mdot
.23139 .15689 Mdot
.23139 .14513 Mdot
.17257 .09807 Mdot
.20787 .12944 Mdot
.22747 .16081 Mdot
.16865 .12944 Mdot
.16081 .13336 Mdot
.14513 .13336 Mdot
.11376 .10983 Mdot
.81958 .77253 Mdot
.54117 .46667 Mdot
.42746 .37648 Mdot
.38824 .34119 Mdot
.31766 .27845 Mdot
.29021 .251 Mdot
.22355 .20394 Mdot
.20002 .18826 Mdot
.18042 .18042 Mdot
.16865 .16865 Mdot
.16081 .16473 Mdot
.1765 .16865 Mdot
.20002 .18434 Mdot
.20394 .18042 Mdot
.20002 .17257 Mdot
.20394 .16865 Mdot
.20394 .16865 Mdot
.16865 .14513 Mdot
.16081 .1412 Mdot
.15689 .13336 Mdot
.16473 .13728 Mdot
.19218 .15297 Mdot
.21963 .17257 Mdot
.19218 .15689 Mdot
.18826 .15689 Mdot
.18042 .15689 Mdot
.14905 .13336 Mdot
.17257 .1412 Mdot
.20394 .15689 Mdot
.16865 .12944 Mdot
.13336 .09807 Mdot
.09807 .07062 Mdot
.07846 .05494 Mdot
.06278 .04317 Mdot
.05886 .03925 Mdot
.09415 .07062 Mdot
.10591 .07846 Mdot
.1216 .09807 Mdot
.10591 .08239 Mdot
.08631 .0667 Mdot
.08631 .05886 Mdot
.10983 .07062 Mdot
.09807 .05886 Mdot
.08631 .04709 Mdot
.07454 .04317 Mdot
.07062 .03925 Mdot
.07062 .03925 Mdot
.06278 .03141 Mdot
.07454 .04317 Mdot
.08631 .06278 Mdot
.07846 .05886 Mdot
.12552 .09415 Mdot
.15297 .10591 Mdot
.18042 .11376 Mdot
.18826 .10199 Mdot
.11376 .03533 Mdot
.21571 .1216 Mdot
.10591 .07062 Mdot
.1961 .16865 Mdot
.14513 .1412 Mdot
.20002 .16865 Mdot
.22747 .18434 Mdot
.9333 .90585 Mdot
.749 .72547 Mdot
.52549 .47451 Mdot
.42746 .39217 Mdot
.27845 .27453 Mdot
.28237 .27061 Mdot
.21571 .21963 Mdot
.19218 .1961 Mdot
.18434 .18434 Mdot
.1765 .1765 Mdot
.16865 .1765 Mdot
.18042 .18042 Mdot
.16865 .16473 Mdot
.16865 .15297 Mdot
.18826 .16473 Mdot
.1765 .14905 Mdot
.15689 .13336 Mdot
.14905 .12552 Mdot
.14513 .1216 Mdot
.14905 .1216 Mdot
.14513 .11768 Mdot
.14905 .12552 Mdot
.16473 .13728 Mdot
.18434 .14905 Mdot
.17257 .1412 Mdot
.18826 .14905 Mdot
.27061 .19218 Mdot
.18042 .1216 Mdot
.13336 .09023 Mdot
.09023 .07062 Mdot
.07062 .05886 Mdot
.07062 .05102 Mdot
.07454 .05102 Mdot
.09023 .06278 Mdot
.11768 .08631 Mdot
.1216 .09415 Mdot
.12552 .08631 Mdot
.11768 .07062 Mdot
.12552 .07846 Mdot
.1412 .08631 Mdot
.1216 .07062 Mdot
.11376 .0667 Mdot
.08631 .05494 Mdot
.07454 .05494 Mdot
.08239 .05886 Mdot
.07062 .04317 Mdot
.04317 .01572 Mdot
.05102 .02357 Mdot
.04709 .02357 Mdot
.05102 .01965 Mdot
.05886 .02749 Mdot
.08239 .04317 Mdot
.11768 .07062 Mdot
.09415 .05886 Mdot
.3255 .23139 Mdot
.05102 .04317 Mdot
.44314 .36472 Mdot
.41569 .33335 Mdot
.07062 .06278 Mdot
.1412 .10983 Mdot
.91761 .89409 Mdot
.62744 .58823 Mdot
.50588 .4353 Mdot
.34511 .29021 Mdot
.32158 .26276 Mdot
.28629 .23139 Mdot
.24708 .20787 Mdot
.22355 .20002 Mdot
.22747 .20002 Mdot
.16081 .15689 Mdot
.16473 .15297 Mdot
.15689 .14513 Mdot
.15297 .1412 Mdot
.13728 .12552 Mdot
.14513 .12944 Mdot
.17257 .1412 Mdot
.16865 .13336 Mdot
.14905 .10983 Mdot
.14905 .10983 Mdot
.16473 .1216 Mdot
.16081 .1216 Mdot
.16865 .11768 Mdot
.18042 .11376 Mdot
.18434 .11376 Mdot
.18042 .11376 Mdot
.14513 .08631 Mdot
.1216 .07062 Mdot
.10983 .06278 Mdot
.09807 .05494 Mdot
.09415 .05494 Mdot
.10983 .0667 Mdot
.10983 .06278 Mdot
.1216 .07846 Mdot
.12944 .08631 Mdot
.1216 .07846 Mdot
.12944 .09415 Mdot
.1412 .09807 Mdot
.13728 .09415 Mdot
.13728 .09415 Mdot
.10591 .0667 Mdot
.07454 .05102 Mdot
.08239 .05886 Mdot
.07062 .04709 Mdot
.05494 .02357 Mdot
.04709 .01572 Mdot
.03925 .01965 Mdot
.03141 .01572 Mdot
.03141 .02749 Mdot
.02749 .01965 Mdot
.03925 .01965 Mdot
.04317 .0118 Mdot
.06278 .01572 Mdot
.10199 .04317 Mdot
.12552 .05886 Mdot
.16081 .08239 Mdot
.15297 .07846 Mdot
.10983 .05494 Mdot
.78429 .73724 Mdot
.60391 .55294 Mdot
.41961 .3608 Mdot
.33335 .28629 Mdot
.30982 .25884 Mdot
.28237 .23924 Mdot
.25884 .21571 Mdot
.22355 .18434 Mdot
.1961 .16473 Mdot
.15689 .13728 Mdot
.13336 .11768 Mdot
.13728 .1216 Mdot
.13728 .12552 Mdot
.15297 .12944 Mdot
.15689 .11768 Mdot
.1412 .09807 Mdot
.1216 .08239 Mdot
.1216 .07846 Mdot
.16081 .10591 Mdot
.12944 .07062 Mdot
.13336 .0667 Mdot
.15297 .07846 Mdot
.14513 .08239 Mdot
.1412 .08631 Mdot
.13728 .09023 Mdot
.13336 .09023 Mdot
.12552 .09023 Mdot
.11768 .08239 Mdot
.09807 .0667 Mdot
.10983 .07846 Mdot
.1216 .08239 Mdot
.13728 .09023 Mdot
.14905 .09807 Mdot
.14905 .09807 Mdot
.14905 .09415 Mdot
.14513 .09415 Mdot
.13336 .08239 Mdot
.1216 .06278 Mdot
.10199 .05102 Mdot
.08239 .03925 Mdot
.07454 .02749 Mdot
.06278 .01965 Mdot
.06278 .02749 Mdot
.05102 .01965 Mdot
.03925 .01965 Mdot
.03141 .01572 Mdot
.03533 .01572 Mdot
.03925 .0118 Mdot
.03925 .00396 Mdot
.05886 .00788 Mdot
.07846 .02357 Mdot
.10591 .03925 Mdot
.07454 .01965 Mdot
.05102 .0118 Mdot
.74508 .71371 Mdot
.42746 .37648 Mdot
.36472 .3059 Mdot
.32943 .26668 Mdot
.29413 .24316 Mdot
.24708 .21571 Mdot
.21571 .1961 Mdot
.20787 .18434 Mdot
.19218 .17257 Mdot
.17257 .16473 Mdot
.15689 .15297 Mdot
.14905 .14513 Mdot
.13728 .12944 Mdot
.12944 .11376 Mdot
.11768 .09415 Mdot
.13728 .10199 Mdot
.12552 .09023 Mdot
.12552 .07846 Mdot
.14905 .09807 Mdot
.16473 .11376 Mdot
.15689 .10983 Mdot
.15297 .11376 Mdot
.15297 .11376 Mdot
.16081 .1216 Mdot
.14905 .10591 Mdot
.13728 .09023 Mdot
.15297 .09023 Mdot
.16865 .09023 Mdot
.17257 .09415 Mdot
.18826 .10199 Mdot
.16865 .08239 Mdot
.17257 .08239 Mdot
.16081 .08239 Mdot
.15297 .09023 Mdot
.13728 .07846 Mdot
.13728 .07454 Mdot
.13336 .06278 Mdot
.10983 .05102 Mdot
.10983 .05102 Mdot
.08631 .04317 Mdot
.07454 .03533 Mdot
.08631 .04709 Mdot
.07062 .04709 Mdot
.05886 .03533 Mdot
.05886 .03141 Mdot
.0667 .02749 Mdot
.06278 .02357 Mdot
.06278 .02749 Mdot
.08239 .03925 Mdot
.0667 .03533 Mdot
.03925 .01965 Mdot
.87448 .86272 Mdot
.72939 .70587 Mdot
.40393 .38824 Mdot
.3059 .29806 Mdot
.28629 .27061 Mdot
.26668 .23531 Mdot
.23531 .20002 Mdot
.19218 .17257 Mdot
.16081 .16081 Mdot
.13728 .15297 Mdot
.12552 .13728 Mdot
.11376 .12552 Mdot
.12944 .12944 Mdot
.12944 .11376 Mdot
.10199 .09023 Mdot
.08239 .07062 Mdot
.08631 .07062 Mdot
.09415 .07454 Mdot
.10591 .08239 Mdot
.10591 .07454 Mdot
.10983 .07846 Mdot
.11768 .08239 Mdot
.1216 .07846 Mdot
.13336 .08631 Mdot
.12552 .06278 Mdot
.11768 .05102 Mdot
.12944 .05886 Mdot
.1412 .06278 Mdot
.13728 .05886 Mdot
.13336 .05886 Mdot
.1216 .05102 Mdot
.12552 .05494 Mdot
.12552 .05886 Mdot
.11768 .04709 Mdot
.11768 .04317 Mdot
.12944 .05494 Mdot
.1216 .05494 Mdot
.10591 .05886 Mdot
.08631 .05102 Mdot
.08631 .05102 Mdot
.07062 .04317 Mdot
.06278 .04317 Mdot
.05494 .04709 Mdot
.05886 .04709 Mdot
.0667 .04709 Mdot
.06278 .04317 Mdot
.05886 .04709 Mdot
.05494 .04709 Mdot
.03925 .03141 Mdot
.88232 .87056 Mdot
.61176 .56862 Mdot
.47451 .39217 Mdot
.23531 .20394 Mdot
.22355 .21179 Mdot
.17257 .18826 Mdot
.1216 .15689 Mdot
.10591 .14513 Mdot
.10591 .1412 Mdot
.12552 .14513 Mdot
.12552 .14513 Mdot
.11768 .13336 Mdot
.08239 .09807 Mdot
.0667 .08239 Mdot
.0667 .07454 Mdot
.05886 .05494 Mdot
.05102 .03141 Mdot
.07846 .04709 Mdot
.08239 .04317 Mdot
.07454 .03533 Mdot
.08239 .04317 Mdot
.07846 .02749 Mdot
.10199 .03533 Mdot
.10591 .03141 Mdot
.11768 .03533 Mdot
.10199 .01965 Mdot
.09807 .00788 Mdot
.11768 .01965 Mdot
.12552 .03141 Mdot
.10199 .02749 Mdot
.08631 .01965 Mdot
.07454 .0118 Mdot
.08239 .02749 Mdot
.07846 .03533 Mdot
.07846 .03925 Mdot
.07062 .05102 Mdot
.07846 .06278 Mdot
.05886 .05102 Mdot
.04709 .04317 Mdot
.03141 .02749 Mdot
.05102 .03925 Mdot
.0667 .05102 Mdot
.05494 .05102 Mdot
.05886 .05102 Mdot
.06278 .04709 Mdot
.04317 .03533 Mdot
.69018 .68234 Mdot
.42746 .45491 Mdot
.25884 .3059 Mdot
.15297 .21963 Mdot
.12552 .18826 Mdot
.10591 .16081 Mdot
.10199 .1412 Mdot
.09023 .12552 Mdot
.07846 .11376 Mdot
.07846 .10983 Mdot
.08239 .10199 Mdot
.07454 .08239 Mdot
.07454 .0667 Mdot
.08239 .06278 Mdot
.08631 .05886 Mdot
.08239 .05494 Mdot
.07454 .04709 Mdot
.06278 .03533 Mdot
.05102 .02357 Mdot
.10199 .05102 Mdot
.12944 .05102 Mdot
.11376 .03141 Mdot
.11376 .02357 Mdot
.11376 .0118 Mdot
.1216 .01965 Mdot
.1216 .02749 Mdot
.09415 .01965 Mdot
.09023 .02357 Mdot
.07454 .02357 Mdot
.08239 .02749 Mdot
.05886 .02749 Mdot
.06278 .03925 Mdot
.07454 .05102 Mdot
.07846 .05886 Mdot
.07062 .04709 Mdot
.05886 .03925 Mdot
.05494 .03141 Mdot
.05494 .03141 Mdot
.08239 .05886 Mdot
.05494 .05102 Mdot
.05494 .05102 Mdot
.06278 .05886 Mdot
.05886 .04709 Mdot
.55686 .60783 Mdot
.19218 .24316 Mdot
.19218 .21571 Mdot
.1412 .15689 Mdot
.10199 .1216 Mdot
.09023 .10591 Mdot
.09807 .10199 Mdot
.09023 .09415 Mdot
.09807 .10199 Mdot
.09807 .09807 Mdot
.09807 .09023 Mdot
.07846 .07454 Mdot
.09415 .08631 Mdot
.06278 .06278 Mdot
.05102 .05102 Mdot
.05102 .04709 Mdot
.0667 .04709 Mdot
.09807 .05102 Mdot
.10591 .04709 Mdot
.11768 .05102 Mdot
.10591 .03533 Mdot
.09807 .02357 Mdot
.10199 .02749 Mdot
.11768 .03925 Mdot
.10591 .03925 Mdot
.10983 .05494 Mdot
.10199 .05886 Mdot
.08631 .04317 Mdot
.07846 .04709 Mdot
.07454 .04317 Mdot
.07454 .04709 Mdot
.08239 .04709 Mdot
.07062 .03141 Mdot
.0667 .03141 Mdot
.06278 .02749 Mdot
.07062 .04317 Mdot
.07454 .05494 Mdot
.07454 .0667 Mdot
.07454 .0667 Mdot
.07062 .05886 Mdot
.8039 .8039 Mdot
.58823 .58823 Mdot
.15297 .15689 Mdot
.12552 .13336 Mdot
.10591 .11768 Mdot
.09023 .09807 Mdot
.08631 .09415 Mdot
.09415 .09415 Mdot
.09415 .09415 Mdot
.07846 .09023 Mdot
.06278 .07846 Mdot
.07062 .08239 Mdot
.06278 .07062 Mdot
.03925 .04709 Mdot
.07454 .0667 Mdot
.10983 .09023 Mdot
.11768 .08239 Mdot
.10983 .0667 Mdot
.11768 .0667 Mdot
.10983 .05494 Mdot
.11768 .05102 Mdot
.10983 .04317 Mdot
.10591 .05102 Mdot
.10591 .05494 Mdot
.10199 .05886 Mdot
.09807 .05102 Mdot
.08631 .05102 Mdot
.07846 .05102 Mdot
.07454 .05494 Mdot
.08631 .05494 Mdot
.09023 .04709 Mdot
.07454 .02357 Mdot
.05102 .0118 Mdot
.04709 .01572 Mdot
.05886 .03141 Mdot
.05102 .03141 Mdot
.05102 .03141 Mdot
.05494 .03141 Mdot
.57254 .57646 Mdot
.34511 .34511 Mdot
.10983 .10983 Mdot
.11376 .11768 Mdot
.10591 .10983 Mdot
.09415 .09415 Mdot
.07846 .08239 Mdot
.07062 .07846 Mdot
.07846 .09023 Mdot
.07846 .07846 Mdot
.05886 .05494 Mdot
.05886 .04317 Mdot
.08631 .05102 Mdot
.10983 .06278 Mdot
.12944 .07454 Mdot
.1412 .07846 Mdot
.14513 .07454 Mdot
.13728 .0667 Mdot
.11768 .05494 Mdot
.10591 .05886 Mdot
.10591 .05886 Mdot
.10591 .05886 Mdot
.09807 .05494 Mdot
.08239 .05102 Mdot
.0667 .03925 Mdot
.07846 .05494 Mdot
.08631 .06278 Mdot
.08631 .04317 Mdot
.07846 .03533 Mdot
.07454 .02749 Mdot
.0667 .02357 Mdot
.06278 .01572 Mdot
.05494 .0118 Mdot
.07846 .03141 Mdot
.07846 .03141 Mdot
.56862 .57646 Mdot
.33335 .3608 Mdot
.09807 .13336 Mdot
.11376 .14513 Mdot
.1216 .14905 Mdot
.09807 .12944 Mdot
.08239 .10199 Mdot
.07062 .0667 Mdot
.05494 .04709 Mdot
.0667 .05102 Mdot
.08631 .05886 Mdot
.11376 .07846 Mdot
.12944 .08631 Mdot
.1412 .09023 Mdot
.12944 .08239 Mdot
.10983 .07062 Mdot
.10983 .07454 Mdot
.10591 .07846 Mdot
.08239 .06278 Mdot
.07062 .05102 Mdot
.07846 .05494 Mdot
.08239 .05886 Mdot
.09415 .0667 Mdot
.08631 .05886 Mdot
.07454 .03925 Mdot
.07062 .03533 Mdot
.0667 .03533 Mdot
.07062 .03925 Mdot
.07454 .03533 Mdot
.07846 .03533 Mdot
.05886 .01965 Mdot
.03533 .00788 Mdot
.77253 .78429 Mdot
.63528 .63528 Mdot
.16473 .18826 Mdot
.12944 .16081 Mdot
.11376 .13728 Mdot
.09023 .09807 Mdot
.07062 .0667 Mdot
.07062 .05886 Mdot
.08239 .06278 Mdot
.09807 .07454 Mdot
.1216 .10199 Mdot
.13728 .11376 Mdot
.11768 .09415 Mdot
.09807 .07454 Mdot
.10199 .07454 Mdot
.11376 .09415 Mdot
.09023 .07846 Mdot
.09023 .07454 Mdot
.09023 .07062 Mdot
.10199 .0667 Mdot
.09807 .0667 Mdot
.10199 .07454 Mdot
.08239 .05886 Mdot
.0667 .04709 Mdot
.07062 .05102 Mdot
.07454 .05886 Mdot
.08631 .06278 Mdot
.0667 .04317 Mdot
.04317 .01965 Mdot
.02749 .00788 Mdot
.78429 .78821 Mdot
.5647 .57254 Mdot
.12944 .10983 Mdot
.15297 .10983 Mdot
.1216 .08239 Mdot
.10591 .07062 Mdot
.09415 .06278 Mdot
.10591 .08239 Mdot
.10983 .09415 Mdot
.10983 .09415 Mdot
.10591 .09415 Mdot
.12552 .11376 Mdot
.12552 .11376 Mdot
.11768 .10591 Mdot
.10983 .09415 Mdot
.10983 .09023 Mdot
.08631 .0667 Mdot
.10983 .07846 Mdot
.10591 .07846 Mdot
.09415 .07454 Mdot
.07454 .0667 Mdot
.05886 .05494 Mdot
.07846 .07454 Mdot
.09023 .07846 Mdot
.0667 .05494 Mdot
.03925 .02749 Mdot
.0118 .00788 Mdot
.60391 .56862 Mdot
.35687 .31374 Mdot
.13728 .08239 Mdot
.12944 .08239 Mdot
.10591 .08631 Mdot
.09415 .08631 Mdot
.10199 .09023 Mdot
.11768 .10591 Mdot
.12552 .10983 Mdot
.13336 .11768 Mdot
.12552 .11376 Mdot
.12552 .10983 Mdot
.1216 .10591 Mdot
.10591 .09023 Mdot
.11768 .09023 Mdot
.1216 .09023 Mdot
.09807 .07454 Mdot
.09415 .07062 Mdot
.07846 .06278 Mdot
.05886 .05102 Mdot
.05886 .04709 Mdot
.04709 .03533 Mdot
.02749 .01965 Mdot
.0118 .00396 Mdot
.57646 .56078 Mdot
.34511 .34119 Mdot
.08631 .10199 Mdot
.09807 .10591 Mdot
.12552 .11376 Mdot
.1412 .11768 Mdot
.15297 .11768 Mdot
.14513 .11768 Mdot
.1412 .11376 Mdot
.1216 .09807 Mdot
.11376 .09415 Mdot
.11768 .09415 Mdot
.1216 .09023 Mdot
.1216 .08631 Mdot
.09415 .07062 Mdot
.06278 .04709 Mdot
.03925 .03141 Mdot
.03925 .03141 Mdot
.02357 .01572 Mdot
.0118 .00788 Mdot
.0118 .00396 Mdot
.76861 .77645 Mdot
.53333 .54902 Mdot
.07454 .09023 Mdot
.07846 .07454 Mdot
.10199 .08239 Mdot
.10983 .08631 Mdot
.09023 .07846 Mdot
.09807 .08239 Mdot
.09023 .07846 Mdot
.09807 .07846 Mdot
.09023 .06278 Mdot
.08631 .04709 Mdot
.06278 .03141 Mdot
.02749 .01572 Mdot
.03925 .03141 Mdot
.05102 .03925 Mdot
.02749 .02357 Mdot
.01965 .01572 Mdot
.01965 .0118 Mdot
.76469 .76861 Mdot
.52941 .53333 Mdot
.07846 .07454 Mdot
.09023 .08631 Mdot
.08239 .07454 Mdot
.07846 .05886 Mdot
.08631 .05102 Mdot
.09023 .05102 Mdot
.07454 .04317 Mdot
.04709 .02749 Mdot
.03925 .01965 Mdot
.04317 .02357 Mdot
.05494 .03141 Mdot
.03925 .01965 Mdot
.02749 .0118 Mdot
.02749 .01572 Mdot
.58431 .57646 Mdot
.34511 .33727 Mdot
.11768 .10591 Mdot
.08631 .06278 Mdot
.07846 .05494 Mdot
.07846 .07454 Mdot
.07062 .07062 Mdot
.05494 .05886 Mdot
.05886 .05494 Mdot
.0667 .05102 Mdot
.0667 .03925 Mdot
.02749 .0118 Mdot
.02357 .00396 Mdot
.55686 .55686 Mdot
.33335 .33727 Mdot
.13728 .13728 Mdot
.10591 .11768 Mdot
.08631 .10983 Mdot
.06278 .08631 Mdot
.05102 .05886 Mdot
.04317 .03925 Mdot
.03533 .01572 Mdot
.02357 .00788 Mdot
.76076 .77253 Mdot
.54117 .55686 Mdot
.06278 .09415 Mdot
.03141 .0667 Mdot
.01572 .04317 Mdot
.0118 .01965 Mdot
.0118 .00788 Mdot
.01572 .0118 Mdot
.76469 .77645 Mdot
.51765 .53725 Mdot
.02749 .04317 Mdot
.01965 .02357 Mdot
.0118 .0118 Mdot
.51372 .51765 Mdot
.25492 .26668 Mdot
0 0 1 r
.8588 .84703 Mdot
.5098 .47451 Mdot
.48628 .44314 Mdot
.73724 .72155 Mdot
.56862 .53725 Mdot
.58823 .5647 Mdot
.59607 .5647 Mdot
.57254 .54902 Mdot
.68626 .67057 Mdot
.78429 .77645 Mdot
.58823 .54902 Mdot
.59607 .57646 Mdot
.61176 .60391 Mdot
.60783 .61568 Mdot
.59999 .61568 Mdot
.58823 .60391 Mdot
.59215 .59607 Mdot
.70194 .70194 Mdot
.89801 .90193 Mdot
.59215 .56078 Mdot
.61176 .59215 Mdot
.61568 .61568 Mdot
.61568 .62744 Mdot
.61568 .6392 Mdot
.61176 .64313 Mdot
.59999 .6196 Mdot
.60783 .6196 Mdot
.61176 .6196 Mdot
.6196 .6196 Mdot
.81566 .81566 Mdot
.91369 .90977 Mdot
.58039 .55294 Mdot
.6196 .60391 Mdot
.6196 .61568 Mdot
.62744 .63136 Mdot
.63528 .64705 Mdot
.62744 .64705 Mdot
.62744 .62744 Mdot
.62744 .6196 Mdot
.62352 .61568 Mdot
.63136 .62352 Mdot
.6392 .62352 Mdot
.64313 .61568 Mdot
.65097 .60783 Mdot
.83135 .79998 Mdot
.61176 .57254 Mdot
.63136 .60783 Mdot
.6392 .62352 Mdot
.6392 .63136 Mdot
.63528 .62744 Mdot
.63528 .62744 Mdot
.63528 .62352 Mdot
.63528 .61568 Mdot
.62744 .60783 Mdot
.63136 .61176 Mdot
.63528 .60391 Mdot
.64313 .60783 Mdot
.65489 .60783 Mdot
.65489 .60783 Mdot
.67057 .61568 Mdot
.749 .70194 Mdot
.83527 .8039 Mdot
.59215 .56078 Mdot
.63136 .59607 Mdot
.6392 .60391 Mdot
.63136 .60783 Mdot
.63136 .60783 Mdot
.63528 .60783 Mdot
.62352 .59607 Mdot
.61568 .58431 Mdot
.63136 .59607 Mdot
.64705 .61176 Mdot
.65097 .61568 Mdot
.65489 .62352 Mdot
.65489 .61568 Mdot
.65097 .61176 Mdot
.65489 .61568 Mdot
.65097 .61176 Mdot
.66273 .6196 Mdot
.63528 .59215 Mdot
.80782 .79213 Mdot
.89801 .88624 Mdot
.60783 .57646 Mdot
.62352 .59607 Mdot
.62744 .59999 Mdot
.62744 .60391 Mdot
.62352 .59215 Mdot
.63136 .59215 Mdot
.62744 .59215 Mdot
.63136 .59999 Mdot
.63136 .60391 Mdot
.63528 .61568 Mdot
.64313 .61568 Mdot
.64705 .61568 Mdot
.65489 .6196 Mdot
.65489 .6196 Mdot
.65097 .62352 Mdot
.66273 .63136 Mdot
.65881 .62352 Mdot
.65489 .6196 Mdot
.64705 .60783 Mdot
.65097 .60391 Mdot
.52157 .49804 Mdot
.749 .73724 Mdot
.82743 .83135 Mdot
.58039 .55294 Mdot
.6196 .58823 Mdot
.63528 .60783 Mdot
.63528 .61176 Mdot
.62352 .61176 Mdot
.61176 .59999 Mdot
.6196 .60783 Mdot
.62744 .6196 Mdot
.63136 .62352 Mdot
.63136 .62744 Mdot
.64313 .62744 Mdot
.6392 .61568 Mdot
.64705 .6196 Mdot
.65489 .62352 Mdot
.64313 .6196 Mdot
.66273 .63528 Mdot
.65097 .62744 Mdot
.66273 .63136 Mdot
.65881 .6196 Mdot
.65489 .6196 Mdot
.67057 .62744 Mdot
.63136 .58431 Mdot
.50588 .46667 Mdot
.54117 .52549 Mdot
.68626 .66665 Mdot
.58039 .53725 Mdot
.62744 .59607 Mdot
.64313 .61568 Mdot
.6196 .61568 Mdot
.62352 .6196 Mdot
.61568 .62744 Mdot
.61568 .62744 Mdot
.62352 .62744 Mdot
.63136 .62744 Mdot
.63528 .63136 Mdot
.6392 .6392 Mdot
.65097 .64313 Mdot
.65489 .64313 Mdot
.65881 .6392 Mdot
.66273 .63136 Mdot
.66665 .62744 Mdot
.65881 .62744 Mdot
.65881 .63136 Mdot
.6745 .64313 Mdot
.6745 .6392 Mdot
.6745 .63528 Mdot
.67057 .63136 Mdot
.66665 .6196 Mdot
.63136 .58431 Mdot
.5647 .51765 Mdot
.48235 .42354 Mdot
.50588 .47843 Mdot
.64705 .63528 Mdot
.60783 .56862 Mdot
.6392 .61568 Mdot
.64705 .6392 Mdot
.64313 .64313 Mdot
.63528 .65097 Mdot
.63136 .64705 Mdot
.62352 .63136 Mdot
.6196 .62744 Mdot
.62744 .62744 Mdot
.63528 .63528 Mdot
.65097 .64313 Mdot
.65097 .64313 Mdot
.65097 .6392 Mdot
.65489 .6392 Mdot
.66273 .63136 Mdot
.66665 .62744 Mdot
.67057 .63136 Mdot
.6745 .6392 Mdot
.66665 .65097 Mdot
.68234 .65489 Mdot
.67842 .65489 Mdot
.6745 .64313 Mdot
.67842 .64313 Mdot
.68234 .64705 Mdot
.67842 .6392 Mdot
.66665 .61568 Mdot
.62744 .5647 Mdot
.43922 .40785 Mdot
.40393 .37648 Mdot
.75292 .72939 Mdot
.81958 .8235 Mdot
.6196 .58823 Mdot
.64313 .6196 Mdot
.64705 .64313 Mdot
.64313 .65097 Mdot
.6392 .65489 Mdot
.63528 .65489 Mdot
.62744 .65097 Mdot
.62352 .6392 Mdot
.63136 .63528 Mdot
.6392 .6392 Mdot
.64705 .64313 Mdot
.65097 .6392 Mdot
.65881 .63528 Mdot
.66665 .63528 Mdot
.66665 .63528 Mdot
.65489 .62744 Mdot
.66665 .6392 Mdot
.6745 .65097 Mdot
.67842 .66665 Mdot
.68234 .67057 Mdot
.67842 .66665 Mdot
.68626 .6745 Mdot
.67842 .66665 Mdot
.67842 .66665 Mdot
.68626 .66665 Mdot
.68626 .65489 Mdot
.6941 .65097 Mdot
.6745 .62352 Mdot
.59215 .55686 Mdot
.52941 .50196 Mdot
.39609 .40785 Mdot
.34119 .36864 Mdot
.77645 .76076 Mdot
.89017 .8784 Mdot
.60391 .57646 Mdot
.63136 .60783 Mdot
.63528 .6196 Mdot
.63136 .62744 Mdot
.6196 .62744 Mdot
.62352 .6392 Mdot
.63136 .64705 Mdot
.62744 .6392 Mdot
.63136 .6392 Mdot
.6392 .63528 Mdot
.65097 .64705 Mdot
.66273 .65489 Mdot
.66665 .64705 Mdot
.6745 .64705 Mdot
.6745 .6392 Mdot
.66273 .64705 Mdot
.67057 .66273 Mdot
.66665 .66273 Mdot
.67057 .65881 Mdot
.6745 .67057 Mdot
.67842 .67057 Mdot
.68234 .67057 Mdot
.68234 .6745 Mdot
.69018 .67842 Mdot
.70194 .68234 Mdot
.70587 .67842 Mdot
.69018 .65489 Mdot
.70194 .65097 Mdot
.54509 .51372 Mdot
.41961 .41569 Mdot
.4353 .43138 Mdot
.48235 .47451 Mdot
.65881 .60783 Mdot
.6392 .59215 Mdot
.74116 .70587 Mdot
.84703 .81958 Mdot
.59607 .58431 Mdot
.62352 .62352 Mdot
.63528 .64705 Mdot
.62352 .64705 Mdot
.61568 .63528 Mdot
.61568 .63136 Mdot
.62744 .63528 Mdot
.63136 .63136 Mdot
.63136 .62744 Mdot
.64313 .64313 Mdot
.64313 .65489 Mdot
.64705 .66665 Mdot
.66273 .6745 Mdot
.65881 .66273 Mdot
.66273 .65097 Mdot
.67057 .65881 Mdot
.68234 .67842 Mdot
.6745 .67842 Mdot
.6745 .6745 Mdot
.67842 .6745 Mdot
.67842 .67057 Mdot
.67842 .66665 Mdot
.6941 .68626 Mdot
.69802 .69018 Mdot
.69802 .67842 Mdot
.6941 .67057 Mdot
.6941 .67057 Mdot
.70979 .6745 Mdot
.59999 .57254 Mdot
.42746 .4353 Mdot
.42746 .43138 Mdot
.61568 .58039 Mdot
.66665 .62744 Mdot
.6745 .6392 Mdot
.70194 .65489 Mdot
.70979 .66273 Mdot
.71371 .67057 Mdot
.76076 .73724 Mdot
.81958 .81566 Mdot
.59999 .59999 Mdot
.62352 .64705 Mdot
.63136 .66665 Mdot
.6196 .65881 Mdot
.6196 .65489 Mdot
.62744 .65881 Mdot
.63528 .65489 Mdot
.63136 .6392 Mdot
.6392 .64313 Mdot
.6392 .65097 Mdot
.6392 .65881 Mdot
.64705 .66273 Mdot
.65097 .66273 Mdot
.65881 .66273 Mdot
.65489 .65881 Mdot
.65881 .66273 Mdot
.6745 .68234 Mdot
.67057 .68626 Mdot
.6745 .67842 Mdot
.68626 .67842 Mdot
.69018 .6745 Mdot
.67842 .6745 Mdot
.68234 .68626 Mdot
.69018 .69018 Mdot
.70194 .69802 Mdot
.70587 .69802 Mdot
.70979 .68626 Mdot
.70979 .68626 Mdot
.6745 .65881 Mdot
.6392 .62744 Mdot
.60783 .59215 Mdot
.65097 .6196 Mdot
.69802 .65489 Mdot
.69802 .66665 Mdot
.70979 .68234 Mdot
.71371 .68626 Mdot
.70979 .69018 Mdot
.70979 .69018 Mdot
.69802 .67842 Mdot
.70194 .6745 Mdot
.85487 .83527 Mdot
.9333 .92154 Mdot
.58823 .59215 Mdot
.60783 .63528 Mdot
.62744 .66665 Mdot
.62352 .67057 Mdot
.61568 .66273 Mdot
.61176 .65097 Mdot
.61568 .65097 Mdot
.62352 .64313 Mdot
.63528 .65489 Mdot
.6392 .65881 Mdot
.63136 .65097 Mdot
.65097 .65881 Mdot
.65881 .66273 Mdot
.65489 .65881 Mdot
.65489 .66273 Mdot
.65881 .66273 Mdot
.68234 .68626 Mdot
.69018 .6941 Mdot
.68234 .67842 Mdot
.67842 .68234 Mdot
.68234 .67842 Mdot
.68234 .67842 Mdot
.68234 .6745 Mdot
.68626 .68234 Mdot
.6941 .68626 Mdot
.70194 .68626 Mdot
.69802 .6745 Mdot
.70979 .68234 Mdot
.70979 .67842 Mdot
.70194 .66665 Mdot
.68626 .65489 Mdot
.69802 .66273 Mdot
.70979 .67057 Mdot
.70587 .67842 Mdot
.70979 .69018 Mdot
.72155 .70587 Mdot
.71763 .70194 Mdot
.72939 .71371 Mdot
.72155 .70194 Mdot
.72547 .69802 Mdot
.70587 .6745 Mdot
.72547 .67057 Mdot
.72547 .64313 Mdot
.8588 .81958 Mdot
.92546 .90585 Mdot
.59607 .59999 Mdot
.6196 .62744 Mdot
.62744 .64705 Mdot
.62352 .65881 Mdot
.61568 .65881 Mdot
.61176 .64313 Mdot
.61568 .6392 Mdot
.61176 .6392 Mdot
.62352 .64705 Mdot
.63528 .65489 Mdot
.6392 .65489 Mdot
.64313 .64705 Mdot
.64705 .65097 Mdot
.65097 .66273 Mdot
.65489 .66665 Mdot
.65489 .66273 Mdot
.67057 .67057 Mdot
.6745 .6745 Mdot
.68626 .68234 Mdot
.67842 .68234 Mdot
.69018 .69018 Mdot
.67842 .68234 Mdot
.69018 .69018 Mdot
.6941 .70194 Mdot
.6941 .70979 Mdot
.69802 .70587 Mdot
.6941 .6941 Mdot
.70979 .69802 Mdot
.70979 .69018 Mdot
.70194 .68234 Mdot
.70587 .68234 Mdot
.70194 .67842 Mdot
.70194 .68234 Mdot
.70979 .68234 Mdot
.71763 .6941 Mdot
.72155 .70194 Mdot
.71763 .70587 Mdot
.72939 .71371 Mdot
.73332 .70979 Mdot
.73724 .70979 Mdot
.72939 .69018 Mdot
.72939 .6745 Mdot
.74508 .67057 Mdot
.74116 .66665 Mdot
.72547 .65881 Mdot
.79998 .749 Mdot
.87448 .83919 Mdot
.58823 .59215 Mdot
.62352 .63528 Mdot
.63528 .65881 Mdot
.63136 .66273 Mdot
.61568 .65097 Mdot
.61568 .64705 Mdot
.61568 .64705 Mdot
.62352 .65881 Mdot
.62352 .66273 Mdot
.62352 .65881 Mdot
.63528 .66273 Mdot
.64705 .67057 Mdot
.64313 .66665 Mdot
.65097 .67842 Mdot
.65489 .67842 Mdot
.65489 .6745 Mdot
.65097 .67057 Mdot
.65489 .6745 Mdot
.67057 .68626 Mdot
.67057 .6941 Mdot
.67842 .69802 Mdot
.67842 .70587 Mdot
.68626 .70979 Mdot
.70194 .72155 Mdot
.6941 .71763 Mdot
.69018 .70979 Mdot
.69018 .70979 Mdot
.6941 .70587 Mdot
.70587 .71371 Mdot
.69802 .70194 Mdot
.70979 .70979 Mdot
.71763 .71371 Mdot
.71371 .70587 Mdot
.70979 .69018 Mdot
.71371 .69018 Mdot
.72547 .70979 Mdot
.73332 .72155 Mdot
.73332 .72155 Mdot
.73332 .71371 Mdot
.73332 .70587 Mdot
.73724 .6941 Mdot
.73724 .67842 Mdot
.749 .67842 Mdot
.749 .67842 Mdot
.749 .68234 Mdot
.749 .68626 Mdot
.74116 .68626 Mdot
.74116 .6941 Mdot
.79213 .76076 Mdot
.87448 .84703 Mdot
.58823 .59999 Mdot
.6196 .6392 Mdot
.63528 .66273 Mdot
.62352 .66273 Mdot
.6196 .65489 Mdot
.6196 .65097 Mdot
.61176 .64313 Mdot
.62744 .65097 Mdot
.63136 .66273 Mdot
.6196 .65489 Mdot
.64313 .67057 Mdot
.6392 .67057 Mdot
.65097 .67842 Mdot
.64313 .6745 Mdot
.65097 .67842 Mdot
.64313 .6745 Mdot
.64313 .6745 Mdot
.6392 .6745 Mdot
.64313 .6745 Mdot
.65097 .67842 Mdot
.66273 .69018 Mdot
.66273 .69018 Mdot
.6745 .70194 Mdot
.6941 .71763 Mdot
.69802 .72155 Mdot
.6941 .71371 Mdot
.69018 .70979 Mdot
.69802 .71371 Mdot
.6941 .70979 Mdot
.70194 .70587 Mdot
.70194 .70194 Mdot
.70587 .70194 Mdot
.70979 .69802 Mdot
.72155 .70587 Mdot
.72155 .71371 Mdot
.72155 .71371 Mdot
.72547 .71763 Mdot
.72939 .72155 Mdot
.72939 .71763 Mdot
.74116 .70979 Mdot
.74116 .70194 Mdot
.74116 .68626 Mdot
.749 .69018 Mdot
.75292 .69018 Mdot
.749 .68234 Mdot
.749 .68234 Mdot
.74508 .68234 Mdot
.75292 .6941 Mdot
.749 .69018 Mdot
.749 .69018 Mdot
.73332 .67842 Mdot
.85095 .81958 Mdot
.91761 .89801 Mdot
.52549 .54902 Mdot
.62352 .63136 Mdot
.61568 .64313 Mdot
.59999 .64313 Mdot
.59215 .6392 Mdot
.60783 .64313 Mdot
.60783 .6392 Mdot
.62352 .65097 Mdot
.62744 .65881 Mdot
.62744 .66273 Mdot
.62352 .65489 Mdot
.63528 .66273 Mdot
.6392 .67057 Mdot
.64313 .67057 Mdot
.64705 .67057 Mdot
.64313 .66665 Mdot
.65097 .67842 Mdot
.65489 .68234 Mdot
.65881 .68626 Mdot
.65489 .68234 Mdot
.65489 .68234 Mdot
.65881 .68626 Mdot
.65881 .68626 Mdot
.66273 .68626 Mdot
.6745 .68626 Mdot
.68626 .68234 Mdot
.68626 .68234 Mdot
.70194 .70194 Mdot
.69802 .70979 Mdot
.6941 .70587 Mdot
.69802 .6941 Mdot
.70194 .68626 Mdot
.70194 .69018 Mdot
.71763 .70587 Mdot
.72155 .71763 Mdot
.70587 .70194 Mdot
.71371 .71371 Mdot
.72155 .71371 Mdot
.72547 .70587 Mdot
.72939 .69802 Mdot
.72547 .69018 Mdot
.749 .69802 Mdot
.749 .69018 Mdot
.74116 .67842 Mdot
.74116 .6745 Mdot
.749 .67842 Mdot
.75292 .67842 Mdot
.74508 .6745 Mdot
.749 .6745 Mdot
.75684 .68626 Mdot
.75292 .69018 Mdot
.74508 .67842 Mdot
.74116 .66665 Mdot
.64313 .56862 Mdot
.75292 .72939 Mdot
.86664 .85487 Mdot
.55686 .5647 Mdot
.59607 .59999 Mdot
.61176 .63136 Mdot
.60783 .64313 Mdot
.59215 .6392 Mdot
.59215 .64313 Mdot
.58823 .6392 Mdot
.60783 .65489 Mdot
.6196 .67057 Mdot
.62352 .6745 Mdot
.62352 .66273 Mdot
.62352 .65881 Mdot
.6392 .67057 Mdot
.63136 .65881 Mdot
.64313 .65881 Mdot
.64313 .65881 Mdot
.65097 .66665 Mdot
.65881 .67057 Mdot
.66273 .66665 Mdot
.66273 .66665 Mdot
.67057 .67057 Mdot
.66665 .6745 Mdot
.65881 .67057 Mdot
.66665 .68234 Mdot
.6745 .68234 Mdot
.69018 .6745 Mdot
.69802 .68234 Mdot
.6941 .67842 Mdot
.70587 .69018 Mdot
.70979 .6941 Mdot
.71371 .6941 Mdot
.71371 .6941 Mdot
.70979 .68626 Mdot
.70587 .68626 Mdot
.71763 .70194 Mdot
.70587 .70194 Mdot
.71371 .71371 Mdot
.71371 .70979 Mdot
.71763 .70194 Mdot
.72547 .70587 Mdot
.73332 .70979 Mdot
.73332 .6941 Mdot
.74508 .6941 Mdot
.749 .6941 Mdot
.74508 .68626 Mdot
.74508 .68234 Mdot
.749 .6745 Mdot
.75292 .6745 Mdot
.74508 .6745 Mdot
.75292 .68626 Mdot
.749 .69018 Mdot
.75292 .68626 Mdot
.75292 .68234 Mdot
.74116 .6745 Mdot
.70587 .6392 Mdot
.69018 .6196 Mdot
.76469 .71763 Mdot
.80782 .78429 Mdot
.58431 .56862 Mdot
.60783 .60391 Mdot
.6196 .63528 Mdot
.60783 .6392 Mdot
.58823 .63528 Mdot
.59215 .63528 Mdot
.60391 .6392 Mdot
.60783 .63528 Mdot
.61176 .6392 Mdot
.61568 .64705 Mdot
.6196 .65097 Mdot
.62352 .65097 Mdot
.63136 .65881 Mdot
.6392 .65881 Mdot
.63528 .64705 Mdot
.64313 .65097 Mdot
.64705 .66273 Mdot
.64705 .65489 Mdot
.64705 .65097 Mdot
.65489 .65489 Mdot
.65489 .65489 Mdot
.65881 .66273 Mdot
.65881 .67057 Mdot
.67057 .6745 Mdot
.66665 .67057 Mdot
.6745 .6745 Mdot
.68234 .68626 Mdot
.68626 .69018 Mdot
.68626 .68626 Mdot
.69802 .68626 Mdot
.69802 .68626 Mdot
.70979 .6941 Mdot
.71371 .6941 Mdot
.70979 .69018 Mdot
.70587 .6941 Mdot
.72155 .70587 Mdot
.70979 .70587 Mdot
.72155 .70587 Mdot
.71371 .69018 Mdot
.72547 .69802 Mdot
.72939 .69802 Mdot
.72547 .68626 Mdot
.73724 .6941 Mdot
.749 .69802 Mdot
.749 .69802 Mdot
.749 .6941 Mdot
.749 .69018 Mdot
.749 .67842 Mdot
.74508 .67842 Mdot
.75684 .68626 Mdot
.76469 .6941 Mdot
.76076 .69018 Mdot
.76076 .68234 Mdot
.75292 .67057 Mdot
.74508 .6745 Mdot
.74116 .6745 Mdot
.74508 .66665 Mdot
.74116 .65881 Mdot
.72155 .63528 Mdot
.78037 .71763 Mdot
.63136 .6392 Mdot
.53333 .52549 Mdot
.60783 .60391 Mdot
.61568 .63136 Mdot
.61176 .6392 Mdot
.60391 .64313 Mdot
.59999 .65097 Mdot
.61176 .65881 Mdot
.61568 .65097 Mdot
.6196 .65097 Mdot
.62352 .64705 Mdot
.62352 .64705 Mdot
.6196 .64705 Mdot
.62352 .65097 Mdot
.63528 .65097 Mdot
.6392 .64705 Mdot
.64705 .65489 Mdot
.64705 .65881 Mdot
.65881 .6745 Mdot
.65489 .65881 Mdot
.66665 .66273 Mdot
.65881 .65097 Mdot
.66273 .65881 Mdot
.67057 .66273 Mdot
.68234 .6745 Mdot
.67842 .68234 Mdot
.68234 .68234 Mdot
.69018 .69802 Mdot
.6941 .69802 Mdot
.68234 .69018 Mdot
.70194 .69802 Mdot
.70194 .69018 Mdot
.70979 .69802 Mdot
.70587 .69018 Mdot
.70979 .69802 Mdot
.70979 .69802 Mdot
.72155 .70979 Mdot
.72547 .70587 Mdot
.71763 .6941 Mdot
.72939 .69802 Mdot
.72547 .69802 Mdot
.72939 .69802 Mdot
.72547 .69018 Mdot
.73724 .69802 Mdot
.74116 .69802 Mdot
.749 .70194 Mdot
.74508 .70194 Mdot
.749 .69018 Mdot
.749 .68626 Mdot
.749 .67842 Mdot
.76076 .68234 Mdot
.75684 .68234 Mdot
.75684 .68234 Mdot
.75292 .68626 Mdot
.75292 .68234 Mdot
.76861 .6941 Mdot
.76076 .68234 Mdot
.76076 .67842 Mdot
.76469 .67842 Mdot
.76861 .6745 Mdot
.79213 .67842 Mdot
.49804 .45098 Mdot
.26276 .26276 Mdot
.65489 .6392 Mdot
.89801 .87056 Mdot
.53333 .52549 Mdot
.58431 .59215 Mdot
.60391 .63136 Mdot
.61568 .65489 Mdot
.60783 .65881 Mdot
.61176 .66665 Mdot
.60391 .66273 Mdot
.61568 .66665 Mdot
.6196 .66665 Mdot
.6196 .65489 Mdot
.63136 .65881 Mdot
.63528 .66273 Mdot
.63136 .66273 Mdot
.6392 .67057 Mdot
.64313 .66665 Mdot
.64313 .65881 Mdot
.65489 .66665 Mdot
.66273 .68234 Mdot
.65489 .67842 Mdot
.66273 .68234 Mdot
.6745 .68626 Mdot
.67057 .68234 Mdot
.67057 .68234 Mdot
.67057 .68234 Mdot
.67842 .68626 Mdot
.68234 .69018 Mdot
.6941 .69802 Mdot
.69802 .69802 Mdot
.69018 .6941 Mdot
.6941 .69802 Mdot
.71371 .70587 Mdot
.70979 .69802 Mdot
.71763 .70587 Mdot
.71371 .71763 Mdot
.71763 .72155 Mdot
.72155 .72547 Mdot
.73332 .72155 Mdot
.73332 .71763 Mdot
.74116 .71371 Mdot
.73724 .71763 Mdot
.73332 .71371 Mdot
.72939 .70979 Mdot
.74508 .71763 Mdot
.749 .71763 Mdot
.74508 .70979 Mdot
.749 .70194 Mdot
.75684 .70194 Mdot
.75684 .69018 Mdot
.75684 .68234 Mdot
.75684 .67842 Mdot
.77253 .6941 Mdot
.76076 .69802 Mdot
.76076 .70587 Mdot
.76469 .71371 Mdot
.76076 .70979 Mdot
.76469 .71371 Mdot
.77253 .70587 Mdot
.77645 .6941 Mdot
.77645 .67842 Mdot
.79213 .6745 Mdot
.76469 .64313 Mdot
.50588 .4353 Mdot
.35295 .33335 Mdot
.73724 .63136 Mdot
.6196 .54902 Mdot
.85095 .80782 Mdot
.92154 .89801 Mdot
.51765 .52157 Mdot
.58431 .60783 Mdot
.59999 .6392 Mdot
.60391 .65097 Mdot
.59215 .64705 Mdot
.59999 .64705 Mdot
.59607 .64705 Mdot
.60391 .64705 Mdot
.61568 .65097 Mdot
.62744 .65881 Mdot
.63136 .65489 Mdot
.62352 .65489 Mdot
.6196 .66273 Mdot
.63528 .67057 Mdot
.64705 .67057 Mdot
.62744 .65097 Mdot
.6392 .65097 Mdot
.65097 .66273 Mdot
.66273 .68234 Mdot
.66665 .6941 Mdot
.66273 .70194 Mdot
.66273 .69802 Mdot
.67057 .69802 Mdot
.67057 .69018 Mdot
.66665 .68626 Mdot
.67842 .6941 Mdot
.67842 .69018 Mdot
.67842 .6941 Mdot
.67842 .69802 Mdot
.69018 .70194 Mdot
.70194 .70587 Mdot
.70587 .70587 Mdot
.70979 .71763 Mdot
.70194 .71763 Mdot
.69802 .71371 Mdot
.70979 .72155 Mdot
.71371 .72939 Mdot
.70979 .72155 Mdot
.72155 .71763 Mdot
.70979 .70587 Mdot
.71371 .70979 Mdot
.72155 .70979 Mdot
.73724 .72547 Mdot
.73724 .72155 Mdot
.749 .72155 Mdot
.74116 .70979 Mdot
.74508 .70979 Mdot
.74508 .69802 Mdot
.749 .70194 Mdot
.749 .69802 Mdot
.75292 .6941 Mdot
.75292 .70587 Mdot
.76076 .72155 Mdot
.76076 .72547 Mdot
.75684 .71763 Mdot
.76076 .70587 Mdot
.76469 .70587 Mdot
.76861 .69802 Mdot
.76861 .6745 Mdot
.76469 .66273 Mdot
.76076 .66665 Mdot
.74508 .66273 Mdot
.70587 .6392 Mdot
.72939 .65489 Mdot
.74116 .67057 Mdot
.749 .66665 Mdot
.74116 .65097 Mdot
.79998 .72939 Mdot
.69018 .68234 Mdot
.53725 .54902 Mdot
.57646 .61568 Mdot
.57646 .63136 Mdot
.57646 .63528 Mdot
.58431 .63528 Mdot
.59607 .6392 Mdot
.59999 .63528 Mdot
.59607 .63136 Mdot
.60783 .64313 Mdot
.61568 .64705 Mdot
.62744 .65881 Mdot
.62352 .65881 Mdot
.62352 .66273 Mdot
.62352 .65489 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.62352 .65097 Mdot
.63528 .66273 Mdot
.65489 .68234 Mdot
.64705 .69018 Mdot
.65097 .69802 Mdot
.65097 .69802 Mdot
.64705 .68626 Mdot
.66273 .6941 Mdot
.67057 .69802 Mdot
.66665 .6941 Mdot
.66665 .69802 Mdot
.67057 .70194 Mdot
.68234 .70587 Mdot
.68234 .70194 Mdot
.68234 .70194 Mdot
.68626 .70587 Mdot
.70587 .72155 Mdot
.70194 .71763 Mdot
.69802 .71763 Mdot
.70194 .72547 Mdot
.70194 .73332 Mdot
.70587 .72547 Mdot
.71763 .72155 Mdot
.71371 .71371 Mdot
.71371 .70587 Mdot
.71371 .70194 Mdot
.72939 .71371 Mdot
.73332 .71763 Mdot
.73724 .71371 Mdot
.74116 .71371 Mdot
.749 .70587 Mdot
.74508 .69802 Mdot
.74116 .69018 Mdot
.74508 .69018 Mdot
.74508 .69018 Mdot
.749 .69802 Mdot
.76076 .71371 Mdot
.76076 .71371 Mdot
.76861 .71371 Mdot
.76076 .70979 Mdot
.76076 .69802 Mdot
.76469 .68626 Mdot
.76469 .68234 Mdot
.76861 .68234 Mdot
.76469 .67842 Mdot
.76469 .68234 Mdot
.75684 .67057 Mdot
.75684 .67842 Mdot
.75292 .6745 Mdot
.76469 .67842 Mdot
.76861 .67057 Mdot
.76469 .66273 Mdot
.6941 .61568 Mdot
.67842 .60391 Mdot
.77645 .70979 Mdot
.93722 .90977 Mdot
.54117 .5647 Mdot
.58039 .6196 Mdot
.59607 .64313 Mdot
.59607 .6392 Mdot
.58823 .63528 Mdot
.58823 .63136 Mdot
.59215 .63528 Mdot
.59999 .64313 Mdot
.59999 .65097 Mdot
.60391 .65097 Mdot
.61568 .67057 Mdot
.61176 .66273 Mdot
.6196 .65881 Mdot
.63136 .66273 Mdot
.62744 .65881 Mdot
.62744 .65881 Mdot
.63136 .66273 Mdot
.6392 .66665 Mdot
.64313 .6745 Mdot
.65489 .67842 Mdot
.64313 .68234 Mdot
.64313 .6941 Mdot
.65881 .70587 Mdot
.65489 .70979 Mdot
.66665 .71371 Mdot
.67057 .70587 Mdot
.6745 .70979 Mdot
.6745 .71763 Mdot
.69018 .72547 Mdot
.68626 .71763 Mdot
.69802 .71371 Mdot
.6941 .70587 Mdot
.69802 .70194 Mdot
.6941 .70194 Mdot
.6941 .70587 Mdot
.71371 .71763 Mdot
.71763 .72547 Mdot
.72547 .72547 Mdot
.72547 .72155 Mdot
.72547 .71763 Mdot
.72155 .70194 Mdot
.72547 .70194 Mdot
.74116 .70979 Mdot
.74116 .70587 Mdot
.74116 .70979 Mdot
.74116 .70194 Mdot
.74116 .69802 Mdot
.74116 .68626 Mdot
.749 .68626 Mdot
.749 .68626 Mdot
.74508 .68234 Mdot
.74508 .69018 Mdot
.749 .69018 Mdot
.74508 .69018 Mdot
.75684 .69802 Mdot
.76861 .70587 Mdot
.76469 .70194 Mdot
.77253 .70194 Mdot
.76861 .70194 Mdot
.76469 .69802 Mdot
.76469 .67842 Mdot
.76469 .6745 Mdot
.77645 .6745 Mdot
.77645 .67842 Mdot
.77645 .6745 Mdot
.77253 .6745 Mdot
.77253 .66273 Mdot
.77645 .66273 Mdot
.78037 .66273 Mdot
.76469 .65881 Mdot
.76076 .65097 Mdot
.76469 .64705 Mdot
.76469 .6392 Mdot
.89017 .8235 Mdot
.94114 .90585 Mdot
.52941 .54902 Mdot
.58039 .60391 Mdot
.59215 .6196 Mdot
.60391 .62744 Mdot
.59215 .62744 Mdot
.59999 .64313 Mdot
.59215 .6392 Mdot
.59215 .65097 Mdot
.59999 .65097 Mdot
.60783 .65489 Mdot
.59607 .64705 Mdot
.61176 .66665 Mdot
.61568 .66665 Mdot
.62352 .65881 Mdot
.63528 .66273 Mdot
.64313 .66665 Mdot
.63136 .66273 Mdot
.63136 .66665 Mdot
.63136 .68234 Mdot
.64313 .69018 Mdot
.65097 .69018 Mdot
.64313 .6941 Mdot
.64705 .70194 Mdot
.65489 .70979 Mdot
.66665 .71371 Mdot
.67057 .70587 Mdot
.66665 .70194 Mdot
.67842 .71371 Mdot
.68626 .71763 Mdot
.67842 .70587 Mdot
.68626 .69802 Mdot
.6941 .69802 Mdot
.6941 .6941 Mdot
.69802 .6941 Mdot
.70587 .70587 Mdot
.71371 .71371 Mdot
.70587 .71371 Mdot
.71763 .71763 Mdot
.71371 .71371 Mdot
.72547 .71371 Mdot
.72547 .70587 Mdot
.73332 .69802 Mdot
.73724 .6941 Mdot
.74508 .6941 Mdot
.74116 .70194 Mdot
.73724 .69802 Mdot
.74116 .70194 Mdot
.74508 .70194 Mdot
.73724 .6941 Mdot
.76076 .70587 Mdot
.76076 .70194 Mdot
.75684 .70194 Mdot
.76076 .70194 Mdot
.76469 .69018 Mdot
.76861 .6941 Mdot
.76861 .69802 Mdot
.77253 .70587 Mdot
.76469 .70587 Mdot
.77645 .71763 Mdot
.76861 .71371 Mdot
.77253 .70587 Mdot
.76076 .68234 Mdot
.76469 .67842 Mdot
.77253 .6745 Mdot
.78037 .67057 Mdot
.78429 .66665 Mdot
.78037 .65881 Mdot
.78429 .65489 Mdot
.77253 .65097 Mdot
.78037 .65881 Mdot
.78037 .65097 Mdot
.78429 .64705 Mdot
.78429 .6392 Mdot
.77645 .63136 Mdot
.77645 .6196 Mdot
.75684 .60391 Mdot
.89017 .80782 Mdot
.50588 .53333 Mdot
.57254 .59607 Mdot
.58823 .6196 Mdot
.59215 .62352 Mdot
.58823 .6196 Mdot
.59607 .62744 Mdot
.59215 .63136 Mdot
.59607 .63528 Mdot
.59607 .63528 Mdot
.59215 .62744 Mdot
.59999 .63528 Mdot
.61176 .64705 Mdot
.60783 .65489 Mdot
.61176 .66665 Mdot
.62352 .67057 Mdot
.62352 .65881 Mdot
.63136 .66665 Mdot
.63528 .6745 Mdot
.6392 .68234 Mdot
.6392 .68234 Mdot
.6392 .68234 Mdot
.65489 .6941 Mdot
.65489 .70194 Mdot
.65097 .69802 Mdot
.65489 .70194 Mdot
.66273 .70194 Mdot
.66665 .69802 Mdot
.66273 .69802 Mdot
.66273 .70194 Mdot
.6745 .70194 Mdot
.68626 .70587 Mdot
.69018 .70194 Mdot
.69018 .6941 Mdot
.69802 .69018 Mdot
.70194 .69802 Mdot
.71371 .71371 Mdot
.70979 .72155 Mdot
.70979 .71763 Mdot
.70979 .72155 Mdot
.71371 .71763 Mdot
.72155 .70979 Mdot
.73332 .70587 Mdot
.73332 .70194 Mdot
.73332 .69802 Mdot
.74116 .70194 Mdot
.74116 .70587 Mdot
.73724 .70979 Mdot
.74116 .70979 Mdot
.749 .70979 Mdot
.74508 .70587 Mdot
.75684 .70979 Mdot
.75292 .71371 Mdot
.749 .70979 Mdot
.76076 .70587 Mdot
.75292 .68626 Mdot
.76076 .68626 Mdot
.76469 .70194 Mdot
.76861 .70979 Mdot
.75684 .70587 Mdot
.77253 .71371 Mdot
.77645 .70194 Mdot
.77645 .69018 Mdot
.77645 .68234 Mdot
.78821 .67842 Mdot
.78821 .67057 Mdot
.78037 .65097 Mdot
.78429 .64313 Mdot
.78429 .64705 Mdot
.77253 .64705 Mdot
.78037 .65881 Mdot
.77645 .65097 Mdot
.77253 .64705 Mdot
.78037 .64705 Mdot
.78429 .6392 Mdot
.77645 .63528 Mdot
.77645 .63136 Mdot
.78037 .62744 Mdot
.78429 .62352 Mdot
.78037 .67842 Mdot
.8235 .76469 Mdot
.51765 .54902 Mdot
.57254 .60391 Mdot
.59215 .62744 Mdot
.59215 .63136 Mdot
.58823 .62744 Mdot
.58823 .6392 Mdot
.58823 .63528 Mdot
.60783 .64313 Mdot
.60783 .63528 Mdot
.60783 .63136 Mdot
.6196 .64705 Mdot
.62352 .65489 Mdot
.6196 .66273 Mdot
.61176 .65881 Mdot
.62352 .67842 Mdot
.6392 .68626 Mdot
.63528 .68234 Mdot
.64313 .68626 Mdot
.64313 .68626 Mdot
.64313 .68234 Mdot
.65097 .68234 Mdot
.65881 .68234 Mdot
.65881 .6941 Mdot
.66665 .70979 Mdot
.66273 .70979 Mdot
.66273 .70587 Mdot
.67057 .70979 Mdot
.68234 .71763 Mdot
.67842 .70587 Mdot
.67057 .6941 Mdot
.68626 .6941 Mdot
.69802 .69018 Mdot
.70194 .69018 Mdot
.71371 .69802 Mdot
.70194 .69018 Mdot
.70979 .70194 Mdot
.70194 .70587 Mdot
.71371 .72155 Mdot
.71763 .73332 Mdot
.72547 .73332 Mdot
.72939 .73332 Mdot
.73332 .72939 Mdot
.73332 .71763 Mdot
.74508 .72155 Mdot
.74508 .71371 Mdot
.73724 .70194 Mdot
.73724 .70194 Mdot
.749 .72155 Mdot
.76469 .73332 Mdot
.749 .71763 Mdot
.76469 .72547 Mdot
.749 .71763 Mdot
.749 .70587 Mdot
.75292 .70194 Mdot
.76469 .70194 Mdot
.76076 .6941 Mdot
.77645 .70587 Mdot
.77253 .70587 Mdot
.76469 .70587 Mdot
.78037 .70979 Mdot
.78429 .69802 Mdot
.78037 .68234 Mdot
.78429 .69018 Mdot
.78429 .68626 Mdot
.78429 .67057 Mdot
.78037 .65881 Mdot
.79213 .65489 Mdot
.79606 .65489 Mdot
.78037 .64705 Mdot
.78429 .65881 Mdot
.78037 .65489 Mdot
.77645 .65489 Mdot
.78821 .66273 Mdot
.78821 .65097 Mdot
.78037 .63528 Mdot
.79998 .64705 Mdot
.79606 .64705 Mdot
.78821 .64313 Mdot
.78037 .63528 Mdot
.78037 .63528 Mdot
.76469 .62744 Mdot
.83527 .73724 Mdot
.94898 .91369 Mdot
.56078 .55686 Mdot
.60783 .61176 Mdot
.6196 .6392 Mdot
.59999 .64313 Mdot
.58039 .6392 Mdot
.58823 .65489 Mdot
.58823 .65489 Mdot
.59607 .65489 Mdot
.60783 .65881 Mdot
.60783 .64313 Mdot
.60783 .64313 Mdot
.6196 .65881 Mdot
.6196 .67057 Mdot
.62744 .67057 Mdot
.63136 .67842 Mdot
.63528 .67842 Mdot
.63136 .67842 Mdot
.6392 .68626 Mdot
.64313 .67842 Mdot
.64313 .6745 Mdot
.65489 .68234 Mdot
.65489 .68626 Mdot
.65489 .69018 Mdot
.66273 .70194 Mdot
.67057 .70587 Mdot
.66665 .69802 Mdot
.67057 .70194 Mdot
.67842 .70194 Mdot
.68234 .70587 Mdot
.68626 .6941 Mdot
.69018 .6941 Mdot
.69802 .70587 Mdot
.70194 .69802 Mdot
.70194 .69018 Mdot
.6941 .68626 Mdot
.70587 .69018 Mdot
.71763 .70587 Mdot
.71763 .71371 Mdot
.71763 .71763 Mdot
.72155 .71763 Mdot
.72547 .71763 Mdot
.71763 .70979 Mdot
.73332 .71763 Mdot
.73332 .71763 Mdot
.73724 .71763 Mdot
.73332 .71371 Mdot
.73332 .71371 Mdot
.74116 .72155 Mdot
.75292 .73332 Mdot
.73724 .72155 Mdot
.749 .72939 Mdot
.75684 .73332 Mdot
.76076 .72155 Mdot
.76076 .71371 Mdot
.75684 .70587 Mdot
.76469 .70194 Mdot
.76861 .70194 Mdot
.77253 .70979 Mdot
.78037 .71763 Mdot
.76861 .69802 Mdot
.76861 .69018 Mdot
.78821 .69802 Mdot
.78037 .69018 Mdot
.78037 .68626 Mdot
.77253 .67057 Mdot
.77253 .66665 Mdot
.78429 .66665 Mdot
.78821 .66273 Mdot
.78037 .65881 Mdot
.77645 .65881 Mdot
.77253 .65489 Mdot
.78037 .65881 Mdot
.79213 .66273 Mdot
.79606 .65881 Mdot
.79606 .65097 Mdot
.79998 .65881 Mdot
.79606 .65097 Mdot
.79213 .65097 Mdot
.78037 .6392 Mdot
.78821 .64705 Mdot
.78429 .65489 Mdot
.78037 .65489 Mdot
.77645 .65097 Mdot
.77253 .64313 Mdot
.86272 .79998 Mdot
.90977 .88232 Mdot
.5647 .57254 Mdot
.58823 .6196 Mdot
.59999 .6392 Mdot
.58823 .64313 Mdot
.57646 .65489 Mdot
.58823 .6745 Mdot
.59999 .68234 Mdot
.60391 .6745 Mdot
.61568 .66273 Mdot
.61568 .64313 Mdot
.61176 .6392 Mdot
.6196 .64313 Mdot
.6196 .65489 Mdot
.62352 .65881 Mdot
.63136 .66273 Mdot
.63136 .66665 Mdot
.63528 .6745 Mdot
.63528 .68234 Mdot
.6392 .67842 Mdot
.64313 .6745 Mdot
.65881 .68626 Mdot
.65097 .68234 Mdot
.65489 .68626 Mdot
.65489 .6941 Mdot
.65097 .69018 Mdot
.66665 .69802 Mdot
.67057 .6941 Mdot
.6745 .69802 Mdot
.6745 .6941 Mdot
.66665 .68626 Mdot
.68626 .6941 Mdot
.69802 .70587 Mdot
.69802 .70587 Mdot
.69802 .70587 Mdot
.69018 .69802 Mdot
.69802 .69802 Mdot
.70587 .70979 Mdot
.70587 .71371 Mdot
.71371 .71371 Mdot
.72155 .71371 Mdot
.71371 .70979 Mdot
.70979 .70587 Mdot
.72155 .71371 Mdot
.73724 .72939 Mdot
.73332 .72547 Mdot
.73332 .72155 Mdot
.72939 .71763 Mdot
.74116 .72939 Mdot
.73724 .72547 Mdot
.74116 .72547 Mdot
.74508 .72547 Mdot
.75292 .72547 Mdot
.76076 .72547 Mdot
.749 .71371 Mdot
.74508 .72155 Mdot
.75292 .72155 Mdot
.75684 .72155 Mdot
.76076 .72155 Mdot
.75684 .71763 Mdot
.76076 .71371 Mdot
.76861 .70194 Mdot
.78037 .70194 Mdot
.77645 .6941 Mdot
.78429 .6941 Mdot
.78429 .68626 Mdot
.77645 .67842 Mdot
.78037 .68234 Mdot
.77645 .67842 Mdot
.78037 .68234 Mdot
.78037 .68626 Mdot
.78821 .69018 Mdot
.77645 .67842 Mdot
.76469 .67057 Mdot
.77645 .66665 Mdot
.78821 .66665 Mdot
.79998 .65881 Mdot
.79606 .65489 Mdot
.78821 .65881 Mdot
.78429 .65489 Mdot
.78429 .66273 Mdot
.78037 .66665 Mdot
.78429 .66665 Mdot
.78429 .66273 Mdot
.77253 .65881 Mdot
.76861 .65489 Mdot
.749 .64313 Mdot
.75684 .65097 Mdot
.88232 .82743 Mdot
.56862 .58431 Mdot
.58431 .62744 Mdot
.59607 .65881 Mdot
.59215 .66665 Mdot
.58823 .6745 Mdot
.58431 .6745 Mdot
.57254 .66273 Mdot
.58431 .66273 Mdot
.60783 .66273 Mdot
.61568 .65881 Mdot
.6196 .65489 Mdot
.62352 .66273 Mdot
.62744 .66665 Mdot
.63136 .67057 Mdot
.63528 .6745 Mdot
.6392 .67842 Mdot
.62744 .67057 Mdot
.63528 .68234 Mdot
.6392 .69018 Mdot
.65097 .69802 Mdot
.64705 .68234 Mdot
.65881 .68626 Mdot
.65489 .67842 Mdot
.65489 .67842 Mdot
.64705 .68234 Mdot
.64313 .67842 Mdot
.66273 .69018 Mdot
.67057 .6941 Mdot
.6745 .6941 Mdot
.68234 .70194 Mdot
.68234 .6941 Mdot
.6941 .70194 Mdot
.69018 .69018 Mdot
.69018 .69802 Mdot
.68626 .69802 Mdot
.68626 .69802 Mdot
.69802 .70587 Mdot
.70587 .70587 Mdot
.70194 .70194 Mdot
.72155 .71371 Mdot
.72939 .73332 Mdot
.72155 .72939 Mdot
.71763 .72155 Mdot
.71763 .71763 Mdot
.72547 .72547 Mdot
.72939 .73332 Mdot
.73724 .73724 Mdot
.73724 .73724 Mdot
.73724 .74116 Mdot
.73724 .74116 Mdot
.74116 .73724 Mdot
.749 .74116 Mdot
.749 .74116 Mdot
.75292 .73724 Mdot
.749 .72939 Mdot
.75684 .73332 Mdot
.75292 .72939 Mdot
.76861 .73724 Mdot
.76861 .72939 Mdot
.76861 .71763 Mdot
.76469 .69802 Mdot
.77253 .70194 Mdot
.77253 .69802 Mdot
.78037 .70194 Mdot
.78037 .70194 Mdot
.78429 .71371 Mdot
.78429 .70979 Mdot
.77645 .70587 Mdot
.77645 .70587 Mdot
.77253 .69802 Mdot
.78037 .69802 Mdot
.78429 .69802 Mdot
.78037 .69018 Mdot
.78037 .69018 Mdot
.78037 .6745 Mdot
.79213 .67842 Mdot
.78037 .66273 Mdot
.79213 .6745 Mdot
.79213 .68234 Mdot
.78821 .68626 Mdot
.78429 .67842 Mdot
.78429 .6745 Mdot
.77645 .66665 Mdot
.78821 .6745 Mdot
.78037 .6745 Mdot
.77253 .66665 Mdot
.76076 .65881 Mdot
.76861 .65881 Mdot
.76469 .65097 Mdot
.81566 .72547 Mdot
.86664 .81174 Mdot
.56078 .58431 Mdot
.58431 .63136 Mdot
.59607 .65489 Mdot
.58431 .66665 Mdot
.58431 .6745 Mdot
.58431 .67057 Mdot
.58823 .66665 Mdot
.59607 .66273 Mdot
.61176 .66665 Mdot
.61176 .65881 Mdot
.60783 .65881 Mdot
.61568 .66665 Mdot
.62352 .6745 Mdot
.6392 .68626 Mdot
.62744 .67842 Mdot
.62744 .67842 Mdot
.63136 .67842 Mdot
.64313 .6941 Mdot
.64313 .70194 Mdot
.64705 .70194 Mdot
.65097 .70194 Mdot
.65881 .69018 Mdot
.65881 .68626 Mdot
.65881 .68234 Mdot
.6745 .6941 Mdot
.65881 .69018 Mdot
.65881 .68626 Mdot
.66665 .69018 Mdot
.67842 .69802 Mdot
.68234 .69802 Mdot
.6745 .69802 Mdot
.67842 .70194 Mdot
.69018 .70979 Mdot
.69018 .70979 Mdot
.6941 .71371 Mdot
.69802 .70979 Mdot
.70194 .71763 Mdot
.70979 .71763 Mdot
.71371 .70979 Mdot
.72155 .71371 Mdot
.71763 .71763 Mdot
.72155 .72939 Mdot
.73332 .74508 Mdot
.72939 .73724 Mdot
.72939 .71763 Mdot
.73724 .72155 Mdot
.73724 .73332 Mdot
.74116 .73724 Mdot
.73332 .73332 Mdot
.74508 .74508 Mdot
.749 .75684 Mdot
.75684 .76469 Mdot
.75292 .76469 Mdot
.75292 .75684 Mdot
.75292 .75292 Mdot
.75292 .749 Mdot
.749 .73724 Mdot
.76076 .74116 Mdot
.76076 .73332 Mdot
.77645 .72939 Mdot
.78429 .72547 Mdot
.77253 .71371 Mdot
.77253 .70979 Mdot
.77645 .71763 Mdot
.77645 .71763 Mdot
.77253 .71371 Mdot
.77645 .71763 Mdot
.78429 .72155 Mdot
.78821 .72547 Mdot
.78429 .72155 Mdot
.78429 .71763 Mdot
.78429 .71371 Mdot
.78429 .70587 Mdot
.78821 .70587 Mdot
.78429 .6941 Mdot
.79213 .68626 Mdot
.78429 .67842 Mdot
.78821 .68626 Mdot
.78821 .6941 Mdot
.79606 .6941 Mdot
.79606 .69802 Mdot
.78429 .68626 Mdot
.78821 .67842 Mdot
.79213 .67842 Mdot
.78821 .68234 Mdot
.78821 .69018 Mdot
.78821 .68626 Mdot
.78037 .6745 Mdot
.78821 .67842 Mdot
.78037 .67057 Mdot
.78037 .66665 Mdot
.76469 .65097 Mdot
.81174 .72547 Mdot
.93722 .90977 Mdot
.55294 .58039 Mdot
.58431 .63136 Mdot
.60783 .66273 Mdot
.59607 .66273 Mdot
.58039 .67057 Mdot
.57646 .66665 Mdot
.58823 .66665 Mdot
.59607 .67057 Mdot
.59999 .6745 Mdot
.60783 .67842 Mdot
.61568 .68626 Mdot
.61568 .68626 Mdot
.62744 .69018 Mdot
.63528 .68626 Mdot
.63136 .68234 Mdot
.63136 .68626 Mdot
.62352 .68626 Mdot
.63528 .6941 Mdot
.63528 .6941 Mdot
.6392 .6941 Mdot
.65489 .69802 Mdot
.65097 .68626 Mdot
.65489 .68626 Mdot
.65881 .68626 Mdot
.6745 .6941 Mdot
.66665 .69018 Mdot
.67842 .69802 Mdot
.66665 .6941 Mdot
.67842 .70587 Mdot
.68626 .71371 Mdot
.6941 .71763 Mdot
.68626 .71763 Mdot
.68626 .73332 Mdot
.69018 .74116 Mdot
.6941 .72939 Mdot
.68626 .71763 Mdot
.69802 .72155 Mdot
.70194 .72155 Mdot
.71371 .72547 Mdot
.72155 .72939 Mdot
.71763 .72155 Mdot
.72547 .72939 Mdot
.71371 .72939 Mdot
.72547 .74508 Mdot
.72547 .73724 Mdot
.73332 .73724 Mdot
.73332 .74116 Mdot
.73332 .74508 Mdot
.72939 .74116 Mdot
.73724 .74508 Mdot
.74508 .75684 Mdot
.749 .76076 Mdot
.76076 .76076 Mdot
.75684 .75292 Mdot
.76076 .75292 Mdot
.75684 .74508 Mdot
.75684 .73724 Mdot
.76469 .73724 Mdot
.76076 .72547 Mdot
.77645 .72547 Mdot
.79213 .72939 Mdot
.77253 .70979 Mdot
.76861 .70194 Mdot
.77253 .70194 Mdot
.76861 .69802 Mdot
.77645 .70587 Mdot
.76861 .71371 Mdot
.78037 .72155 Mdot
.78429 .72547 Mdot
.78821 .72547 Mdot
.78821 .71371 Mdot
.77645 .70194 Mdot
.78037 .70194 Mdot
.78429 .69802 Mdot
.78821 .68626 Mdot
.78037 .6745 Mdot
.78429 .6745 Mdot
.78821 .69018 Mdot
.78429 .6941 Mdot
.78821 .70194 Mdot
.78821 .69802 Mdot
.78821 .69018 Mdot
.78821 .68234 Mdot
.78821 .67842 Mdot
.78821 .68234 Mdot
.78429 .68234 Mdot
.78821 .68626 Mdot
.77253 .68234 Mdot
.76861 .67842 Mdot
.78037 .68234 Mdot
.77645 .6745 Mdot
.77645 .66665 Mdot
.77253 .66665 Mdot
.76861 .65881 Mdot
.76469 .65097 Mdot
.88232 .8235 Mdot
.93722 .90977 Mdot
.55686 .56862 Mdot
.57646 .60783 Mdot
.59607 .6392 Mdot
.59215 .65489 Mdot
.58039 .65097 Mdot
.59607 .66665 Mdot
.59215 .66665 Mdot
.59999 .68234 Mdot
.58823 .68234 Mdot
.59215 .68234 Mdot
.59999 .69018 Mdot
.61176 .69802 Mdot
.6196 .68626 Mdot
.6392 .69018 Mdot
.6392 .68626 Mdot
.62744 .68234 Mdot
.63136 .69018 Mdot
.63528 .69802 Mdot
.6392 .6941 Mdot
.64313 .69802 Mdot
.64705 .70194 Mdot
.65881 .70979 Mdot
.66273 .71371 Mdot
.67057 .71763 Mdot
.65881 .70979 Mdot
.66665 .70587 Mdot
.6745 .69802 Mdot
.6745 .69802 Mdot
.67842 .70194 Mdot
.68234 .70587 Mdot
.68234 .71371 Mdot
.67842 .71763 Mdot
.6745 .72547 Mdot
.68234 .74116 Mdot
.68626 .74116 Mdot
.69018 .73724 Mdot
.6941 .73724 Mdot
.70979 .74116 Mdot
.70587 .73724 Mdot
.70587 .74116 Mdot
.70979 .74116 Mdot
.70979 .74116 Mdot
.71371 .74508 Mdot
.70979 .74508 Mdot
.72155 .75684 Mdot
.72155 .75292 Mdot
.72547 .74508 Mdot
.73724 .749 Mdot
.73724 .75292 Mdot
.749 .76076 Mdot
.74508 .76076 Mdot
.75292 .75684 Mdot
.73724 .74116 Mdot
.75292 .749 Mdot
.76469 .75684 Mdot
.76076 .749 Mdot
.75292 .74116 Mdot
.76861 .74508 Mdot
.749 .72547 Mdot
.749 .72155 Mdot
.76861 .72155 Mdot
.77253 .71763 Mdot
.78429 .72155 Mdot
.78429 .71371 Mdot
.77253 .70587 Mdot
.78037 .71371 Mdot
.76861 .71371 Mdot
.77645 .71763 Mdot
.78429 .72155 Mdot
.78429 .72939 Mdot
.78429 .72939 Mdot
.78821 .71371 Mdot
.78821 .69802 Mdot
.78821 .69018 Mdot
.79213 .68626 Mdot
.78821 .67842 Mdot
.79606 .68234 Mdot
.78037 .67842 Mdot
.78429 .6941 Mdot
.79213 .70979 Mdot
.78821 .70979 Mdot
.78821 .70587 Mdot
.78821 .6941 Mdot
.78429 .68626 Mdot
.78821 .68626 Mdot
.78821 .6941 Mdot
.79213 .70194 Mdot
.78429 .70194 Mdot
.78429 .70587 Mdot
.77645 .6941 Mdot
.78429 .69018 Mdot
.77645 .67842 Mdot
.76861 .66273 Mdot
.78037 .66273 Mdot
.78037 .65489 Mdot
.77645 .65097 Mdot
.76469 .65097 Mdot
.69802 .60391 Mdot
.86664 .81566 Mdot
.54902 .56078 Mdot
.57646 .60783 Mdot
.58431 .63136 Mdot
.58823 .65097 Mdot
.58823 .64705 Mdot
.58823 .65097 Mdot
.59999 .65489 Mdot
.59215 .65881 Mdot
.58823 .66665 Mdot
.59999 .67057 Mdot
.61176 .68234 Mdot
.61568 .68626 Mdot
.62352 .67842 Mdot
.62352 .67842 Mdot
.62744 .67842 Mdot
.63136 .68234 Mdot
.62744 .68234 Mdot
.62744 .69802 Mdot
.62744 .6941 Mdot
.63136 .6941 Mdot
.65097 .70587 Mdot
.65489 .70979 Mdot
.64705 .70979 Mdot
.64705 .71371 Mdot
.64705 .72155 Mdot
.66665 .72155 Mdot
.6745 .71371 Mdot
.6745 .70979 Mdot
.67842 .70587 Mdot
.67842 .71371 Mdot
.68234 .71371 Mdot
.68626 .70979 Mdot
.68626 .72155 Mdot
.6941 .74116 Mdot
.69018 .74116 Mdot
.6941 .74508 Mdot
.6941 .749 Mdot
.69802 .749 Mdot
.69802 .749 Mdot
.70194 .75292 Mdot
.70979 .749 Mdot
.71763 .75292 Mdot
.71763 .75292 Mdot
.72547 .76076 Mdot
.71763 .76076 Mdot
.72939 .76469 Mdot
.72547 .75292 Mdot
.74116 .75684 Mdot
.749 .76076 Mdot
.74508 .76076 Mdot
.749 .75684 Mdot
.749 .75292 Mdot
.75684 .749 Mdot
.74508 .73724 Mdot
.73724 .72939 Mdot
.74508 .73724 Mdot
.74508 .73332 Mdot
.75684 .74116 Mdot
.75684 .73332 Mdot
.76076 .72547 Mdot
.76861 .72547 Mdot
.76469 .72547 Mdot
.77645 .74116 Mdot
.77645 .74508 Mdot
.76469 .72939 Mdot
.76469 .72547 Mdot
.76861 .72939 Mdot
.76469 .72547 Mdot
.78037 .73332 Mdot
.77645 .72939 Mdot
.77253 .72939 Mdot
.78821 .72547 Mdot
.79606 .72547 Mdot
.79213 .70194 Mdot
.78429 .69018 Mdot
.79998 .68626 Mdot
.79213 .6745 Mdot
.79213 .68234 Mdot
.78821 .6941 Mdot
.78429 .69802 Mdot
.78429 .69802 Mdot
.77645 .69802 Mdot
.79213 .70587 Mdot
.78037 .69802 Mdot
.77645 .69802 Mdot
.77645 .6941 Mdot
.78037 .6941 Mdot
.77253 .69802 Mdot
.78821 .71371 Mdot
.77645 .70194 Mdot
.77645 .69018 Mdot
.77253 .68234 Mdot
.77645 .6745 Mdot
.77645 .66273 Mdot
.78429 .66273 Mdot
.77253 .66273 Mdot
.76861 .66665 Mdot
.76469 .66273 Mdot
.75292 .65489 Mdot
.749 .65881 Mdot
.80782 .74116 Mdot
.81958 .78429 Mdot
.54117 .57254 Mdot
.59215 .62744 Mdot
.59999 .65489 Mdot
.59215 .65489 Mdot
.59215 .65881 Mdot
.59215 .65097 Mdot
.58823 .65097 Mdot
.59607 .65881 Mdot
.58823 .66665 Mdot
.60391 .6745 Mdot
.61568 .67057 Mdot
.61568 .67057 Mdot
.6196 .6745 Mdot
.6196 .6745 Mdot
.61176 .66665 Mdot
.6196 .66665 Mdot
.6196 .6745 Mdot
.62744 .6941 Mdot
.62744 .70194 Mdot
.63528 .71371 Mdot
.6392 .71371 Mdot
.65097 .71371 Mdot
.65881 .71763 Mdot
.64705 .70979 Mdot
.65489 .71763 Mdot
.66273 .71763 Mdot
.67057 .71371 Mdot
.67057 .71371 Mdot
.67842 .71763 Mdot
.67842 .71763 Mdot
.68234 .72155 Mdot
.68234 .72155 Mdot
.69802 .72939 Mdot
.69802 .73332 Mdot
.6941 .73332 Mdot
.69018 .72939 Mdot
.6941 .74116 Mdot
.69802 .74116 Mdot
.70194 .74116 Mdot
.70194 .74508 Mdot
.69802 .74508 Mdot
.71371 .75292 Mdot
.71763 .749 Mdot
.71763 .74508 Mdot
.71371 .74508 Mdot
.72547 .75292 Mdot
.72155 .74508 Mdot
.72155 .749 Mdot
.72547 .75292 Mdot
.72939 .75292 Mdot
.73332 .75292 Mdot
.72939 .74508 Mdot
.73724 .749 Mdot
.74508 .749 Mdot
.74508 .749 Mdot
.74508 .74508 Mdot
.74116 .74116 Mdot
.75292 .73332 Mdot
.75684 .73332 Mdot
.75684 .72939 Mdot
.749 .72547 Mdot
.749 .72939 Mdot
.76469 .74116 Mdot
.76861 .74508 Mdot
.77645 .74508 Mdot
.78429 .74508 Mdot
.78037 .74508 Mdot
.76469 .74116 Mdot
.76469 .73332 Mdot
.77645 .73724 Mdot
.77253 .72547 Mdot
.77253 .71371 Mdot
.76076 .6941 Mdot
.77645 .69802 Mdot
.78037 .69802 Mdot
.78429 .69018 Mdot
.78821 .68626 Mdot
.78037 .68626 Mdot
.78037 .6941 Mdot
.77253 .6941 Mdot
.78037 .70194 Mdot
.78037 .70194 Mdot
.78821 .70587 Mdot
.78429 .70194 Mdot
.78037 .70194 Mdot
.77645 .69802 Mdot
.78821 .70587 Mdot
.77645 .70194 Mdot
.78821 .71371 Mdot
.77645 .70587 Mdot
.76861 .6941 Mdot
.77253 .6941 Mdot
.77253 .6941 Mdot
.77253 .67842 Mdot
.77253 .6745 Mdot
.76861 .66665 Mdot
.78037 .68234 Mdot
.78037 .67842 Mdot
.75684 .65881 Mdot
.75292 .66273 Mdot
.749 .66273 Mdot
.749 .65881 Mdot
.749 .65097 Mdot
.78037 .71763 Mdot
.92546 .90585 Mdot
.57646 .59999 Mdot
.58823 .62744 Mdot
.60391 .65097 Mdot
.59607 .65881 Mdot
.60391 .67057 Mdot
.60391 .67057 Mdot
.58431 .65881 Mdot
.59999 .67057 Mdot
.60391 .66665 Mdot
.60391 .66273 Mdot
.59999 .65489 Mdot
.60783 .65881 Mdot
.62352 .6745 Mdot
.62744 .67842 Mdot
.63528 .68626 Mdot
.63528 .68626 Mdot
.6392 .6941 Mdot
.63136 .69802 Mdot
.63136 .70979 Mdot
.63136 .71763 Mdot
.63528 .71371 Mdot
.6392 .70979 Mdot
.64705 .70979 Mdot
.65881 .72939 Mdot
.65489 .72155 Mdot
.66665 .71763 Mdot
.6745 .71371 Mdot
.67842 .71371 Mdot
.68626 .71763 Mdot
.68234 .71371 Mdot
.68626 .72547 Mdot
.68626 .72939 Mdot
.68626 .73332 Mdot
.70194 .73332 Mdot
.70587 .73332 Mdot
.70587 .73332 Mdot
.70587 .73332 Mdot
.70587 .73724 Mdot
.69802 .73724 Mdot
.70979 .749 Mdot
.70587 .74508 Mdot
.71371 .749 Mdot
.71371 .76469 Mdot
.71371 .76076 Mdot
.71763 .749 Mdot
.71763 .74508 Mdot
.72547 .75292 Mdot
.72547 .76076 Mdot
.72547 .75292 Mdot
.72155 .749 Mdot
.73332 .75292 Mdot
.73332 .75292 Mdot
.73724 .75684 Mdot
.74508 .76076 Mdot
.74508 .75684 Mdot
.74508 .75292 Mdot
.74116 .75292 Mdot
.76076 .76076 Mdot
.75292 .75292 Mdot
.749 .749 Mdot
.75684 .749 Mdot
.75684 .74116 Mdot
.76469 .74116 Mdot
.76469 .73724 Mdot
.76469 .73724 Mdot
.76861 .73724 Mdot
.75684 .73724 Mdot
.76861 .75292 Mdot
.76861 .74508 Mdot
.76469 .74116 Mdot
.76076 .73724 Mdot
.76861 .73724 Mdot
.77253 .72155 Mdot
.76861 .70979 Mdot
.76469 .70979 Mdot
.77645 .71371 Mdot
.77645 .6941 Mdot
.79213 .70194 Mdot
.78429 .6941 Mdot
.78037 .6941 Mdot
.78429 .70194 Mdot
.78037 .70194 Mdot
.78037 .70194 Mdot
.78821 .70587 Mdot
.79213 .71371 Mdot
.78821 .71371 Mdot
.77645 .70587 Mdot
.77645 .70587 Mdot
.78429 .70979 Mdot
.78037 .71371 Mdot
.77645 .70587 Mdot
.77645 .70587 Mdot
.77253 .69802 Mdot
.78037 .69018 Mdot
.77645 .69018 Mdot
.77645 .68626 Mdot
.77645 .68234 Mdot
.78037 .68234 Mdot
.77645 .67842 Mdot
.76076 .67057 Mdot
.76076 .67057 Mdot
.76076 .67057 Mdot
.76076 .6745 Mdot
.74116 .66273 Mdot
.74508 .66665 Mdot
.74116 .64313 Mdot
.85095 .80782 Mdot
.90585 .89017 Mdot
.54902 .59215 Mdot
.58823 .63136 Mdot
.59999 .65881 Mdot
.59607 .67842 Mdot
.59607 .67842 Mdot
.60391 .68234 Mdot
.60391 .67842 Mdot
.61568 .6745 Mdot
.60391 .65881 Mdot
.61568 .67057 Mdot
.61568 .67842 Mdot
.61568 .67057 Mdot
.62744 .6745 Mdot
.6392 .67842 Mdot
.64313 .69018 Mdot
.6392 .68626 Mdot
.6392 .6941 Mdot
.6392 .70587 Mdot
.64313 .71763 Mdot
.64313 .72155 Mdot
.64313 .71371 Mdot
.65489 .71371 Mdot
.65489 .70979 Mdot
.66273 .72155 Mdot
.67057 .72547 Mdot
.6745 .71763 Mdot
.68234 .72155 Mdot
.68234 .71763 Mdot
.69018 .72155 Mdot
.70194 .72939 Mdot
.69018 .73332 Mdot
.68234 .72939 Mdot
.6941 .73724 Mdot
.70587 .74116 Mdot
.70587 .73332 Mdot
.71371 .74116 Mdot
.71371 .75292 Mdot
.71763 .75292 Mdot
.71763 .749 Mdot
.72547 .75292 Mdot
.72547 .75292 Mdot
.73332 .76076 Mdot
.71371 .749 Mdot
.72547 .76861 Mdot
.72939 .76861 Mdot
.72939 .76076 Mdot
.72155 .75292 Mdot
.72939 .76469 Mdot
.72547 .75684 Mdot
.72547 .75292 Mdot
.73332 .76076 Mdot
.73724 .76076 Mdot
.75292 .77253 Mdot
.74116 .77253 Mdot
.74508 .77253 Mdot
.76076 .78037 Mdot
.75684 .76861 Mdot
.76861 .76861 Mdot
.76076 .75292 Mdot
.75292 .75292 Mdot
.75292 .74508 Mdot
.76076 .74116 Mdot
.76861 .74116 Mdot
.76861 .73724 Mdot
.76861 .72939 Mdot
.76469 .73724 Mdot
.76861 .74116 Mdot
.78037 .75292 Mdot
.77253 .76076 Mdot
.77645 .76076 Mdot
.77645 .76076 Mdot
.78429 .77253 Mdot
.76861 .749 Mdot
.78037 .74116 Mdot
.79213 .74508 Mdot
.78821 .74508 Mdot
.78429 .72547 Mdot
.79998 .72939 Mdot
.79606 .71371 Mdot
.79998 .70979 Mdot
.8039 .71371 Mdot
.79998 .70979 Mdot
.79213 .70979 Mdot
.79213 .71371 Mdot
.78429 .71763 Mdot
.78821 .72939 Mdot
.78429 .72547 Mdot
.78821 .72547 Mdot
.78429 .72155 Mdot
.78821 .72547 Mdot
.77253 .71763 Mdot
.77645 .71763 Mdot
.77645 .71371 Mdot
.78429 .70979 Mdot
.78821 .70979 Mdot
.78429 .70979 Mdot
.78429 .71371 Mdot
.77645 .70194 Mdot
.78429 .69802 Mdot
.78429 .6941 Mdot
.78037 .6941 Mdot
.77645 .68626 Mdot
.77645 .68626 Mdot
.76861 .68234 Mdot
.77253 .6941 Mdot
.76469 .69018 Mdot
.749 .67842 Mdot
.73724 .66665 Mdot
.70194 .62352 Mdot
.85095 .81174 Mdot
.54117 .58823 Mdot
.57254 .63528 Mdot
.58823 .66665 Mdot
.58823 .67842 Mdot
.58431 .68234 Mdot
.60391 .6941 Mdot
.59999 .6745 Mdot
.59607 .66273 Mdot
.59607 .65489 Mdot
.59999 .65881 Mdot
.6196 .6745 Mdot
.6196 .67057 Mdot
.62352 .66665 Mdot
.63528 .67057 Mdot
.64313 .69018 Mdot
.6392 .69018 Mdot
.62352 .69018 Mdot
.62352 .69802 Mdot
.62744 .70194 Mdot
.6392 .70587 Mdot
.64313 .70194 Mdot
.65097 .69802 Mdot
.65881 .70587 Mdot
.65489 .69802 Mdot
.67057 .71371 Mdot
.67057 .71371 Mdot
.6745 .70979 Mdot
.67842 .70979 Mdot
.68626 .71763 Mdot
.68626 .72939 Mdot
.69018 .73332 Mdot
.6745 .71763 Mdot
.69018 .72547 Mdot
.69802 .73332 Mdot
.70194 .73332 Mdot
.70979 .73724 Mdot
.70979 .74116 Mdot
.71371 .749 Mdot
.71371 .75292 Mdot
.72155 .75684 Mdot
.72547 .749 Mdot
.71763 .73724 Mdot
.71763 .74116 Mdot
.71763 .749 Mdot
.72547 .75684 Mdot
.72939 .76469 Mdot
.73332 .76861 Mdot
.72939 .76469 Mdot
.72939 .76469 Mdot
.73332 .76469 Mdot
.73724 .76469 Mdot
.72939 .76076 Mdot
.73332 .76861 Mdot
.72939 .76469 Mdot
.73724 .76861 Mdot
.75292 .76469 Mdot
.75292 .76469 Mdot
.75684 .76076 Mdot
.75292 .75292 Mdot
.75684 .75292 Mdot
.75684 .75684 Mdot
.76076 .75684 Mdot
.77253 .75684 Mdot
.77253 .75292 Mdot
.76076 .72939 Mdot
.77253 .73332 Mdot
.76076 .72547 Mdot
.77253 .74116 Mdot
.76861 .74116 Mdot
.76469 .74116 Mdot
.76469 .749 Mdot
.77253 .75684 Mdot
.76861 .749 Mdot
.78037 .74508 Mdot
.77645 .73724 Mdot
.77253 .72939 Mdot
.78429 .72939 Mdot
.78037 .71371 Mdot
.78429 .70979 Mdot
.78821 .70587 Mdot
.78821 .71371 Mdot
.79606 .72547 Mdot
.78429 .72155 Mdot
.78429 .72155 Mdot
.78037 .72939 Mdot
.78037 .73724 Mdot
.78821 .74116 Mdot
.78429 .73724 Mdot
.78429 .72939 Mdot
.79213 .72939 Mdot
.78037 .72155 Mdot
.78037 .71371 Mdot
.78037 .70194 Mdot
.78429 .70194 Mdot
.78821 .71371 Mdot
.78429 .71763 Mdot
.78037 .72155 Mdot
.78037 .71763 Mdot
.78429 .70979 Mdot
.77645 .69802 Mdot
.78037 .69802 Mdot
.77645 .69018 Mdot
.77645 .69018 Mdot
.76861 .6941 Mdot
.76861 .70194 Mdot
.76076 .6941 Mdot
.75684 .69018 Mdot
.74508 .68234 Mdot
.73724 .68234 Mdot
.74116 .67842 Mdot
.69018 .62744 Mdot
.74508 .69802 Mdot
.78821 .76861 Mdot
.54509 .58823 Mdot
.57254 .63528 Mdot
.58823 .65881 Mdot
.58823 .67842 Mdot
.56862 .66665 Mdot
.57254 .66665 Mdot
.58039 .65097 Mdot
.58823 .65097 Mdot
.59999 .64705 Mdot
.60783 .65097 Mdot
.59999 .65489 Mdot
.60391 .65881 Mdot
.60783 .66273 Mdot
.61568 .67057 Mdot
.6196 .6745 Mdot
.6196 .67842 Mdot
.62744 .69018 Mdot
.61568 .69018 Mdot
.62352 .69802 Mdot
.63136 .70194 Mdot
.64705 .70587 Mdot
.65489 .69802 Mdot
.64705 .69018 Mdot
.65489 .70587 Mdot
.65489 .71763 Mdot
.65489 .70979 Mdot
.67057 .71371 Mdot
.67842 .71763 Mdot
.67842 .72155 Mdot
.67057 .71763 Mdot
.67057 .72155 Mdot
.67057 .71763 Mdot
.68626 .72155 Mdot
.69018 .72547 Mdot
.69018 .72939 Mdot
.6941 .72939 Mdot
.6941 .73724 Mdot
.6941 .74508 Mdot
.6941 .74116 Mdot
.70979 .749 Mdot
.70979 .749 Mdot
.71371 .749 Mdot
.72155 .749 Mdot
.71763 .74116 Mdot
.71763 .74116 Mdot
.72155 .73724 Mdot
.72547 .75684 Mdot
.72939 .76076 Mdot
.72547 .75684 Mdot
.72939 .76076 Mdot
.73332 .76076 Mdot
.74116 .75292 Mdot
.74116 .76469 Mdot
.73332 .76076 Mdot
.73332 .75292 Mdot
.73332 .74508 Mdot
.74116 .749 Mdot
.75292 .749 Mdot
.75292 .74508 Mdot
.75292 .749 Mdot
.74508 .74116 Mdot
.74508 .74508 Mdot
.75684 .75684 Mdot
.74116 .74508 Mdot
.74508 .73724 Mdot
.749 .73332 Mdot
.75684 .73332 Mdot
.76076 .73332 Mdot
.76469 .74116 Mdot
.77253 .749 Mdot
.76469 .749 Mdot
.76469 .74508 Mdot
.77253 .749 Mdot
.77253 .74116 Mdot
.76469 .73332 Mdot
.77645 .74116 Mdot
.77645 .73332 Mdot
.78037 .72155 Mdot
.78037 .71371 Mdot
.77645 .70194 Mdot
.78429 .70979 Mdot
.78821 .71371 Mdot
.78037 .70587 Mdot
.78429 .72155 Mdot
.76861 .72155 Mdot
.76469 .72939 Mdot
.76469 .72547 Mdot
.78429 .72547 Mdot
.78037 .72547 Mdot
.77253 .71763 Mdot
.78037 .71763 Mdot
.77253 .70979 Mdot
.77253 .69802 Mdot
.78429 .69802 Mdot
.77645 .69018 Mdot
.76861 .6941 Mdot
.77645 .69802 Mdot
.77645 .6941 Mdot
.77253 .69018 Mdot
.77253 .69018 Mdot
.77253 .69802 Mdot
.76076 .69018 Mdot
.76076 .6941 Mdot
.74508 .68626 Mdot
.74116 .68234 Mdot
.75684 .6941 Mdot
.75292 .6941 Mdot
.75292 .69802 Mdot
.74508 .69802 Mdot
.74116 .69018 Mdot
.72939 .6745 Mdot
.72155 .66665 Mdot
.71763 .66665 Mdot
.65097 .59999 Mdot
.73332 .68626 Mdot
.91761 .89801 Mdot
.54117 .57254 Mdot
.57254 .61568 Mdot
.58039 .6392 Mdot
.57646 .65489 Mdot
.57646 .66665 Mdot
.5647 .66273 Mdot
.58039 .66665 Mdot
.58039 .65489 Mdot
.59215 .65097 Mdot
.59215 .65489 Mdot
.59999 .67057 Mdot
.59999 .6745 Mdot
.60391 .67057 Mdot
.61176 .67057 Mdot
.60783 .66665 Mdot
.61176 .66273 Mdot
.6196 .67842 Mdot
.61568 .68234 Mdot
.62744 .69802 Mdot
.6196 .6941 Mdot
.62744 .70587 Mdot
.6392 .70979 Mdot
.62744 .70194 Mdot
.64313 .70979 Mdot
.64313 .70979 Mdot
.64705 .70587 Mdot
.65881 .71371 Mdot
.67057 .72155 Mdot
.67057 .71763 Mdot
.66665 .72155 Mdot
.66665 .72547 Mdot
.67057 .72547 Mdot
.6745 .71763 Mdot
.6745 .70587 Mdot
.67842 .70979 Mdot
.68626 .72155 Mdot
.6941 .73332 Mdot
.70194 .74508 Mdot
.70587 .75292 Mdot
.70587 .75684 Mdot
.70587 .76861 Mdot
.69802 .75684 Mdot
.70587 .76076 Mdot
.70587 .76469 Mdot
.72155 .76469 Mdot
.71763 .749 Mdot
.72547 .75684 Mdot
.72547 .76076 Mdot
.72547 .76076 Mdot
.72939 .76469 Mdot
.72547 .75684 Mdot
.72939 .75684 Mdot
.74116 .77253 Mdot
.73724 .77645 Mdot
.73332 .76861 Mdot
.72155 .75292 Mdot
.72547 .75684 Mdot
.73332 .75684 Mdot
.73724 .75684 Mdot
.73724 .75292 Mdot
.74116 .75292 Mdot
.73724 .749 Mdot
.73332 .74508 Mdot
.74116 .75292 Mdot
.75292 .76076 Mdot
.73724 .74116 Mdot
.74116 .73724 Mdot
.749 .74508 Mdot
.75684 .74508 Mdot
.76076 .75684 Mdot
.749 .75684 Mdot
.749 .75292 Mdot
.749 .749 Mdot
.75684 .75292 Mdot
.749 .749 Mdot
.76076 .749 Mdot
.76076 .749 Mdot
.75684 .74116 Mdot
.77253 .74508 Mdot
.78037 .74116 Mdot
.78037 .73724 Mdot
.77645 .73724 Mdot
.76469 .72547 Mdot
.76861 .72547 Mdot
.76861 .72547 Mdot
.76469 .72155 Mdot
.76469 .71371 Mdot
.77253 .71371 Mdot
.77645 .72155 Mdot
.77253 .72155 Mdot
.77253 .71371 Mdot
.76469 .70587 Mdot
.77253 .70194 Mdot
.77253 .69802 Mdot
.78037 .70194 Mdot
.76861 .70194 Mdot
.76469 .70587 Mdot
.77253 .72155 Mdot
.76076 .70979 Mdot
.76469 .70979 Mdot
.75684 .70587 Mdot
.75292 .70587 Mdot
.76861 .70979 Mdot
.75292 .69802 Mdot
.74508 .6941 Mdot
.749 .6941 Mdot
.749 .70194 Mdot
.75684 .70979 Mdot
.73724 .69802 Mdot
.73724 .6941 Mdot
.73332 .68626 Mdot
.72939 .68234 Mdot
.73332 .69018 Mdot
.72547 .69018 Mdot
.71371 .67057 Mdot
.70587 .65881 Mdot
.70194 .63528 Mdot
.84311 .81566 Mdot
.83919 .84703 Mdot
.55686 .57646 Mdot
.57254 .60783 Mdot
.58823 .63136 Mdot
.58431 .64313 Mdot
.57254 .64705 Mdot
.57254 .65881 Mdot
.57646 .66273 Mdot
.58823 .67057 Mdot
.58823 .66665 Mdot
.59215 .66665 Mdot
.59999 .68234 Mdot
.61568 .69802 Mdot
.60783 .6941 Mdot
.62352 .6941 Mdot
.60783 .67842 Mdot
.60783 .68234 Mdot
.6196 .69018 Mdot
.6196 .69018 Mdot
.62744 .6941 Mdot
.63136 .70587 Mdot
.6392 .71371 Mdot
.64313 .71763 Mdot
.64705 .71371 Mdot
.6392 .70587 Mdot
.64313 .70587 Mdot
.6392 .70587 Mdot
.65489 .72155 Mdot
.66665 .72547 Mdot
.6745 .72939 Mdot
.67057 .72939 Mdot
.65881 .73332 Mdot
.66273 .73332 Mdot
.66665 .72547 Mdot
.67057 .72547 Mdot
.66665 .71371 Mdot
.69018 .73332 Mdot
.70587 .749 Mdot
.69802 .75684 Mdot
.69802 .75292 Mdot
.70194 .76076 Mdot
.70979 .76469 Mdot
.70587 .76076 Mdot
.70194 .77253 Mdot
.71371 .78037 Mdot
.70979 .77253 Mdot
.71371 .76861 Mdot
.72155 .76469 Mdot
.72155 .76469 Mdot
.71763 .76861 Mdot
.72155 .76861 Mdot
.72547 .76469 Mdot
.72939 .76469 Mdot
.72155 .75684 Mdot
.74116 .77645 Mdot
.73724 .77253 Mdot
.72939 .76469 Mdot
.73724 .77253 Mdot
.72155 .76076 Mdot
.73332 .76469 Mdot
.74508 .77645 Mdot
.75292 .78429 Mdot
.73724 .76861 Mdot
.74116 .76469 Mdot
.74116 .75684 Mdot
.749 .76076 Mdot
.75292 .76469 Mdot
.75292 .75684 Mdot
.75292 .749 Mdot
.749 .74116 Mdot
.75292 .749 Mdot
.75684 .76076 Mdot
.75292 .76076 Mdot
.75292 .76469 Mdot
.75292 .76076 Mdot
.75684 .76861 Mdot
.75292 .76469 Mdot
.75684 .76469 Mdot
.75684 .75684 Mdot
.75292 .75292 Mdot
.76469 .76076 Mdot
.76861 .76076 Mdot
.77253 .75292 Mdot
.76076 .74116 Mdot
.76469 .74116 Mdot
.76469 .72547 Mdot
.76469 .72547 Mdot
.76076 .71763 Mdot
.76469 .71763 Mdot
.76861 .71763 Mdot
.77645 .72155 Mdot
.77253 .71371 Mdot
.77253 .70979 Mdot
.77645 .71371 Mdot
.76861 .70979 Mdot
.77253 .71371 Mdot
.77253 .70979 Mdot
.76469 .71763 Mdot
.76076 .72939 Mdot
.75292 .73332 Mdot
.76076 .73332 Mdot
.76076 .73332 Mdot
.75684 .72155 Mdot
.75684 .71371 Mdot
.75292 .70194 Mdot
.75684 .70587 Mdot
.75292 .69802 Mdot
.75292 .69018 Mdot
.749 .68626 Mdot
.75292 .69802 Mdot
.74508 .6941 Mdot
.74116 .6941 Mdot
.72939 .68626 Mdot
.72939 .69018 Mdot
.72939 .6941 Mdot
.72547 .69018 Mdot
.71763 .67842 Mdot
.71763 .6745 Mdot
.71763 .68626 Mdot
.59215 .59215 Mdot
.59999 .58431 Mdot
.59999 .63528 Mdot
.52941 .58039 Mdot
.58039 .62744 Mdot
.58431 .6392 Mdot
.59215 .65489 Mdot
.57646 .6392 Mdot
.57254 .6392 Mdot
.56862 .64705 Mdot
.58431 .65881 Mdot
.58039 .66665 Mdot
.58039 .67057 Mdot
.58823 .68234 Mdot
.59215 .69018 Mdot
.59607 .68626 Mdot
.60391 .69018 Mdot
.61176 .6941 Mdot
.60783 .69018 Mdot
.60391 .69018 Mdot
.60391 .6941 Mdot
.61568 .70194 Mdot
.63136 .70587 Mdot
.6392 .71371 Mdot
.63136 .70979 Mdot
.6392 .71371 Mdot
.64313 .70979 Mdot
.65489 .70979 Mdot
.65097 .70979 Mdot
.65489 .71763 Mdot
.65489 .71371 Mdot
.64705 .71371 Mdot
.65881 .72547 Mdot
.64705 .72547 Mdot
.65489 .73332 Mdot
.66273 .74116 Mdot
.66273 .73724 Mdot
.66273 .74508 Mdot
.6745 .749 Mdot
.68234 .75292 Mdot
.69018 .76076 Mdot
.6941 .76469 Mdot
.71371 .76861 Mdot
.71371 .76469 Mdot
.70979 .76469 Mdot
.71371 .77645 Mdot
.71763 .78037 Mdot
.70587 .76861 Mdot
.70979 .76469 Mdot
.70979 .76076 Mdot
.71763 .76076 Mdot
.71763 .75292 Mdot
.71763 .75292 Mdot
.72155 .76076 Mdot
.71763 .75292 Mdot
.72547 .75292 Mdot
.72547 .75684 Mdot
.72939 .75684 Mdot
.72547 .75684 Mdot
.73332 .76076 Mdot
.73724 .76469 Mdot
.72547 .75684 Mdot
.73724 .76469 Mdot
.74508 .76861 Mdot
.74116 .76469 Mdot
.73332 .76076 Mdot
.73332 .76076 Mdot
.73724 .749 Mdot
.74508 .749 Mdot
.749 .74508 Mdot
.75684 .73724 Mdot
.75684 .73332 Mdot
.76076 .73332 Mdot
.76076 .72939 Mdot
.75292 .73332 Mdot
.74508 .73332 Mdot
.72547 .71763 Mdot
.75292 .73724 Mdot
.75292 .74508 Mdot
.749 .74116 Mdot
.74508 .74116 Mdot
.75292 .74508 Mdot
.75684 .75684 Mdot
.75292 .749 Mdot
.75292 .74508 Mdot
.75684 .73724 Mdot
.75684 .72939 Mdot
.76469 .72155 Mdot
.75292 .70587 Mdot
.76076 .71371 Mdot
.76076 .71371 Mdot
.76076 .71371 Mdot
.75684 .71371 Mdot
.76469 .71371 Mdot
.76861 .70979 Mdot
.76469 .70194 Mdot
.76076 .6941 Mdot
.75684 .69018 Mdot
.75292 .68234 Mdot
.749 .69018 Mdot
.75292 .70194 Mdot
.749 .70979 Mdot
.74508 .71763 Mdot
.75684 .72155 Mdot
.76076 .72155 Mdot
.76469 .71763 Mdot
.75684 .69802 Mdot
.749 .6941 Mdot
.749 .68626 Mdot
.749 .67842 Mdot
.75292 .6745 Mdot
.76076 .68234 Mdot
.75292 .6745 Mdot
.75292 .67842 Mdot
.74508 .68626 Mdot
.73724 .69018 Mdot
.73332 .68626 Mdot
.72939 .6745 Mdot
.72155 .67057 Mdot
.71763 .67842 Mdot
.71763 .67842 Mdot
.71371 .66665 Mdot
.70587 .65489 Mdot
.59999 .55294 Mdot
.3608 .34511 Mdot
.51372 .4902 Mdot
.55686 .5647 Mdot
.52549 .57254 Mdot
.55686 .6196 Mdot
.5647 .6392 Mdot
.5647 .65097 Mdot
.56078 .64705 Mdot
.55686 .6392 Mdot
.5647 .65489 Mdot
.57254 .65881 Mdot
.58039 .66665 Mdot
.58039 .67842 Mdot
.59215 .68626 Mdot
.59215 .69018 Mdot
.58823 .6941 Mdot
.61176 .70587 Mdot
.61176 .69802 Mdot
.61568 .70979 Mdot
.61568 .70979 Mdot
.6196 .70979 Mdot
.6196 .71371 Mdot
.62744 .71763 Mdot
.63528 .72155 Mdot
.63528 .72155 Mdot
.6392 .72939 Mdot
.63528 .72547 Mdot
.64313 .72547 Mdot
.65489 .72155 Mdot
.65489 .71763 Mdot
.64313 .70587 Mdot
.65489 .71763 Mdot
.65881 .72547 Mdot
.66273 .73724 Mdot
.66665 .74508 Mdot
.67057 .749 Mdot
.66665 .749 Mdot
.67842 .76076 Mdot
.66665 .75684 Mdot
.66665 .75684 Mdot
.6745 .75684 Mdot
.68234 .76076 Mdot
.69018 .76076 Mdot
.6941 .76076 Mdot
.70587 .76861 Mdot
.70979 .76861 Mdot
.70979 .77253 Mdot
.71763 .78037 Mdot
.71763 .76861 Mdot
.71763 .76076 Mdot
.72155 .76076 Mdot
.72939 .76469 Mdot
.72939 .76076 Mdot
.72547 .75684 Mdot
.72155 .75684 Mdot
.72155 .75292 Mdot
.73332 .75684 Mdot
.73332 .75292 Mdot
.72547 .75684 Mdot
.73724 .76861 Mdot
.73724 .76469 Mdot
.72547 .76469 Mdot
.72939 .76469 Mdot
.73332 .76861 Mdot
.72939 .76076 Mdot
.73724 .76469 Mdot
.72939 .75292 Mdot
.73724 .749 Mdot
.749 .75292 Mdot
.75684 .749 Mdot
.75684 .73332 Mdot
.749 .72547 Mdot
.75684 .72939 Mdot
.75684 .72547 Mdot
.76469 .72547 Mdot
.75292 .72939 Mdot
.75684 .73724 Mdot
.75684 .73724 Mdot
.76469 .749 Mdot
.75684 .73724 Mdot
.749 .73332 Mdot
.75684 .74116 Mdot
.76076 .75292 Mdot
.76469 .75684 Mdot
.76469 .75292 Mdot
.76469 .74508 Mdot
.749 .72547 Mdot
.75684 .72939 Mdot
.76861 .72939 Mdot
.76861 .72939 Mdot
.76076 .72939 Mdot
.75684 .73332 Mdot
.76861 .74116 Mdot
.749 .72547 Mdot
.76469 .72939 Mdot
.76076 .71763 Mdot
.77253 .71371 Mdot
.76861 .70979 Mdot
.76076 .70194 Mdot
.76076 .70587 Mdot
.75292 .71371 Mdot
.76076 .73332 Mdot
.76861 .74116 Mdot
.75292 .73332 Mdot
.75684 .72155 Mdot
.76076 .72155 Mdot
.749 .71371 Mdot
.74508 .71371 Mdot
.73332 .70587 Mdot
.72939 .6941 Mdot
.72939 .69018 Mdot
.74116 .68626 Mdot
.74508 .68626 Mdot
.73332 .68234 Mdot
.73724 .6941 Mdot
.74116 .70194 Mdot
.73332 .6941 Mdot
.72939 .68626 Mdot
.72547 .68626 Mdot
.72155 .6941 Mdot
.72155 .6941 Mdot
.71371 .68626 Mdot
.70587 .67057 Mdot
.71763 .65881 Mdot
.69802 .63528 Mdot
.59999 .53725 Mdot
.14513 .16865 Mdot
.19218 .1961 Mdot
.58431 .58431 Mdot
.78821 .79213 Mdot
.54509 .59607 Mdot
.57254 .6392 Mdot
.57646 .66273 Mdot
.57254 .66665 Mdot
.56078 .66273 Mdot
.55294 .65097 Mdot
.58039 .66273 Mdot
.57646 .65881 Mdot
.58039 .65881 Mdot
.57646 .66665 Mdot
.58431 .67842 Mdot
.58039 .67842 Mdot
.59607 .68626 Mdot
.60391 .69018 Mdot
.59215 .67842 Mdot
.60391 .6941 Mdot
.61176 .70194 Mdot
.62352 .70979 Mdot
.62352 .70979 Mdot
.62352 .70979 Mdot
.62744 .71371 Mdot
.63528 .72155 Mdot
.63136 .72547 Mdot
.63136 .72155 Mdot
.63528 .72155 Mdot
.63136 .72155 Mdot
.64313 .71763 Mdot
.64705 .71371 Mdot
.65489 .72155 Mdot
.65489 .72155 Mdot
.64705 .72547 Mdot
.65097 .72939 Mdot
.66665 .74116 Mdot
.66665 .73724 Mdot
.67057 .74116 Mdot
.6745 .75292 Mdot
.6745 .76076 Mdot
.6745 .75684 Mdot
.67057 .75292 Mdot
.68626 .76076 Mdot
.69018 .76076 Mdot
.6941 .76076 Mdot
.70194 .76861 Mdot
.70979 .77645 Mdot
.70194 .76861 Mdot
.70587 .76861 Mdot
.70587 .75684 Mdot
.72547 .77253 Mdot
.73332 .77645 Mdot
.73332 .76861 Mdot
.72547 .749 Mdot
.72939 .749 Mdot
.72939 .75292 Mdot
.73332 .75292 Mdot
.72939 .75292 Mdot
.72939 .75292 Mdot
.72547 .749 Mdot
.72939 .76469 Mdot
.72939 .76469 Mdot
.73332 .76861 Mdot
.73724 .76861 Mdot
.73332 .76469 Mdot
.73332 .76469 Mdot
.74116 .76861 Mdot
.73724 .76076 Mdot
.73332 .74508 Mdot
.75292 .75292 Mdot
.74508 .73724 Mdot
.74116 .73332 Mdot
.74116 .72939 Mdot
.74508 .73332 Mdot
.749 .73724 Mdot
.74508 .73724 Mdot
.74116 .73724 Mdot
.749 .74116 Mdot
.749 .74508 Mdot
.75684 .74508 Mdot
.749 .74116 Mdot
.75292 .74116 Mdot
.75292 .75292 Mdot
.76076 .76469 Mdot
.75684 .76076 Mdot
.76469 .749 Mdot
.75684 .73724 Mdot
.75292 .73332 Mdot
.75292 .72939 Mdot
.75292 .73332 Mdot
.74508 .73332 Mdot
.75292 .749 Mdot
.74508 .75292 Mdot
.749 .76076 Mdot
.749 .75292 Mdot
.749 .74116 Mdot
.749 .72939 Mdot
.74508 .72155 Mdot
.74508 .72155 Mdot
.749 .72155 Mdot
.749 .73724 Mdot
.75292 .73724 Mdot
.76076 .74508 Mdot
.76076 .749 Mdot
.76076 .74508 Mdot
.75684 .72939 Mdot
.74508 .72547 Mdot
.74116 .72155 Mdot
.74116 .72155 Mdot
.74508 .72155 Mdot
.74508 .71763 Mdot
.74508 .70587 Mdot
.74508 .70587 Mdot
.73724 .69802 Mdot
.73724 .69802 Mdot
.74508 .71371 Mdot
.73724 .70979 Mdot
.72547 .70194 Mdot
.72547 .69802 Mdot
.70979 .6941 Mdot
.70979 .69018 Mdot
.70587 .68626 Mdot
.70194 .6745 Mdot
.69802 .66665 Mdot
.6941 .65881 Mdot
.70587 .65489 Mdot
.44706 .4353 Mdot
.28629 .29413 Mdot
.18826 .20002 Mdot
.1765 .18042 Mdot
.15689 .17257 Mdot
.57646 .58823 Mdot
.78037 .78821 Mdot
.53333 .59999 Mdot
.55686 .6392 Mdot
.55686 .65881 Mdot
.5647 .6745 Mdot
.55686 .67057 Mdot
.54902 .67057 Mdot
.5647 .66273 Mdot
.57646 .67057 Mdot
.56862 .66273 Mdot
.57254 .66273 Mdot
.58823 .67842 Mdot
.60391 .6941 Mdot
.59607 .69018 Mdot
.60783 .6941 Mdot
.60783 .69018 Mdot
.60783 .68626 Mdot
.61176 .6941 Mdot
.6196 .70587 Mdot
.62352 .71371 Mdot
.63136 .71763 Mdot
.62744 .70979 Mdot
.6392 .71763 Mdot
.64705 .72547 Mdot
.6392 .72547 Mdot
.63528 .73332 Mdot
.62744 .72939 Mdot
.62744 .72155 Mdot
.63528 .71763 Mdot
.64705 .72547 Mdot
.66273 .73332 Mdot
.64705 .72939 Mdot
.64313 .72939 Mdot
.65489 .73332 Mdot
.66273 .73332 Mdot
.66273 .72939 Mdot
.66665 .74508 Mdot
.66665 .75684 Mdot
.6745 .76861 Mdot
.68234 .77645 Mdot
.67842 .76861 Mdot
.68234 .75684 Mdot
.68234 .75292 Mdot
.68626 .75292 Mdot
.69802 .76076 Mdot
.69802 .76076 Mdot
.70979 .76469 Mdot
.71371 .76861 Mdot
.72155 .76469 Mdot
.70587 .749 Mdot
.71763 .75684 Mdot
.72155 .75292 Mdot
.72547 .749 Mdot
.72155 .749 Mdot
.71371 .749 Mdot
.71763 .749 Mdot
.72547 .76076 Mdot
.72547 .76469 Mdot
.73332 .77253 Mdot
.72547 .76076 Mdot
.72547 .76469 Mdot
.72939 .77253 Mdot
.72547 .77253 Mdot
.72155 .76076 Mdot
.72939 .76076 Mdot
.73332 .77253 Mdot
.73724 .76861 Mdot
.73724 .76469 Mdot
.74508 .75684 Mdot
.74116 .75292 Mdot
.74508 .75684 Mdot
.75684 .76469 Mdot
.75292 .76861 Mdot
.749 .76076 Mdot
.74508 .749 Mdot
.74116 .74508 Mdot
.73724 .73724 Mdot
.749 .73724 Mdot
.749 .74508 Mdot
.74508 .74116 Mdot
.74116 .73724 Mdot
.74508 .749 Mdot
.75292 .75684 Mdot
.749 .75684 Mdot
.75684 .75292 Mdot
.75292 .74116 Mdot
.75292 .74116 Mdot
.75292 .74116 Mdot
.74508 .74508 Mdot
.74116 .749 Mdot
.74508 .749 Mdot
.75292 .75292 Mdot
.74116 .74508 Mdot
.74116 .749 Mdot
.74116 .74116 Mdot
.749 .74508 Mdot
.73724 .72547 Mdot
.74508 .72939 Mdot
.749 .73724 Mdot
.74116 .73724 Mdot
.74116 .74508 Mdot
.73724 .74116 Mdot
.74116 .73724 Mdot
.74508 .73724 Mdot
.74508 .72155 Mdot
.73724 .71371 Mdot
.74508 .70979 Mdot
.74116 .70194 Mdot
.73724 .6941 Mdot
.74508 .70194 Mdot
.749 .71371 Mdot
.74116 .70587 Mdot
.73724 .70194 Mdot
.73724 .69802 Mdot
.72939 .69802 Mdot
.72547 .70587 Mdot
.73724 .71763 Mdot
.72547 .70194 Mdot
.71763 .69018 Mdot
.70587 .67842 Mdot
.70194 .68626 Mdot
.70587 .68626 Mdot
.70194 .68626 Mdot
.70587 .68234 Mdot
.68626 .65881 Mdot
.58039 .56078 Mdot
.30982 .32158 Mdot
.26276 .26668 Mdot
.25492 .25492 Mdot
.21179 .23139 Mdot
.18434 .21571 Mdot
.34903 .38432 Mdot
.58431 .59999 Mdot
.51765 .60783 Mdot
.53725 .64705 Mdot
.55686 .67057 Mdot
.56078 .68234 Mdot
.55686 .67842 Mdot
.55686 .67842 Mdot
.56078 .66273 Mdot
.55686 .64705 Mdot
.56862 .64705 Mdot
.57254 .64705 Mdot
.57646 .65489 Mdot
.59999 .68234 Mdot
.59215 .68234 Mdot
.58823 .66665 Mdot
.60391 .67057 Mdot
.62352 .68626 Mdot
.6196 .69018 Mdot
.60783 .6941 Mdot
.61176 .70979 Mdot
.6196 .71763 Mdot
.62352 .71371 Mdot
.62352 .70587 Mdot
.62744 .70587 Mdot
.62744 .71371 Mdot
.63136 .72547 Mdot
.62744 .72155 Mdot
.63136 .71763 Mdot
.63528 .71371 Mdot
.65097 .71763 Mdot
.64313 .71763 Mdot
.65097 .72939 Mdot
.65881 .74116 Mdot
.66665 .74116 Mdot
.65881 .72939 Mdot
.66273 .73332 Mdot
.65881 .73332 Mdot
.67057 .749 Mdot
.67842 .76469 Mdot
.6745 .76469 Mdot
.67842 .76076 Mdot
.68626 .76469 Mdot
.68234 .749 Mdot
.69018 .75292 Mdot
.69018 .75292 Mdot
.70194 .76076 Mdot
.69802 .75292 Mdot
.70587 .749 Mdot
.71371 .75292 Mdot
.71371 .749 Mdot
.72155 .75684 Mdot
.71763 .75292 Mdot
.70979 .74508 Mdot
.70194 .73724 Mdot
.70979 .749 Mdot
.72155 .75684 Mdot
.72547 .76076 Mdot
.72547 .76469 Mdot
.72547 .76469 Mdot
.72939 .76861 Mdot
.72155 .76861 Mdot
.72547 .77253 Mdot
.72547 .77253 Mdot
.72547 .77253 Mdot
.71763 .75292 Mdot
.72155 .75684 Mdot
.72547 .76076 Mdot
.73724 .76469 Mdot
.72939 .76076 Mdot
.72939 .75292 Mdot
.74116 .75684 Mdot
.74116 .75684 Mdot
.73724 .75292 Mdot
.72547 .74116 Mdot
.73332 .72939 Mdot
.73724 .72547 Mdot
.73724 .72155 Mdot
.74116 .72547 Mdot
.74116 .73724 Mdot
.73724 .73332 Mdot
.73724 .73332 Mdot
.73332 .73332 Mdot
.74116 .74508 Mdot
.749 .75684 Mdot
.73724 .74116 Mdot
.73724 .72547 Mdot
.74508 .72939 Mdot
.73724 .73332 Mdot
.73724 .74508 Mdot
.74116 .749 Mdot
.75292 .749 Mdot
.74116 .74116 Mdot
.749 .749 Mdot
.73332 .73332 Mdot
.73332 .73332 Mdot
.74508 .73332 Mdot
.74116 .72155 Mdot
.74508 .72155 Mdot
.73724 .71763 Mdot
.73724 .72155 Mdot
.72939 .72547 Mdot
.73332 .72547 Mdot
.73724 .72939 Mdot
.72939 .72155 Mdot
.73332 .71371 Mdot
.72939 .70587 Mdot
.72939 .69802 Mdot
.73332 .69802 Mdot
.72547 .69018 Mdot
.72939 .6941 Mdot
.73724 .70587 Mdot
.73724 .70194 Mdot
.73724 .6941 Mdot
.73724 .69018 Mdot
.72939 .68234 Mdot
.72547 .68234 Mdot
.72155 .69018 Mdot
.72547 .69018 Mdot
.72155 .69018 Mdot
.71371 .68234 Mdot
.69802 .6745 Mdot
.6941 .68234 Mdot
.6941 .67842 Mdot
.6941 .67057 Mdot
.69802 .66273 Mdot
.70194 .66665 Mdot
.62744 .60783 Mdot
.48628 .5098 Mdot
.50196 .51372 Mdot
.47059 .47843 Mdot
.21963 .26276 Mdot
.1961 .21963 Mdot
.15689 .1765 Mdot
.14905 .16865 Mdot
.34903 .36472 Mdot
.56862 .56862 Mdot
.51765 .59999 Mdot
.54509 .64313 Mdot
.55294 .65881 Mdot
.54509 .66665 Mdot
.55294 .6745 Mdot
.56078 .6745 Mdot
.56078 .66273 Mdot
.56862 .65489 Mdot
.5647 .64313 Mdot
.56862 .6392 Mdot
.58431 .64313 Mdot
.58431 .64705 Mdot
.58823 .66273 Mdot
.59215 .65881 Mdot
.58823 .65489 Mdot
.59999 .6745 Mdot
.59999 .67842 Mdot
.59215 .69018 Mdot
.60391 .70194 Mdot
.61568 .70587 Mdot
.62352 .70194 Mdot
.63136 .70587 Mdot
.63136 .70587 Mdot
.62744 .70194 Mdot
.63136 .71763 Mdot
.6392 .72939 Mdot
.64705 .72547 Mdot
.64705 .71371 Mdot
.6392 .70979 Mdot
.63528 .71371 Mdot
.6392 .72547 Mdot
.66273 .74116 Mdot
.65881 .73332 Mdot
.66273 .73332 Mdot
.66273 .73332 Mdot
.67057 .73724 Mdot
.66665 .74508 Mdot
.66665 .749 Mdot
.66273 .75292 Mdot
.66665 .76076 Mdot
.66665 .75684 Mdot
.67842 .75684 Mdot
.68234 .75292 Mdot
.68626 .75292 Mdot
.69802 .75684 Mdot
.69018 .74116 Mdot
.70194 .74508 Mdot
.70979 .75292 Mdot
.71763 .75292 Mdot
.72155 .75292 Mdot
.71763 .75292 Mdot
.71763 .75292 Mdot
.71371 .75292 Mdot
.72155 .75684 Mdot
.71371 .75292 Mdot
.71763 .75292 Mdot
.71763 .75292 Mdot
.71763 .75684 Mdot
.72155 .76076 Mdot
.72155 .76861 Mdot
.72547 .77253 Mdot
.72155 .76861 Mdot
.72547 .77645 Mdot
.72155 .76861 Mdot
.72939 .76861 Mdot
.72155 .76076 Mdot
.73724 .76469 Mdot
.73332 .76469 Mdot
.73724 .76076 Mdot
.73332 .749 Mdot
.74116 .75292 Mdot
.74116 .75292 Mdot
.72939 .74508 Mdot
.72939 .73724 Mdot
.72939 .73724 Mdot
.74116 .74508 Mdot
.73724 .749 Mdot
.72547 .749 Mdot
.72547 .749 Mdot
.73724 .749 Mdot
.73332 .74116 Mdot
.73724 .74116 Mdot
.73724 .74116 Mdot
.73724 .73724 Mdot
.73332 .73332 Mdot
.72939 .73724 Mdot
.74116 .74508 Mdot
.73332 .74508 Mdot
.73724 .75292 Mdot
.73332 .75292 Mdot
.74116 .75292 Mdot
.74116 .74508 Mdot
.73724 .74116 Mdot
.73332 .73724 Mdot
.72939 .73332 Mdot
.72939 .72547 Mdot
.73724 .72939 Mdot
.73332 .72155 Mdot
.73332 .72155 Mdot
.72939 .72547 Mdot
.72547 .72547 Mdot
.73332 .72547 Mdot
.71763 .70979 Mdot
.72155 .70979 Mdot
.72155 .70979 Mdot
.73332 .72155 Mdot
.73332 .71371 Mdot
.72155 .70587 Mdot
.72939 .70587 Mdot
.72547 .69802 Mdot
.72547 .69802 Mdot
.73332 .6941 Mdot
.72547 .68626 Mdot
.72155 .67842 Mdot
.71371 .67842 Mdot
.72155 .70194 Mdot
.70979 .70979 Mdot
.70587 .70194 Mdot
.70587 .6941 Mdot
.70194 .69018 Mdot
.70194 .69018 Mdot
.69018 .68234 Mdot
.69018 .68626 Mdot
.68626 .6745 Mdot
.68234 .6745 Mdot
.67842 .67842 Mdot
.67842 .69018 Mdot
.67057 .68234 Mdot
.66665 .66273 Mdot
.57254 .56078 Mdot
.16081 .22355 Mdot
.18434 .21571 Mdot
.16081 .18434 Mdot
.1412 .16081 Mdot
.13728 .13728 Mdot
.13728 .10591 Mdot
.57646 .54902 Mdot
.78821 .77253 Mdot
.52549 .58823 Mdot
.55294 .6392 Mdot
.55294 .65881 Mdot
.54509 .66273 Mdot
.55686 .66665 Mdot
.55294 .65881 Mdot
.55686 .65881 Mdot
.55294 .65489 Mdot
.56862 .66665 Mdot
.57646 .66665 Mdot
.58823 .65881 Mdot
.59215 .65881 Mdot
.58823 .65489 Mdot
.58823 .66273 Mdot
.59215 .67057 Mdot
.59215 .67057 Mdot
.59215 .67057 Mdot
.59607 .68234 Mdot
.60391 .69018 Mdot
.61568 .6941 Mdot
.6196 .6941 Mdot
.6196 .69018 Mdot
.61568 .6941 Mdot
.62352 .70587 Mdot
.63528 .71763 Mdot
.64313 .72155 Mdot
.6392 .71763 Mdot
.63528 .72155 Mdot
.64705 .72939 Mdot
.65097 .73724 Mdot
.6392 .73724 Mdot
.65097 .73724 Mdot
.65097 .73332 Mdot
.65489 .72939 Mdot
.65881 .72939 Mdot
.67057 .73332 Mdot
.66665 .74116 Mdot
.65881 .749 Mdot
.66273 .749 Mdot
.67057 .76076 Mdot
.68234 .76469 Mdot
.6745 .76076 Mdot
.68234 .76469 Mdot
.69802 .77645 Mdot
.69802 .77253 Mdot
.70194 .76861 Mdot
.6941 .76076 Mdot
.69802 .75684 Mdot
.69802 .75684 Mdot
.70979 .76469 Mdot
.70979 .76076 Mdot
.71763 .75684 Mdot
.71763 .75292 Mdot
.71763 .75292 Mdot
.71763 .749 Mdot
.72155 .75292 Mdot
.71763 .749 Mdot
.71371 .74508 Mdot
.72547 .75684 Mdot
.72547 .75292 Mdot
.72155 .749 Mdot
.72155 .75292 Mdot
.71763 .749 Mdot
.72547 .749 Mdot
.71371 .74116 Mdot
.71763 .749 Mdot
.72547 .75292 Mdot
.72547 .749 Mdot
.72939 .75292 Mdot
.72939 .74508 Mdot
.72939 .73724 Mdot
.74116 .75292 Mdot
.74508 .75684 Mdot
.73724 .75292 Mdot
.72939 .74508 Mdot
.73332 .749 Mdot
.73332 .749 Mdot
.72155 .749 Mdot
.71763 .74508 Mdot
.72547 .749 Mdot
.73332 .74508 Mdot
.73724 .749 Mdot
.73724 .749 Mdot
.73724 .74508 Mdot
.73332 .74508 Mdot
.72547 .74116 Mdot
.72939 .749 Mdot
.73332 .75292 Mdot
.73724 .74508 Mdot
.73332 .74116 Mdot
.73332 .74508 Mdot
.73332 .74116 Mdot
.72939 .73332 Mdot
.72939 .73332 Mdot
.72547 .72547 Mdot
.73332 .72939 Mdot
.74508 .73724 Mdot
.75292 .74116 Mdot
.74116 .73724 Mdot
.74116 .74116 Mdot
.73332 .72939 Mdot
.72939 .72547 Mdot
.72155 .71763 Mdot
.71371 .71371 Mdot
.71371 .71763 Mdot
.72155 .72155 Mdot
.72939 .72939 Mdot
.72547 .72155 Mdot
.73332 .71763 Mdot
.73332 .71371 Mdot
.72547 .70587 Mdot
.71763 .70194 Mdot
.72155 .70587 Mdot
.71371 .70194 Mdot
.70587 .6941 Mdot
.71763 .71371 Mdot
.70194 .70979 Mdot
.71371 .71763 Mdot
.69802 .70587 Mdot
.69802 .70587 Mdot
.69802 .70587 Mdot
.6941 .70194 Mdot
.69018 .69802 Mdot
.68626 .68234 Mdot
.67842 .67842 Mdot
.66665 .6745 Mdot
.68234 .68234 Mdot
.6745 .6745 Mdot
.67057 .6745 Mdot
.68234 .67057 Mdot
.47059 .49412 Mdot
.34119 .38432 Mdot
.23924 .28629 Mdot
.20394 .251 Mdot
.16473 .20394 Mdot
.18042 .19218 Mdot
.22747 .20787 Mdot
.31766 .26276 Mdot
.16473 .14513 Mdot
.58431 .58823 Mdot
.78429 .78821 Mdot
.54117 .59607 Mdot
.5647 .6392 Mdot
.56862 .66273 Mdot
.56078 .66273 Mdot
.55294 .65881 Mdot
.55294 .65489 Mdot
.56078 .65881 Mdot
.56862 .66665 Mdot
.57254 .6745 Mdot
.57646 .67842 Mdot
.58823 .68234 Mdot
.58431 .66665 Mdot
.58431 .65881 Mdot
.58431 .66273 Mdot
.58823 .67842 Mdot
.59999 .68626 Mdot
.60391 .68626 Mdot
.60391 .68626 Mdot
.60391 .68626 Mdot
.61176 .69018 Mdot
.6196 .70194 Mdot
.61176 .70587 Mdot
.6196 .70979 Mdot
.62352 .71371 Mdot
.62352 .70979 Mdot
.63528 .71763 Mdot
.64313 .72547 Mdot
.63528 .72547 Mdot
.64313 .73724 Mdot
.64313 .73724 Mdot
.6392 .73724 Mdot
.64705 .73724 Mdot
.64705 .72939 Mdot
.65489 .72939 Mdot
.66273 .72547 Mdot
.66665 .72939 Mdot
.66665 .73332 Mdot
.65881 .72939 Mdot
.66665 .73724 Mdot
.67057 .75684 Mdot
.6745 .76861 Mdot
.6745 .77645 Mdot
.6745 .77253 Mdot
.68234 .77253 Mdot
.68626 .76861 Mdot
.6941 .76861 Mdot
.6941 .76861 Mdot
.70194 .77253 Mdot
.70979 .77253 Mdot
.70194 .76469 Mdot
.70979 .76861 Mdot
.71371 .76469 Mdot
.71371 .76861 Mdot
.71763 .76861 Mdot
.71763 .749 Mdot
.71763 .74116 Mdot
.72155 .74116 Mdot
.71763 .73724 Mdot
.72547 .749 Mdot
.72155 .75292 Mdot
.71763 .749 Mdot
.71763 .73724 Mdot
.70194 .73724 Mdot
.70979 .74508 Mdot
.71763 .75292 Mdot
.72155 .75684 Mdot
.72155 .75684 Mdot
.72547 .76076 Mdot
.72155 .75684 Mdot
.72547 .75684 Mdot
.73332 .75684 Mdot
.72547 .74508 Mdot
.72547 .74116 Mdot
.72939 .74508 Mdot
.72939 .749 Mdot
.72155 .74116 Mdot
.72547 .749 Mdot
.72939 .749 Mdot
.72939 .749 Mdot
.73332 .75684 Mdot
.73332 .76076 Mdot
.73332 .76469 Mdot
.72939 .75292 Mdot
.73332 .75292 Mdot
.72939 .74508 Mdot
.73332 .749 Mdot
.72547 .74508 Mdot
.72155 .73724 Mdot
.72547 .73724 Mdot
.73332 .74116 Mdot
.73332 .74508 Mdot
.73724 .749 Mdot
.72547 .72939 Mdot
.72155 .71763 Mdot
.73332 .72155 Mdot
.73332 .72939 Mdot
.73724 .74116 Mdot
.73332 .73724 Mdot
.73724 .74508 Mdot
.73724 .749 Mdot
.72939 .73724 Mdot
.73724 .73724 Mdot
.72155 .72939 Mdot
.72155 .72939 Mdot
.72155 .73724 Mdot
.70979 .72939 Mdot
.71763 .72939 Mdot
.72155 .73332 Mdot
.72155 .72547 Mdot
.71371 .71763 Mdot
.72155 .72155 Mdot
.72155 .72547 Mdot
.71371 .72155 Mdot
.71371 .72547 Mdot
.71371 .71763 Mdot
.70979 .70587 Mdot
.70194 .69802 Mdot
.69802 .6941 Mdot
.69802 .69802 Mdot
.69018 .69018 Mdot
.69018 .69802 Mdot
.6941 .69802 Mdot
.70194 .69802 Mdot
.70194 .69802 Mdot
.68626 .68626 Mdot
.67057 .6745 Mdot
.68234 .6745 Mdot
.67842 .6745 Mdot
.67842 .67842 Mdot
.67057 .66665 Mdot
.65881 .65489 Mdot
.65097 .6392 Mdot
.47843 .50196 Mdot
.40001 .44706 Mdot
.27845 .36472 Mdot
.29021 .36864 Mdot
.6392 .61568 Mdot
.5647 .54509 Mdot
.33727 .35687 Mdot
.35295 .34119 Mdot
.10199 .13728 Mdot
.30982 .34119 Mdot
.54117 .56078 Mdot
.51765 .59215 Mdot
.54902 .6392 Mdot
.56078 .65881 Mdot
.56078 .66665 Mdot
.55686 .66665 Mdot
.54509 .65881 Mdot
.55686 .66273 Mdot
.56078 .67057 Mdot
.5647 .67842 Mdot
.5647 .6745 Mdot
.56862 .67842 Mdot
.56078 .66665 Mdot
.5647 .66273 Mdot
.57646 .67842 Mdot
.57646 .6941 Mdot
.58431 .69802 Mdot
.59999 .70587 Mdot
.59999 .70587 Mdot
.60391 .69802 Mdot
.61568 .70194 Mdot
.61176 .70979 Mdot
.59999 .71371 Mdot
.61176 .72155 Mdot
.61176 .71763 Mdot
.6196 .71371 Mdot
.62352 .71371 Mdot
.62744 .71371 Mdot
.64313 .73332 Mdot
.6392 .74508 Mdot
.64313 .74508 Mdot
.64705 .74508 Mdot
.65097 .74508 Mdot
.64705 .73332 Mdot
.64313 .72547 Mdot
.64705 .73724 Mdot
.65881 .73724 Mdot
.66273 .73724 Mdot
.66273 .749 Mdot
.66273 .749 Mdot
.6745 .76076 Mdot
.66273 .76861 Mdot
.6745 .78037 Mdot
.6745 .77645 Mdot
.67842 .76861 Mdot
.6745 .76076 Mdot
.69018 .76861 Mdot
.68626 .77253 Mdot
.6941 .77645 Mdot
.69018 .77253 Mdot
.69018 .77253 Mdot
.70194 .78037 Mdot
.70587 .77645 Mdot
.71371 .77645 Mdot
.71763 .76861 Mdot
.72155 .75684 Mdot
.72547 .749 Mdot
.71371 .73332 Mdot
.71763 .749 Mdot
.71371 .749 Mdot
.71763 .75292 Mdot
.71371 .749 Mdot
.70979 .74508 Mdot
.70979 .74508 Mdot
.71371 .75292 Mdot
.71763 .76469 Mdot
.71763 .75684 Mdot
.71763 .75292 Mdot
.71763 .749 Mdot
.71371 .74508 Mdot
.71763 .749 Mdot
.72155 .75292 Mdot
.71763 .74508 Mdot
.72547 .74508 Mdot
.72547 .74116 Mdot
.72547 .749 Mdot
.72155 .74116 Mdot
.72547 .74116 Mdot
.72547 .73724 Mdot
.72939 .74508 Mdot
.74116 .75292 Mdot
.73332 .75292 Mdot
.73332 .76076 Mdot
.72547 .75292 Mdot
.72155 .75292 Mdot
.72547 .75292 Mdot
.71371 .74116 Mdot
.71763 .74508 Mdot
.72155 .74116 Mdot
.73724 .74116 Mdot
.73332 .73724 Mdot
.73332 .73724 Mdot
.72939 .73332 Mdot
.72547 .73724 Mdot
.73724 .74116 Mdot
.74116 .73332 Mdot
.73332 .72939 Mdot
.72939 .73724 Mdot
.73332 .749 Mdot
.72155 .74116 Mdot
.72939 .74508 Mdot
.72547 .73724 Mdot
.72939 .73332 Mdot
.71763 .73332 Mdot
.71763 .73724 Mdot
.72155 .74116 Mdot
.72155 .74116 Mdot
.70587 .73724 Mdot
.70194 .73332 Mdot
.70587 .72939 Mdot
.71763 .72547 Mdot
.72547 .71763 Mdot
.72939 .71763 Mdot
.72547 .71763 Mdot
.71763 .70587 Mdot
.71371 .70587 Mdot
.70587 .69802 Mdot
.69018 .68626 Mdot
.69802 .6941 Mdot
.70194 .70587 Mdot
.6941 .70979 Mdot
.6941 .70979 Mdot
.69802 .70979 Mdot
.70587 .70979 Mdot
.6941 .70194 Mdot
.68234 .69802 Mdot
.67057 .68626 Mdot
.67057 .68234 Mdot
.67842 .6941 Mdot
.68234 .6941 Mdot
.6745 .68626 Mdot
.65881 .6745 Mdot
.65489 .6745 Mdot
.64313 .67057 Mdot
.63528 .65881 Mdot
.59215 .6196 Mdot
.58039 .60391 Mdot
.59999 .61176 Mdot
.6196 .61176 Mdot
.60783 .59607 Mdot
.63528 .58823 Mdot
.3059 .31766 Mdot
.06278 .1216 Mdot
.08631 .13728 Mdot
.07846 .11376 Mdot
.30198 .3255 Mdot
.52157 .53333 Mdot
.47059 .56862 Mdot
.54117 .64705 Mdot
.54902 .66273 Mdot
.54902 .66665 Mdot
.54509 .67057 Mdot
.54902 .66273 Mdot
.55686 .66665 Mdot
.55686 .66273 Mdot
.55686 .66665 Mdot
.56078 .66665 Mdot
.55686 .66273 Mdot
.56078 .66665 Mdot
.57254 .67057 Mdot
.57254 .67057 Mdot
.57646 .67842 Mdot
.58039 .68234 Mdot
.59215 .69802 Mdot
.59999 .69802 Mdot
.59215 .68626 Mdot
.60391 .69018 Mdot
.61568 .70194 Mdot
.61568 .70194 Mdot
.60783 .70587 Mdot
.60391 .70194 Mdot
.60783 .70587 Mdot
.61176 .71371 Mdot
.61568 .72547 Mdot
.6196 .73332 Mdot
.62352 .74508 Mdot
.63136 .74508 Mdot
.64313 .749 Mdot
.65097 .749 Mdot
.65097 .74508 Mdot
.64705 .74116 Mdot
.65881 .73724 Mdot
.65097 .72547 Mdot
.66273 .74508 Mdot
.65881 .75292 Mdot
.66273 .75684 Mdot
.67842 .77253 Mdot
.67057 .76861 Mdot
.66665 .76861 Mdot
.6745 .77253 Mdot
.6745 .76861 Mdot
.68234 .76076 Mdot
.68234 .75684 Mdot
.67842 .75684 Mdot
.68626 .76861 Mdot
.68234 .76469 Mdot
.69018 .76076 Mdot
.70194 .76469 Mdot
.70194 .75684 Mdot
.70587 .75292 Mdot
.70194 .74508 Mdot
.70979 .749 Mdot
.70587 .74116 Mdot
.71371 .74508 Mdot
.71763 .749 Mdot
.70194 .74508 Mdot
.70194 .74508 Mdot
.70587 .749 Mdot
.70979 .749 Mdot
.71763 .75292 Mdot
.71763 .76469 Mdot
.70587 .76469 Mdot
.71763 .76469 Mdot
.71763 .76076 Mdot
.71371 .75292 Mdot
.71371 .749 Mdot
.71763 .74508 Mdot
.72547 .75292 Mdot
.70587 .73332 Mdot
.70979 .74116 Mdot
.72547 .75292 Mdot
.72155 .75292 Mdot
.72155 .74508 Mdot
.72155 .74116 Mdot
.71371 .73332 Mdot
.71763 .74116 Mdot
.72547 .74508 Mdot
.72939 .74508 Mdot
.72155 .73332 Mdot
.72547 .74508 Mdot
.71371 .74116 Mdot
.71371 .74116 Mdot
.71763 .74116 Mdot
.70979 .74116 Mdot
.71371 .74116 Mdot
.71371 .72939 Mdot
.72155 .72939 Mdot
.71763 .72547 Mdot
.71763 .73332 Mdot
.72547 .73724 Mdot
.73332 .74116 Mdot
.74116 .74116 Mdot
.74116 .74116 Mdot
.73332 .74116 Mdot
.72547 .73724 Mdot
.71371 .73724 Mdot
.70979 .74116 Mdot
.71371 .74116 Mdot
.71371 .73724 Mdot
.71763 .74116 Mdot
.71371 .73724 Mdot
.71371 .74116 Mdot
.70979 .73332 Mdot
.70979 .72939 Mdot
.72155 .72939 Mdot
.72155 .72547 Mdot
.71763 .71763 Mdot
.71763 .70194 Mdot
.71371 .69018 Mdot
.71371 .68626 Mdot
.70979 .68234 Mdot
.70587 .6941 Mdot
.70587 .69802 Mdot
.70587 .70587 Mdot
.69802 .69802 Mdot
.6941 .69802 Mdot
.69802 .70979 Mdot
.69018 .70979 Mdot
.69018 .71371 Mdot
.67842 .70587 Mdot
.68234 .70587 Mdot
.68234 .70194 Mdot
.67842 .69802 Mdot
.66665 .69018 Mdot
.6745 .70194 Mdot
.66665 .6941 Mdot
.65489 .68234 Mdot
.64705 .6745 Mdot
.65489 .68234 Mdot
.64705 .67842 Mdot
.65489 .68234 Mdot
.64313 .66665 Mdot
.6392 .65881 Mdot
.63136 .65097 Mdot
.63136 .64313 Mdot
.62352 .63528 Mdot
.60783 .61176 Mdot
.58039 .56078 Mdot
.31374 .33335 Mdot
.18434 .21571 Mdot
.14513 .16865 Mdot
.10591 .13336 Mdot
.07454 .10199 Mdot
.11376 .12552 Mdot
.60391 .59999 Mdot
.78429 .78821 Mdot
.49412 .57254 Mdot
.53725 .63136 Mdot
.55294 .66273 Mdot
.55294 .6745 Mdot
.54509 .67057 Mdot
.54117 .66273 Mdot
.55294 .65489 Mdot
.5647 .65097 Mdot
.57646 .65489 Mdot
.5647 .64705 Mdot
.56862 .65881 Mdot
.56078 .65881 Mdot
.56862 .67057 Mdot
.57646 .6745 Mdot
.57646 .6745 Mdot
.58823 .68234 Mdot
.59215 .69018 Mdot
.57646 .68234 Mdot
.58431 .68626 Mdot
.58431 .68234 Mdot
.58039 .6745 Mdot
.59607 .68234 Mdot
.59999 .67842 Mdot
.60391 .68234 Mdot
.59999 .69018 Mdot
.60783 .70194 Mdot
.6196 .71763 Mdot
.61568 .71371 Mdot
.62744 .72155 Mdot
.63528 .73724 Mdot
.63136 .73332 Mdot
.63528 .73332 Mdot
.64313 .72155 Mdot
.64313 .70979 Mdot
.65097 .70979 Mdot
.64705 .71763 Mdot
.65489 .72939 Mdot
.65097 .73724 Mdot
.64705 .74116 Mdot
.65881 .749 Mdot
.66273 .749 Mdot
.66665 .75292 Mdot
.6745 .76076 Mdot
.67842 .76076 Mdot
.6745 .75292 Mdot
.66665 .73724 Mdot
.68234 .74508 Mdot
.6745 .74116 Mdot
.69018 .749 Mdot
.68234 .749 Mdot
.68626 .74508 Mdot
.6941 .73724 Mdot
.6941 .72547 Mdot
.70194 .73332 Mdot
.6941 .73332 Mdot
.69802 .74116 Mdot
.6941 .73724 Mdot
.70194 .74508 Mdot
.6941 .73724 Mdot
.69802 .73724 Mdot
.70979 .74508 Mdot
.70587 .74508 Mdot
.71371 .75684 Mdot
.70194 .75684 Mdot
.69802 .75684 Mdot
.6941 .75292 Mdot
.70979 .75684 Mdot
.70587 .75292 Mdot
.69802 .74508 Mdot
.70587 .74116 Mdot
.70587 .73724 Mdot
.71371 .74116 Mdot
.71371 .74508 Mdot
.70194 .74116 Mdot
.70979 .74116 Mdot
.70979 .74116 Mdot
.71371 .74116 Mdot
.70587 .74116 Mdot
.71763 .74508 Mdot
.71763 .74116 Mdot
.71763 .73724 Mdot
.71371 .73724 Mdot
.71371 .73332 Mdot
.70979 .74116 Mdot
.70587 .73724 Mdot
.71371 .74508 Mdot
.70979 .74508 Mdot
.70979 .74116 Mdot
.71371 .73332 Mdot
.71763 .73724 Mdot
.71371 .73724 Mdot
.71763 .73332 Mdot
.71763 .73332 Mdot
.72155 .73332 Mdot
.71371 .72939 Mdot
.70979 .73332 Mdot
.71763 .74116 Mdot
.70587 .73724 Mdot
.70979 .73724 Mdot
.70979 .73332 Mdot
.70979 .73332 Mdot
.70587 .72939 Mdot
.70194 .72155 Mdot
.69802 .72155 Mdot
.70587 .72939 Mdot
.69802 .72939 Mdot
.70194 .72547 Mdot
.70587 .71763 Mdot
.70194 .70587 Mdot
.70194 .70587 Mdot
.71763 .70587 Mdot
.70979 .68626 Mdot
.71763 .68234 Mdot
.70194 .68626 Mdot
.70979 .69802 Mdot
.70587 .70194 Mdot
.70194 .70587 Mdot
.6941 .69802 Mdot
.69018 .6941 Mdot
.68234 .68626 Mdot
.68626 .70194 Mdot
.6745 .70587 Mdot
.65881 .70587 Mdot
.66273 .70587 Mdot
.67057 .69802 Mdot
.66665 .69802 Mdot
.67057 .70979 Mdot
.65881 .70587 Mdot
.65881 .70587 Mdot
.65881 .70194 Mdot
.65881 .69018 Mdot
.64705 .67842 Mdot
.6392 .6745 Mdot
.6392 .67057 Mdot
.63136 .66273 Mdot
.62744 .66273 Mdot
.62744 .65881 Mdot
.62352 .65881 Mdot
.62352 .65881 Mdot
.60783 .6392 Mdot
.61568 .62352 Mdot
.59607 .58823 Mdot
.58039 .54902 Mdot
.44314 .43138 Mdot
.20002 .24316 Mdot
.19218 .22747 Mdot
.14905 .18042 Mdot
.1961 .20787 Mdot
.21571 .21963 Mdot
.17257 .19218 Mdot
.57254 .58823 Mdot
.78429 .79213 Mdot
.5098 .5647 Mdot
.53333 .61176 Mdot
.54902 .64705 Mdot
.54902 .65881 Mdot
.55294 .66273 Mdot
.54117 .64705 Mdot
.54902 .6392 Mdot
.55686 .6392 Mdot
.54902 .63136 Mdot
.54902 .63528 Mdot
.54509 .63136 Mdot
.55294 .64705 Mdot
.55294 .65097 Mdot
.5647 .65881 Mdot
.57254 .66665 Mdot
.57646 .6745 Mdot
.58823 .68626 Mdot
.57646 .67842 Mdot
.58039 .67842 Mdot
.58823 .67842 Mdot
.58039 .67057 Mdot
.58431 .67057 Mdot
.59607 .68234 Mdot
.59999 .69018 Mdot
.59999 .6941 Mdot
.59215 .68626 Mdot
.58823 .68626 Mdot
.60391 .69802 Mdot
.61568 .70587 Mdot
.62352 .71371 Mdot
.6196 .70979 Mdot
.63136 .71763 Mdot
.6196 .70587 Mdot
.63528 .70587 Mdot
.65489 .71371 Mdot
.64705 .71371 Mdot
.6392 .71763 Mdot
.63528 .72155 Mdot
.64313 .72547 Mdot
.65881 .73724 Mdot
.65097 .72939 Mdot
.66273 .73724 Mdot
.66273 .749 Mdot
.65881 .74508 Mdot
.67842 .749 Mdot
.6745 .74116 Mdot
.67057 .72939 Mdot
.68626 .73724 Mdot
.6745 .73724 Mdot
.6745 .73332 Mdot
.6745 .72547 Mdot
.68234 .72939 Mdot
.69018 .72547 Mdot
.69802 .72939 Mdot
.69802 .72939 Mdot
.6941 .73332 Mdot
.68626 .73332 Mdot
.68626 .74116 Mdot
.68626 .73724 Mdot
.69018 .73724 Mdot
.6941 .73724 Mdot
.68626 .74116 Mdot
.68234 .74116 Mdot
.6941 .749 Mdot
.68234 .73332 Mdot
.68234 .74116 Mdot
.6941 .74508 Mdot
.69802 .74116 Mdot
.69802 .749 Mdot
.70194 .749 Mdot
.69802 .73724 Mdot
.69802 .73724 Mdot
.69802 .73724 Mdot
.69018 .72939 Mdot
.69802 .72939 Mdot
.70194 .72939 Mdot
.69802 .72155 Mdot
.69802 .72547 Mdot
.70194 .72547 Mdot
.71371 .73332 Mdot
.70587 .73724 Mdot
.70587 .73724 Mdot
.6941 .72939 Mdot
.69018 .72547 Mdot
.70587 .72939 Mdot
.70587 .72939 Mdot
.70979 .73332 Mdot
.69018 .72155 Mdot
.6941 .72155 Mdot
.6941 .72547 Mdot
.69802 .72939 Mdot
.70194 .72547 Mdot
.70194 .71763 Mdot
.71371 .72939 Mdot
.70979 .72939 Mdot
.70587 .73724 Mdot
.69802 .73332 Mdot
.70194 .74116 Mdot
.70587 .73724 Mdot
.70194 .72547 Mdot
.70194 .71763 Mdot
.6941 .71371 Mdot
.6941 .71371 Mdot
.69802 .71763 Mdot
.69802 .72155 Mdot
.69018 .72547 Mdot
.70194 .73332 Mdot
.69018 .71763 Mdot
.70194 .71763 Mdot
.70194 .71763 Mdot
.6941 .70587 Mdot
.69802 .70194 Mdot
.69802 .69802 Mdot
.6941 .69018 Mdot
.68626 .68234 Mdot
.67842 .6745 Mdot
.68626 .68626 Mdot
.69018 .68626 Mdot
.68234 .68234 Mdot
.67057 .68234 Mdot
.6745 .6941 Mdot
.66665 .6941 Mdot
.66273 .69802 Mdot
.65881 .6941 Mdot
.64313 .67842 Mdot
.65097 .68626 Mdot
.65097 .68626 Mdot
.65097 .69018 Mdot
.64313 .68626 Mdot
.64705 .6745 Mdot
.6392 .65881 Mdot
.62744 .65881 Mdot
.62352 .65881 Mdot
.6196 .65489 Mdot
.6196 .65489 Mdot
.61568 .65097 Mdot
.61568 .64313 Mdot
.60783 .62744 Mdot
.59607 .62352 Mdot
.59215 .62744 Mdot
.59999 .62352 Mdot
.58823 .60391 Mdot
.58431 .59607 Mdot
.58431 .58823 Mdot
.51765 .52941 Mdot
.49804 .50196 Mdot
.43922 .45491 Mdot
.40001 .41569 Mdot
.26276 .30198 Mdot
.20394 .26276 Mdot
.25884 .30198 Mdot
.35295 .35687 Mdot
.42746 .43922 Mdot
.53333 .55686 Mdot
.48628 .52549 Mdot
.54509 .60391 Mdot
.55294 .6392 Mdot
.55686 .65097 Mdot
.54117 .64705 Mdot
.55294 .64705 Mdot
.54509 .63528 Mdot
.54902 .63136 Mdot
.54509 .63136 Mdot
.55686 .65097 Mdot
.55686 .65489 Mdot
.55294 .65489 Mdot
.54902 .65489 Mdot
.56078 .65489 Mdot
.56862 .65881 Mdot
.57254 .66665 Mdot
.57646 .67842 Mdot
.57646 .68234 Mdot
.58431 .68234 Mdot
.58431 .6745 Mdot
.58823 .6745 Mdot
.59215 .67842 Mdot
.60391 .6941 Mdot
.59215 .69018 Mdot
.59999 .6941 Mdot
.59215 .6941 Mdot
.59999 .70194 Mdot
.59607 .69802 Mdot
.60783 .70194 Mdot
.62352 .70979 Mdot
.62352 .71371 Mdot
.62352 .71763 Mdot
.62744 .71371 Mdot
.6196 .70587 Mdot
.62744 .70587 Mdot
.63136 .70979 Mdot
.62744 .71371 Mdot
.63528 .71763 Mdot
.64705 .72939 Mdot
.65489 .72939 Mdot
.66273 .72939 Mdot
.66273 .73332 Mdot
.66273 .74116 Mdot
.65097 .74508 Mdot
.65881 .749 Mdot
.67057 .75292 Mdot
.67057 .74508 Mdot
.6745 .74116 Mdot
.67842 .74508 Mdot
.67842 .74508 Mdot
.67057 .73724 Mdot
.67842 .73724 Mdot
.6745 .72939 Mdot
.6745 .72547 Mdot
.68234 .73724 Mdot
.68626 .749 Mdot
.68626 .74508 Mdot
.68626 .74508 Mdot
.68234 .73724 Mdot
.69018 .74116 Mdot
.69018 .74116 Mdot
.68234 .73724 Mdot
.67842 .74116 Mdot
.68626 .749 Mdot
.69018 .749 Mdot
.6941 .75292 Mdot
.69802 .749 Mdot
.69802 .749 Mdot
.67842 .74508 Mdot
.68234 .74116 Mdot
.67842 .73724 Mdot
.68626 .74116 Mdot
.69018 .73332 Mdot
.68626 .72939 Mdot
.68626 .72939 Mdot
.6941 .73724 Mdot
.69802 .73724 Mdot
.70194 .73724 Mdot
.6941 .72939 Mdot
.70194 .72939 Mdot
.69802 .73332 Mdot
.70194 .73724 Mdot
.6941 .73332 Mdot
.70194 .72939 Mdot
.70194 .72939 Mdot
.69802 .72547 Mdot
.70194 .72939 Mdot
.6941 .73724 Mdot
.69018 .73724 Mdot
.6941 .73332 Mdot
.69802 .73724 Mdot
.6941 .72939 Mdot
.69018 .72155 Mdot
.6941 .72547 Mdot
.70587 .73724 Mdot
.70979 .749 Mdot
.70194 .74116 Mdot
.69802 .75292 Mdot
.70194 .74508 Mdot
.69018 .72939 Mdot
.6941 .71763 Mdot
.70587 .72155 Mdot
.70587 .72939 Mdot
.69802 .73332 Mdot
.6941 .73332 Mdot
.6941 .73332 Mdot
.69018 .72547 Mdot
.68626 .71371 Mdot
.68234 .70979 Mdot
.68626 .70979 Mdot
.6941 .72155 Mdot
.6941 .71763 Mdot
.67842 .70194 Mdot
.69018 .70587 Mdot
.68234 .70194 Mdot
.6745 .69802 Mdot
.6745 .69802 Mdot
.68626 .69802 Mdot
.67842 .68626 Mdot
.6745 .68626 Mdot
.66665 .69018 Mdot
.65881 .69018 Mdot
.66273 .69802 Mdot
.65881 .6941 Mdot
.65097 .69018 Mdot
.65489 .6941 Mdot
.65097 .6941 Mdot
.6392 .67842 Mdot
.6392 .6745 Mdot
.64313 .6745 Mdot
.64313 .6745 Mdot
.63528 .66665 Mdot
.63528 .66665 Mdot
.6392 .66665 Mdot
.6392 .66273 Mdot
.62352 .65489 Mdot
.61568 .64705 Mdot
.62352 .64705 Mdot
.61568 .63528 Mdot
.61568 .62744 Mdot
.60783 .6196 Mdot
.59999 .61176 Mdot
.59607 .61176 Mdot
.58431 .60783 Mdot
.58039 .60391 Mdot
.5647 .58823 Mdot
.56078 .58039 Mdot
.55294 .57254 Mdot
.52549 .54902 Mdot
.51765 .54902 Mdot
.52157 .55686 Mdot
.53333 .56078 Mdot
.45883 .47843 Mdot
.15689 .22747 Mdot
.23924 .25884 Mdot
.28629 .32943 Mdot
.52157 .54117 Mdot
.48628 .52549 Mdot
.52549 .58431 Mdot
.54902 .61568 Mdot
.55686 .6392 Mdot
.54117 .64705 Mdot
.54509 .65489 Mdot
.54902 .65489 Mdot
.54902 .65489 Mdot
.54902 .65097 Mdot
.54902 .64705 Mdot
.54902 .64705 Mdot
.54902 .65097 Mdot
.55294 .65881 Mdot
.55294 .65489 Mdot
.57254 .65881 Mdot
.56862 .65881 Mdot
.57646 .66665 Mdot
.58431 .6745 Mdot
.58431 .67842 Mdot
.58431 .6745 Mdot
.58823 .6745 Mdot
.58823 .6745 Mdot
.59215 .68234 Mdot
.58431 .68234 Mdot
.58431 .69018 Mdot
.58431 .6941 Mdot
.59215 .70194 Mdot
.58823 .70587 Mdot
.60391 .70587 Mdot
.61176 .70979 Mdot
.61176 .70979 Mdot
.60783 .72547 Mdot
.61568 .72547 Mdot
.61176 .71763 Mdot
.6196 .72547 Mdot
.62352 .71763 Mdot
.6196 .71371 Mdot
.62744 .72155 Mdot
.62744 .72939 Mdot
.63528 .74116 Mdot
.64313 .74116 Mdot
.64313 .73332 Mdot
.65489 .74116 Mdot
.65097 .74508 Mdot
.65097 .749 Mdot
.65489 .74508 Mdot
.67057 .749 Mdot
.66273 .72939 Mdot
.66665 .74116 Mdot
.6745 .749 Mdot
.6745 .749 Mdot
.67057 .74508 Mdot
.67057 .74116 Mdot
.6745 .74508 Mdot
.6745 .749 Mdot
.67057 .74508 Mdot
.67842 .749 Mdot
.68234 .74508 Mdot
.68234 .74508 Mdot
.67842 .74116 Mdot
.68626 .74508 Mdot
.68234 .75292 Mdot
.6745 .75684 Mdot
.68234 .76076 Mdot
.68626 .76076 Mdot
.68626 .75684 Mdot
.68626 .75684 Mdot
.68626 .749 Mdot
.69018 .749 Mdot
.69018 .749 Mdot
.68626 .74116 Mdot
.68234 .72939 Mdot
.68626 .72547 Mdot
.68626 .72939 Mdot
.69802 .74116 Mdot
.70194 .74116 Mdot
.69802 .74508 Mdot
.68626 .749 Mdot
.6941 .76076 Mdot
.69802 .76076 Mdot
.69802 .75684 Mdot
.69802 .75292 Mdot
.68626 .73332 Mdot
.68626 .72547 Mdot
.6941 .73332 Mdot
.6941 .72939 Mdot
.69018 .72547 Mdot
.69018 .73724 Mdot
.67842 .74116 Mdot
.6941 .749 Mdot
.69802 .75684 Mdot
.69802 .75292 Mdot
.6941 .749 Mdot
.68626 .73724 Mdot
.68234 .72939 Mdot
.6941 .73332 Mdot
.69018 .73332 Mdot
.6941 .73724 Mdot
.69802 .73724 Mdot
.6941 .73332 Mdot
.68626 .73332 Mdot
.69018 .73332 Mdot
.6941 .74116 Mdot
.6941 .74116 Mdot
.6941 .749 Mdot
.68234 .73332 Mdot
.68626 .72939 Mdot
.68626 .72155 Mdot
.67842 .70979 Mdot
.68234 .70979 Mdot
.67842 .71371 Mdot
.68234 .71763 Mdot
.69018 .71763 Mdot
.69018 .72155 Mdot
.67842 .72155 Mdot
.66665 .70979 Mdot
.66665 .70587 Mdot
.66273 .70194 Mdot
.66273 .69802 Mdot
.66665 .6941 Mdot
.65489 .69802 Mdot
.66273 .71371 Mdot
.65881 .71763 Mdot
.65881 .71371 Mdot
.66273 .71371 Mdot
.66273 .70979 Mdot
.64705 .70194 Mdot
.63528 .69018 Mdot
.64313 .68626 Mdot
.63136 .67842 Mdot
.63136 .6745 Mdot
.63136 .6745 Mdot
.63136 .66273 Mdot
.62744 .66273 Mdot
.61568 .65881 Mdot
.61176 .66665 Mdot
.60783 .65881 Mdot
.61176 .65097 Mdot
.61568 .64705 Mdot
.60783 .63528 Mdot
.59999 .6196 Mdot
.59999 .61176 Mdot
.60391 .6196 Mdot
.59607 .61568 Mdot
.58823 .60391 Mdot
.57254 .58431 Mdot
.5647 .57646 Mdot
.5647 .57646 Mdot
.56078 .57254 Mdot
.54509 .57254 Mdot
.54117 .58039 Mdot
.52941 .57254 Mdot
.53725 .56862 Mdot
.4902 .52157 Mdot
.50588 .50588 Mdot
.251 .28237 Mdot
.10199 .15297 Mdot
.07062 .09807 Mdot
.5098 .52157 Mdot
.75292 .75684 Mdot
.48628 .51372 Mdot
.54117 .58431 Mdot
.54509 .61176 Mdot
.54509 .62744 Mdot
.54117 .64705 Mdot
.53333 .65097 Mdot
.51372 .64313 Mdot
.52157 .65097 Mdot
.53333 .65489 Mdot
.54902 .65489 Mdot
.54509 .64313 Mdot
.54902 .64705 Mdot
.54509 .65489 Mdot
.55294 .65489 Mdot
.56078 .65097 Mdot
.5647 .64313 Mdot
.57646 .6392 Mdot
.58039 .64313 Mdot
.56862 .64705 Mdot
.57646 .67057 Mdot
.57646 .67057 Mdot
.58039 .6745 Mdot
.58823 .67842 Mdot
.58823 .68234 Mdot
.58431 .69018 Mdot
.58431 .70194 Mdot
.57646 .70194 Mdot
.58431 .70979 Mdot
.58823 .69802 Mdot
.59607 .69802 Mdot
.60391 .70587 Mdot
.59999 .71371 Mdot
.60783 .72547 Mdot
.60391 .72547 Mdot
.60783 .73332 Mdot
.61568 .72939 Mdot
.61568 .70979 Mdot
.6196 .71371 Mdot
.62744 .72547 Mdot
.62744 .72939 Mdot
.62744 .72547 Mdot
.63136 .72547 Mdot
.64313 .72939 Mdot
.65489 .74508 Mdot
.65097 .74116 Mdot
.65489 .74116 Mdot
.66273 .74116 Mdot
.66665 .74116 Mdot
.66273 .73724 Mdot
.66273 .73724 Mdot
.66665 .74508 Mdot
.66665 .75292 Mdot
.65881 .749 Mdot
.66273 .75292 Mdot
.67057 .75684 Mdot
.65881 .74508 Mdot
.66273 .75684 Mdot
.6745 .75684 Mdot
.6745 .75684 Mdot
.6745 .749 Mdot
.67842 .73724 Mdot
.6745 .74508 Mdot
.66665 .749 Mdot
.66665 .75292 Mdot
.6745 .749 Mdot
.6745 .74508 Mdot
.6745 .73724 Mdot
.67842 .749 Mdot
.67057 .74116 Mdot
.6745 .73724 Mdot
.67842 .73332 Mdot
.68234 .72547 Mdot
.69018 .72155 Mdot
.6941 .73332 Mdot
.6745 .72155 Mdot
.67842 .73724 Mdot
.68234 .75684 Mdot
.68626 .76861 Mdot
.68234 .76469 Mdot
.68234 .76469 Mdot
.6745 .75684 Mdot
.67057 .75292 Mdot
.66665 .74508 Mdot
.6745 .73332 Mdot
.68234 .73332 Mdot
.68626 .73724 Mdot
.67842 .72547 Mdot
.6745 .72547 Mdot
.67842 .72939 Mdot
.67057 .73332 Mdot
.6745 .74508 Mdot
.68234 .74116 Mdot
.67842 .73724 Mdot
.67842 .73332 Mdot
.6745 .72547 Mdot
.67842 .72939 Mdot
.68626 .73332 Mdot
.68234 .72547 Mdot
.68626 .72939 Mdot
.68234 .73332 Mdot
.67057 .71763 Mdot
.68234 .72547 Mdot
.68234 .72939 Mdot
.68234 .72939 Mdot
.6745 .72547 Mdot
.67057 .72155 Mdot
.68234 .72155 Mdot
.6745 .71371 Mdot
.67842 .71371 Mdot
.6745 .70979 Mdot
.67057 .70979 Mdot
.66273 .71371 Mdot
.66273 .71371 Mdot
.65881 .70194 Mdot
.67057 .70979 Mdot
.66665 .71371 Mdot
.65097 .70587 Mdot
.64313 .70194 Mdot
.64705 .68626 Mdot
.65097 .68234 Mdot
.65097 .68234 Mdot
.65097 .70194 Mdot
.65097 .71763 Mdot
.63136 .70979 Mdot
.64313 .71371 Mdot
.63136 .69802 Mdot
.62744 .68626 Mdot
.64313 .70587 Mdot
.63528 .69802 Mdot
.63528 .6941 Mdot
.63528 .68626 Mdot
.63136 .67057 Mdot
.62744 .65881 Mdot
.6196 .65489 Mdot
.61176 .66273 Mdot
.61568 .66273 Mdot
.60391 .65489 Mdot
.60783 .64313 Mdot
.61176 .62744 Mdot
.60391 .61176 Mdot
.59999 .60783 Mdot
.59607 .6196 Mdot
.59215 .62744 Mdot
.58823 .61568 Mdot
.58431 .60783 Mdot
.55686 .57646 Mdot
.56862 .58431 Mdot
.56862 .58431 Mdot
.5647 .59215 Mdot
.54902 .58823 Mdot
.55294 .58431 Mdot
.55294 .57646 Mdot
.54117 .55686 Mdot
.53333 .54509 Mdot
.5098 .52157 Mdot
.54902 .53333 Mdot
.25492 .27845 Mdot
.04709 .09415 Mdot
.03533 .0667 Mdot
.01965 .04709 Mdot
.48628 .53333 Mdot
.54117 .59607 Mdot
.55294 .62352 Mdot
.54509 .64705 Mdot
.54117 .66665 Mdot
.53333 .66273 Mdot
.52157 .65097 Mdot
.52941 .64705 Mdot
.53333 .64313 Mdot
.53725 .6392 Mdot
.54902 .64705 Mdot
.54902 .65097 Mdot
.54902 .66273 Mdot
.56078 .67057 Mdot
.58039 .6745 Mdot
.57254 .65097 Mdot
.58039 .65097 Mdot
.57646 .64705 Mdot
.56862 .65489 Mdot
.58431 .67842 Mdot
.58039 .69018 Mdot
.58039 .69018 Mdot
.58823 .68626 Mdot
.57646 .6745 Mdot
.58431 .69018 Mdot
.57254 .70194 Mdot
.58039 .71371 Mdot
.58823 .70979 Mdot
.59607 .69802 Mdot
.60391 .6941 Mdot
.61568 .70979 Mdot
.58823 .6941 Mdot
.60391 .71763 Mdot
.60783 .72547 Mdot
.60391 .72547 Mdot
.61176 .72155 Mdot
.61176 .70587 Mdot
.6196 .70587 Mdot
.62352 .70587 Mdot
.6196 .70194 Mdot
.63528 .70979 Mdot
.63528 .71371 Mdot
.6392 .71763 Mdot
.64705 .72547 Mdot
.65097 .73332 Mdot
.6392 .72547 Mdot
.65489 .73724 Mdot
.66665 .72939 Mdot
.66665 .72547 Mdot
.66273 .73332 Mdot
.65489 .73724 Mdot
.65489 .74508 Mdot
.66273 .75684 Mdot
.66665 .75292 Mdot
.65489 .74116 Mdot
.65881 .74116 Mdot
.65881 .73724 Mdot
.66665 .75292 Mdot
.66665 .76076 Mdot
.67057 .75684 Mdot
.67842 .749 Mdot
.6745 .74508 Mdot
.66665 .749 Mdot
.6745 .75292 Mdot
.6745 .74116 Mdot
.67057 .73332 Mdot
.68234 .73724 Mdot
.67842 .73724 Mdot
.6745 .73724 Mdot
.6745 .72939 Mdot
.67057 .71763 Mdot
.67842 .70979 Mdot
.68234 .71371 Mdot
.6745 .71763 Mdot
.67842 .72939 Mdot
.67842 .74508 Mdot
.67842 .75684 Mdot
.67057 .75292 Mdot
.67057 .75684 Mdot
.6745 .76469 Mdot
.66665 .75684 Mdot
.67057 .75684 Mdot
.6745 .75292 Mdot
.6745 .73724 Mdot
.68234 .73724 Mdot
.68234 .72939 Mdot
.67057 .72547 Mdot
.66273 .72155 Mdot
.67842 .72547 Mdot
.67842 .72547 Mdot
.6745 .73724 Mdot
.67057 .72939 Mdot
.6745 .72939 Mdot
.68234 .73332 Mdot
.6745 .72939 Mdot
.6745 .72939 Mdot
.67842 .72547 Mdot
.67842 .72547 Mdot
.67057 .72939 Mdot
.68234 .73332 Mdot
.68234 .72939 Mdot
.68234 .72547 Mdot
.67842 .71763 Mdot
.68234 .71763 Mdot
.6745 .72547 Mdot
.67842 .72547 Mdot
.67842 .72155 Mdot
.67842 .71763 Mdot
.68234 .71763 Mdot
.6745 .70979 Mdot
.67057 .71371 Mdot
.65881 .70587 Mdot
.66665 .70587 Mdot
.66665 .70587 Mdot
.65881 .70587 Mdot
.65489 .70979 Mdot
.65097 .70587 Mdot
.65097 .70587 Mdot
.65489 .70587 Mdot
.64313 .6941 Mdot
.6392 .69018 Mdot
.65097 .70194 Mdot
.63528 .70979 Mdot
.64313 .72547 Mdot
.6392 .71763 Mdot
.63528 .70194 Mdot
.63136 .6941 Mdot
.6392 .69802 Mdot
.6392 .70194 Mdot
.62352 .68234 Mdot
.62744 .68234 Mdot
.62744 .67842 Mdot
.61176 .66665 Mdot
.6196 .6745 Mdot
.6196 .67057 Mdot
.61568 .6745 Mdot
.60783 .66273 Mdot
.60783 .64705 Mdot
.60391 .63136 Mdot
.60391 .62352 Mdot
.59607 .61568 Mdot
.59607 .62352 Mdot
.58039 .6196 Mdot
.58039 .6196 Mdot
.58823 .61568 Mdot
.5647 .58431 Mdot
.56078 .57646 Mdot
.5647 .58431 Mdot
.55686 .59215 Mdot
.54509 .59215 Mdot
.54509 .58823 Mdot
.53725 .5647 Mdot
.52549 .54117 Mdot
.52941 .54117 Mdot
.5098 .52549 Mdot
.51765 .52941 Mdot
.51765 .51765 Mdot
.1961 .26668 Mdot
.14905 .21963 Mdot
.1216 .18434 Mdot
.47843 .54509 Mdot
.54509 .6196 Mdot
.56078 .64705 Mdot
.54509 .65097 Mdot
.54117 .66273 Mdot
.52941 .66273 Mdot
.53333 .65881 Mdot
.54509 .65489 Mdot
.56078 .65097 Mdot
.5647 .64705 Mdot
.55294 .65097 Mdot
.55294 .65881 Mdot
.55686 .66273 Mdot
.56862 .67057 Mdot
.57254 .66665 Mdot
.57646 .65881 Mdot
.58431 .65489 Mdot
.58431 .66665 Mdot
.57254 .67057 Mdot
.57646 .68234 Mdot
.58039 .6941 Mdot
.58039 .6941 Mdot
.58431 .68626 Mdot
.58823 .68234 Mdot
.58823 .68234 Mdot
.59215 .69802 Mdot
.59215 .69802 Mdot
.58431 .69018 Mdot
.59607 .69018 Mdot
.61176 .6941 Mdot
.60391 .68626 Mdot
.59607 .68626 Mdot
.60391 .70194 Mdot
.60391 .70979 Mdot
.60783 .71763 Mdot
.60391 .70587 Mdot
.61568 .70979 Mdot
.61568 .70979 Mdot
.6196 .70979 Mdot
.62352 .71371 Mdot
.6392 .71763 Mdot
.6392 .70194 Mdot
.64705 .70194 Mdot
.64705 .71371 Mdot
.65489 .73332 Mdot
.65489 .74508 Mdot
.65489 .74116 Mdot
.65489 .73332 Mdot
.66273 .73724 Mdot
.67842 .75292 Mdot
.65881 .74508 Mdot
.66273 .75292 Mdot
.66273 .749 Mdot
.66665 .749 Mdot
.6745 .75292 Mdot
.6745 .749 Mdot
.67842 .75292 Mdot
.67057 .75684 Mdot
.66273 .76076 Mdot
.66273 .75684 Mdot
.66665 .75292 Mdot
.66665 .74116 Mdot
.66665 .73332 Mdot
.67842 .73724 Mdot
.68626 .749 Mdot
.67842 .74116 Mdot
.6745 .73724 Mdot
.6745 .74116 Mdot
.67842 .74508 Mdot
.66273 .73332 Mdot
.67057 .72939 Mdot
.67057 .72155 Mdot
.68234 .72155 Mdot
.66665 .71763 Mdot
.67842 .72547 Mdot
.68234 .74508 Mdot
.68626 .75684 Mdot
.67057 .75292 Mdot
.67057 .75684 Mdot
.66273 .75292 Mdot
.6745 .75684 Mdot
.67842 .76861 Mdot
.6745 .76469 Mdot
.67842 .75292 Mdot
.67842 .74116 Mdot
.68626 .74508 Mdot
.68234 .749 Mdot
.68234 .75292 Mdot
.69018 .75292 Mdot
.68626 .749 Mdot
.67842 .74116 Mdot
.68234 .73332 Mdot
.68626 .72939 Mdot
.6745 .72939 Mdot
.67842 .73332 Mdot
.6745 .73332 Mdot
.67842 .72939 Mdot
.6745 .72939 Mdot
.68234 .74508 Mdot
.6745 .73332 Mdot
.67842 .72939 Mdot
.67842 .73332 Mdot
.6941 .749 Mdot
.69018 .74508 Mdot
.6941 .74508 Mdot
.68234 .74116 Mdot
.68234 .73724 Mdot
.68234 .72939 Mdot
.6745 .71371 Mdot
.67057 .70979 Mdot
.67842 .71763 Mdot
.67842 .71763 Mdot
.67057 .70979 Mdot
.67057 .71371 Mdot
.66273 .70587 Mdot
.64705 .69802 Mdot
.65097 .70194 Mdot
.65881 .70587 Mdot
.65881 .70587 Mdot
.65489 .70587 Mdot
.64705 .69802 Mdot
.65881 .70979 Mdot
.64313 .70979 Mdot
.64313 .72155 Mdot
.63136 .70979 Mdot
.6392 .70587 Mdot
.64705 .70587 Mdot
.6392 .6941 Mdot
.63528 .69802 Mdot
.63528 .70587 Mdot
.62744 .6941 Mdot
.62744 .68626 Mdot
.62352 .67842 Mdot
.61568 .67057 Mdot
.62352 .6745 Mdot
.6196 .67842 Mdot
.61176 .6745 Mdot
.61176 .65881 Mdot
.60391 .63528 Mdot
.60783 .62744 Mdot
.59999 .60783 Mdot
.61176 .61568 Mdot
.60391 .6196 Mdot
.60391 .61568 Mdot
.59999 .60391 Mdot
.58431 .58431 Mdot
.58039 .58039 Mdot
.56862 .58431 Mdot
.5647 .58823 Mdot
.57254 .60391 Mdot
.55686 .60391 Mdot
.54509 .59607 Mdot
.53333 .58431 Mdot
.53725 .57646 Mdot
.53333 .56078 Mdot
.52157 .54902 Mdot
.51372 .54117 Mdot
.50588 .52941 Mdot
.45098 .48235 Mdot
.44314 .45491 Mdot
.46667 .54509 Mdot
.53725 .6196 Mdot
.54902 .64313 Mdot
.54117 .64313 Mdot
.54902 .65881 Mdot
.54509 .65881 Mdot
.53725 .65097 Mdot
.54509 .64313 Mdot
.53725 .6392 Mdot
.54509 .64705 Mdot
.54902 .65097 Mdot
.55686 .65097 Mdot
.55686 .65881 Mdot
.56078 .66273 Mdot
.5647 .66273 Mdot
.55686 .65097 Mdot
.58039 .65881 Mdot
.58039 .67057 Mdot
.57254 .6745 Mdot
.56078 .6745 Mdot
.5647 .6745 Mdot
.56862 .67842 Mdot
.58823 .69802 Mdot
.58431 .70194 Mdot
.58823 .69802 Mdot
.59215 .70194 Mdot
.58431 .69802 Mdot
.59999 .69802 Mdot
.61176 .70194 Mdot
.60391 .6941 Mdot
.59999 .6941 Mdot
.59999 .70194 Mdot
.60391 .70194 Mdot
.60391 .70587 Mdot
.60391 .70979 Mdot
.61176 .70979 Mdot
.62352 .71763 Mdot
.6196 .71763 Mdot
.61176 .71371 Mdot
.6196 .70979 Mdot
.62744 .70587 Mdot
.63528 .70194 Mdot
.64705 .70587 Mdot
.64705 .70587 Mdot
.65097 .72547 Mdot
.64313 .73332 Mdot
.65097 .73724 Mdot
.65881 .74116 Mdot
.65097 .73332 Mdot
.64313 .73332 Mdot
.64313 .73724 Mdot
.65489 .74508 Mdot
.66273 .749 Mdot
.66273 .75292 Mdot
.65881 .75292 Mdot
.65881 .76076 Mdot
.65881 .76861 Mdot
.66665 .77253 Mdot
.66273 .77253 Mdot
.65881 .76469 Mdot
.66273 .76469 Mdot
.66665 .75292 Mdot
.67057 .749 Mdot
.68234 .75292 Mdot
.6745 .73724 Mdot
.67057 .73724 Mdot
.67057 .74116 Mdot
.67057 .749 Mdot
.6745 .75684 Mdot
.65881 .75292 Mdot
.66273 .749 Mdot
.66665 .74508 Mdot
.6745 .73724 Mdot
.68234 .73724 Mdot
.6745 .72547 Mdot
.67842 .73724 Mdot
.66665 .74116 Mdot
.66665 .749 Mdot
.66665 .749 Mdot
.67057 .749 Mdot
.67057 .749 Mdot
.67057 .76076 Mdot
.6745 .77253 Mdot
.6745 .76469 Mdot
.6745 .75292 Mdot
.67057 .75292 Mdot
.66665 .75292 Mdot
.67057 .75684 Mdot
.6745 .76076 Mdot
.67057 .76076 Mdot
.6745 .75684 Mdot
.67057 .74116 Mdot
.66665 .73724 Mdot
.65881 .74116 Mdot
.66665 .74116 Mdot
.66273 .73724 Mdot
.6745 .74116 Mdot
.66665 .73724 Mdot
.67842 .75292 Mdot
.67842 .75684 Mdot
.67842 .75292 Mdot
.6745 .74508 Mdot
.67057 .74116 Mdot
.66665 .749 Mdot
.67057 .749 Mdot
.67057 .749 Mdot
.67057 .74508 Mdot
.66273 .72939 Mdot
.67057 .72547 Mdot
.67842 .72939 Mdot
.67057 .73332 Mdot
.6745 .73332 Mdot
.66665 .72155 Mdot
.66273 .71371 Mdot
.65881 .71763 Mdot
.65881 .71763 Mdot
.65881 .71371 Mdot
.65881 .71763 Mdot
.65489 .70979 Mdot
.64705 .70194 Mdot
.65097 .70194 Mdot
.65097 .70587 Mdot
.64705 .69802 Mdot
.64313 .6941 Mdot
.6392 .70194 Mdot
.63136 .69802 Mdot
.63528 .70194 Mdot
.63136 .70194 Mdot
.6196 .69018 Mdot
.6392 .70587 Mdot
.6392 .70587 Mdot
.62744 .69802 Mdot
.6196 .68234 Mdot
.61568 .67842 Mdot
.60783 .65489 Mdot
.59999 .65097 Mdot
.60391 .65489 Mdot
.60391 .65489 Mdot
.61176 .65097 Mdot
.60391 .63528 Mdot
.59999 .61568 Mdot
.60783 .60783 Mdot
.59999 .61176 Mdot
.58823 .60391 Mdot
.58431 .59607 Mdot
.58039 .59215 Mdot
.57646 .58823 Mdot
.5647 .58431 Mdot
.55686 .58431 Mdot
.56078 .59607 Mdot
.55686 .59999 Mdot
.55686 .59999 Mdot
.54509 .59215 Mdot
.54509 .58431 Mdot
.54902 .59215 Mdot
.52941 .57254 Mdot
.52157 .54902 Mdot
.51765 .54117 Mdot
.5098 .52157 Mdot
.48628 .48235 Mdot
.44314 .53725 Mdot
.53725 .63136 Mdot
.54509 .65097 Mdot
.54117 .64705 Mdot
.54117 .65489 Mdot
.54117 .65097 Mdot
.53725 .65097 Mdot
.53333 .64705 Mdot
.52549 .64705 Mdot
.53725 .65097 Mdot
.54509 .65881 Mdot
.54509 .65097 Mdot
.54902 .65097 Mdot
.5647 .66273 Mdot
.56862 .66665 Mdot
.56862 .66273 Mdot
.57646 .66665 Mdot
.58823 .67842 Mdot
.57254 .66665 Mdot
.56862 .66665 Mdot
.57254 .66665 Mdot
.56862 .66665 Mdot
.56862 .68234 Mdot
.57646 .70194 Mdot
.58039 .70194 Mdot
.58039 .70587 Mdot
.58039 .70194 Mdot
.58431 .70587 Mdot
.59215 .70979 Mdot
.58431 .69802 Mdot
.59215 .69802 Mdot
.59607 .70587 Mdot
.58039 .69802 Mdot
.59607 .70979 Mdot
.60391 .71371 Mdot
.61176 .72155 Mdot
.61176 .71371 Mdot
.61176 .71371 Mdot
.60783 .71371 Mdot
.61568 .71371 Mdot
.6196 .71371 Mdot
.62744 .71371 Mdot
.6392 .70979 Mdot
.6392 .70587 Mdot
.64313 .72547 Mdot
.63528 .72939 Mdot
.64705 .73724 Mdot
.64705 .749 Mdot
.64705 .73724 Mdot
.64313 .73332 Mdot
.65489 .749 Mdot
.65489 .75684 Mdot
.65097 .75684 Mdot
.65097 .75292 Mdot
.65097 .75292 Mdot
.66273 .76076 Mdot
.65489 .76469 Mdot
.65489 .76469 Mdot
.65489 .76469 Mdot
.65489 .76469 Mdot
.65881 .76861 Mdot
.65489 .75292 Mdot
.66665 .75684 Mdot
.6745 .75292 Mdot
.67057 .74116 Mdot
.66665 .73724 Mdot
.67057 .74116 Mdot
.65881 .74116 Mdot
.66665 .76076 Mdot
.66273 .76861 Mdot
.65097 .76469 Mdot
.65489 .76076 Mdot
.66665 .75292 Mdot
.67057 .749 Mdot
.67057 .74508 Mdot
.66665 .749 Mdot
.66273 .74508 Mdot
.65881 .74508 Mdot
.65881 .749 Mdot
.67057 .75684 Mdot
.66665 .75292 Mdot
.67057 .75684 Mdot
.66273 .76469 Mdot
.65881 .76469 Mdot
.66665 .76861 Mdot
.65881 .76469 Mdot
.65489 .76469 Mdot
.66273 .77253 Mdot
.66665 .77645 Mdot
.65881 .77645 Mdot
.66665 .77645 Mdot
.65881 .76469 Mdot
.65881 .76469 Mdot
.66273 .76469 Mdot
.66665 .76469 Mdot
.65881 .75684 Mdot
.66665 .75292 Mdot
.6745 .75292 Mdot
.67057 .75292 Mdot
.67057 .75684 Mdot
.67842 .76076 Mdot
.67842 .76076 Mdot
.66273 .74508 Mdot
.66665 .74508 Mdot
.66665 .74116 Mdot
.66273 .74116 Mdot
.65881 .74116 Mdot
.65881 .74116 Mdot
.67057 .74116 Mdot
.66665 .73724 Mdot
.66273 .73332 Mdot
.66665 .73332 Mdot
.66273 .73724 Mdot
.65881 .72547 Mdot
.64705 .71763 Mdot
.65489 .72547 Mdot
.65489 .72547 Mdot
.65097 .72155 Mdot
.64705 .71763 Mdot
.63528 .70194 Mdot
.64313 .70194 Mdot
.64705 .70587 Mdot
.64313 .70194 Mdot
.63528 .6941 Mdot
.63528 .6941 Mdot
.6392 .6941 Mdot
.62744 .6941 Mdot
.62744 .70194 Mdot
.62744 .69018 Mdot
.62352 .68234 Mdot
.6196 .68626 Mdot
.61568 .67842 Mdot
.6196 .68234 Mdot
.62352 .67842 Mdot
.61176 .66665 Mdot
.59607 .65097 Mdot
.59607 .64705 Mdot
.59607 .64705 Mdot
.59607 .6392 Mdot
.59215 .63136 Mdot
.59215 .62744 Mdot
.58431 .6196 Mdot
.58039 .61568 Mdot
.56862 .61176 Mdot
.57646 .61568 Mdot
.58039 .60783 Mdot
.57254 .59607 Mdot
.5647 .58823 Mdot
.55686 .58823 Mdot
.56078 .59999 Mdot
.55686 .59999 Mdot
.54509 .58823 Mdot
.54117 .58039 Mdot
.53333 .58039 Mdot
.52549 .57254 Mdot
.51765 .55686 Mdot
.51765 .54902 Mdot
.51372 .53725 Mdot
.50196 .5098 Mdot
.50196 .4902 Mdot
.46667 .54509 Mdot
.52157 .62352 Mdot
.54117 .65489 Mdot
.54117 .6745 Mdot
.54117 .6745 Mdot
.53725 .67057 Mdot
.52157 .65489 Mdot
.52157 .65489 Mdot
.52941 .65489 Mdot
.54902 .65881 Mdot
.54117 .64705 Mdot
.54902 .65097 Mdot
.55686 .65489 Mdot
.54902 .65097 Mdot
.56078 .65881 Mdot
.5647 .65881 Mdot
.56862 .66273 Mdot
.57646 .68234 Mdot
.55294 .67057 Mdot
.5647 .67057 Mdot
.56862 .67057 Mdot
.56862 .67057 Mdot
.56862 .67057 Mdot
.58039 .69018 Mdot
.57254 .6941 Mdot
.56862 .69802 Mdot
.57646 .70194 Mdot
.57646 .69802 Mdot
.58823 .70194 Mdot
.59215 .70194 Mdot
.59999 .70587 Mdot
.59607 .71371 Mdot
.59999 .72547 Mdot
.58823 .71763 Mdot
.59215 .72547 Mdot
.59999 .72547 Mdot
.60391 .71763 Mdot
.60783 .71371 Mdot
.61176 .72547 Mdot
.61176 .72155 Mdot
.62352 .72155 Mdot
.61568 .71763 Mdot
.63136 .71371 Mdot
.63136 .70979 Mdot
.62744 .71371 Mdot
.63136 .72155 Mdot
.63528 .73724 Mdot
.63528 .74508 Mdot
.62744 .73332 Mdot
.65097 .749 Mdot
.64313 .74116 Mdot
.64313 .74508 Mdot
.6392 .75292 Mdot
.64705 .75684 Mdot
.64705 .75684 Mdot
.65489 .76076 Mdot
.65489 .76076 Mdot
.65489 .75684 Mdot
.65489 .75292 Mdot
.65097 .75292 Mdot
.65489 .75684 Mdot
.65097 .749 Mdot
.65881 .749 Mdot
.66273 .74508 Mdot
.66273 .74508 Mdot
.66273 .74508 Mdot
.65881 .74116 Mdot
.65881 .74116 Mdot
.65881 .74508 Mdot
.65881 .749 Mdot
.66273 .76076 Mdot
.65881 .75684 Mdot
.65881 .75292 Mdot
.65881 .75292 Mdot
.65881 .749 Mdot
.65881 .75292 Mdot
.65097 .75684 Mdot
.65489 .76469 Mdot
.65489 .75684 Mdot
.67057 .76469 Mdot
.66273 .75292 Mdot
.65881 .75292 Mdot
.66665 .75684 Mdot
.65881 .75292 Mdot
.65881 .76469 Mdot
.66665 .77645 Mdot
.67057 .78429 Mdot
.66665 .77645 Mdot
.66665 .77645 Mdot
.66665 .77253 Mdot
.66273 .76469 Mdot
.66273 .76469 Mdot
.65881 .76469 Mdot
.6745 .77253 Mdot
.66273 .76469 Mdot
.65489 .76469 Mdot
.66273 .76861 Mdot
.66273 .76469 Mdot
.67057 .76469 Mdot
.66665 .75684 Mdot
.67057 .75292 Mdot
.67057 .75292 Mdot
.65881 .74508 Mdot
.66665 .74116 Mdot
.67057 .73724 Mdot
.66665 .74116 Mdot
.65881 .73724 Mdot
.66665 .749 Mdot
.66665 .74508 Mdot
.66273 .73724 Mdot
.65097 .72939 Mdot
.65489 .73332 Mdot
.65881 .73332 Mdot
.65097 .72155 Mdot
.64313 .71371 Mdot
.65097 .71763 Mdot
.6392 .70979 Mdot
.65097 .71763 Mdot
.64313 .70979 Mdot
.6392 .70979 Mdot
.6392 .70587 Mdot
.64313 .70587 Mdot
.6392 .70587 Mdot
.63528 .70194 Mdot
.62352 .69018 Mdot
.62744 .68626 Mdot
.63136 .6941 Mdot
.62352 .6941 Mdot
.63528 .70194 Mdot
.62744 .69018 Mdot
.6196 .67842 Mdot
.61176 .6745 Mdot
.61176 .67842 Mdot
.60391 .67057 Mdot
.61176 .6745 Mdot
.61568 .67057 Mdot
.60783 .65489 Mdot
.60783 .65489 Mdot
.59607 .64313 Mdot
.59215 .64313 Mdot
.59215 .64705 Mdot
.58823 .6392 Mdot
.57254 .62744 Mdot
.57254 .63136 Mdot
.57646 .62744 Mdot
.57646 .61568 Mdot
.58431 .61176 Mdot
.56862 .61176 Mdot
.5647 .61568 Mdot
.54902 .6196 Mdot
.53333 .61568 Mdot
.52549 .60391 Mdot
.52549 .59215 Mdot
.52941 .58431 Mdot
.53333 .57646 Mdot
.53333 .56862 Mdot
.53333 .55686 Mdot
.52549 .54117 Mdot
.52157 .51765 Mdot
.50588 .48628 Mdot
.45883 .54117 Mdot
.52157 .61568 Mdot
.53333 .64313 Mdot
.54117 .65881 Mdot
.52549 .66273 Mdot
.51765 .65881 Mdot
.5098 .65097 Mdot
.53333 .66665 Mdot
.52941 .65881 Mdot
.53333 .65881 Mdot
.54117 .65489 Mdot
.53725 .65097 Mdot
.53333 .64313 Mdot
.55294 .65489 Mdot
.53725 .65881 Mdot
.55294 .67057 Mdot
.5647 .67057 Mdot
.56862 .6745 Mdot
.56862 .6745 Mdot
.56862 .67057 Mdot
.57646 .67057 Mdot
.58431 .67842 Mdot
.58431 .67842 Mdot
.58823 .6745 Mdot
.58039 .67057 Mdot
.58431 .67842 Mdot
.57254 .67842 Mdot
.58431 .68626 Mdot
.58039 .68626 Mdot
.58823 .68626 Mdot
.59215 .69018 Mdot
.59215 .69802 Mdot
.59607 .71371 Mdot
.59999 .72155 Mdot
.59215 .72155 Mdot
.59999 .72547 Mdot
.59607 .72155 Mdot
.60391 .71371 Mdot
.60391 .70587 Mdot
.61176 .71371 Mdot
.61568 .72547 Mdot
.61568 .72155 Mdot
.6196 .71763 Mdot
.6196 .70587 Mdot
.61568 .70194 Mdot
.6196 .70979 Mdot
.6392 .72939 Mdot
.6392 .73724 Mdot
.63136 .72939 Mdot
.62744 .73724 Mdot
.63528 .74508 Mdot
.63136 .74116 Mdot
.63528 .74508 Mdot
.64705 .76076 Mdot
.65489 .76469 Mdot
.65097 .76076 Mdot
.64313 .75292 Mdot
.65881 .75292 Mdot
.65097 .74508 Mdot
.65489 .749 Mdot
.64705 .74116 Mdot
.65881 .74508 Mdot
.66273 .74116 Mdot
.65489 .73332 Mdot
.65097 .72939 Mdot
.65097 .73724 Mdot
.65881 .74116 Mdot
.65097 .73724 Mdot
.65489 .74116 Mdot
.64705 .73724 Mdot
.65097 .74508 Mdot
.64313 .74116 Mdot
.65881 .75292 Mdot
.65881 .749 Mdot
.65097 .74116 Mdot
.65489 .74508 Mdot
.65097 .749 Mdot
.65097 .75684 Mdot
.66273 .77253 Mdot
.66665 .77253 Mdot
.66273 .76076 Mdot
.66665 .75684 Mdot
.66273 .75292 Mdot
.65881 .75292 Mdot
.66273 .75292 Mdot
.66665 .76469 Mdot
.67057 .77253 Mdot
.65489 .76469 Mdot
.66273 .75684 Mdot
.66273 .749 Mdot
.66273 .75684 Mdot
.65097 .75292 Mdot
.64705 .749 Mdot
.65489 .75292 Mdot
.65489 .76076 Mdot
.66273 .76469 Mdot
.66273 .76469 Mdot
.66273 .76076 Mdot
.66273 .75684 Mdot
.65881 .75292 Mdot
.65881 .749 Mdot
.66665 .74508 Mdot
.66273 .74508 Mdot
.65881 .73332 Mdot
.66273 .73332 Mdot
.65097 .73332 Mdot
.65881 .74116 Mdot
.67057 .75292 Mdot
.67057 .75684 Mdot
.66665 .74508 Mdot
.65097 .73332 Mdot
.64705 .72547 Mdot
.65097 .72155 Mdot
.65489 .72155 Mdot
.64705 .70979 Mdot
.65097 .70979 Mdot
.65881 .71763 Mdot
.64705 .72547 Mdot
.63136 .71763 Mdot
.63528 .71371 Mdot
.63528 .70979 Mdot
.63528 .6941 Mdot
.63136 .69018 Mdot
.63136 .68626 Mdot
.62352 .68626 Mdot
.6196 .68626 Mdot
.62352 .69018 Mdot
.61568 .69018 Mdot
.62352 .69018 Mdot
.60783 .69018 Mdot
.61568 .6941 Mdot
.61176 .68626 Mdot
.60783 .6745 Mdot
.59607 .65881 Mdot
.59607 .65489 Mdot
.60391 .66665 Mdot
.59607 .65489 Mdot
.59999 .65489 Mdot
.59607 .65097 Mdot
.58823 .64313 Mdot
.58039 .64313 Mdot
.56862 .63136 Mdot
.56078 .62352 Mdot
.56862 .62352 Mdot
.5647 .61568 Mdot
.56862 .60391 Mdot
.5647 .59999 Mdot
.56078 .59607 Mdot
.55686 .59999 Mdot
.54902 .61568 Mdot
.55294 .62744 Mdot
.54117 .61568 Mdot
.53725 .59999 Mdot
.53725 .58823 Mdot
.52941 .57646 Mdot
.52157 .55294 Mdot
.52549 .54117 Mdot
.52157 .52549 Mdot
.5098 .50196 Mdot
.51765 .48628 Mdot
.46667 .54902 Mdot
.50196 .60783 Mdot
.51765 .63136 Mdot
.52157 .6392 Mdot
.52549 .65097 Mdot
.52941 .65881 Mdot
.52549 .65489 Mdot
.52549 .65881 Mdot
.5098 .64705 Mdot
.52549 .65881 Mdot
.54117 .66273 Mdot
.52941 .65097 Mdot
.54509 .65881 Mdot
.54902 .65881 Mdot
.54509 .65881 Mdot
.56078 .66273 Mdot
.55686 .65881 Mdot
.55686 .66273 Mdot
.54902 .65881 Mdot
.56078 .65881 Mdot
.56078 .65881 Mdot
.56862 .66665 Mdot
.57254 .66665 Mdot
.56862 .66273 Mdot
.57254 .66273 Mdot
.57646 .67057 Mdot
.58039 .67842 Mdot
.57646 .68626 Mdot
.58039 .6941 Mdot
.58823 .6941 Mdot
.57646 .68234 Mdot
.57646 .69018 Mdot
.58823 .70194 Mdot
.60391 .71371 Mdot
.59999 .72155 Mdot
.59607 .71763 Mdot
.61176 .72155 Mdot
.60391 .70194 Mdot
.61176 .70194 Mdot
.59607 .69802 Mdot
.59999 .71763 Mdot
.59999 .71763 Mdot
.59999 .70587 Mdot
.61176 .70587 Mdot
.61176 .70587 Mdot
.6196 .70979 Mdot
.62352 .71371 Mdot
.62352 .71763 Mdot
.62744 .72547 Mdot
.61176 .72155 Mdot
.61176 .73332 Mdot
.61176 .72939 Mdot
.62352 .72939 Mdot
.62744 .73332 Mdot
.62744 .73332 Mdot
.62744 .73724 Mdot
.63528 .74116 Mdot
.63528 .74116 Mdot
.62744 .72939 Mdot
.62352 .72939 Mdot
.6392 .749 Mdot
.63136 .74116 Mdot
.6392 .72939 Mdot
.64705 .73332 Mdot
.64313 .72939 Mdot
.64313 .72939 Mdot
.64705 .73332 Mdot
.65097 .74116 Mdot
.64313 .72939 Mdot
.64705 .72939 Mdot
.6392 .72547 Mdot
.64313 .72939 Mdot
.64705 .73724 Mdot
.65489 .73724 Mdot
.65097 .72547 Mdot
.65097 .73332 Mdot
.65489 .749 Mdot
.65097 .75684 Mdot
.65097 .75292 Mdot
.65881 .76469 Mdot
.65881 .76469 Mdot
.66273 .76469 Mdot
.65097 .75292 Mdot
.65881 .75292 Mdot
.65489 .74508 Mdot
.64705 .749 Mdot
.64705 .74508 Mdot
.64705 .73724 Mdot
.65097 .73724 Mdot
.64705 .73332 Mdot
.65489 .74508 Mdot
.65489 .74116 Mdot
.64313 .72939 Mdot
.64313 .74116 Mdot
.65489 .75292 Mdot
.65097 .75292 Mdot
.65489 .75292 Mdot
.65097 .749 Mdot
.65097 .749 Mdot
.65097 .74116 Mdot
.65097 .72939 Mdot
.65489 .72547 Mdot
.66665 .72939 Mdot
.66273 .73332 Mdot
.65489 .72939 Mdot
.6392 .72155 Mdot
.64705 .72155 Mdot
.64705 .72939 Mdot
.64705 .72547 Mdot
.65097 .72939 Mdot
.64705 .72939 Mdot
.64313 .71763 Mdot
.63528 .71371 Mdot
.6392 .71763 Mdot
.6392 .71371 Mdot
.64313 .72155 Mdot
.64705 .72155 Mdot
.63528 .72155 Mdot
.62744 .71371 Mdot
.6196 .70587 Mdot
.62352 .70587 Mdot
.62352 .6941 Mdot
.63136 .68626 Mdot
.62352 .67842 Mdot
.61568 .67842 Mdot
.61176 .67842 Mdot
.60391 .67842 Mdot
.61176 .67842 Mdot
.59999 .66665 Mdot
.59999 .66665 Mdot
.60391 .6745 Mdot
.61176 .68626 Mdot
.60391 .67842 Mdot
.60391 .67057 Mdot
.59215 .66273 Mdot
.58039 .65097 Mdot
.56862 .64313 Mdot
.57646 .64705 Mdot
.57254 .64705 Mdot
.57254 .6392 Mdot
.56862 .63528 Mdot
.56862 .63528 Mdot
.55686 .62352 Mdot
.55294 .62352 Mdot
.5647 .62744 Mdot
.56078 .6196 Mdot
.55686 .60783 Mdot
.56078 .60783 Mdot
.5647 .61176 Mdot
.54902 .59607 Mdot
.54509 .59607 Mdot
.52549 .59215 Mdot
.52941 .58823 Mdot
.54117 .59215 Mdot
.51765 .56862 Mdot
.51372 .55294 Mdot
.51765 .53725 Mdot
.51372 .51372 Mdot
.50588 .49804 Mdot
.4902 .46667 Mdot
.45098 .5647 Mdot
.4902 .61568 Mdot
.51765 .64705 Mdot
.52157 .65097 Mdot
.51765 .65097 Mdot
.52941 .66273 Mdot
.52157 .66273 Mdot
.52549 .67057 Mdot
.52941 .66665 Mdot
.54117 .66665 Mdot
.54509 .65881 Mdot
.54902 .65881 Mdot
.54509 .65881 Mdot
.54902 .65881 Mdot
.54902 .65881 Mdot
.55686 .66273 Mdot
.5647 .66273 Mdot
.56862 .66273 Mdot
.56862 .66273 Mdot
.55294 .65489 Mdot
.55686 .65881 Mdot
.56862 .66665 Mdot
.56862 .67057 Mdot
.57646 .67057 Mdot
.57254 .66665 Mdot
.56862 .65881 Mdot
.58039 .67842 Mdot
.58431 .6941 Mdot
.58039 .69802 Mdot
.58431 .6941 Mdot
.59999 .6941 Mdot
.59999 .6941 Mdot
.59607 .69018 Mdot
.59215 .70194 Mdot
.59607 .72155 Mdot
.59215 .72155 Mdot
.59215 .72155 Mdot
.59999 .72547 Mdot
.60391 .71763 Mdot
.61176 .72547 Mdot
.61176 .73332 Mdot
.60783 .72939 Mdot
.60391 .71763 Mdot
.61176 .70979 Mdot
.61568 .70979 Mdot
.61568 .70979 Mdot
.6196 .71763 Mdot
.61568 .72547 Mdot
.62352 .73332 Mdot
.6196 .73332 Mdot
.61568 .72939 Mdot
.61568 .73332 Mdot
.6196 .73332 Mdot
.61176 .72547 Mdot
.63136 .73724 Mdot
.63528 .74116 Mdot
.63136 .74116 Mdot
.63528 .74508 Mdot
.64705 .75292 Mdot
.63136 .749 Mdot
.63136 .749 Mdot
.62744 .74116 Mdot
.63136 .74116 Mdot
.62744 .73724 Mdot
.63528 .749 Mdot
.64705 .75684 Mdot
.65489 .75292 Mdot
.65097 .74508 Mdot
.64705 .73724 Mdot
.65489 .73724 Mdot
.65489 .73332 Mdot
.64313 .72547 Mdot
.65097 .73332 Mdot
.65489 .74508 Mdot
.65881 .73724 Mdot
.65097 .72547 Mdot
.65489 .74116 Mdot
.65097 .76076 Mdot
.65489 .76469 Mdot
.65881 .76861 Mdot
.65881 .76861 Mdot
.65881 .76861 Mdot
.65489 .76861 Mdot
.65881 .76861 Mdot
.65881 .76861 Mdot
.65881 .76469 Mdot
.66273 .76076 Mdot
.66273 .75684 Mdot
.66273 .749 Mdot
.65489 .74116 Mdot
.65489 .749 Mdot
.66273 .75684 Mdot
.65489 .749 Mdot
.64705 .74116 Mdot
.64313 .74116 Mdot
.64705 .75292 Mdot
.64313 .75292 Mdot
.65881 .76076 Mdot
.66273 .75684 Mdot
.66273 .749 Mdot
.66273 .73724 Mdot
.67057 .73332 Mdot
.6745 .72547 Mdot
.6745 .72547 Mdot
.67057 .72547 Mdot
.67057 .72939 Mdot
.66665 .73724 Mdot
.65881 .74116 Mdot
.65881 .74508 Mdot
.66273 .74508 Mdot
.65489 .73724 Mdot
.64313 .72939 Mdot
.64705 .72939 Mdot
.64313 .72939 Mdot
.65881 .74508 Mdot
.65881 .73724 Mdot
.65881 .73724 Mdot
.64705 .72547 Mdot
.64705 .72939 Mdot
.6392 .72155 Mdot
.6392 .72155 Mdot
.63136 .71371 Mdot
.62744 .71371 Mdot
.63136 .71371 Mdot
.62744 .70979 Mdot
.6196 .69802 Mdot
.61568 .69802 Mdot
.6196 .6941 Mdot
.62352 .68234 Mdot
.6196 .68626 Mdot
.61176 .67842 Mdot
.61176 .69018 Mdot
.60391 .6941 Mdot
.59999 .68234 Mdot
.59607 .67842 Mdot
.59999 .68234 Mdot
.59215 .66665 Mdot
.60391 .6745 Mdot
.59607 .66273 Mdot
.58823 .65097 Mdot
.58823 .65097 Mdot
.58039 .65097 Mdot
.5647 .6392 Mdot
.57254 .65489 Mdot
.56862 .65881 Mdot
.57646 .65489 Mdot
.5647 .6392 Mdot
.55294 .63528 Mdot
.55686 .63136 Mdot
.56078 .6196 Mdot
.55686 .61176 Mdot
.53333 .60783 Mdot
.52941 .61176 Mdot
.54509 .61568 Mdot
.52941 .58823 Mdot
.53725 .57646 Mdot
.53333 .55294 Mdot
.52549 .52549 Mdot
.52549 .50588 Mdot
.52157 .48235 Mdot
.45883 .58039 Mdot
.52157 .65489 Mdot
.53333 .67057 Mdot
.52549 .66665 Mdot
.51372 .65489 Mdot
.52549 .66273 Mdot
.53333 .67842 Mdot
.52941 .68234 Mdot
.52941 .67057 Mdot
.52941 .66273 Mdot
.54117 .65881 Mdot
.54509 .66665 Mdot
.54117 .66273 Mdot
.54902 .66665 Mdot
.56078 .66665 Mdot
.56078 .66273 Mdot
.5647 .65489 Mdot
.56078 .65489 Mdot
.56078 .66273 Mdot
.56862 .6745 Mdot
.56862 .67842 Mdot
.56078 .68626 Mdot
.5647 .69018 Mdot
.5647 .69018 Mdot
.57646 .69802 Mdot
.57646 .69802 Mdot
.57646 .69802 Mdot
.57254 .69802 Mdot
.56862 .69018 Mdot
.58039 .6941 Mdot
.58431 .69018 Mdot
.59607 .69802 Mdot
.60783 .70587 Mdot
.59215 .70194 Mdot
.59999 .72547 Mdot
.59999 .73724 Mdot
.59215 .72939 Mdot
.58431 .71371 Mdot
.58431 .71371 Mdot
.59999 .73332 Mdot
.60783 .73332 Mdot
.60391 .73332 Mdot
.59999 .72155 Mdot
.61176 .70979 Mdot
.6196 .70979 Mdot
.61176 .70587 Mdot
.61568 .71371 Mdot
.6196 .71763 Mdot
.62352 .71371 Mdot
.61568 .70587 Mdot
.6196 .71371 Mdot
.61176 .71763 Mdot
.62744 .72547 Mdot
.61176 .72155 Mdot
.62352 .72547 Mdot
.6392 .73724 Mdot
.63528 .73724 Mdot
.6196 .73332 Mdot
.62744 .74116 Mdot
.64313 .74508 Mdot
.6392 .73724 Mdot
.63136 .73332 Mdot
.63528 .73332 Mdot
.63136 .74116 Mdot
.62352 .74508 Mdot
.63136 .75292 Mdot
.6392 .75684 Mdot
.6392 .75292 Mdot
.64705 .76076 Mdot
.6392 .75292 Mdot
.65097 .74508 Mdot
.64313 .72939 Mdot
.63136 .71763 Mdot
.65097 .73332 Mdot
.65881 .74116 Mdot
.64313 .72939 Mdot
.64705 .73332 Mdot
.65489 .749 Mdot
.64705 .76076 Mdot
.65097 .76861 Mdot
.65489 .76861 Mdot
.65881 .76469 Mdot
.65881 .76469 Mdot
.65881 .76469 Mdot
.64313 .76076 Mdot
.65097 .76076 Mdot
.65097 .76469 Mdot
.64705 .75684 Mdot
.65097 .75292 Mdot
.65097 .75292 Mdot
.65097 .76076 Mdot
.65881 .76076 Mdot
.64705 .749 Mdot
.65881 .74116 Mdot
.65489 .73724 Mdot
.64705 .73724 Mdot
.6392 .74116 Mdot
.64313 .749 Mdot
.6392 .74508 Mdot
.65489 .749 Mdot
.65489 .749 Mdot
.65489 .74508 Mdot
.65097 .72547 Mdot
.65489 .72155 Mdot
.64705 .71763 Mdot
.65097 .71763 Mdot
.65489 .72547 Mdot
.65881 .72547 Mdot
.65881 .73724 Mdot
.65097 .73724 Mdot
.65097 .73332 Mdot
.64705 .72939 Mdot
.63136 .71371 Mdot
.63136 .70979 Mdot
.63136 .71371 Mdot
.6392 .72155 Mdot
.6392 .72155 Mdot
.63136 .70979 Mdot
.63136 .70979 Mdot
.63136 .70587 Mdot
.62744 .70979 Mdot
.62744 .70979 Mdot
.62352 .70979 Mdot
.61568 .71371 Mdot
.61568 .71371 Mdot
.61176 .70979 Mdot
.61568 .69802 Mdot
.6196 .6941 Mdot
.61568 .68626 Mdot
.60783 .69018 Mdot
.59215 .68234 Mdot
.58431 .67057 Mdot
.58823 .67057 Mdot
.59215 .6745 Mdot
.57646 .66273 Mdot
.57646 .67057 Mdot
.57646 .65489 Mdot
.58823 .65489 Mdot
.58431 .64705 Mdot
.58039 .63528 Mdot
.57254 .63528 Mdot
.57646 .64705 Mdot
.56078 .64313 Mdot
.56078 .64705 Mdot
.5647 .66273 Mdot
.54902 .65097 Mdot
.53333 .63136 Mdot
.54509 .63136 Mdot
.54509 .62352 Mdot
.54117 .60783 Mdot
.52549 .59607 Mdot
.51765 .59215 Mdot
.52549 .59999 Mdot
.52157 .59607 Mdot
.5098 .57646 Mdot
.52549 .56862 Mdot
.51765 .55686 Mdot
.51765 .53333 Mdot
.50588 .50196 Mdot
.48628 .46667 Mdot
.42746 .54117 Mdot
.49412 .61568 Mdot
.50588 .64705 Mdot
.50196 .64313 Mdot
.51372 .65489 Mdot
.50588 .65881 Mdot
.50588 .65881 Mdot
.52157 .66273 Mdot
.52549 .66273 Mdot
.52941 .66273 Mdot
.52941 .65881 Mdot
.52941 .66273 Mdot
.54117 .66273 Mdot
.54902 .66273 Mdot
.54902 .65489 Mdot
.55294 .65097 Mdot
.55294 .65097 Mdot
.56862 .66665 Mdot
.55294 .65881 Mdot
.5647 .6745 Mdot
.55686 .68234 Mdot
.56078 .6941 Mdot
.56862 .70979 Mdot
.56078 .70587 Mdot
.56078 .70587 Mdot
.56862 .70194 Mdot
.57646 .70194 Mdot
.58039 .69802 Mdot
.58039 .6941 Mdot
.57646 .69802 Mdot
.58039 .70194 Mdot
.58039 .70587 Mdot
.59607 .71371 Mdot
.59607 .71763 Mdot
.59607 .72547 Mdot
.59999 .72939 Mdot
.58823 .71371 Mdot
.58823 .71763 Mdot
.59607 .72155 Mdot
.60783 .72547 Mdot
.59999 .71371 Mdot
.58823 .70194 Mdot
.59607 .70587 Mdot
.59999 .70587 Mdot
.61176 .70979 Mdot
.61568 .70979 Mdot
.61176 .70587 Mdot
.61568 .70587 Mdot
.61568 .70194 Mdot
.61568 .69802 Mdot
.62744 .70587 Mdot
.61568 .70587 Mdot
.6196 .71371 Mdot
.61568 .70979 Mdot
.6196 .71763 Mdot
.6196 .72155 Mdot
.6196 .72547 Mdot
.62744 .73332 Mdot
.63136 .74508 Mdot
.62744 .74508 Mdot
.62744 .72939 Mdot
.63136 .73332 Mdot
.63528 .73724 Mdot
.63528 .74116 Mdot
.63136 .749 Mdot
.63528 .75292 Mdot
.63136 .749 Mdot
.63136 .74508 Mdot
.6392 .75292 Mdot
.6392 .74508 Mdot
.63528 .73332 Mdot
.64705 .72939 Mdot
.64705 .72939 Mdot
.65097 .72939 Mdot
.64705 .72155 Mdot
.65097 .72547 Mdot
.64705 .72939 Mdot
.6392 .72939 Mdot
.62744 .72547 Mdot
.63528 .73724 Mdot
.64313 .749 Mdot
.65097 .75292 Mdot
.64313 .74508 Mdot
.64705 .75684 Mdot
.64313 .76076 Mdot
.64313 .76469 Mdot
.6392 .76076 Mdot
.64705 .76469 Mdot
.64313 .75292 Mdot
.64313 .75292 Mdot
.65097 .75292 Mdot
.65489 .74508 Mdot
.65881 .73724 Mdot
.65881 .72939 Mdot
.6392 .71763 Mdot
.63528 .72155 Mdot
.64705 .73724 Mdot
.64705 .74116 Mdot
.63528 .73724 Mdot
.64705 .74116 Mdot
.64705 .749 Mdot
.65097 .74508 Mdot
.63136 .72547 Mdot
.63528 .72547 Mdot
.64313 .72547 Mdot
.63136 .71763 Mdot
.64313 .72547 Mdot
.64313 .72155 Mdot
.63528 .71763 Mdot
.6392 .71763 Mdot
.63136 .71763 Mdot
.6392 .72155 Mdot
.63528 .71371 Mdot
.6196 .69802 Mdot
.63528 .70587 Mdot
.63136 .71371 Mdot
.62744 .71371 Mdot
.62744 .70979 Mdot
.63136 .71371 Mdot
.62352 .70587 Mdot
.62352 .6941 Mdot
.62352 .68626 Mdot
.61176 .68626 Mdot
.62352 .70194 Mdot
.61176 .70194 Mdot
.60783 .6941 Mdot
.60783 .69018 Mdot
.59215 .67842 Mdot
.60783 .69018 Mdot
.60783 .6941 Mdot
.58823 .67842 Mdot
.57646 .66273 Mdot
.58823 .66273 Mdot
.58039 .65489 Mdot
.58823 .66665 Mdot
.57646 .65881 Mdot
.56862 .64313 Mdot
.58039 .6392 Mdot
.57254 .6196 Mdot
.56862 .61568 Mdot
.57646 .62352 Mdot
.55294 .6196 Mdot
.56078 .62744 Mdot
.55294 .63136 Mdot
.54902 .64313 Mdot
.53725 .64313 Mdot
.53333 .6392 Mdot
.54117 .63136 Mdot
.55686 .62744 Mdot
.53333 .60783 Mdot
.52941 .60391 Mdot
.51372 .58823 Mdot
.50588 .57646 Mdot
.51765 .58823 Mdot
.5098 .58431 Mdot
.50588 .57254 Mdot
.50196 .56078 Mdot
.50196 .53725 Mdot
.50588 .50588 Mdot
.48628 .46275 Mdot
.4353 .54509 Mdot
.48628 .60783 Mdot
.51372 .64313 Mdot
.51765 .65881 Mdot
.5098 .65097 Mdot
.5098 .65097 Mdot
.5098 .65097 Mdot
.52941 .66665 Mdot
.53725 .67057 Mdot
.54509 .6745 Mdot
.54117 .66665 Mdot
.54509 .65881 Mdot
.54509 .65097 Mdot
.55294 .64705 Mdot
.55294 .64313 Mdot
.56078 .65097 Mdot
.55294 .65489 Mdot
.55686 .66665 Mdot
.54509 .66273 Mdot
.55294 .67842 Mdot
.55686 .68626 Mdot
.55686 .69018 Mdot
.56078 .69018 Mdot
.5647 .69802 Mdot
.5647 .69018 Mdot
.56862 .68234 Mdot
.57254 .67842 Mdot
.57646 .67842 Mdot
.58431 .68234 Mdot
.58039 .68234 Mdot
.58039 .69018 Mdot
.58039 .70194 Mdot
.58431 .70194 Mdot
.58431 .70194 Mdot
.58431 .69802 Mdot
.58431 .6941 Mdot
.59607 .71371 Mdot
.59607 .71763 Mdot
.59999 .71371 Mdot
.61568 .72155 Mdot
.60783 .70194 Mdot
.60391 .70194 Mdot
.59215 .69802 Mdot
.60391 .70979 Mdot
.60391 .70587 Mdot
.61568 .70979 Mdot
.61176 .70194 Mdot
.61176 .70194 Mdot
.59999 .69802 Mdot
.61568 .70587 Mdot
.62352 .70979 Mdot
.61568 .71371 Mdot
.61176 .72155 Mdot
.61568 .72547 Mdot
.61176 .72547 Mdot
.6196 .72939 Mdot
.61568 .72547 Mdot
.61176 .72547 Mdot
.62352 .73724 Mdot
.63528 .74508 Mdot
.6392 .74116 Mdot
.6392 .73332 Mdot
.63136 .72547 Mdot
.62744 .72939 Mdot
.6392 .74508 Mdot
.63136 .74116 Mdot
.63136 .73724 Mdot
.63528 .72939 Mdot
.6392 .72939 Mdot
.6392 .72547 Mdot
.63528 .71371 Mdot
.65097 .71763 Mdot
.65097 .71371 Mdot
.64313 .70587 Mdot
.63528 .69802 Mdot
.64313 .70979 Mdot
.64705 .72547 Mdot
.64313 .72547 Mdot
.6392 .71763 Mdot
.65097 .72547 Mdot
.64313 .72939 Mdot
.65097 .74508 Mdot
.65097 .74508 Mdot
.64705 .75292 Mdot
.64313 .76469 Mdot
.64313 .76076 Mdot
.65097 .76861 Mdot
.64313 .76076 Mdot
.6392 .75684 Mdot
.6392 .749 Mdot
.65097 .74116 Mdot
.64313 .72155 Mdot
.64313 .71371 Mdot
.64313 .71763 Mdot
.6392 .71371 Mdot
.6392 .71371 Mdot
.64313 .72939 Mdot
.64705 .74116 Mdot
.64313 .74116 Mdot
.64705 .73724 Mdot
.63136 .72155 Mdot
.6392 .72155 Mdot
.6392 .72155 Mdot
.62352 .71371 Mdot
.63136 .72547 Mdot
.63528 .72547 Mdot
.63528 .72155 Mdot
.64313 .72939 Mdot
.64313 .72547 Mdot
.6392 .72547 Mdot
.6196 .70979 Mdot
.6196 .70979 Mdot
.63528 .71763 Mdot
.62352 .70587 Mdot
.62744 .70194 Mdot
.63136 .70979 Mdot
.63528 .71763 Mdot
.6196 .71371 Mdot
.61176 .70587 Mdot
.6196 .70194 Mdot
.62744 .70194 Mdot
.62352 .6941 Mdot
.61568 .68626 Mdot
.61568 .69018 Mdot
.61176 .70194 Mdot
.60391 .6941 Mdot
.59999 .68626 Mdot
.58431 .66665 Mdot
.59999 .6745 Mdot
.59215 .67057 Mdot
.58431 .66273 Mdot
.57646 .65097 Mdot
.57254 .65489 Mdot
.5647 .64313 Mdot
.5647 .6392 Mdot
.57254 .6392 Mdot
.5647 .63528 Mdot
.57646 .64313 Mdot
.57646 .63136 Mdot
.57254 .6196 Mdot
.56862 .60783 Mdot
.56078 .60391 Mdot
.56862 .62352 Mdot
.55294 .62352 Mdot
.55294 .62744 Mdot
.54902 .63528 Mdot
.54509 .63136 Mdot
.53725 .62352 Mdot
.53725 .61568 Mdot
.52941 .59999 Mdot
.51765 .58431 Mdot
.51372 .57646 Mdot
.50196 .57254 Mdot
.50588 .58039 Mdot
.51372 .59215 Mdot
.50196 .56862 Mdot
.49804 .54902 Mdot
.50196 .52941 Mdot
.4902 .49804 Mdot
.48628 .46275 Mdot
.4353 .54117 Mdot
.4902 .60783 Mdot
.50196 .6392 Mdot
.50588 .65097 Mdot
.50588 .65097 Mdot
.50196 .64313 Mdot
.51372 .64313 Mdot
.53333 .65881 Mdot
.54117 .67057 Mdot
.53725 .67057 Mdot
.53725 .66665 Mdot
.54117 .65097 Mdot
.53725 .64705 Mdot
.54117 .64705 Mdot
.54509 .64313 Mdot
.55294 .64705 Mdot
.55686 .66273 Mdot
.55294 .67842 Mdot
.54902 .67842 Mdot
.55686 .67842 Mdot
.54902 .65881 Mdot
.5647 .67057 Mdot
.57254 .68234 Mdot
.56862 .68626 Mdot
.5647 .68626 Mdot
.5647 .67842 Mdot
.56862 .66665 Mdot
.57254 .66273 Mdot
.57254 .65881 Mdot
.56862 .67057 Mdot
.5647 .69018 Mdot
.57646 .70587 Mdot
.59607 .71371 Mdot
.59607 .70194 Mdot
.59607 .6941 Mdot
.58823 .69018 Mdot
.59607 .70587 Mdot
.59607 .71763 Mdot
.60783 .72939 Mdot
.59999 .72155 Mdot
.60391 .71371 Mdot
.59215 .69802 Mdot
.59607 .6941 Mdot
.59215 .69018 Mdot
.59607 .69802 Mdot
.59607 .6941 Mdot
.59215 .69018 Mdot
.59999 .6941 Mdot
.60783 .70194 Mdot
.59999 .70194 Mdot
.61176 .71763 Mdot
.60783 .72547 Mdot
.59999 .72155 Mdot
.61176 .72939 Mdot
.61568 .72939 Mdot
.6196 .72939 Mdot
.61176 .73332 Mdot
.61176 .73724 Mdot
.6196 .73724 Mdot
.6196 .72547 Mdot
.62744 .71763 Mdot
.62352 .70979 Mdot
.63136 .71371 Mdot
.6392 .72155 Mdot
.63136 .72547 Mdot
.6392 .73332 Mdot
.64313 .73724 Mdot
.62352 .71763 Mdot
.62352 .70979 Mdot
.63528 .70587 Mdot
.63528 .70194 Mdot
.6392 .70194 Mdot
.63528 .69802 Mdot
.64313 .70194 Mdot
.64313 .70194 Mdot
.6392 .70194 Mdot
.64705 .71371 Mdot
.65097 .72547 Mdot
.65489 .73332 Mdot
.65097 .72155 Mdot
.64705 .70979 Mdot
.64313 .70979 Mdot
.63528 .71371 Mdot
.6392 .72547 Mdot
.64313 .73724 Mdot
.64705 .74116 Mdot
.65097 .74508 Mdot
.63528 .73332 Mdot
.62352 .73332 Mdot
.63528 .74116 Mdot
.63528 .74116 Mdot
.62744 .72155 Mdot
.6392 .71763 Mdot
.64313 .71763 Mdot
.64313 .72155 Mdot
.64705 .72939 Mdot
.63136 .72939 Mdot
.62744 .73332 Mdot
.6392 .73332 Mdot
.64705 .72547 Mdot
.63136 .71371 Mdot
.6392 .70979 Mdot
.64313 .71763 Mdot
.6392 .72547 Mdot
.62352 .71371 Mdot
.62352 .70587 Mdot
.6196 .69802 Mdot
.62744 .70587 Mdot
.64313 .71371 Mdot
.63528 .70587 Mdot
.6196 .70194 Mdot
.61568 .70979 Mdot
.62352 .70587 Mdot
.63136 .6941 Mdot
.6196 .69018 Mdot
.61176 .6941 Mdot
.6196 .70979 Mdot
.6196 .70979 Mdot
.61568 .70194 Mdot
.61568 .70194 Mdot
.61176 .6941 Mdot
.61176 .6941 Mdot
.59999 .68626 Mdot
.59999 .6941 Mdot
.59215 .68234 Mdot
.58431 .66273 Mdot
.58823 .65489 Mdot
.59607 .65489 Mdot
.58823 .65097 Mdot
.58431 .65097 Mdot
.58431 .64705 Mdot
.57254 .64313 Mdot
.56862 .63136 Mdot
.58039 .6392 Mdot
.56862 .63136 Mdot
.57254 .63136 Mdot
.56862 .6392 Mdot
.5647 .63528 Mdot
.56862 .63528 Mdot
.5647 .61568 Mdot
.56078 .60391 Mdot
.55686 .59999 Mdot
.56078 .61176 Mdot
.54902 .61568 Mdot
.54509 .62744 Mdot
.53725 .62352 Mdot
.53333 .62352 Mdot
.53333 .63136 Mdot
.53725 .62352 Mdot
.52549 .59999 Mdot
.5098 .57646 Mdot
.51372 .58431 Mdot
.50588 .58823 Mdot
.49804 .58823 Mdot
.50588 .59607 Mdot
.49412 .56862 Mdot
.50196 .54902 Mdot
.48628 .5098 Mdot
.49412 .49412 Mdot
.48628 .46667 Mdot
.42746 .52157 Mdot
.48235 .59607 Mdot
.49412 .62352 Mdot
.50196 .64313 Mdot
.4902 .6392 Mdot
.50196 .64313 Mdot
.51372 .63528 Mdot
.5098 .6392 Mdot
.52157 .65489 Mdot
.53333 .66665 Mdot
.53333 .65881 Mdot
.54117 .65489 Mdot
.54117 .65489 Mdot
.54509 .65097 Mdot
.54117 .64705 Mdot
.54509 .64705 Mdot
.54509 .65097 Mdot
.54902 .65881 Mdot
.54902 .66665 Mdot
.54902 .66273 Mdot
.54902 .64705 Mdot
.55294 .6392 Mdot
.5647 .65097 Mdot
.5647 .65881 Mdot
.5647 .67057 Mdot
.57254 .67057 Mdot
.57254 .66665 Mdot
.57646 .66273 Mdot
.58039 .66273 Mdot
.58039 .66273 Mdot
.57646 .6745 Mdot
.57254 .68234 Mdot
.57254 .68234 Mdot
.58431 .68234 Mdot
.57646 .67057 Mdot
.58823 .67842 Mdot
.58823 .69018 Mdot
.59215 .70587 Mdot
.58823 .71371 Mdot
.59215 .71763 Mdot
.58823 .70587 Mdot
.58431 .6941 Mdot
.59607 .6941 Mdot
.59607 .6941 Mdot
.58431 .68234 Mdot
.59607 .68626 Mdot
.59999 .69802 Mdot
.60391 .69018 Mdot
.58823 .6745 Mdot
.59607 .69018 Mdot
.59607 .6941 Mdot
.59999 .70587 Mdot
.60391 .72939 Mdot
.59999 .73332 Mdot
.60391 .72547 Mdot
.60783 .71371 Mdot
.60783 .71371 Mdot
.60391 .71371 Mdot
.59999 .71763 Mdot
.61568 .72547 Mdot
.62744 .72155 Mdot
.62352 .70979 Mdot
.62352 .70194 Mdot
.6196 .70587 Mdot
.61568 .71763 Mdot
.60391 .72155 Mdot
.6196 .71763 Mdot
.62352 .70587 Mdot
.62352 .69018 Mdot
.62352 .68626 Mdot
.62352 .68626 Mdot
.6196 .6941 Mdot
.62352 .69802 Mdot
.63136 .69802 Mdot
.6196 .68626 Mdot
.63136 .69018 Mdot
.62352 .69018 Mdot
.62744 .70979 Mdot
.62744 .71763 Mdot
.62744 .71371 Mdot
.63136 .69802 Mdot
.6392 .6941 Mdot
.64313 .6941 Mdot
.64705 .70194 Mdot
.6392 .70979 Mdot
.6392 .71763 Mdot
.64705 .72547 Mdot
.6392 .71763 Mdot
.63136 .71371 Mdot
.62744 .70979 Mdot
.63136 .72155 Mdot
.6196 .70587 Mdot
.62352 .70587 Mdot
.62744 .70979 Mdot
.6196 .70979 Mdot
.63528 .72547 Mdot
.6392 .73332 Mdot
.62352 .71763 Mdot
.63136 .72547 Mdot
.62744 .71763 Mdot
.62352 .70194 Mdot
.62744 .70194 Mdot
.63136 .69802 Mdot
.63528 .71371 Mdot
.63528 .71371 Mdot
.62352 .70587 Mdot
.6196 .69802 Mdot
.61568 .6941 Mdot
.62352 .70587 Mdot
.6196 .69802 Mdot
.62352 .70979 Mdot
.62352 .71371 Mdot
.61568 .70194 Mdot
.61176 .68626 Mdot
.60783 .67842 Mdot
.61176 .68626 Mdot
.60391 .69018 Mdot
.60783 .70194 Mdot
.61176 .69802 Mdot
.6196 .6941 Mdot
.60783 .67842 Mdot
.58823 .66665 Mdot
.59607 .67842 Mdot
.59999 .68626 Mdot
.58431 .6745 Mdot
.57646 .65097 Mdot
.58823 .64313 Mdot
.59215 .6392 Mdot
.58823 .63136 Mdot
.58431 .63136 Mdot
.58431 .6392 Mdot
.57254 .63528 Mdot
.57646 .6392 Mdot
.57254 .63136 Mdot
.5647 .6196 Mdot
.56078 .61568 Mdot
.56078 .6196 Mdot
.57254 .6392 Mdot
.55686 .63136 Mdot
.54902 .6196 Mdot
.54509 .60783 Mdot
.54117 .59215 Mdot
.55294 .60391 Mdot
.53725 .60391 Mdot
.54509 .61568 Mdot
.54117 .6196 Mdot
.52941 .62352 Mdot
.51372 .6196 Mdot
.5098 .6196 Mdot
.51372 .60783 Mdot
.50588 .59607 Mdot
.49412 .59215 Mdot
.4902 .59999 Mdot
.49412 .59607 Mdot
.49804 .58823 Mdot
.49412 .5647 Mdot
.4902 .52941 Mdot
.49412 .51372 Mdot
.50196 .49412 Mdot
.4902 .46667 Mdot
.42746 .53725 Mdot
.48235 .59999 Mdot
.50196 .62352 Mdot
.50196 .63136 Mdot
.49412 .6392 Mdot
.50196 .64313 Mdot
.51372 .65097 Mdot
.50196 .64313 Mdot
.51765 .65881 Mdot
.52549 .66273 Mdot
.51372 .65489 Mdot
.52549 .65881 Mdot
.54117 .66273 Mdot
.54902 .66665 Mdot
.54902 .66665 Mdot
.54509 .66273 Mdot
.54902 .65881 Mdot
.56078 .66273 Mdot
.55686 .65881 Mdot
.54902 .65097 Mdot
.55686 .65489 Mdot
.55294 .65097 Mdot
.55686 .65489 Mdot
.55686 .66273 Mdot
.55294 .65881 Mdot
.55686 .65881 Mdot
.55686 .65881 Mdot
.5647 .66665 Mdot
.56862 .66273 Mdot
.57646 .67057 Mdot
.58039 .6745 Mdot
.58431 .68234 Mdot
.58431 .67842 Mdot
.58431 .6745 Mdot
.58431 .66665 Mdot
.59215 .67842 Mdot
.58823 .67842 Mdot
.58431 .6745 Mdot
.58431 .68234 Mdot
.58823 .68626 Mdot
.59607 .6941 Mdot
.58823 .69018 Mdot
.58431 .69018 Mdot
.59607 .70194 Mdot
.58823 .69018 Mdot
.60391 .69018 Mdot
.60391 .68626 Mdot
.59999 .69018 Mdot
.59999 .69018 Mdot
.59999 .69802 Mdot
.59999 .70587 Mdot
.60391 .71371 Mdot
.60391 .72939 Mdot
.60783 .73332 Mdot
.61176 .73724 Mdot
.60783 .72939 Mdot
.60391 .72547 Mdot
.60391 .72547 Mdot
.59999 .71763 Mdot
.61176 .71371 Mdot
.6196 .71371 Mdot
.61568 .70587 Mdot
.60783 .70194 Mdot
.6196 .71371 Mdot
.61568 .71371 Mdot
.60783 .71763 Mdot
.6196 .72547 Mdot
.62352 .71763 Mdot
.62352 .70587 Mdot
.62352 .70979 Mdot
.62744 .71371 Mdot
.62352 .70194 Mdot
.63136 .6941 Mdot
.63136 .69018 Mdot
.62744 .68626 Mdot
.6196 .68234 Mdot
.6196 .68234 Mdot
.6196 .69802 Mdot
.61568 .70587 Mdot
.63136 .70979 Mdot
.62744 .70194 Mdot
.64313 .70587 Mdot
.63136 .69802 Mdot
.63528 .70979 Mdot
.63528 .70979 Mdot
.6392 .72155 Mdot
.63528 .72547 Mdot
.63528 .72155 Mdot
.64313 .72939 Mdot
.6392 .72547 Mdot
.63136 .71763 Mdot
.63136 .72155 Mdot
.6392 .72155 Mdot
.62744 .71763 Mdot
.61568 .70979 Mdot
.61568 .70979 Mdot
.62352 .71371 Mdot
.62352 .71763 Mdot
.62352 .71763 Mdot
.62744 .72155 Mdot
.61568 .70979 Mdot
.62744 .71371 Mdot
.62744 .70979 Mdot
.63136 .71371 Mdot
.63136 .70979 Mdot
.62352 .70587 Mdot
.62744 .70587 Mdot
.6196 .70587 Mdot
.61176 .70979 Mdot
.60783 .71371 Mdot
.61176 .71371 Mdot
.6196 .70979 Mdot
.6196 .69018 Mdot
.61568 .68234 Mdot
.61176 .6745 Mdot
.61176 .6745 Mdot
.61176 .68234 Mdot
.60391 .68234 Mdot
.60391 .68234 Mdot
.60391 .68234 Mdot
.60391 .68626 Mdot
.60783 .68234 Mdot
.59215 .67057 Mdot
.58823 .66665 Mdot
.59215 .66665 Mdot
.58039 .64705 Mdot
.59215 .64705 Mdot
.58039 .63528 Mdot
.57646 .62744 Mdot
.58431 .6392 Mdot
.5647 .62744 Mdot
.56862 .62352 Mdot
.58039 .62352 Mdot
.58431 .62744 Mdot
.56078 .61176 Mdot
.55294 .6196 Mdot
.54509 .62352 Mdot
.55686 .63136 Mdot
.55686 .63136 Mdot
.54509 .62744 Mdot
.54117 .62744 Mdot
.53725 .6196 Mdot
.53333 .61176 Mdot
.52941 .61176 Mdot
.52549 .6196 Mdot
.52157 .6196 Mdot
.51765 .61568 Mdot
.51372 .61568 Mdot
.5098 .6196 Mdot
.5098 .61568 Mdot
.49412 .60391 Mdot
.49804 .60783 Mdot
.49412 .60391 Mdot
.49804 .59999 Mdot
.49804 .58039 Mdot
.47843 .54902 Mdot
.48235 .54117 Mdot
.48235 .51372 Mdot
.47451 .4902 Mdot
.47451 .47059 Mdot
.4353 .53333 Mdot
.4902 .60783 Mdot
.50196 .62352 Mdot
.5098 .63528 Mdot
.50588 .63136 Mdot
.49804 .63528 Mdot
.50588 .64313 Mdot
.50196 .64705 Mdot
.51765 .65489 Mdot
.51372 .64705 Mdot
.52157 .65489 Mdot
.54509 .67057 Mdot
.54117 .67057 Mdot
.54902 .6745 Mdot
.54117 .66665 Mdot
.54509 .67057 Mdot
.54902 .67057 Mdot
.56862 .68234 Mdot
.55294 .66665 Mdot
.54902 .67057 Mdot
.55294 .66665 Mdot
.56078 .66665 Mdot
.55686 .66273 Mdot
.55686 .66273 Mdot
.55686 .66665 Mdot
.56078 .66665 Mdot
.56078 .66273 Mdot
.5647 .66273 Mdot
.57646 .67057 Mdot
.56862 .66273 Mdot
.57254 .67057 Mdot
.57254 .6745 Mdot
.57646 .6745 Mdot
.58431 .67842 Mdot
.59607 .68626 Mdot
.58431 .66665 Mdot
.59607 .67057 Mdot
.58431 .66273 Mdot
.58039 .6745 Mdot
.57646 .67842 Mdot
.57646 .67842 Mdot
.59215 .69802 Mdot
.58431 .69802 Mdot
.58823 .69802 Mdot
.58039 .68234 Mdot
.58823 .68626 Mdot
.58431 .69018 Mdot
.58431 .68626 Mdot
.58431 .68626 Mdot
.59215 .70194 Mdot
.59607 .70979 Mdot
.58823 .70979 Mdot
.59215 .71371 Mdot
.59607 .71763 Mdot
.60783 .73332 Mdot
.60783 .73332 Mdot
.60783 .73332 Mdot
.60391 .72939 Mdot
.61176 .72939 Mdot
.61176 .72155 Mdot
.6196 .71763 Mdot
.62352 .71371 Mdot
.6196 .70587 Mdot
.61568 .69802 Mdot
.61568 .70194 Mdot
.61176 .70587 Mdot
.61176 .71371 Mdot
.61176 .71763 Mdot
.6196 .72547 Mdot
.61568 .72155 Mdot
.60783 .70979 Mdot
.62352 .70979 Mdot
.62352 .70194 Mdot
.6196 .69018 Mdot
.61176 .67842 Mdot
.61176 .67842 Mdot
.62352 .68626 Mdot
.61176 .69018 Mdot
.62352 .71371 Mdot
.63528 .72155 Mdot
.63528 .72155 Mdot
.62744 .71763 Mdot
.62352 .70979 Mdot
.63136 .71371 Mdot
.62744 .70979 Mdot
.62352 .71763 Mdot
.62352 .72155 Mdot
.63528 .74116 Mdot
.64313 .74116 Mdot
.64313 .73724 Mdot
.64705 .72939 Mdot
.63136 .70587 Mdot
.63136 .70194 Mdot
.62352 .69802 Mdot
.62352 .70587 Mdot
.62744 .71371 Mdot
.62352 .71371 Mdot
.62744 .71763 Mdot
.62744 .71763 Mdot
.62744 .72939 Mdot
.62352 .72547 Mdot
.6196 .71763 Mdot
.62352 .72155 Mdot
.61568 .71763 Mdot
.61568 .72155 Mdot
.60783 .71371 Mdot
.61568 .70587 Mdot
.6196 .70979 Mdot
.61568 .70979 Mdot
.61176 .71371 Mdot
.61568 .71371 Mdot
.60783 .69018 Mdot
.61176 .67842 Mdot
.61568 .68626 Mdot
.61176 .68626 Mdot
.60391 .6745 Mdot
.60783 .6745 Mdot
.60391 .67842 Mdot
.59215 .67057 Mdot
.59999 .67842 Mdot
.58431 .67057 Mdot
.58823 .66665 Mdot
.59215 .66665 Mdot
.59607 .67057 Mdot
.59215 .67057 Mdot
.58823 .65489 Mdot
.57646 .64313 Mdot
.57646 .64313 Mdot
.56862 .63528 Mdot
.5647 .63528 Mdot
.57254 .64313 Mdot
.56078 .62352 Mdot
.57254 .61568 Mdot
.56078 .60391 Mdot
.5647 .6196 Mdot
.55686 .62352 Mdot
.54902 .6196 Mdot
.54117 .6196 Mdot
.55686 .63136 Mdot
.54509 .62352 Mdot
.54117 .62352 Mdot
.53333 .6196 Mdot
.52549 .62352 Mdot
.52157 .62352 Mdot
.51765 .62744 Mdot
.51765 .63136 Mdot
.50588 .62352 Mdot
.50588 .6196 Mdot
.50588 .61568 Mdot
.49804 .60783 Mdot
.49412 .59607 Mdot
.48628 .58431 Mdot
.4902 .58823 Mdot
.49804 .58823 Mdot
.49412 .5647 Mdot
.48235 .54902 Mdot
.47451 .54117 Mdot
.47059 .52941 Mdot
.47059 .5098 Mdot
.46275 .48235 Mdot
.42746 .52941 Mdot
.47059 .58823 Mdot
.4902 .61568 Mdot
.49804 .63136 Mdot
.50196 .64313 Mdot
.49804 .6392 Mdot
.49804 .6392 Mdot
.50196 .6392 Mdot
.5098 .64705 Mdot
.5098 .6392 Mdot
.52549 .64705 Mdot
.53333 .66273 Mdot
.54509 .66665 Mdot
.54509 .65489 Mdot
.54509 .65489 Mdot
.55294 .66273 Mdot
.54902 .65881 Mdot
.56078 .6745 Mdot
.56078 .67842 Mdot
.55294 .68234 Mdot
.54509 .6745 Mdot
.54117 .66273 Mdot
.5647 .67842 Mdot
.56078 .6745 Mdot
.56862 .68234 Mdot
.5647 .68234 Mdot
.5647 .6745 Mdot
.5647 .6745 Mdot
.57254 .68234 Mdot
.56078 .6745 Mdot
.56862 .68234 Mdot
.58431 .6941 Mdot
.57254 .68234 Mdot
.57646 .68626 Mdot
.57646 .67842 Mdot
.58823 .67842 Mdot
.59215 .68234 Mdot
.58039 .67842 Mdot
.58431 .68234 Mdot
.57254 .6745 Mdot
.58039 .67842 Mdot
.57646 .68626 Mdot
.58431 .6941 Mdot
.57646 .68234 Mdot
.58823 .69018 Mdot
.58431 .69802 Mdot
.58823 .69802 Mdot
.58823 .69802 Mdot
.59215 .69802 Mdot
.59607 .6941 Mdot
.60391 .69802 Mdot
.59999 .70587 Mdot
.59999 .70587 Mdot
.60391 .70979 Mdot
.59999 .71763 Mdot
.59607 .72155 Mdot
.59607 .72547 Mdot
.60391 .72547 Mdot
.60391 .71763 Mdot
.61568 .72155 Mdot
.62352 .72155 Mdot
.61176 .71371 Mdot
.60783 .70979 Mdot
.59999 .70194 Mdot
.61568 .70587 Mdot
.61176 .70587 Mdot
.6196 .71371 Mdot
.6196 .72155 Mdot
.61568 .72547 Mdot
.61568 .70979 Mdot
.62744 .70587 Mdot
.61568 .6941 Mdot
.61176 .69802 Mdot
.61568 .70194 Mdot
.6196 .69802 Mdot
.61568 .6941 Mdot
.6196 .6941 Mdot
.61176 .6941 Mdot
.61568 .70194 Mdot
.62352 .71371 Mdot
.62744 .72547 Mdot
.62744 .72547 Mdot
.62744 .72547 Mdot
.62352 .72155 Mdot
.62352 .71763 Mdot
.62352 .71763 Mdot
.62352 .72155 Mdot
.61568 .72155 Mdot
.6196 .72155 Mdot
.62744 .71371 Mdot
.62352 .70587 Mdot
.62352 .69802 Mdot
.6196 .6941 Mdot
.63136 .70587 Mdot
.63136 .72155 Mdot
.62352 .72155 Mdot
.62352 .72155 Mdot
.61568 .71763 Mdot
.62352 .72155 Mdot
.62352 .72547 Mdot
.61176 .71371 Mdot
.6196 .71763 Mdot
.61176 .72547 Mdot
.61568 .72155 Mdot
.6196 .71763 Mdot
.61176 .70979 Mdot
.60783 .70194 Mdot
.61176 .69802 Mdot
.61568 .70194 Mdot
.60391 .69802 Mdot
.60391 .69802 Mdot
.60391 .68626 Mdot
.61176 .68234 Mdot
.60391 .69018 Mdot
.60783 .69802 Mdot
.59999 .69018 Mdot
.59999 .69018 Mdot
.59999 .68626 Mdot
.60391 .67842 Mdot
.59607 .6745 Mdot
.58431 .66665 Mdot
.58039 .6745 Mdot
.58823 .68234 Mdot
.57254 .65881 Mdot
.58431 .66665 Mdot
.58431 .66273 Mdot
.57254 .65881 Mdot
.56078 .64705 Mdot
.56862 .65097 Mdot
.56078 .64313 Mdot
.55686 .6392 Mdot
.55686 .6392 Mdot
.55686 .63528 Mdot
.54509 .62352 Mdot
.55686 .6392 Mdot
.54902 .63136 Mdot
.54509 .63136 Mdot
.54117 .6392 Mdot
.53725 .63528 Mdot
.52941 .63528 Mdot
.52941 .63136 Mdot
.52157 .62352 Mdot
.51372 .62352 Mdot
.50196 .61176 Mdot
.50588 .6196 Mdot
.49804 .61568 Mdot
.5098 .6196 Mdot
.49804 .60391 Mdot
.49412 .59215 Mdot
.48628 .58431 Mdot
.48235 .57254 Mdot
.47451 .55686 Mdot
.47843 .55686 Mdot
.47451 .5647 Mdot
.48235 .5647 Mdot
.47451 .56078 Mdot
.46275 .54902 Mdot
.46275 .53333 Mdot
.46275 .5098 Mdot
.45098 .47843 Mdot
.44706 .54509 Mdot
.47843 .59607 Mdot
.49412 .62352 Mdot
.49412 .6392 Mdot
.49804 .64705 Mdot
.4902 .64313 Mdot
.4902 .6392 Mdot
.50196 .64313 Mdot
.51372 .65097 Mdot
.51765 .64313 Mdot
.51765 .63528 Mdot
.52157 .65097 Mdot
.52941 .65881 Mdot
.53725 .65881 Mdot
.54509 .65097 Mdot
.54902 .65097 Mdot
.56078 .66273 Mdot
.55294 .65881 Mdot
.55294 .6745 Mdot
.55294 .68626 Mdot
.56078 .68626 Mdot
.55686 .66273 Mdot
.5647 .65881 Mdot
.55686 .65489 Mdot
.5647 .65881 Mdot
.56078 .66665 Mdot
.55686 .6745 Mdot
.55686 .6745 Mdot
.5647 .68234 Mdot
.5647 .67057 Mdot
.56078 .66273 Mdot
.56862 .67842 Mdot
.57254 .68234 Mdot
.5647 .6745 Mdot
.56078 .66665 Mdot
.58039 .6745 Mdot
.58823 .67842 Mdot
.58823 .67842 Mdot
.58823 .68626 Mdot
.59215 .69018 Mdot
.58823 .69018 Mdot
.59999 .70979 Mdot
.58039 .69018 Mdot
.59215 .6941 Mdot
.58823 .68234 Mdot
.59607 .6941 Mdot
.58039 .6941 Mdot
.59607 .70587 Mdot
.59999 .69802 Mdot
.61176 .69802 Mdot
.61176 .6941 Mdot
.60783 .69018 Mdot
.59215 .69018 Mdot
.59999 .70587 Mdot
.59607 .70979 Mdot
.59999 .71371 Mdot
.59999 .71371 Mdot
.60391 .70979 Mdot
.61176 .70979 Mdot
.60391 .70194 Mdot
.60783 .70587 Mdot
.60783 .70587 Mdot
.59215 .70194 Mdot
.59999 .70979 Mdot
.60391 .70587 Mdot
.60783 .70979 Mdot
.61176 .71371 Mdot
.60783 .71763 Mdot
.60783 .72155 Mdot
.61176 .70979 Mdot
.6196 .70979 Mdot
.61568 .70194 Mdot
.6196 .70587 Mdot
.61176 .69802 Mdot
.61568 .70194 Mdot
.60391 .69018 Mdot
.61176 .69018 Mdot
.61568 .68626 Mdot
.6196 .69018 Mdot
.6196 .69802 Mdot
.62352 .70979 Mdot
.6196 .70979 Mdot
.6196 .71371 Mdot
.62352 .71371 Mdot
.61176 .70194 Mdot
.61176 .69802 Mdot
.61568 .70979 Mdot
.6196 .71763 Mdot
.61568 .70979 Mdot
.61568 .70194 Mdot
.61176 .69018 Mdot
.6196 .6941 Mdot
.62352 .70587 Mdot
.62352 .70979 Mdot
.61568 .71371 Mdot
.62352 .72155 Mdot
.61176 .71371 Mdot
.61568 .70979 Mdot
.62744 .71371 Mdot
.62744 .70587 Mdot
.61176 .6941 Mdot
.61568 .69802 Mdot
.61176 .70194 Mdot
.60391 .69802 Mdot
.61176 .69802 Mdot
.61568 .69802 Mdot
.61176 .6941 Mdot
.61568 .70194 Mdot
.61176 .70194 Mdot
.60783 .70194 Mdot
.60391 .70194 Mdot
.59607 .69018 Mdot
.58823 .67842 Mdot
.58823 .68234 Mdot
.59607 .6941 Mdot
.58431 .6941 Mdot
.58431 .68626 Mdot
.58431 .67842 Mdot
.58039 .65881 Mdot
.58823 .66273 Mdot
.58039 .65881 Mdot
.58431 .6745 Mdot
.58039 .68234 Mdot
.57646 .6745 Mdot
.57254 .66665 Mdot
.56078 .64313 Mdot
.57646 .65097 Mdot
.5647 .65097 Mdot
.55686 .65097 Mdot
.55686 .65881 Mdot
.56862 .66665 Mdot
.55294 .65881 Mdot
.55686 .65489 Mdot
.54509 .6392 Mdot
.54117 .63136 Mdot
.54509 .63136 Mdot
.53333 .63528 Mdot
.53333 .64313 Mdot
.52941 .64313 Mdot
.53333 .65097 Mdot
.51765 .63136 Mdot
.50588 .61176 Mdot
.51765 .60783 Mdot
.5098 .60391 Mdot
.50588 .60783 Mdot
.49804 .61176 Mdot
.50196 .60783 Mdot
.50588 .60783 Mdot
.48628 .59215 Mdot
.4902 .58431 Mdot
.4902 .58431 Mdot
.48235 .57646 Mdot
.48235 .5647 Mdot
.47059 .5647 Mdot
.46275 .55686 Mdot
.45491 .55294 Mdot
.45491 .54509 Mdot
.45491 .52941 Mdot
.45491 .50588 Mdot
.44314 .47451 Mdot
.4353 .53725 Mdot
.46667 .58039 Mdot
.49412 .61568 Mdot
.50196 .64705 Mdot
.4902 .64705 Mdot
.49412 .64705 Mdot
.48628 .6392 Mdot
.4902 .6392 Mdot
.50588 .64313 Mdot
.51372 .64313 Mdot
.5098 .6392 Mdot
.52549 .65881 Mdot
.52549 .65097 Mdot
.53333 .65489 Mdot
.54509 .65881 Mdot
.55294 .65881 Mdot
.54117 .65097 Mdot
.55294 .65881 Mdot
.55686 .65489 Mdot
.55686 .65881 Mdot
.5647 .66273 Mdot
.56078 .65489 Mdot
.55686 .6392 Mdot
.56078 .63528 Mdot
.57646 .64313 Mdot
.5647 .64313 Mdot
.57254 .65881 Mdot
.56862 .65489 Mdot
.56078 .65881 Mdot
.57646 .67057 Mdot
.56862 .66273 Mdot
.56862 .65881 Mdot
.57254 .67057 Mdot
.56862 .67057 Mdot
.5647 .67842 Mdot
.57254 .68626 Mdot
.57254 .68626 Mdot
.58039 .68626 Mdot
.59215 .69802 Mdot
.58823 .70587 Mdot
.59215 .70979 Mdot
.58431 .69802 Mdot
.58039 .69802 Mdot
.58823 .70587 Mdot
.58823 .70194 Mdot
.58823 .68626 Mdot
.58823 .6941 Mdot
.59607 .69802 Mdot
.59607 .69018 Mdot
.60391 .69018 Mdot
.60783 .69018 Mdot
.59607 .67842 Mdot
.59999 .67842 Mdot
.59607 .69018 Mdot
.59607 .69802 Mdot
.59999 .70587 Mdot
.60391 .69802 Mdot
.59607 .69018 Mdot
.60391 .69802 Mdot
.59999 .69802 Mdot
.59999 .70194 Mdot
.58823 .69018 Mdot
.58823 .6941 Mdot
.58823 .70587 Mdot
.58431 .70194 Mdot
.59607 .70587 Mdot
.60391 .71763 Mdot
.60391 .72155 Mdot
.60391 .70979 Mdot
.60391 .70194 Mdot
.61176 .70194 Mdot
.61176 .69802 Mdot
.61176 .70587 Mdot
.6196 .71371 Mdot
.60783 .70587 Mdot
.60391 .6941 Mdot
.6196 .68626 Mdot
.62352 .68234 Mdot
.62352 .68234 Mdot
.6196 .6941 Mdot
.6196 .70587 Mdot
.61176 .70587 Mdot
.62352 .71371 Mdot
.61568 .70979 Mdot
.61568 .70194 Mdot
.60783 .68626 Mdot
.61176 .70194 Mdot
.6196 .71763 Mdot
.61176 .70587 Mdot
.61568 .70194 Mdot
.61568 .6941 Mdot
.61176 .68234 Mdot
.61568 .6941 Mdot
.61568 .69802 Mdot
.60783 .69802 Mdot
.61176 .71763 Mdot
.60783 .70979 Mdot
.60391 .70194 Mdot
.61176 .69018 Mdot
.60391 .6745 Mdot
.61176 .67842 Mdot
.61176 .6745 Mdot
.60783 .68234 Mdot
.59999 .69018 Mdot
.59999 .6941 Mdot
.59607 .6941 Mdot
.59607 .6941 Mdot
.60391 .70194 Mdot
.59607 .70587 Mdot
.59215 .70194 Mdot
.58823 .6941 Mdot
.59215 .69018 Mdot
.59607 .69018 Mdot
.58431 .6745 Mdot
.58431 .67842 Mdot
.58431 .67842 Mdot
.58431 .68234 Mdot
.58039 .67057 Mdot
.58431 .67057 Mdot
.58431 .66665 Mdot
.57254 .65097 Mdot
.57646 .66273 Mdot
.57254 .66665 Mdot
.56862 .66273 Mdot
.58039 .66665 Mdot
.56862 .65097 Mdot
.57254 .63528 Mdot
.56078 .62352 Mdot
.55294 .63136 Mdot
.55686 .64705 Mdot
.54902 .64705 Mdot
.54902 .65489 Mdot
.54509 .64705 Mdot
.53725 .6196 Mdot
.54509 .61568 Mdot
.52941 .60391 Mdot
.53725 .61568 Mdot
.52941 .62352 Mdot
.52157 .62352 Mdot
.53333 .6392 Mdot
.52157 .62744 Mdot
.51765 .61176 Mdot
.51372 .59999 Mdot
.50196 .58823 Mdot
.49804 .59607 Mdot
.49412 .59999 Mdot
.48628 .60391 Mdot
.4902 .61176 Mdot
.48235 .59999 Mdot
.47451 .58823 Mdot
.46275 .57254 Mdot
.46667 .56862 Mdot
.45491 .56078 Mdot
.44706 .56078 Mdot
.44706 .5647 Mdot
.44314 .55294 Mdot
.4353 .53333 Mdot
.44706 .53333 Mdot
.44314 .50588 Mdot
.4353 .45883 Mdot
.4353 .52157 Mdot
.45098 .57254 Mdot
.48235 .60783 Mdot
.4902 .62352 Mdot
.49804 .63136 Mdot
.49412 .63528 Mdot
.47843 .6392 Mdot
.47843 .63528 Mdot
.49804 .64705 Mdot
.50196 .6392 Mdot
.51372 .64313 Mdot
.52941 .64313 Mdot
.53333 .6392 Mdot
.53725 .6392 Mdot
.54117 .6392 Mdot
.54902 .64313 Mdot
.55294 .65489 Mdot
.55686 .65881 Mdot
.55686 .65097 Mdot
.55294 .64313 Mdot
.55686 .64313 Mdot
.53725 .63136 Mdot
.54902 .63528 Mdot
.54902 .63528 Mdot
.5647 .64313 Mdot
.56078 .63136 Mdot
.5647 .63528 Mdot
.55294 .63136 Mdot
.56078 .65489 Mdot
.56078 .67057 Mdot
.56862 .68234 Mdot
.57254 .68234 Mdot
.57646 .67842 Mdot
.56862 .67057 Mdot
.56862 .67842 Mdot
.56078 .68234 Mdot
.57254 .70587 Mdot
.56078 .69802 Mdot
.56862 .69802 Mdot
.58431 .70194 Mdot
.57646 .67842 Mdot
.5647 .67057 Mdot
.58039 .68626 Mdot
.58431 .6941 Mdot
.58039 .69802 Mdot
.56862 .68234 Mdot
.57646 .68234 Mdot
.58039 .67842 Mdot
.58431 .6745 Mdot
.59999 .67057 Mdot
.60391 .6745 Mdot
.58823 .67057 Mdot
.59215 .6745 Mdot
.59215 .67057 Mdot
.59607 .6745 Mdot
.59999 .6745 Mdot
.59215 .66665 Mdot
.60391 .6745 Mdot
.60391 .6745 Mdot
.59607 .67842 Mdot
.58823 .68234 Mdot
.59607 .68626 Mdot
.60783 .6941 Mdot
.59999 .68626 Mdot
.59999 .68626 Mdot
.59999 .69018 Mdot
.58431 .68626 Mdot
.59215 .6941 Mdot
.59999 .69018 Mdot
.59215 .68234 Mdot
.59607 .67057 Mdot
.59215 .66665 Mdot
.58823 .66273 Mdot
.59607 .6745 Mdot
.59999 .68234 Mdot
.60391 .67842 Mdot
.60783 .6745 Mdot
.60391 .65881 Mdot
.61176 .66665 Mdot
.60783 .6745 Mdot
.60391 .68626 Mdot
.59999 .69018 Mdot
.60391 .6941 Mdot
.60783 .6941 Mdot
.59999 .68626 Mdot
.60391 .69018 Mdot
.59999 .69018 Mdot
.60391 .6941 Mdot
.60391 .69018 Mdot
.60391 .68234 Mdot
.61176 .6745 Mdot
.60783 .65881 Mdot
.59999 .65881 Mdot
.60783 .68626 Mdot
.60783 .69802 Mdot
.60391 .70194 Mdot
.59999 .69018 Mdot
.59607 .67842 Mdot
.60391 .67842 Mdot
.59999 .67057 Mdot
.60391 .66665 Mdot
.60391 .66665 Mdot
.59999 .66665 Mdot
.58431 .67057 Mdot
.58823 .68234 Mdot
.58431 .69018 Mdot
.59215 .70194 Mdot
.59215 .70194 Mdot
.59215 .69802 Mdot
.59215 .69802 Mdot
.58431 .69018 Mdot
.59215 .69018 Mdot
.58431 .68234 Mdot
.58823 .68234 Mdot
.58431 .67842 Mdot
.58039 .66665 Mdot
.57646 .66273 Mdot
.58431 .6745 Mdot
.57646 .66665 Mdot
.56078 .64705 Mdot
.56862 .65097 Mdot
.56078 .64705 Mdot
.56862 .65881 Mdot
.5647 .64705 Mdot
.56862 .6392 Mdot
.57646 .64313 Mdot
.56862 .63136 Mdot
.56078 .62352 Mdot
.55294 .62744 Mdot
.56078 .63528 Mdot
.54509 .63136 Mdot
.53333 .64313 Mdot
.54117 .65097 Mdot
.52941 .63136 Mdot
.53725 .62352 Mdot
.52157 .60391 Mdot
.51765 .59607 Mdot
.51372 .59607 Mdot
.51765 .60391 Mdot
.51765 .60783 Mdot
.5098 .59999 Mdot
.50196 .59999 Mdot
.49804 .59999 Mdot
.48628 .58823 Mdot
.48628 .59215 Mdot
.49412 .59607 Mdot
.47843 .59607 Mdot
.47451 .59607 Mdot
.47059 .59215 Mdot
.47059 .58823 Mdot
.45883 .57646 Mdot
.45098 .57254 Mdot
.45491 .58039 Mdot
.43922 .56078 Mdot
.42746 .54509 Mdot
.4353 .54509 Mdot
.43922 .54117 Mdot
.42746 .52157 Mdot
.4353 .50196 Mdot
.42746 .46275 Mdot
.42746 .5098 Mdot
.45491 .5647 Mdot
.47843 .59607 Mdot
.48628 .60391 Mdot
.4902 .61568 Mdot
.47843 .61568 Mdot
.47843 .63136 Mdot
.48235 .64313 Mdot
.49804 .65097 Mdot
.51372 .64705 Mdot
.53333 .6392 Mdot
.52941 .63136 Mdot
.51372 .62744 Mdot
.52549 .63136 Mdot
.52549 .62744 Mdot
.52941 .62744 Mdot
.54902 .64705 Mdot
.55686 .65097 Mdot
.56078 .64313 Mdot
.55686 .63528 Mdot
.54902 .6392 Mdot
.54902 .65097 Mdot
.55294 .65489 Mdot
.54509 .65097 Mdot
.5647 .65881 Mdot
.57254 .65097 Mdot
.56862 .64705 Mdot
.5647 .64705 Mdot
.55686 .65881 Mdot
.5647 .68234 Mdot
.57254 .6941 Mdot
.5647 .68234 Mdot
.57254 .67842 Mdot
.56862 .67057 Mdot
.56078 .67842 Mdot
.57254 .69018 Mdot
.58039 .70587 Mdot
.57254 .70587 Mdot
.56078 .68626 Mdot
.56862 .68626 Mdot
.57646 .6745 Mdot
.58039 .67057 Mdot
.56862 .66665 Mdot
.56862 .66273 Mdot
.56078 .67057 Mdot
.55294 .66273 Mdot
.54509 .65489 Mdot
.55294 .65097 Mdot
.54902 .63528 Mdot
.54117 .62352 Mdot
.54902 .6392 Mdot
.55294 .65097 Mdot
.5647 .65097 Mdot
.56862 .64705 Mdot
.56862 .64313 Mdot
.58431 .64313 Mdot
.58823 .64313 Mdot
.58823 .64313 Mdot
.58823 .65097 Mdot
.59607 .65881 Mdot
.60783 .6745 Mdot
.59215 .66273 Mdot
.60391 .67057 Mdot
.60391 .67057 Mdot
.60783 .67057 Mdot
.60783 .67057 Mdot
.59999 .67842 Mdot
.60783 .69018 Mdot
.59215 .6745 Mdot
.59215 .66273 Mdot
.60391 .66665 Mdot
.59215 .65489 Mdot
.59607 .65881 Mdot
.59999 .66665 Mdot
.61568 .67842 Mdot
.59999 .66665 Mdot
.59607 .65881 Mdot
.60783 .66273 Mdot
.60783 .66665 Mdot
.60391 .67057 Mdot
.60391 .68234 Mdot
.59215 .67842 Mdot
.60391 .69018 Mdot
.59215 .68234 Mdot
.59999 .68626 Mdot
.59607 .68626 Mdot
.60391 .69018 Mdot
.60783 .69802 Mdot
.61176 .69802 Mdot
.59999 .68234 Mdot
.60391 .6745 Mdot
.60391 .66273 Mdot
.59999 .65881 Mdot
.59999 .66665 Mdot
.59215 .67057 Mdot
.59607 .68234 Mdot
.59607 .67842 Mdot
.60391 .68234 Mdot
.59607 .67057 Mdot
.59999 .66665 Mdot
.59999 .67057 Mdot
.59607 .66665 Mdot
.59607 .67057 Mdot
.58039 .66665 Mdot
.58039 .6745 Mdot
.58823 .68234 Mdot
.57646 .6745 Mdot
.58039 .68234 Mdot
.59215 .69018 Mdot
.59215 .69018 Mdot
.57646 .67842 Mdot
.58431 .68234 Mdot
.57646 .67842 Mdot
.57254 .66273 Mdot
.58039 .66273 Mdot
.57646 .65097 Mdot
.57646 .64705 Mdot
.56862 .64705 Mdot
.56862 .64313 Mdot
.5647 .63528 Mdot
.57254 .63528 Mdot
.57646 .64313 Mdot
.55686 .63136 Mdot
.55294 .63528 Mdot
.55686 .6392 Mdot
.56078 .6392 Mdot
.55294 .63136 Mdot
.54509 .61568 Mdot
.54902 .61568 Mdot
.55686 .62352 Mdot
.53333 .6196 Mdot
.52941 .63136 Mdot
.52549 .6392 Mdot
.52157 .63528 Mdot
.51765 .62352 Mdot
.52157 .60391 Mdot
.52157 .59215 Mdot
.51765 .58823 Mdot
.51372 .59215 Mdot
.52157 .59999 Mdot
.50588 .59215 Mdot
.49804 .59999 Mdot
.50196 .60391 Mdot
.49412 .59999 Mdot
.4902 .58823 Mdot
.48235 .58039 Mdot
.47059 .57646 Mdot
.47059 .58431 Mdot
.47059 .59215 Mdot
.45491 .59215 Mdot
.44706 .58039 Mdot
.45883 .57646 Mdot
.45883 .56862 Mdot
.45491 .56078 Mdot
.44314 .54117 Mdot
.43922 .54117 Mdot
.43138 .53333 Mdot
.41961 .51372 Mdot
.41177 .48628 Mdot
.41961 .46275 Mdot
.43138 .5098 Mdot
.48235 .57646 Mdot
.50588 .60783 Mdot
.50196 .61568 Mdot
.50196 .6196 Mdot
.4902 .61176 Mdot
.48235 .6196 Mdot
.49804 .6392 Mdot
.50588 .64705 Mdot
.5098 .64313 Mdot
.52549 .63136 Mdot
.53333 .6196 Mdot
.52157 .61176 Mdot
.53333 .62744 Mdot
.53725 .63528 Mdot
.53725 .6392 Mdot
.54509 .64313 Mdot
.56078 .64313 Mdot
.5647 .63528 Mdot
.56078 .63136 Mdot
.55686 .62744 Mdot
.55686 .6392 Mdot
.54902 .65097 Mdot
.53333 .64705 Mdot
.54117 .64313 Mdot
.55686 .6392 Mdot
.56862 .63528 Mdot
.5647 .63528 Mdot
.56078 .64705 Mdot
.5647 .67057 Mdot
.56078 .68234 Mdot
.5647 .68234 Mdot
.5647 .68234 Mdot
.56078 .67057 Mdot
.56862 .67057 Mdot
.5647 .67057 Mdot
.57254 .68234 Mdot
.56862 .69018 Mdot
.5647 .67842 Mdot
.5647 .67057 Mdot
.58039 .66273 Mdot
.58823 .66273 Mdot
.57646 .65097 Mdot
.57254 .64705 Mdot
.56078 .65097 Mdot
.55686 .66273 Mdot
.55294 .66273 Mdot
.54902 .64313 Mdot
.54117 .6196 Mdot
.52941 .60783 Mdot
.52941 .61568 Mdot
.51372 .61568 Mdot
.51372 .62352 Mdot
.5098 .61568 Mdot
.50588 .59999 Mdot
.52549 .59999 Mdot
.52941 .58431 Mdot
.53725 .58823 Mdot
.54117 .59607 Mdot
.55686 .60783 Mdot
.5647 .6196 Mdot
.56862 .62352 Mdot
.58431 .63528 Mdot
.60391 .65097 Mdot
.61568 .65881 Mdot
.60783 .65489 Mdot
.60783 .66273 Mdot
.60783 .67057 Mdot
.58823 .66273 Mdot
.60391 .66665 Mdot
.60783 .65489 Mdot
.60783 .64705 Mdot
.60783 .65097 Mdot
.60391 .66273 Mdot
.61176 .6745 Mdot
.61176 .67842 Mdot
.59215 .65881 Mdot
.60783 .65881 Mdot
.61176 .65489 Mdot
.60391 .65489 Mdot
.59607 .66273 Mdot
.59999 .67842 Mdot
.60391 .68234 Mdot
.59999 .67842 Mdot
.59215 .67057 Mdot
.59999 .67842 Mdot
.60783 .68234 Mdot
.59607 .67057 Mdot
.58823 .67842 Mdot
.58431 .6745 Mdot
.59607 .67057 Mdot
.59999 .66273 Mdot
.59607 .66273 Mdot
.60391 .67057 Mdot
.59607 .66273 Mdot
.59215 .67057 Mdot
.59215 .67057 Mdot
.59607 .67057 Mdot
.58823 .66273 Mdot
.58431 .65489 Mdot
.60391 .66665 Mdot
.59999 .67057 Mdot
.60391 .68626 Mdot
.58431 .67057 Mdot
.58039 .65881 Mdot
.58039 .65489 Mdot
.58039 .65881 Mdot
.58431 .65881 Mdot
.58431 .66273 Mdot
.58039 .66665 Mdot
.57254 .67057 Mdot
.58823 .67842 Mdot
.58431 .65881 Mdot
.58431 .64705 Mdot
.57646 .64705 Mdot
.56862 .6392 Mdot
.56862 .6392 Mdot
.5647 .63136 Mdot
.5647 .62744 Mdot
.56862 .62744 Mdot
.57254 .62352 Mdot
.57646 .62744 Mdot
.56862 .63136 Mdot
.55294 .63528 Mdot
.54902 .6392 Mdot
.53725 .62352 Mdot
.55294 .63136 Mdot
.54509 .62352 Mdot
.55294 .62352 Mdot
.55294 .61568 Mdot
.54117 .61568 Mdot
.53333 .62352 Mdot
.52549 .63136 Mdot
.52157 .63136 Mdot
.51765 .6196 Mdot
.51372 .59215 Mdot
.51765 .58431 Mdot
.5098 .58431 Mdot
.50588 .58431 Mdot
.5098 .59607 Mdot
.50588 .60391 Mdot
.49804 .59999 Mdot
.49412 .58823 Mdot
.49412 .58431 Mdot
.48628 .57254 Mdot
.48628 .57254 Mdot
.48235 .57254 Mdot
.47059 .57254 Mdot
.46667 .58039 Mdot
.45491 .58039 Mdot
.44314 .57254 Mdot
.44314 .56078 Mdot
.45491 .54509 Mdot
.45098 .52549 Mdot
.4353 .52157 Mdot
.43138 .52157 Mdot
.41177 .50588 Mdot
.41569 .51372 Mdot
.41177 .4902 Mdot
.38432 .43922 Mdot
.43138 .5098 Mdot
.48628 .56862 Mdot
.4902 .58431 Mdot
.48628 .58823 Mdot
.48235 .58823 Mdot
.49412 .59607 Mdot
.4902 .59999 Mdot
.49804 .61176 Mdot
.49804 .6196 Mdot
.51372 .62352 Mdot
.52157 .62352 Mdot
.51765 .60391 Mdot
.52549 .60783 Mdot
.52941 .6196 Mdot
.54509 .63528 Mdot
.54117 .63136 Mdot
.54902 .63136 Mdot
.56078 .63136 Mdot
.56078 .61568 Mdot
.5647 .61568 Mdot
.55294 .61568 Mdot
.5647 .63528 Mdot
.55294 .63136 Mdot
.55294 .6392 Mdot
.55686 .63528 Mdot
.5647 .63136 Mdot
.57254 .63528 Mdot
.5647 .64313 Mdot
.5647 .65097 Mdot
.56078 .65881 Mdot
.55686 .65881 Mdot
.5647 .66273 Mdot
.56078 .65881 Mdot
.5647 .65881 Mdot
.56078 .65097 Mdot
.57254 .65489 Mdot
.57646 .65881 Mdot
.56862 .66665 Mdot
.57254 .6745 Mdot
.57646 .66665 Mdot
.58823 .66273 Mdot
.58431 .64705 Mdot
.58431 .64313 Mdot
.56862 .6392 Mdot
.57254 .65097 Mdot
.57646 .65881 Mdot
.57646 .65881 Mdot
.58039 .65881 Mdot
.56862 .64705 Mdot
.56862 .64313 Mdot
.55294 .63136 Mdot
.54509 .63528 Mdot
.51765 .62352 Mdot
.52157 .61568 Mdot
.5098 .59999 Mdot
.5098 .58039 Mdot
.50588 .56078 Mdot
.50588 .55686 Mdot
.50196 .56078 Mdot
.49804 .5647 Mdot
.49412 .5647 Mdot
.4902 .55686 Mdot
.49804 .56078 Mdot
.49804 .56078 Mdot
.50196 .56078 Mdot
.53333 .57646 Mdot
.55294 .58823 Mdot
.57254 .60783 Mdot
.58039 .61568 Mdot
.59999 .62744 Mdot
.60391 .62352 Mdot
.60783 .62352 Mdot
.60391 .63136 Mdot
.59999 .64705 Mdot
.59215 .64705 Mdot
.60783 .65097 Mdot
.59607 .6392 Mdot
.61176 .65097 Mdot
.60391 .63528 Mdot
.60783 .63136 Mdot
.60783 .6392 Mdot
.60783 .65097 Mdot
.58823 .64705 Mdot
.58823 .64705 Mdot
.59607 .65097 Mdot
.60391 .66273 Mdot
.59607 .66273 Mdot
.59999 .66273 Mdot
.59215 .66273 Mdot
.58039 .65489 Mdot
.58431 .65097 Mdot
.58823 .64705 Mdot
.59215 .64705 Mdot
.59215 .64313 Mdot
.58039 .63528 Mdot
.58431 .65097 Mdot
.59215 .65881 Mdot
.58823 .65489 Mdot
.59215 .65881 Mdot
.59999 .65881 Mdot
.60391 .65881 Mdot
.58823 .65489 Mdot
.59607 .67057 Mdot
.59215 .67057 Mdot
.58431 .65489 Mdot
.58039 .65097 Mdot
.59607 .65489 Mdot
.58431 .6392 Mdot
.58431 .6392 Mdot
.57254 .63528 Mdot
.58823 .64705 Mdot
.57254 .63528 Mdot
.58039 .62352 Mdot
.58039 .61568 Mdot
.58039 .61568 Mdot
.57254 .61176 Mdot
.5647 .60783 Mdot
.56862 .61568 Mdot
.56078 .61568 Mdot
.5647 .60783 Mdot
.55686 .59607 Mdot
.56862 .59215 Mdot
.56862 .59607 Mdot
.55686 .59999 Mdot
.54509 .61568 Mdot
.53725 .62744 Mdot
.53333 .61568 Mdot
.54117 .61568 Mdot
.55294 .61568 Mdot
.54117 .59999 Mdot
.53333 .59607 Mdot
.53333 .60783 Mdot
.5098 .59999 Mdot
.50588 .60391 Mdot
.51765 .61176 Mdot
.5098 .59607 Mdot
.50588 .58039 Mdot
.5098 .57254 Mdot
.5098 .57254 Mdot
.50196 .58039 Mdot
.50588 .58431 Mdot
.49412 .57646 Mdot
.47843 .55686 Mdot
.48628 .56078 Mdot
.47843 .55686 Mdot
.46667 .54509 Mdot
.46275 .54509 Mdot
.46275 .55294 Mdot
.45098 .55294 Mdot
.45491 .55686 Mdot
.44314 .54902 Mdot
.43138 .52941 Mdot
.4353 .51765 Mdot
.43922 .51372 Mdot
.4353 .50588 Mdot
.42746 .49412 Mdot
.40393 .48235 Mdot
.40785 .47843 Mdot
.40785 .46667 Mdot
.40393 .44314 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo3@00o`04o`0000<00?l0XOl0000;ooooo`002_ooool00ol00000oomo0?ooO`1D0?oo
O`03o`00001oool0Oooo05X0Oooo00?o0000ooooooooool03ooooolF003o09kooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o00000?ooO`3oogl0E@3oogl00ol00000Oooo07ooo`1I07ooo`03
o`000?oooooooooo00oooooo5P00o`2Nooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
003oogl0oomo05D0oomo00?o000007ooo`1oool0F@1oool00ol0003oooooooooo`0?oooooaP00?l0
W?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1F0?ooO`03o`00001o
ool0Oooo05P0Oooo00?o0000ooooooooool03ooooolH003o09cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0E`3oogl00ol00000Oooo07ooo`1G07ooo`03o`000?oooooo
oooo00oooooo6000o`2Looooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo
05L0oomo00?o000007ooo`1oool0E`1oool00ol0003oooooooooo`0?oooooaP00?l0W?ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1H0?ooO`03o`00001oool0Oooo05H0
Oooo00?o0000ooooooooool03oooool2003o00<0003o6000o`2Gooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00003oogl0oomo05P0oomo00?o000007ooo`1oool0EP1oool00ol0003ooooo
ooooo`0?ooooo`03o`000?ooool0003o0080003o6000o`2Gooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`00003oogl0oomo05P0oomo00?o000007ooo`1oool0EP1oool00ol0003ooooooooo
o`0?ooooo`03o`000?ooool0003o0080003o6000o`2Gooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo05T0oomo00?o000007ooo`1oool0E@1oool00ol0003oooooooooo`0?
ooooo`03o`000?ooool00?l001/00?l0U_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
0000oomo0?ooO`1J0?ooO`03o`00001oool0Oooo05@0Oooo00?o0000ooooooooool03oooool00ol0
003ooooo003o0002003o00<0003o5P00o`2Fooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`00003oogl0oomo05X0oomo00?o000007ooo`1oool0E01oool00ol0003oooooooooo`0?ooooo`03
o`000?ooool00?l000800?l00`000?lJ003o09;ooooo00?o0000ooooooooool02Oooool000[ooooo
00?o00000?ooO`3oogl0F`3oogl00ol00000Oooo07ooo`1C07ooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00P00o`030000oaX00?l0T_ooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol00000oomo0?ooO`1K0?ooO`03o`00001oool0Oooo05<0Oooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`03ooooob<00?l0Roooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1K0?ooO`03o`00001oool0Oooo05<0Oooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`03ooooobL00?l0Qoooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
0000oomo0?ooO`1L0?ooO`03o`00001oool0Oooo0580Oooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`04ooooo`<0003o8`00o`27ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`00003oogl0oomo05d0oomo00?o000007ooo`1oool0D@1oool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Cooooo0`000?l2003o00<0003o7`00o`26ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00003oogl0oomo05d0oomo00?o000007ooo`1oool0D@1oool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Cooooo0`000?l2003o00<0003o2@00o`030000oa<00?l0
Q_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1N0?ooO`03o`00001o
ool0Oooo0500Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`<00?l01000
0?l8003o00<0003o4`00o`26ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo05l0oomo00?o000007ooo`1oool0C`1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Sooooo0P00o`030000o`P00?l00`000?lA003o08Sooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o00000?ooO`3oogl0G`3oogl00ol00000Oooo07ooo`1?07ooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01oooool60000oad00?l0Qoooool00ol0003oooooooooo`09oooo
o`002_ooool00ol00000oomo0?ooO`1P0?ooO`03o`00001oool0Oooo04h0Oooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`07ooooo`<0003o1P00o`030000oaP00?l0Q_ooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1P0?ooO`03o`00001oool0Oooo04h0Oooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`<0003o1@00o`040000oaX00?l0
Q?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1Q0?ooO`03o`00001o
ool0Oooo04d0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`800?l02000
0?l2003o00<0003o5`00o`22ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0680oomo00?o000007ooo`1oool0C01oool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00_ooooo1`000?l3003o00<0003o0P00o`030000oa800?l0P_ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000oomo0?ooO`1R0?ooO`03o`00001oool0Oooo04`0Oooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0;ooooo`H0003o1000o`030000o`800?l00`000?lB003o
08;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0H`3oogl00ol00000
Oooo07ooo`1;07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool30000o`T0
0?l00`000?lE003o07oooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0
H`3oogl00ol00000Oooo07ooo`1;07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3_ooool30000o`@00?l00`000?lK003o07kooooo00?o0000ooooooooool02Oooool000[ooooo00?o
00000?ooO`3oogl0H`3oogl00ol00000Oooo07ooo`1;07ooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool30000o`@00?l01@000?lJ003o07gooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0I03oogl00ol00000Oooo07ooo`1:07ooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03oooool6003o00H0003o7000o`1jooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`00003oogl0oomo06D0oomo00?o000007ooo`1oool0B@1oool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo1@00o`050000o`04003o00000?l0003o
0000oaP00?l0N_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1U0?oo
O`03o`00001oool0Oooo04T0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aoooo
o`04003o00000?l0003o0000o`800?l020000?lH003o07[ooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o00000?ooO`3oogl0IP3oogl00ol00000Oooo07ooo`1807ooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04_ooool30000o`800?l020000?lH003o07[ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o00000?ooO`3oogl0IP3oogl00ol00000Oooo07ooo`1807ooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool30000o`@00?l02@000?lE003o07[o
oooo00?o0000ooooooooool02Oooool000[ooooo0_l0001W0?ooO`03o`00001oool0Oooo04P0Oooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`<00?l000?ooooo003o0000o`00
0`00o`070000oaP00?l0Moooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Ooooo`00
001W0?ooO`03o`00001oool0Oooo04L0Oooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Fooooo`@00?l020000?l3003o00<0003o4P00o`1gooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00001oool0Oooo00;o0000IP3oogl00ol00000Oooo07ooo`1607ooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06Oooool01@00o`00003o0000o`000?l00?l000@0003o0`00
o`030000oa@00?l0MOooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`02
07ooo`;o0000I03oogl00ol00000Oooo07ooo`1607ooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool06Oooool00`00o`00003o0000o`060000o`<00?l00`000?lD003o07Gooooo00?o0000
ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0101oool2o`0006<0oomo00?o000007oo
o`1oool0A@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo1@000?l00`00
o`00003o0000o`030000o`04003o00000?l0003o0000oaL00?l0M?ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000Oooo07ooo`0607ooo`;o0000H@3oogl00ol00000Oooo07ooo`1507oo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool50000o`03003o00000?l0003o
00<0003o00@00?l00000o`000?l0003o5`00o`1dooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`00001oool0Oooo00P0Oooo0_l0001O0?ooO`03o`00001oool0Oooo04D0Oooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Gooooo`D0003o0`00o`070000oa`00?l0Koooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0:07ooo`03o`00003oogl0oomo05d0
oomo00?o000007ooo`1oool0A01oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01So
oooo0`000?l4ooooo`H0003o7@00o`1_ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
001oool0Oooo00/0Oooo0_l0001N0?ooO`03o`00001oool0Oooo04<0Oooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Nooooo`800?l01@000?lO003o06gooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o000007ooo`1oool03@1oool00ol00000oomo0?ooO`1K0?ooO`03o`00001o
ool0Oooo04<0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Nooooo`800?l01000
0?lP003o06gooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool03P1oool0
0ol00000oomo0?ooO`1K0?ooO`03o`00001oool0Oooo0480Oooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Nooooo`800?l010000?l6003o00<0003o5`00o`1]ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`00001oool0Oooo00l0Oooo0_l0001K0?ooO`03o`00001oool0Oooo
0480Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qooooo`D0003o00<00?l00000
o`000?l01@000?l7003o00<0003o3P00o`1[ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`00001oool0Oooo0140Oooo00?o00000?ooO`3oogl0F@3oogl00ol00000Oooo07ooo`1107ooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool70000o`03003o00000?l0003o00D0
003o1`00o`030000o`P00?l000?ooooo003o0000o`000`00o`1[ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00001oool0Oooo0180Oooo0_l0001I0?ooO`03o`00001oool0Oooo0440Oooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`L0003o00D00?l00000o`000?l0
003o003o00030000o`L00?l00`000?l>003o06_ooooo00?o0000ooooooooool02Oooool000[ooooo
00?o000007ooo`1oool0501oool2o`0005P0oomo00?o000007ooo`1oool0@01oool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01oooooo0`000?l2ooooo`H00?l010000?l>003o0003oooo
o`00o`000?l000T00?l0JOooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07oo
o`0F07ooo`;o0000EP3oogl00ol00000Oooo07ooo`1007ooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool09?ooool5003o00@0003o6`00o`1Yooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00001oool0Oooo01P0Oooo0_l0001D0?ooO`03o`00001oool0Oooo0400Oooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Tooooo`<00?l01P000?lK003o06Wooooo00?o0000
ooooooooool02Oooool000[ooooo00?o000007ooo`1oool06P1oool2o`0005<0oomo00?o000007oo
o`1oool0?`1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo1@000?l3003o
00<0003o6000o`1Wooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo01`0
Oooo00?o00000?ooO`3oogl0D@3oogl00ol00000Oooo07ooo`0n07ooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool09oooool30000o`05003o00000?l0003o0000o`00o`000`000?lJ003o
06Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool07@1oool2o`000540
oomo00?o000007ooo`1oool0?P1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02_o
oooo0`000?l01000o`00003o0000o`000?lJ003o06Gooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool07`1oool2o`0004l0oomo00?o000007ooo`1oool0?P1oool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo02_ooooo0`000?lN003o06Gooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o000007ooo`1oool08@1oool2o`0004h0oomo00?o000007ooo`1oool0
?@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02_ooooo2000o`030000oaD00?l0
I_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0S07ooo`;o0000C03o
ogl00ol00000Oooo07ooo`0m07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Ooo
ool6003o00@0003o5000o`1Vooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0
Oooo02D0Oooo0_l0001:0?ooO`03o`00001oool0Oooo03d0Oooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0]ooooo`800?l020000?lD003o06Kooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o000007ooo`1oool09`1oool00ol00000oomo0?ooO`180?ooO`03o`00001oool0Oooo
03`0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0_ooooo`P0003o1000o`030000
o`d00?l0I_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0X07ooo`;o
0000B03oogl00ol00000Oooo07ooo`0l07ooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0;oooool80000o`@00?l00`000?lA003o06;ooooo00?o0000ooooooooool02Oooool000[ooooo
00?o000007ooo`1oool0:P1oool2o`0004L0oomo00?o000007ooo`1oool0>`1oool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03Cooooo0`000?l4003o00D0003o3`00o`1Rooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo02`0Oooo0_l000150?ooO`03o`00001o
ool0Oooo03/0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`<0003o1000
o`050000oa800?l0Goooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0^
07ooo`03o`00003oogl0oomo04<0oomo00?o000007ooo`1oool0>P1oool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03Kooooo0`00o`070000oa@00?l0GOooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000Oooo07ooo`0_07ooo`;o0000@`3oogl00ol00000Oooo07ooo`0j07oo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=oooool2003o00D0003o5P00o`1Moooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0340Oooo00?o00000?ooO`3o
ogl0@@3oogl00ol00000Oooo07ooo`0i07ooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0;_ooool50000o`Cooooo0P00o`050000oaL00?l000Cooooo003o0000o`000?l0F?ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0b07ooo`03o`00003oogl0oomo0400
oomo00?o000007ooo`1oool0>@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02ko
oooo1@000?l4ooooo`800?l01@000?lG003o0004ooooo`00o`000?l0003o05Sooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o000007ooo`1oool0<`1oool2o`000400oomo00?o000007ooo`1o
ool0>@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02kooooo1@000?l4ooooo`80
0?l01@000?l7003o00<0003o3@00o`001?ooool00?l0003o0000o`1Hooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`00001oool0Oooo03D0Oooo0_l0000o0?ooO`03o`00001oool0Oooo03P0
Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0iooooo`D0003o1`00o`030000o`l0
0?l0F_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0g07ooo`;o0000
?@3oogl00ol00000Oooo07ooo`0h07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
>Oooool50000o`800?l000?ooooo003o0000o`000P00o`030000o`l00?l0F_ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0i07ooo`03o`00003oogl0oomo03X0oomo00?o
000007ooo`1oool0>01oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Wooooo1@00
0?l3oooooaH00?l0F_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0j
07ooo`;o0000>`3oogl00ol00000Oooo07ooo`0g07ooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0>oooool3003o00?ooooo0`00o`000oooool00?l0003o0008003o0003ooooo`00o`00
0?l000D00?l0F_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0l07oo
o`;o0000>@3oogl00ol00000Oooo07ooo`0g07ooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0@Oooool2003o00<0003o00?ooooo003o0000o`000P00o`030000o`h00?l0EOooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0n07ooo`?o0000=`3oogl00ol00000
Oooo07ooo`0f07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@Oooool2003o00<0
003o00Gooooo003o0000o`000?l0ooooo`030000o`h00?l0EOooool00ol0003oooooooooo`09oooo
o`002_ooool00ol00000Oooo07ooo`1107ooo`;o0000=@3oogl00ol00000Oooo07ooo`0f07ooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0@Oooool2003o00L0003o00Cooooo0000o`00
0?l0003o3P00o`001?ooool00?l0003o0000o`1Aooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`00001oool0Oooo04<0Oooo0_l0000c0?ooO`03o`00001oool0Oooo03H0Oooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`14ooooo`H0003o0`00o`000oooool00?l0003o0003003o
00<0003o1P00o`001?ooool00?l0003o0000o`1Aooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`00001oool0Oooo04D0Oooo0_l0000a0?ooO`03o`00001oool0Oooo03H0Oooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`14ooooo`H0003o2@00o`030000o`d00?l0C_ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`1707ooo`;o0000<03ooglh07ooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Aoooool2003o00H0003o1000o`030000o`04
003o00000?l0003o0000o`@00?l000?ooooo003o0000o`000P00o`1>ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`00001oool0Oooo04T0Oooo0_l0000^0?ooOcP0Oooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`11ooooo`<0003o0oooool2003o00H0003o0oooool5003o00<0
003o2@00o`001?ooool00?l0003o0000o`1:ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`00001oool0Oooo04/0Oooo00?o00000?ooO`3oogl0:`3ooglh07ooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0@Oooool30000o`05ooooo`000?l0003o0000o`00o`001P000?l2oooo
o`800?l00`000?l01000o`00003o0000o`000?l7003o00?ooooo0`00o`1:ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`00001oool0Oooo04`0Oooo0_l0000[0?ooOcP0Oooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`11ooooo`L0003o00Cooooo0000o`000?l0003o1Oooool2
003o00H0003o3P00o`1:ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo
04h0Oooo0_l0000Y0?ooOcP0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`14oooo
o`@0003o00?ooooo003o0000o`0010000?l2ooooo`800?l01P000?l>003o04[ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o000007ooo`1oool0D01oool3o`0002H0oomo>01oool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo2`000?l2ooooo`800?l01P000?l>003o04[o
oooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0D`1oool2o`0002@0oomo
00?o000007ooo`1oool0=@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Gooooo
2P000?l4ooooo`L0003o2P00o`1=ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001o
ool0Oooo05D0Oooo0P00000R0?ooO`03o`00001oool0Oooo03D0Oooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`15ooooo`X0003o0_ooool:0000o`d00?l00oooool3003o04?ooooo00?o
0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0E`1oool00ol00000oomo0?ooO`0O
0?ooO`03o`00001oool0Oooo03D0Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`15
ooooo`<0003o1?ooool?0000o`d00?l00oooool4003o04;ooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o000007ooo`1oool0F01oool200000003o`00003oogl0oomo01`0oomo00?o000007oo
o`1oool0=@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Gooooo0`000?l4oooo
o`X0003o00<00?l00000o`000?l010000?l<003o0003ooooo`00o`000?l000<00?l0@_ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`1K07ooo`800000703oogl00ol00000
Oooo07ooo`0e07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0AOooool40000o`Co
oooo40000?l00`00o`3ooooo003o000?003o04;ooooo00?o0000ooooooooool02Oooool000[ooooo
00?o000007ooo`1oool0G@1oool200000003o`00003oogl0oomo01H0oomo0_l0000g07ooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0AOooool70000o`03ooooo`000?l0003o00h0003o
0P00o`000oooool00?l0003o000=003o04;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o
000007ooo`1oool0H01oool200000003o`00003oogl0oomo01<0oomo00?o000007ooo`1oool0=P1o
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Kooooo1`000?l4ooooo`d0003o00<0
0?l0ooooo`00o`003000o`14ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0
Oooo06<0Oooo0P0000000ol00000oomo0?ooO`0?0?ooO`;o0000>01oool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo04Kooooo60000?l00`00o`3ooooo003o000<003o04Cooooo00?o0000
ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0IP1oool200000003o`00003oogl0oomo
00X0oomo0_l0000j07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0A_oooolH0000
o`03003o0?oooooooooo00l00?l0@Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000
Oooo07ooo`1Y07ooo`@000002Ol0000k07ooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0A_oooolK0000o`05ooooo`000?l0003o0000ooooool02P00o`11ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`00001oool0Oooo06l0Oooo1?l0000n07ooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0Aoooool70000o`03ooooo`000?l0003o00`0003o00Gooooo0000o`00
0?l0003oooooo`030000o`;ooooo2`00o`0oooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`17oooooaX0
003o00Cooooo0000o`000?l0003o0_ooool<003o03kooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wo
oooo6@000?l7ooooo`X00?l0?_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0BOoooolN0000o`04oooo
o`000?l0003o0000o`P00?l00oooool3003o00;ooooo0`00o`0cooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`19oooooah0003o00Cooooo0000o`000?l0003o2000o`03ooooo`<00?l00_ooool3003o03?o
oooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04Wooooo5`000?l00oooool00?l00000o`080000o`04003o
00000?l0003o0000o`@00?l00_ooool4003o00;ooooo0`00o`0cooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`19oooooaL0003o00<00?l00000o`000?l020000?l01000o`00003o0000o`000?l=003o03Go
oooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04_ooooo80000?l01000o`00003o0000o`000?l2ooooo`/0
0?l0=Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0BooooolQ0000o`03003o00000?l0003o00@0003o
2@00o`0eooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1;ooooobP0003o00<00?l0ooooo`00o`001@00
o`0fooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1<ooooobL0003o00<00?l0ooooo`00o`001@00o`0f
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1<ooooobD0003o0`00o`000oooool00?l0003o0004003o
03Kooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo04cooooo9@000?l2ooooo`<00?l00_ooool3003o03Ko
oooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04cooooo9P000?l4003o0003ooooo`00o`000?l000800?l0
00Cooooo003o0000o`000?l0<_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_oooolV0000o`800?l0
00?ooooo003o0000o`000P00o`001?ooool00?l0003o0000o`02ooooo`<00?l0;Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0C_ooool[0000o`04003o00000?l0003o0000o`800?l00_ooool3003o00<0
003o:_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0DooooolV0000o`04003o00000?l0003o0000o`80
0?l00_ooool3003o00<0003o:_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0D_ooool[0000o`Oooooo
0`000?lZooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Booooob/0003o00<00?l0ooooo`00o`001000
o`04ooooo`@0003o9Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a
07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0D_ooool[0000o`03003o0?ooool0
0?l000@00?l00_ooool60000obGooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007oo
o`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo:`000?l00`00
o`00003o0000o`040000o`;ooooo1P000?lUooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Boooooc80
003o0_ooool60000obGooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0
/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo9`000?l00`00o`00003o
0000o`0A0000obCooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1o
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo;0000?l00`00o`00003o0000
o`0>0000ob;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05?ooooo:`000?l00`00o`00003o0000o`0>
0000ob;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo05Cooooo>`000?lRooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1GooooocP0003o0_ooool3003o01gooooo00?o0000ooooooooool02Oooool000[ooooo
00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Oooooo
>0000?l2ooooo`<00?l07Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07oo
o`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Fooooolc0000o`?ooooo0`00
o`0Mooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Koooooc<0003o8oooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0Fooooold0000ob;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1o
ool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05_ooooo0`000?l2ooooobl0
003o8_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0H?ooool_0000ob;ooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo067ooooo;@000?l7ooooo`<00?l06Oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0HOooool^
0000o`Kooooo0`00o`0Iooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo
0;40Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Qooooobl0003o1Oooool3003o
01Wooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo06;ooooo;P000?l3003o01kooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo06Cooooo;P000?l00`00o`3oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1Wooooob/0003o00<00?l0ooooooooool07?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Ioooool^
0000oacooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo06Sooooo:0000?l2ooooo`<0003o7?ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0J?oooolX0000o`;ooooo0`000?lLooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1/ooooob@0003o8Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07oo
o`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0K_oooolQ0000o`<00?l07ooo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0K_oooolP0000o`03ooooo`00o`00003o0080003o7_ooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0KooooolO0000o`03ooooo`00o`00003o0080003o0P00o`0Loooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1`oooooad0003o0`00o`030000o`800?l07?ooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0LooooolE0000o`03003o00000?l0003o00P0003o0P00o`02ooooo`<00?l0
5oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0LooooolI0000o`03ooooo`000?l0003o00@0003o0`00
o`001?ooool00?l0003o0000o`0Gooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001o
ool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1eooooo`<0003o0_oo
ool60000o`Cooooo3`000?l3003o0004ooooo`00o`000?l0003o01Oooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo08Sooooo20000?l2003o00<0003o00<00?l0ooooo`000?l00P000?lGooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`29ooooo`L0003o0P00o`030000o`03003o0?ooool0003o0080003o5oooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0SOooool5003o00T0003o00@00?l00000o`000?l0003o4_ooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0SOooool2003o00`0003o00@00?l00000o`000?l0003o4_ooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0S_ooool00`00o`00003o0000o`020000o`03003o00000?l0003o
00T0003o4_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Soooool40000o`03003o00000?l0003o00T0
003o4_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0T?ooool40000o`03003o00000?l0003o00<0003o
00?ooooo0000o`000?l00P000?lBooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001o
ool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Aooooo`<0003o0_oo
ool80000oa?ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo097ooooo0`000?l2ooooo`H0003o5Oooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0Toooool30000o`03003o00000?l0003o00<0003o00<00?l0oooo
ooooool04_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07ooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Toooool30000o`03003o00000?l0003o00<0
003o00<00?l0ooooooooool04_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Toooool30000o`03003o
00000?l0003o00<0003o00<00?l0ooooooooool04_ooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol00000Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0V?oo
ool30000o`03003o0?oooooooooo01?ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
07ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Wooooo1@00o`03
0000oa3ooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo09Wooooo0`00o`050000oa3ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo09Wooooo0`00o`070000o`kooooo00?o0000ooooooooool02Oooool000[ooooo
00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Wooooo
0`00o`070000o`kooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1o
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09kooooo1@000?l3003o00_ooooo00?o
0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo09kooooo1`000?l00`00o`3oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2Nooooo`X0003o2Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000
Oooo07ooo`2a07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0W_ooool:0000o`Wo
oooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0:7ooooo2@000?l7ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2Qooooo`T0003o1oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a
07ooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Xoooool00`00o`00003o0000o`04
0000o`Oooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1oool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0:Cooooo0`000?l:ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2aooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0
Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2aooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40
Oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00001oool0Oooo0;40Oooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2aooooo`03o`000?oooooooooo00Wooooo000:oooookGo00004Oooooneo`0000_ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0557921, \
-0.0252998, 0.00554406, 0.00554406}, {{10.0625, 190.438}, {184.875, 4.5}} -> \
{-14.4348, -6.64788, 1.41581, 1.41581}, {{10.0625, 190.438}, {184.875, 4.5}} -> \
{-14.4348, -6.64788, 1.41581, 1.41581}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-295.282, -6.60135, 1.41532, 1.41532}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute expected error", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(errors = {ExpectedError2D[p1rg, p2rg, x, y], 
          ExpectedError2D[p1rb, p2rb, x, y], 
          ExpectedError2D[p1gb, p2gb, x, y]};\)\), "\[IndentingNewLine]", 
    \(\(BarChart[errors, \ Frame \[Rule] True, \ 
        BarStyle \[Rule] {Red, Green, Blue}, 
        FrameTicks \[Rule] {None, Automatic, None, Automatic}, 
        GridLines \[Rule] {None, Automatic}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.125 0.3125 0.0147151 0.183731 [
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10658 -18 -4.5 ]
[-0.0125 .10658 0 4.5 ]
[-0.0125 .19845 -6 -4.5 ]
[-0.0125 .19845 0 4.5 ]
[-0.0125 .29031 -18 -4.5 ]
[-0.0125 .29031 0 4.5 ]
[-0.0125 .38218 -6 -4.5 ]
[-0.0125 .38218 0 4.5 ]
[-0.0125 .47404 -18 -4.5 ]
[-0.0125 .47404 0 4.5 ]
[-0.0125 .56591 -6 -4.5 ]
[-0.0125 .56591 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .10658 m
1 .10658 L
s
0 .19845 m
1 .19845 L
s
0 .29031 m
1 .29031 L
s
0 .38218 m
1 .38218 L
s
0 .47404 m
1 .47404 L
s
0 .56591 m
1 .56591 L
s
0 g
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10658 m
.00625 .10658 L
s
[(0.5)] -0.0125 .10658 1 0 Mshowa
0 .19845 m
.00625 .19845 L
s
[(1)] -0.0125 .19845 1 0 Mshowa
0 .29031 m
.00625 .29031 L
s
[(1.5)] -0.0125 .29031 1 0 Mshowa
0 .38218 m
.00625 .38218 L
s
[(2)] -0.0125 .38218 1 0 Mshowa
0 .47404 m
.00625 .47404 L
s
[(2.5)] -0.0125 .47404 1 0 Mshowa
0 .56591 m
.00625 .56591 L
s
[(3)] -0.0125 .56591 1 0 Mshowa
.125 Mabswid
0 .03309 m
.00375 .03309 L
s
0 .05146 m
.00375 .05146 L
s
0 .06983 m
.00375 .06983 L
s
0 .08821 m
.00375 .08821 L
s
0 .12495 m
.00375 .12495 L
s
0 .14333 m
.00375 .14333 L
s
0 .1617 m
.00375 .1617 L
s
0 .18007 m
.00375 .18007 L
s
0 .21682 m
.00375 .21682 L
s
0 .23519 m
.00375 .23519 L
s
0 .25357 m
.00375 .25357 L
s
0 .27194 m
.00375 .27194 L
s
0 .30868 m
.00375 .30868 L
s
0 .32706 m
.00375 .32706 L
s
0 .34543 m
.00375 .34543 L
s
0 .3638 m
.00375 .3638 L
s
0 .40055 m
.00375 .40055 L
s
0 .41892 m
.00375 .41892 L
s
0 .4373 m
.00375 .4373 L
s
0 .45567 m
.00375 .45567 L
s
0 .49242 m
.00375 .49242 L
s
0 .51079 m
.00375 .51079 L
s
0 .52916 m
.00375 .52916 L
s
0 .54754 m
.00375 .54754 L
s
0 .58428 m
.00375 .58428 L
s
0 .60265 m
.00375 .60265 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10658 m
1 .10658 L
s
.99375 .19845 m
1 .19845 L
s
.99375 .29031 m
1 .29031 L
s
.99375 .38218 m
1 .38218 L
s
.99375 .47404 m
1 .47404 L
s
.99375 .56591 m
1 .56591 L
s
.125 Mabswid
.99625 .03309 m
1 .03309 L
s
.99625 .05146 m
1 .05146 L
s
.99625 .06983 m
1 .06983 L
s
.99625 .08821 m
1 .08821 L
s
.99625 .12495 m
1 .12495 L
s
.99625 .14333 m
1 .14333 L
s
.99625 .1617 m
1 .1617 L
s
.99625 .18007 m
1 .18007 L
s
.99625 .21682 m
1 .21682 L
s
.99625 .23519 m
1 .23519 L
s
.99625 .25357 m
1 .25357 L
s
.99625 .27194 m
1 .27194 L
s
.99625 .30868 m
1 .30868 L
s
.99625 .32706 m
1 .32706 L
s
.99625 .34543 m
1 .34543 L
s
.99625 .3638 m
1 .3638 L
s
.99625 .40055 m
1 .40055 L
s
.99625 .41892 m
1 .41892 L
s
.99625 .4373 m
1 .4373 L
s
.99625 .45567 m
1 .45567 L
s
.99625 .49242 m
1 .49242 L
s
.99625 .51079 m
1 .51079 L
s
.99625 .52916 m
1 .52916 L
s
.99625 .54754 m
1 .54754 L
s
.99625 .58428 m
1 .58428 L
s
.99625 .60265 m
1 .60265 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.0625 .01472 m
.0625 .60332 L
.3125 .60332 L
.3125 .01472 L
F
0 g
.5 Mabswid
.0625 .01472 m
.0625 .60332 L
.3125 .60332 L
.3125 .01472 L
.0625 .01472 L
s
0 1 0 r
.375 .01472 m
.375 .03508 L
.625 .03508 L
.625 .01472 L
F
0 g
.375 .01472 m
.375 .03508 L
.625 .03508 L
.625 .01472 L
.375 .01472 L
s
0 0 1 r
.6875 .01472 m
.6875 .03632 L
.9375 .03632 L
.9375 .01472 L
F
0 g
.6875 .01472 m
.6875 .03632 L
.9375 .03632 L
.9375 .01472 L
.6875 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`005Oooool00ol0000000000000003o000000L000000Ol00001ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Oooooo0Ol00001ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool0
ooooool7ooooo`7o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004oooooooo0000
2ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00gooooo
00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`0=ooooo`03o`000?l0o`3o0?l0043o0?l0
00?o0000ooooooooool03Oooool00ol0003o003oo`00o`10o`00o`03o`000?oooooooooo00gooooo
0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00gooooo
00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`0=ooooo`03o`000?l0o`3o0?l0043o0?l0
00?o0000ooooooooool03Oooool00ol0003o003oo`00o`10o`00o`03o`000?oooooooooo00gooooo
0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00gooooo
00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`0=ooooo`03o`000?l0o`3o0?l0043o0?l0
00?o0000ooooooooool03Oooool00ol0003o003oo`00o`10o`00o`03o`000?oooooooooo00gooooo
0Ol00001ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool0
0010ool00003o`000?oooooooooo00gooooo00?o0000o`3o0?l0o`00@?l0o`000ol0003ooooooooo
o`0=ooooo`03o`000?l00?oo003o043o003o00?o0000ooooooooool03Oooool1o`00007ooooo000E
ooooo`;o00003_ooool00ol0003oo`00ool00010ool00003o`000?oooooooooo00gooooo00?o0000
o`3o0?l0o`00@?l0o`000ol0003oooooooooo`0=ooooo`03o`000?l00?oo003o043o003o00?o0000
ooooooooool03?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool0
0?oo0000@?oo00000ol0003oooooooooo`0=ooooodCo00003ooooom4o`0000oooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000oooooooo
ool0/oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000
@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo00?o0000ooooooooool03Ooo
ool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`005Oooool2
o`0000kooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2booooo`;o00000Oooool0
01Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooooooo
0;?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043o
o`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo
00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol0
0001ooooo`005Oooool2o`0000kooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2b
ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool0
0003o`000?oooooooooo0;?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oo
oooooooo0;?ooooo0Ol00001ooooo`005Oooool2o`0000kooooo00?o0000ool00?oo0000@?oo0000
0ol0003oooooooooo`2booooo`;o00000Oooool001Gooooo00?o0000ooooooooool03Oooool00ol0
003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`000_ooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003o
o`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`0000Goooooo`000?oooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo00001Ooooooo
0000oooooooooooo000000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo00001Ooooooo
0000oooooooooooo000000_ooooo00?o0000ooooooooool00_ooool2o`0000h0001o00?o0000ool0
0?oo0000@?oo00000ol00000001o0000O`2b0000O`;o00000Oooool00005ooooool0003ooooooooo
ool000001oooool4o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool0
0003o`000?oooooooooo0;?ooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000007oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool0
0003o`000?oooooooooo0;?ooooo0Ol00001ooooo`000_ooool2o`0000Sooooo1Ol00004ooooo`03
o`000?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o
00000Oooool001Gooooo0_l0000>ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0
/_ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000@?oo
00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo00?o0000ooooooooool03Oooool0
0ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003o
ooooooooo`2cooooo`7o00000Oooool001Gooooo0_l0000>ooooo`03o`000?oo003oo`00043oo`00
00?o0000ooooooooool0/_ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o
0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000oooo
ooooool0/oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo
0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo0_l0000>ooooo`03o`00
0?oo003oo`00043oo`0000?o0000ooooooooool0/_ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooo
oooo0;?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00
043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00go
oooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo
0_l0000>ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/_ooool2o`00007ooooo
000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003ooooooooo
o`2cooooo`7o00000Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo00gooooo00?o0000
ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool000kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000oooo
ooooool0/oooool1o`00007ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`00
3_ooool00ol0003oooooooooo`04ooooo`;o00003P0007l00ol0003oo`00ool00010ool00003o`00
000007l0001o0;80001o0_l00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Ooo
ool000gooooo0_l00006ooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000@?oo0000
0ol0003oooooooooo`2cooooo`7o00000Oooool000kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003o
ooooooooo`2cooooo`7o00000Oooool001Gooooo0_l0000>ooooo`03o`000?oo003oo`00043oo`00
00?o0000ooooooooool0/_ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o
0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000oooo
ooooool0/oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo
0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo0_l0000>ooooo`03o`00
0?oo003oo`00043oo`0000?o0000ooooooooool0/_ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooo
oooo0;?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00
043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00go
oooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo
0_l0000>ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/_ooool2o`00007ooooo
000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003ooooooooo
o`2cooooo`7o00000Oooool001Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010
ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eooooo`;o
00003_ooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;;ooooo0_l00001ooooo`00
5Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0
/oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000@?oo
00000ol0003oooooooooo`2cooooo`7o00000Oooool00004ooooool0003o0000o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool0
0010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo0002ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00_ooool2o`0000h0001o00?o0000ool00?oo0000@?oo0000
0ol00000001o0000O`2b0000O`;o00000Oooool000;ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0
003oooooooooo`2cooooo`7o00000Oooool000;ooooo00?o0000ooooooooool01oooool4o`0000Go
oooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?o
oooo0Ol00001ooooo`0000?oooooo`000?l000002Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o0000
0Oooool000;ooooo00?o0000ooooooooool01oooool5o`0000Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`005Oooool2
o`0000kooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2booooo`;o00000Oooool0
01Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooooooo
0;?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043o
o`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo
00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol0
0001ooooo`005Oooool2o`0000kooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2b
ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool0
0003o`000?oooooooooo0;?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oo
oooooooo0;?ooooo0Ol00001ooooo`005Oooool2o`0000kooooo00?o0000ool00?oo0000@?oo0000
0ol0003oooooooooo`2booooo`;o00000Oooool001Gooooo00?o0000ooooooooool03Oooool00ol0
003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003ooooo
ooooo`2cooooo`7o00000Oooool001Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool0
0010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`005Oooool2o`0000kooooo00?o0000
ool00?oo0000@?oo00000ol0003oooooooooo`2booooo`;o00000Oooool001Gooooo00?o0000oooo
ooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001oooo
o`003?ooool5o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003
o`000?oooooooooo0;?ooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o
00000Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00?ooooo0_l0000>0000O`03o`000?oo003oo`00043oo`0000?o00000000O`0007l0/P00
07l2o`00007ooooo000<ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000<
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000=ooooo`?o00001Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0
003oooooooooo`2cooooo`7o00000Oooool001Gooooo0_l0000>ooooo`03o`000?oo003oo`00043o
o`0000?o0000ooooooooool0/_ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo
00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000
ooooooooool0/oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool0
0?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo0_l0000>ooooo`03
o`000?oo003oo`00043oo`0000?o0000ooooooooool0/_ooool2o`00007ooooo000Eooooo`03o`00
0?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oo
oooooooo0;?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003o
o`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eooooo`;o00003_ooool00ol0
003oo`00ool00010ool00003o`000?oooooooooo0;;ooooo0_l00001ooooo`005Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003ooooo
ooooo`2cooooo`7o00000Oooool001Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool0
0010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eoooo
o`;o00003_ooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;;ooooo0_l00001oooo
o`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000oooooooo
ool0/oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000
@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool000Go00000oooool00ol0003ooooooooo
o`02ooooo`?o00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o
0000ooooooooool0/oooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000
@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool000;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`;o00003P0007l00ol0003oo`00ool00010ool00003o`000000
07l0001o0;80001o0_l00001ooooo`000oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooo
oooo0;?ooooo0Ol00001ooooo`0000Go0000ooooooooooooooooo`000007ooooo`Co00001Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1
o`00007ooooo00001Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1
o`00007ooooo00001?oooooo0000o`000?l00008ooooo`Go00001?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eoooo
o`;o00003_ooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;;ooooo0_l00001oooo
o`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000oooooooo
ool0/oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000
@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo00?o0000ooooooooool03Ooo
ool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1
o`00007ooooo000Eooooo`;o00003_ooool00ol0003oo`00ool00010ool00003o`000?oooooooooo
0;;ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043o
o`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00gooooo
00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000
ooooooooool0/oooool1o`00007ooooo000Eooooo`;o00003_ooool00ol0003oo`00ool00010ool0
0003o`000?oooooooooo0;;ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00gooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oo
oooooooo0;?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003o
o`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eooooo`;o00003_ooool00ol0
003oo`00ool00010ool00003o`000?oooooooooo0;;ooooo0_l00001ooooo`005Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0/oooool1o`00007o
oooo000=ooooo`?o00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`00
00?o0000ooooooooool0/oooool1o`00007ooooo000<ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00043oo`0000?o0000ooooooooool0
/oooool1o`00007ooooo000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`003_ooool2
o`0000Gooooo0_l0000>0000O`03o`000?oo003oo`00043oo`0000?o00000000O`0007l0/P0007l2
o`00007ooooo000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0
003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`003?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool0
0003o`000?oooooooooo0;?ooooo0Ol00001ooooo`003Oooool3o`0000Gooooo00?o0000oooooooo
ool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?ooooo0Ol00001ooooo`00
5Oooool2o`0000kooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2booooo`;o0000
0Oooool001Gooooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oo
oooooooo0;?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003o
o`00043oo`0000?o0000ooooooooool0/oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
00gooooo00?o0000ool00?oo0000@?oo00000ol0003oooooooooo`2cooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool03Oooool00ol0003oo`00ool00010ool00003o`000?oooooooooo0;?o
oooo0Ol00001ooooo`005Oooool2o`0000koooooA?l0002dooooo`;o00000Oooool001Gooooo00?o
0000ooooooooool0ooooool7ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0ooooool7
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0ooooool7ooooo`7o00000Oooool001Go
ooooool0000;o`00007ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.143078, -0.217504, \
0.0120503, 0.0204959}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify training and test image", "Subsection"],

Cell[BoxData[{
    \(\(crg1 = 
        ClassifyImage2D[trn, p1rg, 
          p2rg, {Red, Green}];\)\), "\[IndentingNewLine]", 
    \(crb1 = ClassifyImage2D[trn, p1rb, p2rb, {Red, Blue}]; 
    cgb1 = ClassifyImage2D[trn, p1gb, p2gb, {Green, \ Blue}];\)}], "Input"],

Cell[BoxData[{
    \(\(crg2 = 
        ClassifyImage2D[tst, p1rg, 
          p2rg, {Red, Green}];\)\), "\[IndentingNewLine]", 
    \(crb2 = ClassifyImage2D[tst, p1rb, p2rb, {Red, Blue}]; 
    cgb2 = ClassifyImage2D[tst, p1gb, p2gb, {Green, \ Blue}];\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show classification results", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{trn, crg1}, {crb1, cgb1}}], \ 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
%%ImageSize: 400 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0178571 0.47619 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0178571 0.477324 0.357993 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF80000000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0178571 0.97619 0.357993 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.392007 0.477324 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
10110910110811110A11110B10100E13131115161217181216170F16170F181810171810
181A10171B1014170D14170E15170E16180F18190F17190E15180E14180D13160D11140D
13170F131810141810131811151812181A13181913191913191A12191B11191B12191C13
191D14191D13191E121A1F13191E12191D11171A11171B131A1E141A1E13181B11181B10
191B111A1C111D1F131C1F131C1D151C1E171B1D161C20191C20191B1F171A1E16191C15
1A1E15181C14171B13181C12191C11181B111A1C121A1D131B1E151B1F181A1F181B1F17
1D20181B1E151A1D14191C14181A141B1E171C1F161C20141A1E131D20161B1E141B1F15
1C20161C1F161E20161D1F131C1D131D1E151D1E161D1E151D1E161B1D161A1D151A1D16
181B15181B15181B14191B131B1C141A1B13191B12181911181A111A1C13161711151611
15161015160E17171017171215151114140F16171216161215141011100B13130B13140D
13140C13150D15190D12170D10150C11140C0F12090E11080E10090E11090E0F070E0E07
0F110B0E13100E12140D10170E0E180F0C150E0C0E0D0E0B0A0C090C0E0C0C100E080B0D
010205000002000101000001000003010005000006000006000004000003000003000002
000001020001030101030000
3940383D453D404941414B4339403D23282B1B1F201C211C171B15161B12171B0F191F10
1C21121C20121D21121D20111D20121C1F111D20121D21121C21121C22131A1F131B2013
1C21141A20131B22151C22171E231820231A1F231A20231A2024182125172024171D2215
1D23171E2518202816232A19232A1923281922251822261924281A222718212617222718
242A19252A1A272C1C262B1D262A2024271F24271E242A20232A1D242C1C252E1C262D1B
282E1C262C1D262A1E272B1D262B1C252B1B262C1B272C1C272D1D262D1F232B1D232A19
252C1A242B1A262C1B262B1B252B1A292F1C282E1B282D19282F1B292F1D252A19262B1A
262A1B25291B272B1C2A2E1F2C30202B2F202C2F212D2F212C30222A2F22272C1E272C1B
272D1B282F1C292F1E2C301E2A2F1D2C30202C2E20292B1F2A2D202A2E2226292024261D
23261A22251923251926261C25261D22241C22241B2123191E21161F2115222516212416
2224152225152125151F22131D21121D20111D21111C20101C1F111C20131B1F121B1E12
1B1F12191F111920111F29190D100D0C0E0C0C0E0B0B0D0B0A0C0911150E13180F070905
060702060803050703040603060704060705060805050805050805050804050704050805
050804060903060803080803
94AA9699B19D9CB6A09DB8A08FA69040494812141A191D1C1316140F120E0E120911150A
151A0C171C0C171C0D181C0C191E0D1A1F0E1B1F0D1B1F0E1A1D0F1A1D111B1E121D2015
1E22171D22161D23181D22181D22191D23191D23191E23191F24181F25161F25161D2215
1E24161E25151D25131F26142126162226162225152124162224172022151E20131F2215
21251720261822271824291C25292023261F22261E24291F23291B262B1A272D19272C17
282C182B2F1D292B1E282B1D2A2C1E292D1D282C1B282D1B282C1C252A1A252A1A262B1B
282F1C2A311C262E1B242B1A252A18272D18282D17282E17282D17272C17242915242816
25291923271825271927291C292A1F2A2D212C2E212E31232C31222A2F20282D1D29301E
29311D2C331F2E34202E33202D31212E33232F34252D31222E31222E32242E30242B2D22
282A20282C21292E212C2F222C2F24272B2026291C25281B23251925271A242819232717
2426162527172427172327162426162325152427172326172024162125171F23171E2215
2023151F23131C21121C21111B1F10181C0E151A0F151911151813151A13161B1115190D
14190C14180D13160C11140B14170E171910161811131611121510121611121611131613
141912151B12141911131710
97B09E9BB5A49FBAA59DB8A19BB59D627367191D22151919161A17121612131810151A0E
171E0E19200D181F0E181E0E1A200F1C21111F22111E20101F21131F1F151E20181E2019
1F211A1F221A1E231B1A20181B21181C23191C23191E25181D25171D25151D24131F2514
222716222916222915222815232817242817232716232617242718232717222516222617
222618222619232719262B1E262A2023271E21261C232B1C252D1A282E172A2E16292C16
2B2D192F301E302F202C2C1F3030222E2F212D2F202E2F1F292C1E25271B25281C25291C
282F1C2A341E232C18242C18252C17272D17272D16272C15282D17292E1A262A18252817
25281925271B25261D27271F272720282A222B2E242D30242B31222A3120272E1D272F1A
2A311A2B321B2D331C2C321C2A301D2B301E2D32212D32222D30222F31233033242D3122
2C30242B2F242A2F222B30222C30212A2E1F282D1C272B1B27291A262919252A19272C1A
272B1A272A1A25271A24261824261824251925251B22231A21221922241A1F24181E2316
1D22151F25161E25151E25161F25171D2215181E12171D13161A14151A13151A11151A0F
181C0F171A0F17170E17180F191911191A13181A13161815141714131613161915151814
151913171C14161B13151810
8FA6949BB5A0A0BDA59FBBA39EBBA0849D88394540181C1D191E1A13191311150E13180F
141A0E171D0F1A21111C22131C20131F231521241722231622231721221B20221B1E2019
1D1F181B1F171C22191B21181C24171C23161C24151D26151E26142027141F2513202715
23291722261523271525291825291925281924271824281924291A252B1A252A18252919
23271822261822271823281B23281E20261E20261D242C1D27301D2A311A2B311A2D301B
2D2F1C2C2D1D2F2F212F2F212E30212F31242F30232F31222D2F21292B1E2A2C20282C1F
252B1A252E19252D18242B16262D16272D17282E182A30192B2F1B292C1C272A1B262B1C
23291B24271C23261C282A20282C21292D222B2F222C32222A30202931202A321F2C331E
2F351E30361F2F34212C2F202C30222B30232C32242E32252D32242E34242F33242E3323
2E33232E33242C32222D33212C321F2D321E2D321E2D31202B2E1F2A2D1F272C1D272C1E
282C1F282C1F252A1E262A1D272A1C24271A23251A2224192224192326192025161F2616
2026152228152127131F24141F23161D22151A2015181E15161D13161C11161D11181E0F
191E0C191C0C191A0D19190F1B1D121B1E13191C141A1D16171B15161A15181D16171B14
161B12171E12161B0F15180D
5D6959798B738DA58894AE929AB79897B5955F745E1A201C1014110F140E0C100A0E110B
11150D151B0F181E11191F131A1F141E231720251922271A222618212519202317202317
2023172023151D21141E22141F24161E23141E24131F261421271623281824291A202618
22291A222919212718242A1B252A1B262B1A272C1B272B1A252A19252918252A18252919
2326172025161F25171F251A20261D20271F232A1F262C20262E1E272F1B2A311C2B311C
2D321E2C301F2D31202C2F1E2D31202E33232F33242F31213031202E2F1E2D2E1E2A2C1B
292D1B272D1A242B17242B16262C17282E19292F1B28301B282F1C272D1C272D1E262B1D
252B1B242A19242816272A1A2A2C1D2A2C1E2B2D1F2C2F1F2A2F1F2B31212C33212D3422
3037243137253034262F32282F33292C31282B30262B31242C32232C32242C32242C3322
2D33212E33212B311E2D331F2F351E30341F3032202F31212D30222B2F23292E21262B1F
272D20242B1D232C1D242C1A252B18252A19242718232517222416222517212315212513
2226132126112024101C20111E21161B1F15191D16181F16171E12161C10141A0E151B0C
141A09151A09151A0A15190B181D10191E12191F121A20141B2114191F14171E13171D10
161C0E161C0C171B0D15180C
22281C2F3628424C3A5463496B815F839F75728B64242A1E10130E12180F0F120D0D100C
12160F151B10161D10191F121B22141D24161F251721261721251621241721241723251A
23271B24281B23261822241622251620241421261422271522261722251822251A21271C
21291B21281A22291A23291B242A1A252B1B272D1A292F1A282D1A252918252819252819
24281A242A1A242A1C22291C232B1E232A1D232A1B242C1B252D1C252F1A262E18293119
2A30192A2F1A2C301D2B311E2C321F2C32212F34263134263132223132212E2E1D2E2F1C
2B2F1B292E1B252C18242C18232C18222918232B1A242C18262E1A272E1C272C1C272C1C
272C1B262B19252817282A182C2E1C2B2D1C2B2C1D2C2D1E2A2E1F2A2F1F2B31202C3220
2E342130352332362731342930352A2E34282D32252B31212C31212C31212C32232E3624
2F36232F35222C321F2D332031352132341F3233202F301F2B2E1D2B2F1E282C1B272C1B
272D1B252B1A242B1A232B18232B16262C16272C19252918232617232717232616222615
2124151F23121D21111B21111D22141B2015191E14171E13171C10171C0F13170B15190C
15190B13170913160815180A171C0E181C0F171D0F191F111A2013191F13171D11161C0F
14190B141707141608121408
14190F191E131B20151B2115282F1E3C472E414F34262C1C2126191C2116171C1213190E
151B0F161D10171E11191F131C23151E241621261822261922271922251822241A24261B
25271C25281B24281A24261824251620241221251221251422251624271923271B24281F
242A1F22281D232A1E252C20252C1F242A1C242B1A272D1A292E1A272B19272A19292D1D
292D20292C20292D1F282E1F292E1E282D1B272D18262D16262E18252D18262D172B311A
2C311B2C2E1B2E301D2E311D2D311E2D33223035253033243132242E30212D2F1E2D301E
2A2E1C292E1A28301A272F1C262E1B2129181E2616212818232A1A262B1B272C1C272B1D
272B1D262A1B242719272B192A2E1B2B2F1B2A2E1C2B2F1D2B2E1E2B301D2C311D2C311E
2C321F2F34223238263237283036293036282D34242B311F2C321F2E34212F37242E3623
2D35222F36232F35232E312230322032342132332130311E2F301C2D2F1A2A2D192A2E1B
2A2F1B2A2F1C292E1C282D1C282D1A282E19292E1B292E1D292F1D242C1B222818232817
2125151F21131F22131F23141E22131E21131D20141A1F121A1F10181E0D181C0B181A0C
18190D17180C16170B16180A191B0D1A1D0E171C0E181D10191F12181D12161A1014170E
14160C1216091113070E1004
0E120A10140D12150E14160F171A131B21171E25191D23171B20141A1F12181E0F171F0E
161C0C161D0D181F11161C10181F111B22131F2515222717222617212517212517242719
25281A25281A25291B242719252919262B1A24291822271722271823281A23281B24281E
262A1F262A20262B1F272B1F25291E23281C262B1C282D1C2A2F1D292E1C282D1C282B1E
292C21292D21282C20292E1F2A2E1F2A2E1E282D1A252A16252B18292E1B292F1B2C321C
2E331E2F331F2F321F2E2F1E2E2F1F3133233236263134253335263133242E31202E3221
2D33212C311F2B321D2A321D29311C272F1B242D1A252D1A272D1B262B1B262A1A282D1C
292E1E272C1E242A1B252D1B28301B282F1A282F1C2A311F2C311F2C311F2C301E2D311F
2E331F2E341F2E33203236253338293238292F35252C32212C331F2C341E2C34202F3623
3038263137263034243032223132213132212F2F202E2F1E32331F30301E2C2F1D2B2E1E
2A2E1D2C301E2A2E1C292D1C2A2E1D292E1B282D1B2A2F1E2A2F20262E1F242B1B222919
2328172225162124152123162124162022151E20141D21131D20131D1F101D200F1B1E0D
181A0C18190C18190D18190C191B0B191C0B191C0B1A1D0F171A0E15190D16190E171A0F
14170C1115080F12050F1105
0B0F070E11090E100712130A15170F171C151A1F16191F15191F151B20151A20131A2113
1A2012181F10161C0F161C0F1A210F1C23101D23111F25131F2413212414232616222416
23251724261725281A24281C252B1D242B1E242B1D232B1C22291C21271C23291D25291E
262A1D272B1E25281B262A1B262A1B26291A2A2C1C282C1D2A2F1F2A2F1D2B311F2B301F
2A2F1F2A2F1F29301F282F1E282D1E292E1E292E1E272E1D282F1D2A301C292F1D2A301E
2C311F2E321F2B2E1D2B2E1E2E31213033243237273237273337283136283035272F3325
2D33232C32212C331E2A341C2B331B29321A29321B2B341D2B321D2B301C292D1C2A2E1C
2A2E1D292E1E282F1D28321C27321926301726301829321C2B321F2D33212F3321303522
2F34212D321F2D321E3034203236233539263339263036232E35212D341F2F361E2F361E
3138223137233036233035223236233032212E2E202D2D1F2D2E1E2D2E1E2C2D1E2A2E1E
2B2F1F2B2F1F2B30202C31212B2F21292D1F2A2E202B2F22292E22282F2028301F22291A
1F27161F26141F25132025142227162125162123162022151D1F131D1F131F21121E2111
1D1D0E1D1E101C1D121B1D12191B0E1A1C0D1B1D0D1A1C0E181B0E161B0E161B0E171B0E
13170B101409101409111409
060902070B020B0E04111409181B11181C141619131619121A1E171C1F181B1F141C2014
1B2013191F12181E10181F1019210F1C24111D25111F28131F27141F2615242919242819
25281926281A272B1C272B1E272C20242A20242B21262D22262D22252C21252C20252C1E
272C1C272C1B252919262918272B1A272A192A2C1B2B2E1D2B301F2B2F1D2C311E2E3420
2D32202A301F272E1F282F202A2F202A301F2A2F21292F2029301E29301E272F1D29301E
2A301D292F1E2C311F2B301F2B30202D322230362531372632382831382830362931372B
2F35272B32242A322029321E29321B2933192B34192D351C2E351E2E34202F34212D301F
2C2E1F2B2F1F2B301E2A311D29311A29331A28311A2A311C2C321F2F3322303523313624
31372430362130351E30351E2F341E3137213036203035213035233035213036202E341F
2F361F2E34202F35223137233036223034222E31212E2F202B2C1D2B2C1D2A2C1D292C1D
292D1D292D1E2B2F202C31202B2F1E2A2D1E292C20292D212A2F22292E1F282E1D212818
2029151F28131E26111E26112127142329172327161F23141C20131B20131E22141D2013
1C1E121C1E131B1E141A1C131B1D121D1F111C1F0F191A0D191B0D191B0D191B0C191C0C
181B0C15190B13180B11160B
070A02090C030D110512170B181D10191D1115170E12120C13161011140E12150D14190F
171D111920121B22121B22101B230F1C240F1D260F1D26111E26141E2416212617242918
242718252A1A292F1D292F1E282E20262C20242B21252C22262D23272E23262D21252C1E
262D1E272D1D282D1C292E1B292E1A272B19272B192A2F1C2C311D2D311D2C311C2D321D
2C301D2C2F1E2A2E1F292E202B30222B30232A2E222A2F222B30212C33222B34212A3221
27301D262E1C29311D2A311D2B311D2C331E2F36213138243038262E3724313927333A29
3139292E38262C37242C36222C361E2A341A2C361A2C351B2D341D2E341E2E341F2E3220
2D30202D31212D32222C32212C33202B331E29311C2A311C2D331E2F34202F35222F3522
30362031371E30341B32351D31351F3136203137213136213137243036222F33212E3320
2F34202F34213136243238253137243036232E34222C3020292C1E292B1F2A2B202B2D20
2A2E1F2A2F1F2A2F1F2B301F2A2E1F2A2E1F2B2F21282C1F272C1D272E1D272D1C242C1A
242D18232C161F28131E26122228152429172327162227172127171D23141C22131B1F12
191D11181B10171B11171A11181B121D21141D1F14191A1017170C1A1A0C1B1C0B1A1B0A
191C0A16190A131708111407
060903090B040A0D040B0F050D12061115071417081215090D1109080B05090C060F1409
12180C13180C161C0E1A21111C23121C24121D25131E26161F261820281922281A23291A
222918252D1928311B28301B28301C282F1E242C1E252D1F252D20262C20282E21282F21
2930212A301F2B321F2B311F2A2F1D2A2F1E2A2F1E2A2F1D2C311D2D321D2F341D2F341D
2E321C2F311C2C301D282B1C282C1D2B2F202B30212B30242B30242B31242D33242C3323
2A322028301D28311C29311B2B331B2C341C2F361F3037222F37222D3722303923323B24
313B26303B26303A25313C26303A222E381F313A203139203137202F351E30361E313520
3134223134243033242F33232F35232E35202C331D2C331B2C321B2D311B30351F303620
30361D31351C31351A33361D3539223338223037212F36212F37213037213036212E3520
3037213137223238253137242F35222F36232F34222D32212A2F21292B212A2C222A2C22
2A2E222B2F222A2F21292E1F2A2F202B2F222B3023292E20262C1C272E1C252B18252B15
252C15262D17252C162126122126142225152125162126182027191F27191F26181D2315
1B20131A1D111C1F121B1F121C20131F22161E20151B1D111A1B0F1A1B0D1A1C0C191A09
191B0A191B0A17190B131508
040503050703040701060900080B010B10021217061218081014050A0D020A0D040D1006
0C10060B0D050D110713180C191E111C21131F261521291921281A222A1B212A1A222A19
202817222B17232C17242D17262F1927311C262F1D252C1C282F1F2A2F202B30212D3222
2D31212E32212E31212D31202D32202E33222E33212C31202C33202E35212F3521303521
2F34202E34202D31202C2E1D2B2C1D2B2E1F2A2D1F2B2F212D31222D32242D32252D3424
2C35232C35222B34212A331F28311B2A331C2A341E2C351F2C36202F3922313B24303B22
323B23343C25353D25333B24333A23323921323922323922323722313722323922313621
3135203335213233222F32222E33222F35222C331E2B311D2C311B2C311B30361D2F361E
30361F30361E32371E343920373D24373B263237242F35202E351F2F351F313721313821
3038213239223037212E351F2C331D2B321E2C321F2E35212D33212B2E202A2D212C2F23
2C2F232D30222D30212A2E202A2D202B2E202B30212B301F2A2F1E292F1C272C16272C14
252B13272B16282D1A2427172125172226182125172026181F26182028191F26181D2315
1D21131F22152124151E20121C20101F23121E21121C20111C20121A1C0F181A0D1A1C0F
1A1C101A1C0F17180E13150B
030606040705040701040700030600070A000B0E010B0E010C0F010E1102101104101106
1012080E0E060C0D060A0C050E100814190C191D0C1E2411212715222A17242C18232B17
212A17212A18222B17252E18262F1A262F1C272F1C27301C29311C2B301C2D311F2D311F
2D31202E31213033233135243135243135243035232D33222C33222D35222C35212D3521
2E35223036223135232F311F2C2D1A2B2D1B2C2D1D2B2E1F2C311F2E33222F34242E3625
2C35242A34222B34212C35222B34202A341F2C361F2B351E2B351E2D36202F3821313A21
333B21353D23353C24333A22313821333923323822343924363B27353B28353B27323724
3236213336213335223134212F33222E33212B311F2B311D2B331C2B321B2D351D2E361E
313820303721323920333A21333B23343B24353C263239232E341F2F341F313721333A24
333B243239223037212F37202E361D2C331C2E351E2F361F2D331D2B311E2D31212D3122
2E32242E32222F31222C30222C2E232D30232B30212B2F1F292E1C272C18242B14232B12
232912242914282C1B282C1C25291C24281C2326192025191D23181E24181D23181C2216
1B21131C22141D23141C21121A1F0E1B200E1C200F1C21101C20101A1C0F16190D181C10
171B11171B1215180F11150C
0308050309030509010509000307000205000306000406000606000B0A01131207181A0C
17180C1212080D0F06090C03070A02090D030D1203141A071C220E212914252E19252F1A
26301D272F2027311F27311E26301D242D18232D162630182831182A31192D341D2E321E
2E31202F32233033263035293035283137293036282E35262D35242E36232E3823323925
3339233238233136233033202E2F1D2F301D30311F3132222F3323303524303524303725
2F37252C36232C36232D37232E38222F381F30391F2F371E2D341C2D341E2E341F2E3520
313722333B23323922323922313821333921323820343922373C26363B27373C27353B26
3439223639233537243235223135232E34232B32202A311D2A311B2B331D2A341D2E391F
30391F2F371E30381E31381F303820343A23363C26333A253036232F34222D3220303624
343C28333B27333B27333C25313A2330382131391F32391F2E351C2D331D2E341F2F3421
2F34242F34262F34262E32252D31262B2F252B2E242A2E21292E1D282F19262E17242B14
252A14262B17292D1B282C1C292D1E272B1D25291C24271C20231A1D20171D20171E2216
1E24161E24161D24171D24171D23171B21131A20101B20111D21121C20101B1F0F191D0E
171C10171B1015190D101409
040904040903060A01070B01070A000508000205000306000708000806000F0E02151406
1516081213060D0E020B0B000B0B010809000607000C0E021416091D211324281B292F21
2A33272A34292B362828332327331F25301A242F162530142833152B34172C321930331D
31342133342532342830342C2E332C2E352C2D352B2C35292E3727313A26313A25323823
353A2134382035382135372035362036382435372634352831332833372B313628303725
2F39242C36232B34212C35202F3821333B2132391F32381F343921343822333622323623
313624333826333824343B26353D27353C25353D23343C22353E25373E263A4128393F26
373A243638243637253335243134252E34252A332329322029331F29331F29341D2C381E
2F3C1D2F3B1A2F391930381A31391D343B21353C24353C2732392634392A32372A2F3428
2F3628313829343C28343D27323D26313C2330392030371E30371E30371F303621313522
3034243035272F34293035292E33292C30262C3126292E21282D1E28301D28301B283019
292E18292E192B2F1B2C2E1B2C2C1B2B2B1C2B2D1E292B1E2424192121171F20161F2218
1F23191E241A1F251B21271D21271E1F251A1D25171D23151E23131C210F1C210E1B200E
1A200E191E0C181B09131606
070B03080C040B0D040C0F030C0D030A0B01080A00090B00090A000909000A0B000A0A00
0C0C010C0C000E0D010E0D010C0B010C09020905020805020A070515151221221E272A26
29312B29332C29362B29372728372127341C2734182935162A35152D35162D32182F311C
32352333362733352930332A2F342D2D352E2D372D2D372A303A29323C27353C26363C24
373C23383A213B3C243A3B263B3B283A3A2A38392E36372E34362F33382E333A2D323B29
313C272F3B242E3821303920333C21373D22383C223B3E263C3E29393A2938392A37392C
35382C363B2D363D2C353D29373F29374128363F25343D22353D22383E23393E243B3F27
3A3D2A393B2B37392B3335293135282F36282B34252B35242B35232A352029341C2A3519
2C38172E3A17303A15323B17363D1F363C22363C25373F2A373F2D363E2E343D2E323B2D
2F37282D36242F3721313A20333D21333C1F313A1E31381E343920353823343724343626
33342832362B30352C2F352D2E342B2B31272A312529312229312129322028311D29321C
2B321B2B2F1B2D2E1B2E2F1D2E2D1D2F2D202E2C212C2B2128281F25261F21241C1F221C
1F251D1F251C1F261C20281D21291E1F271A1E26161E25141E26121C240E1C240C1D250E
1E250D1E240C1D210C191A09
0A0C050C0D050F10060E10060A0B03070801050700090A010B0C010A0C01090B00070800
0809000C0C000E0E040D0C040D0B030B09030905030904070803080C090E1515181D2121
242B2727322A28342827362428372027351C29351A2B36192E38182F361A2E351D303520
32362433372932362A30362B32372D313A2F303A2D2F3A2A313C27303B25333C243A4027
3A40273B3E263C3D263D3D2A3D3D2D38392D383A2F373B30363B32363C31343C2E333C2B
343D2A343E28333C25353C23373D233A3E243C3D273E3D2A3D3C2D3A392F393931383A32
353A31353B30363E2F353F2C37422A3943283A4227373E24373C24383C253A3C273B3D2B
3C3E2F3C3F32383D31333A2E323A2B313B292F39272E38242C36202C361D2B3519293315
2A32132B33142E3714313A1733391C33371F343B25353C28343E2B333E2D333E2D323E2B
313B262F39202E371A2E3717323B1931391933391C36391F373923373725353427323127
2F30272D31292E352D2A322C2A32292932262A33232A32212A31202D35222D34212C321E
2E321D2E2F1D30301F313021312F23312E252D2A232B2A24282B262529252127211D231D
1D241C1C241A1F271C1F281A20291A2029181F28141E27121F28111E270E1C230A1D2409
1E220A1F230C1E210D1C1C0C
0E120A0D100A0C0F080A0D05070904050703040601070A020B0E030A0D02080B00080A00
080A000A0C010D0E030D0C030A08020604010402000805040D0A0A0C0A0D0D0C11131519
1B1F21222927252F282532262633232935212B37202C371F2F371D2F361C2F361E2F3521
32352437392B35372D33372E353930343930323A2D303B2B303B27313D25333E25363F25
373F25383F25393E25383B253B3D293A3C2C3A3C2E393C2E373C30363C30343A2E353C2E
353D2E353E2D353E2A353C26353B23383B233A3B253B3B273B392A3B392D393930373933
333732353B32353D3135402E37432B3943293A4327384025383E26383D283A3E2A3D402D
3E3F2F3E40313B4132373E31353E2F343D2C333D29313B252D37202D361C2C3319293016
282F162A31162A30152C33152D34192F351D313721323825323927323929343C2A333B27
313A242F38202E371E30371B30371A30361932381C35391E363821363824363728323227
2D2F252B3026282E26282F272930262B33262C34252D34222C311F2D32202E33212E3220
2E321E2F2F1C2F2F1E2F2F1F2F2C1F302E222E2D242C2C252B2D27272B2523282120251D
1F261C1D251A1E25191F27181E26171E26151F27162026152026131E24101B200C1C220B
1E220D1E210E1E210E1C1E0D
0D120D0C100C0A0C09080A060A0C08070A07050703050801070901070901060801070901
080A01090B0108090008080007060005040004020008060315150E1818151A1A1B1D1D21
1F202622262A242C2C262F2D26322B2732292933252A34222C35202D351F2D341E2F3620
323723353827383A2B37382D35372D34382E33382D343B2E313B2B303B28323D28343F26
363F25363F24373F24363D23393E253A3E283A3E2B3B3F2E383E2F373D2F373D30363C31
353D30343E3135402F333E29333C24353C22373C23383B22393B243A3B273A3B2A393B2E
373A2F35392F353B2E37402F37422E39452D3D482C3D47293C46293C432A3D412B3D412B
3D402C3E402E3E42303B40313B4232384130353F2E333C2B2F37252C331F2B311C282E19
292F1A2A311A2A301A2B321A2B311A2C311C2E331F313621343925353926353A27323825
313724313824323A24323D23323B2030391C31391C32381D34391E353920383A24363826
3334253033272D30272B2E252B2F252C31252E34262F35252C33232D33242C33232D3321
2D321F2D311E2E311D30311E302E1E2E2B1E302D202E2D212C2B1F2B2C1F2B2C1F272A1F
23261C20241B1F23191F24191D24191C24181F26191F25182025172024161E22121D2211
1F23111E22101D20101B1D10
0A0E080A0D09080B07080A05090B06070904050803070A05070904070803090A04070902
060900070900050800040600030500030400020200030300080904171A132E3429353B31
3135312C302E2A302F2B32312F38332C3630283129252E23252E1F252D1C262C1B282E1A
2A301B2C321D2F342131352733362A35382B33382C353B2E323A2B303929303A27343D27
333A25343C25343C24333B22343C23353C25363D28383F29363E29353C29363D2B363C2C
373D2E373F30363F30353E2D363E2B363E28363E27343B23353B22363B22373C23383D26
393D28393D29363C29353D2938422C3B452B3C452A3A432A3B432B3A422C39402B373D29
383E293A3F2A3B402B3B412D3B42303A412F3A4230363E2B3037242C33202B311E29301E
292F1C2A311D2A301B2B311C292F1B272D192A2F1A2C311C2E311E2F331E2E341F303620
333922343B25343C26363F28364028333E23323C2130371D2E341C30361C353A20363A22
3537223335243033252D2F232D2F232B2F222B30242D32252B3224293124283023293120
2A311F2B301E2D321D2F321D2F2E1B2D2B1B2B291A2C2A1A2E2D1A2B28162B291729291A
26281B24261C22241C21231C20241D1E221C1E231C1D231B1D23181B21161C21161D2215
1E23152023151F21151B1D13
060A01070A02080B030A0B040908020808020B0D050E110A10120B0F0F0A0F110A0D1007
0B0E03090B01060900040600040600030500020300020400010300070A06273021323C2B
333A2D373F33343B3131372E353D31353F33242A241D231C1A20161A1F131B21101E2311
2126122226132529142B301D2E3423323828353B2A39412D39412D353F2A363F28384028
373F27393F28393E29393F29383E29383E2A373E29383F2938402A383F2A383F2A373F29
383F2A3A402D393F2F383E2F393F303A402E3A412C363C26363C24363D23384124384123
384024383F25384027373F273841263942263B42283B422B3D432E3C42313A4030373C2C
363C2A363C2A373F2A39412B393F2A3A412B3B432D383F2A343A263037212C321F2A301F
2A301D2B321D2C321E2C321D2A301C282D1B2A2F1C2A2F1C2B301C2B311C2B321C2E351D
333A20343B22353B24363E27373E29363F29353F28333B2430371F30371F31392030371F
2F35203238223136232E33212E32212C311F2A2F1D2B2F1E2C32212E35252D33252C3224
2D32242B2F212C32202E34202E321F2C2F1D2B2B1B2929192A2C19282915262713242614
25271724261822241921231A21241D21251E22271E1F251C1D231A1B21181D22191B2117
1C21171E21181F21191D1E17
050A02060A01080B010A0B020A0A01090A020D100811150C151910151810151911161A10
13180B0C1006080B030508010507000507010405000204000305010306010B100614190C
1F24153B452F373F2B303625373F2D3741301D231A171C1510140F0E120A0F1308141709
191C0B1C1D0E202111292D1B2F3522343A28373F2C39422D38412C38412A3A432A3B4429
3C44283F442A41452C40452D3E432D3B412B3A402C3B412C3C422D3E432F3E442F3B432C
39412B39412D3B412F3D422F3C41303D422F3C422C3B4029393F283A41273C45293C4529
3A44283942283A43293B43283B44283B45283F472B41482E4248324147343F45343C4332
3A3F2F363C2A373E2A383F2A373F273A412939412B3A412E3A412E363D2A2F37252E3423
2C33222B331F2C331E3036203036202D331F2C311E2C311C2C321B2C321C2B311B2B321C
2C331E2D341E2F3720313923323A25343D27354028374028333C24323A22313823313723
3037233038233138233139242E36232D35212E35202D331E2D331F2F36253138262D3423
2C32212A30212C31212C32202C311E2C331E2D331F2B2F1E2A2F1C282D18272C17272B17
272B19262B1B25291A23271A22271D23281D22291D1F261A1E25191E25171D24161D2416
1F26182025192024191E2017
050805070A06080C040709020608010608010709040A0D080F130C12170F151A13171D14
151B110F140A0A0E04060900040801040601030501010501010401040902080D030A0E02
0A0E02161B0C1E2213202415333A273D48332C362721281D15181311130F100F0B10100A
12130C15160E1E2015272B1C303623343A28383F2C3A432F39422D38402B39412B3A422B
3C442A3F452C41472F3F46303C422C3C412D3C422F3D43303F45314047323E45303E4631
3D45313C45323D46313F45303F432F4044303D412E3C412E3B412E3C432F3B442D3C472E
3D472F3D462E3D462B3C46293E472A3E472A3F482D414830424734424836424937424938
3F45343C432F3A402D373E2A353D29373F2A39402B3B432F3E46323B4331363D2D31392A
2F372A2F37273039252F38253038222E371F2E351D2D331B2E351B2C321A2B31192C311B
2C311C2B301D2B301D2C34202F3823313C26313E27333F28333E28333D26333E25313B25
2F38222E36202F37213139223139232F36222E35222D33202C31202E33212F35222C3321
2C31212E33242C31222B2F1F2A2F1E29301E2B311F2B331E2B321C2A2F19292E18282D17
272C17262B18262A1B24281C23281D22281D21291D20291B20281A1F26171E26151E2516
1F2617202717212818202417
0B0E0E090C0B0A0D09070A040406010304000204000608030A0C070D110B10140E12170F
1317100E130A0A0E04070B00040700040501030401020401030503070905080B04060901
050701060701080B030B0E05151A0F232C1C212A1B1E25181D21141D20141A1C12171912
1718131617101B1D1522271D2B3025303629353D2D39413038402E373F2B373F2A39402B
39412B3A412D3C442E3E47303E47303D442E3E45304048333F4731404933404933414933
424B344048333F48323E462F3F452E4147303E432F3D43303E44323C43323D44303E4730
404A323F49313D482D3E492C3E4A2B3E482C3D462E3F472F414934414836454939444938
444A374148344048363D4535384030373E2D373F2C39402C3C432E3E452F3B422D393F2D
383F2E373E2D363D2B323A28303825303A242F38212F371E2F361D2D331C2D341C2E341D
2F331E2E321F2C311E2C321D2C34202F39242F3B252F3B26323F28313E28313D25323B24
2E39222E37202C351F2E36212E38233038243037242D33202C301E2E321F2F311F2F3120
2F32212D30202E32232D31232B30222A30242930222931212C32202C321E2B311C292F19
292F18282D17272C1B25291B252A1D24291C22271B22281B23291D23271A2025171E2416
1D24151D24141E25161D2316
13171C0F14180C1113080B0C0608070407040305020608030E12081014080D12060D1105
0F12090D10080B0E060A0E04080B02070902060702050501060604080905070802030400
030300050502060702080A04090B040D11080F140B10140B12150B12160A14180B1D2214
23281A22281921271A232A1E272F242C3428303A2A343D2C353E2B353F2A37402A363F29
363D2A373F2B3A432E3C462F3C48303D4830404A32414A32404930414A32434B34454C35
444C35414833404833414931414A32424A324147304046303E45313D45313E46303F4931
404A31424D34414C333E49303F4B313F4B31414A32414A333F4A33414B33424933444A34
4349324348314147324146343F44333D43313A422D39402A3D42293D42293E432A3F442E
4247323F44313B3F2F363C2C323A29343D29343D27333A233038202F361F30371F30361F
3035202E33202E34202C321F2D33222C33232C35232D36232C37232D38232E3921313C23
333E23333C23323A223038222F37223038243238252F34222B301E2D311F2D311F2E3120
2D30202B2E1E2B2D1F2D30202C30212C31242B2E232C30242A3122282F1E29301D282E1B
282D1A292E1C292E1D272B1C25291B24271B23261B21251A2125192125191E23171D2216
1E24161C23151C22151A2114
192026192026181D251418201013190C1013090C0E0C0F0E1014100D0F090A0C040C0F05
0E11070F12081012090E0F060C0D040B0A030A09030A09050A08060A0909050505030302
0201010202010708050B0E080E11090C0F07090C050A0D060B0F06080B03090D040F1409
1A2112232C1A2A34202E3724303B28323D2C313B2B303927313A27323C28313A26323925
333B27343D2936402B37422B37442B39462D3D49303F4830424B33444D36444C37454C39
444B37454C37444E37454E36454F36464D35444C35444B364149343F48323D4730404B30
414B31424D34414C343D4A323D4B323D4A303E492F3F4B303E4C2F3E4A2D3F492D414830
40462E4348304348324346324246324247333F462F3E462D3E45293B40243D422641462B
43482F4347314044313E44313C42303B422E384029353D25343B24333923303521313622
2F33202F34202E341F2C321E2B30202C32222F35252E36242D37242E38252E39232F3B21
323E22353F22363E23343B223037212E34212F35243036252E33212C311F2C311D2C311D
2C311E2D311F2C2D1E2C2E1F2D30212D2F232C2F232D33232B3222282F2029301E2A2F1C
292D1C2A2D1D282B1C26291C24281A24271923271C1F241A1E24191E241A1E241B1C2219
1C2318191F131A20131A2013
232A2F232A2E21282B1F25281D2326181E2015191B1418181113130B0C0C0A0A090C0F09
0E13090F13090F12090D0F06090C040A0C040B0B040C0D060F0E0B0F0E0F0C0D0D070809
0404050304040B0E0B10141010140E0C100A0B0E07090C060B0E07070A04060902080B03
0A0D0413180C2229182E3622343D2739422D38402E363E2D353D2B333B2A333A2A2F3627
2D34272B32272B35272E3928313D2A36422C3A462F3D4730414A33434A36434A38434B3A
444C3A454F3A455038465138455037454E36444E36454F37444D35434B33414931404A30
414A30434C34424B35404A35414B333E4A2F3D4B2D3F4D2E404D2F404D2F3F4A2E414A30
4147304347334347344144334045334046333E452F40482E3F482C3E452841462942472A
42462B41452D4145303F43324145334147323D452D3A422A384027373D263439242F3521
2C311F2D32202F34202D311D2C311E2C311F2E35232F37252E37262E39272E39272E3924
2E3A22313C22343E23353D233239232F35222D33212F35242F34232E34222E34212D3320
2C311F2B301F2A2D202A2C1F2A2D202C2E222C31212B31202B3120292E1D292F1C2B311B
2B301B292C1A272A1B262A1D23261A21241820251A1F251A1F261C1F261C1E251A1C2317
1B22141A21121B20111A1E0E
23292E262C30242B2C222928232927242A27212726202626191D1F1316180F11120E110F
10140E11160B1014080D11050A0E02090C030C0E050E11060E11090E100C0D0F0D0D0F0E
0909090709070E120D14171211160F0C100B080B04050701060801070902070902070A02
0608010B0F0613170C1C1F13212417272A1E343B2B3C44333D47343B4433374031323B2E
2B3329252C2321281E1D231B232B1F2D3927343F2B3A452E404A32434D35434C36414936
414A37404936414A36434C37454F38454F3947523C48533A465036444C33444C33444C32
434A30454D34444D35444D37444E37424C35414C32414C30424C2F424D2F41492F434830
434733434736444838434738434838424836414934424C32434D32434C30444C2E444B2C
45492D41452C3D422D3D42323D44343D45313C452E3C452D3C442B384028363D26323823
3035232E32212D31202E32202F33212F33222F35243139272E38262C37252F3A272F3A27
2F39242D3822303B22343D24333B243338243338262F35252E3424303625313726303624
2D33212B30202A2F22282D21282D212A30232C32222C32202B301F292E1C2A311B2B331B
2B321A292D18292A1A27291D24261B24261C23261C1F231A20261C21261C1E25191D2417
1E23141D22111D21101B1E0D
282D30292E32262B2E242929232827262B29262B2A242A2C242A2C2026281C2122171C1B
161B1512170D0D11060B0E020B0F030B0E040C10050F12070F11080C0D08090B070A0B0A
0B0C0A0D0F0A11140D14180F12170C10140A0B1004070A00060900070901080903080B04
080B050809060B0D0A10131014161315181521251E343D2F3C4634404B37414C39384231
2C3426262D201E241A171B151519131D231A262D21303A2A38442F3F4A33404B333F4832
3F48333F4733404833414835434A38454C3A454E3A444F38444F36424E34434E34434E32
444D30444D30464E33464D34444C34414A34414B34424C33414B31404A31414B32444B34
454B36444937444836454938464B3A464B3A454C38434B36424B35434C34444E32434C2F
42492E41452C3C412A3B3F2C393F2E3A41303A41303C44313B432F38402D39412E38402C
353B293136242E33212F35212F36202F35212E34223037242F37252E3824303B252F3C23
303C232D381F2D371F2F3921323B23333A253238253035242D33212D33212F3622313724
3137243035232D34212D32212A30202A30212B31212C33202A2F1C292E1B2A301D2B311E
2A2E1C2A2D1C2B2E1E292C1F26281E24271E21241B20231A2024191F22181F22171C2113
1E22141F23131F22131D2011
272C2A2A2E2C2A2D2D292B2B282A28272A27282C29282C2E262A30272B31272C2F262B2B
212723181C1710140E0E100A0F100A0F0F0B0D0C0A0E0D0C0E0D0C070607030304040505
040504090C0612170C181D0F171D0E11160A0C1003090C01090C02080A020A0C050D0F08
0B0D080A0B070909080C0B0B1110111413121616131C1D18272A2133382B3D4434363D2F
272D2120261916190F171A11171A13181E151F251B2730232E392635412B38452C3A462D
3E482F3F4932404933404835404736414937414B37404D36414F36435036444F35444F31
445030444F2F454F30444D31444D32414A32404A323F4A323F4B323F4B31404A32424B34
444C36454B36454A37454A39464A3A474B3B474C3B424935424A34424B32424C30414B2E
41492D42492E3F442D3C402C393D2D383D2F3A40313B42313A423239423039412E37402B
374129343C25323921333A212F361F2D341F2D34212D36242F37242E38242F3B232E3A1F
2F3B1F2F3B1F2E391F2F3A20313B21333C243138233137242E34222E35212E351F313721
353A24353B243238242F35212B311F282F1D282E1C292F1C2A301A2A2F1B292E1C292C1E
2B2E1F2A2D1F2A2E20272A1F25271D23251C22251C21231A2022171F22161F22151E2113
1D21121F23131F23151C2114
202723252C242A2F262D30282E2F292C2D292D2F2C2C2E2E2A2B302C2E352F3238313639
2B31301C2120181A19151415131013110F130D0B110B091007060E05040B030307040505
0305030507011218081A200F171C0C1215080C0F05090B020A0C040A0D070F110B12140C
10110C0E0F0B0C0C0A0D0C0C1311111715141614131413121818141B1B1722241D24271F
1D221916191210110A12140C1B1F1421281B242B1E232B1D242D1D26311E2A3621303B26
37432B3D4830404C34414B36414B36424D37424E36435136435235475437475237465135
465135465133465034444E33424D31434D33434F35434F35424E34414D34414B33414B33
434D36444D37474D38484E38494E394A4E3A4A503B4B523C494F3A474E37444C33434C32
434B33444C34424A334248324146333F44313E45323F49333F49333D46313C453039442D
39472D38452B374227364024323C203039203039212F3722313A25323B26323C26323C23
313C23313C24313A23343C25353E26363E28353C27353C2831382530362330372030371F
353A22363C23353C24333B232F37202C341E2A321C29321C2A311C2B311D2A2F1C292E1C
2C311F2B30202C3221292E1F25291B25291C262A1F25281D24281C23271C21261A212619
2027182027171F2617202517
171E1E1A211C1E241B22251C262821292B252D312B2E312E2E31312E32342E3437323A3B
313938272D2D2025251F212419192114141E11111C0F101B0A0A1506051003030B010205
0103030305010D1106161C0E181D0F16170D11120A0E0E080D0D090E0F0C131412171915
171A171216140E10100E1011121313151516131113110F1112121111110F131410171912
15190F11130A0F10070B0B0216190C252B1A262C1E1D2319191F16161C13181E131C2416
242D1C2C362234402A39442D3C482F3E4A2F414F31435233445033465136475138464F37
485238475237455135455136445035424E34434E35444E36434D35434D34434C34424B35
424B36444B37464C38474B38484C39494D384B4E3950543F5155404D513C4A4F3A484E39
464C38444B37444B37434B34434B334148304048304149314149324147324047313D462F
3C47303B462F38442B364227344022313D2030391F30391F303A21323C23343F25343D26
333C26313C26323B25343B27353A26363D29373F2A363E2A343E2A333D27333C232E351E
2C321C30361D30371E30381F30381E2D351C2B3219293018282D17272C19282C1B292D1D
2B301F2A2F20292F202A2F20272D1D232A1A24291B23281A21261822261921261A20281B
1F281A21291B202719202517
1B20221A1E1E171C18171B141A1D1720221C282B232C2F282F332E3036332E35342D3436
3038382E3735282F2E272D2E252A2F24292F24263122242F1C1E281415200E0E18080911
04060B0305060B0F0A14180E161A1012150D12130C12110D12110E1413111A1B171D211C
2025221F25231C221F1A1F1E1A1F1E15181A0F11140D0D110D0D0E0C0E0C0D0F0B10130D
10140C0E11080C0F050A0C021A201029321E29331F1F2719191F1414180F12160C12160C
15190F181D101E2415242C1A2C36203440253C482B414D30455033465135475037475238
485336475235455334465437475539465238455138454F38444E37454E37464D36484F37
4A5038484E3A484E3A464C38474C39484D3A4A4F3B4E523C4E523A4E513A4C513A4B513B
4A4F39454E38454F38434D34434D33414B304047304147304147324248344248353F4634
3E46343B443138412C374229353F23313C1D313A1D313A1F313B20323D23364025343E24
323C24313C24323B25343B27353A29353B2B363E2C343B29353C28353E28353D27313924
2D351F2B341C2B351C2A331B2C351C2D361C2B321A292F182A2E192B311E2A2E1E292E1F
292F20272D1F292F1F29301F272F1E252D1A232B182029151F27142128162329181F2717
1D24161F25191F25181E2415
1F22221D2020181C1B161A17161A14191D151C1E151F2119232520282A272B2F2C2C3432
313A38313A362B34302B32302C33332E33343033373033392E31392B2E37232730181C25
10131B0B0D120B0E10101410151A1115191113150E12130D13130D1617101A1B151A1C18
1D211E202724252C27252C27272E282026221519181011130F0E100D0C0E0E0D0E101110
0F13100F120F0D100C0C100911170B181F0F1A22101B221119200F161B0E13160A12150A
13150B12140A12150B13170C1B22112229142C331B3942273F482C434D31465033485134
48523347533647523747533849553A49543A48543B47533B465239454F37444D35485038
49513A48503B474E3B474D38474D38484E39494F394C523A4C50384B50384C523B4C533C
4B523B465038444F36434E34434E34465136444F36434C34434B34434B35434934414735
4048343C44313B422E3B442C384227353F22343D20353E20343E21343D21353D22363E23
363E24353E26343B26323825353C28343A27343B28343C28353C28353C27343B26323B25
313B242F3A222E3A202D381F2C351E2E361E2D331F2C321F292E1D2B30202B3022292F21
282F20282F1E272D1D262D1B272F1A232C17232C16232D16232C16232B16222A16202815
1F2715212917232A181F2516
181D1C1E21201C1C1E17181A171816181A16181914191A151919161918171B1C1A202521
28302A2D362F2E372E2F38312D35312D33312F333430333831333C31353F2F353E2B3239
232A301D2227171D1F171D19181E17151A1413171012160E15180F171B1216191011140E
121510171C1721261F292F252E342A2E352B242A241C1F1C1819191311140E0E12100F13
0F1113101313111413111712121910161D0F171F0C171E0B171E0B151A09131708111506
1115061014050F140510140615190A1518081A1D0A292E17373C2240482B465032495235
49533647533847533746533848553A49553A49553C47533C47533C455139444E38454E3A
47513D49533D47523A454E36464E35474E35484E36484D364A4E37494E374A4F3B484F3C
48513D46503A444E36434E35434E35434D35434D34434D34444E36464E38434A35434835
444A364047333B43303A422E39422C353F28354026374224364022363F23373F23394125
384024373E26363C263339253138252F3523303625333B28343B27333A26303824313923
323A23333B23323A22333B212F361E2D341B2E331E2E33222D32212C31222C31242C3224
2C32222B311F272C1B252B18272E19252D18252E19242D19242C18252C19232B18212916
2028151E26121E26141F2415
1B201F292D282526251F1D201A191D19181C181619171618151314131211111311131712
181E171E251B272F212E362830372C31362E2F332F2F323231333834363E34393F32383F
2F373C2B3436252F2F2028271B2220161B1A161A18171A16161A15161A141418120E110C
0D0F0B10130E1B1F1722261C262A1E2B2E222D32282D312A292E292427261D1F2317191F
12151A1114181519181A201A1A21181A2115171F0F181F0D171D0C1319081217080F1406
0E13050E110310150513170715170912130712120519180722210E2C2D193B412B444D34
47513749553B4A563A49563849573747543647533848533949553B47513A46503B454E3C
47513C47523C48533A455034444E31454E32464D33464C33474B33464B34474C38474E3B
444C3A444D38444E36444F35434D33414A32424B33424B32424933444B34444A33444934
454B37434A373F47373C433539413236402E343F2B344029333E25333E22363F22374024
353E23343B23353B253338253137252E34252D32242D33242E3623303824313823303822
2F382130372030371F2F361E2D341C2C321A2D311D2C301F2B2F202B2F222C30232C3121
2C31202C3120292F1F262B1B252B1A242B18222A17232A17262B1A262D1B262E1C242B1A
2127171E25151E24131D2211
53635749554B353C363136322C2E2E28292B2221241E1C1F1B1A1A18191414171012160F
1318101519101C1F132224172A2B2230332C31342E303331333638373A3E373B41373D44
333B41313A3E2E3739293132232A2B2127282125271F21221C1F1E18191B1314170E0E12
0B0B0E1012121C201B1C201A181B13181A121F221A252A22292E292B322E2A312E212726
191F1E181E1C1B211C1B221A1C241A1A2016171C10191E0F191E0F16180B121409101208
1011090E0F0810110813140A15150C15160C1414091715061B19081C1B0A292C19393F28
4148304850344C54384D56394B573A4B573B49553B49543B48543A49553B49543A47523A
485138485038485037464E34454D34464F35454E35464E35454C33464C34464C34474D35
444A34434934444C34434B35444B35444C35444B34444A33444A35444B35464E34454C34
454B354449364248373F45383C4235394132363E2E323B2A303B26313D24323E23333D23
323C23313A24333B253339242E35212E34202F36222D33202D33202F3522313824313823
3038243038242F37232D35202B331E2B341E2C341E2B321E2A2F1D2B2E1E2C2E202C2F20
2A2F1E2A2F1F2A3020282F20252C1D222A1A212918222917252B1A242A1B222A1B232A1B
22281A2228192128171E2310
71867D72867C65776F5E6D6557625D4C5452454C4A3A413F282C2923282022271D22261D
24281E24261C2222191F1E182320202B2A2B2A2A2B2A2A2C31323335393A373B41394044
384145343D422F383B2C35382B32342C34332F38342D33322A2E3024252C1A192313101B
100D1715131B1B1D20161A1C1113130D0E0C0E110E1316131A1E1A212723252C27232A24
1F2720232C23242E24202A201E261B192014171D10191E101A1E10191A0C14150913130A
14140B1010080F0F08100F0911110A13130C14140D212315282C1A292F1B2C341E343C23
3A412541472A464C314B52384D543B4D563F4B554149554049563E48543B4953384B5538
4D55394C53394D52394A4E38494D38484E39464E38485037484F35484F34464E32444B30
444A31454A32484E35474D37484E3A474D3A464B38454A38434A38414936424C33434C32
444C32444A324348334247354045353F44343C4131373C2D323A2A323D28313D24313C22
313C21323B21343D22343B22323920313820333A22333923323722303622303522303623
3037252F38272E38262E38242D37242D37232C37222B35212A321E2C311F2B2D1D2C2F20
2D31212C30232C30242B3024282F23232B20232B1E232A1B242B1B252C1D22281B1F2719
21271A2128182028161E2612
7E928983968E85989283959081928F7A898877878470807E596768515D5D55615D5A675E
5A665A484F4834373636383B33343B2C2C332221271E1C2122202328282A303234343839
363D3D363F4031393C2B33382D3538313A3B353E3E363F3F384041373A3F2F313A252633
20202D20212B1E202714151C1012150E0E0F0D0D0C0F0F0E11110F131411171B171A1F1B
242C25283229293429263127212A1F1C23171A21131A20121A1F12191C0F16160C16160C
15170C13130912120912120B13130C100F0B100F0E30362A4A58434D5E464B5C4246543A
414C313E472C3F472D434A31464D3647503A4A533E4A553E4A563D4A543B4A53394B5339
4D543A50573E4F563D4E533B4C503A4A50394B513A4A5139495036495034484E34474D34
474C34484C33494D35484D37484D39494E3B464C38444A35444C36444D36434D34434D33
444E34444D34454C34464C34454A354549344145323D42303A402F363F2B343E28333C24
333C23343C23343C24353D25353D25333C24333B25333925333A263139252E36232D3522
2C35232C36232D38242E37242D37252D38262E38272D37272D36272B32242A2E212A2F22
2C30232C2F232A2E23282E23262C23252B22252B21242A1E242B1D242A1C22271A212519
2026182128182027171F2415
82968C8698918A9B988A9A9C8A9A9E88979D86979A8697988495987F90947F9292829793
82978E798B826C7B746F7E775C67652C2E381B19241A191F1513191614191D1D1E262826
2F3330343938353E3C323B3C3943423F4A493F4A493C46483B44483A4147383F46353C45
3239432E353F242934191C2713141E1010161111131111110F0E0D0E0D0C0F0F0C11140F
232A22262E26293127293227242C232129201E261B1C22191B20181A1F17181C14171B12
15180F14170C15160C18190F1716101616101F20182A2B23464E3E515F4A53654C53644A
50614549583E455337434E33434E32444F344750374C543B4B533C4B533B4D563B4D573C
4B553C4C573E4E573D4D563B4D56394D54384D53384C523A4C513A4B503B4B503C4A503C
484E3A474D38474D35474D35464C35474D37474D35474D34474D34454D36444D37434D36
454F37454E37444B36434B35434A334349314148313F47313F46303C432D3A412C353D28
333A27323A26333C29343D2A323C2A313C29303B27303B26313B27313C27303C262F3A25
2F39252F38242F39242E36232D3625323A2A313A2C30382E30392D2D35282C32252A3023
2A30232A3022293022293022282E20292E212A2E21292C21262A1E24291A212417202418
20241923261A24271B202319
80948E869A948A9B9A8B9C9E8C9DA18C9CA38A9A9F8A9A9C8A9B9C8B9D9D8A9F9E8BA19D
8AA2998BA3968AA1928CA1927E90843E43481A19241C1B2117151A141115131113171616
1D1F1D2225222C332E323B363B453F404C443F4A443E47463D45473B4348384048384047
3A434C3A434B3740483036402327311D202815171D121217100F130F0D100F0E0E141614
252B24222922202720252B22272E22242B2022281E1F251D1E241E1F241F1F251E1D231B
1B20171A1F15191E131A1D1319191118181223231B23231A3F433456624C505F493E4B3A
43523E495A414D5F414A5C3B47573547543345503147503449503849503848513849553A
48563A4A573B4D5A3D4B573B4A553A4C553A4C543A4C523B4B503B4B503E4B513F4A503E
484F3F474F3E464F3A464F37464E36474F36464F34474D32474C34464B35464B38444B38
444C3A434B39434C3A424B37414933424830414930424B304349304247303F45303C4330
393F2F343B2B313A2A2F392A2E392A2F3A292F3B26303C24303C23323D23323C24323B25
3239243137243037233036232F36242D33222C342530382A2E38292E37282D36242B3221
282F1E272E1E29311F29321F2B321F2A2F1D2D2F1F2C2F21282D1F25291C212417202217
20221A23261D22251D20211C
7F958D879D968A9F9C8B9F9F8DA0A28D9FA28C9F9F8DA09D8C9E9B8C9F9C8DA19C8CA29B
8CA49A8DA59890A79891A8958FA5926C7C712E3235222426202020181718151314141212
1413111818151C1E1A1E231E282F28303830373D363B413C3D43423E45473E46493F474A
40474C3F464C3E464D3F484E3C454A373F422C303424252A1F1F251A182014121A1E1E21
2327261A1E1E171B181B211A22291D22281C2025191F251B21271E21281E20271C21281B
20281B20281A1F25171C1F1419191216151318181519191645503E5E6F5544513F2D352A
2C34282B34253E4B324C5F3D50623E51623F4C5B3B47533847503848513B47513D454F3A
43503A44523A4A573D4B573E4A563E4B553F4B533B4A513A474F3948503B49523D49513D
48513E474F3E454E3D46503C46503A475138464F35464E34474F35464D35464D35464D37
454D39444B39454D3A434B39414935414A33414931434B31434A3142482F414730414832
3E453139402E343D2B30392930392A2F3827303A25303B22303A2030391F313821303822
2F36222F37222E36213038232F37232D35222B35212E36232E36242F37262F37252D3320
2D32202A301D272E1C252E1C252E1D282E1D2A2F1E2B301F292E1F252A1D2025191E2317
20241722261B20241B1F221C
849B9189A0988AA29C8BA29E8BA09E8BA09E8BA09C8A9F9A8B9F998DA09A8DA1998FA39A
90A59B90A69B92A89B92A79994A999889C8C5D6B63383F3D3034322021231C1B1E191719
161515171614181913161712191A151D1F1925272134362F3B3E383F443F424844434A49
454E4E444E50414B4E3F4A4C3F4A4A4047494046473D4144393C40313139282731292A30
24252A14141B101117121515141814151915191E171C21191E241A1E25191D2417202617
212918232A192226181F22171E1E181C1C1A1E201F1D2120242A262E372D252C24262A22
23271F1C1F171B20152C362446563B536749576A4C54654A4E5C4349553F424D3B3C4636
3A46363D4938424E3B46533F4855414A574249554048553C49553A4C563A4A5437495237
4A5238484F3B464E3C47503D47513A47533A454F35444F33464F34464E33454E34454C34
474D35464C36454B37454C38444C37444D36424B34414A33414B32424A3040482E40482F
3F47303E46313D45313A412F353C2D33392A323927303726313926333B25323A24303824
2B34212B34212B33202E36212D35212E35222D34212D34212E35222F35232F3623303722
2F36212D341F2B321F29301F272F20283020293020293120262E1D252C1C21281A1F2518
2127172126162125171F2318
81988F879F9588A09888A099879E9889A098889E97889C948A9F968EA29990A39B91A59D
92A69D92A59B93A49B95A59C96A79D93A59B899B91798A8057625F383C402E303524242A
2221231D1C1A1B1A161818151615121615121513111D1A1525231D2F302A393D36404640
424B47454F4C404B4B3D48493E494A40494B43494C44494C43484C43464B41434B3C3F48
2C2E391E1E2A1416200F10180E0E150E0F131012121519151A1F191E221B1D23191E2418
212819242A1B24281B24261D262822282929282A2C212527191C2017191C17191C1D1F1D
1E201B1B1C19181B17171B1721281E323D2D3E4C374D5E4457694D52624A3641312A3326
262F232831242C35283743313E4B3545523B47543D48543D49553B4B593A4A5637495435
495335475037485139485039454F36465038465037465035454F34444E33454F34454E33
464C31444830444A32474C36464C36474E35464E35454D35444B34434B333F48303E462F
3D452F3F47314048323E46303A422E39402E363C2A343929333828343A29333A29323B29
2D37262A33232B32202B321E2C321D2D331E2C331E2B331E2D341F3038213037202F3720
2E35202D35222B3423282F22252C20232C1F273020262F1E232B1A242C1B232B1A1D2415
1D2415202514212514202314
839890869D95879E97869F99869D97879D95899E968A9E978CA0998DA19C8DA19C8FA39B
91A49C93A59C94A49D97A79F96A69F95A59D94A59B93A59A86988E6F7D7750595835393C
313432292B2521221D1C1D19191A1617151416121116110F1711101B1714282420353630
383E393E4642414C47424D4A414C4B424D4C444C4C444B4A44494945494B47484F454651
41434E383B472B2F39181A2614141F1111190F10151112151619191B1F1D1D221E1E241D
21271E23291F24281E24251E2F322B363A35363A3A292C301F1F2518181F15151A17181B
1A1C1B191D19191F191A201A161C161920161E2718242F1C3E4D3448593E2E3926222A1B
1C2316181F13161C0F242C1C323B273E473045503848523C48523D49553C4A563B4A5639
4954384753364953364A5136474E34464D35474F37454E37434C36424C36434D37434C35
424B3140482E41482E42482F43482E454A31464B33464B35464A384449384147363E4534
3C44333C44303C452E3D452E3D452E3D452E3D422C3B3E2B383A2A36382A34382C32382B
2D35272C34242B32212A321E2A331C2C351D2A341A2831182831182B341B2B341B2D351F
2D34212C33242B3328262D25222921222920232A20232B20242D1E242D1C232B18202815
2129142328122024101E210E
81938B879C938AA09989A09B889E9B869B9A869C9A899E9D8CA09E8EA09F8FA2A08FA29E
91A39E94A59F95A49E96A59E96A69F96A69F97A89E95A79E96AA9F92A69B82938868766E
58635A4A54482C322B262C251D201C1919181715151813131712111812121A1514201D1A
2626232C2F2D343A363A413D40494447504B48514C48504B464C4A46494A44454C44454D
43464F444A544248513A4046282C3422252B1B1E2413141B12141C1B1F24202628202726
222926222A24212823212520292C26383D363E443E3B413D3034332A2D2D1F20231C1D20
1B1E20191C1C171B191518161015101419111A2114181F0F1D2415262F1D232B1B192013
181E11192013191F131D2417293120353F283C472E404A32424C354852394A563A4B5639
4B56394953374C55374B5336494F35484F36484F36464E37454F38454F39465039464F39
474E37444C343E452F3C422B3D422A3E432B41462F424731444834454B37444A37404737
3F46373D45353B43303B432F3B42303B422F3E452F3C412C3A3E2C3A3E2E383B2E33392D
32382C33392B3037262D35222E35212F38222F371F2D361F2B331E2B321F2A311E2A311F
2B32212B34242B3426293226272F24252D22242C20232B1D262E1D252E1C252E19242D17
272E15262C1323281021250F
83958B8B9F968CA39D889F9C859D9D869D9F869C9E879D9F8A9F9F8CA0A08FA2A191A4A3
92A5A394A6A295A8A095A89F96A79E98A8A198A9A298AAA397ABA295AAA095AA9F91A69A
899D907A8D7E5F6F6249524A3437352C2D2E2525271E1B1D1D1A1B1F1E1E1F1E1D1F1E1C
1D1D1A1E1E1C212220282A27363C3640473F474E464C534D4D53514A4E51474A51444852
404650454E55444E53455051434D4B3F4745393F412C2F3720212D272B35262C341E252A
1C23241B24211C231F1C221C1B1D1A2123202E312E373D383B433C3B433C363D372E3431
242A291D2122171C1C1215150E110F111510161B13171D121A1F1421281B252C1E21281B
1C24161C23171C2317252D1F313B2937422C3B462E3E482D40492C454D31484F32484F32
4A51344C52374C53394B52384951384852384852374954374853374750374A513A4B513C
4C503C4A4E3B464B394348374147333F46304047303E472F3D462F3F48303F48313F4731
3F47333F46333B42313C44333E46353942303A432F39422F37402E39412F394030373F2E
37402E39412D373F2A343C27363D29353C293339263239273038282D3528293225283124
2831242831222832222A34232933232932212A332029301E292E1C292F1C282E1B282D19
282D17272C16262A16252816
879C928DA39B8CA4A08CA3A38AA2A68AA1A5899FA2879D9F899E9F8BA1A18FA3A291A4A2
92A5A292A6A194A7A094A79E97A99F99AAA29AAAA599ACA798ACA697ABA597ACA497ADA5
97ADA496ACA093A8997A8A806C797067746B454B4D32343C373B3F3D41433133362C2E2F
292B2A2729252628222729232B2E2730322D383A3441433D4A4C484D4F4F4E52554B5356
454E52424C4E414C4C434E4B4954504A53524A5154474E543E444C3A4149272D381C222C
141B21131A1C141A181317151110121311141A17192D2C293B3F393C423B3E453D3C453D
363E392D3434252C2D1B21211115140F13101013101216101E251A252C1F293021272E1F
232C1B232B1B20271722281925291A2A2F1D2D321F343923383E253E442A454A2F474C32
474D32494E334A50364A5138495138475037475037485337485237475036484F394A503D
4C52404B513E484E3C444B38424935414A33414B333F4A333D48333D48313C462F3C462E
3D462F3D452F39422E39422E3B433038412F36402D343E2C353F2D36402D353F2C333E2B
353F2C363F2B353F2A343D2A353E2B37402D373F2C363C2C333B2D30392C2F392C2D362A
2A3327283123252E1F262F1E28311E2A341F2A341E29321C293019292E19262B19262B19
262B1824281626281826291A
879E968CA39C8BA29F8CA3A28BA1A48AA0A4899EA4899EA38A9FA18CA1A28DA3A28FA4A2
90A6A192A8A094A9A092A69F95A8A298AAA499AAA698ACA998ACA999ADAA98ACAA98ACA9
9AAEAA9AAFA99AAFA59AAEA28A9B9175827C656F6E596064727C7778847C666E6C606A66
576259414840363A3234352E31302B302D2C34312F3533313A39383F3F3F474A4A4C5352
4C57544A565049554D49544D4C56524D55564C52584C515B4C545D49545B3F4A52354048
242E3520282B171B1E141418120F151711151A141535332B3A393233322F313030323432
393E3A3D45403B4640323E3818211D1117130F130F0E100B1C2317212719232919272D19
282F1B28301D2A301C272D1A2226162123151D1F111E2012252718363B27495237495237
4A54394A5337495136464D35464C35464D36464D37465038444E3745503747513B47513D
48533D48523C465039444E37434D35424C34414C34424E35404C343F4B323D4A303C482F
3B462D3D462D3D452E3B432D3A432F3A423038413037402E38422F38432F36422D34402A
333F29343F29343E28333D29353F2A363F29373F2A363D2B353B2B333A2B323B2C2F382A
2D36292C35262832222831202A34202A342029321E2A311D2A301C2B311C292E1A262C17
242B15252A16252A17262B1A
849A9389A0998BA19D899E9E879C9F879DA0899FA2899FA2899FA08BA1A08DA4A48FA6A6
91A9A692AAA594ABA395A9A497AAA896A9A896AAA898AAA999ABA999ACA99AADAB9CAFAC
9EB0AB9FB1AA9EB0A79FB2A6899A90626C6A626A6A737D7992A09596A59998A89C9AAA9D
95A79773807758615C535B554D524C52564D45443E3937343534323634343C3A3B424344
454A4948504B4D574C515C4F525D535058554C53564A50584F555E5058614C56604A555E
4450553D484B323A3C292C302220241E181C2520204140392F2A2A252124211C211D191E
2323242D312F343E373844392B382C161F1713190F0D120810150B13180C14180B181D0D
1E24142128182329191F26171C2116262B1F252A1E21251B1F21182F34265563465B684B
5B684B576349515A4449513E464C3A434A37434A364047353F4734404936424B38454F3B
46513B48523B46503B444E38424C35404C343F4C33414F34404F33414D31404C313F4A30
3F492E3F472F4047313D43303C42333A423438413238423039443136422D36412C36422B
364229374127373F27353D27343B26323925343B27343B28333B29323C29323C282F3826
2D36252C352529332229322027301E28301E2A301E2A2D1D2A2D1B2A2E1C282C1B252A17
222616252919252A19252A1A
8597948A9E9D8DA0A38B9EA4899CA3899DA28A9FA18BA0A08CA09F8EA1A18FA2A68FA3A8
91A6AA91A8A991A7A694A8A798ACAB97ABAC97ABAB99ABAB9CADAB9CACAA9EAEADA0B0AF
A0B1AEA0B0ACA0B1ABA1B3AC95A59F747F7F6E7777838F8A9DACA19EACA2A3B0A7A6B4AA
A7B5AAA1ADA6949F9A87908D828C868D9B8A646C5F4B504645484040403B3F3C3A3D3A3A
3C3A3C3E3E3D4347414A50474F584D505A514F58534E555653575C53575D4E525B4D535D
4C565D4C585C4B58584652503D434231313434323340403B272326201D221B181F151219
1312161516181A1E1C20261F222A20192319151C11161D0F141A0D13180C13180C14170B
15180D171B10181C1115190F10130D161B141E231A22271C23271C2B31233E4634555F48
5C68506270586070585865514D5544414636363A2C333628353829383B2C3C40303F4533
434B37464E3A444E3C424E3D3F4B383F4D363F4E333F4E30404E2F414D2E404C2E41492E
424A2F4147314045333D44343C43353B443737423435402F35432D35422B35422A364228
384329394229373E28373C2A3439293037272F37263038272E39282D38262E3A252F3A23
2E38212E371F2B341D2B331C2A311B2A301C2B2F1D2B2C1C2D2E1D2D2D1D2B2B1E28291B
27291B272A1D262B1D24281D
8697988B9CA08C9EA78B9DA88A9CA78B9DA68C9EA68EA0A48EA1A38FA1A490A2A690A3A7
8FA4A790A6A78FA6A792A6A796AAAC95ABAE96AAAC98ACAB9BAEAB9BADAA9DACAB9FAEAE
A0B0AFA2B2B0A2B3ADA4B4ADA1B1AB9AA9A495A29D97A59DA1B1A6A3B1A9A7B4ADA8B5AF
A9B4AFABB5B0A9B2AEA9B3ADA7B1A9A5B3A595A49186927D686F616166595E605654554D
4C4D4742423C3E40373E3F3742453C474C434C514B4F5552535959555A5C52595C50575B
4C55584A56574B59594F5C59535E595157544D505145474925222E201F2C1A1A2615131E
12111A1012170F13130F15100F160F111910121A101720101C24121B2211191D0F181B0E
171A0E181B0F15150B1111080E0D070F0E0A13130F1616101617121D1F19292C25373D32
48524452604F596A5660735B5D6E554B5641373A2A28271B26231929251C2D2B21323026
383A2C3F4533414A37414C393D4A353C4A313D4C2D404E2B404D2B404B2A3E48273E4527
3F452B4045303D43323B433339403337403336403235403034402B344128344025384226
394127394028393D28383A28373B2C343A2D32392C2F382C2C362A2933262A35242C3722
2C38202E391E2C381C2C371C2C361B2B331B2D321C2D301E2E2F1F2D2E1E2D2C202A2A20
292B22282B2324282021241D
839797869A9E8A9EA58C9EA98B9CA88A9BA58B9BA38C9DA38E9FA490A1A68EA0A58FA3A5
91A4A691A5A790A5A791A5A697ABAB99ADAE9AADAD99ACAD99ADAD9AACAB9CADAC9EAEAD
9FAFAEA1B1AFA0B1ADA2B3ACA4B4ACA3B2AAA2B0A8A0AFA7A3B2A9A5B2ABA7B4AEA9B5B0
ACB6B2AEB9B5ADB7B3ADB8B2ABB6AEA9B6AAABB9A7A8B6A19FAA979AA593939D8C899283
777F6F5E64544A4F3E3F4234393B303738303738323B3D3A4649484E5453525A5A525C5B
505B5A4C58574A56554D5858545E5B59605D5A5F5E585C60484C543C414C292D3A1E222D
181B2613171E1015180B1210090E0A0E140B1820111E2713232D17252E18232A15202513
1D21111A1E0D161808121105110E05120F0916130D1916111714131512151613171C1A1B
262927353D3647544555664E46563F46553B4551373B402D3D403037352D2F2B292E2A26
313028363A2E393F323C45333B45303B462C3A44283C47273C46283A42273A40263A4027
393F29383F2B373E2D373F30363F31343D30333C2D353D2B373E293840283841273A4228
3B422A3A412A3A402B393E2B363B2A353B2B343C2C30382C2C34272B34262A32252A3323
2B34232B36222C37212D38212B351F2A341F2C341F2B311E292D1C292D1D282C1E272B1F
272B20282C21262B1F23271B
7E9597849B9D899FA38A9EA6889CA5899BA38B9BA18B9CA38C9DA38D9FA58EA0A690A2A5
91A3A591A4A792A6AA91A6A895A8A996A9AA99ACAC99ACAE9AACAF99ACAE9CAEAF9EAFB2
A0B0B49FAFB3A0AFB1A1B1B0A4B3B0A4B2AFA5B3AEA5B3AFA5B3AFA6B3AEA7B5AEA9B7B1
AAB6B3ACB8B4ACB9B4ACB9B3ABB9B0AAB9ABACBCAAADBCAAADBBA9ADBAA9AEBAA9AAB6A7
9BA69992A08D67706140443C3538322F332C2B2D272A2A252D2C283C3D38464A444E5550
525A57535D5A515C5A505B5A545E5C57615C585F5A5A605D5B61605860604A51543E464A
31393E1F252B151B1F0E14140A0F0B0E140B1921111F291429341D2E39212B351C222A14
1D210E181A091113040F11031010051211081A190F1E1D121E1C1326241B28261D221F1B
26252431332E393E36464F3F3036291C211722291B2B34234A573D606C505E6750565C49
474B3D3F43373F43374045373F45353C42313C422C3B43283B4428394127373E26373F26
353C26343B25343B26353C29363C2C353B2D323829333928363A29383C2C373D2D363D2C
373F2C363E2D363E2C363E2A353E27343D27343C263038242D34232C33232B31222B3223
2A31242931252931262933262A34242B34222A332029311E292F1D282F1C282E19262C18
272C19292E1C282C19272B18
809697859C9F8AA0A58A9FA8889DA6879CA38A9BA38C9CA68D9EA78C9DA68FA0A891A3AA
91A3A991A3AB93A5AB92A5AA93A4AA94A4AB95A6AC97A8AE9AAAB09BABB29EADB4A0B0B6
A2B1B7A1AFB5A1AEB4A2AFB4A3B1B4A6B2B3A7B4B3A8B4B3A8B4B3A8B4B1A9B4B0AAB6B2
ADB8B6ADBAB7ADB9B6ACB9B4ACBBB1ACBBADAFBDACB0BEADB0BDADB0BDAEB0BDAEB2BDB0
AFBBAFABBAAC92A094626C66474F4A3A403831362D2D2F242A2A1F2B2921312F2A3B3B37
3F413F474C495059535560595A665E5A655C565F56565E56555D57565E5956615C55605D
4E5B5943504D2C343413171811151213180F1A21131E2615232C1727301B28311B252B16
1E221016170A100F070E0D080E0F0810100B23261C1F20181C1C155661466D7C5A34382D
3D443B41483E3238312A2E2922231E18191312110D0E0E082023196E80618BA17D849878
6D7B67556054555F5450584C4C5345474E3F434A373F48303E482D3E482C3C452A3B442A
384026363E26353B26353A26373B29363B2A32372831362732362833362A31372A31382B
323A2D30392B2E37282F39262F3B242F3A222F39212D371E2C351F2C34202C33202A3120
29312128302327302528322629342429332129342029341E28331D28321A293118282F16
272D16272C18262B18272B19
7E9195879C9F8B9FA5899CA6869BA5879CA4899BA28C9EA48D9FA78D9EA68FA0A791A1A9
93A3AB92A3AB92A4AB92A3AA93A3AB95A3AB95A3AB94A4AC96A5AD99A7AE9BA9B09EACB3
A0AFB4A1AFB3A3AEB2A3B0B3A4AFB3A4B0B3A5B1B1A6B1B0A7B3B0AAB6B2ACB7B6ABB6B4
AAB6B4ACB8B6ABB7B4ACBAB3ABBBB1ADBCAFAEBDAEB0BDAEB0BDACB2BEACB2BDACB3BDAD
B3BEAEB2BEAFAFBDAEA0AE9F8A9888626C6141453E3B4034383B2E38392D34342D33312F
312E2E2F2E2E35363341453E4E564A555E51596355596355566053525C51576356566357
515F5651615747564C252D291D241D191E17181D13171C10191E0F1A1F0F1D2012202416
1F231516170E13120D11100D0F0E0D0F0D0D1919171716141E1F1E7F9377A6C29E94AF90
5F705F3D453B2B2F271B1C1716161215140F13110F11100E0E0C0C47514194AD88899F80
889C8170816F62716361705F63715D626F5D5E6B595D6B5558664E505D454C564048513C
444B384146353D42313A3E2E383C2D373A2B33352A32352A3134283236293035282E3327
2E34272C34262932242A34242A34232A33232B35232C37212C361F29321C29321C29311D
29301E27301F28312128322228322228311F28311D28301A272F1A272E19282E19262C18
242916242A19242A1C22291B
76888D84989A879BA28598A28295A28497A28498A1899CA48D9EA78E9FA88D9EA78E9FA7
90A1A98FA1A991A3A991A3A893A5AA97A7AC97A7AC95A6AD95A7AC98A8AD98A7AD9AA8AD
9BAAAD9EADACA1AFACA4B1AFA6B2B2A6B1B3A6B2B1A6B3AEA8B3AEA9B3AFABB6B4A8B4B2
A7B3B3A9B6B5A9B7B3A9B8B2AAB8B0ADBBB0AEBDAFAFBDAEAFBBABB0BCABB2BEABB2BDAB
B3BDABB4BFADB3BFAFB2BEAEB1BEACA5B19F82897C72786C71776B60655B47494442423E
363332302B2A2A262326241F3132293F43364C5242545B4957614E4A52444C5646485342
424F3E404E3E465543424F3D2A34252026191F24151A1D0F17190C17180C1A1A101E1F16
1E1F1818181212120C11120B12110D12100E1615131B1A1A1B1B1C3B413B5D6D5D92AE8E
7D95783A4435282C1F1E1E1417150D100D080F0B09100B0C0E0B0D2529257C94788EA78A
839A7F80957B63715F586453596453636E5E7D8E7883977D83967C819276758368646D57
6167565E645959605650584E464F4340473B3C4238393D35373B33353A3034392D32382A
3239292F38292E36292A31272C32282B32262930232A32202C331D2A311A2C321A2C321B
2B311D282F1D252D1B242C1D232B1C232B1B242A19242A19252A19262B1A26291A232719
21261821291B21281D20281D
7C8F8F829595869A9D879AA28496A28395A28395A18899A38B9BA68C9DA88C9DA78B9DA6
8CA0A88CA0A78DA1A68FA2A591A3A792A5A893A6A894A7A795A7A796A8A996A7AA9AA9AC
9BAAAB9DACABA0AFACA2AFACA4B0ADA6B2AEA7B3AFA8B4AFA8B4AEA7B2AEA8B4B0A7B4B2
A6B2B2A7B3B3A7B4B1A9B6B1ADB9B3ADB9B1AEBBB0B1BEB0B0BDB0B1BDAEB2BEACB3BDAA
B3BDABB3BDADB4BFAFB4BFAEB4BFADB4BEABB0B9A7ABB3A2A9B2A09CA5957C807673786C
3C353736302F302A2A2A26242825202D2D243334273B3E2E3E44313235272F34262B3122
272F1F29301F323B273B452D3036232A2E1E2528191E2015191A1116170F1A1B1420211B
20211B18191513151113160F13160F12130E181A161E201D2529232529242B312B4D5A4B
5968564A564522251D1D1D15191611110D0C0E090C0D050B0C070E353836738673839A85
7D957F83997F81947974826B677260616A5A7B8B7483957A86977C8C9D808C9E806D7864
5B615762685F646D64697368697565616B5D596358515A524D56504A534B475046444C41
41493C3D4438383F3532372F2F322A2C30262B2F232B2F1E2A2F1B2C2F1B2E301A2E311B
2D301C252A191E2414161C0F12170B11160B14190D161A0F1E221425291A25291A24271A
24261B22261C1F241C1E251B
7D918C859895899C9E879AA18497A18496A18598A28799A18A9BA28B9CA38B9CA48B9EA4
8BA0A68CA1A68DA1A48EA2A490A3A68FA4A78FA4A591A5A592A5A596A8A799A8A99BA9AA
9DAAAA9EAAABA0ABAEA2ADAFA3ADAEA5B0AEA6B1AEA8B3AFA8B4B0A9B4AFA9B3AFA9B6B2
A9B5B3A8B5B1A9B5AFABB7B0ADB8B0ADB7AEAEBAAFB0BCAFB1BDB0B3BEB0B3BDAFB4BEAE
B4BEADB5BFADB6C1AEB5C1AEB5C1ADB5BFAAB5BFABB4BDAAB3BDAAB4BFA9B1BCA6A9B59E
63625C3B3436403C383D3C333A392E37372A3738283233232C2C1D2A281C252419202115
2023142325152B2F1C3539253538262C2F2226281E1F201A1B1C181A1B171E201C222421
20221E1B1E1A171A16171914181B1314160E11130D191A1525291E2D3326363E2F444D3B
48533E424C38262A1F20221A1D1D19181515151114130D13110D13211F234E564F5E6D60
70836E798C73899C7E8B9D8087987E82937980917782957985977B84947B8A9B828B9B85
6670665C655D545A54626B5E8B9D83768371555E57555F595B665F5D6A61647266697867
67756364715E5C665550574945483E3C3E34383B2F35382831332231322032321E30311F
2C2E2025291C191C100F1208080B030407000608020508020C0F0615190D1B2012202315
21241722251A21251A1F2418
7588867F9493859A9E869BA28699A48699A6879AA7879BA6899CA68B9EA58A9DA48B9EA5
8A9EA58B9FA68DA1A590A3A591A5A891A6AA90A5A892A8A994A7A796A7A699A9A89CABAA
9FACACA1ADAEA4AFB0A6AFB0A5AEAFA5AFB0A7B2B0A9B3B0A9B3B0AAB3B1AAB4B3ABB7B4
ACB8B4ABB7B2ADBAB2ADB9B2ADB9B1AEB8B0B0BBB1B2BDB3B2BDB2B3BEB1B3BEB0B4BEAE
B4BEABB6BFABB8C1ADB7C0ADB6C0AEB5C0AFB8C2B1B9C2B0B9C1AEB9C2ACB9C3ABBCC9AC
9EA7905B58524A474279816B6B715D5459485257444345353736283131232D2D1F2A2B1D
282919282A182C2E1D3839293A3A2D3233292A2A2323241E1D1E191C1D18222420262924
2629242528222125201C1F1C1A1D1812140F0F100C10110C15170F1C20152B31213A422D
3B442E363E292B312024271A1F20181C1C181B1A1A1A1A1A1D1F1D1D201E252925363D34
434B3F484E427E8C7397A98C8FA18792A48890A1858EA0848D9F858A9B84889984889B86
8193807584736E7A69697564889A808FA5896B7A6A616F615B685B555F55626F62758774
798C767C8F777B8E7673836D6C7B66697561646D5A58604E535A494E5442464C393C4132
363C30282E251C221811150D0A0D06060801040600010300000100030501070A030D0F05
181A0D212414222716232A19
7387857D929384989F869AA48699A68699A78698A78699A7889CA8899DA78A9FA68DA0A7
8D9FA88FA2AA90A4AA8EA2A790A5A894A7AB94A7AD93A7AC96A9AF97AAAE9AAAAE9BAAAD
9BAAAD9EADAFA0AFB0A2AFB1A3AFB1A3AFB1A6B3B3A7B5B2A8B5B2A9B4B5AAB4B6ABB6B8
ACB7B7AEB9B7AFBAB5AEB9B5B0B9B5B0B8B4B0BBB6B1BDB6B2BDB5B1BDB2B2BEB2B5C0B0
B6C0AFB7BFAEBAC1AFBBC1B1BAC0B3BAC2B6B9C1B5BBC1B4BCC4B4BBC4B0BAC4ACBCC7AB
B9C6A89CA48D75746A9FA692A9B19C9DA79295A089777E6A49493D444636434734434731
3F432B3C4028383B283B3B2D3D3C3039382D2D2D2527271F21211A1E1E1720201A24241D
282A232C2F272C30292325241D1E1D1213120F100E0D100D0F120D1317111D2319242B1D
272D1D29301D252A182022141C1C161918171B1A1B1B1A1D303534444D47434E464E5C50
505B4E4C53474D504993A38A8A998484938080907B808F7A899C84899C858A9D878B9F89
879C858599817D9077778A72798B727C90757B8F767B8F76778A73738670738570738571
7486737788767889767889767889757A8B747C8B73798673748070717E6E6E7C6C677466
5C6A5C363F381C201D171B16090A06040501020300010200000100000100000200020400
0C0E031A1D0C222713252A17
7284857D90958295A08396A48296A38396A38497A38497A2859AA3889EA58A9FA58A9EA5
899DA68A9FA88CA2A88A9FA68A9FA58EA3A792A5AB94A7AF94A7B196A7B197A8B099A8AE
9AA9AF9BAAAF9BAAAF9CAAB09EACB1A0ACB1A3AFB1A4B2B3A7B3B5A7B2B5A6B1B4A8B2B6
A9B2B8ABB4B8ACB6B6ABB4B4ACB3B3AEB5B3AFB9B5AFB9B7B1BCB6B1BCB5B2BDB4B3BDB2
B3BDB0B4BDB0B6BEB0B8BEB2BAC0B6B9C2B8B8C1B7B7C0B4B6C1B3B7C3B0B7C2ACB7C1A9
B6C1A9B6C0AAB3B8A6B2B8A6B6BDABB6BEABB5C0A9AEB9A1787A706D6F647C836F818A71
7279635B614F525747484B3D4444393D3A313230272D2C2327261E21201A20201823241B
26261F282A22292B242224201D1D1C181718141315111413121713171D171B211A21291D
272E20293120252B1A1F22141B1C151B19171815171C1A1F373D3E7588776D8270617464
6476625A67544A4F4698AB908EA28B718373647365515B5271816D82957D849880899E86
889D878AA1885F6F60485349859A7C72836A6F7E6B7B8D797D917C7A907B7A907A778B75
76897575847474827572807572817573837374837174827175827074816E74816F74826F
788A734F5B501212170B0B0C010101000000000000000000000100000100020400090B02
121406171A0A1F2411232814
79898E7E91998093A07F93A08094A18194A08397A08397A08498A1869AA3899DA6889DA7
899DA68A9EA68A9EA68A9EA68B9EA68DA0A691A3AB92A4AD93A4AF95A3B096A4AF98A7B0
9AA9B19BA9B19CA9B19CA9B29EACB3A2ADB3A3AEB2A3ADB2A7B0B5A9B1B5A8B0B5A9B2B6
ABB4B9ACB4B8ACB5B7ADB5B5ADB5B3AEB5B2B0B8B4B1BAB5B2BAB5B2BBB4B2BCB2B2BCB0
B1BCAEB2BCAEB3BDAEB3BCAFB5BEB2B5BFB3B4C1B3B4C1B2B3C0B1B5C2AFB6C2AEB8C2AE
B8C2ACB9C1ABBBC1ABBBC2ABB9C0AABAC1AABCC3A9BBC3A8B4BBA2AEB39DADB39CB0B99F
ABB4999CA38A8D937B696A5A5C5A4E4B483D3D3B2F3535292D3024262A2027271E292A1F
2A2B2125281D20221B1D1D191A1A171817171515161618171B1F1B242920272D21293023
2B31252C32262B3122262B1D25281E22231D1D1C191818183036317B927688A48052624D
4D5A463F4839393E3464715E5F6D5D6A7F69697D675A6A566A7B647A8D747E927A82967F
849882899F86616F614045419AB18F51594E4248468FA48D7F948066786B7185747A8E7B
6D7B6D6C786D717C74727D7871807972817672827373817174826F707E696E7A656A7761
616D5A3F453D14121509050805030403010202010201000100010001030005070216180D
202314222717232A19242C18
7A898F7F929A8195A08297A18195A18296A18397A28497A38497A48698A5899AA7899BA8
8A9CA88C9EA88DA0A88C9FA78DA0A78EA1A890A1AB93A5AD94A4AD94A2AF97A5B199A6B3
9AA8B49CA9B39DAAB39EABB5A0ADB6A1ADB6A2AFB4A4B0B2A6B0B1A7B0B1A7B0B3AAB3B5
ABB4B6ADB6B7AEB7B7AEB7B5AEB7B3AEB8B1B1BAB2B2BCB1B2BBB3B2BBB2B2BCB2B2BCAF
B1BCAEB3BEAEB3BEAEB4BDAFB5BFAFB4BFAEB5C0AFB7C2B2B8C3B3B8C2B1B9C3B3B9C2B2
B8C2AEB8C2ACBAC2ABBCC4ABBDC5ABBEC6AABDC4A8BDC4A6BEC6A6BCC4A6BBC3A6BBC4A4
BAC3A2BAC5A1B4BE9AA2A98A93997E71745F4948374447323C422F353A2A333427313124
2F2E222A2A1F24241B1F20191C1E171A1C16191B161C1E1921241E2D31272F3327303528
3134293033283034282E31252C30252B2E241E1F17191A1216181024291D3A4532313829
2E3225282C22272B22272C2420251E4E5D496B7F6162735873866A71836A70816B6D7E6B
718574778C7B7387756E806D889E835E6A5F42494A8AA08B92AB92798C7A7C8F7B7F917D
3D3F404345487581786F79755F686668766E6E7D6E6E7D6C6D7D686C7C656B7B6467765F
515C4A363E33191B190D0C0D0B080A080507060404030202020101080A061417101F2318
272C1C292F20282F20293020
74868A7D919581959B83979E82969E8396A08496A18395A38596A38697A38797A28A99A6
8B9BA78C9CA78D9FA88EA1A78EA0A78F9FA890A0AB91A1AD95A3AD96A4AF97A5B199A5B2
9AA7B39BA9B29AA8B19CAAB39DABB49DABB39FACB0A2AFB1A4AFB0A7B0AEA9B2B1ABB3B4
AAB3B5ABB5B5ABB5B5ACB6B4ACB7B3AEB9B1AFBAB0AFBBAFB1BCB1B1BBB1B1BBB2B1BBB1
B2BCB1B5BDB2B8C0B2B8C0B3B8C0B2B8C1B0B8C2AFB9C2AFBAC3B1BAC2B3B9C2B3BAC3B4
BBC3B3B9C3AFB8C1ABBBC4ABBDC6AABEC6A8BEC6A6BFC7A5BDC4A4BDC4A5BDC4A5BEC6A4
BEC5A2BBC6A1BAC59EB7C29BB5C19AA8B48D6F71575E60485B5D46575A45525441464537
3E3C3133312829292024261C22241A1F21191E1F1720221924271D2F322635372A383A2D
383A2D36372C3233292D2E25292A222A2C23282B2220221B1C1E171517121516111A1B14
1919131819141B1E1820231C1C1F1A24292047543E505E46738866697C5E58674F3C4538
434D444E5B5465786A6B806E6F846F6A7E6D627568728876849D83879F84859A81707D6D
2E2B332B29346E7E737282763C414555605A7487725A67593A40394C564665755D61705A
4A564530392F1C201D12131209090A060506050404040301020200171C122B34222C3523
2D35232B3121272C2025291E
6F8088798C9380949C83969E83959E84959F8495A08597A18598A084979F8799A08A9AA3
8B9AA68C9AA78E9DAA8E9EA9909EA993A1AB95A2AD95A2AD96A3AD98A4AE98A6B098A5B1
99A7B29AA8B29AA7B19BA9B29BA9B19BAAB19FAEB1A2AFB2A4AFB0A6B1AFA8B2B0AAB3B3
ABB3B5ABB4B6ABB4B8ACB6B7ACB6B6AEB9B5AFBAB4AFBAB1B1BBB1B3BBB2B3BBB2B5BCB4
B7BEB5B8BEB4B9BFB4BABFB5B8BDB3B8BFB3B8C0AFB8C0AEBBC1B1BCC2B3BBC1B3BCC2B4
BEC5B2BDC6AFBBC4ADBCC7ACBCC8AABBC6A6BDC6A3C0C8A4BEC5A3BEC6A6BEC5A6BEC4A5
BFC6A4BDC6A2BBC5A0BCC7A1BBC6A0BCC7A0AFB8949EA3859BA183A2AA8997A080747761
45413A3F3D3533332A2C2F23292E20292D202A2B1F2B2B202B2C2332332A3F4233434738
3E4337373A3231362D2C2F29282A2624262224282123271E20231A1B1F151C1F161C1D16
1615101A1B1220221723261C21231D1B1D191A1F1823281F313A2B37412F38412F303628
2A2F22272B21343D3045524162765D556550424E415363536B7E69728771748976768778
515A573F48495D6E637C937C56655763736171836D4F594D1C1A1D292A285F6C59546050
3942392A322C1F2420181B170F120F080A08050804050802060902181F113F4F33445439
38442F2D3626282F2224281E
75878C7F929883979F8497A08394A08294A18294A28497A3859AA38599A0889BA28B9DA5
8D9DA88E9CA88E9EAB8FA0AD92A1AE94A2AE95A2AD94A3AC96A4AC98A5AD99A7AF9AA8B3
9BA8B49BA8B39CA9B39EACB59EADB49CABB09EADAFA1B0B0A3B2AFA6B4B0A7B1AEAAB3AF
ABB3B2ACB4B5ADB5B8ADB7B8AEB9B8AEB8B8AFB9B6AFBBB5B1BCB5B1BAB3B2BAB3B4BCB6
B7BFB9B8BDB7B9BFB7BABFB8BABFB5B9C0B3B8C0B2B9C1B0BDC4B2BDC4B3BDC3B3BEC3B2
BFC5B0BEC7AEBFC6AEBEC7AEBCC6AABBC6A8BEC7A6BFCAA6BCC6A5BCC6A6BDC5A6BDC5A5
BFC8A7BFC8A6BDC7A2BFC9A4C0CAA4BFC9A3BEC8A2BEC7A2BBC5A1BCC5A4BAC5A3AAB494
7172625250465355494B4F41454A394449374346364345363F42353D413544493A494F3F
41473A383C34373B353034302C2F2C292C2B2A2E29292D26272B2324282024281E22241C
1919131B1C1521231A24271D21241C1D1F1A181B1617191521261D272B2126291F23251D
2022191F221721261923281C48563E505F4438412E2F3427373E3140483C4751485C6A5F
7387765E6E635464595F71606779646C7E696D7D6C5F6C61414745494F4B5D665B4D534D
616F5E1B1F1F1B201D1116100C100A070A05050804090B060D100A0F130B2833223B4A34
3845333641332F382D242C22
7A8E8E83979986999F8698A28493A28594A68595A88597A88599A7869AA48599A2899BA4
8B9CA78B9DA88C9FAA8DA0AB8E9FAA90A1AD92A2AC90A2A993A5AB96A6AD99A6AE99A7B0
9BA8B29DA9B19DAAB19DAAB19FACB29FACB09FAEAFA2B0B2A2B0B2A3B2B1A4B0AFA7B2AF
AAB4B2ADB5B4ADB5B6ADB7B6ACB7B4ACB6B4ADB7B4AFB9B6AFBAB6AEB9B4AFB9B5B2BBB6
B5BDB8B4BBB7B5BDB8B9BFB9BAC1B7B8BFB5B8BFB4B9C0B3B9C1B2BBC3B4BDC3B5BBC2B3
BBC3B0BDC6B0BEC6B0BDC6AEBCC5ACBBC4A9BCC6A9BDC7A9BCC6A9BCC4A9BCC5A8BDC5A7
BEC6A8BFC8A7BFC9A6C1CBA6BFCAA5BEC8A4BDC7A3BDC7A4BDC6A5BDC6A6BDC5A5BBC6A5
B0BB9B959A82979F868D957C777D676F745E6669566062505154464A4E4145483C434538
3F41353B3C34393935383935373A35383A373437342F322E2F332D2D322B2B3029252922
1B1D18191A151D201821241A21231A1C1E161719121D1F182B2F262D3227292D2221221C
1E1F181B1C15191E141B1F141C2013282E1D2C321F2C3220262A1B2022181D1F19212420
4550434C584B343C38363E38475347576758627564677A6A657567687769626E64323638
48544A242B251F251F0D110D0C10090A0C050A0A040F0F0B0F100D0D0D0C0E0F0F111412
14181528302631392E272E26
7E909384969C8697A28696A58693A68693A98695AB8596AA869AA8879CA4889CA2899DA3
8A9DA58A9EA68CA0A88EA1AA8E9FAA90A0AD91A2AD91A3AB93A5AC96A6AD98A5AD98A5AE
98A4AE98A5AE9CA9B09EAAB09FABB09FAAAF9FABAFA2AFB2A3B0B2A3B0B3A3AEB1A5AFB0
A8B1B2AAB2B4AAB3B3ACB6B4ACB6B5ABB5B5ABB5B4AEB8B6AEB9B7AEB9B7AFB9B7B1BAB8
B2BBB9B3BAB8B4BCB8B8BDB8BAC0B9B9BEB7B9BDB7B9BEB7B9C0B7B9C0B7B8C0B6B8C1B4
B9C2B1BAC4B0BBC4B0BCC7B0BBC6AEBCC6AEBEC6AEBEC4AEBEC4AEBFC6AFC0C7AFC1C6AE
BEC3ACBFC4ABBFC6A9C0C9A8BFC9A6BFC8A7BEC7A8BEC7A9BCC5A8BEC6A8BFC7A9BEC6A8
BCC5A8B8C0A4B7C0A4B5BEA2ADB69A9AA286888F75767B645B5D4D585A4A5051454B4B41
45453C4141393E3C364C5043586150515A4B4C5446393D3230322A2B2D26282A24272924
21231E1C1D181F211923261B21261B1E20181A1B1624261F2A2E262C2F262A2C2225271F
22231C20221A1E21181B1D1314140B13130918190D1F20121E1E1217170E13140D11110C
23261D56664F2F372E242A25212727232B2936413A5262515D6E59576454576556435045
3E4C403F4D3C1E241C0D110C11150F12130C12120D13110F100D0D0C080B0A070A090609
0A060A0E0D10151516202320
80909485949D8595A48596A88595AA8494AB8192A98294A88498A7879CA7879BA5899DA7
8B9EA98DA0AB8DA0AB90A1AB91A0AB93A1AD94A2AF94A4B195A4AF97A6AE98A6AC99A5AC
99A6AD97A4AC9AA7AE9CA9AF9EAAB0A0ACB19FACB1A0ADB1A1AEB0A2AFB1A4AFB2A5AEB1
A7B0B3A8B2B3A9B3B3ACB6B4ADB7B6AEB8BAAEB7B9ADB7B8ADB7B7AFB9B8B2BBBBB3BABA
B4BABBB6BBBCB7BCBCB9BDBDBBBEBEBABEBCBABFBBBABFBBB9BFB9BAC1BBBAC3BABAC3B7
BAC3B4BAC4B3BBC4B3BDC5B3BDC6B3BEC6B4BFC6B5BFC6B5BEC5B4BDC5B2BFC5B2C0C7B1
C2C6B0C2C6B0C0C5ADC2C8ADC0C6A9C1C8ABC1C9ADC1C9AEC0C8AEBFC7ACBEC6AABFC7AA
BEC6ABBEC5ABBCC4A9BBC4A8B9C4A7B5C1A3AEBA9DA4B0938990777D836B7072605F5D53
524F4A4E4D4747483F4B4F425C695366775B6373563A3F2E2D2F2428282022221D20211E
2222202323222628242629242329241E23211D21203740373D473C31372F2C3127292B22
282A202A2D232629201C1D1613130C10100616170A1D1D0E1B1B0C1211090D0C070A0905
0F0F0B3740312B33292127221B211F171E1C1419181E261E293323252C1C272E1E303928
3F4A3847543D1C1F1615171021251B191B151F211A1D1D191412130F0B100D080F0D060D
0D060C0C050E0C0610141217
7C8E9483959E8597A58395A88293AA8293AA8395A98396A88499A8869AA8879BA9899BA9
8C9DAC8FA0AD8F9EAC919FAC92A0AC95A1AF96A2B195A2B196A4B196A5AF97A6AD99A7AD
9BAAAF9BA8AE9CA8AF9BA8AF9EABB19FACB19FACB29FACB2A0ADB4A2AFB6A4AFB5A4AFB4
A8B1B5A8B3B6A8B4B4AAB6B5ACB6B6AEB7B8AFB8BBAEB8BAAFB9B8AFBAB7B2BAB9B5BBBA
B6BBBAB7BBBBB9BCBEBBBFC1BCC0C2BBC0C0BBBFBFBABFBEB9BEBBBAC0BBB9C0BABBC3B8
BFC8B8BCC4B4BCC3B2BDC3B3BDC4B4BDC4B4BDC4B5C0C6B7BFC7B7BEC8B7BEC7B6BEC6B4
C0C6B3C3C8B3C2C6B0C3C7AEC1C7ABC1C8ADC2C8AFC2C9B0C2C9B1C0C7AEBFC7ACC0C8AB
C0C8ACC0C7AEBFC6ADBDC5ABBDC6ACBCC6ABBAC5A9B9C5A7B4BFA3ADB69BA6AF958B907D
6C6D6358575155554D494A4242453B494E3F454C3C353A2E2E3429282C232426201F211E
202220272A272B2F2A2B302B2A2F2B2629282427283B443D434E44353E36333B3230372D
2F352B2E342A2528221C1D1A12111010100A15160D1B1D101C1E1017190E10100A0D0C07
0C0B0711100C161913161A16141816111513111612171E16192015171E10171D0E161A0D
1A1C112225181C1F151D221721261C1B1E162E34273136282B2F2325271E26241F26231E
1F1919191316140F15110D15
7A8D9381959D8396A48598A88394A88293A88495A98597AA8496AB8598AC889AAE8A9BAF
8C9DAF8FA0AE91A1AE929FAD939FAE94A0AF95A1B195A2B096A4B097A5B098A5AF99A7AF
9BA9B09BA9AF9EABB09EAAB0A0ABB2A1ADB3A3AFB6A2ADB6A2ADB9A3AEBBA3AEBAA3AEB7
A4B1B8A5B2B8A6B4B8A8B6B8AAB5B8ACB5B9ACB5BAADB5BBAFB7BDAFB7BBB1B9BCB4BABD
B5B9BCB5BABDB6BCC0B8BEC0B9BEBFB9BFBFB9C0BFB8C0BDB8BFBBBCC2BBBBC0B8BCC2B7
BFC6B7BDC5B5BDC4B4BEC5B2BCC4B1BDC5B2BDC3B4BEC4B5BFC7B7BFC7B8BFC7B7BEC6B3
C0C6B1C3C7B0C3C7ADC3C6ABC3C7ABC3C7ADC2C7AFC4C8B2C3C8B2C3C8B1C2C8AEC1C6AB
C3C8ACC3C8ADC2C7AEBFC5AFBDC4ADBDC5ADBDC5ABBCC5AABAC3A9BAC3A8B9C3A6B5C0A3
A4AE957F837575796A61635752534B4E4F4544463C3B3E3533362F2B2D29292927232524
2527262B2F2B2E342D2F352C2D322A2E30292E2E2A2F302D2F322F2E332D2E332B2F352B
31392D2E362C282E272326231E1F1D1B1D181E211A1F241A1B2115161B1110130D0E1109
0D100811120B151811181C161519150F13100F130E131810151A1013180C13160B12140B
10120912140C141810181C15171B15181B161E23192C3322303720282D162B2C1732301F
302D212A261F2C2C26282A24
7C8E9081939882959F8495A48293A48595A68796A88797AA8595AB8495AC8597AD8899AF
899CAE8DA0AD8FA1AD8F9FAD909FAD91A0B092A0B092A0AF95A3B299A5B39AA6B59CA7B6
9AA7B69AA8B49DAAB29FABB1A1ABB2A1ACB3A1ADB4A2ACB5A1ABB6A2ACBAA3ACBBA3AEBB
A4B0BCA5B1BCA5B1BBA7B2BCAAB4BDABB4BCACB4BDAEB5BEAEB5BFAFB7BFB1B8BFB3BBBF
B4BCBEB5BDC0B6BDC1B6BEBFB5BDBDB4BDBCB6C0BDB6BFBDB6BEBCB9C1BDB8BFB9B9BEB7
BCC2B6BCC3B6BDC5B7BFC5B7BDC3B4BEC4B5BCC2B5BCC3B5BFC6B8C0C6B9C0C6B9C1C7B7
C3C9B3C3C8B0C3C8AFC4C9ADC4C8ACC3C7ABC3C7AEC4C8B1C4C8B2C3C6B2C4C7B0C2C6AE
C3C7AFC3C7B0C3C7B0C2C6B1C2C6B2C0C5B1BFC6AFBFC5ACBEC3A9BDC5A8BDC6A6BAC5A6
B7C2A5B0BBA0AAB49B9AA38D80867570746557595051544A3E3E393736333230312C2B2C
292829292A2A2C2E2C2D302D2D302B2E302931332A2B2C2427282124261F24261F272B22
2B3026292E25282D25272C252529232429222E3729262F231C241915191210120E0C0F0A
0B0E0910130E151913181D17171C1513181112170F161C11151B1013170C0F130A0E110A
0D120A0C0F070B0F0710120B0F100B1619111B1E14202516272B181E1E0D40442A211C13
38352E44473E2324212A3128
788B8F8092998293A08395A48395A48495A48696A58697A78495A78497AA879AAB899CAC
889CAC899EAB8A9DAA8C9EAB8D9EAC8FA0AF8F9FB090A0B194A2B397A5B399A5B598A3B4
98A3B59AA7B69CAAB59DAAB39EABB39EABB59EACB5A0ADB5A2AEB6A4AFBAA5B0BBA4AFBB
A4B0BDA5B1BDA5B1BDA7B2BDA9B2BDACB4BEADB5BEAFB7BFAFB6BFB0B8C1AEB7BFAFB9BF
B2BBC0B3BCC0B3BCC0B4BCBEB5BDBEB4BDBCB4BCBAB5BDBBB4BDBBB6BFBBB7C0B9B8C0B8
BBC2B7BDC2B8BEC3BBC0C5BDBFC4BCBDC2B9BEC4BABDC2B9BEC3B9BFC4B9BEC3B8BFC5B6
C2C7B5C2C8B3C0C7AFC2C9AEC3C9ACC3C8ACC4C7AFC2C6B0C3C7B1C1C5B1C3C8B2C2C6B2
C1C6B2C0C5B1C2C5B0C2C6B1C3C6B4C2C5B3C1C4B0C0C4AEBFC5ACBDC4AABEC6A9BCC4A7
BBC3A9B9C3A9B5C0A7B3BFA7B1BCA5A0AA968E96857E84765F605852504B43413E3B3835
38343035302E312D2C312D2C2D2A292927242B2A252B2B2527272124241F23251F22271E
20231C20231C232820252D24232B21232C212F3B292934231B2317141A1111150E10120D
10120B12160E171B12191E14191E14181D12171E121B2215191F13181E1212170F0D120C
0D120D0C100B070B04080B04090A040A09040B09040E0D0614150B14130A2D31201A1910
363A2E5C6A51171A131A1F16
798C9381959E8497A48396A58497A88496A68395A58495A78396A88598A98699A8879CA9
889CAA899DAB899CAA8A9CAA8C9EAC8E9FAF909EB192A0B493A0B496A3B497A5B498A5B5
98A5B59AA7B59BA9B49BAAB49DABB59EABB59EABB6A1ADB8A3B0B9A4B0B9A5B0B9A4AFB8
A4B0BAA3AFBAA5B0BAA8B2BCA8B1BCABB3BDADB6C0ACB5BEACB5BCACB6BDACB6BCAEB7BE
AFB7BEAFB8BDB1B9BEB3B9BDB3B9BDB4BCBEB4BCBEB5BDBDB4BBBCB6BEBCB8BFBBB9BFBA
BABEBABABEB9BBC0BBBCC2BBBDC3BCBEC5BDBDC5BCBCC2BCBDC2BBBCC2BABDC3B9BDC3B6
BBC1B1BDC3B0BDC4B1BEC5B1C0C6AEC1C6AEC1C6AEC0C4AFC0C5B1BFC5B2C0C6B1C1C6B1
C1C7B2C1C5B1C1C6B2C0C5B2C2C6B4C3C6B3C0C3AFBFC2B0BFC3B1BDC3ADBCC3ABBBC3A9
BCC4ACBBC6ACB7C2A8B5BFA8B6BFA8B6BFA8B5C0A7ACB7A09DA5928E97826F7361595B4B
535242474338423D35403B3437332D302D272D2A2629252224211E22211D242721232821
20261C1E24191D25191E251A212A1C212A1A1F2917212A181D2414191F11171D10151A0E
14190E171A10171A0F191C121A1E14181E14191F151C23181C23171A2217141E130E160D
0D140C0C120B0A0F06080B040809040808030707030705030607020608010709000E1205
161A0A1E24101E230F181B0B
7D919882969F8498A48497A78597AA8598AA8396A88497A98499A8869AA88699A7869AA7
889DAA8A9FAC8CA1AD8DA0AD8FA2AF90A0B092A0B393A1B693A1B594A2B495A3B399A7B7
9AA7B89AA8B69CABB69DACB5A0AEB6A2AFB6A2ADB7A2ADB8A3ADB9A6B1BAA8B3BAA7B3BA
A8B3BCA7B2BBA7B2BBA9B4BDAAB4BDABB6BEAAB4BFAAB5C1ABB6C0ACB6BEADB7BFB0B8C0
B1B8C0B1B7BFB2B9BFB4B9C0B5BBC1B5BCC1B3BDC0B3BDC0B4BCBFB8C0C1B8BFBFB8BDBE
B9BFBDB9BFBCBAC1BBBBC2BBBAC2BAB9C2BAB9C1BABBC1BDBEC4BEBDC3BDBCC2BDBEC3BD
BEC3B9BDC3B6BDC3B5BFC5B7BFC6B4C0C8B3C0C8B1BFC7B0C1C8B2C1C7B2C1C6B1C2C7B3
C3C8B4C4C8B5C0C5B4C0C5B4C2C6B4C2C7B5C0C4B3C0C5B4BFC4B3C0C5B0BFC5B0BFC7B0
BEC6AFBDC6AEBCC4ACBBC2ABBBC2ABBBC1AABAC2AAB7BFAAB7BFACB3BEA8A7B19B919885
8085736666595755494F4C404746393E3D3237362D2D2B25282621252521222320212420
20261F1C231A191F15171D131B23171A2113181E0F1E24131F25161F24171E23171C2318
1B2218191F16161B12171B111A20141C23151F26171E26161D27161B2515192214161F11
131D0E11180B0F15070C11050D0F060C0D040B0B040A0A05070904060902060901080C00
0C10021216061113050B0A01
798B957F929E8396A58497AB8395AC8599AE8599AC859AAA8498A7869AA9899CAB889CAA
8A9EAB8CA0AA8FA3AE8FA2AE8EA0AF90A0B291A2B492A3B593A3B494A5B496A6B498A7B4
9AA9B69BAAB69DACB69EADB5A0AEB6A4B0B9A4B0B9A3ADB9A4AFBAA7B2BBA8B3BAA8B4BB
A9B5BDAAB5BEABB6BFAAB6BFABB8BFABB9BFA9B6BDAAB6C0AEB9C3AEB9C2AEB7C0B0B8C1
B2B9C1B3B8BFB3B9C0B5BAC1B7BDC3B6BCC4B5BBC4B8BFC5B8C1C4BAC2C2B9C1BFB8BFBF
B8BFBEB8C0BDBAC3BDBBC4BDB9C2BABAC3BABCC2BBBEC5BEBEC4BFBFC4C0BFC4C0C1C5C3
BFC4C0BFC5BCC2C8BDC1C7BCC0C7B9C0C8B8C1CAB6C3CAB4C4CBB5C4CBB6C2C9B5C1C8B5
C1C7B6C1C7B8C0C7B8C0C7B9C0C7B8C1C8B8BFC5B6BFC5B5C0C6B5C1C6B3C3C8B5C2C7B5
C0C6B5C1C6B5C1C6B2C1C6B0C1C6B1BFC5AFBEC5ADBDC4AEBDC4B0BBC2AFB9C0ADB5BCAA
AFB8A6A1A997858A7A696D5E5C605050524643443D3A3A3537383234342E2F2F2B282927
2425252023221B201E191D191B2019191F18171D141A20151E251920261A1D241A1D231A
1E251B1E261A1C24171D25161F2715212A15232C17212A152029131E26121D25141C2314
1B22121A210E181E0D181C0D15190C13140A13140A11120A0D0F090B0F080B0F080C1008
0B0F070E12080F10090C0B05
7789957E909E8294A78394AC8192AC8495AD8296A98396A78397A58698A6899AA88A9CA9
899BA88B9DA88FA1AD90A1AE8E9EAE8D9DB08E9EB18FA1B291A3B192A4B095A5B196A5B0
98A8B398A9B499AAB49CABB49FADB5A0ACB7A2ADB8A1ACB6A3ADB7A6B0B9A8B1BAA8B1BA
A9B3BBA8B2BCA9B3BDA9B5BFAAB6BDA9B6BBA9B5BAACB6BCAEB7BEB0B8BFB2B9C1B3B9C1
B2B9C1B3B8C0B5BAC1B6B9C0B7BAC1B5B8C1B6B9C1B7BDC1B8BEC0B9BFC0B9BFBEB9BFBE
B9BFBEB9C0BEBAC2BFBAC1BDBAC0BABBC1B9BCC1B8BDC2B9BDC2BBBDC1BBBDC1BCBFC2BE
BFC3BDC1C4BCC0C4BAC0C4BAC0C6B9BFC5B6BFC6B3C1C7B2C3C6B4C3C8B6C2C7B6C0C6B7
BFC5B8BEC4BABFC5BBBFC7BABFC6B8BFC6B7C0C6B7BFC5B5BFC5B2C1C6B1C3C7B2C3C6B4
C1C4B4C1C5B4C1C6B2C1C5B0C0C5B0BEC4AFBEC3AEBCC1AEBBC1B0BAC1B0B9BFAFB8BEAE
B6BDAEB6BDADAFB5A7A3AA9C90968B7A7D7662645F54554F494A413E3F3534332E2C2A29
252125201D221B1A1F1D1F211D211F181C1A1114120F12100F131011151010150E12160F
14191013190E151B11141B0D131A0A141B09161E0B171E0A161D0A161C08161C09161C0B
141A08131807161D0A171C0C16190C14150B13140C0F100A0C0E0A090C09090C0A0B0F0B
0B0E0A0B0D0B0B0D0B0A0A07
7689947E909D8293A38494A98192AA7E8FA87F92A78094A58396A48598A58799A68798A7
8698A8879AA88A9CA98C9CAA909EAD8E9CAD8E9DB08D9EB190A1B293A4B293A3B095A4B1
96A5B595A5B498A8B49DABB69EABB69EA9B79FA8B7A0A9B6A1ABB6A2ADB5A5ADB7A7AEB7
A7B0BAA7B1BCA6B0BCA8B2BDA9B3BEA9B4BEABB5BEACB4BDAFB6BDB1B7BCB1B7BEB2B9C0
B2B8C0B3B9C1B4B9C1B4B9BEB7BCC1B6BAC2B4B9C0B3B9BEB4BABEB6BCBFB6BDBDB6BDBE
B6BDBDB5BCBCB7BCBEB8BCBEB9BDBCBABDBAB9BEB9BBC0BBBCC1BCBEC2BDBEC1BEBFC0BD
C0C1BDC0C2BDBFC1BBC0C3BCBFC3BABEC3B8C1C6B7C1C5B4C1C5B4C1C6B5BFC5B4BEC5B5
BEC4B6BCC2B8BCC2B8BEC5B7C1C6B8BFC4B6BFC4B6BEC4B4BDC3B1BFC5B0C1C5AFC0C2AF
BFC2B0C0C5B2BFC3B1BFC3B0BEC2B1BBC1B0BBC0B0BABFAFB8BDADB9BDAEB9BEAFB9BEB2
B8BCB1B6BBAEB5B9ACB3B7AAB1B7AAA8AFA39FA799939B8B858E7B585A4E3D3938373235
2B232D231B281D18241E1B241E1C241B1C2015161B1012170E11130C0F0E0A0D090E120A
10140B0C12090C13090B12070E1608131C09131C07131B04111801141C03181F06151A06
1315040F110210120411120610110810100B0F110D0E100D0A0C0A070906080A070D100C
0B0E0C0A0C0B0C0E0C0C0C09
748A917A8F987F929F8192A48091A77E8FA87E91A97E91A68195A58396A68597AA8799AC
8799AC879AAB899AAA8A9AA98C9CAB8D9CAD8F9EAF8E9FB18E9FB391A1B591A1B394A1B3
94A1B395A3B498A5B59BA9B79EAAB79EA9B69FA8B7A0A9B8A0A9B6A1AAB4A3ABB3A6AEB6
A8B0BAA8B1BCA8B1BDAAB2C0AAB3C2A9B1C1AAB2C1ACB2C2AFB5C2AFB5C0B1B7BFB2B8C1
B2B8C1B3B8C2B2B8C1B3B8C0B6BAC2B7BBC4B4BAC3B3B8C0B2B8C0B2B7BFB4B9BFB4BAC0
B5BCC1B4BBBFB5BABEB6BBBFB9BEC1B8BDBEB8BCBCB9BCBCBCBEBCBDBFBEBFBFC0BEBDC0
BFBEBFC0BFC0C0BFC0C0C0C0C0C1BFBEC0BDBEC1BDC0C3BDC0C5BDBFC5BCBDC2BABDC2BA
BCC2B7BEC3B7BDC0B5BEC2B5C2C5B7C2C5B7C0C3B5BFC2B4BEC3B3BEC3B2C2C5B3C2C4B4
C0C3B5BFC3B6BDC1B6BBC1B5BBC1B5BABFB4BAC0B4BAC0B2B9BEB1B8BDB0B9BDB1BABFB3
B7BDB2B7BCB1B6BBB0B3B8AEB2B9AFB2B9B0AFB7ADADB5AAA8B3A59AA29768666C534F5A
383042282032261F2C211B251D171F17131A1713191414181114161013121114110F140F
0F130E0D120D090E09060C060A1108131C0C121C08121C06121B03121C03141C05141A05
1216051214071214071111060F0F0811110A12120C10120B0C0E080A0D060A0C060D110B
0D100C0C0E0C0E0F0E0F0F0D
768C937C929A7F949F8194A27F91A37F91A47E90A58193A88395A98294A88595AB8999AF
8A99B08B9BB08A9AAD8A98AC8C9AAE8F9CAF909DAF929FB293A1B495A2B595A3B594A2B3
94A2B295A3B397A4B49AA7B69CA9B79DA8B89EA7B9A0A6BAA2A8B9A4A9B9A3A8B7A7ACB9
ABB0BEABB1C0AAB1C0ABB2C0ADB4C1ACB3C1ADB3C4AFB5C6AFB4C4AEB3C2B1B5C1B3B7C2
B3B6C1B3B6C1B3B7C1B4B8C1B5B7C0B6BAC2B5BAC2B3B9C1B4BAC2B5B9C2B5B9C1B6BBC3
B8BEC5B7BCC4B6BAC2B6BAC0B8BDC0BABEC0BBBFBFBBBEBDBBBFBBBCBEBCBFC0BEBFBEBE
BEBEBFBEBCBEC0BFC0C0BEC1C0BEC0C0BFBFBEBFBFBFC0BFBFC1C0BFC2BFBCC1BCBCC1BB
BCC1B9BDC0B6BFC0B6C0C1B6C1C2B5C1C3B5C1C3B5C1C4B5C1C4B3C0C3B2C2C3B3C0C2B1
BFC0B2BFC0B6BDBFB8BABEB7BBC1B9BBC0B7BABFB5BABFB1BABFB1B9BEB0B8BEAEB8BEAC
B9BEAEB8BEAFB8BDAEB6BAAEB3B8ADB4B9B0B2B8AEAFB6ABAEB5ABADB6ADA2AAA498A19A
616268332E3B3B363B31292B271E2222191D1E181A191518181718181819171817121313
1214141012120C0C0D0B0B0B0D100D12170F141A0E141B0D121B0B0F1807101806141C08
131A09151A0C15190D15170C12130A12120A11110A12130B1012090D10060C0F050D0F07
0F100B10100D0F100E0F100D
7487937D919D7E91A08094A57E91A47D8FA17E90A38092A68193A88293A98494AC8796AF
8795AF8A98AF8B9AB18B9BB08D9AB08F9AB1919CB2929EB395A1B596A1B595A1B595A2B4
98A5B698A4B49AA6B599A5B499A4B49BA6B79DA6B99FA6BAA2A7BBA5A8BCA6A9BDA7AABE
A8ABBEA9ADC0ABAFC2ACB1C2ADB4C1ADB4C2AEB4C3AFB4C4AEB4C4AFB5C3AEB4C1B0B5C1
B1B6BFB2B6BFB3B7BFB2B5BFB2B6BEB4B8C0B4B9C0B2B8C0B4B9C1B6BAC1B7B9C1B7B9C1
B8BBC1B8BBC1B7BAC0B7B9C0B7BABEB8BCBEBABEBDBABEBABABFB9BCC0BABCC0B9BDBFB9
BCBEB9B9B9B6BEBEBABEBFBBBEBEBBBDBDBBBEBFBDBEC0BEBDBFBEBCBFBDBCC0BBBBBFB9
BBC0B7BCC0B4BEC1B5BFC0B4C0C0B6C0C1B7BEC1B6BDC2B4BFC2B3BFC2B1BFC1AFBDBFAD
BCBEAEBDBEB1BCBEB5BABFB7B9C0B7B9C0B7BAC1B5BAC0B3B9BEB1B8BCAFB7BCADB8BDAC
B8BFACB9BFABB9BEABB7BDADB7BCAFB6BAAEB4BAACB3B7AAB2B7ACAFB5ACADB5ABABB4A8
A0AA9D7C80766C6D6233292B3127282C2123251D1E1F17191C16171B17171B1716181414
151012141012130F110D0B0C0E0E0D141611171D13171D11171E11161D0E171E0D161D0C
13190B141A0D14190E13180C12150C0F120B0F110C11140D12150B0F13070B0E030B0B02
0C0C040D0D050C0D060E1008
7586937A8C9C7D8FA27D8FA57C8DA47B8CA27D8FA57F91A78092A88192AA8494AC8695AD
8795AF8A99B18998AF8B9AB28E9CB48F9DB4909DB4909DB4929FB694A1B795A1B994A0B7
96A1B797A3B698A4B697A3B399A5B59AA7B79DA8BA9EA7BCA1A9BDA3A8BDA5ABBFA5A9BF
A5A9C0A5AAC0A6ABC0A8ADC0A9AFC1AAB2C2ABB2C2ACB4C4ADB4C4AEB5C3ACB5C1AEB7C1
B0B9C3B0B9C1B0B8C0B1B8C0B1B7BFB2B9BEB2B9BDB2B9BFB3B9C1B4BAC2B5B8C1B6B9C2
B8BAC3B7B9C2B8BAC1B8BAC0B7BABFB7BCBEB8BFBEB8C0BBB7BEB8B8BEB9B8BEB8B9BFB7
B9BFB8BABEBABBBFBBBAC0BCBBC0BDBBBEBABBBFBABBC1BEBCC1C1BBC1BFBAC1BCB9BFB9
B9BFB8BBC1B9BCC2B9BDC0B9BFC0BABFC0BCBCBEBABBBFBABBC0B8BDC2B6BEC1B4BDC0B4
BCC1B4BBBFB5BCC0B9BCC2BBB9C0BBB8C0B9B7C0B7B6BEB6B7BCB5B7BBB4B6B9B2B6BAB1
B6BAAFB7BCAFB6BBAEB5B9AFB4BBB1B4BAB1B2B9AFB2B7AEB1B6AFAFB5B0ADB4AEABB2AB
AAB4A8A9B3A4A0A999534D4D382F31332B2C2E2526271E1F251D1E221A1D1E171A1A1517
191316171419161315100F0F0C0D0B0F120B13180D171D111A21131C23131B2111171D0D
141A0D141A0F12180E11160C10140C0D110A0F140C11150F0F140A0F13080E11060E1005
0E10050E0F040E10040F1105
7889967C8E9E7E91A67D8FA87D8FA87B8CA77E90A78092A78092A68091A78494AB8694AC
8795AC8A99AF8897AD8998AD8C9AB08E9DB38F9EB48E9EB48F9EB491A0B692A0B7929FB7
93A0B8939FB794A0B695A2B599A5B69AA6B798A3B897A3B79CA6BAA0A9BBA1A9BBA3AABD
A4A9BFA4AAC0A4AAC0A5ACC0A6ADC0A6AFC0A8B0C2ABB3C3AAB2C3ABB2C2AAB3C1ACB5C1
AEB7C3B0B8C2AFB8BEB1B8BDB2B8BEB2B9BFB1B8BDB0B8BEB0B8BEB1B9C1B1B9C1B2B9C2
B4BAC3B3B9C3B4B9C1B6BAC2B5BAC2B3B9BFB5BCBFB5BDBDB5BCBBB5BBBAB6BDBCB6BEBD
B6BEBDB6BCBBB7BDBBB8BDBCB9BFBDB9BEBCBABEBDB9BEBDBABFC0BABFC1B8BFBEB8C0BC
B7BFBAB8BFBAB8BDB9B9BDBABCBDBDBBBCBEBABDBFBABDBFB9BDBDB9BDBAB9BDB8B8BCB7
B9BCB7B9BDBAB9BDBAB8BFBCB9BFBEBAC0BDB8BFBAB6BDB8B7BBB6B8BCB6B7BCB5B6BDB6
B5BCB3B5BDB3B4BCB2B3BBB2B3BCB3B2BBB3B1B9B3B1B8B2AEB5B0ABB3AFAAB2AEA8B1AC
A8B2ABA6B0A9A7B2A88F958E6564653C353B3A3233352E2F2F282C272028201B24252229
28262B1A192215161D0F11130B0D0D0B0D0B0E120C141811181E161B21171B2016171B11
161A11161A141015100E120D0F130D10140D11160F12160F0F130B0D11080D10090D1009
0E12090E12080C0E04070801
7686997A8BA07C8DA77D8EAA7D8DAB7B8AAA7C8DA87E8FA87E8FA78190A78492A98A97AE
8A97AF8997AE8B9AAF8D9BAF8E9CAF8E9BB08E9CB3909FB68F9FB58FA0B492A1B694A2B8
94A1B9939FB8939EB795A0B598A3B79AA5B99AA5B998A4B99BA6BB9DA7BAA0A7B9A1A8BB
A2A7BEA6ABC2A4ACC4A3ABC2A3ACC0A3ACBEA5AEBEA7AFBFA8B0C0A9B2C0A9B4C1ABB6C1
ACB4BEADB4BEB0B6BEB2B7BFB2B6BCB2B5BDB2B6BEB1B7C0B0B7C2B0B8C3B0B9C2B1B7C2
B2B8C3B0B7C3B0B6C1B1B8C0B4B9C2B3BAC3B4BAC2B4BBC0B4BCBFB5BCC0B6BEC1B6BEC2
B5BCC0B6BCBDB7BCBBB8BBB9B9BCB9B9BDBBB9BCBBBABCBABBBCBCBABEBEB9BEC0B7BEBF
B6BEBCB6BEBAB7BDBBB9BDBCB9BCBDB9BDBEBABDBDB9BDBDB8BBBDB8BBBBBABDBCB8BBB9
B8BCB7BABDB9B9BCBAB7BBBAB6BABBB7BBBBB8BCBAB7BBB7B7BBB4B7BBB3B4BBB1B2BBB0
B2BBB1B3BCB3B2BCB4B1BBB1B1BBB1B0B8AFB0B8B1B1B9B3B1B9B1AEB7AFADB4ACAAB1AC
A9B2ADA8B2ADA7B1ACA6B0A99BA59D6F7271504D514D4B4D48454935313A28252F2A2B31
2B2D321E20271B1E24181B1C13161410141011140F141711171B151D1F191C1D19191914
1919131A1D1816191615181314171214180F1419101519111215100E110C0C0F0B0F120F
1115100D110C080B06040501
7282997787A17C8CA87C8CAB7D8CAB7D8DAB7D8EA87C8DA47D8EA38090A28391A38795A9
8996AC8694A88796A78B9BAB8E9BAD8C99AF8C99B28D9CB58E9DB48F9EB2919EB3939FB4
95A0B6959FB7959FB697A1B599A3B498A1B599A3B79DA7BC9EA8BC9DA7B9A0A8BAA1A7B9
A2A8BBA4AABFA3ABC1A2ABC1A2ABC1A2ACBEA5AEBEA6AFBFA8B1C0A8B0BEA9B2BDACB4BE
ADB5BEAFB6BFB0B6BFB1B4BEB1B3BCB2B3BDB4B5BFB2B6C0B1B7C0B2B7C1B3B9C2B4B8C3
B5B7C4B3B7C4B0B8C5AFB6C1B0B7C0B1B7C0B2BBC3B2B9C1B2B9C0B3BBC0B4BBBFB4BBBF
B4B8BCB5B8BAB7BAB8B9BAB8BABBB9BABABBBABABBBBBBBBBABABAB9BABCB9BCBFB6BABC
B4B9B8B4BBB8B6BCBBB6BBBCB7BBBEB8BDBFB8BCBDB9BDBDB8BABBB7B9B9B8BBB9B8BAB7
B8BBB7B8BBB6B8BAB6B8B9B7B8B9B8B8BAB9B6B8B6B6B9B5B5B8B3B4B9B3B2B9B2B0B8B0
B1B8B0B1B9B1B1B9B1B1BAAFB1B9AEB0B8ADAFB7ACB0B6ADB0B6B0AEB5B0ADB5ADAAB1AC
A9B0ADA7B0ACA6AFAAA6B0AAA7B1AAA0A9A48C9094898E92838B8C575D6230333B252A2E
22262A1F21261D1F221D201C24281C1D20141A1B1117180F1818121A18141C1A161D1A17
1D1C191E1F1C1B1D1A1A1C18191B17151813151811171C141317111114100D0F0E0D1110
0F13110D100D070906010201
7384977889A07A8BA67A8AA87B8BAA7C8DAA7C8DA87C8EA67E8EA57E8FA38192A38495A4
8595A68695A78594A68896A98998AC8896AE8A98B18C9AB18D9DB18E9EB1919FB2939EB2
959FB498A1B79AA4B899A3B69AA2B59AA2B799A1B89AA5BB9BA7BA9BA6B99EA6BAA1A9BA
A2A9BCA1A8BEA0A8BFA1A9C0A1A9C0A3ABC0A4ACBFA5AEC0A7B0C0A6B0BDA7B1BDAAB2BE
ACB4BEADB5BFAFB5BEB1B6BFB1B5BEB2B6BFB1B5BEB1B6BFB2B5BFB2B6BFB2B6C0B5B7C2
B6B8C2B3B7C2B2B8C3AFB7C1AFB7C0AFB6C0B0B9C0B0B9C0B2BAC0B2BABEB3BABDB4BCBE
B5BBBFB6B9BDB6B9BBB8BABDB8BABDB6B8BDB7B7BDB9B9BDB9B9BCB8BABBB6BBBCB6BBBB
B4B9BAB3B9BBB3BABCB4BBBDB5BABDB5BABEB7BBBEB7BBBDB6BBBBB5B9BBB3B8BAB4B8B8
B5BAB8B7BBB9B8BBB8B8BAB8B8B8B7B8B9B8B5B6B5B5B6B4B4B5B4B4B8B6B2BAB6B0B7B4
B0B8B2AFB9B2AEB8B1AFB8B1AEB7AFAFB6AEAEB4ADAFB6B1AEB4B4ADB3B4ABB3B2AAB2B0
A9B1B0A7B0AFA5AEAEA5AEACA4ACABA3ABABA4ACAEA1ABAE9DAAAB91A3A04C545D262A37
292E3623282E1F23261E231E23271B25281B2427192022161C1D171B17161C18161F1E1A
1F201C1F211C1D211D1D211B1A1E1A171C18171C16191E17161B141318110F120E0A0D0B
0A0D09080A07040503010201
748796788C9F7B8CA67A8BA77B8CA87B8CA77C8DA67D8DA77F8EA88192A98294A88395A7
8495A68594A78795A98896AB8796A98896AB8A98AD8C9AAF8D9CB08D9CAF8E9CB0919DB2
939FB597A2B797A1B697A1B798A2B89BA4BA97A1BA98A3BA99A4BA9AA5B99CA7B89EA8B9
A0A9BB9EA6BBA0A8BCA1A9BFA4ABC1A5ABC2A4ABC1A7AEC3A9B0C4A9B0C3A9B1C2A9B1C1
AAB1C0ACB3C2ADB4C1AFB4C0B0B5BFAFB6BFAEB5BDAEB6BDB0B6BDB1B5BDB1B6BEB3B7BF
B2B6BEB1B6BCB0B5BCB0B6BCAEB5BCADB6BEAEB7BFAFB8BFAFB8BFB0B7BDB2BABCB2BBBD
B4BBBEB5BBBFB4B9BDB4B9BEB4B9BEB2B7BEB3B6BDB5B7BEB6B9BEB6BABEB4BABEB4BBBD
B4BABDB4B9BEB4B8BCB5B9BDB7BABDB6B9BCB5B9BDB5B9BCB2B8BAB1B8B8B1B8B7B2B9B9
B5BBBAB7BDBBB8BDBCB8BBBCB7BABAB7B9B9B5B7B7B3B5B5B2B5B6B2B6B7B0B7B9B0B8B8
AFB8B6AFB9B6AEB8B4AEB6B3AEB5B3AFB5B4AEB4B2AEB5B2ACB3B3ACB3B4A9B1B2A7AFB1
A6B0B1A5AFB2A4AFB1A4AEAEA3ACACA1AAABA3ACACA0ACAA9DAAAA9BAAA9879697697379
4A505A393D492D2F3D2B2E38484F4D5964583539362C2E2D2121231A161B1813181C1B1A
1E1F1A1F221B1C221A1A2019181E18161B17171B16171C14161B1212160F0B0E0A080907
080806060504040201040100
7589977A8FA07C8FA67D8FA97C8CA77B8BA67E8DA6828FA98390AB8290AB8293AC8191A9
8292A78492A88694AC8796AE8898B08899B08798AF8A9AB08C9CB28C9AB28D9BB48E9DB5
8F9DB4929FB594A1B695A2B896A2BA97A3BB96A2BB98A4BB98A4B998A4B89BA7B89EA8B9
9FA9BA9FA8B99FA8BAA1AABEA1AAC2A3AAC4A4ABC5A4ABC3A5ADC2A7AFC3A7AEC2A9B0C3
A9B1C4A9B1C3AAB3C3ACB3C3AEB5C3AEB5C3ADB6BFADB6BCAEB6BBAFB6BBAFB6BDB1B7BE
B0B6BEAFB6BBAEB3BBAFB3BCB0B5BEAFB6BFAFB6BFB0B6C0B0B6C0B0B6BFB1B8BFB0B8BE
AFB7BBB0B8BCAFB7BCAFB6BCAFB7BCAFB8BDB1B9BEB4BABFB4B9C0B5BAC2B3B9C0B2B9BF
B4B9BEB5B8BDB4B7BCB4B7BBB4B8BAB4BABBB4B9BCB5BABCB2B8BAB1B7B8B2B8B7B4BAB8
B4BABAB5B9BCB6BABCB4B9BCB3B9BBB5B9BAB5B8BAB3B7B9B3B7BBB1B5BAAFB4B9AFB4B9
AEB5B8ACB5B7AEB6B7AFB8B8AFB5B7AFB5B6AEB5B5ABB3B3A9B1B1A8B1AFA7B0B0A7B0B1
A5AFB0A6B0B2A7B2B2A6B1B1A4AFAFA0ABACA0ABABA0ABAB9FADAD9CABAB9BA8A899A6A5
879295767E865E617157596B848F918A97936B747568736E36373A150E1A18131D141218
12101314131215161214151213161313141014151014160E12150A0E0F07070703090705
0C0B070A0806070503070403
718095798AA17B8CA67C8DA87B8CA87A8AA77E8CA8808DA9818DAB828EAA828FAB818EA9
818EA88390AA8492AE8493B08596B28697B38798B08A9AB08C9CB38B99B38D9AB68E9AB5
8F9BB5909CB5929DB595A0B996A1BC96A1BD98A3BD99A4BD99A4BB99A3B99AA4BA9DA6BA
9FA7BBA0A8BDA1A8BFA2AAC19FA8C2A0A8C4A1ABC4A1ABC3A2ABC1A5ADC2A5AEC3A7AFC4
A7AEC4A6AEC3A9B1C4ABB2C4ADB4C4ACB4C1ADB6C0ADB6BEACB5BBAEB6BDACB4BDADB5BE
ACB4BDADB3BDAFB4BDB0B5BFB0B5C0B0B5C0B0B5BFB1B6BEB1B5BDB2B5BDB3B7BEB1B5BD
AFB6BCAFB7BCB0B8BEB0B7BDB0B7BBAFB8BBB1B8BBB3BABDB3B9BDB4B9BFB3B8BFB2B7BF
B3B7BFB3B5BCB3B4BCB3B5BBB3B7BAB4B9BAB5B9BAB5B8BAB4B7BAB4B9BCB5BCBAB5BAB8
B5BABAB5B9BCB3B7BBB3B7BCB3B7BBB4B7BAB3B6BAB3B4BAB4B6BCB1B5BAB0B4BBAFB4BB
ADB4B9ACB5B7AEB6B5B0B8B4B0B7B3B0B6B1AEB4B1ACB3B1A8B1AFA8B1AFA8B1B1A8B1B4
A7AFB3A8B0B4A8B0B4A5AFB2A4ADB1A2AAAFA0A9ADA0ABAF9FABAF9EAAAE9BA6AB9BA6AB
9AA4AB9AA4AA949CA38F989E919A9E929D9D919D9B92A09970797424212D1D192618141F
15131A0F0C121311131D1C1A19171616161114150C15150C12120B0E0D090A09060A0A06
0D0D080C0C06070501080501
6D7A917988A07B8AA77B8AA97B8AAA7A8AA87C8BA77F8CA7808DA7828EA8818DA7818DA8
828FA98490AA8491AB8592AC8695B08496AF8395AC8597AD8899AF8B9AB08C99B08E98B0
8F99B2909AB4909BB6929DB8939EBA96A0BC97A1BD99A3BD9AA5BC99A3BA9CA5B99CA4B7
9FA7BBA0A6BD9FA5BDA2AAC1A2AAC1A1A9C2A2ABC3A2ACC3A3ACC1A2ABBEA4ABBEA6ADC0
A8AEC1A8AEC0A9B0C0A9B2BFAAB2BDAAB2BBABB3BCAAB3BCAAB3BCACB4BDABB2BDABB1BC
ACB3BDAEB3BEAFB5BFB0B5C1AFB3C2AFB3C1AFB5C1AFB4BFAFB4BDB0B4BDB2B6BEB2B4BB
B0B3BBB1B6BEB1B6BEB2B6BDB0B6BCAFB4BAB2B6BCB1B6BCB2B8BCB1B7BAB1B6BBAFB5BB
AFB4BBB0B4BBB2B4BCB3B5BCB4B5BAB4B6BAB1B5B8B2B7B9B2B7BAB2B9BBB3B9BBB3BABB
B4B9BCB3B6BBB3B5BBB2B4BBB2B5BCB0B4BAB1B5BBB1B4BBB1B5BCAFB3BAAFB4B9AFB5B8
AEB5B6ADB5B5ACB5B3ACB5AFACB4ADABB3ACADB4AFADB3B1AAB2B2A7B0B1A6AFB0A7AFB1
A7AFB2A6ADB3A5ABB3A6ABB2A7ACB2A5ABB1A2A9B0A1A9B19FA8B19EA8AF9AA4AC9CA5AC
9CA3AB9DA4AC9AA3AA98A2A897A0A697A0A5969EA4919B9E8C98966973734F545634363A
2220271A171F19151B2C2C2B2826262222201718141514101514121414141010120D0F10
0C0E0D0C0F0A080904060500
71809178879D7C8BA57E8CA97C8AAA7988A77B8BA67E8EA48190A4818EA37F8DA37E8DA5
7E8DA78090A98191AA8393AB8594AD8393AD8392AC8494AC8492AA8795AB8B97AC8C97AB
8E98AE8E98B08E9AB3909BB3929DB5969FB8979FB897A0B897A1B698A2B49BA5B49BA4B5
9DA5B79DA4B99DA4BB9EA6BC9FA6BD9EA6BDA1A9BFA1AABFA2AABEA1A9BBA4AABAA6ACBA
A7ADBCA7ADBDA5ACBBA7AEBAA8AFB8AAB1B9AAB0B9A9B0BBA8AFBAA8AFBCAAB0BBAAAFBA
ACB2BCADB3BDADB2BEADB1BEACAFBEABAFBEADB0BEADB1BEADB2BDAEB2BCADB2BBAFB3BB
AFB3BBAEB2BBAEB2BBAFB3BAB0B4BAAEB2BAAFB3BBB0B5BCB0B6BBAFB4BAAEB3BAAEB3BB
AEB3BAAFB3BAB1B4BBB1B2B9B2B3B9B2B3B9B1B4B9B1B4B9B0B4B8B0B5B9AFB5B9AFB3BA
AFB3BAAEB3BBAFB3BAAFB4B9AFB3B9ABB1B7ACB2B7ABB0B6ABB1B7ABB0B7ACB1B9AAB1B6
A9B1B4AAB1B3ABB3B2ABB3AFABB4ADAAB2ADAAB1AEAAB1AFA8B1B1A6B0B0A4AEB0A4ACAE
A5ACB0A6ABB2A6A8B3A5A7B2A4A7AFA4A7AFA4A8B1A2A7B29FA5B29DA5B09CA5AD9AA3AB
9AA1AA99A0A8979FA7969EA7969DA6959DA5949CA4919AA28F999F8B97998895927A8581
54575C40424A3A3B4237373D3B3D3F29293125262D24252A24272818181C14141A0C0E14
08090E070808040603040501
70808D778798798AA07B8BA57B8BA67A8AA4798AA17C8BA07D8BA07E8BA17D8AA17B8BA3
7B8BA47D8EA67F90A88091A98392AC8392AC8592AC8694AC8593AA8794AB8B97AD8D97AE
8D97AF8B95AE8C95AE8D97AF909AB2949DB4969DB4979EB5979FB4969EB298A2B398A3B4
98A1B598A1B69AA3B99CA5BA9DA6B99CA7B99EA8BC9DA7BCA0A8BDA2AABDA3AABBA5ACBB
A6ACBCA5ABBAA3AAB8A6ACB9A7ADB7A8AFB8A9AFB8A8AEB9A7AEBAA6ADBBA7ADBBA8AEBA
A9AFBBA8AEBAA8ADBBA9AEBDA9ADBBA9AEBCABB0BDACB0BCACAFBCACB0BDABB0BBABB0BB
ABB0BAAAAEB8AAAFB8ADB1B9ADB0B8ADB1B7ACB1B7AEB3B8AFB3BAAEB2BAAEB1BAACB0B8
AEB1B9AEB1B9AFB3BAADB0B8ADAEB7AEB0B8B0B1BAB0B1B8ADB1B6ADB3B7AEB4B9AFB4BB
ADB1BBABB0BBADB2BCAAB1B8AAB1B6A9B0B4AAB1B6AAB1B6A9B0B7A9AFB8ABB0B8AAAFB6
AAAFB5ABB1B5AAB0B4A9B0B3AAAFB1A9AEB0A7AEAEA5ACACA4ACADA6AFAFA4ADADA2ABAD
A3AAAFA2A8AFA3A8AFA4A7AFA1A4ADA1A5ADA0A5AE9EA4AE9CA2AC9CA3AB9BA3A996A0A7
979FA8969EA6979EA6969CA5959CA3939BA090989E8F989E8F989D8B959A8B94988B9597
848E907A8488737E816770765B646A4042514C525E5A65694A52541615221717200A0B14
04050D020306010201020201
6B7C86748693798A9E7B8CA3798AA47A8AA4798AA3798AA17A8AA17C8CA37D8CA57C8CA6
7B8BA67C8CA57E90A67F90A88291A98392AC8393AC8394AB8594AB8694AA8A96AD8B96AE
8C97AF8A95B08B96B18B97B18C98B2909CB4929CB4939CB5959DB5919BB4919DB4929EB4
929EB4949FB596A1B897A3B999A6BA9AA7BA9BA7BA9BA5BC9BA5BD9DA7BEA0A9BDA1A9BB
A4AABCA6ABBDA4AABCA4AABBA4ABBAA4AAB9A5ABBBA5ADBDA5ADBEA5ADBDA4ACBCA5ADBB
A6AEBCA5ADBCA5ABBCA7ADBEA7AEBEA8AFBFA8AFBFA8B0BDA8AEBDA8ADBCA8ACBAA8ADBB
A8AEB9A9ADB8AAAEB9ACB0BBACB0BBACB1BBABB0BAABB1BBACB1BCACB2BBABAFB9ABB0B8
AAB1B8AAB0B7ABB1B7ABB0BAAAAEBBABAFBBACB0BBACAFBAA9AEB8A8AEB8A9B0BAACB2BC
ACB1BCABB0BCACB2BDA8AFB9A7AFB7A9B1B7AAB2B9AAB2BBA9B0BBA8AFBAA8AEB8A7AEB6
A7ADB4A8ADB4A9AEB5AAB0B7A8AEB4A9AEB3A7ADB4A5ABB3A2A9B1A4ABB1A4ABAFA3AAAF
A2A8AFA1A7AFA1A7B1A0A7B19FA6B09FA7B09DA4B099A1AD98A1AA98A0AA98A2A996A1A9
96A1A995A0A995A0A8959DA7939BA4939CA4919BA2919B9F909A9D8E989B8E979A8C959A
899399869095838E92818D917C898F79858C79868F7A8790728087434A593F4A501B212C
070B17060A10030507020203
6B7B8372839077899A7A8B9F798AA37889A47889A67788A57889A6798AA57A8BA47A8AA4
7A8BA67B8BA57D8FA67E8FA68191A68493A88493A98293AA8294AA8495AB8795AC8995AD
8793AE8693B08794B18895B38996B28B99B28D99B38E99B68F9AB78D9AB68E9BB78F9DB8
8E9CB5909DB6929EB893A0BA93A1BB92A1B996A4BA99A5BC9AA6BD9AA5BD9FA9BD9FA8BA
A0A7BBA3A8BCA4AABDA3A8BDA3A9BDA3AABDA5ABBEA3AABDA3A9BEA4ACBEA3ACBEA3ABBD
A4ACBCA3ACBDA3AABEA4AABFA7ADC1A6ACBFA5ACBEA5ADBEA5ACBDA7AEBDAAAEBCA9ADB9
A8ADB8A8AEB9AAAEBAABB0BBABB0BDABAEBFABAFC0AAB0C1AAB0C0A8AFBFA7ADBBA6ADB9
A7AEB9A8AFB9A7AEB7A8AEBAA8ADBCA8ADBDA9AEBFAAB0BFA9AFBDA7AEBBA6ADB9A6ADB9
A7AEB9A7AEBAA9AFBAA8AEBAA7ADB9A7AEBAA7AFBBA8AEBBA7AEBBA6ACBAA7AEB9A6ACB6
A5ACB5A6ACB4A5ABB4A5ABB5A6ACB5A6ACB5A5ABB5A4AAB5A2A8B3A1A7B2A1A7B0A1A7AF
A0A6B0A0A6B3A1A7B69EA5B59EA6B59DA6B49AA4B298A1B098A2AF97A1AE969FAC94A0AA
93A0A8929EA7929CA6919AA7919AA7909AA58F9BA38E9AA08D999D8C979B8C979C8B969B
89959A869194838F93818F92808E927E8B917D89937B88927A8890748289708083566768
242E37090E1803070D010206
697B82758791798A9A798A9E7989A47686A57382A37183A37285A47588A4778AA3798AA3
7989A57B8CA77D8FA77E8FA48091A28292A28391A48190A78192AB8192AB8493AB8694AC
8794AE8793B18592B28693B48795B18996B08C98B38D97B38F99B78F99B88F9AB9909BB9
909BB4909CB3929EB6929EB6919FB7919FB793A1B898A4BA9AA5BB9AA4BA9DA6BBA0A9BC
A1A8BAA1A7B9A2A8BBA3A8BDA3A8BFA2A7BEA3A8BEA1A7BDA1A7BEA4A9C0A3AAC0A2AABF
A2ABBCA2ABBCA3A9BEA4A9BFA4AABDA3AABCA6ABBBA6ACBCA4AABBA5AABBA6ABB9A7ADB7
A7ADB6A8AEB8A7ABB8A7ABBAA7ACBFA9ADC1A9ABC1A9ABC2A7AAC0A5A9BFA4A9BDA5AABB
A5ABBAA7ADBAA7ABB8A6A9B7A7AAB8A7AAB8A7AABBA8ABBBA7ABBBA5ABBAA4AAB9A5ABB8
A6ADB8A6ACB8A6ACB8A7ACB9A5AAB7A5ABB7A6ABB7A6ACB7A5ABB7A4AAB6A5ABB6A6ABB5
A5ABB5A6AAB4A4A9B4A1A7B4A1A8B49FA7B2A2A8B2A2A8B49EA5B29EA4B19EA4B09DA3AD
9DA3AD9FA5B0A0A4B49CA1B49AA1B4989FB2979EAF99A1B098A0B1969FAF95A1AE939FAB
919EA8929DA7929BA8919BA88E99A68C98A38D9A9F8B989B8A989A8B969C8A959D88939C
88959B828E94818D92818F93828E95808B95808A947D8A917B898D798689768185788685
5A67681619270C0D17090712
6C7D8A7587967B8C9E7B8AA37989A87787A87385A67487A57488A3778AA2788AA37B8BA5
7C8CA77C8DA98092AA8092A78092A48192A58290A68392AB8393AE8192AE8293AD8392AB
8694AD8693B18693B38694B28796B08B99B0909AB18F97B09098B38F99B58F99B6909AB5
919BB3939CB2939DB2939DB394A0B494A1B495A1B498A3B69BA4B99AA3B99BA4BA9DA7B9
9FA8B8A2A9BBA2A7BBA1A6BDA4A7BFA3A8BEA1A8BDA0A8BCA1A8BBA3A9BEA4A8C0A3AAC0
A3AABEA4ABBEA3A8BCA5AABDA6ACBDA3ABBAA5ACBBA5ABBAA5ABBAA4A9B8A3A9B6A4AAB4
A4ACB4A4ABB5A5ABB7A6ABBBA6ABBEA5AABFA5A9BFA6AAC1A5AAC0A4A9C0A5AAC0A6AABD
A6ABBBA8ADBAA8ABB9A7A9B9A8ABBAA9ACB9A9ACBAA8AAB9A8ACB9A7ACB9A6ABB8A5AAB8
A5ABB7A6ACB8A5ABB9A5ABB9A6ACB8A7ADB8A7ADB7A8ADB7A8ADB8A8ACB8A8ACB8A8ABB6
A7ACB5A6ABB4A4AAB4A2A8B4A0A9B39FA9B49EA7B39DA5B29DA5B29DA6B39EA6B39DA4B0
9DA2B09FA5B19DA3B49CA2B69BA2B699A1B399A1B099A1B099A1B197A0AF949FAD929FAC
909BAA909CAA919DAB909CAB8D9AAA8A9AA58999A089999F88979C8A989D89959D87949C
86959B829195828F92848F93848E95828B96818B967D889279868D7A868A798388798286
788486545C66373B4B2F3242
69798B7485987B8CA27A8BA47A89A77987A87686A67689A5788CA47B8DA47B8CA57D8CA6
7D8DA77E8EA97F8FA98090A78192A58494A88390A98391AB8392AD8292AE8394AF8494AE
8695AE8895B08895B08894AF8A97AF8D99AF8E98AE8E97AF9098B19198B39199B59199B3
949BB3959CB4949CB4949DB495A0B595A1B298A3B29BA4B59CA4B89CA5BC9CA5BC9DA5BA
9EA7BBA1A9BDA1A7BCA1A7BDA2A8BEA2A9BEA1A9BEA1AABEA2AABFA3AAC1A3A8C1A2A7C0
A3A8BFA3A9BDA3A8BAA5ABBBA5ACBCA4ABBBA4AABBA4AABBA5ABBDA2A9BBA1A8B9A3AAB8
A4ABB7A4ABB7A4ABB7A5ACBBA5ACBEA4ABBFA4AAC0A4A8BFA5AABFA5AAC1A6ABC3A6ABC0
A6ABBDA7ACBDA8ACBEA9ACBFAAADC0AAADBFA9ACBDA9ACBAA9ACB9A8ABB9A7ABBAA5AAB9
A5AAB9A5ABB9A5ACBDA6ABBCA5ABBAA5ABBAA7ADBCAAAEBEAAADBDA8ACBDA7ACBCA6ABB9
A5AAB6A4AAB5A4AAB6A3ABB7A1AAB59FA9B49EA7B39DA5B39CA5B29DA7B39EA7B39DA6B3
9CA4B29DA6B39BA4B39AA3B498A0B497A1B299A3B299A2B197A0B097A0B295A1B2929FAF
909DAD909CAA919CA9909CA98F9AAA8C9BA88A9AA489999F88989B8B9A9B8A9A9C88999B
879899859595859394859194848E94848F97828D987F8B987B89957C88937D89917C858D
79838A7682886C7980647478
6574897183997789A27789A37889A5798AA57688A57688A47487A27788A37B8AA57B8BA4
7C8CA67D8EA77F8FA8808DA68391A78693AA8491AA828EAA818EA9818FAA8492AE8593B1
8694B18795B28794B28996B18C98B18C97B08C97B08C96B18F97B18F98B29199B49299B4
949CB4949DB6929BB5929BB3939EB394A0B295A1B297A2B29AA4B698A3B999A4BA9BA5BB
9BA5BA9AA4B99BA3BB9DA6BE9EA7BE9DA6BE9EA5BF9FA6C09EA6C2A0A7C39FA8C3A0A6C2
9FA6C1A1A7BFA3AABEA4ACBFA3ABBBA4AABAA4AABBA3AABDA4AAC0A2A8C19FA6BF9FA7BE
A0A9BCA2ABBBA2ABB9A2ABBBA2A9BCA1A8BDA1A7BDA3A8BDA5A9BEA5A9BFA6AAC3A5A9C2
A5AAC0A4A9C0A3A8C0A5A9C0A6AAC1A5A8C1A6A9C1A6A9BEA5A8BDA4A7BDA4A8BDA3A8BC
A3A9BCA4A9BBA4AABEA5ABBFA4ABBFA4ACBEA3A9BDA4A9BDA5A9BEA3A9BCA3A9BDA2A8BA
A3A9B9A4ABBAA3AABAA1A9B9A0A9B89FA7B59FA6B5A0A7B79EA6B69EA7B69CA5B59AA2B2
9AA4B19AA4B299A3B197A3B095A1B095A1B196A0B1969FB1949DAF949EB096A1B2929FAF
909DAD909DAB8F9AA88C97A48B97A48B97A48B98A48998A188979D89979B87969A849399
829297829296829195828F94818D93818D96808D977E8B957C8A947C8A947C89947A8691
76838C7583897181856C7E7D
6372896F829A7489A3768AA77689A77789A67687A57585A47485A47687A57989A57A89A5
7B8BA57D8DA68290A88390A78491A78794AB8591AA8390A98390A98290A8828FAB8591B0
8691B28792B38791B28792B18A95B48A94B28C96B18E96B39095B49096B49197B59299B7
929AB5919AB5909AB5919BB5929DB5929DB493A1B493A1B396A3B695A1B896A2BB97A3BD
98A2BB9AA4BB9CA4BC9DA4BE9CA4C09BA4BE9CA4BE9DA6BF9EA6C19DA6C19DA5C19EA6C2
9FA6C29FA6C0A1A7BEA3A9BEA2AABDA3A8BBA3A8BBA1A7BCA2A8BEA3A8C2A1A6C2A0A6C1
A1A8BFA1A9BFA1A9BEA1A8BDA1A7BEA0A7BEA0A6BEA4A9C0A4A9BFA5A9BFA4A8C1A4A7C1
A3A7C2A4A8C3A3A6C2A4A7C3A6A9C5A4A7C4A4A8C4A4A7C3A3A7C2A4A9C3A4A9C2A2A7C1
A0A7C0A1A9C0A2AAC0A2AAC0A2ABC1A3ABC0A1A8BDA1A9BCA2A8BCA1A8BBA1A6BCA1A7BB
A2A8BBA2A9BBA2A7BAA2A7BAA2A8BBA0A6B89FA4B79FA5B79FA4B79EA5B79CA5B699A2B3
99A2B29BA3B39AA2B298A1B196A0AF96A1AF969FB0969FB1969FB0959EAE939DAD919CAC
8F9CAC8F9CAB8E9CAA8D98A78B97A48B97A48A96A28A95A18A95A089949F87929D85919D
83929D84939C839299829097818E967F8C987E8C997C89967A87947A879378859277848F
74838C7382897182846D7F7D
67778B70829A7286A27588A87588AA7386A97183A67183A67486A77789A8788AA5798AA5
7B8BA47C8CA57E8BA5818EA78390A98591AB828EAA818EA9838FA98491AA8491AA8794AD
8792AD8890AF8890B08791B08993B08C95B18E97B19097B39197B69096B69095B69197B8
9098B68F98B59099B6919BB6919DB7909CB7929EB5929EB3929DB3929EB596A1B996A2BC
959FBA99A2BC9BA3BC9BA2BC99A0BE9BA4C09AA4C09AA5C19CA6C09DA6BF9DA6BE9DA6BE
9DA5BE9EA6BE9FA6BDA1A7BCA1A7BCA1A6BCA1A7BCA1A7BCA0A6BCA1A6BDA2A7BFA1A6BF
A2A6BFA1A6BF9FA5BE9FA6BE9FA4BE9FA5C09FA5C1A2A9C2A2A8C0A2A7BFA2A8BFA2A7BF
A2A7C0A3A8C3A5A9C6A5A8C5A4A8C4A3A8C2A3A7C1A3A8C2A3A7C1A3A7C2A4A8C2A2A7C1
A1A7C29FA7C2A1A9C2A1A9C0A2AABFA2A9BEA1A8BDA1A8BBA2A9BBA1A8BBA1A7BCA3A9BD
A3AABEA2A8BCA0A5B99FA5B99FA6B99FA5B79EA3B49DA4B59DA4B59DA3B59AA2B499A1B4
9AA1B39AA2B298A1B196A0B1959EAF969DAD979EAE969EAF969FB1969EB0949DAD929BAC
909BAB8E98AA8E99A98F9BAA8E99A78D99A68C98A58995A28A95A38994A287919F85909F
84919E83919B84929A839099838E9A818B9C7E8A9E7A869B778596778695778793768690
75868D7385897183836F827D
6575896F819870849F7287A47286A67183A66E81A47084A77184A57285A57386A57587A5
7687A47B8AA67B88A67E8BA8808EA9828FAA828EA98290A98290A98391AA8492AB8593AA
8592A88692AA8691AC8793AD8892AE8A94AE8A94AD8B94AF8D95B28F97B58E97B68E97B7
8E98B68E98B38F99B28E98B28F9AB6909BB7909BB4909CB3909BB2929CB4949FB795A0B8
969FB8959DB8969EBB969FBB959FBB97A1BE99A4C097A3BF95A2BE97A3BD97A2BB97A3BB
99A4BC9BA5BD9CA5BB9CA4B99CA3B89CA3B99EA5BA9DA4BA9EA4BA9EA4BA9EA4BB9EA2BB
9EA4BD9FA6BD9DA5BA9DA5BB9EA6BD9EA5BF9FA7C29FA8C3A0A8C19FA8C09EA7BE9EA7BE
9FA7BFA0A7C0A1A7C1A0A5C0A0A6BEA0A7BDA0A7BF9FA5BF9EA3BCA0A5BEA1A6C0A0A6C1
A1A8C09FA7BF9FA8BF9DA6BD9DA6BC9FA8BCA0A8BC9DA6BA9CA6B99DA5BA9DA5B99FA7BC
A0A8BD9FA7BB9EA5BA9CA3B89BA3B69DA5B69CA3B49BA3B39CA5B69BA3B798A0B6979FB4
97A0B397A0B096A0AD949EAC959EAD949CAD959CAE939BAD919AAC919AAD8F99AE909BAD
8E9AAB8C98A88B96A68B96A68A95A58B95A58A95A58893A38792A28690A1828D9E828D9D
828E9C808E9A7E8E977F8D97808D97808B997F8B9C7B879A77879776889574859172838D
7183897083846D817F6C807A
67758C6A7B966D819F6D84A26F84A47386A77285A77185A76E83A57084A67388A87488A6
7689A6798BA77A8AA67D8CA67E8DA77F8DA77E8CA67E8DA67E8DA67F8FA88090A98090A8
8191A88191A78693AA8792AD8893AF8894B08894AE8894AE8B95B08D97B38D98B68B95B5
8D98B68D9AB58E9AB38D99B28C98B68C97B68B97B58C99B28D9BB2909CB3939DB4939DB6
959EB8939CB8919AB9939BB9939CB8939DB8939EBA93A0BB91A0BB93A1BC95A1BB949EBA
95A0BC959FBC96A0BA99A2BA9BA3BA9BA3BB9BA4BB9AA4BB9AA3B99AA3B99AA3B89AA2B8
9BA3BA9CA5BB9CA6B99CA5B99CA6BC9DA5BF9DA5C09DA5C09EA7C29EA6C29EA6C19EA6C0
9DA5BE9DA5BF9DA4BE9DA5BC9CA5BC9CA5BA9CA6BC9CA6BD9BA4BB9BA3BB9DA4BD9DA4BE
9DA5BF9CA5BF9CA5BE9AA5BC9BA5BA9CA7B89FA9B99EA9B99DA8B99CA5B89CA4B79CA4B9
9DA5B99DA6B99DA5B99BA3B79AA1B599A1B69BA3B79AA4B89AA5B899A3B897A0B5959EB4
969EB4959FB2959FB0939EAE929DAD929CAC909AAC8F9AAC8D99A98E9AAA8E99AA909AAD
8E99AD8D98AB8B97A98B95A78892A48992A58993A58692A38591A28491A2808D9E808D9F
808EA1808FA07C8D9C7C8D9C7D8D9C7D8C9A7C8B9879869676859677889774859371828E
7083896F83836E82806B7F79
6774906C7C9C6E82A46F85A67083A57284A77486AA7385AA7186AA7287A97489A6778AA7
778AA7798AA77B8CA87C8DA87E8FA87F8FA7818FA77F8DA77E8CA77F8EA9818FAB8191AB
8192AB8190A98592AC8692AF8691B08792AF8996AF8996AF8B96AF8B96B18D96B58C96B8
8A95B78A96B78C98B68E99B88E9BBA8C99B98B98B68B99B38E9CB4909BB3939CB5939CB6
969EB8959CB8949CB8959BB9959CB9939BB7949EBA95A1BB94A0BB949FBB98A2BE99A2BE
98A0BD97A0BB99A0BB989FBB999FBC9CA2C09DA4C09CA4BE9BA4BD9CA5BC9CA6BB9BA3B9
9BA3B89CA5BB9DA7BC9BA4B89CA5BA9EA5BF9EA5C29EA6C29FA7C3A0A7C3A0A6C29FA5C2
9EA5C29EA6C29EA7C19EA7C09DA7BE9BA6BD9AA6BF9AA6BF9BA6BF9BA5BC9DA4BC9CA3BD
9AA2BE9BA5BF9BA6BF9CA6BD9DA7BC9EA8BB9DA8B89FAAB7A0AAB79FA8B79FA8B89EA7BA
9FA7BB9FA7BC9EA6BB9DA5B99DA3B89CA2B89CA4BA9DA5BA9CA6B99BA3B798A1B699A1B6
98A1B6979FB5959EB4949DB5939EB5929CB3909CB1909DB0909DAD919CAE919AAD9099AD
8E98AE8D97AC8B95AA8B96AB8B96AA8C97A98B97A88795A58694A48593A58390A3828FA4
8290A78290A67E8EA27B8BA17B8B9F7B8C9C7A8B9978879877859A78879B758596758692
74868D7285877084816D827A
6873917381A17484A77384A77282A67282A67584AA7483AA7485AA7386A87587A67888A8
7988A87A89A87C8CA87E8DA77F8DA6818EA6828DA7848FAA848EAC838EAE838FB0828EB0
8390B18591B18592B18591B18890B08992B08993B08B95B08E98B38D97B38C97B68E97BA
8C96B88A94B58A93B48D96B78F99B98E99B98D99B78E99B4919CB3929CB3939BB3959CB4
969DB4969CB2969DB3979DB5999EB6969CB6969CB798A0B999A0BA979EBA999EBB9AA0BC
99A0BA99A0B99A9FB99CA0BB9B9EBD9C9FBD9DA0BE9CA1BF9CA1BF9CA2BF9EA4BD9DA3B9
9BA1B79DA4B89FA6BB9EA4B99FA3B9A0A4BBA0A3BE9FA3C09FA5C1A1A6C1A1A5C0A1A5C0
9FA3C09FA4C19EA4C19DA3C09DA4BE9CA3BE9DA5C09DA5C09DA6BE9FA6BBA0A4B99EA3B9
9DA2BB9CA2BC9BA1BC9CA4BC9FA6BE9FA5BD9EA5BA9EA4B79EA3B69FA3B6A0A5B79EA5B7
9FA5B99EA4BA9DA3B99DA3B89CA1B59CA0B39B9FB39BA0B59DA2B69BA0B499A0B3979EB2
979EB2989EB2989EB2979CB3959CB4939BB3929BB0929AAF939BAE939AAF9096AC8F95AB
8E94A98E95A98C94A98B93A98990A58993A48892A186919F8591A08490A1838EA2838DA2
838DA6808BA57B88A17B89A07B8A9E79879A788698768396768296768396758193758290
74828D7282896F80816A7C78
646D8A6A7796707FA16F7FA37281A57281A67280A57584A87685A87687A87686A87887A8
7A89A77B8AA67B8BA57D8DA57E8BA5818EA7808CA7828DA9848DAD828DAF818EB1818EB2
818EB2818FB08291B08392B08592AF8792B08992B18A93B28A94B38A94B48B96B68D96B7
8D96B68B96B68B96B68E99B78F9AB58D96B28C96B18E97B2909AB3919BB4919BB3929CB2
919AB1939BB1969EB2969CB3969BB4969BB5969CB6979DB7979DB7979EB89AA0BB9AA1BD
9AA0BA9AA1BA9BA0B99CA0BB9CA0BE9CA1BE9AA0BD9AA1BC9AA1BD9BA2BD9AA0B99BA2B8
9CA4B89CA4B89DA3B69FA4B79FA4B89FA2B89DA0B89CA0B89EA2BBA0A5BDA0A4BDA0A4BF
9FA2C09FA2C19FA3C19FA3C19FA3BF9EA3BD9FA4BE9EA5BC9FA5B8A0A6B89EA3B69CA1B6
9EA2B99EA5BC9BA2BB9BA2BB9DA3BB9FA3BB9EA2B99D9FB69EA1B89EA0B79FA1B79FA2B7
9EA2B79BA2B699A0B699A0B69BA1B6989EB299A0B2999FB4989FB5979FB4969EB4969EB3
979FB1979EAE979CAD979CB0959BB1929AB09199AF8F96AC9097AC9299AE9095AA8D93A8
8D94A88B91A68B92A68A91A6878FA38791A286929F85909B85919D828D9C828D9D828D9F
828BA08088A27D88A27C879F7D8A9D7B889A7A8598778295748091758193768294748091
707E8D6E7E896D7E81687B77
636E8A6C79967180A07382A57381A57180A47281A47584A77887A97989AB7889AA7688A7
7789A4798AA37A8BA27D8DA47F8CA6808CA97F8AA97F8AAB818BAC828DAD818DAE818FB0
808EAF7F8EAC7F90AB8091AB8392AB8491AB8591AE8792B18894B28995B28A95B18A93AE
8C95B28D97B58E99B68D99B68E9AB38D99B18D97B18D97B18F98B28F99B28E99B18E9AB1
8E98B1919AB2949CB4959CB6949BB7949BB7959BB7979CB9979CB9969AB8979CBA999FBB
99A0BA99A1B99AA0B79A9FB79AA0BA9AA1BC99A1BB979FB897A0B79AA2B798A1B499A3B4
98A3B398A3B298A0B09BA2B29DA3B69EA4B79EA3B79EA3B69FA4B79FA3B9A0A4BBA0A3BC
A0A3BF9EA3BF9FA4C09EA2C09DA1BE9DA2BE9DA3BC9AA2B79BA2B49BA3B59CA2B59CA2B6
9BA1B69BA2BB9BA3BB9CA3BA9BA0B79CA1B59DA1B69C9FB69C9EB69DA0B69C9FB59DA1B6
9DA3B79BA2B7989EB4969CB3969EB4979FB2979FB1979EB3969FB5959DB5939BB3939CB2
949DB2949DB0939BAE939BAF9199B08F97AE8E97AC8C95A98D96A98F96A98D94A78C92A4
8A90A48890A3868FA18790A2868FA1858FA18491A183919D808F9A7F8E99808E9B808D9D
808B9E808AA07D889F7C889E7C889D7A8698798394788293758091737F92738195707F91
6E7E8C6C7D856A7C7F677A77
616D886A7794717D9E727EA3717EA3717FA37481A27785A47887A77986A97887A97789A6
7588A47789A57888A37B8BA37F8CA67F8BA97F8BAB7E8BAA7F8AA7818EA78390AA8390AB
818FAC808FAC7F90A98090A88290A68390A88490AC8590B08793B28B96B18B95AE8D95AE
8F96B18F97B58F98B88E97B78E98B68C96B18E97B08E95AE8F96AF9097B08F97AF8E98AF
8E97AF9198B09299B39399B59398B79299B9939AB9959CB8959AB79499B8969BB9969CB8
969EB7969EB498A0B49AA0B59A9FB699A0B999A1BA979FB6969EB398A0B199A0B09AA0B1
98A0B198A1B298A1B198A1B199A1B29BA3B69DA4B99CA3B69CA3B39CA2B29DA2B39FA2B5
9FA3B89EA3B99EA4BA9DA2BA9B9FB99A9FB99AA0BA979EB798A0B69AA1B69AA2B69CA2B8
9CA1B9999FB99AA1B99AA2B89AA1B49AA0B39DA1B49DA1B69C9FB59A9DB3989DB1999DB1
9DA1B39BA0B2989DB2959BB3969DB3959EAF959CAD959BAF939AB1949CB3939CB2929CB1
929BAF9199AE9098AE8F97AF8C96AE8A93A88A94A58B95A38D96A48C94A38C94A38B92A2
8990A18991A087909F88909F8990A0878FA1848FA1808D9D7F8D997D8B977F8D997F8B9A
808A9D80889E7E879E7C86A07A859E798499788294788094777F96747D96727E966E7D91
6C7E8B6B7C83697C7D687C77
606B856976926F7C9C727EA1707CA2717EA37481A27381A27583A57886A87785A67787A6
7889A6788AA67989A57A8AA57B8AA37D8AA57E8BA77E8BA87E8BA47F8BA2818DA4828DA6
838DA8828FA9818FA8808FA78392A88492A88492AA8592AC8691AC8993AC8993AA8B94AA
8D94AC8F95B08E94B28F95B38E95B28D93AF8F96AF8F96AF8F95AE9096AD9198AF9299AF
9097AD9196AE9297AF9297B29398B79198B99198B99399B7929AB59299B69298B5949AB6
969DB6969DB4969CB2989CB3989CB59599B6959BB6969DB4979EB1979DAE999DAF999DAF
989EB0979EAF969EAE979EAE969EAE979EB2969DB4969EB596A0B298A2B09BA2B09DA2B1
9EA2B49DA2B59EA2B79CA1B69BA0B5999FB4989FB5969CB4959DB3969EB4979DB4999DB5
9A9FB7989EB5989EB7989FB6969EB3979EB2999FB19A9FB39CA1B49A9EB3999DB2999CB0
9A9DB2999CB1999DB3979DB5969DB2959BAE9299AB949AAD9399AD9299B0939AB0929BAF
919AAD8F96AA8E96AA8E96AC8B94AB8992A58A94A38D94A28E94A08F94A08C92A18B92A0
8B92A18A919F88909D858D9A868D9C898FA0858DA0808A9D7F8A9B7D89987F8A987F8899
80889A81889C7F859D7C829D79809C79819B787F98777D96767C97757C97727D956E7C90
6A7B886A7C83697C7E687B78
636E896B7895707F9D7180A0727FA1717EA27380A4717EA27481A57685A77583A67685A7
7888A87A8AA97B8AA97A89A97B8BA77F8FA87F8DA77F8BA6808CA6818CA5818CA5818CA7
808CA7818DA7808DA7818FA88290A88391A98492AA8693AC8793AC8994AB8993A98C95AB
8D95AA8D95AA8C93AB8D94AD8D95AE8E96B08D94AF8E95B18D95AF8E97AE8F98AE9096AE
9096AE9197B09197B39197B49297B79299B9939ABA939AB9929AB99198B89198B6919AB5
959DB5969DB4969CB2979CB3979CB3949AB4959BB7959CB6969EB5979DB5989DB5999DB3
999FB1989FAF979FAE959CAC949CAC949DAF949CB2969FB4959FB398A1B399A0B29AA0B3
9C9FB39CA0B69DA0B79CA0B89CA3BA9BA2B99BA1B79BA0B69BA1B599A0B5979DB3979CB3
979DB4979EB5979EB6989FB7969DB6979EB59A9FB5989DB49A9FB5999DB49A9DB39C9DB3
9B9BB49B9BB5999BB6979CB4969CAE959CAD939AAB939BAB939BAC9299AC9097AC9098AC
8F97AC8F98AC8D97A98C96A98B96A98B94A58C93A38D93A28C919F8D92A18A91A1878F9E
87929D88919C878F9B858C9C848B9D858C9F868DA0828A9F828A9E80889D7F879C7F859B
80849D80839D7D829D7B819C7A809D79809C777E99757D99747D99747E98727D936C798B
6A7888697A8566787F647779
636D886977946D7C9B707F9F727F9F727FA1727FA2717EA27380A47481A37683A47B89A8
7B89A97B8AA97A89A87A89A97C8AA97F8DAB7F8DAB7E8AAA7F8BAA818CA9828DAA808CA9
818EAA818EAA828EA9838FA98390AA838FA98591AB8692AB8691AB8893AC8A95AD8994AA
8A95A98A94A98A93AA8A92AB8A91AC8B93AE8D94B08C94AF8C93AD8D94AE8D93AF8E93AE
8D94AE8F95B09197B39096B49095B39196B59298B79299B99198B99199B99299B8929AB7
949CB6969DB4959CB3939AB0959BB1949BB2949CB4959CB6969CB8969BB6969BB4979CB3
979DB1969CB0949BAD949BAC949DAE929BAF949CB298A0B698A0B7979FB7979EB5999FB5
9A9FB5999EB59A9EB79B9FB99BA0BB9BA1B99DA2B89DA1B49B9FB19B9FB19A9EB3999EB5
999EB5979DB5979DB5989EB8989DB8989DB6999DB7999CB7999CB7989AB5989AB3989AB2
9A9CB2999AB3979AB49599B0939AAB949BAD939BAF9199AD9099AC9099AC8F97AB8F97AB
8D95AA8B93A88D95AA8D96AA8D95A98D95A78D92A48B91A38A8FA2898EA1888FA1858E9F
858F9C848E9A858E9C858D9D838B9D828A9D838A9F81899E80889E80879E7E849D7D839D
7D829E7D829E7B809E797F9C777E9B757D99737C95707A91707B92727C92717B8F707A8C
6C77896A768766768263757B
636E876875926C7B9A6F7DA0717FA3727EA3707DA1717EA27481A47481A27683A27986A6
7A88A87989A67989A47B8AA57E8CA77F8CA97E8DAB7D8BAD7E8CAC7D8AA8808CA9818DAA
838FAB838EAB828EAB838EAB8390AC848FAB848FAB8691AE8692AE8691AD8590AB8693AB
8896AC8894AC8B94AD8A93AC8A93AC8B94AF8B93B08B93AD8C94AE8F95B08F94B19095B2
8F95B19197AF9298B09398B19397B19398B39298B59297B69196B69298B6939AB6949BB5
969DB6959CB59399B49298B2949AB2949BB2959BB4959BB5959BB7969BB4999DB2999CB1
989BB0979BB0969CB1949BAF959CB0939BAF949BB0969DB3979EB5979EB6989EB7999EB6
999DB5999DB5999DB6999BB6989CB5989DB3989DB1999DB0999DAF9C9FB39C9FB69B9EB7
9A9DB6989CB6999DB69A9EB7989CB4989CB4989BB5989AB6999CB4989CB3979BB2979BB1
989BB1969AB19498B09299AE9298AC9398AE9398B09197B08E96AE8E97AD8E97AB8E96AA
8F95A98D93AA8E94AD8C92AA8C91A88C92A68C91A6898EA4898EA4888EA4888DA4868DA3
858CA2828AA0838AA0848AA18488A08387A18288A28086A27E84A07C839D7D829D7C809B
7B7F9B7A7D9B797F9B787F99757C96747B94727B9270798E6F798D70788E6F778E6E778D
6A758B69748766748161727A
636F896975926D7B9B6F7CA0717DA3727DA4717BA2717DA27580A37782A37781A17985A4
7885A67887A67A89A57A8AA57C8CA67D8CA77D8CA97D8CAB7E8DAC7F8DA97F8EA6808EA4
8290A5828FA7838EAA848EAB848EAB8490AA838EA8848FA98690AC858FAA838EA88491AA
8693AB8995AC8C95AE8C95AF8B94AF8C96B28A93B08B94B08B95AE8D95AE8E94AF8F96B1
8F97B1929AB0939BAF939AAE9297AD9398B09197B29298B49198B49197B29299B29299B2
9399B19399B29196B29196B39096B39198B3949AB5939AB6949AB7959AB4979CB3969BB2
989CB3979CB3949AB2939AB0929BAE929CAD949DAE949CAF959DB3959CB4959CB4979DB5
969BB3959AB0979AB1999BB4989BB4979CB2969BAF979CAF989DB29A9DB3999CB49A9CB6
989BB5969BB3979CB2989DB2989CAF979CAF979BB19599B19599B0959AB0969BB0959AB1
969AB29499B29297B19197B09196AD9094AB9195AD8F95AF8C94AE8B94AB8A93A98B94A8
8B93A68D93A88D93AC8C91AB8B92AA868FA58890A38A8FA3888DA3898CA5888DA7878CA7
858CA6828AA180899F82899D82899F8287A18186A17F86A37C84A177809B7981997A8197
7A7F99797E99777D99767F9A727C97707A94707A936F79926F798F6D768E6B748E69728C
65718A657287647381607178
636E8667738F6D7B9A717EA1737EA3747DA3747BA2737AA1777EA27880A27880A27B85A6
7986A57986A47B89A57C8BA67C8BA67C8BA67C8CA57D8DA57F8EA77F8CA57E8CA27C8CA0
8190A1828FA1858FA3868EA4858DA58590A88590A9868FA98790A9868FA9868FAA8890AD
8991AF8890AE8C93AF8D94B28C95B28A93B08B93B18C94B18C95B28B94AF8B95AF8B95AF
8B96AD8E98AD9099AD9097AC9096AB9197AD9197AF9297B09198AF9197AD9399AF9297B0
9196AF9095AF9095B09095B18F94B18F95B19097B39097B49198B39298B19299B09399AF
9398AF959AB1949AB19298AF939AAD939CAC949DAC949CAE949CB1939AB2949BB3969BB3
959AB19699AE9699AF999CB4979AB2949AB0959BAF949AAB959AAC979BAF979AB0979AB4
9598B39398B0949AAF9499AB949AAA959BAA9499AB9397AD9296AE9296AF9396B09397B1
9297B29196B29094B19195AF9195AE9195AD9094AC8E94AB8C93AB8B93AA8A93A98A92A8
8990A5888FA68A91A88990A78A91A78891A48890A1898F9E888C9E898DA1878BA38589A4
8289A47F889E7D889C7D869A7E859A7E859B7D839C7D859F7B839E78829B778198757E95
767C96777C98757B98737A997079986E78956D75926B738F6C738F69708E676F8D666E8C
636F89626F876170825E6E76
666E8468718D6C769670799B737C9D757C9F7579A17578A1787CA3777EA27882A17A85A2
7A85A17A85A07B87A07C88A17D8AA47E8CA6808DA57E8CA27E8BA27D89A17E8AA27D8BA2
808EA3828FA2848FA0848DA1858DA5878EA98990AD8991AE8992AC8891AA888FAB898EAD
8D91B28C90B28A8EB08C91B08B92AC8890A98B91AB8C92AD8B91AF878EAC858EAA8490A9
8692A98892A68D95A88E94A98F95AA8E95A88E96A98F97AA9097A99097A99197A99296AA
9297AC9096AC9197AD9299AD9198AC9298AD9095AD8F96AF8F96AE8F96AB9096AA9095A8
9094A79296A99398AB9399AC9399AA9299A7939BA8939AAA9499AC9397AD9497AE9599AF
9497AE9597AE9698AE9699B09698AF9498AD949AAA9399A69397A69699AC9799AF9598AF
9599AF9598AD9498AB9497A99498A99499A99497A89294A89193AB9294AF9495B09395B0
9295B09396B09193AE9294AE9193AD9193AC9093AB8D92A88C92A68C93A98B92A8888EA4
898FA3888EA3888EA3888EA3888FA18A91A2898FA0878D9E888C9D898D9F888A9F8588A2
8386A38186A27E859E7C83997A82967C83967D82977C83987C8197797F97777E98757C95
757B95767C967379957177956F76956E76956C74926C73926B7392697190656D8A656D89
656E88626C845F6B7F5D6C77
696D816D728C737995757C9A777D9C777A9B76799E777AA17A7DA47B80A47C84A17C869F
7B839D7C849F7C86A07C869F7C89A27F8CA5818EA4808DA0808BA0828CA4828BA5808AA5
808CA6838FA58690A3878FA2878DA58A8EAA8B8FAE898FAE8990AC898FAA898EAA8B8FAD
8E92B08D91B18A8EAE898FAC8A91AB8C92A98B91A78B90A7898EA7888DA8858BA6838AA4
828BA082889C83879D8789A2888AA2878BA1858BA0868EA088919F89919E8C93A18E95A4
9197A88E95A68F97A7919AA9929AA9939BAA939AAB9399AE9096AB8F96A89198A89297A5
9397A59498A7969BAB9499AA9396A79498A69599A79498A89698AC9497AC9498AE9397AD
9296AC9497AD9698AE9799AF9899AF9597AD9497AA9599A99497A79698A89697A99596AA
9597AC9598AC9497AA9496A89597A99597A99497AA9193A99092A99294AA9192AA9092AA
9395AD9495AE9192AC9294AD9293AB9092A88F93A68F92A48F91A48C8FA38A8FA2898FA1
8B90A08C91A1898EA1878CA1878CA1878CA1868BA0858A9E868A9C898C9D88899C86869F
8585A18185A27E839F7B83987C84967D83957C81947E82977C80977B7E97797D97787D97
787C95777A927579927377937176956D73956970926A72916B748E6A738B677088676E87
676C86656A8361687D5D6775
696C8073768D777D97787E9A797D9A797C9A797B9B7B7C9E7C7FA17C80A27E84A07F859C
7F849A7F859C8288A18088A17F89A27F8DA1818EA0828E9F838D9E848DA1848CA38188A3
8089A2838CA1868FA1888FA1898EA38A8EA88B8EAB8A8EAB898EAB898EA9898EA88A8FA8
8D91AB8D91AD8C90AD8A90AA8C93A88E94A68E93A58D91A38B8FA48A8EA7898DA7868CA4
858BA084899C85869B85849C83819D81819C7D7F987D81967E83937F8492818594838796
848998828A98848D9B87919E8994A08D96A18F96A29098A59097A69098A69199A4929AA3
9299A39398A69598A8949BAA9298A79299A6949AA59498A49597A59598A89497AB9298AB
9196A99297AA9598AB9598AB9596AA9394AA9294A99295A79396A79597A89596A69494A6
9696AA9395A89295A79295A69497A89597A89697AB9396AB9092A79093A59194A79294A6
9394A69392A69292A89393A99193A69193A29093A18E90A08C8E9E8C8F9F898E9E898F9E
8A8F9C8C919C8C909C8B8D9E8A8BA086889F86899F868A9D878B9D888B9B87889A87879C
84839C80819E7E829D7B81977A81937B81937B80927D80957E80987C7E97787B93787C92
777B9078798E77798F75768F7374907072906B7090686E8C687188687185686E83696D82
65687F64677F64687C5D6271
6A6D8073788C767C93777B95787A94797B967A7C987B7D9A7B7E9C7D819D7F849E7F839A
7F849980859C8289A08189A0818AA0808C9F828D9D848E9C828C9C858D9E848CA1848CA1
848BA1878EA08990A0898FA2898FA48A8DA68B8DA78A8EA88A8EA8898EA7888DA68A8FA6
8E92A78C90A78C91AB8C91A98D94A88E94A48F94A38E91A28D90A38E91A68D92A68E92A6
8C91A48C8FA28B8CA08989A086839E84829D8181997E7F937D7F8F7E808D7E7F8D7C7D8E
7B7D8F787C8D777D8E787F8F777F8E7E8691858B95898F998D939D8E979E919A9E919A9D
90989E9198A39096A49299A59098A39099A39299A29399A09498A09699A49495A59194A4
9296A59397A79497A89698A89495A79393A79193A59094A39295A49296A39193A19293A3
9595A79294A69296A69397A69498A69395A69495A99497AB9093A68F93A59396A59395A3
9393A29291A19393A39192A290929F90939C8F929B8D919B8B8E9A8B909C888E9C898F9B
878E97898F968B90978A8E97898A9B87889D86869D86879B898B9C878998878897888799
8382977F7F987F829A7D81977A80937A80917C80917C7F927E80947C7E9277798D777A8E
77798D76768B75748A75758C72728B70718C6D718C686C87666E84676F82686E80696C7D
64667B64667A6367775F6571
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.392007 0.97619 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FFFF8000FF80000000FFFF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 300},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001;2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`003Ooooon]0?n001[ooooo[@3oP00?ooooo`003Ooooon]0?n001[ooooo
[@3oP00?ooooo`003Oooool50000ojP0oh006_ooool50000ojP0oh003oooool000gooooo1@000?nX
0?n001[ooooo1@000?nX0?n000oooooo000=ooooo`H0003oY`3oP00Jooooo`H0003oY`3oP00?oooo
o`003Oooool20?n000@0003oY`3oP00Jooooo`80oh0010000?nW0?n000oooooo000=ooooojd0oh00
6_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]
0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oo
oooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=
ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0
oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oo
oon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n0
00oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo
000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=oooo
ojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh00
6_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]
0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oo
oooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=
ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0
oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oo
oon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n0
00oooooo000=ooooojd0oh006_oooon]0?n000oooooo000=ooooojd0oh006_oooon]0?n000oooooo
000=ooooo`80003oZ`3oP00Jooooo`80003oZ`3oP00?ooooo`003Oooool90000oj@0oh006_ooool9
0000oj@0oh003oooool000gooooo3`000?l00`3oP000003o0?n0002K0?n001[ooooo3`000?nN0?n0
00oooooo000=oooooa80003oV`3oP00Joooooa80003oV`3oP00?ooooo`003OoooolB0000oi/0oh00
6_oooolB0000oi/0oh003oooool000gooooo4`000?nJ0?n001[ooooo4`000?nJ0?n000oooooo000=
oooooaH0003oU`3oP00JoooooaH0003oU`3oP00?ooooo`003OoooolH0000oiD0oh006_oooolG0000
oiH0oh003oooool000gooooo60000?nE0?n001[ooooo5`000?nF0?n000oooooo000=oooooaT0003o
U03oP00JoooooaT0003oU03oP00?ooooo`003OoooolL0000oi40oh006_oooolK0000oi80oh003ooo
ool000gooooo7P000?n?0?n001[ooooo7P000?n?0?n000oooooo000=ooooob00003o103oP0000`00
0?l0oh000?n000260?n001[ooooo80000?l40?n000030000o`3oP000oh0008H0oh003oooool000go
oooo7`000?l30?n000H0003oQ@3oP00Joooooal0003o0`3oP0060000ohD0oh003oooool000gooooo
;@000?n00?n001[ooooo;@000?n00?n000oooooo000=ooooobh0003oO`3oP00Jooooobh0003oO`3o
P00?ooooo`003Ooooold0000ogT0oh006_oooold0000ogT0oh003oooool000gooooo=P000?mg0?n0
01[ooooo=P000?mg0?n000oooooo000=ooooocL0003oMP3oP00JooooocL0003oMP3oP00?ooooo`00
3Oooooli0000obd0oh000P000?l;0?n000030000o`3oP000003o03L0oh006_ooooli0000obd0oh00
0P000?l;0?n000030000o`3oP000oh0003L0oh003oooool000gooooo>P000?l]0?n000030000o`3o
P000oh0000X0oh0000<0003o0?n0003oP000=P3oP00JooooocX0003o;@3oP0000`000?l0oh000?n0
000:0?n000030000o`3oP000oh0003H0oh003oooool000gooooo?`000?le0?n00080003o=`3oP00J
ooooocl0003o=@3oP0000`000?l0oh000?n0000f0?n000oooooo000=oooood40003o?`3oP0020000
o`@0oh0000<0003o0?n0003oP000903oP00Joooood40003o@03oP0000`000?l0oh000?n000020?n0
00030000o`3oP000oh0002@0oh003oooool000gooooo@@000?lo0?n00080003o103oP0000`000?l0
oh000?n0000T0?n001[ooooo@@000?m00?n000030000o`3oP000oh000080oh0000<0003o0?n0003o
P000903oP00?ooooo`003Ooooom20000ocH0oh002`000?l40?n000030000o`3oP000oh0002<0oh00
6_oooom20000ocH0oh002P000?l50?n000030000o`3oP000oh0002<0oh003oooool000gooooo@`00
0?l00`3oP000003o0000o`020000oc00oh000`000?l20?n000L0003o:@3oP00Joooood<0003o00<0
oh000000o`000?l00P000?l`0?n00080003o0`3oP0060000obX0oh003oooool000goooooBP000?l^
0?n00080003o1P3oP0040000obT0oh006_oooom:0000obh0oh000P000?l70?n000<0003o:@3oP00?
ooooo`003Ooooom@0000oc40oh000`000?l20?n000030000o`3oP000oh000080003o1`3oP0020000
oaT0oh006_oooom@0000oc80oh000P000?l20?n000040000o`3oP000oh000000o`P0oh000P000?lI
0?n000oooooo000=oooooe80003o<@3oP00010000?l0oh000?n000000?l20?n00080003o8P3oP00J
oooooe80003o=03oP0000`000?l0oh000?n000020000ob80oh003oooool000goooooE0000?lf0?n0
00@0003o7`3oP00Joooooe@0003o=P3oP0030000ob00oh003oooool000goooooFP000?mC0?n001[o
ooooE`000?l00`3oP000003o0?n0001C0?n000oooooo000=oooooe/0003oDP3oP00Joooooe/0003o
DP3oP00?ooooo`003OoooomN0000odl0oh006_oooomL0000o`030?n000000?l0oh0004h0oh003ooo
ool000goooooH@000?m<0?n001[oooooH@000?m<0?n000oooooo000=ooooof<0003oBP3oP00Joooo
of<0003oBP3oP00?ooooo`003OoooomW0000odH0oh006_oooomW0000odH0oh003oooool000gooooo
J@000?m40?n001[oooooJ@000?m40?n000oooooo000=ooooofT0003oA03oP00JooooofT0003oA03o
P00?ooooo`003Ooooom/0000od40oh006_oooom/0000od40oh003oooool000goooooK`000?ln0?n0
01[oooooK`000?ln0?n000oooooo000=ooooog<0003o>P3oP00Jooooog<0003o>P3oP00?ooooo`00
3Ooooome0000ocP0oh006_oooome0000ocP0oh003oooool000goooooM`000?lf0?n001[oooooM`00
0?lf0?n000oooooo000=ooooogX0003o<`3oP00JooooogX0003o<`3oP00?ooooo`003Ooooomm0000
oc00oh006_oooomm0000oc00oh003oooool000goooooP0000?l]0?n001[oooooP0000?l]0?n000oo
oooo000=oooooh80003o:`3oP00Joooooh80003o:`3oP00?ooooo`003Ooooon30000obX0oh006_oo
oon30000obX0oh003oooool000goooooQ@000?lX0?n001[oooooQ@000?lX0?n000oooooo000=oooo
ohH0003o9`3oP00JooooohH0003o9`3oP00?ooooo`003Ooooon70000obH0oh006_oooon70000obH0
oh003oooool000goooooQ`000?lV0?n001[oooooQ`000?lV0?n000oooooo000=oooooh/0003o8P3o
P00Joooooh/0003o8P3oP00?ooooo`003Ooooon=0000ob00oh006_oooon=0000ob00oh003oooool0
00goooooS`000?lN0?n001[oooooS`000?lN0?n000oooooo000=oooooiH0003o5`3oP00JoooooiH0
003o5`3oP00?ooooo`003OoooonG0000oaH0oh006_oooonG0000oaH0oh003oooool000goooooVP00
0?lC0?n001[oooooVP000?lC0?n000oooooo000=oooooi`0003o4@3oP00Joooooi`0003o4@3oP00?
ooooo`003OoooonP0000o`d0oh006_oooonP0000o`d0oh003oooool000goooooY@000?l80?n001[o
ooooY@000?l80?n000oooooo000=ooooojT0003o103oP00JooooojP0003o1@3oP00?ooooo`003Ooo
oonY0000o`@0oh006_oooonY0000o`@0oh003oooool000goooooZ`000?l20?n001[oooooZP000?l3
0?n000oooooo000=ooooojd0003o6_oooon]0000o`oooooo000=ooooojd0003o6_oooon]0000o`oo
oooo000=ooooojd0003o6_oooon]0000o`oooooo000=ooooojd0003o6_oooon]0000o`oooooo000=
ooooojd0003o6_oooon]0000o`oooooo000=ooooojd0003o6_oooon]0000o`oooooo000=ooooojd0
003o6_oooon]0000o`oooooo000=ooooojd0003o6_oooon]0000o`oooooo000=ooooojd0003o6_oo
oon]0000o`oooooo000=ooooojd0003o6_oooon]0000o`oooooo000=ooooojd0003o6_oooon]0000
o`oooooo000=ooooojd0003o6_oooon/0000o`030?n00?oooooooooo00gooooo000=ooooojd0003o
6_oooon]0000o`oooooo000=ooooojd0003o6_oooon]0000o`oooooo000=ooooojd0003o6_oooon]
0000o`oooooo000=ooooojd0003o6_oooon]0000o`oooooo000=ooooojd0003o6_oooon]0000o`oo
oooo000=ooooojd0003o6_oooon]0000o`oooooo000=ooooojd0003o6_oooon]0000o`oooooo000=
ooooojd0003o6_oooon]0000o`oooooo000=ooooojd0003o6_oooon]0000o`oooooo000=ooooojd0
003o6_oooon]0000o`oooooo000=ooooojd0003o6_oooon]0000o`oooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo000=ooooo`06010A2@0@
4@P04A4:014A2`0@40h04a<A0P0E5Q802`0G61805QL?01HG3`0H61005aP@01PJ400G6a0051L=01@G
3P0E5`h05QP?008061T?00/05aT>01DH3P0D60d04aH=014D3@0C5`l04aP@01@H400C61405APB01PJ
4`0201PI4`0<01TI4`0I6Q806A/A01TK4P0I71<06AdD01TM4`0I7Q806QlC01TN4P0I7A405aXA0P0G
6a<02`0J7Q@06QhC01PK4@0H6a006A/A01XL4@0M7a<071lC01`M5@0L7QL06adF00<0720I00X06alG
01XN5P0I71D06QhE01PL500G6a<061`B01TL4@0H6a406Q`B0P0J7A<02`0K7QD06alH01XO600K7aL0
7B0H01/N5@0J7A@06A`D01PJ500K7QL071lF0080720D00`06QhC01dP5P0K7Q@06alE01`P5P0L7aH0
7R0F01dO4`0L7A<07AhE01dN5P0M7QD201dN5P0301/M5P0J7AD06QdF008061/E00H061/D01TK4`0K
71@06Q/C01TK4P0H6A4201PJ4@0;01XL4`0F5a405AHA01DF400E5Ph05aL@01LG4P0E5A4051@?01HG
4P0F5Q800P0E5100300A40/04a<;01<D3@0C50`04aD=01DI3@0B5`d041D<014D300?4PT03Q4800h@
2@803Q4900/03Pl700h>1`0?4@/03Q<@00hB500=41L03PhH00l<5@0>30h03@h;00X<2@0200`>3008
00`@3P082`d00@8500000P000@40000100000`0100D200001P090000100000<0000300000`000080
000100800@030@400`0001[ooooo[@3oP00?ooooo`003Oooool01P0i@3P0?DDm0419@@11Bd<0>D0m
02<X:`806alP00/0724L01LK5@0F6a805a/?01TO400L8A80720B01dQ4P0M81407B0B01`O4@0201dP
4P0;01dQ4P0L8A80728C01XO4`0K81<0724D01XP4`0K8QD0728G01hS600P8aX00P0O8aX0200P8aX0
82@H024U5`0P91L07B8E01dS5`0N9AP082PF0P0S:QT03`0S:1T08RDH028V6@0R9QT092PJ028W600Q
9QL08RLH02@Z6@0U:QX09b`L02H[7@0V:R0092LO02@W7P0202@Z800;02<Z7@0T;1`09BhL02H]6`0X
;Q`09R`M02HZ7P0W:ad09R/L02D[6`0V;1/00P0W;1`02`0W;Ad09RdO02<[7@0S:QT09B`J02@[6P0V
;1/09R/K02D[6P0Y;a`0:2hK0080:2dI00`0:2lK02T_7@0U:QT09R/J02HZ6`0U:A/09b/L02X^7`0/
<200:blP02`_8@0];b4202``8P0;02X_8P0W;1h09b`K02L]6`0X;a`0:BlN02``7P0Z;ad0;30P02`^
800Y:al00P0Z;B002`0Z;R809RTP02@V7@0S9QX08RDI02<U6@0V9Q`09BHM028T700R91/08B<I0080
7R4F00`07b4E028U5P0Q91H08R@E028U5@0Q9AD07b8C01dQ4P0M81407B4A01`P400L7a4201`P4`0;
01/O4P0K7Q806alB01TO4@0I81407bTI00d@3@0<3P`030h;00/=2`0:30T00P0A5@h02@0C60l01`T5
00H70P0620<01@L300@60`061`@01PL500H81@0200D81@801@P400H01@L400D81@0520@01PT300H8
0`0820<Jooooojd0oh003oooool000gooooo00H0U:ZF09VaW@2L]Z00WKRP08nVT010BDP2018D6P0;
01TM700C5Q@03a8>00hB2@0A5@X05AX<01LL300G70d061`<01TN3@0J7`h00P0K7`d02P0K7`h06Qd?
01XM4@0K7Q807B0E01hR5`0M8QH07B<H01dR600M8QT301dS6@0<01hS6@0O91P07bDF01lU5P0M8QD0
7R@F01hU5@0M9A<07bHD024V5P0R9QH08RDE0P0Q91H02`0R91L0828E01hP4`0O8QD08BDG020V600R
9aP092TL02DY800S9Ql08RHN008092TO00/08bTK02H[6P0W;AT09b`G02P/600[;ad0:B/N02P[7@0Z
;1h0:BdM02P/6`0202P]6`0;02P/700U:QX09BXJ02H[6`0X;a`0:S4L02H^6`0T:aX09BXH02L]600X
;AL00P0X;QL0300X;AL09b`G02@Y5@0T:1H09BTI02<W600U9aT09bTL02TZ7`0Z;B40;2hQ02ha8`80
;34R00/0:RlP02P]7@0Y<1h0:C4M02`c7`0^=200;S<P02da8@0^<b<0;c@U02da8P0202ha8P0;02hb
900^<2@0:bdR02PZ800X;240:BhQ02`_8P0/;b@09b/P02HY700U:1/00P0S9AT0300U9aX092PI02<W
5`0T9QH09BLG02@W5`0S9aH092HF02<U5@0T9aL08bHG020T5P808BDG00/07b<G01hR5@0P8aD07b<C
01`Q4P0L8A406al@01PL3P0E6Pl05ATA01DH4`0201DJ4`0;01HK4@0E6@d051T<01@H3@0C5P`04A@;
01@G3P0G6A005QPA01<F4@0B5A000`0B5Q401@0C5Q<051TB01DK4P0D6A404aL@01[ooooo1@000?nX
0?n000oooooo000=ooooo`0609N`WP2K]J@0WkZU09fhX@2K]Id0HW=W0P0I7B802`0E6AT05QXG018F
4P0C61005AX>01LN3P0I80d061l>01PN3P0J80l0724A00807b8A00X07R0@01lQ4`0O7aD07R0H01hP
6@0O8AX07b8J01hS6`0J81P06b4H0`0L8aT0300N9AP07BDG01dU5@0M91<07bDD028W5P0R:AH08RTE
028X5@0S:1L092PG02<W5P808bHG00/092LH02<W5`0R9AH08RHG028V600R9QT08bLI02H[7P0V:R00
8bLN024V700202<[700;02D]6P0X;QL0:RhF02T/5P0[;AT0;c0N030_800/;1l0<30R02h_8@0];b00
0P0^;al02`0Y;1h09BLK02DX700U:A`0:2lL02Xd7P0S;1P092`H02D/5`0W;AL09bdF00809b`E00`0
:2dG02T^6P0V:QP09BPG02DX6@0U9a/09BHM02LW7`0W9b00:2XR02/^900]<2@202/a8P0;02Xa800W
;Qd09blJ02Xa6P0[<Q/0;C<L02`b700Z<1d0:c0N02db8@0]<R800P0]<2802`0_<B<0<3<T02da8P0/
<2@0:blT02X_8P0[<280;30Q02X^7`0X;A`09b/K00809bTJ00H09RTI02DZ6@0W;1X09b/J02LZ6P0U
9aX202@V600402@U6@0U9A/08R<J024R6@808R@J00/07b@H01hS5P0M8QD07bDF01hU5@0N9AH07bDG
01dR5@0H7Q805adC01HJ500201DJ4`0;01DJ4@0E6Pl061`?01LJ3`0G5`h05aP?01TI4@0I6Q<061XC
01HH5@0D5a@00P0C5Q<01P0F6AD05APD01DI4`0G71@05Q/C01DH41[ooooo1P000?nW0?n000oooooo
000=ooooo`0608nVU02K]J00X;fU09nkX`2N^j00Q9f80P0iAD002`0H71d06AhJ01<I4`0A5@h04aP?
01@J3P0G7@l06R4A01`R4`0L81<07b<E00808B@G00/08R<F028S5`0Q8Q/0828K01hP6@0M7aP06alG
01`R6@0K8AP072@G01`S5P0201`T5@0<01dV5@0N9Q@082LD01lU4`0P9aD08bTG028V5@0S9aD09BTH
02DY6@0U:1T092LH0P0T:1T02`0T:AX09B/J02DZ600U:AT08bLH028V600R9aP08bPK02<X7P0P9Qh0
82HM008092`M00H09c0M02Xa6P0[<AX0;C0K02d_700/;Ad202l_8@0302h`8@0_<B@0;c0S0080;c4R
00/0;BlQ02T[7P0Z;200:2`O02D[6P0U;QT09BdH02@[5P0V;AH09bdG02P^600202X`6@0<02/_6`0Y
;1`09bXK02H[700S:A/092LL02<V700X:R00:2`Q02T]8P0[;b80;38R0P0Z<2002`0Y<B00:S8O02`c
7P0_=Ah0<3HO02ld8@0/;b00;30R02/`8`0/<R@0;S8U0080;C8T00P0;S@T02lc900^<b<0;S<S02hc
900/<R80;C<Q02`b7`80;C8N00H0;C4P02/^7`0[;Ql0:RdO02L/7@0W;1h202P/7`0502DZ7P0V:Qd0
9bXL02@W6P0S9AX00P0R91T202<V6@0;020U5P0O9QH082HE028X5@0Q9a<07b@D01lS5P0M8QD06R0E
01PN5@0F7A<00P0F71402`0F7A4061h?01TN300I70`06AX=01TI3`0K7A806ahC01TL500J7AH05a/E
00805QXE00H061dF01LK500F6a805ahB01HK3`0E60dJooooo`H0003oY`3oP00?ooooo`003Oooool0
1P1MJET0NH]c08fUR02D[Y80V[NH09NeU@80GgAN00/06R0L010D4@0?50h0310:00hA2`0A5@d05A/?
01PN4@0I7a<06QlD01hS5`02020U6@03028W6P0R9QP08BDI00<082<G00D082<E01dQ500N8Q@07b@F
01hS500201hT4`0<01lV500Q9aH08bPH02@Y6P0P9QP08RTJ028Y6@0Q9aP092XK02DZ6`0V:aX09b`K
0P0W:aX02`0U:QT09BTH02DZ600U:AT08bHG020U5P0O9AL07bDJ020V7@0P9al08bXO00809R`P00/0
9RhN02L_6`0Z<A`0:c4L02db7P0/<1l0;C4P02`_7P0]<B00;S<S02lc900202la8@0;030a800^;ah0
;BhN02X/6`0Y;A/09bdJ02@[5`0T:aH09R`G02P^6@0Y;a/00P0X<1/0300X;a`09bdL02L]7P0V:ad0
9B/K02@Z6@0T:1H09bXJ02X/7@0Z;1h0:bdO02`_7`80:RlO00/0:c4Q02`c8@0]=280<3LT034g9@0`
=2H0;c8X02lc:@0/<BP0:c0V02/a900202`b8`80;38T00T0;3<R02dc8@0^<b40:c4N02dc7`0_=Ah0
<3@O030b800_<B400P0]<280300[;b<0:BhQ02H[7`0W;B0092/M02</7@0T;1X09B/H02DZ6@0T9aP0
8bDG028T5P808RDG00/08B<E024U4`0R9Q<08BHA020T400L81407R4F01/O5@0I7AH061lF01LN4P02
01HL400;01@J3P0E6``051X901DJ2@0E6PX05AT;01PM400I7Q806AlB01XP500K8A@00P0I7a@01P0G
7Q<05ad@01HL3P0F70`05a/=01DH31[ooooo00<0oh000000o`000?l01@000?nU0?n000oooooo000=
ooooo`06028X700_=RP0@T`j05ASB@1[PEl0Pime0P1bRf@02`0T:Qh041<>018H3`0?4Pd03A0<018F
3`0E6a005Qd@01TO4P0K8Q@07B@F00807bDG00/08BHG024U5P0Q91L08B@G02<U6P0S9a/092PK02<V
600R91H08RDF020T5002024V500<028W5@0R9QL08RDH028U6P0Q9a`08BTK024X6P0R:AX08bTK02@Z
6P0U:a/09bdJ0P0Y;aX02`0X;AX09BTH02DX6@0U:1T092PJ02@Z6P0T:Q`08RTL02<[7P0S:Qd08bXK
008092`K00/09BdL02D_6P0V;QP0:C4I02X`6@0Z;aX0;30M02/a7P0/<Ql0;38Q02ld9P02034d9P0;
034b8P0a<R40;RhM02h_700[;a/0:BhK02D/600T;1P08b`H028Y600S:aX00P0T;1P0300V;QX09bhL
02L/700W;1`09b`K02H[6@0U:1L0:2XH02`^700[;A`0:b`M02`]7P80:RhO00/0:RlO02/a800/<R00
;S@Q030e8`0b=RL0<C@Y030e:P0^=2P0;C8U02/a8@0302`a8@0:02`b8`0^=R@0;cHS02le8P0/<Ql0
;C<P034e8@0b=1l0<S<P02l`7`80:bhM00`0:blN02P/6`0W;1/09bdK02D[6P0T:aX08b/H02<[5P0V
;1H09b`I02DY600S9QL202<W5`0;02<V5P0R9QD08B@E01lS4P0M8A406b4A01dR500K81D06AhD01LN
4`0G71000P0G70l02`0C5`/05AT<01DI2`0C5`T04aH801DH2P0G70h061`?01LM3`0I7a406R0C0080
6AlC00H05adA01HL3`0D6@/051L701@F200B50PJooooo`@0oh0010000?nU0?n000oooooo000=oooo
o`06028X700_=RP0@T`j05ASB@1[PEl0Pime0P1bRf@02`0T:Qh041<>018H3`0?4Pd03A0<018F3`0E
6a005Qd@01TO4P0K8Q@07B@F00807bDG00/08BHG024U5P0Q91L08B@G02<U6P0S9a/092PK02<V600R
91H08RDF020T5002024V500<028W5@0R9QL08RDH028U6P0Q9a`08BTK024X6P0R:AX08bTK02@Z6P0U
:a/09bdJ0P0Y;aX02`0X;AX09BTH02DX6@0U:1T092PJ02@Z6P0T:Q`08RTL02<[7P0S:Qd08bXK0080
92`K00/09BdL02D_6P0V;QP0:C4I02X`6@0Z;aX0;30M02/a7P0/<Ql0;38Q02ld9P02034d9P0;034b
8P0a<R40;RhM02h_700[;a/0:BhK02D/600T;1P08b`H028Y600S:aX00P0T;1P0300V;QX09bhL02L/
700W;1`09b`K02H[6@0U:1L0:2XH02`^700[;A`0:b`M02`]7P80:RhO00/0:RlO02/a800/<R00;S@Q
030e8`0b=RL0<C@Y030e:P0^=2P0;C8U02/a8@0302`a8@0:02`b8`0^=R@0;cHS02le8P0/<Ql0;C<P
034e8@0b=1l0<S<P02l`7`80:bhM00`0:blN02P/6`0W;1/09bdK02D[6P0T:aX08b/H02<[5P0V;1H0
9b`I02DY600S9QL202<W5`0;02<V5P0R9QD08B@E01lS4P0M8A406b4A01dR500K81D06AhD01LN4`0G
71000P0G70l02`0C5`/05AT<01DI2`0C5`T04aH801DH2P0G70h061`?01LM3`0I7a406R0C00806AlC
00H05adA01HL3`0D6@/051L701@F200B50PJooooo`@0oh0010000?nU0?n000oooooo000=ooooo`06
01@I3`0I7Q<06b0E01/Q5@0X;ah0?4L^0P11Cc@02`0V;1`08BHI01`Q5P0G71804aT>01DK3`0F7A00
5ahA01TO4`0L8aD07R@F00808BHH00/08RHI028W6@0R9AP08R@J02@V6`0U9a`09BPK02@X6P0T9QP0
92DF020T4P02024U4P0<024U500R9AH092LI02<W6`0T:1l092XO028X7@0S:Qh09B`P02D/7`0T:Q`0
92/J0P0W;AX02`0Y;QX09b/I02LZ6@0Y;Ad0:BdP02T/800Y;Al0:2hO02T^7P0X;A/09bdH00809RdF
00/09RhH02D]600V;AL0:c4J02`a6`0/;Q/0;S0M02ha7@0]<Ah0;C<R030e9@02030c900;034b900^
<240;BlN02d`7P0Z;Q`0:BhJ02P`6P0W;a`09RhK024Y600N9QH00P0Q:1P00`0S:QX09R/K02L/7002
02L[7@0702HZ6`0T9aT09b/I02X^6`0[;a/0:RhL02/_7@0202/^7P0;02/`7@0/<Ad0;34N02`b7`0_
=280<SPV038g:00`=RT0<3HX02dd900[<Al00P0/<Ql02`0^=240;cLT02hf8`0]=B80;cHS02le8`0^
<B80<38P038d8@0b<b40<34N0080;c0L00`0;BlJ02X]6@0Z;Q/0:RlK02X_700Y;Q`0:2dL02P]6P0X
;QT0:BhK02T^7@0Y;ad202@/6`0;028X600S:1L08BDE01lQ4`0O8Q<07b<D01hR4`0N8A<07B0D01XO
4P0J7a000P0H7Pd02`0H70/061X<01PI3@0G60`05QL;01HH2P0I6`d06Qd>01LL3P0H7A006AlB0080
61dB00H05QX@01@G3P0D5P`04QH9014C1`0>40@Jooooojd0oh003oooool000gooooo00H03Q8:010D
3@0B5@h051H?01LJ4`0K8AL201hU6@0;01dS5`0K81@06QlB01PN3`0G7`h05Q`<01HM3@0H7a405Q`@
01PO4@0K8Q<00P0O9AD01@0R9aL08RHG024U5`0Q9AL092LI00809BPJ00@09BTK02@W6@0U:AT09R/J
0P0T:AP0300R9aL08RLH02<X6P0S:1/092PN02HZ7`0V:R009R/O02L[7`0U:Ah08bPL02H[7080:2dL
00/0:RlM02T^700X;A`0:2/N02T/8@0Y;B40:2`P02T^7`0Z;Ql0:RhN02P]6P0202DZ5P0;02D[600Y
;Q/0:BlK02`b700^<ah0;c<O02lb7`0^;ah0;RlO034c8`0b=RH00P0a=2D02`0c=BH0<C<T02ha800^
<R40;C<Q02`a7`0[<Qd0:S8M02Ta700W;a/092dJ00809BdJ00`09bdK02H[6`0V:QX0:2dL02T^7P0W
;1h092XK02D]6`0X<1/0:2lJ02P_700Z<Al302`a7`0:02``7P0]<Al0;S<O02hd7`0^<b00<SHU03<h
:@0b>2T0;cDU02`b8@80;3<O00L0;3@N02`d800_=R<0<3PV034g9P0`=2@0<38R0080<C8Q0100;blP
02h_7P0b<al0<S<O030`7P0/;ad0:bhN02X^7@0/<1h0:RhL02T]700Z;Qd0:BhK02P]6`0Z;ah0:RlP
0P0V;Ql02`0T:a/08RTI02<X5`0R9AH08B@E024S5P0Q91H0828E01hP500M8A<07B0C00807Al@00L0
7B0?01/N3@0H6P`061T<01PI3@0H6@`06A/;00806A`;00X06Qd?01LJ3P0E6@d05AT=01HI3P0G6Pl0
51L<014E200?4PD03a456_oooon]0?n000oooooo000=ooooo`0600/?1`0>4@T03Q07018C2P0E5`l0
5a`E0P0J7aH201TO5@0501/P5@0J81<06R4C01XP4P0H7a000P0F70l03`0J8@l072<@01dS4@0M8a40
7bDC01lT4`0Q91@08bHF028T5P0S9AL092HG02DX6P0T:1`09B/M02@[7P0202@[7@0802<[700R:A`0
8BLL02<Y7@0U:Ah09RXM02L[7P0U:1/202HZ6`0802HY6P0Z;1`0:2`M02P/7@0Z;al0:RlM02/a7`0[
<1l202X_7`0302T`7`0X;ah0:2dN0080:BhN0P0W;Qd02P0X;ad0:S0L02T_7@0Z<1h0;34O02hb7`0[
;Qd0:bhN02ha8@0`<b@3038g9`0;03<g:00a=RP0<3DW02lc9@0]<b<0;38Q02`c7P0Z=1`0:c<K02Tb
6P0Y<Q/00P0[=1d0300[<Qd0:c0L02T]700Z;Q`0:RhM02T^7P0X;ad0:38L02Lb6@0V<1L09S0H02Tb
7080:c8O00/0;C<Q02lc8@0`=B80;c@Q02db7`0]<Qh0<3@P038f8`0e>BH0<cTV030f8`0202he8@0;
02dd7`0_=Qh0;cHN034h8P0a=b<0<3HS030e8P0b=R<0<38Q02h^800];Al00`0];Qh02`0/;Ah0:RhN
02/_7`0[;al0:c0P02`a8@0[;b40:BdO02X^800[;b80:BhR0080:2lP00X0:30O028Y6P0O9aH07bHD
01lU4`0P9A@08RLF024U5P0Q8aH0828E0`0M7a<02`0O8A807R4A01dM3P0M7Q0071dB01/M4P0I6`h0
6Q`=01/M3@0J70h061/>00<05Q/>00D05a/>01<G2`0@50T041@9014D2@0Jooooojd0oh003oooool0
00gooooo00H01PT200L;0P0;3P@04A@901PK4@0H71@201HI4`0;01HI4P0J7QL071lH01/O500L81@0
6b0C01TO4P0H7Q0061l@01TQ3`0L91400P0M9A402`0O:1<07bLD01lV5@0T:AT092PI02DX6@0V:1X0
9b/L02L[7P0W;20092XP008092/Q0P0V;B802P0U;2409B`P02D/7P0W;1`09b`K02DY6@0V:AP09b/J
02LZ6@0Z;1/202/^7@0;02/`7`0[;ad0;34N02hd800]<R00:S0O02L^7`0X;b00:RlP02X`7`0Z;b40
0P0Y;b0202T`7P0902L_7@0Y<1h0:S0M02T_7P0/<Al0:c0O02/`800]<R80<3HU0080<CLV00/0<SPX
034h:00`=RT0<CL[02le9`0[<R@0:S8P02Tb7P0Y<Q/0:C<I02/d6@0202de700<02he7P0^=200;c@Q
02d`7`0/;Ql0:blO02/`7P0Z<Ad0:C4J02Tc6P0X<AX0:S4L0P0/<Ql01@0_<b80<3DS034f900a=b@0
<3HQ0080<3DN00@0;c@N034g8@0`=R00<3DQ0P0`=B<02`0`=B40<3HP02hd7`0_=Ql0;S@P02le8P0a
=b<0<3HR030d8P0^<B40;RlP00<0:b`M00/0:R`M02T/7@0Y;Ad0:BdN02/_800/<B00:blN02X]7P0Y
;200:BdQ02X_8P0202T^7`0402P^7@0Q:1P082TE01lX4`807RHA00D08BLD02<Y5`0S9aH07b<D01`P
4`0201/P4`0:01hR500M81<071hB01`N4`0K7Q@06Q`C01/M4P0M7a4071l?01TJ3@<06A/=00H06A/<
01TL300H6``05AT;01<H2`0A5P/Jooooojd0oh003oooool000gooooo00H01`X200T<0`0=4@D04QL;
01PM400I7A4201DG3P0;018B300C5Q004A@>018E3@0D6@l05adA01TP4P0K8Q806b8@01/S3`0L90l0
0P0M9Pl02`0M9Q407RHD01hT5P0Q9QL092TH02@W600U:QX0:BlM02T_7P0X;R009R`P008092/Q00X0
9B`R02H]8`0W;R<09RdQ02D/7P0V;Ah09bdM02P]700Y;Q/0:BhJ0P0W:aT202X_700;02`a7@0]<Ad0
;34L02db7@0/<1d0;2lN02X^7`0Y;R00:c0R02/`8`0Z;R800P0Z;b802`0[<240;3<R02/d8@0Z<R40
9c0M02H^700Y<Ad0:S4M02/a7@0/<ah0;cHQ0080<CPT00/0<3PV02hg900a>BL0<cXY034i:@0^>2H0
;3LT02`f8P0/=Qh0:S@J02`f6P0202`e6`0<02dd7@0^=1h0;S@O02hb800]<200;C4Q02db8P0/<R40
;3<P02/c7P0Y<A`0:S4L0P0]<ah02`0_=200;cDR02le8P0`=R00<CLN030d6`0b=Ad0<CDO034f800a
=b40<CHQ0080<CLT00/0<3HR02lc8@0^<b00;c@P02ld8@0a=R@0<SPU034g900`=R<0;S@R02``8002
02T/7P0402T[7`0Z:b00:bdP02X^7`80:RlO00H0:c0O02X^7`0Z;Ql0:blQ02P/7`0W;1d202L^7@0;
02L]700T;1X092dH02</5P0O:1<07RHB028X5@0T:AL08bLF028W5`0Q9aL00P0M8a@02`0L8Q<06alB
01TM4@0H6a005a/A01LJ4@0H6a807B4D01dO500I6Q005aL<00806QX<00H06a`;01XK2P0I70X05QT:
01<G200A50LJooooojd0oh003oooool000gooooo00H01PT300T;100:3@@02`l500dB1P0A5@L201@G
200;018E2@0=4@T020/500T<1P0?50T04QP<01<H300F70h06R4A01`S4P0L91800P0M9A<02`0N9QH0
7bHH020X6@0R:1X08bTJ028Y600U;AT0:34K02P`6`0X<1`0:2lN008092`N00X09BdO02D]800V;200
:2hQ02P_8@0Y<240:S0O02/b7`0[<Al0:RlM0P0Z;ah202X_7@0;02`a7@0]<Qd0;c@M02ld7@0^<Q`0
;c4L02``7@0X:a`0:2`M02/_800[<2400`0[<2@02P0[<B@0;C<T02`c8`0Z<R00:30M02Pa700Y<A/0
:c<K02`d700_=Ql2030g8P0;02lg8P0]=b80<3TS038k900a>bH0<3/V030j9@0a?2H0<3XR02hh7`0a
>R000P0a>B00300a=b00;cDN030f7P0a=B00<C@R034d900`<b@0;c<S02le8`0^=B00;3<M02`c6`80
;38K00/0;C4K030e7`0`=R00<3HM034e700a=AX0<cHM03Di8P0c>280<3LQ02lf8@0202lg8@0;030g
8@0`=R40;SDP030g8@0a=b80<SPU034g900_=B80;cHS02ld8P0]<R400P0Z;b40300Y:b40:R`R02X/
8P0Z;R80:blR02X_8@0Y;Ql0:RlP02/_8P0[<2<0:BhP02H/70809bhL00/09B/H02D[5@0U;1D09RdG
02D/5P0Q9Q808BHD028U5@0Q9AH08BHH020W6@0201lW6@0;01lV600M8aD06b0C01XM4@0L7a806alB
01`P4`0O8QH07R0E01/M4@0J6`l00P0J6`d01P0J70`06AX901TK2P0I6`X05aT;01<E21[ooooo[@3o
P00?ooooo`003Oooool01P041@<01@L300@70@062@0020/100/@0P804QL600/04QP8010D1@0:3@80
2Pd400d@1P0<40H02`d500dA1`0C60`06AhA01`Q4`0201lV5@0;024Y6@0Q:1X08RXK024Z6P0R:QT0
82PG028[5`0S;1L092dG02H_6@0W<A`00P0V;ad0300U;1`0:2lO02X_800[<240;C8R02da8@0^<R40
;S4Q02da800]<R00;S<R02hc8@80;34P00/0;3<P02he8@0_=B40<3DQ02ld800^=200;C4P02`^7@0[
;1d0:bhO02X]7`0202/_8@0;02da8P0]<R@0;C8U02dd900/=B<0;3DR02/d8@0Z<al0:34K02Xc700Z
=1h00P0/=Al02P0/=R00;cTR034k900`>b80<S/S03@l9@0e?BD0<c/T03<j8`0b>B43038i8P0<038g
8P0a=b80<STR034f8@0a=B00<cDQ038c8P0_<R80;S<R02le8P0/<ah0:c4M0`0/<A/02P0`=Qd0;cHN
030f7`0`=Qh0<SLN03@i800g?B@0=c/V038g900_=B0202he7`0;02le7`0a=b40<CPQ030h8@0b>B80
<3LQ02he7`0/<ad0:c8N02`b7`0^=B400P0]<b40300[;R00:RdQ02`_8`0/;b<0;C0R02d`8@0Z;R00
:RdP02/^800[<240:c0O02X_7P80:BlL00/09b`F02L/500U:a<09b/F02P]6P0T9aL08BDG028V600Q
9AL082HH01lV6002020X6@0;01lV600M8aD07B4C01lR5@0Q91D07R0B01`P400O8a807R4B01`P4@0L
81800P0J70l01P0H6Pd06Q`?01XL400J70l05aP>01<E2a[ooooo[@3oP00?ooooo`003Oooool01P03
1PH010L500@70@041`000`H000L:00<02`h100X030l100hA0P0@4@@04146010B200>3PH030d600X<
1@0>40P051T<0P0I7@`02`0N91408BLE028Z5`0T;1P08b/G024Z5`0Q:QP08R/G02D^600V;aX09RlL
00809blL00<09c0L02Ta700[<1`00P0]<Al00`0]<B00;S4Q030c8`03034e900>030e8`0]<b80;C<R
02`c8P0]=B80;3DQ02de8@0^=B80<3HR034e8`0_<Al0;2dJ02/]6`0/;Ad202/^7`0;02`a7`0^<b80
;c@T02hf9@0/=B@0:S@R02/d8@0/=B80:c@P02Xd7`0/=Ql00`0[=Ah02P0]=R00;cPQ034j8@0c>b40
=CdS03Dl900c>R80<CPQ03<i8`0b>28203@i900<03Hk9`0e>bP0=C/W038g900b=R40<cHQ03<e8P0a
=240;c<R02hc8@0[<Al0:c4M0P0[<a`02`0[<Q/0;CDM02hf7P0a>200<3LQ038i800c>R40<c/S03@k
900e?2H0<STS0080;S@O00/0;c@O034g8@0c>R@0<c/T038i8P0`=b40;cLP02hf7@0/<a`0;SDN02lf
7`0202dc7@0<02/a7P0]<B40;C4R02hb900^<R80;c4R02``8P0/;R<0;C0S02/`8@0[;al0:BhL0P0W
;1P02`0T:a@08b/B02<Y4P0T:A@0:2`K02P/700U:A`092PL02<V6@0P9AT07B<H00807R@H00/07B<H
01`R5P0K8A<0728D01dS500L8A806Ql>01/P3P0L80l0724@01`P400201XL3`0601HI3@0H71005a/A
01LK4P0E60l04AD<6_oooon]0?n000oooooo000=ooooo`0600<81@032@<01@T100D900031`000PD0
0P031P002`041P001PH000/:0@0C4PL061X<01LH300B4PP03@l600T<0`072P802@d300803A8300/0
51X701`R3P0Q:A@09BhI02D_6P0V<1d09blP02La7`0W<Ah09S0M02@]600202<]5P0<02H`600X<AP0
:S4I02dd7@0^<Qh0;S4P02lb8`0`<bH0<3DY030e:00a=bT0<3HX0P0^=BH02`0]=B@0;SHS02hh8`0b
>BD0<cTS038h8`0a=R<0<3<P02h_7@0_<1d0<34O0080<C8R00D0;c<S030e900`=B@0<3LU02lg9@02
02`f8`0402dg8`0^>280;cPO030i7`80;cLN00H0;C@L02dd7P0^=1l0;SDP034g8P0c>b<2038i8P03
034h8@0c>B40<SPP0080=3TR00`0=c`V03Hk9`0g?2L0=C/V03@i8P0f>B<0=CLT038e8P0a=B<0;S@S
02/b800Z<Ad202Xa6`0;02/c7@0Z=1d0;STO030i7`0_=ah0<3PN034h7`0`>200=3XS03Hl9P0c>RD0
0P0`=R<0100_=280;C8P030f900d?2P203<k9`0503<l9@0a>R<0<3PQ034i7`0b>Al00P0^=A`0100]
<ad0;S@O02ld8@0_=2@202ld9P0602hb9@0]<BH0:blU02/^900Z;R40:BhM0P0X;aT02`0V;QL092/D
02DZ500V:aL0:BdK02P/700Y;Ah09b/M02DY700T9a`082<J00<07B0G00<07R8F01hT5P0N91H00P0M
91L01@0M8aL06b4C01XP400K81407B4B0080720@00H06al?01TM3P0G71005a/@01DI3@0@50TJoooo
ojd0oh003oooool000gooooo00H010T400@90`062P401`/100L:000520020085000;00<600072000
20H000l>0P0E50H05AH8018C1P0=3P802`/000/;0@082@000P061`002`0<3P8051H901dQ4`0T:1/0
:BlQ02Xc9`0Z=2T0:cHX02Pc8`0W<al09C0J008092lF00`09C0D02Pc5@0[=1L0;38I030c7@0a=240
<c@U038d:00`=2`0;S</02he;00]=B/202`e:@0;02hg9`0a>RH0<CXU038h8`0e>R40=3PP03Dh8@0e
=b00=CHP03Hh900e=bH00P0d=BP02`0a<bP0<cL[034f:00`=bD0;cTT02`f8`0[=240;3DP02lh8@0c
>b40<STO0080<SPO00/0=3TQ03@h8P0c=R80<SHS034f900c>2H0<cPT03@k9P0e?BL0=C`U03Dm8`02
03@l8P0<03Dn9@0g?RH0>T4X03To9P0g>R@0=SPT03Hg9@0c=B@0<C@U02hd9@0Z<b<0:C8P0`0Y<al0
2P0Y=1d0;3PN02ll7@0_>aX0;cTI030h6P0a>Ad0=3/Q03Dl900e?2L2038i9P0:03@i:P0b=bX0;c@X
02lf:00a>2T0=3`X03@m9`0b?BH0<C`S030i80<0<3LN00`0<3LO030f8@0a=B80<3@T030e9`0_=2T0
<3DY02hc:@0/<2H0;34V02T^8@0X;Ah202P`7@0;02P`6`0X<1T0:BhH02T^6@0[;a/0;2hK02`/6`0[
:a`0:bdN02T[7P0T91T00P0Q8AL02`0O81H07b8H01lS6@0N91X07bDK024W7@0Q9ah07bDJ01dU5`0M
8aD07R<C0080724?00H0724>01/P3P0J80h06Ah<01PK2@0C5PHJooooojd0oh003oooool000gooooo
00H01`/300P<100;3@@030l300`=0`0:2`4200P:000700T;00092P002@T000X;000:2P0030`100`<
000200h=0@0?00`;0@0<2@802@D200T50P081@802PL501DE4P0Q8Qh09bXV02Ta:`0Y<b`0:CH[02Tg
9`0X=b409c@L00809c@H00`0:CDF02Xe5@0]=AH0;C8H02la700b=B<0<cHW03<e:@0`<bX0;c@]02de
;P0]=bd202dg:P0;030j:@0b?2L0=C`V03Hl900g?2<0>3XQ03/l900j>bH0>c/X03Xj:P0h>Bh00P0f
=bh02`0d=Rl0<cP^03<j;@0b>bT0<C`W02lk900^>240<3TP03<l8@0g?B80>3`R0080>chV00/0?3hY
03Tj:@0h>BX0=cT/03Dh;00f>bd0=Sd/03Dm:@0g?bT0=d4X03Ho9@0203@m8P0<03Dm8P0h?R<0>ChT
03/o9`0j?BX0>C/[03Li:`0c=BT0<CDX02lf:00[=2D0:cDT0P0[=B<02`0Z=B00:C@L02Xe6@0/>1L0
;SXG030j5@0b>aL0=SdO03Hl8P0f?2D0=clZ0080=cl]00/0=Sh^03@m;P0b>bd0;cLX02df900_=b40
<CXP03<m8@0c?1l0<CXN034h7P0203@i800<03Dh8`0d=b@0=3HV03<d:00b=R/0<3D/02le;@0^=2/0
:c4W02Xa9@0Y<B80:C4Q0P0Y<R002`0X<Ad0:C8L02/b6`0[;a/0;BhK02h_7@0^;Ad0;bdP02h/8@0/
:b40:2PO00809BHO00/08B@L01lR700O9Ad07bDL01lV700P:1d08BTN01lW6P0N9QH07RDD01hV4P02
01`T3P0601`T300M9@h07RD=01hT300M8@`06AX96_oooon]0?n000oooooo000=ooooo`0600X<1@0<
3@D03a0600h@1P0:2`<01`P10P051`002`092P402``100X<0@092`001`P000P9000<30003Ph400d<
100=2`<02`T300802@D300/02@@700P3200<2@h05ADH01dQ8@0T:bL09c8Z02Pd:00W=R@0:3LP02Le
700202Te6P0<02/f6@0^>1P0;cHJ02he7@0`=B00<SHT03<g:@0b=RX0<3H[038g;@0a>Rl0<3X]0P0_
>RX00`0a?2L0<3/U03<l900203Y09`0603/n9P0l?BH0?CdZ03dm;@0h>Bd0>3X_0P0g>c002`0f>c80
=S`a03@l;P0c?2/0=3dZ03@n:00c?2D0=C`S03Lm8`0j?R@0?3dW0080?SdZ00/0?C`]03Xi;`0i>C40
>3Xb03Dj<@0e>c00=Sh_03Do;00g@RX0>D<X03Y29`0203Ln900<03Ll900h?2D0>S`W03/m:`0l?Rl0
?3lb03Pm<@0c>Rh0<SX[034k:@0_>BL0;SPT0P0/=R002`0/=Qd0:cDI02Tc5@0Z<Q<0:c<D02hg500a
>QL0<cTL03<g7`0d>bD0=C`X0080=3h[0P0c?Rd02@0b?R/0<C/V02li800^=aX0;SLG038k6@0a>AT0
<cTL03Hi7`0203Li8`0<03Lg9@0e=2L0<S4W02l`9`0]<BT0;SD]02Xb;00Z<RT0:C8V02Xc8`0Z<R40
:S4P0P0]=B802`0]=240;38N02hb7@0^;ad0<30O034`8@0a;b<0<BhU02dZ8`0[:R@0:2/V00809BTU
00/08BLQ01dS7@0M91`072@J01lW700O:1X082TJ020Y600O:1@07RLB01lX4@0201hW3P0601`S2P0M
90T07R8:01lS300N8@d071`<6_oooon]0?n000oooooo000=ooooo`0600hB2P0=40X030l800X=1@07
2@@01@L30P041P4010072P802`h300X=0P082`0200P:000500X<0@0=3P<03@`300X80P0610400P04
0P002`081@@03@X:00`:3@0=31404aDI01/O8@0R:BL09BlX02Db9P0V<b<0:CDQ0080:cLP00`0;3LO
02lg7@0_=Q`0;cHN02le8@0b=B@0=cT[03Dg;@0c=bh0=CT`03@i<00b>Rd2030k:`0;030k9`0a?BD0
<chU03Ho9@0g?bD0>3lU03Tn9@0h>bD0>cdY03Xl;00j?2h00P0i?2h02`0g?300=S``03@j;P0e?2h0
=Cd^03Dn;@0e?RX0=C`V03Dk8`0h>b<0>S/U0080>c/W00/0>cTZ03/i;@0i>C00=cTc03<g<P0e>c80
=Cda03E0;P0g@b/0>D<Y03Y39`0203Q09@0<03Pn9P0h?BP0>ShZ03e0;@0n?bl0?T0a03]1<P0g?S40
=Ch_03@m;00c?BT0<C/U0P0]=b002`0]=Q`0;3<I02T`5P0X;aH0:S4F02X`5@0/<aD0;C@I02le7@0a
=b40<SPU0080<STW00/0<STY03@l:P0c>bL0<CXT02lh800^=ah0<3LK030g6P0`=QT0<SPL03Di7P02
03Hh8@0<03Hh900f=bP0<S8W02d_9@0[<2H0:2hV02P_9`0Y<2H0:c<V02`d9@0]=280;34O0P0]<R00
2`0^<b40;S8P02hb7P0_;a`0;blN02l_7`0_;1l0<2hR02h]900/;2D0:bdW00809b/U00/08bPQ020U
7@0O9Q`07BDJ01hU6@0O9aP07RHG01hV5@0O9aH082HE020V4`0201hT400301/P300L8P/07R8=0080
7R4>00<071h=ooooooooool06?oooon]0?n000oooooo000=ooooo`0600dB3@0<40`02P`900P:1P0:
30P01`X70P051`<02`0520401`T100L90@0620401`T100P:0@092`4020T000P800071P001@@00080
108000/020H301DE3P0H61D06QXK01dM8@0O82H08RHZ02@/;00V;bd09S8[02Lb:@0202Tc9@0<02Xd
8P0/=B00;CDO02dd7P0_=R00<SLS03Dh9`0h>R/0=cP]03Dg;@0d>2h0<cP]0P0d>bh02`0a>b/0<3/X
038m:00d?bH0=SlU03Ho900g?b@0=SdS03Tn9@0j?RP0>Sh[0080>cl^00/0>3h_03Lm;`0g?C00=S`a
03Dm<00d?S40=D0_03<n:@0c?2@0=C`R03Ll8`0203Pk8P0;03Tk900j>bL0>S/Z03Tk;P0g>Rl0=CT_
03Dk;P0g@2l0=d8^03U5;@0mB2`00P0mAbT0300lART0?4<Z03e1:`0m@B/0?D0/03i0;P0n@S00>d0a
03]2<P0h@C00=Cl^03<l:`80;cLU00/0;3<O02/a700X;QT0:BlJ02Xa6P0Z<1X0:c8J02/a6P0/<A`0
;S<O034f8@0203@i9@0;03Di9P0e>RL0<SPU034g900a>2@0<SXT038m8`0b>b00<3TL034i700b>1d0
0P0d>Ah0300e>B00>3XT03Hh9P0c=2D0<3<W02d`9`0[;RD0:blU02`a9@0^=2H0;cDU02`c8`80;C<T
00/0;3<S02dc8@0]<Ql0;C4N02ha7@0`<Ah0<2hN02h[7P0`;B00;RdQ02`[7`0302//7`0:02LZ7`0S
9Q`082@K01lS6@0O91T07B@I01`T600O9QT07bDH020U5`8082@F00H07R8B01dR4@0O8a407R8@01dP
400K7A0Jooooojd0oh003oooool000gooooo00H03A8=00`@300:30T020X600X<20072PL200D70`0;
00D80@072@401`T100H80@072@4020X100T;0@082@0020P000L6000510000P040P002`081P<05AD>
01PH5@0J6Q/07AdQ01lP9P0R9RX092`/02H_;@0V<R/09c8Y0080:C<U00`0:S@R02`e800]=Al0;C@N
02lf800b=b<0=CPW03Pj:`0g>2d0=CL]03@h;P0c>2d203@k;P0;034k:`0`>bP0<SdX03@o9P0f?bD0
=SlT03Lo900f?B<0>ChU03Xn:00j?R/00P0k?bh02`0h?Rl0=cd_03Lm<00f?340=Cd`03@n<@0e@2l0
<chY03<l900e?280=c`S0080>3/R00/0>C/T03Xk9`0j>bX0>C/^03Lj;`0e>Bl0=C/^03M0;`0g@Rh0
>DD]03e8;00203e7:@0<03a6:@0l@bX0?D4[03e1:`0m@2`0?T0^03i2<00k@340>d8b03Q1<00e?bh0
<c`[0P0_=bD02`0/<al0:c4L02P^6@0Y;aX0:S4J02X`6P0[<QX0:c4J02`a700^<al0<CHQ0080=3TU
00/0=CTV03Dj9`0b>2D0<CLT034h900b>R@0<SdS038k800`>A`0<CTL038h7@0203@i7P0<03Di800h
>R@0=SPV03<d9@0`<bL0;C0W02/^9@0[;bD0;34U02hd9P0_=BD0;3<S0P0]<b@02`0/<b<0;C<Q02db
7`0]<Ah0;S4M030a7P0`;Qh0;R/N030]800^;B40;2/O00<0:b`O00X09bXO02<V700P91/07b<I01lT
6@0M91T072@H01lV6@0O9AP082DG0P0P91H01P0N8Q807B8A01lS4@0N8Q007B0@01/M41[ooooo[@3o
P00?ooooo`003Oooool01P0:3PP02Pd900P;1`082PD02@/600L910801@P300/01`X500L9100720<0
2@X400L90P062@001`T000D800041P000`D000<400020082000;00<300082@@05aXC02hd:@0e>c40
<CDa02``;P0Z<2l0:c8a02lh<`0/=S000P0X<BT0300U;R<09BhO02D]700V;1/0:2hJ02X`6`0/<Qd0
;c@Q034e9`0c=RX0=CP[03<h;080=C/^00/0<SX[030i:@0`>RL0=3dW03<j9@0d?2D0=3`T03<k8P0d
?2<0=C`U03Hm:00203Po:@0;03Hn:@0e?2T0=Sd[03Hl;00g?Bh0=cl`03Ho<00e?Rd0=Sh[03Hn:00f
?RL00P0d>b<02`0e>b80=S/R03Ll8`0h?BH0>CdX03Tm:@0f?2T0=CdY03Q2;00kAB/0?4DZ0080>T<Z
00`0>d<[03Y2;00i@2/0=cdY03Pn:@0j?bX0>d0[03]1;@0k@S00>T4_03Y2<00f?R/2030g900;02`c
800[<Ah0:C0N02T_700Z<Ad0:S0K02/a700Y;a/09bdI02X_6P0/<A`00P0^<Ah02`0_<ah0;S@O030f
800c>B80=3/U03@l9P0f?bP0=T0X03<n8`0b?240<3LM0080;S@L00H0<3HL03Dj800f>R80=CLR03<e
900`<bD202d_8`0402/_8P0[<2@0;C8U02/b9080:C4T00/0:30S02Ta800Z<Al0:c0N02db7@0_<Qd0
;bhK02d[6`0[:AX0;2XJ02h]6P0202/X5P0;02/Y5`0Y:AX09RPK02@V700R91`08B<L020T7@0N8Q`0
7R<L01dS6`0M8aP00P0K8AH01P0L8AH07B8E01hS5@0P8aD07b4E01/M4a[ooooo[@3oP00?ooooo`00
3Oooool01P062P401`X200P;0`0:2`@02@P200P80P802`d500P03Q4:010B2`0?3`X03a4:00d@1`0;
3P<02@/100H9008010H000h00`D0008300020`000P@0004300072PH09c0Q038l:`0c>Rd0=clc03@k
<@0a=bh0=Cda03Do<`8092XT00`07B<L01XP5P0J7a<06b4@01hS4@0Q9Q808RHC02DY500[<1d0;S@S
038h:00e>bX303U1;@0:03Do:P0f?bP0>40X03Lo9`0i?bP0>ChY03To:@0h?RT0>3hZ03Ln:@80>3lY
00/0>40Z03Po:P0h?bX0=clY03Po:P0j@2d0>Cl_03Pn;`0i?c00>T0^03Y1;00203Hl9P0;03Hl900f
?B<0>44T03Q18`0h@2@0>3lU03Q09`0g?bL0>44V03U29P0k@RP00P0k@R/0100m@bh0?48a03Y0<00g
?2`203Hl:P0603Lo:P0i@B/0>ClZ03Y1:`0k@bd0>3lZ0P0d>RH02@0`=b40;38O02X`7`0Z<1d0:c8M
02`b7P0/<Qd0:S0L02P]6`0202X_7080:c0L00/0:c4L02/b700^=Ad0<cXP03@k8P0e>b@0=ShW03Ln
:@0f?bT0=ClX03<k9003030g7`0;034i800`=al0;cDP038h8P0a=R<0;S<Q02hb8@0/<Al0:RlM02/_
7P0/<R400P0^=BD02`0]<bD0;38T02db900[;b40;38P02hd800^<Ql0;2lM02/[6`0Y:AT0:R`I0080
:2TE00/09RLC02@V500U9aL092HH028T6@0Q8aX08B@M024U7P0R9ah07bDL01dS6P0201/Q600601dR
6@0K8AL0724G01hQ600O8AT07AhG6_oooon]0?n000oooooo000=ooooo`0600D:0P062P4020/100X;
0P0:2P402@X20P0=40P02`0A5@`05AT@01DH400E6A405QX@01<H2`0<40H020/300D80@051`001@L1
008010D000/00P@000<50@031P402a0601@I300O91D0>dD_03Lo:`0`=RD0=cl]03M1<00201dS6P0<
01LL5@0@50l03Q8:00lC200D5`T06A`;01`M3P0P8A40:BdK02le8P0d>RP0=cl/0P0i@Rd02`0h@B`0
>44Z03Y3:P0kA2T0?4@X03m4:P11AB`0@4D]03i3;@0k@B/0>T0/0080>d4/00/0?48]03i3;`0nA2l0
>d</03U1:`0i@Bd0>d4_03e2;`0l@C00?D8_03a2;00203]0:@0;03To:00j@BL0?4DY03a5:@0jA2P0
>D8X03Y3:@0k@bP0>d@X03]5:00oAb/00P11B2h02`12B380@DLd03m5=00l@c80>Sl_03Hl:P0g?RX0
>3lZ03Lo9`0j@BT0>D4[00<0>T4^00H0=SdZ02lg9@0^=2<0;3<R02/c7`0/<ah2030f800302dc7`0/
<Ah0;34L0080;38K00/0;38L02/a6`0[<Q`0;3<N02dd7P0_=b00<CTS038j9@0d?BL0=D0X03M0:002
03<l900<038j8P0a>2<0<CLS030g8`0`>2<0<CPS034i900^=R<0;CDQ02he800]<ah0;C<O0P0_=RD0
2`0a>2H0;C@S02`b8@0Z<240;34Q02`b800/<Ah0;3<N02dc7`0[;ah0:RlL0080:2dH00/09b`G02L[
5`0W:aT09R/K02DY6P0S9aX08RLM02<X7@0R:Ad07bHJ01hU6@0201hU5`807B@F00@07bHH020U6@0P
91T07R0G6_oooon]0?n000oooooo000=ooooo`0400D81@072PH020`400L90P801PP10P072@@02`0:
3@P03a<<018G3`0E6Q<05adD01DK4@0?50X02Ph400H90004204010H100800`D100@00@D100440@04
2@8020d30P0:3P801@0F6``07R8C020T5@0c>RL0?DPc0080;3HW00`08BPM01DH4`0A4`l040l;010@
2P0B4``05AH>01hP5@0W:a`0<3HS03@j:00h?b`203Y3;`0;03U2;@0h@2/0>D4[03Y2:`0lA2X0?dD/
0457;`0oAS00?48/03a1;@0l@Rl00P0m@c002`0oAC40@4Lb03i5<00nAS40?DDa03a5<P0mAS40?dD`
03m3;`10A300?D4^0080?44^00P0>d4^03a3;`0kA2d0?4L^03e7;`0mARh0?DH[03a6:@80?TLZ00l0
?dP]0458<011B300@TLd0498=P12BCL0@TTh03m5=00l@bl0>T0]03Ln:P0e?BT0=clZ03U0:`0k@bl0
0P0nAS802`0k@c40=Sd]034i:P0_=bX0;cLW030i9@0_>2D0<3PR02hg7`0^=Ad0;C<K0080;SDK00@0
;38J02/a6@0/<A/0;34L0P0[<1d01@0/=200;cPS034l9P0a?RL0<clX0080<chX00`0<cdV03<n9@0a
>bD0;cPR02hf800_=b40<CTR034i8`0_=R80;SDR02dc800/<B0202hc8@0;02le8P0/<b40;34Q02hc
900/<B80:blO02X_7P0Y<1h0:c4O02/c7P0[<Q`00P0Z;aT02`0Y;QP0:2dG02L/5`0V:aP09RXK02@X
700S:1d08RPM024Y7@0P:A/082PJ00807bHG00H07RHE01hU5P0O9QL082LG024X600P91LJooooojd0
oh003oooool000gooooo00H02`h>00T<2`0:3@T01`X400@60@0310020084000;00H80`0:30L03A4;
010D3P0B5`l04aL@00hC2P0:3P@01`/000@700041@400P0310402`0210400`D300L91@082`@01PT1
00D70@061`4020/300/>1@0E6Pl08b`L00808BXK00`07RDH01dQ500M81@06Q`B01LI4P0G61<05QL@
01/M5@0R9ad0:c0U030f:@0e?Bd203U1<00703Q0;P0g?b/0=clZ03U0:`0i@B/0>T4]03a4;P0203i7
<00503e4;P0nAC00@4Pc0418<`0oAc400P10BC<02011BC<0@T/d0418<`0oB380?TH_03m5;P11Ac00
?T<_0P0m@c002`0nA380?4<b03e4<00nAc00@4Xb03m9<@0mB2d0?TT/03i::`0nB2`0?DH^0080?dL_
00`0@DTd0458=P15BCT0A4Th04A:=`11B3@0@4Pf03e5=@0h@300=ch]03Lo;00i@2`203a3;P0;03i5
;`0k@Rd0>Cl]03Po;P0g?Rd0=Sd[038j:00`>2D0<3XT02lh8@0_=ah00P0_=Qd02`0]<a`0;C@L02hd
7@0_<ah0;S8O02`a7P0/<Qd0;3@P02li900_>bD0;c/V0080<SlX00`0<ChX034m9@0b>b@0;STR02hg
800/=Al0;SHQ02hh8`0`>2@0<3LT02dc800/<1h202hb7`0;02la7`0_<B00;c8Q02d`800^<R<0;C4S
02/`8P0Z<2@0:C0R02Ta8@0/<R000P0/<Qh02`0[<A`0:BlI02T_600X;AL09b`K02DY6`0U:Qd092TL
028W6`0R:1/08bTM00808bLJ00H082DG01hT5P0M91D07B@D01hU5P0M8aHJooooojd0oh003oooool0
00gooooo00H04aLL00lD600<4A<020/<00H81`041`@200<50P0;00H80`0>4PP041@800dB1P0=4@D0
3a8900d@200;3PH02Ph400P;0P072@800P061`802`051@401PH400P91@0720800`@000<300051@80
1PL200P:10092`@03A4800803a@;00`041@;018E2`0B5PX051P;01dR500S:1X08RPI024W6P0S:Qh0
9blT02`d:00`>RX203@m;00;03Dn:`0e?bX0=d0Z03Ho:@0f?BX0=cl[03Y3;P0lARl0?4P`03e8<010
BS800P11BS802`10BC00@DXb04=;=015C3D0A4`e0458<`10B3<0@DTa045:<P12BS80@DL`0080@4H`
00P0?TDa03e5<@0nAS00?dTa041:<@12CC@0@D`c03i9<080?d/a00l0@DXb045:<`11BS<0?dXc045;
<`12BC<0A4Xd04=9<P13B340@DLb0456=00oA3<0?D<a03Y2;@0i@2X00`0m@RT02P0n@bX0?d@^0497
<P0oA340>cl_03Hl;00b>RT0=3dY03@m9`0c>R<2030h800;02lf7`0`=al0<3HO030e800^<b00;S@P
02`b7`0]<b80;3<S02`e8`0]=R<00P0/=b<0300]>2<0;STQ034l8`0c?R<0<c`S038j8P0`>280;cLR
030h900b>2D0;c@R02/`7P<0;C4O00X0;S4P02d`800[;Qh0:bdO02d`800/<240;34T02/^8`0/<2@0
:S4R0P0X;ah02P0Y<1d0:2hK02P]6P0Y;Q`0:BhM02L[700U:A/092LK02<V6`0Q9AX3024U6@0601hS
5`0M8QH07R@F01`S5@0L8QD06R4D6_oooon]0?n000oooooo000=ooooo`806B0V00@061dU01@H800@
4aT0310C0P0930h02`0<3`h041@@00d?2@0:30@030l500hA1`0?4PP0418900h?1P0<3@@02`X30080
2PT300/02PT500X81P0:2@T01@D500<30P020@400P8100L81@0;3PP03Q4900`?1`0200T<1@0<00X=
1P0;3`H020/300T=100?50T06R4B02</6P0Z=200;SLT030k:00b?B`0<C/[0P0`>BL02`0a>RL0<S`X
034j9P0b>BD0<c/W03@m:@0f@2/0=d8[03M4:`0iARd0?DT`0080?dP`00/0@T/c04A==P14C3L0AD`i
04A;=`15C3L0A4hg04E>=P15CcH0ATde04A<=@0204A;=P0;0459=00oB380?DL`041;<011Bc40@Tdd
045<=00mBS80?D/b03e:<00nBBl00P0oBc00300nC2l0?TX]03m9;@11B300@4H^04=8<013B380@dHb
0496<P12Ac<0?dH_03i6;@80?TDY00/0>d0T03e29P11AR/0@dP_04=7<@10A340?T@a03a2<00k@Rh0
>40Y03Dm9@0203@k900;03<i8`0`=B40<CHR02lc800_=200;S@O02`b7P0[<200;38R02le9@0^=R@0
0P0]=b@0300^>2D0;STS02lk8@0b?R80=ClR03Hn8`0d>b80<3LQ02hd8@0_=B@0<3HU02hc8@80;34O
0P0/<Ad02@0/<Ah0;C4O02`]7P0/;Ql0;C0Q02d_8`0/;b<0;C<S02/b8P0202P_800;02T`7P0Z;a`0
:BdL02X]7@0X:a`09RTL02@X6P0T9aT08bLL01lT6P0N91T00P0N91X0100N91/0728I01`S600I7a<2
01XP4a[ooooo[@3oP00?ooooo`003Oooool01P0S:Rl08bX^024X:`0O9BP07B<V01PN80805ATK00/0
51PH014C4`0;30`02PX900`?2@0>4`T03a<900lB2@0=3`H02@`400X<100200/;100;00`=1P0?3P/0
3`h?00`=3@0720T010@500<4100;3P/041@@010D3P0<40X00P0;3PL0300930H02`h700L:10062@80
20/300X=100C60`08RTH02hf8P0d?BL0>D8]03Q0;P80=Sh]00/0=Cd[03<k:P0c>RX0;cHW02dd9`0[
<RL0:cDW02hi:00a?BX0=T8/03Y6;`0203e7<00;045:<`13BSH0@dXh04=;>P14C3X0ADlj04E@>016
DCP0AE0g04E>=P14CSH00P15CcL02`14CCD0@d/c0459<@10BS00@DX`04=<=012BcD0@4Xe045;<`0n
BRl0?D/]0080?dd^0P10CBl02P0oBRh0@DX`0457<013Ac<0@dLd0454<`10AC<0@4Hc03i5;`10B2h2
03m8;00;03i5:011ART0@TLZ0496:`11ABd0@DD`03m3<P11AC<0@DLb03e5;@0j@RX00P0h@2L02`0g
?BH0=3TT02le8@0/<Al0;C8P02ld800]<Ad0;34N02`a7`0^=B<0;cLU0080;SLV0P0^>BL02P0^>B@0
;SXR034l8P0d?R<0=CdS038i8`0_=B80;C<Q02le900_=2<202hd8P0902hd8@0]<b00;34O02/`7`0Z
;B00:R`O02X]800/;R80;34Q0080:c4P0P0Y;Qd02P0Y;a`0:c4K02/`6`0Y;1X09bXK02HZ7@0S9QX0
8B@H020U6P0O9AX301lV700601hU6P0L8aL06b8D01XQ4P0K81406Qh>6_oooon]0?n000oooooo000=
ooooo`0602<Y;P0V;30092//028Y:00S:BL092XW0P0Q9bH02`0P9RH06AdO01<F600?4A803Q4?010D
3P0A5P/041@800dA1@0:3P802@`3008030h500/03Q4600hA2@0>40`03@l=00d?3P092@T01`T700hB
3@0D5a804AH?00`@2`0200P;100<00D70@0620401`T200L90P072P801PP100/?1P0C5``071lC024T
5`0W:Qh0=3/[0P0lA3<02`0mAc@0>d@c03M0<@0b>bh0:c<Y02D/8`0Q:1h07B<K02<[7`0]>BL0=3l[
0080>TD^00/0@4Xb04===@13C3H0@DTf045:=`10BCH0@DXf04=<=`15CcP0ADli04MB?00204QC>P0;
04I@=P14C3<0A4`c04A<<P13BS00ADdd04A==@14CCL0A4hg049<=@11C3800P11C3003012C2l0@Td_
0459;`13B300@dLc04=7=P14B3P0@dLh04=8>012B3H0@DTd049<<P80@ddb00/0@d``04A<;P14Bb`0
ADT]0455;00m@Rd0?D8b03e4=00mAC40?4D^03a5;@0203a4:`0;03Q0:00f?BH0<SPS030e8`0^<R40
;C4P02hb800_<b40;c<R02le900a>BL00P0^>2H0300/=bD0;cXW02lj9`0_>B@0;CPR030k8P0d?B@0
<c/T03<h900c>2H0;cDU02hd9080<3HU00D0<CLV030f900]<b40:c0P02X_8P0202P]8@0402X`8`0/
<R80;38P02/`7`80:BhL00/0:S4K02/c6`0[<QX0:BdH02TZ6P0W:Ad092HK02@V700S9Q`07b<J020V
7002024V700601hU6@0M91L07R<D01dR4@0M8A006ah=6_oooon]0?n000oooooo000=ooooo`0602P]
<00Y;S809R/^02@Y:@0S:2L09R/Y0P0V:bX202@Z;009020V:00L8B805a`K01HK5@0B5`d03A4600/>
0P0;3`<02`h40080310500/03a8700lA200<3@P02@/700X;2P0;30X03@l:014D3@0D60l04QL<010D
2P0200/@100<00L:00062@001`T100P90`082`@020/500P91P0;3@X041<@01@F4`0E61D08BDN0P0d
?Bl02`0lAS@0@4/g045<>@0h@S40;3@V02H]800N91X05a/E01DI4`0M8aX09RdQ0080<3XZ00/0>4@_
03m:<`10Bc<0?dPb03m8<`0oAc<0@4Pc0458=@13BSP0AD`j04E>>P0204A?>00404A?=P12CS@0@dhd
04=><P80A4d`00D0AThc04I==014C3@0@DXd045;=002049<<`08045;<@10BS40@D/b04A;=015BcH0
A4Tg04A8=P15BCP204I;>P0<04E<>013BcH0@T/e049;=@13C3@0A4hb04=<;`12BBh0@DD/03a1:P0k
?b`0>Cl^0P0j@C003P0lA340>d<_03]3;`0h@2d0>D4^03Q0;00e>bT0<CHT02hc8@0_=B40;cHP02le
8@0^=280<3LT0P0_=bD02`0^>2@0<3/U02ll8`0`?2<0;CPO02dg7`0_>B40<S/S03<j9@0b>2D0<3DT
00<0;C<Q00/0;cHR034g900a=b@0<3DS02dd8@0]<R40:S0P02X`8@0[<B40;3<P02X_700202T^6`0;
02X`7@0[<Ah0:RhL02X]700[;Qh0:B`O02HX7P0T9ah08B@K020S6P0P91T00P0O8QP01P0O8QL0724C
01hR500O8a<07b8C01dP4A[ooooo[@3oP00?ooooo`003Oooool01P0W;2X0:Rh/02X];@0Y:b/0:2XX
02LZ9`80:2`Y00/0:2`^02HZ<00W:c409b`_02H[:`0Q9b<061`G010D3P0>40X03a0:00l?2`0200d<
2P803Pd<00T01`H700<310041@D010D400T<1P0B5``061d?01LM3P0A5PX00P0<40<0300930402@`2
00P:0P0:30D03@l800/=200:2`L02@T800`;2`0A414051<B01HF4`8071dH00/09bXQ03<h:`0mA3@0
=Sd_02L]8@0P9QT05QT?01LJ4@0G6Q<061hE01lU6`0202L`8`0;02hi9P0e@B/0>4D/03Y6;@0nB2l0
?dTb0419<`10B3D0@4Lf0459=`11BcL00P10CCH02`11CcH0@e0f04A?=@14Cc40A50`04A?;`15Cc00
A4da04A=<P11BS80@4Xb0080?dXb00`0?d/b03m;<@10BS80@T/d04A<=P15BcH0ADXg04E:>@16BSX0
Ad/k04M<>`12BCD2049:=00;049;<P12C300@D/^0459;@12BBh0?d@]03a0;00i?Bd0>3d_03Y0<@0k
@S400P0j@S802`0i@S00>D4^03M0:`0g@BT0=3`U038i8@0c>R40;cHO02dd7`0]=240;CHT0080;cLT
00<0;SPT02lk8`0^>Ql00P0_>al01`0^>Al0;cXP034k8@0c?2@0<CPS034g900^=2800P0^=B402`0^
=Al0<CLQ03Dj900e>b@0<SPT02le8@0[<Al0:2lM02P^700Y;a`0:S0J0080:RlK00/0:BhL02T/7P0[
;Ql0:RdO02X^800W:Ql09BLM02<U700R9A`08B<J020R5`0201lR5P0601lR5@0N8A<07B4B01lS4`0O
8aD0724D6_oooon]0?n000oooooo000=ooooo`06020W8`0U;2@0:RlV02d`:00^;bT0;2dY0P0];b`0
2`0/;Rh0:R/`02`^=@0_<SP0<CHi02/a<00L8B0061XI01DD5@0C41<04@lC00803@/A00/02`T@00L6
3P0510/00`<700@51@031@<01@L1018H200J80l05a`<018E200200`?1@0<00T;0P0:30@02Pd700lA
2`0B50`0414<00h?2`0<30X03@`<01<A4@0G5A@05Q@C0P0D4a802`0H61@06a/G028T7@0T9al07B8I
01HI4P0@4@X04Q@<01/O500Q:1/092/N00808b/M00L092dM02Ha7P0Z=R40<3/V03M3:`0mB300@4`d
0080@D/f00L0@Tdg049>=P13DCH0@e4f04=B=@17E3L0Ae8g0080AU4e00D0AU4c04I@=014CS<0@Tda
04==<`0304=?=@0<049>=011CC@0@D/c045;<`13CCH0A4dg04M=>018CSP0BDhi04Y>>P1:D3/0Be8l
0P19CcX02P17CSL0A4`c04=<<P13Bc<0A4`d049:<`12B380@DHc03m4<@0nAC8303m9<`0;03e6<@0l
AC00>D@]03U7;@0hAB/0=d8W03I0900b?200<3TP030i8@0_=b800P0a>RD0300b>bH0<S`V038l8`0a
?2<0<C`T034j8`0d?2D0=ChV03Hn:00e?2L0=C`X034h9@80<3HS00/0<3LP030g7`0e>R80=S`S03Dl
900c>b<0;cLP02`d7P0Z<Q`0:C8L02Xa700202/a7@0;02X_700Y;Q`0;34O02/`800/<R40:BhO02DY
6`0U:A`09RXO02DX7@0T:1`00P0S9a`01P0Q9QX08BHI020W600P9aL07bHG020U5a[ooooo[@3oP00?
ooooo`003Oooool01P0G7Qh06R4L01hT6`0R9A`09RPQ02T[9@80;C4[00/0;S4^02ha<@0^<S@0;S@g
038j>`0a>CP09bd]020U9@0O8B@06ATQ01@D7P02014A700;00l@6`0:2QD01PD@00<32`010PD00@<3
00<50@0=4@H05Q`>01PM3`0F5`d00P0A4PX0300>3PP03@d900h?300C51805aTE01LJ5`0B5Q@03Q0@
00h@4@0B4a<05ADF01<A4`804@lA00/04Q8A014A3`0C51005aTB01DI3`0A4`X03a0700/;0P0F6@`0
9B/J02H/7P0201dS6@0;01TO5P0F71<061hC01`T5P0T;A`0;3HR03A0:P0iA2d0?4P_03i:;`11Cc40
0P13DS<02`14D3<0AU4f04MA>016CcL0B58h04MB=`15DCD0AE4f04A@=@12CS@0@dhe0080A4hf00`0
@dde04===013C3@0@T/e049;=P14BcL0AT`h04M;>018C3T0BDdh04]>>@1@E3l2055E@00404eA?01:
CcX0B4hi04I<>080A4/g00D0@d/d04=;<`11B300@4P`0459<@020459<P090457<P10Ac40?DH_03a7
<00kARl0>4@[03I29`0d@280<CdP0080<3TO0P0`>R40300b?2<0=3lU03@m9P0c?2H0<C`V038k9@0d
>bL0=CXV03Hm:@0g?bX0=ShZ03@n:P80<cdW00/0<c`S02he7P0/<Q`0<3HM030g7P0`>1l0<3PN02de
700[<QT0:C0H02P]5`0202L/6@0;02P/6`0Y;Ad0:c0O02X_800Y;b00:RlP02L]7@0S:QX092TK02<X
6P0Q9QP00P0R9QT01P0Q9QX082PK01lX6P0Q:A/082LI020U5a[ooooo[@3oP00?ooooo`003Oooool0
1P0G7Qh06R4L01hT6`0R9A`09RPQ02T[9@80;C4[00/0;S4^02ha<@0^<S@0;S@g038j>`0a>CP09bd]
020U9@0O8B@06ATQ01@D7P02014A700;00l@6`0:2QD01PD@00<32`010PD00@<300<50@0=4@H05Q`>
01PM3`0F5`d00P0A4PX0300>3PP03@d900h?300C51805aTE01LJ5`0B5Q@03Q0@00h@4@0B4a<05ADF
01<A4`804@lA00/04Q8A014A3`0C51005aTB01DI3`0A4`X03a0700/;0P0F6@`09B/J02H/7P0201dS
6@0;01TO5P0F71<061hC01`T5P0T;A`0;3HR03A0:P0iA2d0?4P_03i:;`11Cc400P13DS<02`14D3<0
AU4f04MA>016CcL0B58h04MB=`15DCD0AE4f04A@=@12CS@0@dhe0080A4hf00`0@dde04===013C3@0
@T/e049;=P14BcL0AT`h04M;>018C3T0BDdh04]>>@1@E3l2055E@00404eA?01:CcX0B4hi04I<>080
A4/g00D0@d/d04=;<`11B300@4P`0459<@020459<P090457<P10Ac40?DH_03a7<00kARl0>4@[03I2
9`0d@280<CdP0080<3TO0P0`>R40300b?2<0=3lU03@m9P0c?2H0<C`V038k9@0d>bL0=CXV03Hm:@0g
?bX0=ShZ03@n:P80<cdW00/0<c`S02he7P0/<Q`0<3HM030g7P0`>1l0<3PN02de700[<QT0:C0H02P]
5`0202L/6@0;02P/6`0Y;Ad0:c0O02X_800Y;b00:RlP02L]7@0S:QX092TK02<X6P0Q9QP00P0R9QT0
1P0Q9QX082PK01lX6P0Q:A/082LI020U5a[ooooo[@3oP00?ooooo`003Oooool01P0K82806QhN01LL
600G6a@06QdG020R7080:2/S00/0;2lX02lc;P0`=S<0;SDd02dd=P0`>3P0;SLe02P_;P0W;Bh09BX_
02@Y;`0202@V<@0;028T;`0L7RP051DP00h>60082A4010H;00<51P0;3`X051P>01HJ400B5@d00P0B
4``0200B4@d04Q4>01@C4@0J6aL07B4L020U8P0O9B<0728O0P0J7ah03`0E61X03a4D00d=4@0=3A40
3@d>00`>300=3`/041<=010D300>4@P030l500X<0P0J8100:C8N02Tc7`0201lW6@0;01TO500D60l0
4QH<018F300E6@l061d@01hT5@0T;1X0;3HP03A09@0lB2/00P11CC002`15D3<0AU4e04M@=`17DSP0
B5<f04MB=@15Dc@0AU@g04ME>@16DSP0AE4h0080ADlh00D0A4hg04E>=`16CCH0B4lg04Y@>00204Q>
>P0504I<>017C3T0B4dj04Y?>`1>DS`00P1>DSX02`1>DCX0C54j04]A>`1:CcT0ADhh04E?>013CC@0
@ddc045;<010Ac00@DL`0080@DLb00/0@TPd0498=@0oAS@0?THd03]4<@0h@B`0=d8Y03Do8`0a?1d0
<CXM034j7`02034k800<038m8`0f@2D0=3hT038l900a?2@0<S/U03@k9`0e>RT0=C/[03Hn;00d>bT0
=C`X0P0e?RP02`0e?BL0<CTT02de7`0[=1`0:cDL02Xc6`0/=A`0;CHL02/b6P0Y;aP0:RhI0080:c4N
00/0:RhN02T^7`0Y;b009bdO02T_7`0Y<1l09blN02D]6P0S:aP082TE01lW5002024X5P0602<Y600O
9aL07B@F01lU6@0O9AP07R@E6_oooon]0?n000oooooo000=ooooo`0601lR8P0M820061`K01HJ5`0F
6Q@06AdE0P0L7QD02`0O8AT08bDP02PZ9`0[;b`0;3@b034j>00a>SH0:c@`02/b<00/<c<0;S<d0080
<3<g00/0<3<i02ha>@0[;SL08bL`01PL9@0@4a/02`dB00/>400@51005AXA01DI4@0201<E3P07018C
3@0C4`d05QL@01XK5@0J71P07B4N020W900202D/9`0302L^:00P9R805ATH0080414C00/03`h@00d<
3P0>3@h0414@00lC400?4Pl03A0<00`@2@0A5`/061l?01XR400201/R4@0;01TP3`0F6`h04aH:018E
2P0C5@/04Q@:018E2`0C5``06b8A028Y500/<a/00P0i@RL02`0oB2`0@dda04I@<`18DC@0B58c04MC
=P17DSL0Ae<h04UE>P19E3X0B5@k0080Ae<k00L0AU8i04E?=`14CCD0B50h04UA>P18D3/0Adhk0080
Addh00<0B4hi04U?>@1<DSX00P1<D3P01P1;D3P0C58k04aC?01;DS/0AU0h04A?=P80@dhd00<0AU4f
04A?=P13C3@00P13Bc@02`13BcD0@dTd0457=@10B3@0?4@a03]2;P0kA2`0>48W03Do8P0d?B00=ChP
0080=3hQ00`0=3dQ03Dm8P0f?R<0=ShT03Dn9P0d>bH0<SPU03Dl:00d>RL0=3/X03@l:00e?2P203Dl
9`0;03@k9P0b>bD0<C/T02lj8P0^>R00;CPO02`e7P0^=Qh0;C<O02`b7`0Y;Qd00P0[<2002`0[<280
:BlQ02P_800X;ah09bdM02H]6`0W;aX08b`G02</5P0S;AH08b`F00808b/F00H08RXF020X5@0O9aD0
8BTG02<Z600O9AHJooooojd0oh003oooool000gooooo00H061dL01hQ800L71h05aPJ01LH5P0H6QH2
01PI500;01TJ5@0I6AH06APG01/L6P0P9B40:30Z02df;`0^=bh0;cPa02de<@0]<c400P0_<c@02`0`
<cP0<C<l034e?`0_=Ch0:c8i02<Z<00M8RL05adO01LM6@0H7QL05AXD00804aL@00`04QH>01DH3`0G
6a805QT@014D3P0B5A005a`G024V7`0Y;bD0;S@Z02he:`0T:R@201`O700;01PI6@0C4A@03PhB010?
4`0?4A<041<C014D4`0A5a804QT@01HM3`0G7``00`0G7P/02P0E6PT04aL8014E1P0A5@H041@500lD
1@0@50H05AT:01DH200J7@X202T^5`0;03Ll8P10B2/0AU0b04UB=@19DcH0Ae<h04MC=`16DcP0B5Dj
04UE>P19EC`00`17Dc`02`15DCT0A4hh04E>>P17DCd0BE<m04MB>P15CSH0AThe04M>=@18CSH0B4df
0080BThg00H0BDhg04Y?>`18Cc`0B54m04I@>P14CSH204=>=@0304===@13CC@0@ddd0080A4hf00/0
AThh04=:=@13B3D0A4Xf0417<`0k@c00>T8^03U2;00e?bP0=D0V03M2900203I08P0<03Ho8`0g?b<0
>D4U03Q0900g?RH0=S`V03<i9@0a>2D0;cDS030f9@0c>bP0=3/W0P0c>RH02`0`>2@0<CTS038j8`0c
>b<0<SXR03<k8@0_=Qh0;C@K02hc7P0^<b80;C8Q0080;34R00/0;34T02`b900/<R80:c4O02L/6`0U
:aP09bhI02D]600U;QT092dI02@/600202D/6@0602<[600Q:AH082PE01hV4P0N9Q@07b@E6_oooon]
0?n000oooooo000=ooooo`0601/P7`0Y;BP09BHU01lM800J6Ad06APL0P0H5QT02`0G5QP05A<D01<B
4@0A4a404aLB01PN5`0N9A/09blQ02hf:00`=b`0<CH^0080;c<_00/0;c8b034c>00d=Sh0=3To038h
?`0_=c`0:c@f02D_;`0P:2L06b8P01HK6P0201HJ600<01LJ5P0F6QD05QXD01@H4P0>4@`03@l;010C
3P0K7aL08RHL02HZ7P0[;R80;C8X0P0]<BX02`0Y;RT092LV01dO8`0G6Al04QDJ014D600E6AP06R0J
01XQ600J8AD05al?008061l=00/05ad<01<I200B5`P03a@600hC1@0>4@<041D501<G1`0E5`T04Q<7
018B1@0201TH1`0;028Q3P0/;AT0>d4[04A==017DCL0BEDk04YF>P19ESP0BELg04MD=P17DcP00P18
DcT03019EC/0Ae4j04I@>`15CS`0Ae4l04MB?018DcX0AE0d04A><@15CS80ATdc04I<<`80Ad/c00/0
AT/d04M<>017CS/0A4`j04A=>014CSH0A4le04==<`11BS80@T/c049;<P020499<`0;04A;=014BS<0
A4Td04E;=`13BSL0?dLg03a3=@0i@C80=T0^03@o:`0d@2T00P0c?RD0300c?R80=SlR03M0900e?R<0
=3/S03Dk9@0c>2D0<CLU02hd9@0]<R@0;C<T02hf8`80<3PT00/0<CPS030h8P0_>240<3LP030g7`0_
=Qh0;C@L02`b6P0]<Ad0;30O02/_800202/_8P0;02``8`0/<B40;34P02`a800Y;al09R/K02D[6P0T
:aP08RXG02<Z5`0V:aX00P0V;A/01P0V;Q`092/J024W5`0N9AD07R@C01dR4A[ooooo[@3oP00?oooo
o`003Oooool01P1CHeL0BEE;03Dl=P0a=S80;2h^02PY:`808R4T00/07Q`O01/J6P0H6A@051L@018F
3`0C61005AT@01`O4`0R91L0:R/R030c;002034d;P0;030c<@0c=SP0=cXn03Lk@@0g?D@0<c]1034j
?P0^=cT0:C4b02<Z:`0Q9bP00P0Q9BL0300O8B8071lN01PI6`0C51L03PhB00/;3P0@4Q80720K01`P
6P0H6a<061XB01lR6P809BXR00/0:BhY02/b;P0Z<Bh08BLV01TO7P0H7Q`06b4L01/R6P0L91X06R0F
01LL400301TN3`0:01HH2`0B50T04188010A2@0>3`P0414801<D2P0E5@`05AH<01@D2@805aD600/0
6aT801`K2P0Y;1T0>ClX0458<018D3@0C5@h04eF>@1;EcX0BeLk04UE>`0204UD>`0<04QD>P19EC/0
BE@j04MB>P18DCP0B50h04Q@=`16CS@0ADdd04I?=@15CSD0AThe0P15C3<204I<=00904M==@14BS@0
@dTd04A<=013BcD0A4/e04A<=@14Bc@0A4Xc0080A4Xe00/0A4/e04I>=015C3@0AD/e04A9=P12B3L0
?dDh03a2=@0i@C80=Sh^038k:P02030k9P0:034m900b?R<0<cdS038l8`0a>R@0<c/U03<i900^=B40
;S@P02lf8P80;C<P0P0_=B802`0a>2@0<CPS030h900`>2@0;cLS02de800[<ah0:c@N02`d7P0[<Qh0
:RlM0080:bhN00/0;2hP02`_800Z;ah0:RlO02X`800X;b009B`M028Z6P0Q:AP08RTG02D[6P0202@Z
6`06028Z6`0S:Q/08RPJ028X6@0Q:1L07R<@6_oooon]0?n000oooooo000=ooooo`060766O@1bQW`0
IGM_05i]I@1GHUd0C5AB0P15C4X02`0j@Cl0:2`Y02<X800R9ad08RHM02@X7P0T9Q`08R8I01lN600S
8200:bX[0080:RX[00/0:RX/034b<`0e>CX0=c]103U0A00h@DD0=3e202lh>`0/=CP0:c8d02`d<`02
02lh=00<02dc<P0Z;S0092D/01XI8`0C41/040dG01DC6`0K7B005QXL014C4`0=3P`03Q4>0P0C5Q<0
2`0J7QX08BLS02D/9`0S:R@07bLP02</8`0T;R@082XP01hV6`0I81@05ad@00806Ah@00/06Qh@01TJ
300D5@T04a<:01@D2`0@40P03`l8010?2@0A4@X04a<<01@D3@02024S5@0;02P/6P0Y;a/0;3@N03@l
8`0j@BD0@DLZ04I<<@1;DSP0CE@k04eF?`1;ED400P19ED003019ESh0B5@k04UC>01;ECP0CEDi04aC
>@1=DST0BThh04U=>018CST0AThh04Q@=`80B4le00/0B4ld04I><P14Bc00A4Xa04E:<P18CSD0Addg
04Q>>P17CCX0AT/h04E:>00204=:>00;0459=P12C3<0@d`b04A<<P14BS80@dPc0497=@10ACD0?d@d
03a1<@0g?2d00P0b>RX0300b?BP0<CdT034l8P0a?240<S/Q03@m8P0d>b80<STP034h800c>R80<cTS
038g8P80<3HR00/0<3DR030f8`0`=bD0;cPW02hh9P0^>2@0;CLT02dg8`0/=b80:cDQ02Xb7P0202`a
7`0;02/]7@0/;b00;C4Q02``8`0/<2@0:c0T02P_8`0S:b008b/N02<Z6`0T:a/00P0U;1d01P0R:1/0
7bLI024W6P0Q:1P082PF01hV4Q[ooooo0`000?nZ0?n000oooooo000=ooooo`0607jBR@23UXh0QIRB
08>ET021TXl0NXV80P1gQh@02`1`P7h0FFMX055MG@1EHEd0FVMN05YVFP18CdP0=3Lf03Hh>`0c=3/0
;2`c00808R4W00/07Q`Q028P8`0X:2X0<38d03@h>@0f?Cd0=Sm0034i?00[<cP0;CDh034j>`0203Dn
?P0<03Ho?`0h@440=cXo02la>P0U9S<0820]020Q:`0N82L051DL010B5@0>3Pl03@d<0P0?3`h02`0A
4@l04a@A01LK5`0J7a/092`U02Pb:@0Y=2T09S4W024Z7`0L8aL06R4C00806R0B00/06QlB01TL3`0F
5P`05QH<01DG300C4`T04Q89018B2`0C4``040l;010?3P02030f:P0;04YH@`1=GTH0Bea204ID>P11
C340?TL/03m7;@13BS40ATdf04M@>P1:Dch00P1:ECh0301:ESd0BU@k04YC>@1;DcT0CE@j051G?P1?
ESd0CU<k04a@>P1:D3T0Be4j04YA>@80BE0f00/0BE0d04Q>=017CC@0Ad`d04Q<<`19CCD0B4dg04Q=
>@19CS/0AT`h04A:=@0204A<=P0;04A==P13CC@0@ddc04A>=014CC@0AD`d04I<=015BSD0ADTd0455
<P0m@S000P0j@2l01P0f?b/0=3hX03<l900c?2<0=3`S03@l9080=CdU00@0<c`T03<k9@0c>BD0<cXV
0P0a>BD02`0^=R<0;CDR02`e8`0/=R<0;CPT02hg900]=bD0;CPV02hh9`0]=bL0;CHW0080:c8T00/0
:RhQ02X_8P0/<2<0;2lS02X^8`0X;R<09R`S02D[8P0U:b4092XN02@[7@0202@Z7006028W6P0Q9AT0
82HH024X600P9aL07b@E6_ooool90000oj@0oh003oooool000gooooo00H0PYJ<08JHT@2:ViP0RYZL
08ZJWP28Uid208JGVP0;08JGV024UIP0Oi2D07nBTP22Ui<0PYN>07V;PP1/Ng@0Kgig05aWI@0/;SP0
0P0K6B@02P0J6Al05A<I01HD6@0M7Ah09RPV02lc<00d>CP0=Chl038k?00i@d8303m:B@0<03a6B00k
A4P0>T5703PoAP0e?4D0<SU302he?`0T:C@06A`W01<D7P0@41H04A4C0P0A4A402`0?3Pd03Pd<00l?
300A50l08bXR02H^9P0Y<BL0:C8W02@/8`0Q:B007RHK0080728I00/06b0H01XO5`0H71@05a/B01DH
3`0D5``05AH<01PI3`0G5Q005QH@01lP600202X[8`0;04I>?P1AGdX0DfE<05=TBP1@HDD0BEPn04EC
=`13CS<0@dhb04A?=017D3L00P1<E3/0301;Dc`0Be<k04eF>`1=Ec`0BeDl04aG?P1>Ecd0CEHk04eF
>@1=E3P0CE<h04aB>P80C54j00D0Be0k04]@?01:D3`0B4hj04M=>00204M==@0304I<=@17CCL0Adde
00<0Addd00/0ADdf04A==`13CCH0ADlg04E>=`14BcH0@d/e04=:<`13BC40@DPa03m7<@0203m6<00<
03a3;@0j@B`0=CdX03<j9`0b>RH0<c`Y03@m:P0b?2X0<C`Y030k9`0`>bH0<C/W0P0a?2L02`0`?2H0
;cXU02li9@0_>2@0;cTT02hf8`0]=RD0<SXZ034j;00`>2h0<3T]0080;CDX00@0;38U02X`8`0Z<2<0
:S0R0P0Y<2801@0X;R00:BhQ02X^8@0Y;2409RXN008092TJ00H08B@G020T600P91T08bHJ02@W6`0P
8aTJoooooa40003oW03oP00?ooooo`003Oooool01P20U8h0QYZD08ZKVP2;W9h0S9fQ08bLX`80RYZO
00/0RYZL08ZKW02;WId0RYnN08^QW@2:XYT0Rj>F08ZQTP2<XI80OY2403i3B00201XI900;01`K8@0G
5AX0514E01<A4`0G5QH07AlM028U8P0/<bh0<S/f03]5?`10C4@00P0oBT@0300nAdH0?DE703]3B00h
@4P0>41703Y3C00j@d/0=d18030f@00S9c407B0X01DG7@804Q8G00/040lC00l=400?3Ph051HD02D[
900R:B8082LP02D[8P0W;R8092/P028X7P0201lU7@0;01hT7P0O91l07bDN01dS6`0K81L06QlE01TN
4`0J7A<06ATA01PH4P0S8a/00P0S8aX02`0o@c@0EV9<051OB@0nBcX0@e8n04UJ@@1=Gd40BU`k04MG
=@17E3<0AE0a0080Ae0d0P19D3P02P18DCP0BEDj04QF>P1:Ec/0CEXm04]G>`1:ECX0C5Dj04aD>P1<
DS/204]@>`0;04]@?P1;DCl0BU0n04Q??`17Cch0ATlj04I?=`16CSH0Adlf04I?=017CC800P17C3@0
2`16BcD0AT/h04A;>014C3X0@d/i04=<>P12BcL0@DTc0498<011BC00@T/`0080@dT`00`0@TL`03m5
<00l@c00>Cl_03@k:`0a>RX0;cTZ02hi:P0_>RT0;c/V030l900`?2<2038m8`0;038l900b>bD0<STT
034g900`=b<0<3HS02lf900]<b80;3@U030h:P0^>2T00P0^=bP02`0]=R@0:c8Q02P_7P0W;Qh0:C4O
02Tb7`0[<Ql0:RlM02d_7`0/;b40:2dO00809BTL00H08B@G020R5`0P8QX08bHM028U7@0P8A`Joooo
oa80003oV`3oP00?ooooo`003Oooool01P1oUHd0QifF08ZOW02;Wil0SJ2R08fOXP80S9nO00/0SJ2M
08bNV`2<Wi`0SJ6L08bRV`2<Y9X0SJFH092WV02AZ9D0SjFB06alL@0202hb=@0;028T9P0P820061LH
01DC500D4Q8051<A01PH5@0L7QX07R<N02P_:00`>3000P0g?CH0300k@C`0?D=203i5A`0nATT0?dM:
0417C00oAT`0?TI=03m8CP0lADX0=cm202``=08092DZ00/07alU01XH800D4QX07QhQ02<W9P0J7Qh0
5a/H01/Q6P0R:Ad08RPL020U6@0201lU6`0;024W7P0Q:1h082LL024X6`0P:1/082PJ01lU5`0L7a@0
6ATB01HE4`0H61D00P0I6AH02`15D3h0GVmE04AA?`0]=BX0;3@X02/d9@0nBc80C5lm051R?P1AHSl0
C5/k0080Ae<h00`0Ae0h04QA>`17DCd0ADlj04=@>P14DSX0BULm04]G?P1:ESh0BeDo04]C>`1:DCX2
04M?>@0;04Q@>`19DSd0BE4m04QA?P17Cch0ADhm04I@?016D3X0Ae4h04I?=@16CS@00P17CcD204I=
=@0904I==`15CCT0A4/i04E=>P13BcT0@DTe045:<`11BC40@d/a0080@dXa00`0@TP_0457<011B380
?TDa03U0;P0d?B/0<3TY030i:P0_>2L0<3XU030k8P0`>R02030i7`0;034h8@0`>280;cHR02lg8P0^
=R40<3PS02lg8`0]=B80:cDQ02hf8`0^=R@00P0_=bH02`0_=bD0;C<P02db800Z<1d09bhL02D^700U
;Qd0:2hM02X_7P0[<1l0:BhO00809BXM00H082DI01hS5`0P91L08RHK020T6`0O8Q`Joooooa<0003o
>03oP0000`000?l0oh000?n0001O0?n000oooooo000=ooooo`0408BKT@29X9P0RZ:L08^RWP80Rj2N
0P2;X9`02`2:WiX0RinI08fPVP2=XIT0Sj>J092UV`2@YY/0TZRK09:WV@2DZIT0R9b<0080GF]S00/0
>3lm030d<P0P8B<071/N01TG6@0F5AD05aHD01PI4`0F5a806AXE01dO6@0202DW8@0<03@f;`0k?SP0
?d@o0498A013BTT0ADi>04A>D011Bdh0?dY<03m:BP10AdT0@4I70P0m@D@02`0i?400<C4i02PW<@0Y
:S0092DZ01@D6`0@4AL04QDE01@H500E6AD06AhG0080724I00/07R@J01hU6@0M91L082HG024Y600S
:QT08RHH01lR5`0N7QP071`J01hP7`0201dQ800;02@Z9P0^=bd09B`T02HZ8P0S9al071lG01/P5@0/
=R@0AUHk05=WB@1GJT`00P1DIDX0301>G4<0BEDo049=>`0lASH0>THf03e9>012CS/0AU<o04QE@@1:
Ed80BEE004QE?080BEDj00/0C5Hj04YD=`19DSL0BU8h04Q?>`16CS`0Ae0m04MA>P17DcX0ADle04A?
<`0204I?=00;04I><`15CS@0AD`d04M==@16C3H0AD/g04E<>014C3L0A4df049;=011BS<00P11Bc80
3012BS00@4P^0418;`0oAc00?THa03e5<@0j@Bl0=C`]03<i:P0b>BL0<3LV034i9P80<c/U00P0<SXT
030h900[=240:c@Q02/c800^=R40;CDQ02he8P80;C@Q00h0;SDR02le8`0_=B<0;cHS030g8P0_=R40
;C@O02/b7`0Y<1l09blP02P`800Y<200:C4P02H^7@809B`L00H08BPJ01lU600Q9aL08BHF024U5`0O
8aPJoooooa<0003o@03oP0020000oeP0oh003oooool000gooooo00H0PIR?08NOU@28X9P0R:2I08NN
V029X9P208RNU`0;08RLU02:WiH0SZ:I092SV`2AYId0TZJM09:UV`2CY9/0UJFL09JWW@2CYI/00P29
Vi402@1iRX00Ef9O03Pl@00^<3D092@Z028Q8`0M71X06aXF01PH5@0201HE4P805A<A00`07AXE02DS
7@0_<2X0>Cdf0416@012BdL0ADm<041;B`0mB4T0?TU:0419B`13BD`204A9C00;04=8C013AT/0@D=;
03`oB00/;ST07QhZ01@F800?41P03PhE00h?4`0@4Q800P0E6AD02`0J7aT07R8K01dS6@0N91P08BPI
02@Z6`0T:1/092HM02HX8P0X:BT0:2X/00808BDW00/06A`P01LI700G6A`07AlM01hP6`0K71T061/G
01LK5`0Q:1h0<Sd]03i<=`0204eNA00<05MYC@1BHTX0=T4a02Xc9P0V;b<0:34T02`e:00g@c40?T/e
04EB>`17E3d0B5@m0P19EC/02`1;FCX0BUHg04UD=@19DcD0Ae0g04QA>@18D3T0ADlf04I@>016D3L0
AU0e0080ADld00/0A4hc04E?=015CS<0AT`a04A8<014BS80Ad`f04I<=P17CSD0AThe04E==@0204A;
=00<04=;<`0oB300?TH_03e5;`0oAc40@4Pb03i6<00j@Rh0>D0^03Hl:P0d>BT0<cPX0P0d>RT02`0c
>RT0<S/Y02dg9P0Z<b<0:c8P02/b7P0/<Qd0;C<N02`c7P0[<ah0;C@O0080<3PQ00/0<3LP02lg800^
=B00;CDR02/d8`0X;b809B`P02</7`0W<2009RlN02<[6P0202@/6`0602<[6P0M91D07B@E020U500Q
9A@082<D6_oooolF0000od40oh0000<0003o0?n0003oP000D`3oP00?ooooo`003Oooool01P23V900
QYfE08NNU`26WiT0QYfG08NMU@80RIjF00/0RYjG08bPV@2=XI`0SJ6L08nSV`2AY9`0TjFL09BTW@2G
Yil0UZJO09FUW@0209BUV`0;09>UVP26V8h0Kgeg051IF00e>C`0<C@b02T[9@0Q8Qd071dI01TJ5P0G
5A@00P0F4Q40300F4@l05a4@01/G500X9200=CH`03Pn>@0nAT80@Da7049=BP11C4/0@Te<04A<C080
A4]:00/0A4U904E9B`17B4l0ADIA0453CP0h>dL0:bli01PJ9P0D51l04A4I00l@5@02014B5@0;01HI
6@0K7ad07B8N01hT7@0Q9ah08bTO02@X7P0T9Ah0;c8[03Hj=@0f>SX00P0Y;3002`0O7bD061PO01DE
6P0G61/06Q`K01TM6@0I7aT06R0J01HL5P0I81H07RLH008092lL00`0?Tdd04QI?P0^>BH08RXK01`S
5P0H7a<05Q`?02@/700b>bL0?TL`04E@>018DS`204QB?@0;04UE?01:ES/0BUHi04UD>017DcH0BE<f
04YA=P17CS@0ATde04M?=`15CSL00P13C3H02`12C3H0@ddg04=<=@12Bc40@4P^0458;P12B2l0@dP^
04E:<@16Bc<0AT/e0080ATXh00H0A4Th0457=P0nAC@0?4@c03a4<00lABh303e5;P0303e2;00k?R/0
>3XZ0080=SPZ00T0=3P/038h:`0]=BL0;3@T02/b8@0Z<Qh0:S<L02`e7@0Z=1X00P0X<AP302/d6`0:
02de7`0]=240;3<T02/c:00V;BD08RTQ028Y800S:R008b/P02@]7P8092dL00H08b/H020X5@0Q:A@0
8bPB020T400N8@hJoooooaP0003oU@3oP00?ooooo`003Oooool01P23V900QYfE08NNU`26WiT0QYfG
08NMU@80RIjF00/0RYjG08bPV@2=XI`0SJ6L08nSV`2AY9`0TjFL09BTW@2GYil0UZJO09FUW@0209BU
V`0;09>UVP26V8h0Kgeg051IF00e>C`0<C@b02T[9@0Q8Qd071dI01TJ5P0G5A@00P0F4Q40300F4@l0
5a4@01/G500X9200=CH`03Pn>@0nAT80@Da7049=BP11C4/0@Te<04A<C080A4]:00/0A4U904E9B`17
B4l0ADIA0453CP0h>dL0:bli01PJ9P0D51l04A4I00l@5@02014B5@0;01HI6@0K7ad07B8N01hT7@0Q
9ah08bTO02@X7P0T9Ah0;c8[03Hj=@0f>SX00P0Y;3002`0O7bD061PO01DE6P0G61/06Q`K01TM6@0I
7aT06R0J01HL5P0I81H07RLH008092lL00`0?Tdd04QI?P0^>BH08RXK01`S5P0H7a<05Q`?02@/700b
>bL0?TL`04E@>018DS`204QB?@0;04UE?01:ES/0BUHi04UD>017DcH0BE<f04YA=P17CS@0ATde04M?
=`15CSL00P13C3H02`12C3H0@ddg04=<=@12Bc40@4P^0458;P12B2l0@dP^04E:<@16Bc<0AT/e0080
ATXh00H0A4Th0457=P0nAC@0?4@c03a4<00lABh303e5;P0303e2;00k?R/0>3XZ0080=SPZ00T0=3P/
038h:`0]=BL0;3@T02/b8@0Z<Qh0:S<L02`e7@0Z=1X00P0X<AP302/d6`0:02de7`0]=240;3<T02/c
:00V;BD08RTQ028Y800S:R008b/P02@]7P8092dL00H08b/H020X5@0Q:A@08bPB020T400N8@hJoooo
oaP0003oU@3oP00?ooooo`003Oooool01P21Th/0QibC08ZPV@29X9/0R9jK08JKVP80QYbJ00T0RIjM
08bPWP2>X9l0Sj:P08nRWP2AXih0U:FO09FTWP2FYIh00P2FYYl209NXWP0;09FWWP2FZYl0TZJK08:C
R01XMVh0F6=J04YDB00/<R/09R`U01dP700I6AP00P0G5AD0300H4a<05a8A01PB4P0J5A@081dJ02HV
8`0/;bd0=3Xf03Y1?@10BD@0Ae1;04QAC080B51;00/0ATa:04I9BP14AD`0A4E=04=6C`14BU@0@TQA
03Y0AP0X;3@08RD[01/N900201<D6`0;018D700K7b@082HX020W9P0R:BH08RXT024X8`0Q9B00:B`V
03Pm=P0nA3h00P0k@Cd02`0`=3<0:Rd]01lP8`0L7B006ahP01TL700G6aT05APF010E400D6A406R4D
008061l?00`07B@E02H_7@0S:a/06B0C01PN4@0I81<06AlC01dT5`0Y<B00=ClX03a7;P10BS82049<
=@0804QB>@1:ESX0BeHi04]F>@19DcL0C5Dg04]C=P19CcD204Q?=P0>04I>=`15CcP0ADlh04E?>@16
D3T0ATli04M>=`14C3@0?TD_03a2:`0m@RX0?T<[0456;`12Ac4204A8=00<04E;=`14BSL0@4Lg03m6
=`0mACD0>d<`03]3;`0k@S00>d8_03i5;`0l@B`0>Sh/0P0j?Rh02`0h>bh0<cT]038h;00c>B/0<3LV
02de8P0^=B40;cPR02lg7`0]=Ql0:c<N0080:c8O00/0:S4N02Xa7`0[<R40:c@T02/d9P0Y<RH09blT
02D]8P0T;2008b/M02H^7@0202D^700602D^6@0T;AL09bhE02H/4`0S:1008BD?6_oooolJ0000oi<0
oh003oooool000gooooo00H0PiF;08^OUP2<Xid0R9nL08FMW@26WIl208JLWP0;08NMW`2:Wil0S:2P
08nRX@2AY:<0TZFS09BVXP2EZ:00UJRO09JWWP2HZ:400P2HZJ802`2HZZ<0Uj^R09FZX02EZYl0TJJJ
08VMT01jSGh0GfmR04UBBP0d=cD0;2d^00809BDW00`07Q/M01dJ6`0O7Qh07ahM01lN700M7AX07QhL
024R800X:RL0=S`f0417?`17CTH204aCC@0;04eCD@1:CU40AdYA04A8DP10AU00ADiE04A>D`15D540
@de;03m7A@0i?d400P0/;cL02`0P8Bd09b/e02H/=00N9BX072<T01/T8@0L8al0728L01/M6P0Q8b00
;S4^0080=cdh0P0k@c`02@0f?CL0;S@a02@Z:@0M8B805a`L018E5@0>4@l04AD@01HK4`0201LM4P05
01XO500Q:1/09B`N024X6`0L91H00P0L8aL01@0U;Al0<C/Y03M2;00kARh0?TP]0080@4T/00/0ADda
04Q?<P18Cc80BU4d04aB=`1<DcT0Be8h04UA>018DSP0B58g04UD=`0204QC=`0;04M@=`1:DCX0Be4l
04a@?01:CS/0AT/i04=8=`11Ac<0?dH`0417<00nAbl00P0mARl0300oB300?dPa03m7<@0oAc<0?dHc
03]2<@0lA3<0?THe03U2<00j@bl0>D8_03M0;P80>D4_00/0>D0`03Lo;P0g@2h0>D4]03Lo:P0d?2L0
=SdY03Dl:@0c>BH0<STW030h:00202de:00;02Tb9@0X<B@0:34T02Pa8P0X<R80:S@S02Tc8`0Y<R40
:S<P02T`7P0Y;Q`00P0Y;a`01P0X;Q/0:2dI02P]5`0W;1H09RXF02DX5Q[ooooo70000?nA0?n000oo
oooo000=ooooo`0608NLTP2=Xi/0S:BP08bSX`2:XZH0RZ6U0P29Wj802`27WIl0RIjO08^QX@2?Xj80
TJBR09:UXP2BYZ40U:NP09BWWP2GZIl0VJZR0080VZZU00/0VJbW09R/YP2GZjD0UjbT09N]Y@2G[J@0
UZbP09>XV@1jRX00K7U`06MdJ`0204E;C@0<038d?00g>cl0?D53034c=P0/;Rl0:B/Z02LY9@0V:280
9bTS02/^9`0`<Rd0>3Xd0P11@cd02`1:C4P0CDm?04iBE@1;DeH0ADiB049<CP11C4`0@di;04UDD01:
De80BU5D0080AdiD00/0?TA<03Y1B@0W;CP0728/01@K8@0C6Q`051XH01<G5@0A41804a4D01XG6@02
02d/:@0;03/o>@0l@S/0?TDm03a5?@0f?ST0;C@d02D/;@0K8B404ADD00lC400@4a000P0B5Q00300N
9AX09B`O02T`8@0W;Ql08b`K02<[6`0P9aL08RPI02DY6P0Z;ad0;C8O03@i8`80>3hU00P0?T@Z04E:
;`17C380Addb04U><`1:D3H0BU4h04UA>080Ae0g00h0B5<g04QB=`18DSL0Ae0f04Q?>@1:D3d0C590
04]A?P18CS`0A4/h0499=@11BS<0@D/c03m:<`80?DPc00D0?DPa03a6;`0lARh0?DH_03e5;`0203U2
;P0503]3<00h@Bl0=T0]03@n;00e?bd00P0f@2d02`0e?b`0<ch[03Do;00f?b/0=ClZ03@m:P0e?R/0
=d0]03Lo;00f?2`0<c/]0080<3T/00/0;cT/02df:P0Z<bL0:34S02D^7`0V;ah0:34N02Xd7`0Z=1h0
:C8L02T`6@0202T^6@809R/I00@09R/H02@X5P0V:1P09RTJ6_oooolP0000ohd0oh003oooool000go
oooo00H0QijF08bSW02;XYl0S:>R08^QY02:X:@208VNY00;08VNX`2:Wj40S:6R08fSXP2?Y:80T:JQ
09:XX02DZJ00TZJO09FXXP2HZZ@00P2IZZH209R/Z@0909V]ZP2H[:X0V:bY09Z^ZP2J[jT0VZnU09Z^
XP2:Vi40MH9l0080IFm^00`0FF1T079lM`1hQ7`0IVi/061ZIP1GHUT0@DQ003Hj<P0d=Bh0<C0[030]
;00d<Bl203Dc<@0;03Xi>00o?cl0AdY:04aCDP1<Ee@0BUI@04UEC@19E4d0C5IB04eEEP1<DUP00P1<
DE/02`1<E5d0BEAK03m:DP0e@4P092he020X:`0G6ah051@H018?5@0G4AD06Q@E0080=C<[00/0>STb
03<b;`0a<300<S@b03Tn>P0mAD00>dI0038n>00H8Ad04ALC00lC3`0200h@2`0<01`S5`0Q9aT08bTI
02L]6@0X;a/0:30M02X`700W;AX08RHF024S5@0M7a407R0B0P0U9aP02`0f>bL0BE8g04UB=`1:E3T0
BU<g04UA=P16CCD0AT`e04I==P16CCL0AU0h0080A4hg00/0AE0g04MA>`17DCd0B5<m04QB?016D3T0
A4hg04===@12C3@0@D`d049>=@02041<=00<03m;<P0mBS00?4P_03]6;@0mARd0?DD^03]3;@0j@bl0
>T8`03Q1<00g@2h0>48_0P0h@bl02`0f@Rd0=40Z03<o:@0d?bT0=3hX03<m:@0e?bX0=SlY03Lo:P0f
?B/0=C/[0080<cX[00H0<S//02lh:P0]=RT0;3DV02Pb8P0X<B0202Xd800302Tb7P0Z<Ad0:S0L0080
:c4L00H0:BhJ02H/5`0T:aD09BXF02DZ5`0V:aXJooooob00003o0`3oP0020000ohP0oh003oooool0
00gooooo00H0Q9ZC08VPV@2;XId0RIjN08NLW`27WJ0308VOXP0:08VOX02;XJ00SJBT08nVYP2AZJH0
TZZU09B[X`2EZJ@0UjZX09JYZ080UZZX00/0V:ZY09V[Z@2I[:T0VZf[09b_[02N/:/0Wk6Z09j`Y`2O
/ZH0RIZ@069/JP02069ZJP0<07=mN@2BX9D0UZFI09RXW02JZYd0UJNG07>0M`1HHE`0De]E04eBC01B
ETd0AD@n0P0i=c@02`0e=380=S@d03`j>`12@d@0ADY904Q@B`1=Ed`0DEa?059MD`1@F5D0C5=F0080
BU1H00/0CeEN051HH@1<EV00BUEN04A@E@0mB4/0<SXl02T/<00R82@07QPL02DP80020450>@0;02lZ
:P0U8B@08A`Q01dI7P0S8b@0;C4_03@n=`0hA3T0:cP/01HO5`0C6@l00P0=4PP0300@5@/04aP<01@H
2`0H7@d07R@D024X600S:AT07bHG01`Q5P0V:al09BXN024U6`807b4H00/0;c@V05ESAP1KJ4/0FfQ;
05MSB@1AFT@0BE4n04I<>P13BSL0@dXf0417=@0203m7=00;0419=P12BcP0ADlk04IA>`18DS/0AU0k
04A>>012C3D0@4`d03m<<`11Cc@00P10Cc<03011CC40@4`a03m:<00oBBh0?dL_0417<@0m@c00?48c
03Y2=00h@C80>48`03U4<@80=T8]00/0=T4/03I2:`0f@RT0=d4W03Lo9`0e?BL0=3/V038i9@0d>bL0
=3/X03<k:@02038l:@0;038l:00_>2H0;CHU02`e9@0Y<b80:C8P02L`7P0X<1h0:S0N02X]7@0Z;A/0
0P0Z;Q`01P0X;1/09BXG028V5P0U:AT09BXI02DZ6Q[ooooo7`000?l30?n000L0003oQ03oP00?oooo
o`003Oooool01P25Ui@0RYjM08fPX`2;WZ@0RIbS08VMXP80RYnQ00/0Rj2P08bPW`2>XJ40Sj:V08nS
Z02AYZX0TJRY096WYP2DZ:L0V:b[09N[[00209N[Z`0;09V[Z`2L[J/0W:bZ09j^[@2P/:l0X;6^0:2`
[02P/J/0XK>/09FUW`1dOgl00P1^MgL03023ShX0WJbQ09j/XP2S/:L0Y[BZ0:NeZP2Q[JH0U9nJ08N@
S@22S8H0SI^:06A/G`80Be1600/0ADQ00410>`0o?3X0?CXj03`j?00n?Sd0@dM104Y@A`1?F4d0D5YA
04mHD`0204iEEP0;05=GG01CEed0CU9K04eCG@1<EUd0C5QL04]HF016DU00?D=2034a=00d<S<00P10
@3/02`0W8bH081dR01/H7`0E4QT04a8F01DF600J7Q`082HO028Z800I8aT05A`A00805Qd?00`051X=
01<H300C60`051L;01DH3@0G6a0061`A01DI3`0@4`d05Q/D01hS6P0R9a`202<W700;02/a8`0nAS@0
EEm805aXD01RL5P0H71H05QUD@1=ED@0@DHf03Hj;00c=RP00P0e>2T02`0h>b`0?40`03m5<`13BcL0
AThj04A>?012CSd0?d/h03m==P0oCS<0?dh`0080@4h_00`0@Dd^041<;P11BBh0@TX_0457<@10AC<0
?D@d03a3=@0kA3L0=d8d03E0;`0e@bd203E2:`0;03E2:P0f@RP0>4<Y03U2:@0g?RP0=c`Z03@i:@0`
=bL0;cLV030h9`0^>BP00P0]>2H02`0^>RD0;cXS02hh8@0^=al0:c@M02/c700Z<A/0:S0L02/_7@0[
;1`0;BhM0080;BdM00H0:b/N02PY6`0W:A/09bXM02H[7@0T:1dJooooobd0003o?@3oP0000`000?l0
oh000?n000100?n000oooooo000=ooooo`0608JGV02;W:00S9jW08^MZ02:W:L0RifV0P2<WZH02`2>
X:@0SZ6S08nQY02@XZH0T:>W08nTY`2@YZL0SjJW09:VY`2FZZ`0UJ^^0080UZZ/00/0V:b[09^^Z`2K
[JX0WJb[09n^[P2P/:l0X[:`0::c[@2T]:d0XK6[09ZYY00209FRW@0<09NUW@2Q/JH0Xk6Y0:Nd[@2X
]Jl0ZKB_0:^e/02Y/Zh0ZK>]0:NaZ@2U/jD0UJBA0P26TWd02`1XKf40HFII05iPEP1DEDd0C4e70492
?00n@3L0?Slg0495?017C4<0C55;0080CeEB00/0DeUI05EJG01BFE`0D5MK04aEF01:EUL0BeUI04mL
F@1CGUT0DEMD04e@D@0204E7B@0;02DR;P0P7b`06QXV01DC7P0B4AX0418G00lC4`0?5A003aH?014I
400B6Q000P0G8100300L91806b8A01TM3`0H6`h05aX>01PK3`0E5@/04A4800h=1`0?3PX04a<?01HF
40805QLB00/07AlI02T/9@0g?C80B594059PC`1IJUH0H7=K05e^E@1;ET40=cXZ02PW6`0202HS6@0;
02TU700]:b40<S0V03Pj;00oAC<0@DXg045<>@0mBSD0?4Xa03e<;@10CR/00P10CB/03010BbX0?TPW
03i59`0oAB/0@4D`03e3<P0k@c<0>D0c03M0<`0f@380=D0`03A0:`80=44X00/0=40U03Q29P0i@BL0
>D0X03Tm:00h>RP0=c//03@j;@0b>B`0;cP/02`f:P0202Tc9P0;02Xe900/=b80;3PP02hi7P0/>1`0
;3LL02`f6`0[<a/0;C8L02d`7P0^;al00P0];Qh01P0];200:RXP02T[8P0X:b<092PP024T7A[ooooo
<0000?lk0?n00080003o@03oP00?ooooo`003Oooool01P23UiL0QYZN08ZNY@2<WZT0RibX08ZKY@80
Ri^S00/0S9fS08jOY02@XJH0SZ2U08nSY@2AY:H0TJFW092UY`2AYJH0Uj^[09V][P0209Z][@0;09V/
[@2I[Jd0VZb[09b][02N[Zd0Wjn^0:6a[`2P/Jd0X[>/0:Bd[02S/ZX00P2R/:P0302P[jL0Xk:Y0:Fb
Z`2W]:h0ZKF`0:bf/P2^^KD0[KNc0:fh/P2[]Zh0ZKJZ0:^iY`80Z;JQ00/0WjZG09ZUT`2CWH`0RI:3
07MoK`1NI5@0BTln03m2=00i>c00=cP`03Lh<P0203/m>P0;04I9B01>E5<0DUYJ059LF`1@FeX0C5QG
04YFE@1=F5P0E5iK05UPG@1JGeh00P1HG6002`18C5@0?45<02T]>P0N8Rd061/V01<G7P0@5AP02a8@
00T>2P0>50/0620A00807RLC00`08bdG02D^600S:QD082DC01dQ4@0J7Pd05QP8018A1@0A3PD04Pl9
01HC3@0I5Q4201LD4`0;01DB5@0F4aL071XK02HY9`0e?CH0AeA505EVCP16ESl0AUDk04EA=`0k@2d0
0P0m@3002`0g=Bd0;b/Y02hZ9P0a<2P0=SX^03To<P0lAC<0>dD`03]6;00jA2P0?4LW0080?4HX00`0
>T8W03Y09P0j@2L0>ClY03Po:`0g?Rd0=cl`03Ho<@0d?C00<c`]03Dm:`0g?RT203Q0:00;03Q19`0j
@RP0>d8Z03Y1:P0j@2/0>Ch[03Hk:P0e>b/0=3`/030h;00/=2L00P0[=2H02`0Z<RD0:S<S02/d8`0[
=R80;3LQ02dh8@0[=Al0:S@O02`d7`0[<Ah0:BdL0080:BdM00H0:2`N02L[7`0W:b00:2`Q02H[7`0S
9a/JooooocD0003oN03oP00?ooooo`003Oooool01P1nUIL0Q9^M08VOX`2:WZH0R9bU08VKX`80Ri^Q
00/0RibS08bMX`2=WjD0SZ2V092RY@2AXjD0TJBW09:VZP2AYZP0UJRY09JYZP0209V/[00;09V/[P2J
[:l0VJb^09b^[`2N[k80X;2d09n_/`2P[k40XK6`0:Bc/02T/Zl00P2U/jh20:Fc[`0:0:Jc[P2W]Jh0
ZKNa0:Zf/`2/^;@0[;Vd0:bi/`2[^K00Z[V[0:blZP80[KbZ00/0[K^Y0:fjZ@2^^ZT0Z[JW09^VV@2B
X8d0Ig1Q0414?00e>380;c</02/]9`0202XZ9@0;02d/:00l?CP0ATY404iED01BFUL0DeeJ055LFP1@
FeX0E5iL05MQG01HGeX00P1JH5d02`1KHF00F61P04YAE00nATX0<CTn01lU:`0E6al03Q@D00X?2`0>
50/06B4A00807bTD00`0:C@M02hi8@0[=A`08RXD01dQ3P0H6PT04A<400lA0`0@40D04Q4801XI3`0N
7A8201hL4`0;02HT6`0X9Qd08QlK02HU900a<bh0>Chf04I??`0`=RT0724G028Y6`0[=2<00P1:Ecd0
101PK500GVM@05ILB@17Bcd203m3=`050415=`0oACD0?48a03a2;00k@bP00P0kA2P0300i@BL0=chV
03Lo9P0e?2H0=3/U03@k9P0e?2T0=S`/03Dk;@0b>2T0<cTX03Hj:@80>3`/00/0=cd]03Hm;00g?b`0
=Sh]03Hn;00f?RX0=ChW03@m9`0d?2H0<3PT02dd8`0202`c8`0;02/a8P0[<R<0:S4T02Ta9@0Y<BH0
:C<V02Xd900[=280:S<P02Ta7P0Y;ad00P0X;a`01P0X;QT09R`H02L/6@0Y;Q`0:2`I02L[61[ooooo
=P000?mg0?n000oooooo000=ooooo`06082FU`25W9l0RZ2U08ZOZ028WJH0QibS0P2:Vj<02`2<W:H0
SIjW08bMYP2?X:P0TJ>Z096SZ@2AXj/0TjF[09:UZP2CY:X0U:B[0080UJJ/00/0UjR^09ZZ/02KZk80
WZfd0:2`]P2R/KL0XJne0:6^]02R[k@0Xk6d0:Jb/`020:Nd/`80Z;Bc00X0Z;Ba0:Vd/02Z][80[KRf
0:fj]`2]^KH0[;Vd0:bk/@2/^jd0[kf/0P2`_Zd02`2`_Jd0/;f^0;2m[P2b_K00[k^_0:^j[02BX9@0
HVaV04M?BP0j@3P0<CH]0080;BlT00/0:RXO02/Y8@0a;bX0>c/g03m1?`17C4T0D5UC05EPF@1JIUh0
FVEL05IOEP0205INEP0;05EME`1FGUT0EV5L05EPG@1>FeT0@e1=02`d=00C5aP04ADB01<H3`0J8A<0
0P0N9QD0300S;1L09c0K02Pa6`0U:aH07R8@01HG2P0@3`L03Pd800h?200@40/08bHL01lP608071`E
00/0EV5606elFP0d>2d0?D@k0458?P0b>340:RhY028S7P0H6A<04Q4=00h>2002020S6@0;06j0H@2;
XGd0Q9Qh06ekI`1EH5@0EEmD051HC01<DdD0Adho04=:=`0oB3000P0nB2d0300nB2`0?4DZ03]4:P0h
@2H0=ShV03Dk9P0e>RH0=c/Y03Hk:P0b=bP0<CHW038f:080<cHZ00/0<CLZ034h:`0b>Rd0<3T[02hg
:00_>BH0;c/T02lj8P0_>B40;CLN02`e7`0202`d800;02`c800Z<B00:C4Q02P`8`0W<2D0:38V02Td
900Y<b40:C@P02Td7P0X<ad00P0X<QX01P0Y<AP0:2lF02L]5P0W;1P09R/H02L[6A[ooooo=`000?l_
0?n000030000o`3oP000oh0000T0oh0010000?lg0?n000oooooo000=ooooo`0607jAU@27W9l0RinU
08VLYP26VjD0QibT0P29Vj802P2<WZ@0SInW08fNYP2?X:L0TJ6Y09>SZ`2BXj/0TZB[09:SZP2CXj/3
09FSZ`0;09BT[02FYJd0VJN^09^Y/02N[;<0X:nd0:6_/`2S[[80Xk2c0:B_/`2T/;<00P2U/K40302V
/K00Yk>`0:Zf/P2/]kH0ZkJd0:Zf]02/^;H0ZkNd0:bj/`2[^k40[Kb_0:jm[P80/;f^00/0/;f/0;:n
[02b_J`0/kf]0;>n[P2b_Zl0[kf^0:2^W`2:V8P0HVaQ0455?P0203]0=00:03Pk;P0h>Bd0=3@]03<a
;`0a;Rh0;bh^03Df<`11ACh0CUI:05END@<0FF=E00/0EV1C059LD@1GHeH0EV=G055OEP1AHEL0AeI<
02D]:@0M91d06AhG01PM4`0201LL400<01TN3`0J7`l07B0B020T5P0O8aD05QL>01<B3@0A40d03`h=
00l=3@0I6AL05aHD0P0N7ah02`1oTgL0Y/:N09B_T01OL5l0?DDk02/_9`0K71L05QHB01DD3`0C4@l0
4A0>00803P`<00/0Ae5109B]R029Wh00R9b10721K`1RLF<0HG1O06=aG@1RKed0GV]I05e[E@0205QV
CP0<051MA@1<ET00B54l04A;>011ASD0?D8a03Xn;P0h?2d0=cX[03<e:P0b=BX0<C@X0P0b=RT02`0`
=BP0;S<W02hd9`0/=2H0:C8T02Xd900Z=2<0:S<S02/e8`0/=b40;3HO00<0:C8L00@0:C4M02T`7P0W
<1l0:34Q0P0X<R80100X<Al0:34M02P`6P0W;aX202L^6@0602P^6@0V;1P092TF02@Z6@0T:Q`08RTK
6_ooooli0000ob`0oh0010000?l:0?n000@0003o=P3oP00?ooooo`003Oooool01P1fR8d0Q9RJ08NK
XP25V:80PYFR08BGXP80Q9RQ00X0RIbT08fNY`2>WjP0SIjW08jOY`2@XJT0Sj6Y096SZ@2AXjP0TjFZ
0`2GYj`02`2EYZd0UJN/09RX[@2HYjd0VZR]09^Z[@2N[J`0XJn/0:Ba[`2V/[80Y[6c0080Y[:a00`0
Y[>^0:Rc[P2Y/jl0ZkJd0:Rd/P2W/k<0ZKJe0:Vg/`2Y^;80Z[R`0:fk/02^_Jl20:nm[P0;0:nkZ`2`
_:/0/[j[0;:mZ`2c_J/0];n]0;>o[`2b_Zh0/Kj/0:FaW`22RG`00P1bN6`02`1aMf/0H6EK04M9A012
@Sh0=S<b030[:P0Z9R<09R@O034b:@0o@cH0C5920080E5]900/0Ef5>04YBA01<ETH0B5=2049??P10
CSh0AUE3049??@0Z=2D082HI01lT5@0201XM3`0<01LI300G60`06QX@01hO5P0N7aP061PB018B300A
4P/04Q4=018@3P0F5A<06aXJ0P0K6a`02`0k@C/0GFeM09:^SP1mUGP0>T@e02P/7`0N7Q@05aD=010=
200?2`T040/<00803P/=00/09BTU07bDN02>YhX0PiYo082EN`1SLEl0F6AC05UTD`1SKUh0OHih08>G
O@0208>FO00<086BMP1ePfP0I6eG065WEP1NI5T0FF1F051HCP16Cd<0@4Lk03a2>00i?CD0=c/c0P0e
>S002`0d>Bd0<SPZ038i:@0_>2T0;SHY02Xa9`0/<RP0:c8V02T`8`0Z<R00;3<M0080:S4J00P0;38J
02`b6`0[<Ad0:2lM02D]6`0T;1d08b/L02<[6`8092XI00T09BXI02H[6P0V:aX09RTJ02<W6@0Q9QP0
8BTK024X7@0P:1d06_ooooln0000obT0oh000P000?l:0?n000@0003o103oP0060000ob`0oh003ooo
ool000gooooo00H0O8n?08:EU@26VYd0QiZR08BFXP23UJ8208>EX@0;08RIX`2;VjH0S9fX08bMY`2;
WJH0S:2X08bPY`2=XJH0Sj:U096SY`2BYJP00P2CYZP02`2DYjL0UJNW09JXZ@2FYjX0VZV/09^ZZ`2M
[:/0X:n/0::_[02T/:d0Y[:^0080Yk>_00`0Z;B_0:Rd[P2W/Zh0Z;B`0:Nd/P2V/[80Yk>c0:Nd/@2Y
][40[KVc0:fi/@2^^k020;6n/00;0;2m/02a_Jh0/[j/0;>mZP2c_J/0/kf]0;Bo[`2d_jh0];n]0;Bn
Z`2`^JL00P2[/j802`2Y/Z00W:FE07b0MP1cN6`0?3Dg03H`;`0`:RX0:RHT02PU800];B@0<c@W0080
>ch^00/0?T@a038e9`0_=2H0:c4R02L_7`0Y<1l0<S/W03]5;@0`=R<0:RhN02DX6@0201hP5@0301TJ
4@0F5`l06Q/D0080824K00L061TE01<E4@0C5Pl04aH?018C3P0H6QH07R0M00809BTS00/09BTT02/a
:`1=FT/0FFQF04YFA@0R9Ad07AdE01TF4@0A3@`03PT<00d52`0200`73P0;03Dh=P1cQW<0PiZ507fE
O`23VGl0PIAi07B2J`1WLV00HFYJ07^;M023UGX00P26Ug`0302<WH00S9j006ehI01KHEL0HVQO06A]
I01YLfP0JGEU065[G@1IHeP0DEYB04eFD080BU=;00/0Ae1604A<@@11BC`0?D@h03Po=@0b=bl0;c8Z
02``9P0[;b<0:blN02X_6`0202`_6`0;02h`6P0^<A/0;C0L02DZ6@0N91@05Q`?018G2`0A5P/051T=
01HJ3`0N8Q@00`0U:AX01@0T9aX092HK028V700O91`07RDK01[ooooo@@000?lb0?n000H0003o0P3o
P0070000o`@0oh0000<0003o0?n0003oP000903oP00?ooooo`003Oooool01P1mTH`0QIRE08VLWP27
VZ40Q9NQ08BFX@80QIRR00/0QiVQ08ZKXP2;W:<0RibT08^NY02;X:H0S:6V08fQY02>XZ@0T:>V08nT
Y`0208nTY@0;096UY@2BYJD0UZRW09VXZ@2KZJX0WJZZ09jZZ`2PZjh0XZf_0:>][P2U/:h00P2V/Jh0
302X/jl0Z;B`0:Vd[`2Y/jl0ZKJb0:Ve/`2X]K40ZKF_0:^g/02]^;00[KN^0:jj[`80/;b_00/0/Kf`
0;>n/02c_Jl0];j^0;Bn[@2e_jd0]/6^0;G1[P2e`Jd0]KnZ0;FoZ`020;BmZP0;0;>mZP2d_jT0/KbV
0:VeWP1SHU`0>c@f040l>00m?3<0>ST^03Lg:P0g>2P00P0b<b<02`0/;1d0:RPL02DT6@0P8AD082<D
02<U5@0[;a`0=CTU03Dh9P0/;b809RPN00807b0J00`06a`H01XK5`0N81`08R@Q020R7P0K7QX05aXF
01LI500H6a<051H>014C3@0I6QD202DY7P0;02dc9P0f?Rl0A4dk04QC?P12C3P09RXO020R6P0M7AT0
61DE01DA500C3A<00P0A3A<02`0Q7b<0CUI?05i]H01`Pfh0NHac08VLOP2;WH00QiQn08:CN@20TGL0
PYEi0080QIMk00`0Q9Ak08ZKPP2;VhD0IW1V05aUG@1DFU@0HV]N08^MP`1fPg40EEiG05EOF@1KIUl2
05eZH@0;06AbIP1YN6L0IgES06AaGP1LIUD0D5M904E8?P0l?S@0>3/_03Dh:00a<b800P0a<R002`0b
<Qh0<34O02`^800U:A`06A`@00lB20082`<010L000H80P05208030l600805AT=00H06b0B020S5@0Q
91L08RDJ024U6P0O91PJoooood40003o=03oP00=0000o`@0oh000P000?l60?n00080003o7@3oP00?
ooooo`003Oooool01P1mTH`0QIRE08VLWP27VZ40Q9NQ08BFX@80QIRR00/0QiVQ08ZKXP2;W:<0RibT
08^NY02;X:H0S:6V08fQY02>XZ@0T:>V08nTY`0208nTY@0;096UY@2BYJD0UZRW09VXZ@2KZJX0WJZZ
09jZZ`2PZjh0XZf_0:>][P2U/:h00P2V/Jh0302X/jl0Z;B`0:Vd[`2Y/jl0ZKJb0:Ve/`2X]K40ZKF_
0:^g/02]^;00[KN^0:jj[`80/;b_00/0/Kf`0;>n/02c_Jl0];j^0;Bn[@2e_jd0]/6^0;G1[P2e`Jd0
]KnZ0;FoZ`020;BmZP0;0;>mZP2d_jT0/KbV0:VeWP1SHU`0>c@f040l>00m?3<0>ST^03Lg:P0g>2P0
0P0b<b<02`0/;1d0:RPL02DT6@0P8AD082<D02<U5@0[;a`0=CTU03Dh9P0/;b809RPN00807b0J00`0
6a`H01XK5`0N81`08R@Q020R7P0K7QX05aXF01LI500H6a<051H>014C3@0I6QD202DY7P0;02dc9P0f
?Rl0A4dk04QC?P12C3P09RXO020R6P0M7AT061DE01DA500C3A<00P0A3A<02`0Q7b<0CUI?05i]H01`
Pfh0NHac08VLOP2;WH00QiQn08:CN@20TGL0PYEi0080QIMk00`0Q9Ak08ZKPP2;VhD0IW1V05aUG@1D
FU@0HV]N08^MP`1fPg40EEiG05EOF@1KIUl205eZH@0;06AbIP1YN6L0IgES06AaGP1LIUD0D5M904E8
?P0l?S@0>3/_03Dh:00a<b800P0a<R002`0b<Qh0<34O02`^800U:A`06A`@00lB20082`<010L000H8
0P05208030l600805AT=00H06b0B020S5@0Q91L08RDJ024U6P0O91PJoooood40003o=03oP00=0000
o`@0oh000P000?l60?n00080003o7@3oP00?ooooo`003Oooool01P1eR8H0OiBC08FJWP26Vj80QYVT
08JIYP80QiZW00/0Qi^V08VLYP2;WZD0RYfT08^NY@2:WZD0RinV08fQY@2@XjD0TJFX096VZP02092U
Z00;09:XZ@2DYjL0UZNV09VYZ02LZjX0Wjb/0:6][P2T[k00YZn`0:F^[`2U[k000P2W/[020:Vc/00:
0:Zc/@2Z];<0ZkNd0:bh]02[]k80[KZb0:fi/P2]^K40[[R`0;2k/@80/[fc00/0/[fb0;>n/@2c_[00
];j^0;BnZ`2f_j/0^<6]0;O0[@2f`:h0]L2_0;S2/@020;W2/00;0;W1[P2i`Z`0^L>[0;c9[02NYi00
FeQB04Y7@P1iPF/0Jg5M05AIB01BEd@00P13ACD02`0g=RP0<C4S02d]7`0Z:ad0:2TI02PZ600/;Qd0
>3TY03Xj;@0b<bT0:RXS00808b@N00<07AhI01`M600R92000P0V:B@01`0U:2808BDP01`O700J7AP0
4Q@?00l@300@4@`00P0E5`l02`0L81D0:c4Q03Y2;@0kA2h0=ShY02/a800T9aX07b0H01`L600K6QX0
6QXJ00807AlM00/07B0N02DY9@0f?C@0@d/o04Q>@P1nS7<0UjV<08nQQ`2BY8P0T:6508jPQ00208fO
Q@0<08ZKQ028VH@0R9^6086CP01eQ7<0KWYY06UeI028VX00SjF906]jJP1QKf40FfQK0P1EGeD02`1R
Kf80MHMd07V<MP1lSgL0Nhif07>3K@1/NfH0JGEQ06A]FP1HH4h0DeY90080CUA200/0AT`i03a1<P0f
?300:2hU01`R600A5@d02Pd600H80@041P000@<00001000200<50@0600L:0`0=3`D061X=024T500R
9aH08bXI6_oooom20000o`80oh000P000?la0?n00180003o1@3oP0070000oaP0oh003oooool000go
oooo00H0LhN507fBT`24V9l0QYZT08JIYP26VJL208JHY`0;08JIY`28W:P0RIfW08ZOYP2=X:L0SInX
08nRZP2@Y:X0SZ:W092UZ02DYj/00P2DYjd0102CYj`0UZV_09NZ[P2JZZh209^Z[@0309j][`2P[k00
XZna0080Xjna0P2V/k<0302W]K80Z;Fb0:Vd]@2Z];H0ZkJh0:bg]`2^^KL0[kZe0:ji]@2`^KD0/;Rd
0;2k]P80/Kff00/0/[fe0;6m/P2b_[80]L2`0;K0[`2g_jh0^/6_0;_1/@2j`;<0^/:f0;W1]@020;_1
]00;0;c4]02ka;00^/B/0;c7Z`2iaZP0W:B=07EdJP2OYY80ZK6L09fWTP2EX8T00P1gOVX02`19BCd0
A4Hf04=7=013Ac40?d<[03a0:00h>bP0>c/]03dl<00i>2d0;BdU00809bLO00`08B4J01hN5`0P81X0
92@M02PZ8`0/;bL0;30Y02<U900M7Qd04Q<B00l@3P0=40d200lB3@0;01<G4@0M8aT092/M02L]7@0Y
<1d09BXH020R500L71H06APG01/J6`0K6Qd00P0`=C@02`14CDL0@di604iLD01@Fdh0C5=704e@B@2C
XhX0RYV408BCP020T7/0P8mj0080RIb400T0RIb508ZMQ`2;WhT0Qib508FIP@1mT7L0MhYb07V;LP1l
T7D00P1kSgH01`1gRW<0LhI`07>6L01cQG00LhEa07B6L`1gR7H00P1hRGH01@1hRGD0NX]d07b;L`1i
QW<0M81`0080LGi^00X0KWa/06MdIP1LJU`0=Slh01`P7@0G6aH02@X600@50@020`000@800`000@00
1P000P000P@000`>0`0J7@`08RLC02DZ5a[oooooBP000?l^0?n002@0003o4@3oP00?ooooo`003Ooo
ool01P1bQ8D0OI2E08:EX023UZ@0PYJS08>FX`80Q9NS00/0Q9NR08FJX`28WZD0RYnU08ZNY@29WJH0
RYnX08bRZ02:WjH0RYnU08jSY`0209:UZ`0609BW[`2DYk40UZNa09NX/02IZ:h0VZV_0P2KZZl00`2L
Z[00WZba0:2//@020:>_/@0<0:Bb/`2W/kD0Yk:e0:Ja]02X/[H0ZK:h0:^d^02/][H0ZkBd0:bc/`2^
]K<0[kVe0P2_^KL02`2a_;H0/Kbe0;:m]02c_K80/kf`0;Bm/02f_[00^;jb0;[0]P2i`[P0^<6g0080
]l2d00/0]/6c0;O3/02g`Z`0]l6Y0;K1Z@2f`:X0/kRV0;:hYP2f_J/0][j[0;G0Z@020:jiX@0;07Qj
L01]Kf@0O8=_086:L@1bNF<0Ff5?059GA`18Bcd0A4@i03dj<@0b<2L00P0];2<0300W9Qh08B0J020P
600S91/09RHO02PZ8P0Y:b@08R@P01dM700H5aP051<E014D4`804QLC00/05adG01/Q6P0Q:Ad09bhP
02Ta800U:aX07b8D01/L5@0K6AL061DG01`J7`0203Lm?P0;07F8M`1]PW00HGAT06AfHP1JIe@0BTm6
09R[T02>XX/0LH=c06AcI@1AFe800P1aPFd03022UGd0Q9R008VNQP28WHL0RZ6805m_H018DdT0QIYl
07:3JP1_OV/0Nhei07fAO080NY1k00/0NY1j07N;M@1fRGD0MHAd07B2M@1bP7D0LX5e07>3L`1dPg40
M89a07F2L00207B1KP0707B1K`1dPVl0N8Yc04mKD00B4QL02`/<00410@03000000<0004000H00P@0
00T;0P0B50H05aX:01lT4@0S:1@Jooooodl0003o8`3oP0040000o`80oh0010000?l00`3oP000003o
0000o`050000o`80oh005`000?l@0?n000oooooo000=ooooo`0607V9SP1nTIT0P9>P07nCX020U:40
PIBP0`23Uj001@24V:40QYZS08VMYP28WJL0RIfV00<0RYjV00l0RijV08fPYP2AXj/0TJ>[09:T[@2C
Y:l0UJ>`09JT[`2HYk00VZVa09^Y/@2LZK40W:Vb09j//`2R[K<00P2S[[80302S[K80Yk2e0:Va]@2X
/;D0ZK:f0:^d^@2/];P0[;Fg0:fe]@2]]K<0[[Fb0;2h]080/KZe00/0/[Ze0;:k]02b_;80/[b`0;6l
[P2b_:h0/kf^0;>l[`2e_[80]Knc0;C1/`020;C1/P0;0;?0/@2e`Zl0]/:^0;S2[P2h`Z`0^L6[0;_1
Z`2k`Z/0^L2Z0;[1ZP2l`jT00P2k`jP02`2d^j80[[>M0:fcW02`^Il0ZkBI09bSRP2=Tg/0JFYJ05aJ
CP1;B3d0?C/_0080=CDY00`0;C0T02HZ800W9ah0:BXO02X[8@0U:1d0828K01dM6@0J6QL061LG01DE
5P0F61L201/O6`0;02@Y800W;B40:C0S02/a9@0/<RH0:c4R02H[7@0U:1h08R<M01dL6@0H61P00P0`
=S402`1kTWH0R:B0059RC@1=FTH0?dPi03Tn=01TLEh0GfeM06YoJ@1YOFL0FVYF0080JW]T00`0NXed
07jBNP22UWl0Q9R208VOQP1QKf40@4E109ZaS`1AFDh0@TQ608nTS@1oU80206IhJ`0;0765M01jSW/0
KG]]06ahK@1aO7@0LWeh0760N@1bPGH0LX9c07>1L@1dPVl00P1`OVT02`1^NVD0JWMQ065]FP0oACd0
518E00T520050`@00`4200810P010040004000800@<000H01@L201HH3@0P8a@08RLG02<Z6@0T;1PJ
oooooe80003o803oP0020000o`H0oh000P000?l00`3oP000003o0000o`050000o`80oh0000<0003o
0?n0003oP0004`000?lA0?n000oooooo000=ooooo`0607Z9S`1oTYX0PIFP08:GX@21UJ40PYJQ0P23
Uj802`24Uj<0Q9NT08JHY@29VZL0RI^X08ZLZ02<WZP0SJ2X08bOY`2=X:L0SZ6X0080T:6[00/0TjF]
09BT[@2DXZl0UjFa09VV/`2JZ;@0W:Vc09fZ/`2NZkD0X:ff0:6]]P020::_]00<0:B`/P2V/;40Yk2a
0:N`/`2Z/kD0ZkBf0:ff]`2^]kL0[[Ne0:jg/`2^^;40/KZb0P2b_;401@2b^k<0/[^b0;:l/P2b_:l0
/Kb^0080/kj^00@0];f_0;Fo[`2d_jh0]L2_0P2g`[802`2h`k<0^<:a0;W3/`2i`[80^<:^0;S2[02j
`Z/0_<B[0;g5Z`2naZX0_LBX0080_LBV00/0_/JV0;c4YP2k`jH0^lBT0;[3XP2jaJ40];jJ0::YRP2C
VGh0LGAO04U8=`0204A7<P0<03a2;`0e>RX0<c@W034a900_;R80:RXO02@T6`0O81T071hG01XL5P0I
6aH071hI0P0Q91h02`0]<BL0;c<W030e:00a=2T0<3<X030d:00^<BD0;30U02/^900N7aL06AXB0080
5QP@00/092TM03Y5<P0a>2T0;S8U02P/8P0W:b809b`T020U7P1>GDT0JgmQ069cF00207>6JP0<0763
JP1`PF/0KGi[0765M01gS7/0LhMe06j0K@28WX<0GVYO0499BP2:X8/0TZ^B0P1iS7X02`1lSg/0Oi5m
03do@013ADP0MH5h06miM@1OJ6H0J7I^06imKP1^OF`0KGeX0080K7aU00/0Jg]T06MfG`1AG4X0=Shc
01TK6@0=30d02`P:00P51`0610@00`8200810@0200P:1P0601@G400O8aP09b`L02T_800X;b00:C0P
6_oooomD0000obL0oh0030000?l20?n000H0003o0P3oP0020000o`030?n000000?l0003o00H0003o
4@3oP00?ooooo`003Oooool01P1dQXX0OI6E086EV`23Uih0PYJN08>FX080Q9JQ00/0PiFS08FFX`26
Uj<0QiNR08ZIYP2;VjL0S9bW08fOZ02>XJL0SZ2W08nOZ002092PZ`0;096Q[@2EXjd0UZB_09NU/@2I
YK80VZNc09^Y/P2JZ;40W:Zc09f[]02MZk<00P2O[;001P2R[k40Y:n`0:N`[P2Y/[40Zk>d0:Zc]@80
ZkFe00@0[;Jd0:bg/`2^^K40[kZ`0P2_^jl02`2a_;40/K^a0;6k/P2a^k40/[ba0;Fm/P2h`;80^<2c
0;S0/P2h`K00^<:_0080^L:_00/0^/>a0;[2/`2i`[<0^/>d0;_3/`2i`jl0^<6[0;_4Z`2maZX0_/JX
0;k6YP020;o7Y@0;0;g4Y02ma:D0_LBU0;k6Y02naJ80^lJQ0;[5WP2g`Y/0]L6J0:RdS@1_LEL00P1N
H4P0301KGDH0EeY5059D@@16ACL0?S`a03<a:00Y:B0092HL028T6P0O8AT07QlG020R6@8092LM00/0
;c8V03Dg:P0h>Rd0>3X]03Hg;00b<bT0;BhU02TZ8P0Z;2<0:2/R020R6`0201`N5`0;01DG4P0E5Q40
6Q/D01TI4`0H6A@06ahH020S700L7aX092TP04MD?P1@GTH00P1cR6H0301YO5h0F6M?03a5>013CD@0
CU]D06EhJP1[P6h0KhA_06YnK@1RMFP0LXQf08BMP`80Qin400/0QIZ1071mK@0^:c<0:bTd06inL`1b
PWH0?45505EPFP1dQg80FVMI03Y0>@0204aFAP0;06EeG@1QL5X0BUI5030i;`0L81d04Q<B00T92P06
1@H01@@400@30@020P000P0G71801P0[=280;3DS02de8`0[<B409b`P02DY7Q[oooooE@000?lX0?n0
00<0003o103oP00;0000o`80oh000P000?l20?n000030000o`3oP000oh000080oh0000<0003o0?n0
003oP000403oP00?ooooo`003Oooool01P1_P8P0NHbC082DW023UYh0PiFN08BEW`80Q9FP00/0QINQ
08FHX024Uil0QiVP08ZJX`2;VZH0S9ZW08jMZP2>WZT0T9jY09>QZ`0309FR[@0:09JS[@2HY:h0V:J`
09RU/@2IYk80VZRb09ZW/@2KZK80VjVa09^Z/@80Wjja00`0XZnb0:B_/02V/Jl0Z;:`0:Zc/`2[/kD0
ZkBf0:^d^02/][L0[;Jf0:ji]@2_^[@20:nj/@0;0;6k/@2c^k80/k^b0;Fl]02g_[D0^;jd0;Vo]02j
_kD0^;fc0;Ro/`2h`:l00P2h`:h02`2k`K40_<:c0;_1/`2l`[@0_/Fb0;g6[`2ka:d0_<N/0;c8ZP2k
aZH0_LJS0080`<RT00/0_/FS0;k6YP2naJH0_/BU0;o6Y02maZ80^lFP0;c7X@2kaZ00_<NP0:nhU002
09jSQ@0<09^QP`2RZXT0Uj2007AgH@15@CX0?cde03<c:P0/;b<0:BhP02T]800Z:al0:b/P0P0[;2<0
2`0b<bX0?d8c04=7>00n@cL0=cXb034f;@0/;bT0:2XV02@V8P0T:2408bLN008082<J00/06alE01`O
5P0L7AH05QD@01XK4P0P8QL08bHL024S7@0K7AT06QlH02<X7`02034j:`0<03M1;`0h@Bl0<3HX02X_
8P0W:b40=3d`04EB@@1RMUd0EFE@049>@@1CHe<0JgiY0P1bQg402`1dRGH0MXMh055JE`0oB4T0GFiS
07bCO01FIEL0Hg=Q0763K@1?FDd071XM0080:BXX00/0GfaI05APD00i@ST0:S8/01lT800H6aL03a8?
00P:200520@01@P200H90P0201PO4@0603m?<`14E3T0>4@_02df9P0X;b8092PN6_oooomK0000ob/0
oh0000@0003o0?n0003oP000oh001@000?l20?n00080003o00<0oh000000o`000?l05`3oP00?oooo
o`003Oooool01P1eQh`0Oi:H08>GW`24Uj00PiBP08:DX@80PYBR00/0Q9NS08FJX`25VJ00R9^R08^M
Y@2=WJP0SYbX08jNZ`2?X:d0TZ6^09BR[P0209FR[@0;09BS[02FY:`0V:F]09VW[`2JZ;<0VjRd09^X
/`2LZK<0WZbe09j]]02LZk000P2N[Jl0302Q/;00Xk:_0:Jd/02W/Jh0Z[>_0:^c/P2/];D0[KFh0:fg
^02^^KP0[[Rh0:ni]P80[k^e00/0/Kbe0;6j/`2b^[<0];bf0;No^@2h_KL0^Kng0;Zo^02j_kD0^L2c
0;S0/P020;W1/00;0;g4/P2ma;<0_L>c0;k3/P2oaK00_/N^0;o6[P2najh0_<JZ0;_6Z02najH00P2o
bZH02`2laZD0_<JV0;g5YP2maJD0_lRW0;o8YP2maj80_lVT0<3:Y02obJ<0_/RR0080_/NR00`0^lFQ
0;c5Y02jaJ<0Z[BD075bHP1BD4H0DeE904]?@@15BST0A4Tg04=6=P13ACH203m2=@0;03e1=@14BCX0
BDlo0457>P0h?3@0=c/e030d<00/;b`0:B`[02X^:@0Y;BH00P0W:b<02`0T:20092PN028T700I6A<0
6a`E024S6P0T9ad08B@L01dO6P0H6aH05aTE00808BHM00`09b/Q02HY7`0S9Ad0828I01lR5`0Q9QT0
8bPL04QF?P1@Gd@0>44^02ld9`0g?S420418?00;04MAB01LJUl0LhMf05i^H`1DI5T0Gg5P06MiI01/
OVT0KGe/05m/H@11AdD00P19Cd/02`1MIU/0CE==065_GP0K7al06b0M014F400<40X01`X500D81009
2`H03A0:00803a<;00H0:3<R03]:=00hAC<0=T4c02lh;@0T;28Joooooe`0003o<`3oP0000`000?l0
oh000?n000040000oaL0oh003oooool000gooooo00H0NXj>08>GV@26VIl0QYRR08BCXP25U:H208FE
Z00;08FGZ025VJL0QYZT08FIXP29Vj@0RibW08^MZ02<WjX0SJ2[08jOZP2@XJd00P2BXZ`01`2@XZT0
TjF[09JV[@2IYZh0VJN`09^X/P2MZK400P2MZ[40102O[;80Wjb`09n^[`2O[Zl20::`/P0:0:>b/@2T
/:l0Yk:_0:Zd/P2]]K@0[KFf0:fg]P2/]k@0[;Jd0:fg]080[kVf00/0[kZf0:ji]02_^KD0/[^f0;Fm
^02d^kL0]Kfh0;Vo^@2j`KL0^;ne0;Ro]0020;W0/`0;0;W1/P2k`k@0_L>e0;_2/`2k`k00_LJ`0;k6
/02maZh0_<F/0;_4Z@2laZT00P2majT02`2laZT0_<BY0;c5Z02maJL0_/JX0;o8Y`2obJH0`L^V0;o:
Y@2nb:@0_LNS0080_LNT00`0_LJU0;g6YP2maJD0^lJU0;2kV`2EVX80Uin608fEO01gOFL0KgAN06IY
EP1PHU02055DAP0;04Y>@@15B3`0@dDh03m1=@0k?3@0>CTe03Pi=@0g>SD0>3Xg03@g=00_<Rh00P0_
<bd02`0]<R/0:c0Y02DY8P0K7AP06AXE01dP600Q91X08B<J01`N5P0G6A807AlH0080:blV00`0;C8W
02T]8P0Q8Q`07QlH01/L5@0I7Q@06alD01`P4`0X;Qd0;38O02`b800V:Q/2020R600;01dO6@0Q9200
AE1304aHB`0d?3P0=Shh04MCA`1GIeP0HWET06MjJP1UMFL00P1XMfT02`1RKV@0<SHh04QDBP0T:bD0
7bDO00dA3@0<40T02P`500X:100?3`/03a0=00803@d<00H03Pl?014D4P0D61D0:30V034i;P0W;RHJ
ooooof40003o=03oP0050000oa<0oh003oooool000gooooo00H0OY2C08BFW026Uj80QYJU08JCYP26
TjT208JEZ`0;08FFZP26VZP0QibT08RLXP29WJ<0RYfU08ZNYP2<X:P0SZ6Z08jOZP2@X:d00P2AXZd0
2`2AXj/0TjF/09JV[@2HYJd0V:F^09RT[P2HYJh0W:V`09jZ/02OZk00WjZ_0080Wj^_00`0XZnb0:>`
/P2S/;<0Xjja0:F_/02X/K80Z[:d0:Zc/`2/][@0[;Je0:^e]@2[]K@20:jh]P80[[Vg00T0[kVg0;6j
^02b^kT0/kZh0;Bl^02h_KP0^/2i0;Vn]`2i_KL00P2i_[L20;W0]`090;S0]P2h`K@0^L:a0;[4/02k
a;00_<N`0;_6[P2laZh0_/J^00<0_/B^00X0_lJ_0<37[`31aZh0_/>/0;o4Z`2oaZT0`<VX0;o9YP2o
b:L0_/NX0P2najT0302laJP0_/JX0;o7Z@2naZP0_<FX0;S0Y02g`:@0]KjR0:ffVP2JXXH0R8me07Ik
I080Fee=00/0F5Y:051AA@1;Bd40ADDl0451>@0n?3H0C51305QQD01AFT/0C5A603Tm<P02030b:P0;
02/]9P0X:R@09bTT024S7P0L7AP07b4I02<V6`0Q9Q/07R0H01XK5P0T9Ql00P0Z;RH0300/;bH0:R`R
02DW7`0R8a`0828J01hQ600K7A<051@;01<C2@0H6@d07b0B01hN4P805aL>00/04a@=014A300S9Qd0
EVI?02lg;P0T:RD08BLW02<[:@0f@CX0DV9A05e^F@0205MTE00;05MUEP13D4D0?Ta003m=?00N91`0
3A4<014E3`0B4``04Q8=01<A3`0@3@d00P0<20/01P0:1`X02@H900X62P0>3A005ADF020S81[ooooo
H`000?ld0?n000030000o`3oP000oh0001<0oh003oooool000gooooo00H0P92D08FDW@25UJ@0QIJX
08FEZP24U:/2086BZ@0608:DZ024V:L0QibW08NKY@29WJL0RijY0P2=X:/00`2@XJ/0TJ2[09>Q[@02
09BR[`0;09BT/@2EY:l0UjJ^09RV[02IYJ`0VJJ]09NT[02JYjh0W:V_09jZ/02P[;400P2O[;40302P
[K40XJj`0::_/@2T[k80YJja0:N`/`2X/[<0ZK>c0:bf]02]]kH0[[Rj0:jg^@80[KNh00X0[KNg0:ni
^02b^k/0/kZj0;Bj^`2f^k`0]kbl0;Vm_@2k_[h0^[jl0`2j_k/02P2i_kT0^/6k0;[3^P2j`kL0^/>d
0;[4/`2ka;<0_LFc0;g6/`2na[@30;o6]@040;k5]02maK80_lFb0<37/@80`/J`00D0`<F]0<;8[@30
aZT0`LR[0<79[@020<79[P0<0<38[P2oaj`0_/JZ0;o7ZP2naZ/0_/F[0;c4Z@2ka:P0^LBW0;G1X`2^
^Yd0Y;2C0P29T7L02`1mPf/0L79P05mMD`1BCdX0CTe704M8?`1;Cd80G6UC06IgF`1SLeH0>Sl^0080
;BlT00/0:2PP028R7@0P8Ah08R8P02<S8P0V:2@09RTT02<Y900N8b407B4P03M0=`0203e7?00<034g
;`0/<BL0:B/R02PZ800Z;B<09RTP01`M5P0C4``0410601HG2P0M7@h06a/<0P0B4@T02`0=30L02PT5
00l?2`0g@340:c<Y024W8P0K8Al05ahL01@I600N9Qh0:C<S00809B`L00/09bhN030i:00oBSP0Ae@m
01`O5P0E5a008BDK01TK5@0O8AX07AdI01@B4`0200l;400600d83`0=1Pd03@H<00`53P0<1Q00518G
6_oooomW0000o`H0oh000P000?ln0?n000oooooo000=ooooo`0407b>U023UIh0QINU08>EZ080PY>Z
0P23UJT02`23UZP0Q9VX08JJZ027VjT0RI^Y08bM[02?X:d0Sij/096O[02BX:`0UJ6_0080UZ:a00/0
UJ:a09JT/@2FYJl0UjJ]09VW[@2KZZl0VjR^09bX[`2KZ:l0WZ^a09n//@0309n//P0;0:2]]02R[kH0
Y:ne0:B_]02X/KD0Z;>f0:Rd]02Z][D0[;Jf0:jg^02_^;/00P2^^;X02`2_^KP0[kZg0;:j^@2e^kX0
][^j0;Nk^`2i_;h0^ko10;c0`P2k`<00^kno0080^[nn00P0^Kjk0;[0^`2i`;X0^l>h0;o8^02la;@0
_<>b0;g3/`80_LBd00h0_LBe0<36]`30a[L0_lNg0;k8]`2nakH0_/Jd0<36/`33b;<0`/J`0<?7[P31
aj/0`LR]0<;8[`80`/V`00`0`/Va0<37[P2oaj`0`<R[0<38[030ajh0_lJ]0;g5Z`2maZ`0_<J[0;[5
Z@2iaJL20;BoX`0;0:ffV`2V[iD0Ri1m06a]H`1HEe40EEE=04U:@P12AC/0BDho04E<?00e>Rh00P0^
=2T02`0X;2<092HP01lQ7P0P8R009bXW02/_:P0[<2/0:Rl[02HY:00T9bP0>d@m0080@di400`0=Chf
03<k<P0`=bd0;cD[02hd:P0U:28071dJ018A400@40X05AH=01/M400L7Q0201LI3P0;010@2P0=30L0
30/7014@300F6A<05QXF01@H5P0A5A<04AHB01LN5P0I81D00P0G7Q002`0G7@h05QX=01XL4@0R9AP0
71lE01dR5`0Q9Q`06ahF02hd9`0a=RP0:blS00809BLN00H09R@O02HS7P0O6AT06A<F01@?5@0A3ADJ
ooooofT0003oA03oP00?ooooo`003Oooool01P1jSI<0PIFM08>FY025V:P0PiBX08:CZ080Q9FY00/0
QINZ08BFZ`25V:`0R9Z^08ZK[`2<WJl0Sj2^096Q[P2BWjd0Tin^09BP[`0209FQ/@0;09FR/02FY;00
UjF`09RU[`2IYjl0VjV`09^Y[`2NZk00WZZ`0:2[/P2Q[K<00P2S[kH0302R[KH0XZfi0:>^^`2S[[X0
Xjjg0:Ba^02U/[P0Y[Bh0:Rf^02Z]KP0[;Fi0:be^P80[KFk00/0[kNm0:ng^`2a^K`0];Zm0;Fi_02e
^[d0][c00;Rn`02i_[l0^Kno0;W0_`020;S0_@0;0;Ro^`2l`[/0^l2h0;c2]`2oa[L0_LFe0;g4]02n
aK80_<Ba0;g5/P2m`k@00P2na;D02`2oakL0_lNh0;o7]`2na[<0`<Ja0<?7/033ajd0`lJ[0<?7Z`33
ajd0`/N_0080a<Rb00`0`lRb0<?8/@32b:h0`LJ[0<?8[033b:d0`/N^0;o5[`2ma:d0_LF]0;g5Z`2l
aJX20;[3Z@0;0;[3Z02i`jH0]L2S0:B^U@1oPgD0MGUZ065SE`1BDd/0CTm504A6?00k?SD00P0c=Rl0
2`0[;BT0:BTW02<U900U9bH0:bl[02hd;@0_=B`0;C8Z02h`:@0^;RX0;c0]0080;c8_00`0;S<]02hc
:`0_=B/0<CT]02hf;00X;RL08bHS01hO7@0K7AP07R4J01lT6P0K8AD201HK4@0;010C3@0>4@T03A08
014B2`0E614061`F01DI5@0?4a003a<>01<H400E6Q000P0C60`02`0C5P/04Q@;010B2@0B50`051P@
01PL5@0G6aD061/F01hS6@0/<b80<3LP0080:2dF00H0:b`G038`7`0`;B40:RHO02`/9P0X:R@Joooo
of/0003o@P3oP00?ooooo`003Oooool01P1jSI<0PIFM08>FY025V:P0PiBX08:CZ080Q9FY00/0QINZ
08BFZ`25V:`0R9Z^08ZK[`2<WJl0Sj2^096Q[P2BWjd0Tin^09BP[`0209FQ/@0;09FR/02FY;00UjF`
09RU[`2IYjl0VjV`09^Y[`2NZk00WZZ`0:2[/P2Q[K<00P2S[kH0302R[KH0XZfi0:>^^`2S[[X0Xjjg
0:Ba^02U/[P0Y[Bh0:Rf^02Z]KP0[;Fi0:be^P80[KFk00/0[kNm0:ng^`2a^K`0];Zm0;Fi_02e^[d0
][c00;Rn`02i_[l0^Kno0;W0_`020;S0_@0;0;Ro^`2l`[/0^l2h0;c2]`2oa[L0_LFe0;g4]02naK80
_<Ba0;g5/P2m`k@00P2na;D02`2oakL0_lNh0;o7]`2na[<0`<Ja0<?7/033ajd0`lJ[0<?7Z`33ajd0
`/N_0080a<Rb00`0`lRb0<?8/@32b:h0`LJ[0<?8[033b:d0`/N^0;o5[`2ma:d0_LF]0;g5Z`2laJX2
0;[3Z@0;0;[3Z02i`jH0]L2S0:B^U@1oPgD0MGUZ065SE`1BDd/0CTm504A6?00k?SD00P0c=Rl02`0[
;BT0:BTW02<U900U9bH0:bl[02hd;@0_=B`0;C8Z02h`:@0^;RX0;c0]0080;c8_00`0;S<]02hc:`0_
=B/0<CT]02hf;00X;RL08bHS01hO7@0K7AP07R4J01lT6P0K8AD201HK4@0;010C3@0>4@T03A08014B
2`0E614061`F01DI5@0?4a003a<>01<H400E6Q000P0C60`02`0C5P/04Q@;010B2@0B50`051P@01PL
5@0G6aD061/F01hS6@0/<b80<3LP0080:2dF00H0:b`G038`7`0`;B40:RHO02`/9P0X:R@Jooooof/0
003o@P3oP00?ooooo`003Oooool01P1lSY00PI>H08:EW`24UJ@0PY>T08FEYP80QiJX00/0QiNZ08FE
Z`24UJ`0QIN]08RI[`29W:h0SJ2]08nQ[@2?Wjd0T9n]096P/00209:P/00;09:P[`2EXk80VJFc09ZV
]@2LYkH0VZNf09ZX]02MZ[80Wj^a0:6[/P2Q[;<00P2Q[K@0302R[;D0XJ^f0::/^P2S[;/0Xjjk0:B`
_02U/K`0YK6k0:Nb_02Z];d0ZkBl0:bd_@80[[Fn00/0[[Fo0:ng_`2a^;l0/k^o0;Bl_P2e_L00][g1
0;Jn_`2e_Kd0];fl0;K0_@020;Jo_@0;0;Jn_02i`Kd0^;ni0;Vn]`2l`[H0_<>f0;g5]`2oaKL0_L>d
0;k4]@2l`[D00P2l`kD02`2oa[P0`<Ji0<36^@31akL0`lVc0<?8/033b:l0a<V]0<C8[033aj/0`lN^
0080a<Ra00D0a<Rb0<?6/P34ak00`/J^0<?7[`020<?7/0050<;6/@32a[80`<Fa0;o6[`2oaJ`00P2n
`jT02`2maJP0_LJV0;[5YP2g`ZD0/;^P0:ZdV`2JXhd0P8Ie071dI@1GFE00DEA:0080?Shi00/0=cHc
038`<@0/:b`0:BPY02TZ:P0/;R`0;C0]02d`:`0^<2T0<C<Z02//900202LX8@8092HO00X09b/R02/`
9P0Y;RD0:2dU02L/9@0U:B<092TR02hg:@0V;b<072@I0P0E6A802`0@4Ph030l:00/>2@0@4`h05ATC
01PM5`0G71D04aPA018G3`0F71405A/@00804aL<00/03a<:00hA2P0=4PX030l700/?1`0@4P/03a0;
01HI4@0K7Q@082DF02L[600201hN3@060414:P0Q71<0>3D^04A7?P0S9240:S4X6_oooom^0000ocl0
oh003oooool000gooooo00<0N8^?082BV@22Tj000P23UJ@03P24UJ@0QYJU08JFY@26UjL0Q9FW08BG
ZP27VZ/0RIb/08RL[029WZ/0RYfZ08bNZ`2=WZ`0Sj2_0P2?Wk002`2@X;40U::c09NU/`2IYKD0V:>d
09RS]@2JYkH0W:Ze09fZ/`2NZk<0WZ^e0080WZbe00H0X:fe0::^]P2T[kX0YK2k0:B_^`2T/;d20:Fa
_@040:Nb_@2Y/[d0[;Bn0:fe_P80[kNo00D0[kJo0;2h`@2^]kl0[kVo0;:k`0020;>l`0040;Bl_P2e
_Kh0];fl0;Bl^P80]Kfk00/0];fk0;Jo^`2g`;T0^<2h0;_2]`2m`[P0_/>k0<35_@2oa;`0_L:i0;k4
^P020;g2^@0;0;k3^@2oa;T0_/>h0;o5]P32akD0`/Rc0<37[`32bJh0`lV/0<?8[034ajl00P32a[00
3033ak40`LFa0<?8/P32a[80`LJb0<35/@32aK00`/Ja0<?6]032aK<0`LB`0<34[P80_lF/00/0_LBZ
0;k6Z@2la:L0^l>Y0;W3Z@2e`:L0/knW0;6lY@2PZYH0SYJ507j4MP0205mPF005059@B`13@Ch0>cPe
03Pd<00e<2h00P0a;B`0100]:RT0:BLT02/Z9@0[:bD202LW8@0302@T7`0S9Al08RLN008082<L00L0
8bPP02D]900S:b408b`Q02lk:@0Y=2<06b<G008051XA00D04AD>010B3@0@4P/04QH>01LK4P0201TN
500401PM4P0G7Q806b8E01TO4`8061hB00/04QL?00dB300=4Pd0310;00L;10082`@02@X400X9100;
2@@03Pd601@E2`0201@C2P0602da800J6A00=SX^05aZD@0G6Q<06QlF6_oooom`0000ocd0oh003ooo
ool000gooooo00H0NHbC086EWP24Uj@0PiJU08BGZ024UZH208>EY@0;08BEY`23UZP0QIRY08JIZ027
W:T0R9bZ08VMZ`29W:X0RYbZ08bN[02>Wjl00P2@W[40102BX;@0Tj2d09JS]02GYK@209RU]@0509ZW
]@2KZK@0VjZd09f[]@2NZkD00P2NZkH0302Q[KP0Xk2i0:B`^@2U/;T0Y:nh0:B`^P2S[kX0YK2j0:Rb
_02X/K`0Zk>m0:ff`080[;Fn00L0[;Fl0:bf_@2/][`0[[Nn0:ng_P2_^;d0/KVn0080/kVm0P2d_;h2
0;Fm_@0;0;Bk_02f_[`0^;nk0;Vo^P2j_[X0^[ji0;_0^`2l`[/0_L>l0;k5_@2maK`00P2l`[`02@2m
`[/0_<:j0;g3^@2m`kH0^l6a0;g3/02ma;40_/Fa0<36[P020<76[P80`<B_00`0`<Fa0;o5/P30a[40
`LJa0<77/P31aK40`LJb0<35/P32a[@0`lJc0<33[`2o`[020;o3/@070;g3[@2l`j/0^l>Y0;c4[02k
aZ`0]l:X0;FoZ0020;JoZ00?0;G0Y`2/]j00WJFB09fUTP2>Uh80Kg=Q05UKB`1CDT80Ad<h048m=@10
>c@0=c<]030]9`0]:RH0:BDR0080924N00`08R4M02@W8@0S:24082HL01hT6@0M9AT07RDJ024Z700Q
:QX07bTG024Z600M91@201TO4@0;01LM400E6Ph051T>01LJ400G6Pl06A`B01XN500H7Q@06AlE01`S
600L8aL00P0J8QL02`0D7Q<03QH=00dD300<4P/02Pl600P;10082@@020P300L70`071@<01PL20080
1PP100H01`T000hB1@0F6PX07R@@01hS3`0H6`/Jooooog@0003o>@3oP00?ooooo`003Oooool01P1m
TIP0PYJO08BHY024UjL0QINZ08FHZP80PiJX00/0Q9NY08BIZ026VZP0QYVW08JJY`28WJX0RYn/08bQ
[@2=X:d0Sj:_092P/00209:P/`0;09>Q]P2CXKD0U::d09FS/`2IYkL0VZNh09ZX]P2LZkH0WJbe0:2^
]P2R[kH00P2R[KL01P2R[KP0Xjfi0:Ja^P2X/kX0Yk>j0:Rc_080Yk:k00@0ZKBm0:Zd_@2[][h0Z[Bo
0P2Z]L402P2[]/00[;Jn0:fg_`2`^<00/KS00;6g_`2b^Kl0];W00;Fk`@2e_<430;>m`00;0;Bl_`2h
`<40^;no0;Rm_P2i_kd0^Knl0;[1^`2k`[/0^/:j0;W2^P2i`KX00P2k`Kd02`2na;h0_L>m0;c2_@2n
`kd0_/>i0;g3]P2m`kD0_lFg0;o6]030b;<0`<Ra0080_lN`00H0`LRb0<77/P31a[40`/Nc0<?8]034
b;D20<35]0040<;6]032akD0`<Bc0<35]080_lBc00H0`<F`0;o5/02oak00_/J_0;g6[P2la:`20;_2
Z`030;_1ZP2j`ZX0]knZ0080]kn/00/0/kjX0:NaV`2AV8D0P8Ec06IVF@1GEDT0Cda004M6>@0n?C80
=cH]02d[9@0202PV8@0<02DU8@0R8b008B@P020V7`0L8aX06AlE01LM4`0K8aL06R4C01PN3`0N91<0
7bDF0P0O91L02`0N8aL072<H01/R600I7aH05Q/B01LK4@0J81@072<E01lV5`0N9QH07BLF00806bDE
00/06B8D01HO4@0C7@h04AP;00lE1`0<4@D03@l600`=100;2`@02PX500L9100200H90P0600H90@08
30003102018F1P0A4`D02`X16_oooomf0000ocL0oh003oooool000gooooo00H0NH^E07nBWP23UZD0
Q9N[08>E[025VJh208FI[00;08FJZP24V:L0QYZY08VLZ`28W:X0RYj[08bPZP2?Xjh0Sj:^08jP[`2@
X;800P2AX[@02P2BXkD0Tj>d09BU]02FY[@0V:Nd09ZY]P2KZ[H0WJbf09j]]@2P[[H30:B`^@0<0:>]
^@2T[kX0Yk:k0:Rc^P2X];/0ZKFm0:Ze_P2[][l0Z[Jo0:^h_`2[^Kl0ZKJm0P2Z]/002`2^^L<0[[W2
0:jg`02`^<40/[W10;>h_`2c^L00]K[10;Nm``2f_<@0]K_40080^;o500/0^<740;[2`P2i`Kl0^;no
0;Ro_P2h`;d0^/>m0;_4_@2i`[X0^/>j0;c2^`020;k5_P0;0;k4_`2oa<00_lC00<75``2oa<00_lFl
0<;8_@31ak`0`<Ni0<38^031b[H00P33b[@03034bkD0a<^f0<;9]@31b;D0`LNf0<77^030akP0`<Ni
0<37^031b;P0_lFf0;o5]@80`<Je00/0`LJc0<?8]@32akD0`<Je0<76]@31a[80`LJ`0<76/@2oaJl0
_/F]0;g4[P020;g4/00;0;_2[`2i`:d0]KbZ0:nhYP2QZIL0QHYj06U]GP1LH500D59604=4?@0j>SD0
0P0g>380300d=2h0;bl[02PY9`0T9BD082<R01/P7P0I7AT06b0I01TO600G7A@06R0E01hU6@8082HJ
00/07B@J01dS6P0N9A/07RHJ01`T5`0M9AH07bLE024Z5@0S;1L08BXE020Y4`0201hV4P0701dU500L
8a@06b8B01XQ3P0H7Pd061`=01DI300201<D2P03014B2P0=3`T02`l800802`l800D0310800/?1`0>
4PP03a0900`;1@0JooooogP0003o=@3oP00?ooooo`003Oooool01P1gRID0OY2N08:DY`23U:`0PI:/
08BE[@80PYJY00/0PiJW08>GY@26V:H0RIZX08ZLZ@29VjP0RifX08nQ[@2@XJh0SYj^08fM/00208jN
/@0;08nQ/P2AXk40TZB`09FU/@2FYK00V:Rc09RY]02IZ[@0W:^d09n]]@2P[;L00P2R[KP00`2Q[;H0
Xjfg0:J`^@020:Ra^P070:Vc^`2X/[`0ZK>m0:Ve_`2Z][d0ZKJk0:Ve^P020:bf_00;0:jg_P2`^;l0
/[W10;>i`@2b^L40/kS00;Fj`@2f^L00]k[10;Fh`@2f^L400P2g_L400`2h_/00^Ko00;Vo_P020;Vo
_P060;W0_P2j`[l0^/6m0;[0^P2k`KT0_<6h0P2m`[T01P2m`[/0_L6k0;g1_02o`[h0_l>m0<74_080
`<Bj00<0`<Ji0;o5]P2oa[<00P31ak803033a[@0`lRf0<;7]P30a[L0_lFh0;k4^P2oaK/0_lNj0;o6
^02oa[L0`<Jg0;o5]@80_lFb00/0`LJa0<?7/P33a[@0`LBd0<75]031a[80`LF`0<35/02na:l0_/>^
0;c1[P020;_1/00;0;[1/02i_jl0^;j^0;Jm[P2f_Jd0[kFW0:>ZW02@UX/0NWef069TG`1DEDl00P19
BT40300n?cD0=3<^02`Z:@0U8BD081dR01/J7`0M7b407B4O01PL6P0A51803a8@00lC40804AD@00/0
41D>018F3`0D6A004aT>01DK4@0D6`d04aX:01@K2@0F7P/05ah:01HM2P0201HL200;01HL2@0F70/0
51X801<H1`0F7@X05a`<01HI300D5@/04a@<00l@2P0<3PX00P0930T00`0930X02`l;00/>2P0200/=
2`0300X:1ooooooooooo01SoooooN`000?lb0?n000oooooo000=ooooo`0607J9U01nT9d0PY>S08BD
Z@21TZX0OXnX0P1oTZL02`20U:D0PiJT08FHY@27VJH0QiRW08JHZ027VZP0RYbY08bLZP2@WZd0SYb]
0080SYf`00/0SIja092Q/P2CY;80Tj>`09FT/@2FYKD0UJFd09RX]02MZkH0WZ^f09jY]`0209nX]`0<
0:2Y]P2QZkH0XZfe0:F]]`2W[[L0Yk2j0:Na_02V/;`0Z;:m0:Vc_P2Y];h0ZkFn0P2/];d02`2_][d0
/KNl0;6g_P2b^L00/[S00;>i`@2d^L40];Vn0;Nl`@2f^/80];W00080/kVn00/0];Zn0;Jl_`2f_Kd0
][fn0;Jm_@2e_;`0]kbn0;Rl_P2i_K`0^[fj0;Vn^@020;_0^`0;0;c1_02n`[d0_/6n0;o0_@30`Kd0
`<:m0;o1^`30`k`0_l>j0;k3^031a[L00`31aK@01031a[D0_lFd0;k5]@2na;H20;c2^0050;k5]`31
a[P0_lBf0;o4]P2na;@00P2m`k402`2oaK00`LF_0<32[`2o`[00`<Fb0;o3/@2o`k00_/:a0;_1/02k
`;00^[n_0080^;f]00/0^Kf^0;Vn[`2i_[80^;ba0;Jk[P2e^J`0/kNZ0;6gZP2X[j<0WjNI09>KR`02
08F>N`0<05QJCP0m>CP0=c8e02/S;@0S6bP07APT01hK900N72@06a`P01DF6`0@4QL03Q4C0P0<3`h0
2`0:3@T03Q8:010D2`0<4PT031<900/B1`0>5PP04a`901<L1`0C6`@04AP1008051`300/061l601DJ
1P0C5@@03a42010B100A4PH04148010@2`0?4@d03Q0=00X<2P0200L91P0600P:1`0=40`02`h<00X<
2`0<3P`030`96_oooomo0000obh0oh003oooool000gooooo00H0M8ZA07Z?V01oTYl0PI:T082AY`1n
SjP207jAZ@0407jAYP21UJD0PiJV08FGZP80QiV/00D0QiZ[08VJZP2:VZT0S9b[08fL[@0208nN[`04
08jO/@2>Wk<0TJ6e096Q/`80U:6c00D0UJ>d09RU]@2KZKL0WZZg09jY]P0209nX]`0<0:2Y^02PZKH0
XJZd0:>[/`2V[[H0Z;2j0:Ra_02X/Kd0Z[;00:Zc`P2Y/L40Z[;10P2///800`2_]L80[kG00;6g_`02
0;:h`@060;>h`P2b^<40/kS00;Jj`P2g^l@0];[30P2c^<002`2b^<00/[No0;Bi_`2d^/00]Kc10;Bk
_`2e^[h0][^o0;Vn`@2h_Kh0^;bl0080^Kbl00D0_;jl0;fo_P2o_l00_[g00;nn_`020<2o`0040<30
`030`Kl0_/2m0;k1_@80`<>m00P0`<Fm0;o5_02m`[X0_L:j0;c2]`2n`kL0_L2e0;k2]@80`/Fg00X0
`<>e0;o2]02n`k<0_/>c0;k3/P32aK<0`/Bd0<33]@2o`kH0_L6f0P2k`KD00`2j_k@0^/2d0;[0/P02
0;Vn/@0;0;Rm/02i_K40^[nc0;Nm/P2g_;40][^`0;>h[P2b^Jl0/[V`0:ng[@2]]JX00P2X/jD0302J
XYL0J6I/05=?FP0h<480:20b02HO;00Q6bD07ALO01LC6P0G4aT051@H014D5P8041<B00/04A@A00lD
3`0?4`h03A8=00T>2@0630H02Q4801<L300B70P04Q`6018K0`02018L0`0301@L1@0D6PD04QH50080
4Q@700H04A4600l?200A4@X04Q8<010B2`0<3PP200X=1P0600X<1P0=4@/03A0<00`>300>3`h03`l=
6_oooon10000ob`0oh003oooool000gooooo00H0MXbC07bBVP1oU9l0PIBR07nAX`1oTJ@207j@Y@0;
086CZ023UJT0PYBX08FEZ`29VJl0RYV`08^K/02:VZd0RYR/08bJ[P2?W:l00P2@WJl02`2BWk80Tj6d
09FR]@2EXkD0U::c09BR/P2EXk<0UjBd09ZW]P2LZKL0WJRh0080WZNi00`0X:Jj0::X^@2TZKT0XjRg
0:N/^@2[/;h0Zk700:Za`02[//00[KC10:bc`@2]/l@20:neaP040:nda02^/l80/KG10;>g`P80/kK1
00D0/kO10;Bh`@2e]l00][[20;Fj`P020;>i`@0;0;Bj`P2e^L80]KW10;Jk``2h_/D0]kc40;Jj`P2f
^/00^;g00;Zn`02k_kl00P2k_[d02`2k_k/0_;jl0;o0_P2o_[h0_[jo0;jl_P30_l00`;k10<2n`030
_kl0_[no0080_l2o00T0_l700;o2_`2l`K`0_<6k0;c1^@2m`;H0_l2f0<31]P31`[D00P31`kD03@31
a;D0`LBc0<74/`30`k80`/>c0<32/@2o`;80_l2f0;fo^02j_[L0^l6i0;_0]`2j_kD00`2j_k402`2i
_[00^;j^0;Rn[02i_Zh0^;j_0;Rm[P2f^Zh0/kR]0;Bi/02b^:h0[kJ[0080[[F[00`0[KJ]0::ZY02H
XIX0HF9X03<^>`0k=S/0<BT[02LN8P0R6Ad07QPJ01TE600H5aP201PH6@0;01LH5`0B4a<04Q@D010B
4P0<30d02`/;00d@3@0B5`l051X>01@K3@0B6`/00P0?60L02`0@60H051`801<J2@0E6P`05AT=01DG
300B4`X04Q8:014A2P0B4`/0418900803A0600H030l500d?1`0?40/0410=00l@3P0?40dJoooooh80
003o:`3oP00?ooooo`003Oooool01P1dQi<0OI6M07jAX020U:D0OY6T07f?X@80OY2S00/0P9:V086C
Z022TjT0Q9B/08NF[`27UJl0RYR_08^J/@2;Vk00SIZ`08nJ/@02096L/P0;09:N/`2EXKD0UZ6e09FQ
]@2EX[@0V:Ff09RT]02JY[D0VJFd09VT]02KY[L00P2MY[T0302OY[X0XZNk0:FX_02VZKd0YjZn0:R[
_P2Y[L00Zjo20:ba`P2]]<40[KC20:jd``80[kC400/0[[C40:ne``2^]<40/;G10;6f_`2b][l0/kNo
0;:e_`2b][h0];S00;Bi`0020;:h`0040;Bi`@2f^/40]kW10;Ni`@80^;_100D0]k[00;Ni`02g^[h0
^;bn0;Zn_@020;Zn^P0;0;Zo^@2l`;X0_<2i0;fo^@2l_[T0^KVf0;jn^P2n_k/0_[jk0;fm^`2n_kd0
0P2n`;h0302m_kh0_;nm0;c0^`2k_kT0^l2g0;c0]02n`KD0_l2d0<30]P30`KL0_/6f0;g2]080_l:c
00L0_l:a0;o1[`2m_jd0_;j^0;fn/@2l_[D0^[ng0080^L2g00l0^/6e0;[0/`2i_[40^Kja0;Rl[`2g
_:d0^;f/0;Ro[02i_j/0^Kj[0;Nm[@2g_:l0][Z^0;Bj[02c]jX00P2b]j`0302_]J`0[KF[0:^dZ02P
ZYd0O81f06a]HP0c:B/0<BLX02`Q8`0U7Ah07aLI01`F5`806aLG00/06aLF01PD500E4180510B01<?
4@0=2``03Ph=01@F4@0G7A<05adA01LN4@0201HM3P0;01LN3@0F7@`04aT;01@J3@0D6@h04aP<018E
300?4P/03a4<014D3@0B5@/00P0?4`L01P0;3P<02`/200`<100=3@D030d600h@21[oooooQ@000?lX
0?n000oooooo000=ooooo`0607F6T`1jS9`0OHnR07f?Y@1lSJ@0NhbR0P1mSjD02`1oTJL0P9:X086B
ZP24U:`0QYF]08NE[`2:VK40RIR_08^J/P2>W;@0Sifd00<0T9fd00X0TYnf09BQ]`2EXKT0U:2g09JQ
]`2GXkH0V:Bf09NS/`2IYKD0VZNg0P2MZ;X0302NYk`0XJVm0:>X_@2UZkl0YJVo0:FY`02UZ/00YZ_0
0:R]`02Y[l40Z[;20:^b`P80[;C400/0[KC40:je``2/]L40[[O10;2i``2`^L40/;S00;6h`02a]kl0
/[Vn0;:i_@020;:i_`0;0;>i`@2d^/80]KS10;Ji`P2h^/<0]kW20;Rj`@2h^/00]kZo0;Nl_P2h_kh0
0P2h`;/02`2g_[P0^;ji0;Rn^02i_kL0^Knh0;Zn^P2k_k/0^/2l0;_0_@2k_[X0^knj0080^l6n00`0
_<710;_1_`2j`K`0^Kni0;Vo^02k`KT0_<:i0;g0^@2o`;X0_l2l0;bn^P2k_kX20;_0^00;0;g2]P2n
`K@0_L2d0;c1]02k_kD0_<2i0;c2^`2i`;/0^<2i0;O0]`2f_[H00P2g_;D02`2g^k@0][Vb0;Jj/@2f
^Zl0]kb_0;Jk[P2e^Jl0];^a0;Bj/@2b^Jl0/[N^0080/KJ_00`0[kF`0:fd[P2[/Z/0Z[BX0:VcY02P
ZIT0Dde=03P_<@0c:b`0;RDV02LN7`0U7Ah2028J7@0;01hG6P0J5AL06A<F01LD6@0F4aD040l?00`=
2`0?4P/04aP=01LM4@0J8A<00P0L8a<02`0K8A405ad=01@J3@0D6Pl04QP>014F300@50`03A4:00lD
300A5@l03a@:00803a<800H03Q4600h@1@0>40D03Pl400h@100?4@DJooooohD0003o:03oP00?oooo
o`003Oooool00`1hRIH0O8jN07jAYP0207f?Z00>07^<Y`1nT:L0OY2W082BY`20TZH0P96W08BDZ`26
U:`0QiF/08ZI[`28Ujd0RIR]08bJ/02>WK<208nN]00;08jN]02?W[@0TJ2f09:P]`2BWkL0Tj2h09>O
]`2DX;H0UJ:e09VU]P2JY[L00P2HXkP01P2GXkL0W:Jj0:2Y^`2QZK/0XjZm0:BY_`80Y:[000@0YJc0
0:J]`02V[l00Z;320P2[/l<02`2Z//<0Zk;20:Zc`@2/]L40[[O30;2h`P2_^;h0/KRm0;:h_P2b^Kl0
/KRm00<0/;Rn0P2a^L40202b^L80];[30;>i``2d^L40][[20;Fj`P2c^Kl0]Kbo0P2e_Kd00`2e_;/0
]K^j0;Jm_0020;Jn_@060;Jl^`2g_K/0^;fl0;Vo_@2i_[`0^[jm0P2i_[d02P2j_l00^[o10;Ro_P2h
`;`0]knj0;Ro^P2h_KT0^Kfj0;bm_@2k_;h20;Zm_`80^Kfm00@0^Kfj0;Vm^02h_;L0^Kbg0P2i_KX0
1@2h_k`0^Knn0;[0_@2h_kX0][fh0080]k^f00/0^;bf0;Nl]@2f_KH0]Kbc0;Fm/`2d_;80/k^b0;>l
/`2b^k<0/KVc0;6h/P020:je/00<0:^c[`2Z/Zh0Z;6/0:RbZ`2V/:T0Yk:X08nESP1UI6D0?3Dk03Xb
<`0e;Rl0;bP/0P0W82P02`0P6b@09B8Y02PV:`0J6B805AHM00lA4`0;3@d02`d;00hB300D614061hF
00806b4G00/06b0F01LK4@0F6Q405QXD010E400>4Pd03a<=010D3@0A5Pl04QH?00lC2`0200dA2080
3A0900@03Q8900hB200<3P@01`P16_oooon60000obL0oh003oooool000gooooo00H0MXJI07Z;X01l
SJL0OHjZ07f=Z`1kRZX207b=Z00;07j?Z01nSjL0PI2W08BBZ@2:Ujh0RYN_08VG[P2;VZl0SI^_08jL
[`2>Vk000P2>W;<02P2@WkH0Sine08nP]02BXKH0U::h09BQ^@2CWkP0Tijg09FP]@2HXkL309ZU^@0<
09RT^@2KY[/0WJNj0:2W^@2QZ;/0XZNn0:J[`P2T[<@0Xj_20:>/`02S[;h0YJjn0P2W[kl02`2X/<00
ZK;00:Vd`@2[]/40[;Bn0:fd_P2`][h0/[No0;:f_02b]Kd0/[Jn0080/KO000/0/;O20;2h``2`^L80
/KO20;:h``2`]l<0/;K10;6h`02d^L80/k[30;Bj`P020;Bk`00;0;Bl_`2e_<00][k10;Jn`P2e_<00
][bm0;Nl^`2h^kT0^Kbi0;Vm^`2i_;/00P2j_;X0302k_;`0^[jn0;Vn`02g_[l0][jl0;Jn^P2g_K/0
^Kfl0;Vl_@2i_Kh0^[fm0;Vm_@80^;^m00/0^;^k0;Zm_02h^kT0^;bg0;Zm^@2i_;X0]k^j0;Jj^`2g
^k/0^;bj0;Nk]`020;Nk]0060;Nk/`2d^k40/[^`0;:k/@2c_;<0/[bd0P2a^k400`2`^:l0/;Ra0;6i
/`020;6i/@0<0:jg[`2]]:`0Z[6/0:Vb[@2X/Zd0Yk6/0:J`Z@2KYId0Kg9a051=D@1=Bdd0B4E90P0e
<CX02`0X9Bl0:R/a02/]<P0N82L06ahT01PK700C5Q@041@@014D3`0D5a405a/E00807AlI00/071dI
01TI500I6A<06QdH01HI5P0E61<051LB01@H3`0D6A005ATA018E400200hA300600`?2`0?4Pl04AD@
00dA30082`H010D16_oooon80000obD0oh003oooool000gooooo00H0MXJI07Z;X01lSJL0OHjZ07f=
Z`1kRZX207b=Z00;07j?Z01nSjL0PI2W08BBZ@2:Ujh0RYN_08VG[P2;VZl0SI^_08jL[`2>Vk000P2>
W;<02P2@WkH0Sine08nP]02BXKH0U::h09BQ^@2CWkP0Tijg09FP]@2HXkL309ZU^@0<09RT^@2KY[/0
WJNj0:2W^@2QZ;/0XZNn0:J[`P2T[<@0Xj_20:>/`02S[;h0YJjn0P2W[kl02`2X/<00ZK;00:Vd`@2[
]/40[;Bn0:fd_P2`][h0/[No0;:f_02b]Kd0/[Jn0080/KO000/0/;O20;2h``2`^L80/KO20;:h``2`
]l<0/;K10;6h`02d^L80/k[30;Bj`P020;Bk`00;0;Bl_`2e_<00][k10;Jn`P2e_<00][bm0;Nl^`2h
^kT0^Kbi0;Vm^`2i_;/00P2j_;X0302k_;`0^[jn0;Vn`02g_[l0][jl0;Jn^P2g_K/0^Kfl0;Vl_@2i
_Kh0^[fm0;Vm_@80^;^m00/0^;^k0;Zm_02h^kT0^;bg0;Zm^@2i_;X0]k^j0;Jj^`2g^k/0^;bj0;Nk
]`020;Nk]0060;Nk/`2d^k40/[^`0;:k/@2c_;<0/[bd0P2a^k400`2`^:l0/;Ra0;6i/`020;6i/@0<
0:jg[`2]]:`0Z[6/0:Vb[@2X/Zd0Yk6/0:J`Z@2KYId0Kg9a051=D@1=Bdd0B4E90P0e<CX02`0X9Bl0
:R/a02/]<P0N82L06ahT01PK700C5Q@041@@014D3`0D5a405a/E00807AlI00/071dI01TI500I6A<0
6QdH01HI5P0E61<051LB01@H3`0D6A005ATA018E400200hA300600`?2`0?4Pl04AD@00dA30082`H0
10D16_oooon80000obD0oh003oooool000gooooo00H0LX:I07N7X@1lS:P0O8b[07f<Z`1mSJ/207f>
Z00;07b=Y01mSZ<0P92R08>AX`27UJT0RIJ/08JDZ027UZL0Ri^[08jK[@2<VJl00P2<VK802`2=W;D0
SYfd08nN/P2AW[<0Tind09FP]P2EWkL0UInf09NQ]@2IXk@0V:6e0080VJ>g00P0WJNl09jX_02MYkT0
X:Rj0:6W^@2RZ;/0Y:Zo0:>[`@80XZ_100l0XZbn0:F^_P2V[kl0YZno0:Ra`02X/;h0ZK:m0:bd_P2]
]Kh0[kJo0;2f_`2a];h0/K>l0;:c_@2d]Kl00P2b]/002`2a]l00/[O10;>i`P2d^<<0]KO40;>ga02`
^<D0[kK10;2g`02a]l00/[_30080/[W100T0/[W00;>k`02d^kl0];^o0;Bh_02e^;X0]kZh0;Vj^02j
^kT00P2j^[/20;^k^`0<0;Zj^P2i^[`0^Kbo0;Jj_02d^KP0];^h0;Jl^`2f^k`0]k^n0;Rm_`2h_;d0
^Kfm0P2h^[/02`2g^KT0^;^i0;Rj]`2h^kL0^;^f0;Rj]P2h^KL0^;Vh0;Rj^@2f^;H0][Ve0080]KRc
00@0];Vc0;:i/P2`^;00/KR`0P2a^K401@2a^Zl0/KV^0;2h[@2_]j`0/;J]0080/;J`00`0[[F`0:fe
[@2Z/J`0ZK2]0:N`[02V[jX0Y[2Z0:NaZP2PZJ@0S92D08V>TP23Rh`205MMHP0;030c>`0U:Rh08RHZ
01lQ9P0M7b807B0L02@X700M81@06Q/A01LH3`0H61800P0J61@02`0L6QH07AXG01dL6@0N7a`06adJ
01XL600I6aL05APC01DH4@0G71@04aLA00804A@@00H03@l>00dA400?4a403A0=00L91P010P4Joooo
oh/0003o8P3oP00?ooooo`003Oooool01P1cQ9L0N8VP07Z;YP1jRZP0Nh^Z07b=ZP80O8fX00/0O8jV
07j>Y@1nSj<0PI:S08BEY025UJH0QYFW08FDYP28UZT0RIR/08RF[P0208ZH/@0;08bJ/@2=WK40SYja
096O/P2CW[80UInd09RQ]`2JY;P0VJ>f09ZR]@2JX[L00P2IXKP0202JYK/0VjNj09^V^@2NY[X0XJVj
0::Y_02QZ;h0X:Ro0P2QZL003`2SZl00Y:bo0:F^`02U[/00Yk300:J`_@2W/Kd0Z[:n0:bd_P2]]Kl0
[kFn0;6f_`2a]Kh0/[Jo0;6e_P020;6f_`0:0;:e_`2b][l0/[K00;Fg`P2f^<80/kO20;:h``2_]l40
[kO00:nf`0<0/;W000L0/[[00;:j_P2c^[d0];bn0;Fk_`2f^Kd0][Vk0080^;Zm0100][Rm0;Ng_@2i
^Kd0^KVm0;Vi_02h^[/0][^l0;Jk^`2d^KX0/kVk0;>j_02d^kd0]KZm0;Fj_P2g^kh0]k^m0P2f^k/0
2`2e^K/0/kRj0;Bh^02e^[P0]k^i0;Rk^02h^[P0^;Rg0;Ri^02e][D0]KJd0080];Fd00/0];Rf0;:j
]P2`]k@0/;Rb0:ni/P2^^;40[kRa0:jg[`2_]Zh0[[B]0:nf/@020:jd]00<0:fc]02[/k80Z[:`0:Va
/02W/:l0YJj^0:F^[02T[:/0Xj^[0:B/[P2QZjh0WJZ[0P2AXj002`1<E5d09RXg02T^=P0S:2h07b<V
01hS7P0S9a/09BPK02@W6@0P8QH071dG00806aLF00/071PF01lN6P0O81`07b4L01dQ7@0M8A/06QhJ
01LL600G71H06AhG01HK500201<H4@0600lB3P0:3@/02Pd900P:1`041@<00@816_oooon=0000ob00
oh003oooool000gooooo00H0M8NF07R<W`1kS:H0NX^W07^<Z01kS:L207b=YP0;07f=Y`1oSZP0PI:Y
08:DZ023UJL0Q9FV08FDY`27UJT0R9J[08NFZ@28UZ/00P2:V:d02`2<VZl0SIb`08fL[`2>W;00TIfb
09>O]@2GX[L0Uj6f09NQ]`2HX[P0VjBj0080Uj6j00`0V:>j09VT^P2JYKT0W:Nh09jX^@2PZK/0WZJk
0:2X_02QZKl0Y:_10:F[`P2TZl420:N^``0;0:V`a02Y/<<0ZK720:Va`@2Z/L00[;?20:fd`@2_]<00
/;Fo0:nf_`2^]Kd00P2^][d02`2`][d0/KFm0;6f_P2c]kl0/[Jn0;6f_02`]K`0/;Jl0:je_02]][h0
[[No00<0[kRo00H0/;Nm0;:j_02b^kd0];^n0;Fk_`2d^Kd20;Bi_P0@0;:g_P2c][d0]KNn0;Fg_P2f
^Kh0][Zn0;Bj_P2d^kd0];Zm0;Bi_P2d^;`0]KVm0;Nj_@2f^K`0]KVm0;Fi_080/[Rj00/0/KRh0;6h
]`2b^KT0]K^j0;Nm^`2h_K`0^;^l0;Nj^P2g^KT0]KNg0;>e]@020;:e]P0;0;:f]`2`]kT0/;Rh0:nh
]P2_^KH0[[Rd0:jf/`2^]K<0[kFd0:jd/P2^]K800P2//k<0302//k@0ZK6b0:N_/@2V/;40YJnb0:B_
/@2T[Zh0Xjb/0:6ZZ`2S[:`0X:bZ09fZZP80VjZY00/0QiJG06UcN@1:D5X0>Ce902d_?@0[;SP0B4m=
05UTF00e>CH0;2h]024Q8`0201XF6`0;01PC600L6aX07QlJ01lR6`0L8QX06R0I01PN600F6aL05a/F
01LL500F6a800P0B5Pl01P0;3PX020T700P81P061@@0108100@101[oooooSP000?lO0?n000oooooo
000=ooooo`0607F9U`1jSj00O8nV07f?Z@1lS:L0Nh^V0P1nSJH02`22SjT0Pi2[08:@Z`22Tj`0PI6Y
08:BY`24TZP0QYB/08NF[P28V;00R9V`0080QiR_00/0RYZ`08bL/P2<V[80SI^d08jM]@2?WK@0TYne
09BQ]P2EX[P0UZ:j09NS^`0209JR^`0<09RT^`2HY;T0V:Bh09^W^02NZ;T0WjVj09nX^@2OZ;X0XJZn
0:6Z`P2SZ/@0Y:_50P2TZl<0202U[L80Yjo30:N^`P2Y/<<0ZK740:Va``2Z/l<0[;?30P2^]L<0302]
][l0[KJl0:ff_02^][/0[kJk0:nf_@2a]kh0/;Jn0:nf^`2^/k/0[k>l0;2e_P80[kJo0`2`]/002P2`
][l0/KRo0;2h_P2_]k/0/;Rl0:ng_02_][`0[kNl0:nh_@2a^Kh20;Bj_`0<0;Bi`02e^/80/kW00;:i
_`2d^Kh0]KRm0;Bg_02d]k/0];Rj0;Bj^`2d^K`0]KZl0P2b^;X02`2a]kP0/[Rg0;Bj^02d^[X0]KVl
0;Jj_02d^K`0/kVk0;Fi^P2e^;X0/kNi0080/kNk00/0/KFj0:nd^@2_];T0[[Fh0:be]`2^][L0[kRh
0:ne]`2_]KH0[[Fe0:^c/`020:Va/@090:Ra[`2W/;00Yk2a0:F_/02V/;80Yk:b0:Ja/@2T[jl0X:^/
0080X:^[00h0Wjf]09b[Z`2LZj/0VjRX09VVY@27TYD0MWj605iQL@1GFF/0Q8nA08ZGT`1[M7D0J7=^
03Hg>P805@hJ00/061<M01@B600B41<051<B01DF4P0D5A804aHC01<D400D5A0051H>018E2P0200h?
1`0600L70`091`D030/700X81P071@<01`@36_oooonA0000o`80oh000`000?lG0?n000oooooo000=
ooooo`060760U@1iRZ40NhbV07b=Z01kS:P0NXZW0P1nS:P02`20SJT0PHf[08:>ZP22Sj/0PHjY086>
Z023T:X0Q9:^08BC/025U[80QYNc0080QiR`00/0RYZ`08bL/`2;VK<0SIZf08jJ]@2?VkD0T9be09:M
]@2EX;T0UZ6l09JQ_@0209RS_@0<09VT_@2IY;/0VJ>i09ZT^P2MY[X0WjNk0:2X_@2QZ;l0XZ[109nX
`P2PZ<@0XJ_40P2QZl<02`2RZl40YJg20:F^``2W[l@0Yjk40:J^``2Y/L@0Zk;40:fda02/]<40[KK0
0080[KJn00P0[;Fk0:jf_@2/];d0[KFn0:bd_@2]/kd0[kBm0;2e_`80/;G000h0/;Fo0;6f_P2a][h0
/KFm0;:e_@2c]kh0/KFm0:nf_02_]k`0/;Rn0;2g_@2`]k/0[kRk0;6h^`80/kZm00`0/kVm0;Bi_`2c
^;l0/[No0;>g_`2c]K`0/kBl0;>e^`2c]kX0];Vj0;Fi^P2e^;X20;Bg^P0;0;Bi_02e_;X0]KZh0;Fj
^P2e^K`0/kNk0;>g_02c]k/0];Nj0;>f^P2c];X00P2d][`02`2a]KX0/;Bk0:nd^`2]];T0[;Fg0:jf
]@2`^;@0/;Nc0;2f/@2^];40[;>a00<0Z;6_00<0Z;6a0:Ra]02W[k<00P2X/;@01P2U[k80Y:fa0::Z
[`2PZJd0X:^_09n[[`80WZZ^0P2KYZ/02@2JY:/0VZBZ09BLX`2?V9h0TIZN09:MW@2AWI/0TZ2I071i
M00202@Q;@0;01dI9P0H51l05A<J00l<4P0C4A<07A`J01TG5P0F5Q4051D<01DE300B4P/00P0>3@T0
1P0:2@H02PX600d=200<30H01`D100P50A[oooooV0000?lE0?n000oooooo000=ooooo`0606ejT@1i
R:00NhZW07^:Z@1kRZX0NXZX0P1lRjL02`1oS:L0P8fW08:>Z021SJL0PHfX08:?Z@24T:X0Q96[08FB
[026UK00Q9J_0080PiF/00/0QIN]08RI[`2;V[00S9V`08jH/02?VK80T9Zd092K]P2BWKP0Tijj09JP
_00209NQ_@0809VS_@2JYK`0VJ>j09bU^@2LY;L0WjNk0:2V_@2OYKd20::Z`@0?0:6Y`P2RZl<0XZc3
0::/``2S[<40XZ^n0:B[_P2V[L00Z:k10:R^`02Y/<00ZK:o0:Zb_@2Z/[/0Zk>l00<0Z[>l00X0[;Bm
0:^b_@2[/K`0[;>m0:jc_P2_]Kl0/;G10:nc`P2_/l40[kG10P2_];l01@2_];d0/;Bm0;:f_P2b];/0
/;>k0080/KJn00@0/[Jm0;2f_02_];X0/[Jl0P2a][`0302b^;`0/KNj0;6f^`2_]K/0[kBk0;2d^`2b
];`0/kFl0;Be^P2d][X0/KFh0;:g^@80/[Nj00/0/[Vk0;>i^`2c^[/0];Vl0;>f^`2c]K/0/[Bk0;:e
_02`];X0/KFk0;6d^`020;6e_00;0:nc^P2_];T0[kFh0:je]P2]]KD0[;Fc0:be[`2/]:d0Zk>/0:fd
[`2]/k400P2Z/[80302W/;40YZn`0:N_/@2W[k80YZfc0:F[/`2VZk80Yjbb0:F[/@2RZK00XJVa09nX
/@80WZR_00/0VZB/09bU[02LXj/0WJB/09ZSZP2HXZP0Uj2V09NPY@2FWZ@0TI^N08bHUP0206UcL`0;
04mDEP0d=SX08R0W01XG7`0I5A/0;2`[02PV9P0R8R005aPD01DD400E51800P0D51@01P0@41803@l@
00`>3@0<3`X020T400H501[oooooV0000?lE0?n000oooooo000=ooooo`060760T@1hQid0O8^U07j<
Z@1lRZX0NHRW0P1kRjH02`1nSZ@0PI2T086>X`1oSJ<0OXfU07j=Y`20T:T0PI6Z08>CZ`25U:d0Pi>]
0080Pi:/00/0Q9B/08BBZP27UJ/0RiN/08bGZ`2>V:h0SYR`08jJ/`2@Vk<0TYfe09JO^00209NO^00<
09NP^02GXKH0V::d09^U]02KY;D0WJFg09fT^@2MY;/0WZJl09nV_@2NY[d0XJVo0P2QZ[l02`2RZ[h0
XJVk0:BZ^P2V[;X0Yjfl0:N]_@2U[;/0Yjjj0:R_^02Z/KT0Z[2i0080ZK2k00/0Z:nj0:R__02Z/;/0
ZZnj0:bb_02]/kd0[K:n0:fa_P2/[kh0Zjnn0:f`_P020:fa_P030:fb_@2^/[`0[K:k0080[k>k0P2^
/[/0102_/kX0/;Bj0:jb^P2_/k/20;2e_0080;2f^`2_];X0[[>j0:jc^`2^/kX0[k>j0;6d^`2a/[T2
0;:c^@80/KBi0P2`];P02`2`]KT0[kFi0:nc^P2_/kX0[[>k0:nc^P2_];T0[k>i0:^a]`2//[L0Zk2f
0080Zk6g00/0Zk2g0:ba^@2Z/KH0ZK6d0:Za/`2[/k80Zk>_0:^d[@2Z/Zd0Z[6^0:Za[`020:Ra/@07
0:J`/02T[[00Y:b^0:F//02VZk80YZRc0:FW/P020:BW[`030:BX/@2RYk80WjFb0080WJF`00/0W:F]
09ZSZ`2JXJX0VJ2X09NOY`2FWZL0UYfV09FMY@2DW:@0TIZR08nIW`0208^GV@0;08RETP1jQH40E5ML
0412BP0j>d80=cLm03/m?`0Y:C409BH]02@U:P0T9bP00P0H61`01P0D51X030hD00P93P0720P010H3
00@50A[oooooW0000?lA0?n000oooooo000=ooooo`060720S@1gQiP0NHZP07^;Y@1kRjH0NXZT0P1i
RZ402@1lRj00OH^P07j;X@1mRZ40Nh^S07^;Y01mSZH0Oi2X082AZ@0208>B[080QI:/00/0QYB/08FC
ZP27U:/0RiN]08fG[P2=Ujl0RiF^08bE[P2=Ujl0T9Zb09BM]00209JM]00<09NN]@2GWk@0UYjb09RR
/`2HXk@0V:6e09RQ]P2JXkT0W:Fj09fV^@2LYkT0WZRl0P2MYk`02`2PZ;d0XZZm0:>Z^`2U[;/0YZbl
0:F[^P2SZ[P0YZbi0:N]]`2X[kP0ZJnh0080Z:ji00/0Yjjj0:J]^`2W[K/0Z:jj0:V_^`2X[[X0Z:fk
0:V^_@2Y[K/0ZJjl0:^`_@020:b`_00;0:b__02//;d0Zk2k0:^`^`2[/;X0ZZjh0:Z_^02]/KT0[K2h
0:fa]`2//KL00P2^/kP0102_/kX0[[:j0:ja^P2//;P20:ja^@060:nc^P2]/;P0[Jjg0:j`^02`/KX0
/;6h0P2]/KH02@2]/kL0[[Bi0:nd^`2]/K/0Zk2k0:fb_02Z/KP0Z[6f0:V`]0020:Za]P80ZK2g00/0
ZJnh0:^`^02Z[kH0ZZne0:^a]@2Z/;@0ZK2c0:Z_/@2Y[[00Yjj^0:F/[0020:B/[@0<0:J_[`2T[Jd0
XZ^]0:>Z[`2RZ:l0XjR_0:BW[`2QY:d0XJF]0:2U[P2NY:h0W::/0P2LXj/02`2KXjT0UZ2W09NOZ02F
WZH0UijV09JLY@2EW:<0Ti^P092HWP2?V9h0SiRM0080RiFJ00/0RiBH08^EU`24SY00NXB807=nP@1W
L7H0FfAZ0412D@1<DUh0FVEY04YBE00201HE8P0601LG800:2a@010D=00831P010P400P816_oooonO
0000o`h0oh003oooool000gooooo00H0Jgb607B6T`1iRYh0NhbS07V:Y01jRZ@207V:X`0;07V:X@1j
RZ40O8bS07f<Y@1lS:H0Nh^V07b<Y@1nT:H0Oi2X08:AZ@23TZ`00P23Tj`02`23U:/0QIB[08JDZP2:
UZd0RiJ^08bG[`2:UK00RiJa08^G/@2<V;80T9bd0080TYbd00@0Tibe09FM]@2AVk@0TIfd0P2BW[@0
1P2DWkD0UZ6h09NS^@2IY[X0VZNj09^W^P80VjFl00/0VjFm09fW_P2PZKd0XJVk0:BZ_02VZkd0Y:Zl
0:BZ^`2TZkX0Y:Zi0:F[^`020:F]_@090:F]_P2U[Kd0Y:bl0:F]^`2V[[`0YJfl0:F[_02W[Kh0Yjjn
0080Z:no0P2X/;d01`2X[[d0Z:fl0:R/^P2X[K/0Z:ji0:V]^02Z[[T00P2//;/0402//K/0Zk2j0:^a
^`2[/K/0[;6l0:bb^`2[[kT0Zk2h0:Za^02Z/;L0Zk6g0:^`^P2Z[[/0Zjnk0:b`^`2/[kX20:V^^00;
0:R^^02Y/;X0[;:l0:ba_02[/;`0[;:m0:R_^@2W[kL0ZK6g0:Zb^@2Z/[/00P2Y/;/02`2X[kX0Z:jh
0:N^]P2W[K@0Z:fd0:V^]@2Z/;L0Z:jd0:V^/`2W[K@0YJ^c0080XZVa00`0Y:^a0:B[[`2SZZl0XZR_
0:6W[`2QYk40X:Na09nV/02OYk00WJB`09VQ[@2HXJX209RPZP0;09RRZ@2FXJT0UZ6Y09FPZ@2EX:P0
UIfW09>KY02CW:@0TI^R096KW`2@VYd00P2>V9/02`2>UiX0S9FJ08VCV@26T9D0PhjB086=T@1lRHl0
NHF<07V6S`1jQi00LX270080@dYI00H0?dY@01/Q;0072aL01PX@00<51`020P<JooooojD0003o203o
P00?ooooo`003Oooool01P1[Nh<0LX>@07N9VP1jRil0NHZS07R9Y080N8VV00/0MhRU07R9YP1iRZD0
NX^T07Z:Y01jRjH0Nh^U07f?YP1nSjH0PI6V08BCZ00208BCZ@0;08:CZP22U:X0Q9F[08NE[029UJd0
Qi>^08JC/027U;40R9Fc08VF/P2;VK800P2=VK<0302>VKH0SiZg08fJ]P2>VkL0Sifh08jL]@2@WKH0
TYjh09>P^P2CXK/0TZ6i09JT^P80VJFl00/0VZJm09ZU_@2OZKd0WjRj0:2W^`2SZ;`0Y:Zm0:>X_@2S
ZKd0XjZm0:F[_P020:>Z_@0;0:>Y_P2T[;h0Xjbn0:>[_@2T[;`0Xjbm0:>Z_P2TZ[l0Yjg10:J/_`2U
[;h00P2U[Kh02`2U[;d0Yjjm0:Z^_02Y[KT0Z:fh0:R^^@2Z[[X0Zk2k0:^`_@2[[[l0Zjo00080Z[31
00`0Z[300:R__`2W[K/0YZfi0:N^^@2X[kT0Yjjg0:R^^P2X[K`0Z:fm0:V^_`2Z/;l20:V__@0;0:N^
^`2V[KT0YZfi0:N^^@2W[[X0ZJnj0:R^^P2W[KT0Yjjj0:N_^`2X[[/00P2W[[/01`2V[;X0Yjji0:J/
]P2U[;D0YZbd0:F[]02UZkD00P2V[;D0402UZkD0Y:Ze0::X/`2RZ;<0XJNb0:6W/02QYjl0X:J`0:2V
/`2QYkH0WZFe09jV]@2MY[@0VZBb09RQ/02HXZl209NQ[P0509JO[02DX:X0Tj2X09:NY`2BW:H00P2A
VZL0102@VZD0Si^S08jJX02=VId208bGV`0;08bGW02;UY/0RIFJ08JAU023Si<0PHnB082>TP1nRi40
OHVC07^8TP1jR9000P1dPXT01P1`P8<0EVMX02@^=`093QP00`L=00421Q[oooooZ0000?l50?n000oo
oooo000=ooooo`0606UkPP1eQi40NHZJ07V:WP1iRJ@0MXJU0P1cPZ<02`1aPj<0LXFT07F8Y01gRZ<0
NHZS07V9Y@1kS:L0OHnW07j?Y020TJ80PY:R0080Pi6T00/0PI2W086BZ`21TZ/0Q9>[08JD[027U:h0
Qi>a08FB/P26Tk@0QiFa08VF/00208bH/`0708fG/`2?VKL0SiVh08nJ^@2@VkT0T9^d092L/`0209:N
]P80TIng00h0Tj6h09RT^P2HY;X0VZFk09ZT^P2MY[/0X:Vl0:6X^P2QYkT0XZRk0:>X_@2SZ;l0XZNn
0:>X_P80XJNm00@0XJNn0:BY`02SZ/00XZZo0P2RZk`01@2SZKh0Y:Vo0:BZ_@2SZ[`0YZ^k0080YZbl
00/0Y:Zk0:FZ^`2VZkT0Yjfg0:N]]P2X[[P0Yj^h0:N[^P2W[;l0ZJg10:V[`@020:V[`P080:NZ`02U
ZKl0Y:Vm0:FZ^`2UZkX0Yjfj0:N[^02VZKL20:NZ^0080:NZ^`2XZk/0Yj^k0:N[^`2UZkX0Y:Zi0:F[
^02V[KP20:J/^0050:N/^@2UZ[L0YJ^g0:J[]`2V[;L00P2UZkL02`2TZ[H0YJ^f0:J[]@2UZkD0YZZd
0:BY]02QYk@0XJRd09nW/P2RZ;80XZRd0080WZFb00`0WZBa09jT/02MXjd0WJ>]09nU/02PY;@0W:6d
09ZQ]02HWk80Uij_09VQ/02HX;4209JO[`0;09FQ[P2CWj/0TIjX09:MY`2BVjP0TI^X08jIYP2<V:<0
SIZO08^HV`2:V9X00P2;UY`02`2:UId0R9>L08REV`22SY@0PHfB086?T`22SYD0P8^E082:U01mRY40
NhV=0080NHJ900H0MX6507R6Q@1JIfP05QTW00`=5`091a8JooooojT0003o103oP00?ooooo`003Ooo
ool01P1/OHX0MHNF07^<WP1kRZ<0NHVX07N7Z080LhFV00/0M8NU07B8X`1gRZ80N8ZS07^;Y@1lS:L0
O8fY082BZP20TZL0P9:T086BY@0208:@YP0;08>BZ`23Tjh0PI:^08:C[@23TZ/0QYB]08JC/@26Tk<0
QYBb08NF/02;VK000P2@V[40302?Uk00T9Rc08nI]@2?VKH0T9Ze096K/`2CW;80Tifb09>M/`2DX;@0
U:6d09FQ]080V:>f00/0VjBi09ZS^@2KY;X0WJNi09nX^02RZK/0XZNk0:6V_@2TYkl0XjRn0:6X_@02
0:2X_00;0:6X^`2SZKh0Y:S00:>Z`02SZ[h0Y:^n0:>X_02UZ[d0YZbm0:>[^P2U[;/00`2UZkX02P2T
ZKP0XjVf0:BZ]02T[;@0Y:^e0:F[]`2VZk/0YZ^n0:FZ_`2UZKl20:JZ`@0<0:FZ`02TZL00YJ[00:JZ
_@2VZk/0Z:fj0:R[^@2WZKT0Z:^j0:V/^@2Y[;X0Z:Zi0P2X[;T01@2W[;T0YZ^h0:FZ^02UZkL0YZbh
0080YJ^i00@0YZbh0:N]^02W[KL0Z:fg0P2X[KP20:R/^0080:R[]P2W[;D0YZ^d0:BZ]02RZ;@0X:Vc
09nY]02NYk<309fU/P0909fV/`2NY[<0WJB`09fR/02OYK40WJ>d09bR]P2KX[H0VJ6c0080VJ6`00h0
VJ6a09NP[`2GX:l0U9n]09:O[02@VjX0T9bZ096MZ`2@W:/0SIZZ08ZJY@29VJ00RIVO08RGW080RYRM
00/0RIFM08NDW026UI/0PY6E08:?TP24Si<0Q8jE08:;UP21RiH0OHRB07V6S@0207Z6RP0607V3R01i
PXH0N8B605ALIP0g>d/0;c926_oooonZ0000o`<0oh003oooool000gooooo00H0JGV;07B5V01kS:80
NX^T07Z9Y`1iQjP207J6YP0;07J9Y@1hS:@0NhfT07^<Y@1mS:H0OHfW07j>Z@1oSjT0P92W086BY@24
U:P00P23T:T01P23TJ/0Pi:]08:B[P23U:l0Q9B^08JE[P80R9F`00<0R9B_08ZG[`2=VJl00P2>V:h0
302>Ujl0T9Ra096H/`2AVKD0TIVc09BK/`2EW;@0U9bd09BM]02EX;D0UJ6b09RS/P80VjBe00/0W:Bh
09bU_02LYK`0WJFj09jW^`2QZKd0XJNl0:6W_@2RZ;h0XZVn0:6Y_P020:6Z_P0:0::Z_`2SZ/40XjS1
0::W`02SZ;l0XjVm0:>X^P2UZk/0YJbl0:B[^`<0Y:Zk00@0YJ^m0::Y^`2QZ;T0XjZh0`2TZkL0102U
[;/0YJbn0:B[_`2TZ/020:BX_`0<0:FZ_`2UZ/40YZ_30:J[`02VZkd0Yjbm0:R/_P2Y[;l0ZZg00:Z]
_`2Y[;d0ZJbj0P2Y[;T01`2XZkT0Yj^j0:FZ^@2UZ[T0YJ^i0:F/_@2VZk`00P2UZkX03`2W[K`0ZZjn
0:Z]_@2Z[Kd0Z:bm0:N/_02VZkT0YJZf0:BZ]@2TZ[H0Xj^g0:6Z]@2OZK@0WZNc09fU/`0209bU/P0<
09fW/`2NYk<0WJJc09bT/P2MY[<0VjBc09ZS]02HX;@0Uj6b09VS/P2IX[40Uj2`0P2GX;802`2EXK80
TYn_092M[@2@W:X0TIbY092LZ@2?VZX0S9^X08ZJY029VIl0R9RK0080RiZK00/0RYZL08RIV`27V9T0
QIFE08FCU025TI@0Q8jD08B?U`22SIP0Oh^H07^9U@0207b8T`0607f9T@1lQHd0NH>:07J2R01/NH00
I7Ah6_oooon]0000o`oooooo000=ooooo`0606EdR@1aPiT0MhVR07N9X`1hRJD0NHZU0P1fR:D02`1f
R:@0M8NR07N8X`1kRZD0Nh^T07b<YP1mSZL0OhnX082=YP23TJL0QY>Z0080Q96Z00X0PXjZ086>Z@21
SjX0Q9:^08FC/@26U;40QiFb08ND/P29U[40S9Ra0`2<Uk00302<U[40SiNa08nH/P2AVK@0TYVd09BL
]02DWKH0TY^e09:K/`2CW[<0U:2b09FQ/P80Uj:b00/0VZBf09RS^@2IY;X0VjFk09^U^P2JY;T0Vj>k
09fV_P2NYkh0WJJn09jU_`0209nV`00;09jV`P2PYl<0WjS30:2V`P2OY/40XJNo0:>Z_P2T[;l0Xj^k
0:BZ^P2TZ[/00P2SZ[d02`2TZ/00XZS109nV_`2OYkh0X:Vl0::[^`2RZkT0XZ^k0::Y_02QZ;d0XJNm
0080XjRm00`0YJVn0:FY_`2VZ/<0YJW20:FZ`02TZL00XjS00:FY`02VZ/40YJS10:JY`@2VZKh20:FX
_@0;0:BW_@2TZ;d0XjRl0:>Y_02TZK/0Y:Zn0:F[_`2TZkl0Y:bn0:>Y_@2TZKd00P2UZKh02`2SZK`0
XjVm0::X^P2SZKT0Y:^j0:>Z^P2QZKT0X:Vh09nW]@2OY[D0X:Ng0080WZJf00`0WZNf09bU]@2JX[80
VZBa09ZT/P2IXk40Uj>`09FQ/02EXK40UZ2a09JO/@2DWJl209BN/00609JQ/P2BWjl0T9f]092MZ`2?
VZP0S9NT0P2;Uj@00`2;V:@0RIRQ08RGW@0208VGV`0:08NFVP24TiT0PY:G08:BUP22TID0PXnD086=
T`21SIH0P8fG07j;U@<0O8ZD00H0O8VD07Z6T@1fPh`0MH>90761Q@1/OWdJooooojd0003o3oooool0
00gooooo00H0IGB90763V@1gRJ80MhVS07R9Y@1iRZD207J8Y@0;07J8Y01dQj80MhRS07^:Y@1kRj@0
O8bV07f>Y`1oSjP0P8fV08>AY`26TjX00P24TJX02P22SZX0PHjY086?ZP24TZh0QI>a08JD/@27UK80
QiBb08VF/@2<V;4308bG/00<08bF/@2?Uk40SiRb096I]02BVK@0U9bd09BM]P2BVkD0TY^c09>N/`2D
X;80UJ6b0P2GX[802`2JY;H0V:>i09VT^P2KYK/0VjFj09ZT^@2KXk/0WJJn09jW_P2MY[h0WZFo0080
WjK000/0WZK20:2W``2OZ<<0X:K209nV`@2QYkl0XjZn0:B/_`2SZk/0Y:Zj0:BZ^`020:>Z_@0;0:BZ
`02RZ<40WjJo09nW_P2PZK`0XZ^k0::[^@2RZk/0XZVl0:6X_@2QYkd00P2SZ;d0302UZKh0YJVo0:JZ
``2UZL80YJ[00:BY`02SZ<00YJW00:JZ`@2UZ<40YZW10:JY_P80YJRm00/0Y:Nm0:BX_@2SZ;`0XjVl
0:BY^`2TZ[h0YJ^o0:B[_`2T[;h0XjVm0:BY_@020:FY_P0;0:>Y_02SZKd0XZRj0:>Y^@2TZkX0XjZj
0:6Y^@2PZKP0WjNe09nV]@2PYkL00P2NY[H0302NYkH0W:Fe09ZR/P2JY;40VZBb09VS/@2GXk00UJ6`
09FQ/@2FX;40UYna09BM[`80U9j`00H0UZ6b09:O[`2@WJd0T9f[08nJZ02<Uj@208^GY00308^HY029
V:40R9NM0080RINK00X0QiJJ08BCV@22TYL0PY:F08:AU@22Si@0PHfC086=UP20SIL0OX^E0`1lRY@0
1P1lRI@0NXJA07J3S01ePhT0LH6506anOA[ooooo[@000?l?ooooo`003Oooool01P1SLXT0Kh:J07B9
X`1fRZL0MXVW07N9YP80MXNU00/0MHFT07B5Y01fQjD0NHVU07Z9Y@1kRjD0OHfV08:@Z023T:L0Q96W
08NDZ`0208FAZP80Pi2Y00T0PY2X08:?Z`25TK00QY6b08NB/`27TK80Qi:a08ZE]02:U;800P2<U[40
302>U[<0T9Fd092F]02AUkD0TYVg09:J]@2AV[D0T9Ze096K]@2BWKD0TYfd09>Q]080Tj6c00/0UZ>f
09FQ^02FX[/0Uj>m09RR^`2JY;/0W:Bl09fT_P2LY<00VjBn09bT_P0209fV_`0909jV`@2MY/40WJG1
09jV`P2OY/80WjK00:6W_P2SZKh0XZZm0080XjRk0P2QYk`02`2RZ;h0XjS20:6V`P2PY/40XJRo0:6Y
_`2QZKh0XJRm0:6W_P2PYkh0X:Jn0080Y:W000`0Y:Vo0:FY_`2TZ<40Y:O10:>W`P2TZ<<0XjK20:BW
``2VZLD0Y:O40:BXa02TYl<20:>W`P050:BY``2TZL80XZO10:2W`02QZL000P2RZ/00102RZl40Xj_0
0:6X_@2QZK`20::X_0050:6X^`2QY[`0XJNk0::X^`2RZK/00P2RYkX0102RZ;/0X:Jh09nT]`2OYKL2
09nT]`0<09jU]`2LYKH0VJ:c09VR/P2KXk<0VZ:b09RQ/@2FX:l0UZ6_09JO/02FWk40UYn`0P2EWZh0
1P2CWJd0TIb/08nL[02?W:/0SYbZ08fHY`80RiNT00<0RYJR08ZEX@2:UJ000P29U9l02`27TYd0QI6M
08>BW@24Ti`0Pi:I08:@U`21SYH0OhbH07j<V@1lRIH0NXND0080NXNC00H0N8FB07N4S`1dPh`0Lh:9
0762Q01]OgdJooooojd0003o3oooool000gooooo00H0IgN;0722VP1bQZ80MHRX07F8ZP1cQZT30763
YP0:07B6Y`1gRJP0N8ZU07V:Y@1kRj@0O8bU07j;Y@21SZL0Pi2Y08FAZ`80PXjZ00/0PHjY08>?Z@24
TJX0Q96Z08ND[@27TZd0R92_08R@/027TK00RI>`08bE/@0208jG/@0<092G/`2AUkH0T9Jf092E]P2A
UkP0T9Rf08nH]@2@VKH0TI^f096M]`2@W;L0TYje0P2BW[<02`2BWK<0TYje09JQ^@2FX[`0UInj09VR
_02KXk`0Vj:l09VP_P2KY<00VZC00080VZG100L0W:K009fV_`2MY[h0WJJn09fU_P2NY[h0WjJm0080
XJNl00l0XJJl0:6W_02QYk`0XJNl0:2V_02QY[d0XZNo0:6V_`2RY[l0XJJo09nU_P2OY[h0WjBn09nU
`02OYL400P2RZL80302RZ<00XZNo0::X_`2RYkl0XZO00:>X``2UZLH0YJS50:BXa02SZ<80XjO10:>X
`P80XjO100/0XjO20:BX`P2RYl40XJO209nW`P2QZL80XJW00::Z_`2RZKh0XJRm0:6X^`020::Y^`0:
0:6X^`2QYk`0XjVm0:>Z_P2RZ;`0X:Fi09nU^@2OY[T0WjFg09jS]0<0WJBe00`0WJ>e09ZR]02IXK@0
VZ6c09ZR/P2HXK40UZ2a09FN[`2FWJd0Uij^09JN[`2FWk4209JN/00;09BM[@2BVj`0T9^[08jHZP2>
VJT0Si^Z08jIY`2=VJH0S9RU08VEXP2:UJ<00P29U:802`27TIl0QI2O08BAWP23TI/0Q9:J08>@V@23
SYX0PH^L07j:WP1jQY/0MhFF0080MhJE00H0MhNC07J6T01eQXd0LhF90763P`1_PWdJooooojd0003o
3oooool000gooooo00H0IGF906n1V01`Q9l0LXNT07:6YP1aPjH206j1Y00;0724Y`1aQ:D0LXFU07>6
Y@1eQjD0MXNT07^:YP1kR:H0OX^X082>Z@22SjX00P22SZT208:@Z@0908>AZP24TZ/0QI>Z08FBZ026
TZX0QY6/08NC[@28TZh0RYB^0080RYB]00`0RiB_08fE/P2?UkD0SYNf08jG]`2>V;H0SYRc08nI/P2>
V;80SiZf092K]`2@Vk@2092L/`0;092K/P2BW;@0U9ng09FP^02FWkP0UIfh09JN^`2FWk/0UInk09NQ
_P2IY<000P2GXkl02`2EX[h0Uj>m09NR^`2GXk/0VJBl09^U_@2LYK/0W:Bi09bS^02LXkT0WZFj0080
WJBj0P2NY;X02@2NY;/0WZ:k09jT_@2OY[d0WJFj09fU^`2NY[d0WZFo09nW`P0209nX``0<0:2X`@2O
Z<00WZNn09jW_P2OYkl0X:O00:6W`@2PYL00X:Jn0:2W_@2PYkl0WjFo0P2NXk`02`2PYKh0XJK00:2V
`@2QZ<00WjNo09nX_`2MY[d0WJJl09nX_02PZ;`0WJJj0080W:Ji00/0WJFj09fU^@2OYk`0X:Rm09nW
^`2NYKX0W:>h09^S]P2MYKH0W:>d09^S/`0209bU]P0<09^S]`2HX;H0Uind09NP/`2GX;00UZ2]09BN
[02EWZd0U9b]09FL[P2CVjd0TIZ/0P2AVZd0102?VJh0T9^]08jJZ`2<V:P208^FYP0508ZEY@2;UJD0
RYFU08RCX`27TZ800P26T:402`22SIh0PXfM08:>W020SYX0OXjG07n=U`20SIL0P8^I07n;W01kQiX0
MhNG0080MXRE00H0M8FA07:3S@1aPhT0L8>406f1O`1/P7XJooooojd0003o3oooool000gooooo00H0
IgF<06YkUP1]PIl0KHBR06n4Y01cQZL207:5Y`0;0765Y`1^PjD0L8BV07>8Z01dR:H0MXVV07V;Y`1j
RZH0OHbV07j=Y`1oSJL00P1nS:H207j=YP0907n?Z020T:T0P92X086AZ021TJL0QY>Z08NB[@28Tjl0
R9B`00<0R9B^00/0RiF`08fG/`2=V;H0RiFe08fH]P2=V[D0SYZc08fI/P2<V;H0S9Nf08^G]@0208bI
/P0;08fK/P2@W;<0Tifd09>M]P2EW[P0Tibh096J^@2CVkT0Tibh09>M^02CW[X00P2CX;/02`2AX;/0
Tj6l09FQ^`2DW[X0UJ2l09FO_02FX;X0VJ:j09^S^P2KXk/0VjBk0080VZBk0P2JXkT0202JXkP0VZ:h
09^S^P2LYK/0W:Ji09bU^@2LY[`0WJFo0`2MYL00302NYl80WZK209jV`@2NY/00WJFn09fU_`2MY;h0
WJFl09bU_02LYKX0W:Jl09bV_@80VjBk00/0Vj>k09fT_@2MY;h0WJFo09bU_`2LYKh0VZFl09^U^P2L
YkP0WjVi09jY^@0209fX^@0;09bU^02LY;L0W:Bi09fU^@2MY[T0WJFi09^S]`2JXKD0VJ6f09^S]`2J
Y;P00P2JYKP0302IXkP0Uj2e09FN]02FW[@0UInb09FO/02CWZh0TYf]09:L[02@VZ`0SiZ/08fIZ@80
SYZZ00/0SYVZ092J[@2>VJd0SIR[08^GZ@2;UJL0R9:T08VBY@29TjD0QY:S08FAXP0208BAXP04082=
WP20SIl0P8jQ082?X080O8fL00D0OHfL07f<VP1lRiP0NHJF07J5UP0207N8U`0607B5T`1aPXh0L8>9
06n3P`1^PX00Jgmi6_oooon]0000o`oooooo000=ooooo`0606MdT01/O9`0KX:T06n5YP1`PjD0LXBW
0P1dQZX0101cQJX0LHJZ07:7Z@1dRJH207N:Y`0507V:Y`1kS:P0O8fX07j?Z01oSjL00P21SjL02`1o
SJL0OXbW07n>Z@21Sj/0PI6[086BZ`21T:T0QI:/08JB[`26TK00Qi:_00<0RIJ_00/0RiJ_08^F/@2=
U[D0S9Jh08ZE]`2:U[L0S9Rf08jI^02>VkX0S9Vi08^H]P0208^I/`0;08jL]02@Vk<0Tibe09>L]P2F
W[P0UIbh09BL^02EVkT0UIbi09>K]`2DW[X00P2EXK/02`2DX;/0U9nk09RR_P2IX[h0V:2m09NP^`2I
X;/0V9nk09VO_02LX/00WJC00080W:Bn00/0VjBm09bU_02LY[/0Vj>i09^S^02LYK/0WJNl09^T^02L
YKX0WZFo09jU`P0209jV`P0:09nW``2PYl<0X:K209nU`P2NYL80WZK209jW`@2NYl00WJNn09^V_@80
VZJo0P2KY[l02`2KYK`0WJBl09bS_@2JX[h0VjFo09^V_`2LY[d0WJNl09jX^`2MZ;P0WjZg0080X:Zg
00/0WjRg09nX^02NYkX0WjNk09nW_02NY[/0WJFi09fS^02LX[P0W:Bj09fU^P0209bV^@0<09^S]`2H
XKH0VJ6f09RQ]P2GWkD0UIjd09BM]@2CW[D0TYbc092L/@2@WK00T9f]0P2AW:h02`2AVZd0T9V]08jH
[P2=Uj`0RiFZ08^FZ`2;UZX0S9NY08^GZ027UJD0QYBT0080QI>U00/0Pi2S08:?Y022T:L0PY2V07j>
XP1kRj40Nh^O07^<W01jRiT0N8NH07N5VP0207R7V`0607F5UP1eQY80M8J=07:5Q`1`Q840KH9j6_oo
oon]0000o`oooooo000=ooooo`0406QcT@1cPJ40M8BW07>4Y`80LX:V0P1eQ:X02`1dPjX0M8FZ07>6
Z01eQjH0N8RX07V8Z01jRJP0O8bX07j=Y`1oSJH0PHjV0080PXfW00/0Q8nZ08B>[023SZh0Phn`08:>
/023T;40QI6a08FB/@25TK40R92`08VB/00208VC/00<08^E/02>V;<0SINc08bG]P2>UkX0S9Jh08ZD
]@2:Tk@0SIJg08nI^@2>VKT0SIVg0P2>VK@02`2AW;<0TYbc09>K/`2EW;@0UYfd09JL/P2FWK<0Uife
09VN]P2FW;H0UYbg0080V:2i00/0VJ2j09NN^P2IW[/0VZ2l09VP^P2IX;T0VYni09bP^`2KW[d0W9nm
09fP_P0309bQ_`0:09bR_`2NY;d0WJ>i09^Q]`2MY;P0WjJk09jT^@2OXkT0X:Bk0:2S_P80Wj?000X0
WjG10:6V`@2QYL00XJG009nS`02OY<40WZC109fS`02MY;h0W:>n0P2MYL0209fV_P0;09nV^`2PY;T0
WZ>i09fR^`2LX[`0Vj6l09bT_02OY[h0WjFm09jU^P2NY;L00P2NXkH02`2OXkH0X:Fg09jU]`2OYKT0
WZBj09fS^@2MXkP0W:6e09bP/`2KWk<0Vj2e0080WJ:f00@0Vj2d09VP/`2GW[80Uijb0P2HW[801P2G
W;<0UIbd09>K/`2BVk00TYZ_09>K[P80TiZ_00/0T9J/08nEZ`2>U:T0SYFY08bDZ@2;TjT0RI2U08VC
Y028TZ40QY6O08FAX00208B@X@0;08>>XP23SJ80PhfV082;Y@1kR:40NhVP07^:WP1iQiX0N8JH07J3
UP1fPYH00P1fPiH01P1ePI<0MH:@07B2S@1bPXT0Kh2106YlN1[ooooo00<0oh000000o`000?l0ZP00
0?l?ooooo`003Oooool01P1TKHX0JWNF071oX@1_Oj<0LX6U07:1YP80LX2U00/0MHBX07J5Z01fQjP0
MXJX07R7Z01jRJL0NhZV07^;Y@1mSJD0OX^U086>Y`02082<Y`0408:=Z@24SJd0PXf_086>/@80PHjb
00D0PHn`08:A/023T[00QI:_08NB/00208VB/@0608ZC/P2:U;<0RYBd08^F]P2=U[L0SIJf0P2;U[H0
102>VKL0SiZe08fF/P2<U[4208jG/P0;092J/`2AVk@0TI^c09:L/P2AV[40Ti^a09JN/P2FW;<0UY^d
09JK]@2FW;H00`2GWKL02P2GW[P0VZ2k09ZQ_@2JX;X0VZ6j09^P^@2LX;/0W:2n09bQ_P2JX;d209ZQ
_00409ZQ_@2KX[d0VZ2i09^R^080W:Bh00D0WJ>f09nT]`2OY;P0Wj:h09fP^00209bP^00609jR^`2P
YKd0X:Bm0:2T_`2OX/00Wj;10P2OXl40102OXkl0WZ>m09nT_P2NYK`209nU^0050:2V^02NXkH0W:6f
09jR^@2NYK`00P2KX[/0102MXk/0Wj>k09jR^@2MWkH209jQ^00509jP]`2OXKL0Wj:g09jR]`2KX[H0
0P2IX;H0102KXKH0V9jb09VP/P2IWk@209RO]@0<09NO]02FW[@0UYjc09NO/@2GWZh0Uib]09NL/02E
Vk40TYZ`096I[`2?UZ`0T9N/0P2BVJh02`2@UJX0SI>X08fDZ02;TJH0Ri:V08ZAYP27Sj<0Qi6R08JB
W`25T9/0QI6M0080PXfL00/0PXfM08:=W`22Rj00P8RR07f8XP1lQil0OHZM07^8VP1jQIP0Mh:E07B0
T@0207F1T`0607J2U01dP940L7j=06inR@1]OX40J7]g6_ooool00`3oP000003o0000o`2Z0000o`oo
oooo000=ooooo`0606=^RP1/NIH0LH2P07>2Y@1cPJD0LH2T0P1bPJ@02`1eQ:L0N8NY07V9Z`1hRJX0
MXRW07N9Y01iRZ<0NX^R07f=Y01oS:H0P8bY0080OhZY00/0OhZ[086;[022SJd0PHf^086?/020SZl0
Ohj/07n@Z`20TJ/0Pi:[08BAZ`0208FA[P0;08NB/@28U;80RIFb08ZE/@2:Tjh0S9Fb08fG]@2>VKH0
SIVf08jJ/`2=VK400`2=Uk40202?V;80SiVb08jI/@2>V[40SYRa096J/P2DW;@0UIbf0P2DVkL03P2E
VkL0Uibi09NL^@2GW;T0UYZh09NL^P2IWk/0VJ2j09VQ^@2JX;L0VYng09ZP^P2JXK`0VJ6k0P2GWkP0
2`2GX;L0VZ:g09RQ]02IXk@0V:>c09RS/P2HX;00Vj:b09fS]P2NY;L0WZ>g0080WZ>f00`0WjBg09nS
^@2PY;/0X:>l0:2S_`2NXkl0WjC009jR`02MXKh0WJ:n09fS_02JX[L209^R]00;09^S]@2LX[D0W::f
09^Q]P2KX[/0Vj>k09bS^P2KX;L0W:6e09fQ]P2LWkH00P2LW[H02`2MX;H0W9ne09fQ]P2MXkL0Vj:g
09RN]02FW;<0UYjd09NO/P2GWk40Uijc0080UYne00`0UIfe09>K/`2CW;80U9fb09BM/02CVjh0Ti^_
096I/02?Ujh0SYN/08bEZ@2=UZT208nFZ@0;08fDY`2<TZ@0RY2T08R@X`26Sj40Qi2R08J?X@25Sj40
Q96Q08>AW@20SiX00P1oSYT02`20SY/0P8fM082;WP20RZ00OHRO07b8WP1lR9d0NXJH07V3U01hPY<0
MH2A0080LgnB00H0Lh6E071oT@1^OX`0K7f506YlO`1WNWLJooooo`030?n000000?l0003o0:X0003o
3oooool000gooooo00H0HFf806YgU01aOIh0LWjS075nX`1aOj<207B1XP0;07N5Y01hQjL0NHJY07R7
Z@1gRJH0MHRT07N9Y@1hR:<0Nh^S07n<YP1oRjT00P1oRj/02`1nRjX0OhZW086>Y`23T:X0Pi2[086?
[020Sj`0Oi2Y082@Z022T:H0Pi2X0080Q92/00`0QI2`08NC/P2;U[40RiF^08fE[P2?U[40SiNe08nH
^02>UkL0SYRf08bF/@2>Uk0208jE[P0;08nF[`2@Uk00SiN_08jH[`2>Ujl0TIR`09:I/`2CVKD0TiRg
09:I^@2CV[T00P2EW;P02`2EV[L0U9Vh09JK^@2FW;P0UYjg09JN]02HX;@0VZ2e09ZO]P2IX;T0VJ6j
0080Uinf00H0UYjc09RP/@2IX;00VZ2a09RP/@2HXK8209RQ/@0309VQ/P2KXkH0WJBi0080W:>f00`0
W:>c09bR/P2MX[<0Wj:e09nS^02NXkT0WZBj09fR^P2KWkT0VYni09ZP^P2GW[L209RP]P0;09ZQ]P2J
X[H0W::h09bQ^@2IWkT0VZ6i09ZR^02JXK@0VZ2c09fQ]02MXKH00P2LWkD02`2JWK<0V9fa09VM/@2M
XK<0Vj2b09RM/P2EVk<0UYfc09FN[`2EW:d0UI^_0080TiZa00`0U9bc09>L/P2BW;40TY^_096I[P2@
V:h0SiN_08bF[P2:TjP0RYBU08^EX`2=UZ@308bDX`0:08^BXP29T:40RI6P08N@W`28T9l0RI2P08N?
X@24Sj40P8fM07n=V@80OH^G00/0OhfI07n;VP20RYd0P8RN07j7WP1lQZ00NXFN07V4V@1hPY@0N82D
07MoUP0207AmUP06079nUP1^OI40K7j;06]lP`1YO7d0J7ag6_ooool00`3oP000003o0000o`2Z0000
o`oooooo000=ooooo`06061[Q@1YMY80KgbL079nX@1`O:80LGjS0P1dPJ802`1cPJ80MH>U07R6Z01g
QJH0MhNV07R9YP1hRZH0NHVU07Z:Y@1kRZ<0OHZU0080OX^W00/0OX^X07j;Y01oRj80PHfT08:=YP23
SJP0PXnY086?Z020SjL0Pi:X08BBZ00208BBZP0;08FB[026TJ`0RI>/08VCZP2;U:X0SIB/08nE/02>
U;80SiFc08jE/P2=Tjl00`2?UZl02@2?UJh0T9J]096H[`2BVJl0T9N]096F[P2BUjl0TYNb09>H]`02
096H^@80TiVg00/0TYZe09:I]P2BV;D0U9Zf09JM]P2FWK@0UYbb09RL/`2HW;D0UIVf09FK]P0209JM
]00;09NN/@2GWJh0VIf_09VM[`2HW[00Uij_09JN[P2GWZh0UYj^09NN/P2FWK@00P2FW[D0302FX;80
V::`09^R/02MX[40WZ:d09fR]@2NX[L0W:6f09^P]@2IWk@0V9ne09JL]080UIfc00/0UYjd09NM]02I
WKD0VYng09RN]@2HW[L0V9nf09JN/`2GW[80VIna09ZO/`0209bQ]00;09ZN/`2IWK80VIb`09ZM/P2I
W;40VIfc09NM]@2FWK80UI^^09:IZ`2DVZd00P2CVJd0302BVK00TiZ`09:K[`2AVZd0SiJZ08jFZP2>
UZ`0RiB[08VBY@2:U:<0SIBR08jDX080SiBP00/0S9:Q08^BX02;TZ40RY6O08R@W@25SIX0QXfL08V?
X025SJ00P8ZM07n:V`0207f9V00;07n:V01oR9T0P8RJ0868W01oQId0O8:M07V0W01iPI/0N7nH07Mm
UP1fO9L00P1eO9L01P1bOID0KWb@06YkR01ZO8<0JGan06QkN1[ooooo00<0oh000000o`000?l0ZP00
0?l?ooooo`003Oooool01P1SKXT0JgRE071oW@1aP:00LWnQ075nXP80Lh2T00/0LGjR07B1Y@1fQJL0
MH>V07J5Y`1hR:P0NXZY07^:Z@1jRJT0Nh^W07n?Z00207n=Y`0;07n;YP20S:H0PHbU086<Y@21S:L0
P8bW086=Y`20SJL0PHnX08:@Z023TJT00P24TZX01@26Tj`0Qi>/08VDZ`29TjT0S9F[0080SIFZ00D0
S9>[08fD[@2=UJh0SYJ`08fD[`0208jE/@0308fE[`2>Ujh0SiR^0080T9J^00H0TIN`096G/`2AUk@0
TYNg09:I^@2CV[X209>J^@0709:J^@2AV;P0TIRf096J]@2EWKD0UYfd09JL/P0209NL/`0?09BJ]02E
VkL0UIbf09FL]P2FW[D0Uife09RM]@2IWK<0VIna09RO[`2GWjh0UIb/09BL[02DWJl0U9bb0080UYnd
00`0UInc09RQ/`2IX;80VZ2c09bO/`2LX;H0WJ2g09bP^02LXkX0Vj:i09^Q]`2KX;H209^Q]@0;09VP
]@2GWK<0Uibc09NM]02GW[D0Uijf09RO]`2FWKH0Uije09ZO]@2HWK@00P2JWkD02`2IWK@0VYfc09bM
/`2KVk@0Vi^e09VK]P2GW;@0UYb^09FL[@2CVZ/0Ti^[0080Ti^/00`0TYV/092G[02@V:`0SiN/08nH
[02=UjT0S9JY08^FZ@2;U:D0S9>S08fCXP2<TIl208fBX@0;08ZAX@27Sih0Qi:M08RAW027Si/0QHbL
08B;W@25S9l0QXfP08::W`22RYh00P20R9d02`1oQi`0OhFK0824W@20Pid0OH:M07^1W01jP9d0NH2L
07MnV@1eOIT0M7fI0080M7jH00H0LWfC06aiR`1ZN8P0JGZ506IhO`1TMgTJooooo`030?n000000?l0
003o0:X0003o3oooool000gooooo00H0Hff806UgU01]O9/0L7nO079oW`1bOj42079oXP0:075nXP1c
P:@0M86S07J3Y01kRJP0NhVY07^:Z@1jRJP0NXVY07b:Z@<0Ohf[00D0OXZZ07n;ZP21S:T0PXfZ082<
Z@02086>ZP0408:>Z@23SjT0Pi2Z08>?Z@80QI6[00`0QY:[08JAZ`28Tj`0RYF]08VDZP2:UJT0RYBY
08ZCZP2:TZ/0RY6/08^C[P2=U;0208bD[`0;08bC[@2=U:h0SI>_08jC[P2=U:h0SiF`096G/`2@U[@0
T9Fc096F]@2BV;L00P2BVKT02`2AV;T0TIVi09:I^02BV[L0U9bf09JM]02EW;<0TiZ`09FK/@2DVk80
U9bd0080UIbf00/0UYbh09JK]P2FVk@0Uibc09NM/@2FW;00U9^]09BK[02DWJh0TY^_09BL/P0209RP
]P0<09RP]`2GWkL0Uije09VO]@2JWkD0VIje09ZN]`2KWkT0Vj2k09^Q^@2MX[P0WJ6d0`2KWk400`2J
W[<0VIje09VN]@0209NM]@0409RN^02HWKP0V9ff09VM]`<0VIbg00/0V9Ze09RJ/`2HV[80VYbb09VJ
/`2GV[@0UIV`09>JZ`2DVjd0Ti^_096I[@03092I[080SiN[00T0SIFZ08^CZ02=UJX0SIJZ08fEZ@2=
UJL0SI:T08^AX`2:Sj800P29SZ402`28Sj40QHjO08F?W024SYX0QHjL08F=W@23Rid0PXZM08>:W`21
RIh0P8RN0080P8NN00/0OXBM07f3W@1mPYh0OH:N07^0WP1iOi`0MgjK07EmV@1cO9D0L7ZA071kTP02
079lTP06075kS`1`NX`0K7N906YfQ`1VMX80HgEk6_ooool00`3oP000003o0000o`2Z0000o`oooooo
000=ooooo`0606=^Q`1XMI80K7^J06mmX01aOj<0LWjS0P1`OJ402`1aOZ80M86T07B1XP1fPj80NHJV
07Z8Z01iRJH0NHVT07^:Y@1nS:L0OhbY0080OXf[00X0OH^]07j<[01mRZP0P8bY086=ZP23Sj/0Phj[
08:>Z`23SZ/0Pi2/0`24Sj/02026TJh0QY:^08JA[@25T:/0QY>[08RF[028U:`0RiB]0P2:Tj`03`2;
U:l0Ri>`08^C[@2;Tjd0S9B^08nE/02?U;40T9Fb08nE/@2AUjl0TYR`09>H/@2CUk40TiRc09:H]@02
09:G]P0;096F]P2BV;H0TiZf09BK]@2FWKH0UIbe09>I]02BV;80U9Zb09BK/P2EVk@00P2EVkD02`2E
VkL0UY^d09VM/P2IW;40V9^`09NK/02FW;40U9^_09FL/02CVjl0U9^`0080UYfc00@0Uije09NN]P2H
W[L0VIjf0P2IWKD01P2IWKH0VI^f09RL]@2HWK<0V9fa09VM/080VIf_00L0W9nc09bO]P2KW[L0VYff
09RL]P2IWKH0VYjg0080V9bd00l0V9^e09RJ]P2IW;@0VIbd09RL/`2GVk80Ui^a09RK/@2FV[40U9R`
09:I[P2BV:`0TiR^09>H/02AUk000P2>UZh02P2>Ujd0SYN[08jFZP2?UJT0SI>Z08jD[@2<TZX0S96X
08bBYP2<TJH208V>Y080R8jT00/0R8fT08J=X`25S:80PXZP08>:X024RZ40Q8RP08>7X@22R:80P8JR
07j4X00207b3W@0;07f2W@1lP9/0NgnK07YmV`1iOi/0N7nI07ElUP1dNi@0LW^B071iSP1_NHd00P1`
N8h01P1_Mhh0KWN=06YeR`1YM8L0IWB1065bNQ[ooooo00<0oh000000o`000?l0Y`000?l00`3oP000
003o0000o`0?ooooo`003Oooool01P1SKXL0J7FB06akVP1_OJ00LGnS079nX`80L7fQ00/0LGjR07B1
Y01dPJ80MX>R07V6YP1jR:P0NHVV07V9Y01kRZD0OXbW07n<Z@0207j=Z`0:07f;[@1nS:`0OHZX082<
Z@21SJX0Phn[08>>Z`22SZ/0Phj[08>@[0<0Q8n[00P0QY6^08JB[P26TJd0QI2[08JCZ`28UZ`0R9B/
08^D[@80RY>/00l0RiB_08^C/02;Tjd0Ri>]08bD[P2?UK00SiBa092E/P2?UK40TIN_09:H/02CV;40
TiNa09>H/`2BV;D00P2BUkH02`2AU[H0TYRf09>J]P2DVkD0UYff09FL]@2CVK@0TYRb09BJ/P2DVk80
UI^d0080UI^e00/0UI^g09JK]02IWK80VIba09RK/02GVk00UYba09BK[`2EW;00Ti^_09BK/00209JM
/`0409NN]@2GW[H0V9jg09VN]P80VIfe00H0VIff09VK]P2HW;D0V9fc09RM/@2IWK0209VM[`0709bO
/`2LWkH0Vijg09ZM]P2HW;H0VIff09ZN]`0209RL]00?09RK]@2HV[H0VIbd09VL]02HW;<0Ui^b09NK
/@2HVk40UYZa09BH/02BVJh0TYR/09>H[P2CV;00TIN`0080SYJ^00X0SYN]08jGZ`2>UZX0SiFY08fC
ZP2>U:d0S9:Z08bAZ02<TZH0S96V0P29SZ@208R>Y00;08R=Y026SJ<0QHbR08::X023RZ00Q8ZQ08B8
X023Qj40PXRR0826XP1nQ:000P1lPid02`1mPYd0O82K07]oV`1jOI/0NGnK07QoV@1eO9H0M7^D079k
TP1`NHh0KgV=0080L7R>00H0KgN>06igS@1ZMH/0JGB706IdP@1QLWXJooooo`030?n000000?l0003o
0:L0003o00<0oh000000o`000?l03oooool000gooooo00H0Hfn906UeTP1]Ni/0KgbP075mX`1bOJ@2
075kXP0;075mXP1eP:<0Mh:S07N1X@1iQJ@0N8FV07R7YP1jRJD0NXZU07b<YP1mS:L00P1mS:T0201m
S:/0OXf/07n=Z@1oSZH0P8jT08:@Y@22SjL0PhjZ0P24SZ/03`24T:X0PhjX08>>Z024SjT0QY2/08F?
ZP23SZP0Q96Z08JCZ`29UJ`0S9F^08bE[`2;U:l0S9Jb08ZC/00208^D/00;08^E[P2=UJh0SYB_08nF
/@2?Uk40TYZ`09>K[`2CVZh0TYN]09>H/02AUk800P2BV;@02`2AV;@0TINb09:I/P2BVK80TiVa09>I
/P2AU[80TIJc092F/`2AV;<0U9Ze0080TiZf00/0U9Zg09FJ]02GW;<0UY^b09RL/`2GW;<0U9Zb09>J
/02BVjh0TYb]09BM[P0209BL[`0<09FM/`2EW;@0UIbd09NM]@2FVk<0UIZ`09NJ/@2IVk@0V9^d09NL
/P2FVjl0Uib_0P2HWK802`2JWK<0VIbd09ZL]P2HVkD0UY^c09NL/P2HWK80V9b_09NL[`2GVk40UIVa
0080UIV`00/0UIZ`09JK/02EV[40UYZb09BI/P2BUk40TIN`096F[@2@U:/0TIF]08nE[`0208bD[P0<
08^DZ`2:TjT0RiBX08^CYP2=TjP0SI>/08bAZ`2;TZX0QXnU08R@X`2:Sj<0R8fS0P29S:D02`28SJL0
QhbW08F<YP22RZ40P8VO08:9W@22RIl0PXNQ0866X@1oQZ<0O8BQ0080Mh2K00/0NH6I07Z1U`1jOiT0
NGjI07MmV@1fOiX0LWbG071jU01`NY<0KgVB06miS`0206efSP0606]dSP1YLX`0IG6:06EbQ`1TLh40
H75h6_ooool00`3oP000003o0000o`2U0000o`<0oh000P000?l?ooooo`003Oooool01P1SKXH0Ig>?
06ekVP1aOZ40LgjS07AmX`80M7^R00P0LgZQ07MnXP1hP:80N82R07^5YP1iQZD0NHJT07^9Y@<0O8^V
0P1lS:D02`1mSJD0OhjW07n<Y@1nS:80O8bP086@X@22Sj40QHnS08J>Y025SJD0QI2X0080QI2Y00`0
QXnY08N@Z@26SjT0QXnZ08R@[@29TJl0R92^08bC[`2=U;80S9Fb08ZC/02;Tk4208bD/@0;08bE/P2;
U:l0RiF_08^E[`2;UZd0SYR]092I[@2@Uj`0T9J[096G[@2AUjl00P2BUk002`2AV:l0TIN]09>I[`2B
Uk00TIJ_092E[`2@UK00T9Fa08nD/@2?UK40T9Nc0080T9Nd00/0TIRc09:H/@2BVK00TiV_09>H[`2E
V[40U9Za09:H[`2CVZd0Tib/09BM[00209BL[P0<09BL/@2CV[80U9^c09JK/`2EV[40UYV^09JI[`2I
W;@0UiZb09BJ/02EVjl0U9Z[0P2EVZ`02`2GVjl0UiZ`09NJ]02EV;<0TiR`09BJ[`2DVJ/0U9ZZ09FK
ZP2DVJ/0TiN]0080TYJ^00/0TYJ_09>F/02CUk40TYNb096F/P2@U;40TIF_096E[P2AUJd0T9B/08jD
Z`0208bCZ`0<08^CZP2:TjT0RY:X08V@Y@28SjH0RY6X08V@Y`2:TJL0R96T08R@X@29Sih0R8bN0P29
SJ402`27Rj<0QHVT08:9Y01oR9h0OHRL07f6VP1nQIX0OXFK07f3W01mQIl0Nh>N0080N8:K00/0Mh6H
07EnU@1fO9H0MgbH07EkV01cNYT0L7VH06ihU@1]MI80Jg>?06acS`0206U`SP0606M_S@1VKX`0Hfn9
069_Q`1QL880GVif6_ooool20?n00:<0003o203oP00?ooooo`003Oooool01P1VKX@0J76=06afUP1`
NI/0LgbM07ElW`80MGVQ00/0MGRQ07QlX`1gOZ80N8:Q07Z5XP1jQJ40NXFP07^7X01lR:40OHZT07j<
YP02082=Y@0;07j<XP1nRj80OHVQ07j:XP1mRj80P8jS08:?XP24Sj00Q8fQ08F=Y@27SZT00P29T:d0
3029TJh0RI:/08RAZP28Sj/0RHj]08fA/P2<T;80RXj`08bA/02;TZ`0R92Y08^AZ`80S9:]00/0Ri6_
08N>[025SZX0Q92Y08JBZ@28TZH0SIFX08jDZ@2?UJX0SYFX08jFZ@0208nGZP80T9NY00T0TINY09:F
ZP2BUj`0T9J/096G[@2BVJd0TIR/09:H[@2@UJd00P2?UZl02`2?UZh0SiJ[092FZP2@UJP0T9BW09:F
Z@2CV:/0TiV/09>IZP2BVJL0Ti^X0080TiZZ00`0U9V/09>G[@2DUjh0UIV_09BG[P2EUjh0UYR^09JI
/02FV:l0U9R]09BJZP2CVJH209>GYP0;09JI[02GVJl0UIR_09FI[`2EV:d0U9R[09BGZ@2DV:T0U9VY
09BGZ02BU:P00P2ATj/02`2BU:l0U9F`09>E/02BUK00TiJ`096C[P2BU:h0TI>]096C[02@Tj/0SI:X
0080S9:V00@0S9>Y08^BZ028SZ@0RHnS0`28SZ<01@28Sj40RY6R08V?X027SIh0R8bM0080RHfO00/0
R8ZO08F8XP23QZ<0PHJR07j5WP1lPiT0NX:F07b3UP1mPYL0O8>H07b1U`0207UoU`0;07MnV01eO9D0
MG^E07IlUP1cNID0LGNE06mfU@1^MYD0K7BB06acTP1[Li800P1YLI001P1UKHX0IFf906E^R01RK8@0
Gf]o05e/Ma[ooooo0P3oP02S0000o`P0oh003oooool000gooooo00H0JFf106ebS01cNID0MGbJ07Mm
W01gNY/207IiWP0;07MjX@1jOJ@0Nh2T07b4X@1lQYl0Nh>M07b4W`1lQZ00O8JO07b9XP1oS:D00P21
SZ@02`20SJ00P8^P08:<Y022RjD0P8ZU082<YP23SjD0QY2S08N?XP27SJD0RXjZ0080Rhn^00`0RHn^
08V@[029SjX0RHjZ08^?[@2>T[00SI6a08Z>[P29Sj`0RY6[08bBZ@2;TJL208^@Y`0;08V>Y`28SJP0
QH^V08>:Y022Rj00PXRL08>7W@27RJ80R8ZR08N;X@25Rj000P26SZ002`28TIl0RI6N08bCX@2>UJ@0
TINX08jEYP2?UjL0TIZY09:JZ@2CVjX0TiZ[0080TiV^00/0T9J[08nFZ02AV:P0TYNU09>GY@2DV:L0
UY^[09BIZP2CUZL0U9RV09FIY`0209BHZ00<09JH[02DUj`0U9R^09>G[@2BUZ`0U9N]09JH[P2GVJl0
V9V_09FG[@2DUjX0UIVY0P2DUjL01`2FV:P0UYNY09FFZP2EUj`0UIR/09BGZP2DUZP00P2EUjT03`2D
UjX0TI>Y092BZ@2@TZT0TYBZ096BZP2@TZX0TiF]09BE[P2ATZ`0TYB]09:CZ`2@TZP0Si>V08nBY002
08nAY00608b?X`2:Sj80RHnQ08^@X02<TJ40RHjQ0`27S:400`26Rj00QHZN08J:W00208V<W@0;08R9
W026QYl0QHFQ0865XP1nPil0Nh>H07b4UP1mPiD0O86D07j2U`1lP9L00P1kOYL02`1iOIL0N7fG07Ql
U@1gNY80MGVB07=gT`1aMYD0KG>E06U`TP1ZLY40JgB>0080JW>;00H0Ig2806M^Q`1WK8H0IFZ3065X
O@1MIgDJooooo`030?n000000?l0003o09l0003o0P3oP0000`000?l0oh000?n000060?n000oooooo
000=ooooo`0606U/P01cMXd0MgfG07QnVP1iOIX0NGbJ0P1iNi/02`1kO9h0O7nQ07b0XP1nQ:00OhFL
07n4VP1oQI`0PXRQ0828X@1oRJ80OhfQ0080PHjP00/0PXjO08>=WP24SJ40Q8bS0868X`20RJ80PhbQ
08J?X@28Sj40RHjS08Z>Z00208^>Z`0<08Z>Z`29SZ/0RHjY08V>Z02:SjP0SI6[08fA[@2<T:d0RY2Z
08bCZ02>U:H0SY>U0P2=TJ<02`2;Sj@0RXjW08V=Y`26S:@0QH^P08B9W025QY/0QHBL08>1W@21PI`0
OGnH0080OH6F00/0OX>C07n4TP21QI@0PhNF08B9V022RYP0Q8fK08NAWP29U:00SIJQ08nFXP02092H
Y@0;092GYP2@V:H0TIVT09:JX`2BVJ<0TiRV09FHZ02DVjX0TYRW09:IYP2DVZD00P2DV:@01P2EUjD0
UIRX09BGZ`2BV:/0TIJY09:GZP80UIR[00@0UIJZ09>DZP2BU:T0TYFW0P2CUZL02`2EUjP0UIJV09BD
YP2FUZX0TiFX09:EY`2BUJH0U9NX09FGZ02FUj/0TiJ[0080T9:W00/0T9>U096DY`2BU:H0TiBV09>B
YP2BTZP0Ti>Y096CYP2ATj80T9>Q08j@X00208b>WP0<08b?W`29SYh0RHnN08Z?W02<TI`0S92L08^=
WP2:Rj00QXRO08J9W`26RYd0Qh^M0P28Ri/02`27R9X0QhNL08B3W020PIh0OX:M07^1U`1jPI<0Nh6C
07^0TP1mP9D0OX2H0080O7jG00/0N7^C07QlTP1gNi00N7V>07MiS`1eMXl0LgB@071bT01[L900J6j<
06QaR00206QaQ@0606Q^P`1YKH80IFQo06AWO`1TJ7`0GF9a6_ooool00`3oP000003o0000o`2P0000
o`X0oh003oooool000gooooo00H0JVf007=hS01fO9<0Mg^E07QjU01iNiH207YlV00;07]mVP1kOY`0
OH6M07n4WP1oPiX0OhBI0825W022RJ00PHVP086:X020S9l00P22SId00`24SY`0PXbL08F=WP0208B<
X@0608B;X@27SZ00RI2P08V?XP29Sj@0RXfV0P2;SJL208Z>Z00:08V>Y`28SJH0RXnV08jBY`2<T:L0
S96[08bAZ@2=U:P0SYBT08nDX`80SY6R00/0SI2S08jAYP2=TZH0SY:V08bAY02<Sj80RhbP08V9X026
Pih0Q8:M0861V@0207ioT`0;07eoS`1nP8d0OWn=07amSP1kOHl0N7b=07MmSP1hOhl0Mgn>07j6T@25
RiD00P29SiT02`2=Tid0SYNN096JWP2AVYd0T9RN096HX`2@UZ@0TYVU092HX`2@VJ<0TYVR0080TiVP
00`0U9RP09JIY02DUJD0TIBT09:FY@2CUjL0U9NX09JHZ02DUJL0Ti>W096CY@2@U:<209:EY00;09:F
X`2ATj40TY>S09FEY`2BU:H0TYJV09>GYP2DV:H0TiFV09BEZ@2DUj/00P2@TjH02`2?TjD0TiJU09>E
X`2CTj80TY6Q09>CX`2ATZ80T9:O092CW02?TY/0SI6K0080RhjJ00`0Ri2L08R>W029Si/0QhjG08V?
UP2;T9L0RXjG08V:V`27R9d0QXJM08J7V`29Ri`208N9V00;08N8U`28QiT0Ph:G07moV01oPYX0OH6G
07Z0T`1jP940O82A07aoTP1nP9@00P1lOY802`1gNHd0MgZ>07MiS@1fMX/0MGB:07EeS01bLX/0L76<
06eaS01XK8L0IVj40080Ifn200H0J6j006U/O@1TIW/0I6Ij06=WM`1OIG4Joooooj<0003o2P3oP00?
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {299, 0}} -> {-0.0508884, -0.0375078, \
0.00526762, 0.00526762}, {{9.625, 190.438}, {291.875, 156.25}} -> {-12.9439, \
-9.62807, 0.929149, 0.929149}, {{208.5, 389.312}, {291.875, 156.25}} -> \
{-197.728, -9.62807, 0.929149, 0.929149}, {{9.625, 190.438}, {142.688, \
7.0625}} -> {-12.9439, -148.245, 0.929149, 0.929149}, {{208.5, 389.312}, \
{142.688, 7.0625}} -> {-197.728, -148.245, 0.929149, 0.929149}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{tst, crg2}, {crb2, cgb2}}], \ 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
%%ImageSize: 400 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0178571 0.47619 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0178571 0.477324 0.357993 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FFFF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0178571 0.97619 0.357993 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FFFF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.392007 0.477324 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
2F3A1A2D3A1A2A391C2A38222A37292A382C2B382D2D39312C38322E3736303938303939
313A3A313B38303B38313D39333D39333D3A323C39333C3A333D3B333D39323C3A333E3C
343E3D36413E35403D35423E35413C36443B36433A37443C38463E39473F3B49413C4B42
3D4B423D4B443E4D463F4E47404F48404E48404E4941504A41504941504841504944534A
44534944544A44554C46574D44554B44544C46564E47574E47584E49594E4A5A4F4B5B4F
4B5C504C5D514D5E514C5C4E4C5D4F4D5D4F4B5D4F4D5E514D5E514D5E514B5C4F4B5C4E
4A5A4D4A5A4B4B5D4842553A15200E1018071016060B1003090D02080C02080C02070700
070600070600030300020300010200000200030400030400030300030300030200050203
0502060604060302050202040404020606010605010909030B0B050E0E080F110912130B
14150D15160D15170D14160D13130D10100A0E0D090B0B080C0C080C0C08090A06070803
060803060701050701030500030300020200010200020300030300050601070802050701
0405000606020A0A040F10080F11090F100A10110B0F110B0F100B0D100A0F130B0B0E09
01020001030002030001030000020001010001020000030000030100020500020900010D
01001002000C050407000100
404D45556756425147364041323842363B4A383F4A3B414D393E4D3C41533E44553E4656
414958434C5A45505C47525D48525D48515C48525C49525E49535F47525F47525F46525F
4853604954604954604B56624B55604E575F4C545D4E57604F59624D58624F5A63515B63
515B64515A67525C69545D6B555F6C555D6A565F6C58616E59636E5A646C5B656B5C666C
5D676E5E69715E6A725E6A705F6B705F6B72606D74616F74637175677477687579687578
66757B66757D68787D68797A697A796C7B7A6C7B7B6C7B7D6C7B7E6D7C7E6E7C7D6E7D7B
707E7B707F78707F776E7F725A685C59685A596759576357556154556054515C51363A38
3337353034322C312C292E28292D28282C29282B29272929262727252726242725131117
0F0C130E0D11090A0D07090A070906080A04090C050A0D04090C030A0D04090D060B0D06
0C0E060C0D060F11090F120A0F130B0F130B0F120C0E110D0E110C0E100A0C0E08090C05
090C03090C010B10020D11040E11060E12080E130A0D110A0D10090E10090E0F080C0E07
090B040A0B050B0E050E11080E11080D10070B0E06090C04080B040A0D05090C04060801
060902060902060803060804090C07080B0603050101050103050A030414020316040418
0807170C080B0B0803060701
32384A353C4E343A4F353950353951353952373C52383D52383D53393E55383D56394057
3B41583940573A40573B42583E455B3F465C41495C424A5C424B5D41495D40485E40495E
414B60444C60434B60424A5F454C5F464B5D464B5E474D624A4F654A4F664A50654B5064
4C51664C51684D526A4C52694D536B4D526B4E53694F546950556A505669525969535A6A
545B6C555C6F565D70565D6F575F6F585F705A62725B65735B65735F6876606978606A78
5F6A7A5E697B616C7A626E79646F7A656F7A66707B66717C66717C66727C68747D69747D
6B767D6C777B6D797B6E7C7C707E7E71807F71807D74827D75827E778280768280737F7F
73807F72807D72817A738178748077747F77758079747F7A737E7A707C76707F74393D40
1B1B211B1C1F1114140D110E0A0D090A0C04090C03090C02080B01060A00030600030400
040500040500040400050601050701040501060703070803060502060502070603060703
0608010609010F1308151A0B181D0E1A20101D23131C22131A20121C1F121C1E13181A10
14150C1111080E0F070C0D060B0D050A0B04070A02060900060800040600030400020400
020400030500030500050702090C060A0D06080B020305000304020505040506040D0F06
14160B191A0D16170B11120A
32384B33384F333853333952333952353B54353B53363C54363C53383E55383F56383E56
3B4358383F543940553A42553D45583E465B40485B414A5D424A5F424A5E43495E43495F
434A5F444B60444C61454C62464D62474D62484C63484D64484D654A4F664C51674E5166
4D51654F54674F54684E53674C54674E556950566A505669505669525A6A515A69535A69
545B6A565D6C565D6E575E6F575F6F5960705A62725C65755D65745F68755F6876616A78
616B79626C7A626C79646E7A676F7A68707B67707B66717B66707969737B6A747D69747E
6A757E6B787E6D797D6D7B7C6E7C7C6F7D7E707D7C717F7C727F7E727E7E727E7E727F7F
72807F74827E75827C75827C75817B75807B75807B77817E757F7E747F7B73827A464D50
20202920222517191A1012100E110A0C0E05080C02080C03090C03090D02050801030500
0304000305000403000504000505000908000C0B030B0A03080602060401080702070802
0607010508010D110614180A181C0D1C20111E23141F23151E22131E22111D20101A1C0E
16170B12130A0D0F080B0C05090B05090C05090C04090C02060A01040700040500030500
040700050801040601040600070A01070A010509000204000203000303000403000A0B00
11110514140913130911120B
353A4C353950343953353A53353B51363C52383D53393E55393E563A4056394055393F56
3B42563B41533A41543D44553F45573F465A40485B40475D42495E434A5E444A5F444860
434861434961444B62444B62464C63454C64474E65474D64484E63494E634B4F644D5064
4E52654F54664E53664E54664D54664E56674F556750556851566A52586B51596A525A6A
535B6A555C6B575E6D585E70585E715961725A63725C64735D65735F6874606974626B76
626C77626C78636D79667079666F79676F7A68707B67717B6670786871776A74786A7479
6B767B6B777D6C787D6D797C6F7B7C737E7E747F8075807F73807D73807C73807E73817F
72817E74817D75827D74827B77837D78837E78837F75807E757F7D747F7C73817A50585A
201F2C1E2026191B1D1314140E0F0D0C0D09090B06070904070A03080C02050900030600
0204000203000404000505000405000808000A09010A0903080704050602090A050A0B03
0A0D02090C010A0C020E10051517091A1C0C1E20111F22132024121F220F1E220F1C1F0E
17180B12150B0E120A0B0E07090B05090C05080B03090C03090C04090D02080A00060900
060900070901060801050700080B00070A00030700010300030300040200040100070600
0D0D0411100612130814150C
343A4B34384C353A50363A51373B50393D503C3F533C3F563B3F57393E56393F543B4054
3D42543E42543F435442465742455A42465D444A60434A60434A60434A60434A60434862
444861444A61454B62444B62464C63474D65484E66454D65474E64484D624A4E624C5064
4E52664E53664D53664F55654F556650556750556852576953586A52586A52596A545C6C
545B6C555C6C585E6F5860725960725961735B63735C64735D66745E68745F6973616B74
616C74626D76646F7864707865717966727B67727A68737A68737A6973786973766B7477
6C76786C77796C78796F7A78707B79727E7D737E7D74807E74817D74817D74837D72817C
72827B72817B72817B74847C77847D78837E78827E76807D76817B7580797480795F6866
2626331E20281C2022181B1A1114120C0F0D0A0C09090C05080B01070A00050800040700
040700030500030400030400040600080901090A020A0C050A0C06090C06090D060B0D03
0D12030D12020B0D010A0C01101406161A091B1F0E1E220F1F25121E23111D21101C1F10
1A1D0F161B1012170C0F13090D0F070B0E050B0E040B0E040A0E020B10020C1101090D01
070B01080A02060801040500060800060900030600010400010200010200010100030400
090C040F110611140712150A
343B49363D4C383E4F383D53383E533A3F523C3F513B3F543A4057393F563B41553C4253
3D44533F4554414755434A5943495E43465F444762454964464C65464B64454B63464B63
474C63474D64484F66464E65474E65484F66485067464F674951674951644B51624E5264
4F52664E53664F556650576750566851566953596A53596B54596C535A6C545A6C545B6D
555B6D575E6E585F6F596070585F705961725C63735D66745D66745E6875606B74626C74
616B73616B73626D7564707864707965717B66727A69737A6B757C6C757B6B75786B7678
6C77786D79786C79766E7C76707D79717E7D727F7E73807D72807D74817D75837E73827D
75837E74837E74827E76847F77827E78837E78827D76817C75807B75807B77827C68726F
2D2E3A24252F2022271F2021191B1811120F0B0D08070802050800070A00060A00040700
040701030500030500040601050701090A020A0C040B0F050C10050D11080D11080C1007
0E13060E13070C1006090C030D110712170B181E101B21121E25131F25151C21131B1F12
1B1F12191F11171D10161C1013180C0F14080B10040B10050A0F040C11040D12030B1002
0B0E030C0D03080A00040500050500060700050700040600020300000200000100000200
0608020C0F050F130812170B
343B4A353B4D363C4F363D50363D51393F523A4052393F533A40553A42583C44583E4557
3F47563F4856404856424A59444B5E43485E444660464865484C69484C68464B65484C64
484D63494F67484F69484F694850684950674A51684951684A51664B51644C52644F5365
51546851546851556751576851566852596A535B6C545B6E53596E535A6D545A6E545B6F
555C6F565E70575F6E585F6E5960705C62745D62745E64755E67765F6977626B79626C78
636D7864707A636E7965707B65717B65727C67737D69747E6D767F6D767D69747B6A767B
6C797A6C7A796E7C796E7D796F7E7B707F7D72807E77848076827F778380798481778380
79848179848178848079848077827F7A83807A837F78817D77817C76827C77847C717B75
3B3D4526263024252A2426261E1F1D17181311120C0B0D06080B02080C00080C00090D03
0B0E05080A04050702040603050603080A040A0D050A0D040C11050B0F050C0F060D1208
0E130A0F140B0F130A0C0F070B0D0611150B181E111C22141F25152026171E24161D2215
1E22131A2013161C1013190D10160B0F15090C11070B10060B11070D12080D11050B1002
0B0E020D0E02090B00060900050800050700040700040600030400010200000100010100
0608020C0F050E120810140A
333B4C353C50363D51353C51383F52383F50383F52393F543A41573B425A3C435A3E455A
3E46583D44563F465741485941495B42495E444962474A67484C69484D68464C67474D66
484E67495067484F694950694A50694A50654C51654B51644D52654C51654D52654E5366
4F546751566851576750576651576751586952586A51586B535A6C555B6C555A6D555A6E
555C6F575F70586071595F705B61715D62725E62745D64755E6776606978626B7A636D7A
626C7A636E7B65707B66717C65707B65717B67737C6B767D6D767E6D757C6A737C6B757C
6C767B6B787A6D7A7B6E7B7B6F7C7B71807E727F7E768380778481788381798381798380
79837F7A84807A83807A838078837F7A837F7A837F7C84807B847E78837C76827A788479
4C4E4F24222C26252923242320221E1D1E1715151010110A0C0F06080B03090C030C0F07
0E110A0C0E09090B080708070606060809070A0C080A0C060A0D06090C040A0D040D1107
0E130A10150C10130A0D0E06080A020D1006161C0F1C22142027172027182025181E2317
1D22141B2113171D1013170C10150A0E13090C10070B0F060A0F060B0F06080C030A0D02
090C000A0B00070800050600040600050700040600030400020300010200010200000200
0305000A0C020D10060E1209
353D4E363F50364050373F50373F503940513841533940563B435A3B425B3D435B3E455A
3F46583F4756414959424A5A424A5C444B5E464C62484D65494E65474D64464E64474F63
484F614951624A52654B53674D53694D52684E53674E52664F52664E52664D53664E5567
505668505668505667515867515867525968525A6B53596B555B6C575C6D585D6E595E71
595F715961735B63745C63745E65745F66745E65755D66755F6777616A78636C79636C78
636E7964707966717A67737B67737A67737B69747C6A767B6A757B6C757B6D767D6E767D
6D777D6C787B6D7B7A717E7A72807B75807E727F7F73807E77837F7883807A85817A8482
7B83817B83807B83817B83807B85807A847F7B857F7A847E7A847E79837C76817978847B
545A59231F2824232721212221221F20221B191A1212130C0F110B0E110B0C10090C0F0A
0D100B0D0F0A0C0D08090A060808050908040A0A070A0B08090C07080A040709020A0E06
0F140A12170D11150B0E10060B0B010E1005161B0E1A21131E25151F26171E24161D2416
1E24161C2215181D1114180D10140A0D12080C10070B10060A0E05080B030709020B0D04
090B000A0C00080900050600040600050700060900040600020400020300010300000200
030400090A010C10040C0F06
3740513740523841543841533941533B44553C44583B445A3C435C3D445D3E475D3F475B
3F495A414A5A404959424B5B444E5D464E5F474D60484E62484E61474F61475061485161
4952614952614A51634D52684E526C4F536D4F546C50546A5055695056694F5468505769
515869505666505765525967525A68535A6A555D6E575E6F585E6F575D6F5960705B6272
5D62735C63755C65765D65765E66735F69745E67755F6875606878626B78646D7965707A
65717966737867747867747868757869757A6A757B6B757C6D777E6D777D6E797D6F797E
6F7B7F707D7E707E7A72807873807A75817D74817E76837F7985807A84807B84817D8784
7E87857D85837E85837D85827C86817B857F7B867E7A857D7B867D7B867E79847B7A887E
606B6523212B2323282324262124221F231D1B1E1616181013140E11130D0F120C0E100A
0D0F080E0F080D0D05090B04080800090A020A0A040A0A06090A07070907060805090C08
0F140C12170E12160C0E10060A09010F0F0517190D1B20121D24161F2617212719202619
1F25191E25181A2015151A0F10150B0D11090B0E070A0D05080B03080A03070802080A02
070900080900060700040600040600040700050800060800040600030400020300000200
0507000C0D020E10040C0E05
373E52373F553840573941573941553A42563A42573C435A3E445D3F455E40485F404960
414A60434D60434D5F444E5E475060464F60474E60484F61485262485161485161485261
4B54644C55664D546750556A4F536C4F546E4F546D4F546C4F556A51576A505669505669
51586A515A6B535B6B555D6B545C6C555C6D575F6E575D6E585D6F585E70596172596272
5C63745D65765D66775E67785D66765D66745E67755F6875626A77646B7A646C7A646E7B
65717B6671796773796875786A767A6A757B6B747B6D767C6E767D6F787C6F797B727B7F
727D80717E7E73807E75817E74827E75817F7782807884817A85817A85807C86827D8783
7D86847C85827D85807F87837F89837F88817F89817F89807D887E7D877D78847B7A877C
6C786F2E2E36292A2F292E2C2229241A1F19161B1413140E12130D12120C11110A100F09
0F0E060F0F050B0B01080B01060900080B00080A02090C050A0C06090B07080A070B0E0A
10150C10140C0F13090F10060A0A010A09011618091D211220261721271822261921261A
1F25191E25191A201413190D0F13080C10060B0E050A0D050A0C04080A03070903070903
040600030500010300020400020500040600050700050700030500020500010300020200
0505000B0B021011060F1007
373D54383F563B42593A42593A42583C44563A41553C435840455D40465F404761414963
434C62454E63444E62454E61464F61464E61484F624A5164495364475062485162495162
4951644B53664E55684F546B4F536C4F536E4E546D4F556E4F566D50566A505769515769
52596C535B6E545C6E565E6F565D6E585D70595E72585D70595D705A5E725A60755A6175
5C64765D65775D66765F68765F67765F67755F6976606976626A78646B7C646C7D666F7E
67717D67717D69737D6A757D6A767D6A757C6C757B70777E71787F70787F707A80717C82
727D82737D80747F807782817682817782817982827A84837B85837A84827C86847C8684
7C86847D87847D86827E88837F8983808A837F8A837F89817E887F7E897E7B867C78847B
778478383A3E27282D2C312D2126201619151114100E110C0E100A0E100A0E10090D0F07
0B0C030A0C020A0C00080B00080C020B0E03090C030A0D040A0C04080B030709030B0C06
0E11081012070E10040C0D020908000908011518091C22131F25182027192026191F2418
1E24171E2416191E1112160B0D11060B0E040B0E040A0D040A0C04070A03060902070902
030500010300000200000100010200020300030500040600030400010300010200030300
0909020D0E05101108101209
3940523A41553B42583D435A3E455B3F465C3F465B3F465C41475D414860424A63414963
424A64444D64444D62444E61464F624851624952644C53654B5265495165485265495267
4953664C55694F566D50556F50546F505570515772525873535972535A70545B6D535A6C
535B6C555C6E575F70585F6F565D6F595F725B60755A60745A61735C61745D62765D6377
5F66785E66765D66755F6975616B76606A76626C78636D79646C7A676E7E687181687280
67717E68737E6A757F6B757E6C767F6E787F707A80727B83727B83737E84727D84727E85
727D83767F827780817881827882827982827983827B85847C85847C85857C86857E8887
7F8A877F8A857F89847F8A84808A84818B83808B82828C83828C83818B817E887E7C877D
7C897D45484B25242B292C2B242722191B171112110F0F0B0E0E090F0F090F10080D0E06
0A0B04090B04080A02070901090B030B0E050B0E060B0E05090B04070A02090B040B0D05
0B0E040B0E020A0D010A0C01090A000C0F03181C0D1D23142027172028192027191F2417
2024161F25161B1F1313170C0F12080B0F050B0E040A0C03080A02060903050701050800
020500020300020300020300010300010300030400050600040500020300010100030401
0C0F0510140A12170C10140B
3B43523C43553E445A40455C41455F41466041485F41495E414A5F434B5F434C62434C63
434C62424C5F434D5F454E5F4850614B53644C54654D54664C53664A53664B55694A546A
4B556B4C566C4F586F525970525972525870525A71525971535A72555C72555C71555C70
565E6F575E70596172586071575E705961745A62735961735A63735D65745E66755F6676
6066775F68775F6976606A76626D76626D77636D77646F7B656E7D68707F697183697283
6A74836C76826C77806D777E6E787F707980707B82707C83727E84747E83747E82747E83
757E837881827982827A83827A84837B84837C86847D87857E88877E88877D88877F8989
7F8B88808B877F89857F8A867F8A85808A85818B84838E86848E86838C84808A807D877D
808C7E54585727242D282A2D2629271D1F1C1515120F0F0B0C0D070D0E060E0F060C0C04
0A09030A08040A0904090902080A020A0C040C0E050B0D060A0D06080B050A0C060A0C06
090A04070A03090B030A0D030A0D01101206191D101F2317212618232819222719212518
2023161F24151B201215190D1014090E12070C10060B0D050A0C05080A04050802030500
010400020400020400030300000200010300040600050600030500030400020300030400
0E110814190D151A0E12160E
3B42533C43563F465A40475C41465D41475E41495F3F475F414860434C61444D62444D63
464F6247516248515F4A515F4D53624E54654E54664E55674D56684C55674C55684D566B
4E576B4F586C515A6C535C6E535B6F535B6F555C70555B70555B70555B6F565B70555C72
565D72565D72565E71575F715960725961725A61715A62715B63725C65745E6576606676
626778626878636B79626B78646E78656F7A656D7A666E7D6A707F6B70816C72846C7386
6F76876E75856F78836F79816E797E6F797F717B81727C82737E82767F83767F82767F84
767F867781847881847B85847B85847D87857F89877F89877F8A89808A897E8989808B8C
818D8B828C89838C88838C88838D89818C87818C86818C85848F85858E84838C817F887E
818C7F5E635E27242E28292E2427251B1F1A14171110130A0D10070C0F060D11070B0E05
0B0C04090803080703080A03090B03090B030A0C030A0C050A0D050A0D050A0D05090C06
080B06070A05080B03090C03080A020C0E05161B101D2216212619242819232719222518
2024162025151D2214191E1015190C0F14080C11060B0E040B0E050A0C05070903040601
030500020400030400040400020300030400040600040700020400020400020200030301
0F120914180E161A12151913
3C43533D45563F475941495C41485C434A5E42495F414863424963444C63464F63454F63
4750634A53634A53624D53624F55654F56665056684F57694F58694E58694F586950586A
51586B52596B535B6C545B6D545B6E555D6F555C6E565C6E575D6F5B5F715A5E72585E74
575E74565E72555E71575F705860705A62725C64735D65745E66755F6677616779626877
646979646A7A666C7B656C7B666E7B666F7B676F7C69707E6C71806C73836C72836D7585
717886707884717984727983727A80727B80747C80757D82777E83787F84777F85788189
78818A7982897B83897D86887C86857E87867F89877F8987808A88818B89808A8A838D8D
848E8D858E8C848D89848E88858E89848E89838D86838E84848F83848E83828C81818A7F
818C7E6870682F2C342F3032282A291D221E14191311160B0F12090C0F070B0E070A0D07
0B0D080B0D080B0D080A0D050A0D040A0D040A0D040B0E050B0D050B0E060B0F06090D05
080C05070B03080C03090E030A0D030B0F0512160C1A1E111F241623271824281923271A
2226172227162126161E2214181C0F13170A0E13070C10050B0E030A0D03090C02090A01
060800050500060500070600050500040300030300020400020400010200000100040502
13170B151B0E171C11151810
3B43533D465640495A41485B40475D41485E424A61424963434C65454E65475064485264
4952654A53654C54664D54654E57674E57674F58694F586A4F596A4F5A69515B69535B6A
535C6B545B6C555C6D565D6E565D6F565E70555B6F565C70575D705A5F725A5F72595E73
5960765962755963735961705A62705B64725D66745F6776616A77616B78616A78626B78
636B78656D79666E79656E7A666F7B66707C67717C68717C6B737F6E74826C74816D7781
707984737C85727B83747B82757C81757E80767E80777F817981847A8186798188788189
79818A7A838A7B848A7D868A7F8888818A88818B89818C88828C89838D8A838D8B838D8B
858F8D868F8C868F8B87918B87908A868F89868E87859085848F84838E82858F83838D81
828E80727B7137363C343639333736222423181A181316110E120B0C0F0A0B0D09080A08
0A0C090B0E0A0C0F090A0C05090B020B0D030D0E030D0F030D0E040B0D050A0E05090E04
0A0F040B10040E14040E1405111707101507101407171A0D1D2214212718222818222618
2126162025152128181F25171B2013161B0F11140A0D11060A0E02080C00090C000B0B01
090901070600070600080700060500040300030300020300020200010100000200020401
0D110613190B181D0F181C0D
3C45533E4856404959424A5E434B60434C60434C61444D61444E62465163475264495466
4A54664B56674E57694D57694E586B4E5A6B4E5A6A4F5A6A4F5A6A505A6B4F5A6A515B6A
525C6A535C6A535D6B565E6D575E6E585E70595F71595F72595F72596072595F72585E73
5960775A62765A63745A63715B63705D65715E6673606876616A77626A77626B78636A79
636A79656C7A666F7B666E7C67707D68717E69737E69747E6D757F6E757F6C757F6D7781
707A83737C85747C85757D85777E85787F857880847A82867B82877C838A7B828B7A828C
7B838D7C848B7C85897F8789818989828A89838C8A838D8A848F8B848E8B848E8B86908D
868F8D868D8B868E8B89908D89908C878F8B878F8A879089859188859085869184849083
8591817985783E3F4336393C353A381F2223191B1A1215130E110D0C0E0B0B0D0A090A09
0A0C090A0D090B0D060A0C030A0D020D0E020E0E030E0E020D0E010C0C010D0D020E1005
1115081117081016061015061015060F12040E0F0314150A1F21142327182227181F2516
1E25141D24132027151F26161B2214191D1014170B0F13080C10030B0F010A0E000B0D01
0A0C01090A00090800090900070800050600030400040500030400040300010200010300
0D0F0615180C181E0F181B0C
3E4753404958414B5A424B5E434B5F444D60444D60444E614650634852654853664A5568
4C57694D57694D58694E596C4F5A6C505C6C505C6B505A6A4F5A6B515C6E505B6E505B6C
525D6D535E6D54606E56606F576070585F70585F71585F725A62725961725A61745A6075
5B62775B63785B63775C64755D66755E6774606875606A76626B77616A78646D7A656C7A
646C7A636C7A666F7B67707C6A727D6B747D6B747C6C757B6E777C6E777D6E767F707782
717984737B87747C86747E85767F87767E88777F8879818A7A828B7B838D7B828D7B838D
7C858C7D878B7D878B80898C828B8E828C8E858E8F848D8E848E8F868F8F869090879191
86909086909186908F88918F88928D88938D88938C88938B87928C869389859187839085
8391847C8D7D3B3F422C2F332A2D2B1C1E1C1316120E110C0C0F090A0C070A0C07090B06
080A050A0D050A0C030C0E030E10020E0F020E0E020D0C020E0E010D0D020F0E03121206
1113090E11070B0E03090B01090B010B0B010E0E0317180C1E2013222516222517202416
1F24162024152226162026171B2213191F11161C0F11160A0E13060C11030C0F020C0F01
0A0C010B0D010B0C000A0C000A0C01080B01060900060800050700030400000200010200
0B0C0513150A15180C15170A
404755424A5B444D5F454E60454D61464E61464F614650624851644954654A55664C5668
4E596A4F596A515C6D515C6E515C6D515C6B505C6A515C6A525C6A535E6D535E70535F70
556172546071556070576171586272575F735961755B64745B64735B64745B64755B6475
5C65765D64765D64775C65775D6778606A78626C78626C78636C79636C7B656E7D666E7C
656F7C65717D67727C69737C6C757E6D757E6E767E70777E70797F727B82727A84727A83
737A84737B85747D87747E8676808878818977808978828A7A848B7B868B7B868B7B868B
7D888C7E8A8C7E8A8C818C8E838E90838D90869092858F92869091889191889292869192
86929388949387939187938F89958E8A968C89958A8A978B8A978C88958A869489849388
8494868091824248482325292023231518160F120D0D0F080C0E05080A01080A02090D03
090B010A0C020B0E020D10040E12051012041212061112061110050F0F040F1006101007
0F10080C0E07090B04070902090B030C0D0411120717190D1D2113212616232718222617
21251821261724291A252B1C2027191E24161B2214181F11151C0E141A0C151A0B111507
0E13050F12050E12040E12061116090F14070E13050D1204090D01050800020500020400
090B0312140715180B17180C
434A59444C5F464E63485066484F654951654751644953664B56674C58664D5967505B6A
535C6C535D6D545E6F535D6F535E6E535E6F535E6E545F6F555E6E555E6E565F71566173
5660755660735860735962735A62745A62745C63765D65775B64745B64735D66735C6573
5C65745E66765F66775E66795E677B606A7A626B78636C79636B79656B7D676D80686F81
6770816871816972816C74806E7580717881717781717883737A84747D85747C85747B84
767C85767C86767E89767E8879828A79848A78838979848A7B868B7E898C7D8A8B7D8A8C
808C8F818C8E808C8C828E8E848F8F85908F889491879290889290899291889290879292
8895928895918A95918A95908B96908A968E8A968C8B988D89978B899689899689879589
8696888698864F595326292A1D201E1417140F120C0C0E080A0C04090B020B0D040B0E04
0C0F040D0E040D0E040C0F050E11061014081112081213081113080E11070E11070D0F06
0B0D050B0E060A0D060A0D050B0D040D100410140714180B1B2012212716232817222817
212617232818232A19242C1A232A192027171D24161D24151D25141E25141E2413181D0E
14180912160812170A10160B14190E151B0E171C0F191E0F1115080B0C03060700040400
07070111130817180D181A0E
454C5D464E614852654953684952684B55694852654853664C58694D5A6A4F5B6A525D6D
545E6F555F6F566071546072546171556271556272556072566074576074586174576174
5560755760755A63765B64765C64755D64755E66765E67765C64735C65725B65705D6671
5F68745F68785F677B5F687D606B7E606C7C626D7B636E7A656F7C666E7F687082697184
6971826972816B74826C74826E7583707885717985727987727988757D88757D88767D88
767D88797F8B797F8E77808E78828D79858E79868C79858C7A878E7D8A917D8B907E8D91
808C90828D91828F918291938492938692928996948A95938995938A96938B97958B9696
8B96958A95958C96958F99958F99938E99928D9A928C9A908D9A8E8D9A8C8D9A8C8B988A
8897888A9B88606B612C2E301F2122171A191114120D110C0B0E070A0D040F11080F120B
10130C11130A1011081011081012080E11070E11071012071113080F12080E11080E1108
0C0F060B0E060B0E050B0E040D1204101405111607181D0E1D2213222716232817242917
2328182428172328162329172229162228162026141E26141F27151F28151F27151D2314
1C21121A1F11181E11171D0F191F0F1B21111E22132327171A1B0F1212090D0D050A0803
0707030D0F0813160C161A0F
464D614851654954694955694953684955684956684A56694B57694E5B6B515D6E525D6F
545F71566171566272556272556371566372556370556272566275556275566274566274
5561735762745864745A64735B65735C66745C66735C67715A656F5C68705C67705F6973
606A765F69785E68795F6A7C616C7F646F7F656F7E65707F65707E656E7F677182687385
6972846B74846C75866E76876F77886F78896F7A89707B89707B88727D88727D89757E8A
77808B777F8C77808F7882917783917985927986907A88907A87907C88917E8B927F8D92
808C92818E938290948191958392958593948794948895968996968B98968A97968A9696
8C98978C98978C97958D98948D99928E9A928D9A928D9C918C9A8E8C9A8C8C9B8D8C9A8B
8A98888B9A886E7B6E31343726282A1C20211618191213130F110C0D0F0716190F191C14
16191412151010130B0F12090E11080D10070D10061013061113061013070E12070E1208
0D12060B0F040B10030C1103111706141A09141909161A0B1A1E0F1E2212202515212717
2128172128162228162429172229182128152026142026151F26151E26131F27131E2614
222A172229161E25141E26121E25111E2310202514282D1C2225171B1C1213140C0E0D08
090B080B0D090E130A10150A
444D624650664752684955684955684A56684A56694A57694A58694D596B515D6E535F6F
546071556170566271556170556271576472576571586573576475576476566375566375
5763745863735963745A65755A65765A657559657459667258676F5A68705D68725F6975
5F68765E68785E6A7B5E6A7C606B7D626D7C636E7C666E80666F80666E806871836A7285
6A71846A73846C76866D76866E77876F798A6F7A8B707B8A707B87717E87727E88747E8A
76808C76808D77808F7881917884937986947986937B87927D89927E89907E8990808B92
828D93818F948292958393958494948694938794938895948B97968C98988A96978C9896
8B98958C9A968C9A958C99938C9A928C9A908D9A8F8C9A8E8C9A8E8E9C908F9D8E8F9B8C
8C99898D9B8A79867A3D41453033372327291D2022191B1C14161416181247523E252B22
1114121115120E120C0C0F080B0D060C0D060D0E050F11060E10060E11070D11070C1007
0B0F04090E020A10010F1606141B0A171D0C171C0C13160914160A1A1C0F1E23141F2617
1F26171F26162026172228192329192128162027152026142127162026172027141F2713
232B16242C18222A172028161F27131E26111E2412262D1B262B1B2025171B1E1214160C
0E110A0E120A0C1208090D04
444D614750664853694954694B566A4C56694B56684C57684D58684F5969535D6C55606F
556171546170566472576572566371566372566372576475576376576376576276566276
5864765964765863765A64795B647A5A647A5A657A5965795966775966745B66775D6777
5D67785E687A606A7C5F6A7C5F6B7C606D7C636F7E656E81677183687083697183697281
6972806A74826B75846D76856F788770798B707A8D707B8C727D8B73818975838B76828C
75808E76818F7682917884937885947A87947B88947B87927F8B91808B8F7F8B8F818D91
848F938491938593938794958794938995958995968996968C98988E999B8D999A8E9A98
8D99978D9B978E9C978E9C948F9C93909D93919D91909C91909D92929F92919D8F919D90
8E9C8F8C9B8C8290834B4F52383B402C2F33272B2C2528271C1F1E191C194A5843222A21
11151113171310140F0D110A0C0E090C0D060C0E040D10050D11060D11060C10050D1007
0B0E060A0D050A0E0312180A171D0F191E10151B0D0F140811140A171B101C21151F2518
2025192227192126182227192328192228172128162128162228162026172026161F2515
232A19252D1C222A1B1F27181E26161F28141E26112229142229171F27161E2615192011
13170C1013090D1107090D04
494F5E4B52644C556A4C566C4B556B4B556A4C56694C57674D5865515B68555E6C586270
566271556271566473586675576673566372566373586475596575586575576376576277
57637958647A58657A5A647A5B647B5B647C5B647D5C657D5C677C5D687A5E697C5E697B
5E697A5E6A7B606A7D5F697D626C7F626E81636F82647083667184677284687383687380
6B76806D77826E78856F79866F7A88717C8C717D8E737E8E737F8D74818B76838C77838D
7883917882937781947886957987947987927B89927C8A927E8C91808E91808D91818E92
848F938490938491938692948995958A96978B97998C999B8D999C8E999B8C999A8E9A9A
8F9C9A909D9A909E99909E96919E93929E91929E90919E90939F92939F92929E92919F92
909D908F9C8E8A9788585D5D3A3A4136363C2D2F322C3030262A291A1E1C20251F20261D
1C2319161A1211150C0E130B0D110B0C0F070A0D030B0F030C10040C11050B10040D1106
0C10060A0C05090B040D110714180C181C10181C1113160D10130C161A111B21151F2517
2126192128192027181F2617202717212817202716232918252A182329182126171E2417
22291B262E1E232C1B1F28181F2717202717202716242B172229172027172127181B2113
11160B0F13060D10030A0D02
4A525B4D54604F57684D566B4C566D4B566C4A55694B57684C5867505B69515D6B545F6D
55617054607156627557657957657A566479576578586577586577586578586477596578
59637959637A5964785B65765C66765C66795C657B5D667D5D667C5F677C5F687B60697A
60697A616A7B61697D626B7F636D81626D82636F83646F836570836772826973836A7481
6C76806E79826F7A82707B84717C87727C8B737D8D747E8E747D8E75808D76808E77818F
7A83937B84967984967986967B88957B88947C89947F8C95828E96838F95838E95828E94
8590968591958491948793968895978A97988B98998D999A8C989B8C99998C98988E9A99
8F9C9A919E9A929F9A919E99919D95929C92929E92939F9294A09393A09493A094919F91
8F9D8F8F9D8E8F9C8C6367633A363F39373F3030352D2F322C2F2D2024231C1F1D1C1F1B
1D221A191D1415181010130B1012090E10060B0F030C10030C10030B10030A0E030C1006
0B0F06090C040A0D040F120814190C181B0F1A1D11171A1011130D1518101E221623281A
2328192329192128181F27151F28162029162128152229182128182027171F26171F2517
22291B252C1C212A191F27161F25141F25161F24151F22151E22141E23142025161A2112
10150A0F14060D1103080A01
454E584A525E4E57674E566A4C566A4C576B4B576A4D5A6A4E596A4F596B505A6C535E6F
54617154607155617756627A57647D57657C58657B57637A56637957647A586578596578
5A65785B64795B63785C65755B66755C66775C66795C677A5E677B5E677B60697C626B7B
626B7C626A7E616A7F646D82646D82636E836470846772856872856973836B75836B7582
6C77816D78816C77816F7A85727C8A747C8D747D90757E92768092788193788093798295
7C84977C84987B84977C87977C87967D88967E8896808A97828C96828D95838F96849097
8691978793968794978995988996988A97988C98998E9B9B8D9A9A8D99998E9A9B8E9C9B
8E9C998F9C99909D99929D99939E98959F97949F9794A19693A09592A096929F94919E92
909F90909E8D909F8B717A6E4343453F3F433130362C2E312B2E2B2225221E1F1C20221E
2328201F251B191F1414160C1112080F10060C0E040C0F030C10030B10030C10040C1008
0C10080D10080F120911150B14180D16190E16190D14170C11130A16170D22261825291B
24291A232819212818202817202816212A17212916222A172028171E26161E26171F2618
20281A21291B1F27181D23131A2110191F0F181D0F171B0F15180D15180D151A0E151A0E
12160C0E12080B0F04070B01
464F594953604D5867505B6B505A6C4E596C4B576B4E596D4F5B6E525D70525E70536070
526070536171546273556274566477576578566578576578586577586678596679586578
5A657A5D667C5E667D5D657A5D66795D66785F68785F6979606B7B60697B60697D626A7E
636C7F636C80606A81636D84656F856571876772876973866A73856A73846D77856D7785
6D78866F79886F798A707A8C737C8E747D91757E94767F94757F94767F937881937A8294
7B83967C85957D85977F889880899A80899A818A98818C98838D98858E98859099869099
86919988949989969B8A96988A97998B98998D9A9B8F9D9D8E9D9D8E9D9D8E9C9D8E9D9D
909E9C909E9A919F9A939F9C949F9B95A09A95A09894A19892A09892A09790A095909F93
90A09191A08D93A38D798576494C4B4649473132342B2E2E2B302A252B2421251D262A20
272D2220261B171B1112150A1012071011060F11070D11060E13050D12040D12050E1308
0D110A0F130B12160C12160B13170B12160B12170A11160A1014091215091E2111222717
252919242A19252A19242A19222A19242B1A222918242A162429172127171F25181E2518
1C24171B22151A2113171D10141A0C12180A1115090F13090E11080D10080D12080F1409
11140B11130A0D1007080B03
47525E4955624C58684E596A4F5B6C4E5A6D4D586E4D596F4E5A70515D72505C72505C70
515E705261725160705462715563725664735866755967745A67745A66745B67775A6677
5A66795B667B5D667C5D667C5D677C5C677C5C677C5E6A7C5F6B7C616B7D616A7D616A7E
656E81646D83636C85646D85656F866672876872876872856B74856D77876F78886F7788
6F788971798B717A8D717A8D727B8F747D91767F92768093757E927780917882907A8491
7D85937E86957E8696818998818A99828A9A838A99848C99848E9987909A888F9A89919C
88929C88939D89949C8B959A8B979A8C999B8E9D9F8E9E9F8E9E9E8D9E9D8D9D9D8E9E9E
92A09F93A19E93A09D929F9C939F9C94A09D94A09B93A098919F9793A19992A29790A192
91A29190A18F92A2907F8D7E5155534D524E3233352A2C2C292C2A272B2623272021261E
24292022261F1D1F1818191014170C1213091213081012060C11040B10030C11040D1106
0D10080E11090F120A0F12090F130912160C14190D12170B1014091215091B1E0F222616
242818252A18262C17242B16242B17272D19242B182228162227152024151D2013191D12
161C10151B0F151A0E13180B10140910140A0F120A0D11090B0F090B0F080B0E070C0F07
0D11080E11080D1007090C04
4853604B57644D5A6A4E5A6C4E5A6D4E5B6E4E5C704E5A704F5B70505C71505C71515C70
505C6F526071525F705462715764725865735A67755966745966735C67745D68765C6777
5A66795A66795A667A5B667B5E687C5E687D5E687C5E6A7C5E6B7C5F6B7C626B7C636C7D
656F81646E82646F84646E856470866471876572876873866A73866C76886F7789707789
70798A71798A70798A717B8C737D8E757F907681917781917680917780917882917C8493
7D85937E86947F8895808A96808995828B97848C99838B99858D99868F99868F9889929B
89939C88939B89949A8B969B8D989D8E999E8E9B9F8D9B9E8E9C9E8E9D9D919F9E929F9E
93A09E95A09F94A09D939F9B939F9C94A09E94A19E929F9A919F9892A19991A19891A196
91A194909F9291A191808D81505452545D54323634262928252725242725232624242825
282F282B302823261E191B1414150F1010080F10050F10050D0E040B0E020C11030D1104
0E12070C0F0A0A0C090B0D090D100B11150F13181012170F0E130B0E1309171B0E1F2415
232818252A18252C16232B14242B15232C172129171E26161F26161F23151A1C1015180D
13170C13180B1116090E12060D10060E120910140D0C0F0C0A0D090A0D070A0C050A0D05
090C04090C030A0E04080B03
47535D4A56614C59684E5A6C4E5A6D4D5A6E4D5B6F4E5B704F5A71505C71525D71525D6F
535F6F53617053606F55636F5866725866745966755865765A65775C66795C66795B6679
5A677B5B677C59667B5A667A5D687B5F687D60697E626C80636E82646F82646E80656E81
646F82636F826270826370846471846470846672846873846A74846E76866F7788727A8B
727B8B707A8B707A8C727D8D737D8E777F9079819079818F7881907A83927B84937D8694
7E87957F8895808995818A96818A95818B95838D98848E9986909B86909A869099879199
88929A88949B8A969B8B979C8C979D8E999F8E999E8E9A9F909C9F909D9F93A0A094A1A0
94A09E95A09D96A29D96A39E96A29E96A29F95A29F929F9C93A09A94A29A95A39996A398
94A39692A29493A2928999864C504B4E564C393E39282A2A2527262B2E2B272A29272B2A
2B322C2B312823271F1B1D1815171110110A0D0F070E10070C0F040B0F040C10040C1004
0C10060B0E080A0D090A0D080E140B141A0F141B1112190F0E140A0D1309151B0F1C2315
212919232B19232B16242B15252C16242C17232B182129182028171C2213171C1014190D
10150B10150A0F14080D11080C0F060D11070E13090C0F090A0D06080C04070A01080B01
060A00050A00070C00070B00
47535C4956604C59654D5A6A4E5A6C4E5A6E4D5A6E4E5A714E5A734F5B74515C73515C71
536071556272535F6F54606F5663715865735865745764755864775A657A5C657B5B667A
5A657B5B667C5A667B5A657A5D667B5E677D616A7F636B80656D82656D81646D80646D80
656F82656F83636F83636F826472826471816773816974826B7682707A85727A87737A89
727B8B707A8C717C8F727D90737E90757F9077808F78818E7A84907D86927E85927C8492
7E8795808996818B97818B96818C96828C97838C99848E9A848F9B858F9B86919C87919C
87929B89949B8B979D8D989D8F9A9D919C9F919B9E939DA0939DA2929DA2929EA3939FA4
959FA196A0A1949FA095A1A095A2A097A3A097A3A094A19D95A19C96A19B96A29997A396
96A39494A29293A19092A38D575C5637393A3C413E303332282A2B2B2E2B292C2A242727
242926202521191E1A1518141418140F130F0E110B0E11090D11070D10060C10050D1107
0C10060C10070C10080B10080D130811180B131B0D12190B0F14080C1007181E111F2717
222A19242C1A252C1A262C19272D19242B17242C18222B171E27131A2210161D0F141A0D
0F14090C10080B10070C10080C10070C10060D11060B0E050A0D04080B02050800060900
040700020700020600010400
46515C4955604C59664C596A4E5A6D4E5A6E4D5A6E4E5B704F5B71515D73525D73515C71
525E71545F71545F7054606E56636F5663705764725865725864745A65795C667B5C657B
5C647A5C65785D66785D66785E677961697C616A7D61697C626C7D636D7D636C7C636C7C
646D7D646E7E656F816570836571836572806875806975816C77826F7A83727E87747D89
737C8B717C8B727D8D74808F75809075809077819077818E7A838F7D85917F8694808695
818796828B98828B98828B98828C97828C97838D99848E99858F9986909A87919B88929D
88939C8B959C8D979B919A9D919A9D919A9F939DA1939FA3949FA4949EA4949EA4949EA4
959EA397A0A3969FA2969FA297A2A297A2A096A29E97A39C97A39C97A39B96A29897A395
95A29394A29293A19095A5916770693130363C413F3537362C2D2C2B2E2B2A2D2B292B2B
282B2A1E2122181C1D14161413151011140C0E13090E13070D12040D10020C10020C0F02
0C0F030C10050D12070C11080B10070C12070E13080E12070C10050C1005192012212919
222B1A252E1C262D1C262C1B242919222918222A162029141C2411192010161D10151C0E
10160C0C11080A0F060C11080B10070B0F040B0F030A0D03070A02060801040700050800
040700030700010500000300
46515C4953624C57684B576C4D59704F5A714E5A704F5C72505D73525E72525D71535E71
555F73576374566172555F705762715863725763725865735865735B66765B66795C6679
5D667A5E67785F68776069785F6879616A7C626A7D616A7D636C7E646E7E646F7D646E7D
666F7E67707F6871806771836872846973826A75816C77836E7884707A86737D88747E88
757E89757E8976808E767F9078819078818F7882907883917A85927C85947D86967F8898
81889983899A838A99848C99848C99858D99868E9B878F9C88919D87929D88929C89949D
89949C8B979A8E999A919C9C919B9D919A9F929DA2919DA3939FA495A0A595A0A4969FA3
96A0A398A1A297A1A197A19F97A29F97A39E98A49D98A49C97A49B97A49B96A49996A398
96A39796A39694A39495A6956D786F3133383C4240383C3A3032313134322F32302F3430
2F34301C1F201B1D1D16181511110C1011080D10050C11030B10010C0F010D10030C0F04
0C0F060C0F080D120B0E120C0D120A0C11070C10070D11060D12051116081D2412232B18
252D1C252D1D252D1E242C1E222A1C232B1B222A181E26131A220F161D0E141B0E131A0E
12190E0F160D0D12090D13090C11070B0E040A0D040B0D04080A02050600030500060700
040700030600020500010300
49535F4B56664C576A4C586D4E5A70505C71505B72515C74515C74515D74525D74545D74
555E765760765661755861755962755862735A63755A64755A65765A66775A66775C6778
5E68795F6878606A79616B7A606A7B616A7E616B7E616C7F656F81646E7F666F7F677081
6972826971806872836972846973846A74846D76876F7989717A88717A87737D8A757F8A
757F8877818B78808F797F917A81927B82917B83917B84917C85937E86957F8899808999
838A9A848A9C848B9C848C9C848C9B858C9B888F9E89909F8A91A08A93A08C94A08B959D
8C979D8D979A8E999A929C9B939D9E959EA0949EA2929DA194A0A296A1A397A2A399A3A2
98A2A298A2A198A2A097A29E98A39E99A49E99A4A09AA4A099A49D99A49E99A49C97A39A
97A29997A39797A59498A895768277393B414148463C413E363A37393F38353A332E322B
3338301E1F1D1C1D1917181311130C0F12090E11060C10030C10020D11040D11060D1108
0E120C0E120D0D110C0E120C0F140B0E12080D11070E13060E13051217071C2411232B17
28301D28301F272E20252C20252D20222B1D21291A1E25161A2112151C0E12190C12180C
131A0E11180D0E140A0C11080C10070A0D04090C040A0C04080902060701060500060400
030400020500010400010300
49565F4C59644D59694F5A6E4E596F4F5A70505A70515C72525C72545E73556075545E75
545D76565E77575E775961775963765762745862745862755863755965775965785C6779
5D67795F6978606A795F697A606A7B606A7D616C7E626C7F656E82666F81677081687083
6971846972846972846872826A74836C76846F7987707A87717B89727C89727D8B727D8B
737E8A75808C777F8D7A80907C82907D84917D84917E86927D8691808995808998818A98
81899982899A818A9C838D9E838C9E838C9E868E9E89909D8A929D8B939C8C959D8D959C
8E979C8F999C90999C939C9E949D9F959E9F959E9F949D9E969FA096A0A097A2A297A2A2
97A2A198A2A098A3A099A4A199A4A099A49E9AA49F9AA49E99A39C9AA49B9CA79C9AA499
98A29798A39698A59297A7918391813F4346444A483A3F3D333732343A32343A302D3028
2E32291D1E191B1C1616171111130A0E11070E11050C10040C10030B10040B0E050C0F08
0D100C0E100C0C0D0A0D0F0A0E11090E13090D11050B10020B0E010C10031E2611232B16
272F1A272F1C252E1E242D1F262E20232B1D21291C1E2719192013141C1012190D0F150B
0F150C0D130B0D130A0B0F06080B03080A01080A01070901050600060700060700060600
030400010400010300000200
4A585C4E5B63505C6B505B6E505A70505A72515C73535D72535E70565F70565F71565F72
556074556075565F7758627957637956627855617557627757637758657958647A5B677C
5D697C5D69785E6B795E6B7B5D6A7B5E6B7C626E7E626D7F646D80677082687183677083
6871836972856972856A74856B75836D77826F79826F7A84717B87717C87717D89717D8A
727E8A737E8C76808F7981917B83917C84927C84917D868F7C878E7E8991808996808A99
808B9C818B9D808A9D828B9E848D9F858E9F86909D88929A8B959A8C95998B96998B9598
8E989C8F9A9C8E989A909B9D919D9E929E9E939E9D949E9D969F9F95A09F96A1A296A2A2
96A2A197A2A098A3A09BA6A19BA7A19BA6A09AA59F9AA59D99A59B98A39899A49899A497
98A49697A39698A49497A6928B9A88484B4C404544383D3B2D302D2A2D262B2F26292B23
2C2F251F211A1A1C1415180F11130A0F12070F11040E11040C10050B0E050A0D060B0E09
0D0F0C0E100D0E100B0F100C0E120B10150B1015070E14050E12040C0F031C230F232A16
262B18272E1A262E1D262E1F252E1F252E1F222C1D1E2618181F14131A1011180C10160C
0D12090C10070C1006090E04080C02080B00090C00080A00060800060800060800060801
040600030400010300010100
4A585D4D5A634F5B6A505B6F505A72505B74515B74525D72545F7055606F56616F55606F
5460715561725662765560775562795562775562755664765966795A667B5B677D5B687D
5D6A7B5C6A775E6C785E6A795E6A795F6B7A62707C62717D64717D687380687382687284
6872846871856974866975856974836D7883707984707986707B87727E89727E88737F89
75818C767F8D7981927B82947D84937D86947D85937D86927D87917D87917F89957F8997
7F8B9A818C9C818C9D838C9D848D9D878F9F89929F89939F8B949D8B959C8C969B8B969C
8C989D8D999E8D999D8E9B9D919F9F919FA093A1A094A19F95A2A095A1A293A0A295A2A3
96A4A298A5A299A6A29AA6A29BA7A19BA5A19CA7A39CA8A19BA69E9AA59C9AA69A9AA699
9AA79897A39698A39598A49495A491535756393A3E393D3D2B2D2D252924262A22232620
23261F20231C1C1F17181B1215180F16170D15170B1315090E12070C10070C10080C0F0A
0E110D0F130D10130D11130D12160F12170F11160B1015091115081114051417071D2010
202513242A17272F1B272F1D272F1E252F1E242E1D212B1B1C2416181F12141A0F10160B
0D10070C0F060C10060D11060B0F040B0E030B0F030A0D02070901050701050601070A03
070A02050700030400020200
4B59614D5B64505C6A515C6E525C72525D74515B73525D73525D72546071556371556271
5563725564725765755763765865785664755664725765735966745B68775C697B5E697D
606B7E606C7C606D7A606C78626C7A646F7C65727E67737E67747F677381677383687383
6873846872846A74846A74856B74856E7887727B89737B89747D89747F8B737E8B75808B
78828C78818D7A818F7C83927C84927D85937C85937D86957D87957C87947F88967F8996
808B98838D9C848E9C838D9A86909C88909E8B93A28C94A48C95A38C96A18C979F8D98A1
8C989F8E9A9F8F9B9E909C9E929F9F93A1A095A2A195A2A095A3A196A3A397A2A397A4A4
98A5A398A5A19AA7A19AA6A09BA7A09BA6A09CA7A09CA8A09CA89E9DA89D9DA89B9CA79A
9BA79999A59699A49699A49697A493585A5A3D3D42393C3D2D3031282B2A262A28242824
1F231E1F241B1F261A1D23171B20151D20131A1D0E15180B1014090E12080D11080B0F07
0C100A0F120D11151013171113170F11160C0F140A0E12070C11030C10020C0D011C2010
222716252A18272F1928301A27301A26301B262F1D252E1D2028181B2113171D1211160C
0E12090D11070D12070E13080E12070E11070E11070B0E05070902060801050601060802
070A03050701020400010200
4A56644D5968505C6D515C6E515B71535D74535D75556078545F77535E75546173556372
5563725665735967765966775865775865755966755A67755A68765B69775C697A5E6A7E
606A7F606C7E616D7D626E7B646F7D66717F66717E66727F677281667182667182687382
6975826A75836B77846C76866D76876E7789717A8B737B8B757C8B747D8C747E8D75818D
77828B78828B79828C7A838E7B85907B84917C85937D88957E88957F8796818999828B9A
828B9A848D9C848E9C858F9B87919C88919D8A929E8B94A08B95A18C96A18C98A18D99A1
8D98A18F9AA2909CA1919D9F939F9F95A1A196A1A297A2A397A3A498A4A499A5A49AA7A5
9AA7A499A6A29AA79F9BA89E9BA99F9CA8A09EA99F9EAA9D9EAA9B9CA9999BA7999AA899
99A7989AA7979AA7979AA6969AA7956163603B393F39373A2C2B2D262627232426252A29
1D211F242A21272D2120261A1D22161C1F13181A0D15170B1214091113090E10070C0E06
0C0F080D110A10140E11160F11160D0E12080B0F06080C02070A010709000A0A011E2210
242916272D18272E1828301828311926301927311B27301C232B191F25151A1F1112170C
10140A0F14090E13080D12060D11060C10060D10060B0D04090B03070902050700040601
040600030500020300010300
4A55674D586B515C70525D72525C74525D74545F75556077546076556077566276576474
5665755765765866765966775967775B68785B69785B68785C697A5D6A7C5D6A7C5F6B7D
626D7E636E7F636D80666F816771806973816873816872826872836973846B75856B7586
6A75856B77856E79866D77876E79896F7A8B707A8D727B8C757E8D747F8E768190768291
7682907884917885917985907A85917A87927C89927D8B927F8C95828D97828C99848D9A
838C9A848D9B848D9C858F9D88919F8A94A18B94A08A949E8B96A08E97A28E98A18D99A0
8F9AA1919BA3929DA3939FA296A1A298A3A39AA4A598A2A599A3A59AA5A69CA8A59BA8A4
9DAAA59CA9A49BA8A19AA7A09CA8A29FA9A39EA8A09EA99F9EAB9D9DAA9A9DAB9A9BA999
99A79899A7989AA89899A6969CAA987781763A383C3734372C2A2C2624262323252F3331
2528282527242528231E1F1B22251E23261D1E2116191B0F14150A1213090F11080D0F07
0C0F070D12080D12080D12080E13090F12090D1108090C030608010607000B0C031D2210
252B17292F1C2B311D2B321C2B331D28311C262F1A262F1A242C192026171C2214191E12
14190E11160B10150A1015091115090E12070D10060C0F050C0D040B0E04080A03070A02
060801040600030400030400
4B586A4F5B6E525E74535F74535E75515D73515D71536072546072566274586575576476
5765785663765765765867775867785B687A5967785A68785C697A5C697C5E6B7D606D7D
616D7C646F7E65708066708166718066717F6872816973846972846973856A74866A7586
6B75876B75876C76896E798A6F798A70798D727B8F737C8E757E8E747F8F737F8F758091
7682937884937885937885927A86927C89937C89927C8A92808D94808D94808B96838D99
838D9A838D9D86909F87909E8892A08994A08A959F8A959F8C97A18D98A18F98A09099A0
929CA2929CA2939CA2959EA496A0A397A1A298A2A398A3A39AA5A49AA5A49DA8A69CA8A4
9CA8A49DA9A69CA8A59BA7A59DA9A69EA9A59EAAA39EAAA19FABA09EAA9E9EAB9C9CA99A
9BA89A9BA89A9BA89A99A99799A9988594843D3F403232352D2E2E2827272223222A2C2A
2A2D2C2424262123241F2021414A3D30362B1F21181C1F1316180C1314081113080F1208
0C10050D11050D12070D10080D11090F130A0C1008080B030608010507000B0E051D2412
232A16272F1929321C2A341C2A341C28311B242D17222A151F26141C22131D22131C2114
1B1F12181D1114180D12160B13150A1114081014080F12080D10050A0E020A0E030B0E05
0B0F05080A02060601050501
4C59674F5B6D525F73525E73525F75525E72525E71515E6F525F6F546170556271556473
55647656647656667755657958677A58657A59667A5B69795C697A5C697C5F6B7E5F6B7B
626E7C64707D65717E646F7E66717F6872816873806A75816B75836A74836A7485697484
6A75856B76866C77886E788A6E78896E778970798C727C8D727D8F737F8F748090768291
7783927783937783937986937B87947E89947E89947E8994818B96808B967F8B98818B9A
828B9B848D9D878F9F89909E88909D88919F89929F8C95A28C96A18D97A28E97A19097A2
9199A2939BA1939BA0949CA2979EA5969FA498A1A397A2A297A2A299A4A49CA6A69DA7A7
9DA8A69DA8A79EA9A89CA8A79CA7A69EA9A59EA9A49FA9A3A0ABA29FAAA09EAA9E9DA99C
9CA79B9CA89C9BA99C97A69797A8978A99883F41412F30312E2F2F2A2B2A262825272925
2A2D292224231D21203239323A44372B32251D20151A1D1114160A121307121408101508
0D12050C11060C10070B10080C10080C10070A0D050609010809010608000A0E041C2311
1F2714242E1927311C28321B29321A29311A262E172127101E230F1B1F0F1D2012202315
1E21141D20131C1F131A1C1016170C13130912130916190C151A0A111606131808141A0B
1217090D12060A0C04050601
4D58664F5A6D525F7453607654617655627554617253616F53616F54636F556371556374
5564765665785766795766785967785A67785A68795C6A795D6A795E6B7C606C7D616D7B
626E7C626F7B636F7C636F7D65717F6771826974836B76826A76836A74836B75846A7584
6774836A77866B78886D79896F7A8A707A8B6F798B717C8F737E91737F91758191758291
7783927885937884937984937C86947E87957F8996818A98818A99808A997F8A9A80899B
818A9C848C9C878E9D888F9D89919D8B929E8B939E8D959F8E96A08F97A19098A2929AA2
9199A1949CA0949EA0969FA297A0A397A1A398A1A498A3A398A4A59CA7A89CA6A79CA6A7
9DA7A79EA9A89EA9A79DA8A59DA8A69EA9A39FA8A39FA7A2A1A9A1A1AAA0A0AAA19FA89E
9EA89C9DA99C9CAB9B97A89797AA978E9F8C454A46373B37373B3530332F2A2C27272A24
2D312922241F1D1E1A3A42333C4533343C282226151B1C0D1514091111071114090E1207
0D11050C11050B11070B0F060B0E060A0E05080A03070701080800080800070801191D0C
222916262E1C28311E28311C2B341C2B331B272E192429142226121E21101F2213232617
25281A242919252B1A2326171F201419190F16170D2024152529182125152126121E2511
1D2310171D0C0F1306060901
4D58674F5A6E535E7454607754627755627553607253616F53616E54636F556472546273
5664755967785A687A5967785967765B69765C69755D6A775E6A775D6A785E6A79606C79
616E79616E7A636F7B65717C67727E6873816872836974856A75866975866A7586697687
6876886A78896A78896D7A8A6E7A896F7A8A707A8B707B8E727D8F737F9074808F768291
7883947985947987957984947C87967E8A977F8A97808A99818C9B808B9C7F8B9C808B9C
818B9C848C9D878E9F878F9F88909E89909D8C939F8D959E8F979F9098A19199A2929AA2
9199A1949CA4959EA5949FA595A0A596A2A499A4A698A3A699A4A79AA6A79CA7A69DA8A7
9EA7A89FA9A99EAAA89DA8A59EA9A59FA9A4A0AAA49FA9A3A0A9A3A1ABA2A1AAA39FA8A1
9FA9A09EA99D9CAA9B99AA9A97A89794A691525852353737373A362E2F2C2425221E1F1C
31352B2A2E2320221922251A434D344753351E200F1D1E0F18170C14140B13140A111309
0E12050E12050C11060B0D050A0D050A0C04080902080600080600080701060600181C0F
232917282F1C29321E29331D2A321A293219252E16222A152129141E2313212515252A19
282D1D2A301F2B321F2C321F292D1D25291A2125192830203038242E342129301B282D18
262B16212714161A0C070801
4B58654E5A6B525E72536074546075546174535F71525F6F52626F526271566474566577
57657959677B5A687A5A677A5B68795B67765C68755E6877606A795F6C7B5E6C7B5F6D7B
616F7B61707B63707C67727F69738168738167728468728568738668738769758869768A
6A778C6D798D6D798D6E7A8E707C8D707C8C707C8C717D8D717E8E737F8F74808F768190
7982917A83927A86937A85947C86967E88977F8B987F8B98808A9B818B9C818C9B828D9B
848D9C858E9E848E9F858FA08791A18992A18C95A28E96A18F96A19198A3929AA3939BA2
939BA3949DA5959DA6949EA695A0A897A3A897A4A897A4A997A3AA99A5A89BA6A89DA8A8
9FAAA9A1ABABA0AAA9A0AAA8A1A9A5A0A9A4A0AAA6A0AAA7A0AAA7A1ABA5A1ABA49FAAA2
9FAAA19EAB9E9EAB9B9BAA9999A99799AB9760696235373A33363828282920211E181615
292D233136282D322322241839402B5260402022151D1E1219181014150D14140C12130A
1012071013060E12070E11070D0F050A0B030A0A030C0A030D0C030C0B04080902171B0D
232815292F1A2B311C2A311B272F18252F16212A111C251019210E1A2110202716252C1B
2A2F1F2C33212E36223139242E36212C341F2E3521313A2638402C363D282E351F2A2F1A
282C18272B181D2111101106
4D5A65505D6A52606E546171556074566175556173546171566472576674586577586679
58667A5A67795A687A5C697A5B68795B67785D68785F687B616A7C616B7D616B7D616D7F
636F7F62707E65718067718168738267738267748467738568728769728969748A69748B
6C768D6E778E6E788E707A8F707A8D707B8C717C8C727E8E747F8F758190768290778390
79828F7B858F7E87917E87917E87937E8795818A97828A99838B9B848C9A868F9B868E9C
868F9D86909F86909F86909F8892A28993A48C95A68E96A68F96A59098A39199A2929AA1
939CA2949DA3959DA4959EA5969FA797A2A998A5A898A4A79AA6A99DA9AA9DA8A79EAAA7
9FABA8A0ABA8A0AAA5A0AAA5A1AAA3A1ABA3A0AAA3A0AAA5A1ABA6A2ACA5A0ABA39EAAA1
9EAA9F9EAB9E9EAC9C9CAB9A9AAA989AAB9869736C37383E3032352224241E201D171813
1F2217272A1D2E342325291B4750398DA679343B2A12120C18191213130C111009101007
12120811130711140714160914160811130811120816180B191D0E16190B1214061F2311
272C172A30192A3019262B152228131F28111B220D181F0C171D0B1E2412272E1B293020
2B32212D34223037243139242F36212F3621323923343925363D28343B272F35202A301C
272B19292D19272B181C1F0F
4A58624E5C67525F6E546073566177566178556076546074566273586574596575596676
5A677A5B687C5B697C5C6A7B5E6A785D69785D687A5F697E60697E626B80616A80626D83
636E83646F836470826571816773816674836674846774866773876974896B758B6B758C
6C758C6E778C6E778C6F788D6F7A8D707B8C717B8B717C8C747E8E758091758291758090
7782907984917A84917C86927D87957F8997808A98828B9A838B9A848D9B858E9B848D9B
848E9C8490A08490A084909F8793A18A94A38D96A68D95A68F97A69199A6919AA58F9AA3
919DA4929EA4949FA4949FA5959EA695A0A696A2A698A4A69AA6A89BA7A99CA8A89EAAA7
9EACA79EACA79EACA69FACA4A1ADA4A0ACA39FACA2A0ABA3A3ACA5A4ADA5A1ACA49FACA3
9FABA19FACA09FAC9F9EAB9E9CAA9C9DAC9B76817738383D333635272B2820241E1D1F17
1C1C121D1F13373F2A3F49324C593E95B18144513A10110A1B1E1215150A111204121204
13130512130614160915170A191B0C191B0E18190E222816242C18212915202612272D19
2A311C282F1A242A141E240E1B210D1D240F1E25111F2510222713272C192B2F1D2C3120
2C32222F3625323826313925303723303623323824343926383E29363D293137252D3322
292F1E272F1C282E1B242817
4C58654F5C6B525F71545F76545F77555F77545E76555F76576276586477586477596578
5A667A5C697C5D697D5D6A7C5E6B7B5C69795C687A5E697E5F697E606A7F626C81636E82
636E83636F84636F836371826471816573826775856775886673866774876975896D778A
6E788A6D778B6E778D6F788E707A8D717C8D727D8C727E8B74808D768190768292758191
76828F7884907985937A85957C87987D88987F8A997F8A9A818B9B838E9C838D9C838E9C
828E9D828F9E83909F8491A18693A38995A48B95A58D96A58F98A58F99A48F99A38D99A3
909CA4919EA4939FA494A0A594A0A695A1A796A1A897A3AA9BA6AD9CA6AD9CA8A99DA8A8
9EABA99EACA99DABA79EABA7A1ACA5A1ACA3A1ACA2A2ADA3A4AEA4A4AEA3A3ADA4A1ACA6
A0ABA59FABA39FAAA2A0AAA09EA99E9EAC9E7D877E3D3C4238393A28292822241F1E2018
1C1D111F20134B573C536043525F43859F7246523817190C1E1E10191808151504171706
20211027291A1B1C121B1D13232719232A1A202716262E1A29311B28311A2A321D2B341D
2A331E28301B2229141C230E1E2610232C15262F172A321A2C331C2D33202D32202D3221
2F352632382A333929353C29333927303624323725383E2B3E45303A422C353C292F3526
2A3022272D1E262C1B25291A
4E5969505C6D536073535F75545F75525D74545E75556076566277586578576478596579
5B667B5C687C5C697D5E6A7F5E6B7E5C697C5B677C5D687D5E697E606B7F616C80636F81
646F816370826472846573836573836572826673836874856775856774846873866C7789
6F7A8B6F798C6F798E707A8D717B8D717B8D727E8D727E8D74808F768290788492788392
78838F7985917A87957C87967E88997E899B808A9B818B9B818B9B828D9B828D9C838E9F
83909F83909E85919F8793A38894A58A94A58C96A69098A89099A6919AA6919AA6929DA6
919EA392A0A193A0A394A0A395A1A497A3A798A3A999A3AA9BA5AD9EA7AF9EA8AC9FAAAA
A0ABAAA0ABA99FAAA8A0ABA8A1ACA5A1ABA3A2ACA3A3ACA3A2ACA3A2ACA2A3ADA2A2ACA4
A2ACA6A1AAA4A1AAA2A1ABA19FAA9FA0ADA0828981403E4638383C2D2D2D2122211E1F1B
1A1A132A2D1F5967485360424B563B6374504F593A42472B32321C282612211E0D363824
545C434F58421F20182022192B30232B32222A32202A311E2C331E2C341F2D36202B351E
2A321D2D361F2D351D29301929311A2A331C2B331C2E361E2E35202E34222D32212E3422
303625333928343B29373E2A363C28363B27353B263E4730404A3238422B333D282C3523
262D1E242A1C24281B222518
4E586A505C70525F74525E73535E74535D75545E77566179556177576378586479586579
59657A5B677C5C687B5A677A5C697B5D6B7C5D6A7C5D6A7D5E6A7E5E6A7F5D6A7E616E80
636F806470806472816572816673836774836774836873836775846975866B76886D7789
6E78896F788A70798B707A8A707B8B717C8D727D8E737E90737E91768194778293798592
7884907A86917B87957D87957F8897808A9A818A9C838B9E838B9E828B9D838D9E838D9F
8490A18491A08693A18995A38B95A68B95A68E97A89097A89299A8929AA7929AA5939CA4
949FA394A1A195A2A197A3A299A4A598A2A599A3A89BA5AA9CA6AB9DA6AD9EA8AD9FABAB
A1ABA9A2ABA9A2ABA9A2ABA8A1ACA7A0ABA5A0ABA5A1ABA4A3ACA6A2ACA5A3ACA4A2ACA4
A3ACA4A1AAA19FAAA09FAAA19DAA9F9DAA9B8D988B47484C38393D2E30312325241C1D1B
161613363D2C5665485462464D5A3F434D354B553A63704C5D644455583C3D392A828E6E
8899794B52432D2F2627281F2E32252F34252F35242C33232B33232C35242F39252F3A25
2E3823303A213039202D341D2C321B2D341D2D341C2C331C2D341E2D33202D32212D3221
2E3423313826333928343B28363D29363D28363C274149323E4730353E28323C262A3320
242C1B24291B25281D22241B
4C5768505C6E535E73525D74545E76565D77565E78576079586278586477586577596576
5966775C697A5D6A795C6A785D6B795C6A795C697A5E6B7D5E6B7E5E6B7F5F6C81606C81
616E82626E8164708266718367718367728568748667738568758769768A6B778A6D788A
6D778A6E788A707A8A707A8B707A8D727C90727D91758093767F92788193798392798590
79848E7A85907B85947E87977E8899818B9D818A9C828B9D838D9E848D9E838D9E858E9F
858FA08591A18694A38794A38995A38B97A68F98A79099A6929AA7949BA7949DA6959FA6
949FA594A0A195A2A197A2A299A4A599A3A69AA4A89CA6AA9DA7AC9DA7ADA0A8AEA0A9AC
A1ABACA1ABACA1ABAAA1ACAAA1ACAA9FACA89FABA6A1ADA7A2ACA8A2ABA8A3ABA9A2ACA7
A1ACA5A0ACA39FACA19EAAA09DAA9E9EAC9B93A18F4E4F503A3A3D2E30311F2021171918
111211333B2D5360475361484E5D4446533C57654A6A7B5B707E5D8C9B735C5F4AB4CA9E
88987B42473C3C4134373A2C37392A363A29353C2A343C2A3039272D37262E39272D3826
2E3824313B25303A232E36202C321B2D341C2B321B2A2F1B2D331F2E33212E33212D3222
2E3525303727333C2A353E2B363E2B363F2A363E283E472E3C452D353D27313A2529331F
242C1B23291924281B24261C
4C5967505C6D535F755360775561785660785660765760755964755A6776586675596776
5B68775C6B785D6C7A5C6C7A5C6C795B6A785C6A795F6D7E606C7F5F6B80606C81606C82
616D85616D846470846571846671846672866673876875866875866975876C778B6E788D
6E788D6E798C707A8C717B8E717B90737C93747E947681947781937883927A85937A8591
7B86917B85927E87977E879A7D889B7E8A9C818B9B828B9C838C9E858EA0868FA1878FA1
868FA2858FA38591A38693A48895A48996A48E99A7919AA6929BA4939CA5949FA895A0A9
95A0A894A1A694A1A495A1A498A3A69BA5A99CA6AC9DA7AD9FAAAEA0AAAEA2A9AEA1A9AC
A2AAACA2ABABA1ACABA1ADAAA1ADA9A2AEA8A1ADA8A1AEA8A1ADA8A1ACA8A2ABA7A3ADA6
A2ADA4A3AEA3A2ADA0A1AC9F9FAD9F9FAE9D98A7935154533535382F2F302526251F2120
1817182F332B4E5946525E4A505B47434C3B535F4969785C69765BA1B89086957ABDD8AD
727F6749503E424835373A29343525333525353927343C282F37242C36242D37262D3725
2F3824313B26323C272F38232D33202D3320292F1C272D1B2A301F2D34212F36232E3524
313828333A29353F2A36402B343F2A36402A3540293E492D374025323B212D361E29321C
272E1A272D19262B19272A1C
4C5867505D6D53617453607755617954607755607556617758657959677A5867795A687A
5A68775B69775B6B775B6A7A5B6B7A5B6A7A5B69795D6A7B5F6C7D5F6C7F5F6B7F5E6980
616C84616C856370876471866673866573856573856774836775826975836B76876E7789
6D78896E7B8C6F7C8D707C8E727C8F737D91757F94768192768291788492798591798691
7B88917B88937D88977F899A7F899B808A9D828B9D838B9E838BA0868EA2868FA2868FA2
8691A38590A28592A28695A38897A38998A28C99A3909BA5919CA3939DA4949EA7959FA9
96A1A996A2A795A2A695A2A796A3A899A6AB9BA7AD9CA8AE9DAAAE9FAAAD9EA8AA9EA9A9
A1AAAAA1AAAAA2ACAAA4AEABA4AFABA4AEABA3AEABA2ADA9A1ADA9A2AEA8A3ADA6A5AEA5
A4AFA3A3ADA2A3AD9EA3AE9FA1AC9F9FAD9E9BAA9B595D5E2F2C37312F3428272B212123
1C1B1D2E2F2B535C4C586151474C4230312B3C3F336773595E68539DB18DACC29DAAC29B
59644E383E2C3438252525172525182A2C1F2E32232D32232A2F20282E202A32222C3522
303923323C24323B252F37232D35222B332028301E272F1E28311F2B34202D36222E3623
313825353C29363D2A363D2B353D2A343C28333D283B452D343F27303A222C351C28321A
262E18252C16252A16262A19
4E5B67515E6C546171546074556076555F77535E7556617958657B59667C5A677C5A687A
5967765B68765C6A785B697A5C697C5E6B7D5D697C5C697C5D6A7E5F6C805E6B7F5E6B80
5F6B82606C82626F836470856773856773846773846774836975846974826B75836D7787
6D78886E7A8C6F7D8E717D8F717D8D717D8F747F9276829277839178859078858F79878F
7B88917E88947E88957F88967F899980899C81899D828B9F838CA0868FA28790A28690A2
8692A28591A185939F8796A08897A18A98A28B99A38E9AA58F9AA5929BA6949DA8949FA8
949FA895A1A996A2AB96A3AC98A5AC99A6AC9BA8AD9BA8AD9CA9AC9DAAAD9DA8AA9EAAA9
A0ABA8A1ABA7A4ADA9A5AEAAA5AEAAA5AEACA4AEACA3AEABA3AFACA1AEA8A1ADA4A3AEA3
A3AFA3A4AEA3A2ADA1A3ADA1A1AD9F9FAE9D9DAD9C5D6261302D382D2C33232128201D21
201F203538325F6A5771816843473F302F2D30302D5E69535A634F7785678EA27C819571
4E5A42363D2B2A2F1E1F22151D1F1523251B26291E282C1F272B1D25291D272C1E2A311F
2D35202F371F2C321D292F1E2B32202A332027301E272F1E26301D28321E2B36202D3821
303820323922333925343B27353C273138243037243A422B343D282D36222A321E28301B
262D19232A17242917262B1A
4E5B68515E6D546071545F72545F74566177555F7857627C59657F59667D59667B5A687A
5C69795C6A785D6B795C697A5C697D5D6A7E5D697D5C697C5D6A7D5E6C7F5D6A7E5D6B7E
5E6B7F616E81636F826670856770866972866A75866B75876C76886C76876C76866D7788
6F7A8B6F7A8D707B8E727E8F727E8F727E8F7481907582917683917784917884907A8790
7B88907D89917D88927F88947F88958089987F8A9A818B9C848D9D848E9F858FA08690A0
8791A18792A18694A08795A08A97A38E9BA68F9BA8909BAB909BAA939EAC949EAB949FA9
94A0A896A2AA96A4AB96A3AB98A5AB99A7AA99A7AB9CAAAC9CAAAB9EAAAB9FABAB9EABA9
9FACA7A1ADA5A4AEA8A5AEA8A4AEA7A5AFA9A5AEA9A4AEABA4AEACA3AEABA3AEA7A3AEA4
A4AFA4A2AFA2A1AEA2A1AEA1A0AEA09EAE9D9DAE9B676F6B3E4146303137242429222022
1C1A1B373B3356624F61705A55604F40453B373A3356614E5C6852545F4958654B57664A
4F5C41373F2D29302121261A1D211521241724281A272C1C252A1B212416222517242A1A
272D1C252C1B202418262D2028302129312028321F28311C28311B29321B2C361E2E371D
2F371C2F361C2F361E323A23323A232D332031382439412A343C263037232C33202B321E
2A301E272D1C252B1A272E1E
4D5B67525E6E535F74535E76545F77545F7755607A57627D5A65805A65805A667C5C697C
5D6A7B5C697B5D6A7B5C69795D6A7D5C687E5D6B7E5D6C7E5C6C7C5D6D7B5E6E7A5F6F7D
6170816372826371836471846671856771856973866B76876B75876D77896C77886E788A
6F7A8B6F7A8D707B8E727D8E737F8F73808E74828D7683907683917784927884927A8893
7B89937D8B927D89947F8995818B95828C98828D99828C9B838D9B858E9B85909C86919C
88939F88939E88949E8A96A18C98A48E99A78F99A8919AAB919BAB919DAB939EAB929EA8
94A0A994A1A895A3A896A4A898A5A99BA8AA9CA9AC9DA9AC9EA9ADA0AAADA1AAAFA1ABAD
A1ABAAA4AEA9A5AFA9A5AEA9A5AEA7A5AEA6A5AFA8A6B0AAA6B0AAA6B0AAA5AFA7A4AFA3
A4B0A3A4B0A1A2AF9FA1AD9EA0AE9F9DAC9F9DAE9D79857C454A4D363A3D2C2E2E272825
22211D31322A474C3F4A5245505C4B444E3F39413357664D606F544D59414B573F48533B
454E37353B2A2D322425281D1F221822251924291C22281A1F25161D2113202516232919
252A1C252B1D191C1424281C272D1E272F1E29321E2B341E2C341D2D351D2E351E2F361F
3037202E351F30371F3036212E34202B301E303621384028333A212F371F2B331F2A311F
28301E292E1D272D1E2B3123
4C5A69515D70535F77555F7B55607B55607B55607B57607C5A637E5A657D5D687D5C697B
5E6A7C5E6B7C5E6A7D5D6A7D5E6B7E5E6A7F5E6C805E6C805D6C7F5D6E7E5D6E7C5E6F7D
60707F637181616F806270826471836672856872866A75876C77886B77896C77896F798A
6F7A8B707B8D727D8E737E8E74808E75818D76838F7783927783937782937884947A8795
7C88957F8B97808B97808996808A95818B97828D9A828D9C838E9C848E9B848E9B86929D
88939F88929F8994A08C96A38F99A78F99A89099A99199AA919AAA919CAA929EA9929FA7
94A2A995A2A996A3AA97A5A999A6A79DA8AA9EA9ACA0AAAFA0A9B0A2AAB1A3ACB2A4ADB2
A3ABAEA4ADACA5ADA9A6ADA8A8AFA6A7AFA6A6B0A7A6B0A7A6B0A6A7B1A5A5B1A2A5B1A1
A4B09FA6B19FA5B09EA4AE9EA1AE9E9FAD9E9DAD9D829083484C4D393B3C2F31302A2B28
28272229282238382F494E3F4852403F4838373F2E5463476476554F5C404A563B495338
4349313639272F3122282A1E21231921251A242B1F222A1E1F271A1F2618222A1A242B1A
222A19222819161A0F1A1D11202214222716272E1B2A321D2C341D2E361E2F3720313823
3339252F36233036232E34222D32202A2F1E3137243C442C333A222F371E2B331D29321E
282F1E292E1E2A2F202D3323
4D5A6B515E72535E76545F7A54607C55617D55617B56627A59637A5A647B5D687D5D687D
5D697C5D697A5D697B5D6A7D5E6A7F5C697E5D6A805F6C825D6B805D6B805D6B7F5D6C7D
5F6E7D62717F61707E63727F6573806673826975866A75886B78896B78896C7A8A6E7A8C
707B8D717C8F727E8E727F8D737F8B73808B73818D7583927783937783947884957B8796
7D8896808A96808996808895818896808999838C9C828D9C828D9C848E9F858FA08691A0
8692A08792A08A94A38D98A78F9AA98F99A9909AA8909AA6909AA5929DA6929EA693A0A6
95A3A695A3A797A3AA99A5AB9AA5AA9CA7AB9FA9ADA1AAAFA1A9B0A0A9B0A2AAB0A3ABB0
A3ABAFA3ACACA5ACA9A6AEA9A8AEA7A7AEA6A7B0A7A7AFA9A6AEA7A7B1A6A6B2A4A6B1A2
A4B0A0A5B1A1A6B1A2A5AFA1A3AEA0A0AC9D9EAD9C8B978A484A4E37363B3231322E2D2C
2C2C2A2C2C2732342B4D56434A54403C4533333A2B48533E697A5B515D4349533A495138
454B323A3E2730341F292A1A23241721231722261A23281B24291D24291C232A1B262C1B
2227171C201216180D12140A15160C191C0E282D1A2C311F2E3420303723323925323927
343B27353C283238242F34222E33212A2F1E3137243B432D333B252F38212B341D2B331F
2B3220292F1F272E1D2A311F
4E596E525D74535F78545E7956617D555F7D545F7B56627B58657C5A667D5A667C5B677D
5B687C5A677C5C687C5C697D5E69805D68805D6A815D6A815C6A805E6B815F6C81606D80
606E7F62707E63727D65747E65747D66737F6974836B76876C76896B76896C788A6E7A8D
717A90727C91747D90757F9074808E75818D75818D75818F7783937884977883967C8698
7E87997F8898808899808998818998818A9A838B9B838C9B848E9C848E9F8690A18691A1
8792A18793A08994A38C97A68D98A98E98AA8F9AA8909BA6909BA6929DA7929DA5939FA6
93A1A695A2A796A2A799A3A79AA4A99DA6AC9FA6ADA0A7AE9FA7B09FA8B0A0A9B0A2AAB0
A3ABB0A3ABAFA4ACADA4ACABA6ADABA6ADABA7AEABA7ADABA6ADA9A4AEA6A4AEA4A4AFA3
A3AEA1A5AFA2A5AFA3A4AEA3A3ADA2A2AD9FA0AD9E8C988C494A503C3D413A3B3B383834
32312D2E2C2832332C525B48525D48434C39343B2B424C37697B5A535F444A533B474F36
454B3342472F373A272F2F1F2A2A1C28271C282A1E26271D24261E23251D2023191F2217
1D2114181B0E13160A0F13070D0F060F1207272F1A2C331E303622323825333926323827
3239273239263036232E34212D32202B301E2D3422313C262D37212B351E28321C28311C
2A311E292F1F262B1D2A3220
4E596D515A72535E78545E7B565F7C56617D57627D58637D59657D5B687D5B687D5B687D
5B677D5A677D5C687E5D6A7F5E69805C66805C677F5B687E5C6A7F5E6B7F5F6D815F6C81
5F6C7F616E7F62707D63717C63717D6672816872856A73876A73886C758A6E778B70798D
717A90747C91747D90757E907680917581907682907582917783947883987983987A8498
7B85997E879A818A9D808A9D808A9C828C9C828C9D838C9D838D9E848EA0858FA08690A1
8790A28791A48994A58994A58A95A68C97A88C96A98D98A98F9BA88F9BA6909DA693A0A7
94A0A896A1A997A1A99AA3A99CA4AB9EA5AC9FA7AF9FA8AFA0A7AFA1A8B1A2A9B0A2A9B0
A2ABB1A3ABB0A3ACAEA4ACAEA4ACAEA5ADAEA5ACADA5ACABA5ADAAA4ADA8A4ACA7A4AEA5
A4AEA4A5AFA3A6B0A4A3ADA3A2ACA2A1ABA0A0AC9F919E924D4E544244484347433C3F38
30302A2D2C253030294D53444C53423E45362F34283C44316E825D566547475138485239
464E35454B344347323C3D2C37382B32332A30302A2A2A2424242020211C1E21191E2117
1D2115181B0F13170B1014070E11060A0C042128182F38232F3822313924303925303925
3039242E36232E36212E361F2D331F2A2F1E2C34222F3A252B351F29331C2A331C2B311C
2B311E2B2F1E282B1C292E1E
4D596A505A70555F7756607A555F7A57637D58637E59647F59657F5A657E5B677C5D687D
5B687C5D687E5D687F5D68805E69815E69815D68805D697F5E6A805E6B80606D80606D80
616D81626F816471816673826671836772856973896A758A6A74896D768C6F788E707990
727B91747C92737C90747D91757F937581937681937782947883967984987A85997A8699
7A85987C879A808A9D818A9D80899E818A9E838B9F838C9F848DA0858EA0858E9F8791A1
8891A28892A48A94A68A95A58B97A78C98A88C97AA8D98AA8F9AAA909DA9929EA8949EA7
96A1AA99A2AB99A2AA9BA5AB9CA4AB9EA6ACA0A8AFA0A9B0A0A9B2A0AAB4A1AAB3A0A9B1
A0ABB1A1ABB0A2ABAFA5ADAFA5ADAFA5ADAEA6ADADA6ADACA5AEABA5AEA9A5AEA8A4AEA6
A5B0A7A5AFA5A5AFA4A4ADA4A3ADA3A2ACA3A0ABA196A2985253583C3C434142413D3D38
32312A2F2E253230274A5040494E3E3F433533362B3A3F3170815F59674C454E3A4A543E
48513B464E384B4F3A4748374545373E3E3539383233332E2A292725262220231A1D2014
1A1B1016160D13150B1114090F1208090C041D25162F39252F38253039262E37252D3824
2D38232D38232C36212D37202B331F2A311F2A33202C36222A341F29341E2B341F2B331E
2B311C292E1C2B2E1D2D3220
4D5869505B70545F7556607757617959647C5A637E5A64805B65815A64805B677F5C687D
5B687B5C697C5D697F5D6880606A82606A835F68825F6882606983606A82606B80616D81
626D81616E816370836672866873866973876A748A6C768B6C758B6C758C6E77906F7992
717B93737D93747E937580937480927580927783937883937982937A83947B84977E8698
7E88987F8899818A9B818A9D81899E818A9F828B9F838C9F848D9F858FA08890A18991A1
8991A28A93A58A93A48B94A68C97A88D97AA8E98AB8E99AB8F99AA929DAC949EAB949EA9
969FAA98A1AA99A1AA99A3AB9AA4AA9CA6AB9FA8AE9FA8AF9EA9B19EA8B29EAAB29FAAB1
9FAAAFA1ACAFA2ACAEA4ADACA4ADABA5AEABA7ADABA8AEAAA7AFA9A6AFA7A7B0A5A6AFA3
A5AFA4A5AFA4A6AFA5A6AFA5A4AEA4A2ACA2A0AAA19BA89C6165653E3D434041423E3E3A
36353033312B33312A484B3C4B5140414537313329363A2B6D7D5B667556454B3A4A513F
48503E454C3A5156415D634B5559454C4D3E42423742453B29282626272221231C1C1E14
19190D16160913140912140A1012080E1006171A0C282F1C29301B29301E262D1D252D1D
2831202C37232A352228311E28311D29321C29331D2D381E2D381D2B341C2B331D2B321D
2A301D292F1E2B2F1F2E3321
4D566950596F535D74565F765860775A637A5A637C5A637F5A64805A65815B66805B677E
5A677B5C697C5D687E5D687E5F69806069815E667F5F6780626A81616A80616A80616D82
636E816470826470836671856872856972866A73886C73896D74896D748A6E778D6F798F
727C92757E94757E95757E95757F95757F947680947782937883947983937A84937C8594
7D86958088968088997F889A80899D7F8B9E7F8A9D7F8A9B818D9C848E9D868F9E88909E
88919F8891A08993A18B95A48C95A78C96A78E98A88F9AA9909BA9929CAA939DAA959EA9
969EA997A0A998A2A999A3AA9BA5AB9CA6AB9EA7AC9EA8AD9EA8AF9CA8B09CA9B09DABAF
9FABACA0ABAAA1ACAAA4ADAAA5AEAAA5ADA9A8AEAAA9B0A9A8AFA7A6AEA5A6AFA3A6AE9F
A6AEA0A7AFA3A7AFA4A7B0A4A5AFA3A3ADA2A1ACA1A0AEA0686D6C3937404040423A3A38
3E3F3A42443C474B3F4B50414A4F4041473833372C32372A667757708160444A39474E3E
464D3E414638545B46899A766A725A636A566068564D53482B2B2927292520211B181911
13130A111006100F051010061213091213091416092328142328122125121D21101E2313
262C1B2A321F252D1C1F2516222918262F1C29321C2D381E2D371D2E361C2D341C2D331C
2A301B2A2F1D2C31212D3322
505969545C6E575F7657607659627959647A59657A5A667D5B677E5B687E5D687F5D687E
5B677C5C677C5C677D5D687D5D697E5D697E5E697F616B80616B7F636D80626E81637082
636F816773836872836871846872866972866A74876B75886F7688707788727A8A727B8D
747C90777D94777D96757D97747E96757F95778095788296788396788494788493798494
7C86957F899681899A80899B808A9C7F8A9C7F8A9D808B9C818C9B838E9C848E9B87909C
89929D89929E8B95A08D96A28E96A38F97A5919AA8929CA8939DA8949EA8959EA8959DA7
959EA697A0A69AA3A799A3A79DA6AA9DA7AB9EA9AC9FA9AC9EA9AD9EA9AE9DAAAE9EAAAC
9FABAAA0ABA8A3ADA9A5ADABA7AEACA8AEABA8AEA9A8AFA7A7AFA5A5AEA3A5AEA3A6AFA2
A6AFA1A6AFA2A9B0A4A8AFA3A5AEA2A4AEA3A1ACA2A1AFA36B707235333E3F3F3F373633
5155465358465E644F5A604B4F54434D54433C42353940336070566B7C5F4A5341495240
414739363A2E4E564497AC888B9C7E87957A86947A585F522928282628231E20181A1C12
15160B1112060F0E04100F0514130916170C181A0D1D22101E240E1B220D191F0D191D0D
262B192E35221F231714160E202618252D1C2A331F2F37212F361E3036203137212F3520
2C321E2C321F2D3323303726
4E5869535E6F5962785A637B59637B58647B57637A59657B5B667B5B667C5E687E5F697F
5D687D5B677C5C677C5C677C5D687C5F6A7E5D687E5E697F5F6A7F606A7F616D80616E80
626E806571826872836872846972876A74866A74866A74856D77886F7889717A8A727B8D
747C8F757C92767E95757E97757E97767F967981977981987A81977981967B84957E8799
7F89997F889981899C80889D7F879D80889D818A9F838CA0828B9E828C9F838D9E868F9D
88919E8A929F8B949F8D96A08E97A19098A29299A4939BA6949BA8949DA7949CA8949BA8
959DA897A0A999A3A89AA3A79DA6A99EA6AA9EA8A99FAAAB9FA9AB9EA9AB9DAAAA9DAAA8
9FAAAAA1ABABA2ABABA3ABAAA5ACABA6ADABA8ADA9A9B0A7A8B0A6A6AFA4A6AFA4A6AFA4
A6AFA3A7B1A3A8B0A2A7AFA3A5ADA3A3ADA3A0ABA3A0AEA4737A7A3E3E473E4041363836
5159494F5543626A51616951515745525B49414A3B3B43355A684F697A5C4F59434C5540
40453433342950564491A4838D9F8191A28499AB8C6C7763221E1F2423202022191A1B11
15150B121207110F06111006181B0B1C1F0E1E21111E24121D24121A2111171D0F16190F
3239293D4532151712090A081E24182D362330372232392230361F30361F3236222F3422
2D32222D33222E34232F3625
4C586B515D7155617655607957627C57627C58627A59637A5A647A5B647B5B647C5B677C
5A677B5C697B5D697B5C687A5C697A5D697C5D677D606A7F616B7F5F6A7F606D81616D81
626E81646F836571846772846872866974866A74866A74876D768B6F778C70788D717B8F
727C91737D93747F95757F97777E98787E987A80997A80987980967980947C82967F8497
80859980869A80889B80879B7F869B80879C80899E818BA1818CA1838CA1848DA1858D9E
88909E8892A08A93A08C94A08B95A18C95A18F96A39199A5929AA6939BA89199A8929AA9
949DA9969EA9979FA9979FA898A1A899A3A79BA5A89CA7A89DA8A99EA8AA9DA8A99DA8A7
9EA9A9A1A9ABA1AAABA2ABACA3ABACA4ACABA6ADAAA8AEA9A6AFA5A6B0A5A5AFA4A4AEA3
A5B0A4A4AFA3A5AEA1A5AEA3A6AEA3A4ADA3A1ACA1A0AEA27F888247484D4245453A3E3A
40453C474E3F58604B68745A4F5645535A48454D3D394031515E466A7D5A5563474E5940
4A523B3A3E2F4C52418EA1808A9B7E8C9C8196A689818F752E2D2925221F22221C1C1C16
17160E131209111107121206181B0B1B210E1C21101F25131E24141D2314191C0F13140C
2A2E243E47381A1D1A0B0D0C181E14303A252E3721333A2331371F3036203137232E3423
2D32232E3325313725323825
4B576A4F5B71546077545F7757627A58637C5863795964785A66795C677B5C677C5B667A
5A67795C687B5E6A7B5D69795E6A7B5E6A7C5D687E5F697D606B7F5F6A7F616D81606D81
616E81646F836670846770846772856973876A74886A73896C748B71778E737A8F747C91
747E92758093768095767F97777F98777F987880987881977981967B83957D83957F8395
7D81947E84987F869A7F879B7F879B7F899D7F8A9E7E8A9F7F8B9E818DA0838DA0858DA0
868FA08891A18892A28B94A48B95A58A95A58C96A58E97A6919AA8929BA9919AA8929BA7
929DA7949DA997A0AB98A1AC98A1AC97A0AA9AA3AB9BA5AB9CA6AC9DA8AD9DA9AC9DA8AA
9EA9ACA1AAAEA2ABAEA2AAAFA4ACB0A5ADB1A4ACAFA5ACABA5AEA8A6AFA6A6B0A5A4AFA3
A5B1A4A3AEA3A4AEA3A4AEA3A4AEA3A4ADA3A1ACA2A1AFA48B968E47484D3F4041393B38
3F423B4B51454D53466B79624B52454F5749475041363C314B57446D815F58674A4D5940
4B573E444E3948503E8B9D7B8C9D7F8A9A7D8E9D828F9D824D50462825242524221F1E1C
19191415140F14140D15160C1A1E0F1C21131D22132025152126161F22141A1A0E16150C
1E1F172D31283E47390F11110F130F2932212D35223036232F35222E35212F36232F3421
2E3220313423343827353A28
4E596C505B72525E77515D76535E775460765561755763745865745B67785D697C5B667B
5A677B5B687C5B687C5B687C5D697D5E6A7E5D6A7E5E6B7F5F6B805F6B80606C81616D82
606D82636F82657083666F846670846871876A73876A73876D778A6F798A70798A727B8C
737D8D747E8E757E91768094758096757F967580977782997982987781967A82957C8396
7B81957B82967D84987D85987E889A7F899D808BA1808BA17F8CA0808DA0818DA0838D9F
8690A18791A28790A28892A58994A78894A68A95A68B97A68D98A68F9AA58F9BA3909BA4
919DA6929EA895A0AA96A0AB97A1AC98A1AC99A2AD99A4AE9AA6AF9CA7B09CA8B09DA8AF
9DA8AE9EA9ADA1AAADA2ABAEA4ABB0A3ABB0A4ACAFA3ACABA4ACA8A4ADA7A3AFA7A2AFA5
A2AFA3A2ADA2A3ADA3A4AEA4A3ADA2A2ADA2A0ABA2A0ADA38F9C934A4A513E3E44393A3D
474D475A635550564C6875624951484C564B454F44353C35455042697D6059694F4C5842
4C574247513F4750407F90728A9C7E88977D89987F8997816973643E413C262727212224
1E1F1F191A191818141A1C131D20152123182224182427192527192022151B190F1A1810
515C443F4738596550111211121411252B1F2A31212C32212D32202E33212D33212F3421
2F341F333723363927363927
4E5A6C505D72535F77535F77536077556276546273566373576474596676596678596679
5A667A5B687C5A677B5A68795A67775C69795C697C5E697E5F6A7F5F6B7F5F6B805F6B81
5E6B80616E81626F826370826571856671866973876973876C77896F7A8B707A8B727D8D
717C8D727D8E737F8F7580927581937581947580937780957780967981967A8297798297
7A82977A83977A84967C86987E879A7F899D818A9E818AA0808BA1808CA2818DA3828DA2
8490A28590A28691A28792A48892A48893A58A94A68B96A58C97A48F99A4919BA3929DA3
939EA4929DA6949EA896A0A996A1A998A2AB98A2AC99A3AD9BA7B09CA7B19CA7B09DA8AE
9DA7AC9EA8ABA0AAABA1ABAAA4ABACA4ABADA4ACADA4ACABA3ACA9A3ACA7A2ACA7A1ADA6
A0ADA4A1ADA3A3AEA4A3AEA4A2ADA2A1ADA29EAAA19CA99E8E9B904D505443454A404445
4D544D636D5E52584E5B65584C544B4B5448444D41353B334751416171565C6B514F5B45
4D5744495142495043808F74899A7E88967E89978084917D85937D727D6A201E211F1C21
1B191D161417151313191A151D2016202217222418272A1B2A2C1E2222161C1911191611
63705767775E4751441010131518182F382D2F382C2F38282C34222D34212C34212D3321
2D3421303622333925363A27
4A586A4D5B70505E74515F76525F775462775563755664755765745865755966765A6777
5B68785B68795B68795C6A795A67775B67785D697D606980616B84606B82616C83616D81
5F6C7F616E7F6270816471836572856873886C768B6D768B6E788D727C90737D91737D91
717C91727D92747F927681937682927682937882967781957781957882987A839B7A839B
7B849B7B879B7C869A7F899C80889B808A9E808A9D808BA0808BA1818CA3828DA6828FA6
8390A5838FA3838FA18691A28893A48B96A88D97A78D96A58E98A69098A5929AA6939BA4
939DA4949EA5969FA597A0A797A1A798A2A798A2A89AA4AB9BA6AE9BA6AF9BA6AF9CA6AE
9DA7AE9EA8AE9EA8AD9FA9ADA2ABADA4ACADA3ACACA2ACABA3ADAAA2ADA9A2ADA8A2ADA9
A1ADA9A3AFAAA1ADA6A1ADA59FABA49DA9A09BA89E99A79B8D9B90575C5E45484E4A5152
616C605C655751574A52594B4C54474851443F463A33382E3E4636647457617156525E48
4C5643484F4045493E7A88708D9F828998808B9A8386937F8C9B8385947D2422231B161B
1D1A1C171416141011141210191913212318313424373A2933362724261A1C1D1317140F
545C487E906F55604F1C1D1E141519323C34333D322D37292933222A33212A32202A3320
29311F2B33212F3824333A27
4856684B596C4F5E71505D74515D74535F765563765765775865755966755A66775C6878
5A66795B677A5B677B5B687C59667A59667B5C687E5F69815F6A82606B83616D83616E80
616E7E626F7E63717F6572836873866A76896C778D6F788F707990717A90737C91727D91
737E9274809474809474809375809376819578839777819677829978839A79839B79839B
7A859B7B869C7C879B7E889C7F879C80899E7F8A9F7F8AA17F8BA2818CA3818DA5818EA5
8490A68490A6838FA58691A48892A58A95A78C96A78D97A79098A89098A9919AA9929BA7
929CA5949EA696A0A696A0A796A0A699A3A899A3A99AA4AC9BA4AD9BA5AF9BA5AE9CA7AE
9DA7AF9DA7AF9EA8AF9FA9AFA2ABB0A2ABADA3ACABA4AEABA3ADAAA2ACAAA2ADAAA1ACA9
A2ADAAA4B0ACA2AEABA2AEAAA0AAA79FAAA49DA9A19CAAA096A49A666C6C45474C4C4F4D
88977D595F5054594A5A62524C54483F463E3438342A2D2A353A3163735864745756624A
5059444B524143483B73806792A5848B9C808D9E8389987F89987F8B9B8031312E1B171A
23211E1B1917100D0D0D090A100D0C34382A5B674C606C534A5241282B2424261F22221F
5A64527A8B706E7D663237311413163C473B323A30293126262E20262E1F272F1E29321E
28331E2A331F2E3621323824
4955684B586B4F5B71505D74505C75525E775460765563765663755865785B657B5C657B
59647C5A657E5B667E5C687F5B687D5B677D5C687F5D68805E6A805E6A7F5E6B805F6D80
616E7F626F7D62707F6472836875876B7A8B6C788B6D798C6F7A8D707B8F707B8F727D90
737F90748092737E93737E94747F94757F95768096768097768198758098778199788398
7884987A859A7A859A7B869A7B85997D879E7D89A17D89A27C89A17E8BA17F8CA2818EA4
8490A68490A6838EA6848FA68690A68791A58A95A78D97A98D97A88E98A9909AAA909AA9
909BA8919CA8939EA9939EAA939EA995A0AB98A2AC99A3AE98A2AE9AA4B098A3AF9AA5B1
9BA6AF9DA7AF9FA9B0A0A9AFA2A9AFA2ABADA3ADABA4AEAAA3ADAAA3ACAAA2ACAAA2ACAA
A1ACAAA1ADABA2AEADA3AEABA1ABA8A1ABA6A0ABA59EAAA59BAAA46B7275494B51454746
5960514F54474B50445F6958525B4F444B443A403D2D31303036315767515F6E5356624A
535B474D534341463A68755F91A584899A7D8D9C828C99818B98808F9E844040391D1718
25221F1B18150D0A080907050B0909454E3E849A787E927476876D3A3F3B434A454E564F
64726173846D6F80694952451B1D1B49554332372D2B3226272D20252C1E242D1E252F1D
26311C2A331E2E3520303521
46526749566C4D5A724F5A74515D77515D77535F7754607856627857627959647A5A637B
59627D59647E59657D59657C59657C5B677D5B677F5C67815E69825C69805D6A7F5E6B7E
5E6B7D606D7D616F7E6573826876856A78876A79896C798A6F7A8B707B8E707C90717C91
727D8F727E8F727D90727C92727C92747E92757F94757F95757F95758097768098778198
7882997984997985997985987A85987B869A7C879C7D879D7D899D7E8B9F7E8B9E7F8BA0
828EA3818EA4818EA4828FA38591A48793A48A94A78B95A98A95A88C98A98E9AAA8F9AAA
8E99A98F9AA9919DAA919DA9919DAA929FAB94A0AD94A0AD94A1AD97A3AE98A4AF9AA5B0
9AA5AF9CA6AE9EA9B09FA7AE9FA7ACA1A9ADA1AAABA2ACA9A3ADAAA2ABA9A1AAAAA1AAAA
A1ABAA9FABA99FAAAAA1ABAAA2ABA9A0AAA79FA9A69DA8A59DABA46D757744474E434747
3E433E42473F41473F6C7A67535E5449514C434B46323735313833475242535F4A505A47
4F5546494F443F423B68766390A4878898808C9B848C99848B98828F9E8540413B1D181C
2522211C1B1813130F0E0F0B0E0F0C292F2568795C7B8D6D8394745F68586B7666717E6E
71806E717F6D71816D616E5C3F463D505B4A343C302B3226272D1F232A1C232B1C262F1D
262F1C28311D2D3520313824
4757694A5B6E4E5E73515D74515D75515D75535F76545F7854607A55617B566179576279
58637959657A58657B5B677D5C677F5C687F5B677F5C68815E69835D6A815E6B7F606D80
606C80616D806270816573816978846C7B866D7B886D7A8A6F7A8B717B8E717D90727C90
717C91727D91727E91727C92737E93757F94757F94757F94778196798398788299778198
77829978859B7A869A7986987A86977C88997C889A7D899B7E8B9D7E8B9E7F8C9E7F8C9F
818DA0808DA1818EA2838FA38491A28793A48994A58A95A68B96A78C98A98C99A88D9AA7
8D99A68D9AA78E9AA7909CA7919EA892A0A894A1AA94A0AB95A1AC96A1AC98A2AE99A3AE
9AA4AE9CA6AE9DA7AE9EA8AFA0A9AEA0AAACA1AAABA2ABAAA3ABAAA3ABABA3ACAEA2ABAE
A1ABADA0ACABA0ACABA1ABABA0AAA99FAAA79EAAA59CA8A09EACA1767F7E41424B3C4043
383D3B3F463F4951478194795E6A5A475046454D44323632333830444C3E4B53444F5747
5057484C51453C3E39646E5F94A78A8A9A808D9D838B9B838A998191A286484B43181215
201E1C1A1A1816161412140F12140F161711262A1E525C44829571717F6676836D788771
77867175836F7584706F7E6A63706063725E394035262B21262E1E232B1A242C1928311C
29321D2C3620303824333926
49576A4B5B6E4E5E724F5D72505C71515D7254607655617856627A556179566278556176
58647758667A59657B5A657C5D677E5E68805E68805E6882606A83606C845F6B825F6B7F
606C81626E826471836875846C79846E7C856F7C886F7B8B707B8C717C8E717C8F717C8F
717C91727D93707D94727D95737D94737E93747F94758196768095778296788398798399
78829979849B78849B7B889B7A86997A869A7C889B7D8A9C7E8B9D7F8B9D808D9E818D9E
828E9E828EA0828DA1838FA38390A28491A28794A48A97A48C98A58A97A48B98A48C9AA3
8D9BA48F9BA68F9BA7909CA8919DA892A0A794A2A995A2AB96A1AC97A1AC99A2AD99A3AF
99A3AF9DA6B09DA6AE9FA7AEA0A9ACA0AAACA0ABABA1ABACA2ABADA2ADACA4ACADA2ABAE
A3ACAFA2ACADA2ACACA2ACAC9FABA99FABA89FAAA69DA8A39EACA1818D8544474C3B4042
3537373A3D3850584B7D8C72687460485045464E433135302E2F2A454A3C4D5443515947
525A494F554740423A5E665795A8898A9A808D9D858B9B848A998293A689586151161111
1E1C171816131515131314111314111414111A1A14353B2C6E7E5F57614C6C7960728067
73806974816B7886707686716E7F6B6E7F6A3A4138292E242B3223272E1C272E1A29321D
2B331F2F3622343925333926
4954664C596A4D5B6E4C596D505C70535E73545F76546078566179566279566278566177
58647959657B5A667C5B667C5D677F5D67805D667F5D66805E6882606A835E69815E6A80
606D81626F826673816D79836F7A83707A83707A86717B8B727C8F717C91727D92737E93
727D93737F95727E95737E97727C95727D95757E97768097757F95757F93768093778195
77819579839879849C7B859C7B869B7A859B7D869E7D889D7E8A9C7F8B9D808C9C828D9C
838F9C828D9B838D9C848F9E8390A08491A28794A48A96A48A96A38B98A28C98A38C99A3
8D9AA38E9AA4909CA5909CA6909CA7909DA6919FA794A1A996A0A997A1AA99A1AB99A2AC
9BA3AD9DA5AF9EA6AF9DA6AE9DA7AD9FA9AC9EAAA99EAAA99EAAA99FABA89FAAA7A1ABA7
A2ABA8A2ABA8A3ACA8A3ACA7A2ADA6A0ACA59EAAA49DA8A29EADA286938B474A4F414545
36373738393652584C68745F616B59555E4F41473F2F322F2C2D294043364D5341525945
535A474E5444464A3C5A614F96A7878C9B818D9B858B9B868A9A848EA1875B6455191516
21201B1E1B181C1A1815141212110E12120E16150F363C2A4C573E35382A3B3E316B775F
6E7B65717F68788870798B7073866C708167353B302C31262C3124272D1F262C1C29301E
2A311E2C3220303624333827
4751674955694C596C4F5B6E515B71545E76535E7A535E7A535F7A546179556278566379
57647A58657B59667C5A677D5D68805C677F5C657F5B657F5D66805F68815E68815C6881
606C816370826875826F7B85707B86707A87717B89717B8B737D8F727C91737E92747F93
727E92737E93727D93727C94737C95737D96747E96747F95747E94767F94758092778294
7782937782947884987883997A83977D859A7D859C7D869C7D889C7E899B7F8A9A818D9B
838E9B858E9C858F9E858F9E86909F858FA18892A28A95A28A96A18B97A18C97A28D98A2
8D98A28D99A38F9CA3909CA3929EA4919EA5919FA592A0A695A1A797A0A698A0A798A1A7
9AA3AA9CA4AB9CA5AC9BA4AC9CA6AC9DA8AC9EA9A99EAAA99EAAAA9FAAAAA0ABA8A0ABA7
A1ABA4A0AAA2A1ABA3A2ABA3A1ACA2A0ABA19DA99F9BA89E9EADA189958D484A50424447
363537383A395862555962545A6453545E4F4D5649393D3930332F3E44374B5442515946
5158454B503E464A3B5259488FA2818D9D808C9C848D9D868C9E868FA2885C6557191518
211F1D1D1B191A1A1714141110120D11120C12120B343B294D593D2F31211C181368735C
74836B6F7F6B768871798C72768A6D738768363D30292D25292D23272A21262A1E282D1E
2A301D2C311D2F3420313624
4A54664D576A4F5A6E4F5A71505B73515C75525D78545F7B54617B535F7955617A56637B
56637B57647B58657B59657C5B677E5B667E5B66805B65825D67835E68835D68835D6982
616D846571856975856E7987727D8A717C8A717B8B707B8C717D8E717D8F737E92727D93
717D92717D92717D92717D93737E95737E96758096758196758195758193768192778393
78849478839579839979839B7B839B7E869B7D859A7E869B7F879B7F899C808C9C818E9B
818E9A838F9C848F9E868FA08790A28790A18892A18A939F8A96A08B97A08B979F8B979F
8C99A08D9BA18D9CA08E9CA1909EA3919FA592A0A8919FA795A2A897A2A798A2A799A2A8
99A3AA9AA4AB9BA5AC9CA7AD9CA8AB9CA9AA9DAAAB9EAAAA9EA9A8A0ABA9A2ABA8A2ABA5
A1ACA4A0ACA4A0ADA49EABA49EABA39FACA29DAAA09DAB9E9DAD9F8D9B904A4D52404447
37383A37373850564C4E5449555E504C56484C5749454E43353B3440473A4953414D5743
4F58444B51404144384144398B9D7E8C9E818A9B818B9C848699828A9E84616C5C1D1A1E
2220201D1D1C1A1A1717171316161114150E14160E272B1E5D6B4B3E422E24221C66735D
74856E6E7E6E748574798C757A8D73788B6F3F463C292D273032282D2E242A2C212A2E1E
2B301D2D331E303621333723
4851634C5568505A6F505B72515B75515C77525C78545E7A545F7A55617C56627B56637B
56647B58647B59657C59667C5B677E5B677D5A657F5B66825D67835F68845F6984606A84
636E866772866A74876F7A8A737E8C737F8C737E8C727D8D717D8D707D8F717D91737E92
727E92707D906F7C90717F92727E93747F95747F95737F93758293758192758192768292
7783957983997A839C7A839E7D839E7F869D80879C80879C80899C808A9C808A9C808C9B
808E9B828F9C848F9B848E9B87909E87909E88929E8A95A08B96A18C98A28B98A08A979D
8C999D8D9CA08E9BA18F9BA38F9CA5919EA7929FA9919FA893A1A994A2A998A4AA99A4AB
98A3AB98A3AB99A4AC9BA6AD9CA8AB9CA8A99EAAAA9EA9A89EA9A7A0ABA6A1ABA3A2ACA3
A2ACA3A2ADA3A1ADA49FACA39EABA29DABA19EABA09DAB9D9DAC9C92A1944C4E523E4146
36383D3131334F554A4A4F45494E45464E424B5648475243343B303A433548533E4A553E
4B563D474E393B3D3033342B8091748DA0828A9B818A9C85859883889C856B7A691F1F23
24232321201E1E1E181B1B141A1A13171911191A1320241A2F35272F322840483A718368
75876E71826E748571798C757C8E767D8F754850452B2D2834372D2F31262B2D22292C1E
282D1D2C31202F3423313725
4951644B53674E586C4F5970505A73515B76515B77535D7A56617C56627D56627D55627B
56627C58647C59667C5A667D5A657C5B687D5C687E5E6980606981606880636B84646C85
646E856772866873876D788A727E8D76828F78849076818F748090747F92737F91737F92
737D92707B91727C92737F93727F92727E92748094737F92758092748091758092778394
7682947782977882997A839B7C849D7E869E7F889E7F889D7F899D818B9F818C9F818D9F
808D9F818E9D84909D85909D87919F87919F8892A08994A28A96A38B97A48B98A38C98A2
8C99A08E9BA28F9BA3909BA5919CA8929EAA939FAB93A0AB95A0AC95A1AB97A3AC98A4AC
9AA4AC9AA5AB99A4AA9AA5AB9CA8AB9DA9A99FAAA9A0ABA8A2ACA7A2ABA6A2ABA3A0ABA1
A2ACA0A3AEA1A1ADA1A1ADA2A2ADA2A0ABA1A0ABA2A0ACA09FAB9C9AA898555759414246
3B3E40323234494E444E5346494E43484E434F5A4B434C3F31362C353B2E515E454E5A41
4D563E484E393E4133302F2A78866E8FA1858A9B838D9E88899A858B9D877F8F7C29292D
222022211F1D2120181E1D1319190E14150C16170E20241821241A1F201A21231E6C7D62
76896D71816A7888707D8D747E9076849578565E4E2F3029383A3132362E2D31292A2D24
272C1F2C31212F3525323728
4751654953684C586B4E596D4F5A70505A73515B76525C78535D7955607B56617C55617B
56627B58647B58657B59657A59667A5A677A5A677A5B677C5D687D5E697D626C82636D83
647083667385667384697586707E8C768590788793778492758392748092737F93727E94
737D95717D94717C93717F94707E93707E92727E92727E91758091758091758091778391
7885927884947883967A85997D869B7A849B7B869E7A849D7B869D7E89A0808A9F808AA0
818AA0838CA1848EA0848FA0868FA085909E85919F8692A08793A18894A18A96A38C98A5
8D9AA48D9BA58F9CA6909DA6919DA8929DAA929EAB939FAB95A0AD96A0AC95A0AC98A3AE
9AA4AE9AA5AE9AA5AC9AA6AC9CA8AB9DA9A9A0AAA8A1ABA8A2AAA8A2ABA8A2ABA5A1ABA3
A1ABA3A0ACA29FACA3A1ACA4A2ADA5A0ACA49FABA49FABA39CAA9E9CAC9C5E6261444549
4546463635373F413C474B404C52444D5647525D4D4B5648363E34373F315A694D57654A
505B444D5440464A3C363733707C6A94A78E8A99848C9B878998868C9B888593802C2A31
211E2323221F2020171D1E121B1B0E13140A13150B1F221721261C23291E1515115E6C54
76886B6D7E6678886F7E8F74819277819376535A4B34352F3A3D34363B303035292B3023
2A2E202E3221333726333626
464F6549536A4C586E4D596F4E5971505A73515C75535D77535E7755607957647B56627A
57647B59657B58657A58647959667A5A677A5B677A5A677B5C687C5E697E606A81646F86
6572866674836674816775836C7B8771828D748591748491738190727F8F717D90717C93
727E95727E96707D95727F96727F95727E95737F94737F93758192768291778491778491
7986917884907883917A85957C86987B869A7B889D7B869E7C88A17E89A27E89A17F8AA1
838CA4838CA4848DA4868FA4868FA38691A18692A08793A18895A38A96A38B97A48B98A4
8C99A68A98A68A99A58D9BA58F9DA7919DA9919EAB919EAB929EAB939FAB95A1AD96A2AE
98A4B09AA5B09AA6B09CA7B09CA6AD9CA7AB9FA9AB9EA8AA9FA9A9A0AAA9A2ABA8A3ACA9
A2ABAAA1ACA9A0ACA9A1ACA9A0ACA89FABA8A0ABA99EAAA69AA8A19BAB9F656C6A414247
4245433434343E413C454B424D564A515C4E535F504E5B4C3D4A3C3A46355A6C5059684C
5360464C564042473A3A3B3775836F95A88D8B9B868B9A888896858B9A868493802E2B32
201B232321211E1E171A1A1018190D14160B191B10272C212F372C2E352A292E255C6A54
73856C6E7F6874856D7B8C737F90778093784F584C3539323A4135353B2D3036262D3222
2B301F2F3422333625333725
47516649546A4B566D4D57704F5A73515C76525C77535D78545E79555F79566078566179
56617A57627C58647E58647E58657D59667C5A677C5A657C5C677F5E69815F6B83646F87
6572886674876674866775866876876B7A896E7E8C707F8F727F90727F91727E92727C93
717C94727D94717C95737E96747D97727C96737E96737F95748095758193788593798593
7884937784927783927884947985967B87997B889C7C889D7C889E7B879F7C86A07E89A1
818BA3818BA3838CA4868FA5868FA38790A08893A08993A18994A18894A18995A38995A2
8A96A18A96A28B97A48E99A5909AA6929DA8939DA9939DA9929DA9939FA996A1AA96A0AB
97A0AE98A2AF99A3B19BA5B29DA6B09EA8B09FA9AF9EA8AD9EA9ABA0AAAAA2ABABA2ACAC
A2ACABA0ACAAA0ACA89FAAA79EA9A69EAAA79EABA79CA9A499A79F9CAD9F717B733C3E40
3D413D2F312F4349404B54494C564B5563544F5D4F3F4A3E354034323B2F596B505A6B4E
5260464B5740373D3033352F76866D95AB8C8A9A858B99888A97878B9A88839180333236
1B161D1F1C1F1B1A181B19141A19131718101C1E142D3326444F3D363F324A574760705C
6E806971836B73856F7688747A8C767B8E77525E51373D35394033343C2E3036262E3422
2C32222D3322323826313725
4953674A566B4C586E4E576F4F5972525D76545E78535C79555D7B565F7A586079576179
58607957607A59627D58627D58647E59657F59657F5B66815D67835E68855F6A86626E89
64718A68758C68768C69768D69768B6B788B6E7B8D707C8F717E92707D92717D91717C90
717B92727C93737C96747D99747D99747D99737D99747D97767F97768096758094778295
7681957783967884967984977985977A86997B889B7C889D7E8A9F7E8A9F7E89A07F8AA2
7F8AA1808BA1828DA1838FA0858FA087919E88919E8994A08994A18893A08994A18A96A2
8B96A18C96A28E98A28F9AA3919BA4949DA5949CA6959DA7959EAA949EAB94A0AA95A0AB
98A2AD99A1AE9AA4B09BA4B29BA4B09EA8B19FA9B09EAAAE9EAAAC9FA9ABA1ABABA0AAAA
A0AAA8A0ABA9A2AEA9A0ADA69FACA59FABA49FABA39DAAA19BAA9D9CAD9C737E733B3D3E
3D423E30313043483E4E584A515C4D53605041493F333A31282F28272E26596A515B6F53
49594349564031362A2D2F28707D6795A98B8A99838D9B888D99888C9B8984948336373A
18131A201D1E1E1C181F1D171C1B161616121818112F34275F6D545965514A5447586557
71856F71836E72846F71826F6E806C72876E53604E353A30383E30353B2E3137292F3525
2E34242E3524323926313824
47516848556D4C5A714D5A6F4E5A704F5A71505B73535D77545E78535D76555F76566177
57627857617859637B59647C59657D5A66815965805B65815C67845E6886606B88636E8A
64718B67748D69768F69768E69768D6B778C6D7A8D6F7B8E6F7D916F7C92707C91707C8F
727E92727D93727D95737D99727C98737D98747F98737D97757E96778095747E94757F94
7580947782957886987885987B869B7C879D7D889E7B889E7E8A9F7F8C9F7E8B9E7F8BA0
7F8BA0808C9F808E9F818E9F848F9F86909E88919F8892A08995A08995A08995A28B98A4
8C9AA58C99A48D9AA38F9CA3909CA3929DA3939EA5949FA8949EAB939FAC94A1AD95A1AE
97A2AF98A3AF99A5AF9AA3B09AA4B09DA8B09DA8AE9DAAAD9EAAAEA1ABAFA1AAAEA1AAAC
A0AAAA9FABA9A0ACA9A0ADA89FADA6A0ACA59FACA39EABA19BAB9D9BAC9A7480743F4443
42474336393740473E4F5A4C505C4E535F5140493F38403531392E2D34294D5B4556674C
46523E48554033392C2F312A6D796592A3888998818D9D878F9E8A8E9D8985968237393B
1A171D2220211C1B191B1A161919151516121A1E172931247085656B7E62677863454E47
7B91797288736274623F4B42414E436B816557664E31372A383E2E363B2B333828313725
313724333926343C27323B26
45536846556B48586E49596F4B5A6E4D5A704F5C72515D74515E75525E74536074546074
55617556627857637A57647C58657E5A67815866815A66815A67815C68825E6984626F89
64728A65738B67758C67758C66738A6A778B6C798B6E7C8D6D7B8E707D91717D936F7D93
728095727E94707D94707D96707C96707D95717D94727E94737D94758094758195737F93
737F9075839376859777859878869A7A879D7C899F7B879F7A879E7E8A9F7E8B9D7E8B9D
7E8B9E7E8B9F7F8D9F808D9E838E9F8690A08590A08592A08694A18695A18796A38998A4
8999A48B9AA58C9AA58D9BA3909BA4909CA4919EA6919FA892A0AC92A0AD93A1AE94A2B0
94A1AF96A3AE98A5AE99A5AE9BA7AE9BA8AE9AA8AD9AA8AC9CA8AB9EAAAD9FAAAEA0ABAD
9FABAB9FABAA9EABA99EABA89EABA89DABA79CABA49CABA198A89F9AAC9E7B8980444A4C
3F4445393C3E3B413F464F474B584D5563544B57493C473B373F3534382E383F30414B37
3A42303F4836383E312F302B60695992A4888896828C9C898E9F8E8D9F8C879987393D3F
1410191D1C1E171516151412151611121410252A222F372B5E70566F856763745F454E47
7A8E79768C7659695B161A1D1A1E1D3C463649543F34392B373C2E363B2B343A28323725
343A25363B27363D28343B28
48566649576A4B59704A58714C59724C5A734E5B72505C74505E76525E75525E73525E73
535E7355617656627957647C57647D59657F59658058657F59667E59677D5C697F606E84
63718663728765748967758B68768B6A778B6B778C6D7B8E6D7B8E707D91717E93707E94
6F7D93707E926E7D906E7C916F7D92717E93717E92718092728093748194738095728094
72809274849476859577869977869B78859C78869B7B879D7A879D7C889E7D899F7C899E
7D8B9E7D8A9D7D8A9D7F8C9D818E9D838F9F838FA08491A18493A18493A18595A28797A3
8998A48A9AA78D9AA88E9BA6909BA68F9BA7919DAA909EAB919EAD90A0AE90A0AE92A1AE
93A2AD93A3AD93A3AC96A4AC98A7AD99A8AD9AA9AD9AA9AD9CABAD9CA9AC9EA9AD9FAAAD
9EAAAB9EAAA89EABA89EAAA79DABA79BAAA79AAAA59AAAA498A8A19AABA17A86824B4F54
3C4046454C4A464D47404741505C50556253485244363C3333372F2F33292B30242B3021
2B301F313625383D2D31332A626C5990A2858795818A99878A9C8A899C8B829485313439
16131C1A191D15141414120F15130D13120E272B223033295F6C55778A6E687763637063
708071778B795260540E101516171A1211112528202F3426323629333929323927323826
343A26363C29373C2C35392B
4751634954694B56704C57734C56734B56714D59734F5B75505C75525D76535F76535E75
525E74535F76545F7754617A55637C58647E59648058647F59667F59677E5B6B7F5F6D82
61708264738564738667758868768A69778B6A778B6E7B8E717F91738093738095707E94
6E7D936E7D916D7C8F6E7C8F707C90717C90717D91738093728193718092728094738095
74819576839577859678859979859C78839B7884997A879A7C889C7D899D7E8A9E7E899E
7D899E7F8B9E808D9E808D9D818F9F8290A08290A18391A28291A18393A18594A28594A2
8795A38A98A68D9BA68E9CA68F9BA6909CA88F9CAA8F9DAC8F9EAE8E9EB08F9FB0909FAE
94A3AE95A4AC96A3AC95A3AC98A6AD99A8AD9CA9AE9DA9AD9EAAAD9DA9AC9DA9AC9DA8AC
9EA9AC9EA9A99EAAA79DAAA79DAAA89CAAA79AA9A599A9A397A8A09AABA27B8683494C53
4044484046443D433C32362F4852435A6753535E4C3A40373237302F332B2E33262A3020
262B1A2A2D1B37392734342A60695796A98B8A9A828C9D878B9C87889985839582343839
15131A1B1A1C18171717171417161215141020211928291F616D5376876A6F7E6673826C
72826E7A8D78586459111119110E140F0A0D201E182F3225313424323624343A26343926
343A26353C27363D2B363C2E
464F644952694B556F4C55724D56734D56734D5673505A764F5B76515D76535E76535F76
535E76525D77535F7954617B53617B58647F58657F59667F5966805966805B68805E6B80
606D7F627082657385667485677585687687707F8E7B8A987E8D9D7C8A9C768399707D96
707D956E7D936D7C926F7C91717C91717C91737D92737F93737F92738091738091748094
7581947781957782957783957884977984987985997A869A7B879C7C889D7C889F7D889F
7F8A9E7F8B9E808C9C808D9D828EA0838EA1848FA18591A28592A28592A28592A28694A3
8896A38B97A38D99A38D9BA48E9BA58F9CA7919DAA909DAC8F9DAE8F9DB1909FB192A0AF
95A2AE95A3AF96A4AF97A5AE98A5AE9AA7AD9CA8AD9EA8AC9FA9AB9EA9A99EAAA89EA9A9
9EA8AB9EA8AA9DA9A99EAAA99EAAA99DAAA99CAAA69AAAA498A8A099AA9F85938A45484D
4045463438382E32302425233B42375F6D575965504B56463F463A383D3233382C2E3426
2D32234F583F41443437383153594E94A78C8A9C858A9C858B9C86889882879681454845
16121A201F201D1E1B1C1E191A1B1717171316161024271A5762487B8E6B70816574846B
76856D7787717584713639391C1A1D1F1C1C22201A303123313322333724333825343A26
353B27353C28383E2C373C2D
4850634A53694B556F4C55714D56754F58774F58754F5B76515C77515C76535D76535E77
535E7853607A55617D56617E57627F58658057648058667F59667F57647E5A67815C6880
606C81606D816370846572866674866C7A8D798A9B8294A38697A7808EA378849D717E98
707C946F7C916D7B906E7B906E7B8F6F7C90737E92737E92737F91748093748093758094
7480947681957682957783957985977985987B889B7B879C7B889C7C889C7C889F7D88A1
7D8AA27E8BA17E8B9E808D9F818DA0848FA1848FA3858FA38691A28893A28893A18994A0
8A96A18C9AA38D99A28C99A38D9BA48F9CA6919DA9909CAB8F9BAC919DAF929FB094A1AF
95A1AD96A3AD97A4AD98A5AD99A6AD9AA7AD9CA8AA9CA8A99EA9AA9FAAA79EAAA59EAAA7
9FAAAA9FAAAC9EAAAC9EABAC9DABAA9DABA89CABA59CABA49AABA29AAB9F8FA092474B4F
3B3F402F31322A2D2D2425263439345E6C595865525764524E5A493D4537353B2E2E3327
2C30266C7B5E43483A3A3C364C50488E9F868E9F888C9D878EA0898A9B83899A8051564E
1B151C2321231D1C1C1C1B1A18191717171517181322251B505C457F947172836874856C
76866F7586707588716D7D6855615159665149544134382A3B3E2B383B29313525323726
333A29343C2A373F2D373E2E
444E5D4750644A526B4A536F4C55744E56764E58764E5977505B78505B78505C78515D78
505C79515C7954607B545F7C57627F59648058657F58657F58667F58667E5B68815D6983
5E6A835F6C846370876470886670896F7D937C8CA08091A48091A47C8BA077839A748098
727D94717C906F7B8E6E7A8E6C7A8E6C7A8F6F7C90717D90727D91727E92737F95758097
76819875819777839776829776819776829878849979859C79869D7B889E7C889E7C899F
7D89A17D89A17F8B9F7F8DA0808DA0828E9F838DA08590A38790A58790A58791A38893A1
8893A08996A28A97A28B97A18C98A28E9BA48F9BA68E9AA78F9BAA8F9BAB919DAD939FAD
939FAA929FA993A1A994A3AA98A6AB99A7AA99A7A999A7A99BA9A99DA9A79DA9A69CA9A6
9EABA89FABAA9DA9A99BAAA99BABA89AAAA69AAAA29AAAA199A99E99AB9C90A3934E5756
3D42413134322C2D2C2B2B2B3437325B6856586554566252525E4C454F3F3840312F3628
2C302434382A33342935342E494B4490A28891A28B8E9F8990A28B8B9D868B9C835C6457
1A141A2421221E1B1C1A19181716151717141A191621201B464D3D84997674866C748670
74857374847273856F75896F75896E76896C65735B393D303F4331383B2B2F33252E3325
313728333B28363F2A343B28
444F5D4751634A556A4B55704D57754C57754C57754B57754C59774E5B794E5B784F5D78
4E5C77515D78525E79545F7A55617B57647D56647B55637C56657E57657F5867825A6883
5B68835E6A84626E87636F8865708A6B769175819A78869E78879D748398728095717D94
707B926F7B916F7B926D7A916D7A906D7A906E7A90707C91727D93727D93737F94747F96
747F9875809875809774809875819977849B78849B78859B78879E7A89A07B89A07A89A1
7B89A07C8A9F7E8C9D7F8D9D808D9E828F9F848FA08690A48790A68590A78590A68693A6
8793A48794A48897A58997A58998A48B9BA58C9AA78C9AA88C9AA98E9AAA909BAB929EAC
929FAB92A0AA90A1A991A2AA93A3A995A6A897A6A999A7AA9BA9AA9CA9A89BA8A69CA8A7
9EAAA79EACA99CABA99AAAA79BABA79BABA599A9A299A99F97A99C97A99993A79657615F
454C4C35393A3032313639353C413A576353576554566351515C4B4854433943362C3429
2C31262B2E242929212825213F3E3998A98E9AAC938F9F8B8EA08B8C9F8A8D9E8A6B7668
1D1A1F2223221C1C1B1C1C18191A13191A1117150F1F1E17424838899E7C74866E738472
72827673847772857272896F72896C758B6C5D6B5540463A3F4639383E3133392C30352A
31372A353C2C373F2B353C2A
434E6047516649546C4B54704B56744956734956734C59744C59754D59764C59764D5B76
4F5C76505C77525C79535E7A54617A54627B55627B54607A55637C55647F576681596782
5B67825D69835E6B84606D86626E8865708A69768D6E7B926F7D936E7D936D7B936D7A91
6E7B936C79926B78936A76926B77906D79916E7A916D79916E7A92707B93717D94717E95
727E97737E98747F99747F9975819976829A77849A77849978869B7A899F7A89A179899F
79899F7A8A9D7C8A9C7C8B9B7C8A9C808C9E838FA0848FA28491A58491A58391A48593A5
8694A58794A48795A58997A68997A68B99A78C99A78B99A88D99A98F9AAB909BAB939DAD
959FAD95A1AD94A2AB93A2AB92A1A995A4AB97A6AC99A6AD9AA7AC9CA8AB9CA8AB9EA8AA
9FA9A89DAAA69CAAA69AAAA59AA9A699A8A39AA9A39AAAA198A89D96A79994A7965A6561
464D4C3032362F32323B413C404841596556596656576454515C4D4F5B4B454F432D312C
30332E2C2D28272421231C1E3834339DAD91A2B49992A18C90A08C8F9E8A8E9F8A6C7869
1D1C202323231D1E1A1D1E17191A1117170F16140F23221A4C52418FA58073876E708571
6F83786A7F7777928159705F5F76616B81695865563F48403E453B373E3332392D30372C
30352B343A2D373D2D333B29
424E6345506746526C4A54704A54734852734752734853734854734B56744D59744E5A75
4F5A754F5A754F5A77515C79535F7B53607B54607A535F7955617B56627E576580596680
5B67815B66805C68815E6A83606C84626F8564728767758969778B6A798E6B7A916B7992
6C78956A75946975946B76956B76926B76906C778F6D78906F7992717A93717B93737D95
737F94727E9672809873809775819775819776819876819976829A78849C78859B79869A
7A879B7B879B7C889B7D8A9B7D8A9C7E8B9F818DA1818EA1828FA38390A38390A38390A1
8492A28593A38693A38996A68A97A78A96A88A97A88B98A98C99A98D99A98F9AAA939DAB
959EAA94A0A9939FA894A1AB95A1AE97A3AF97A4AE99A5AE99A5AE9AA5AC9BA6AC9DA7AB
9DA7A89CA7A59BA8A49BA8A59AA6A49BA7A39BA9A19AA89E98A79C96A69992A494545D5B
3A3E412E30342D3030393F383E463C5C6A585A6656586253525B4F4F574C4F574B3F433C
3637342B2828262022231A1F373233A0B094A4B59A93A38D90A08D8E9E898D9F87677365
18171C2021211C1E1B191B1518191017180F16160F1E2017444E3D7E95726A80646A8067
718772586860718878697E6C3F4B446B7E6A5360543D443E3C433A353D3232392F333A2E
33392D353A2D363C2D343A28
404C65424F6845516D4853704A53734A53744953744854734854714A546F4B566E4D5970
4F5B704E5970505B74505B77515C79525E7A535F7A545F7A56627C57637D58647F596580
5A64815B66835D68835E6983616D85626E84626F8564728866748966748B67768E687490
6874916975926A75936C76946D77936B76926B77916E78916E7890707A91717B92727D94
727D93727E94727E95737F957682977783977982977B849B79839D77829B77829A7A859A
7C879A7C879A7C869A7F899C7F8A9D7F8A9E818BA0808BA0828EA1828EA18390A18490A0
8492A08492A08592A18894A38A96A58996A78996A88B98AA8B99AA8C9AAA909BAB919CAB
939CAA939DA9939DA996A0AB97A1AD98A2AD99A3AD9AA4AD9CA5AD9BA4AC9BA6AA9BA6A9
9AA6A79AA8A59BA8A49AA7A499A5A29AA7A19AA69F99A59C98A69B96A69991A193525858
3032393437392F323131342D41483A5E6B5459634F52594A4A4D444A4C4454584E494A44
3F3E3D363335342E3130292D433F3F96A48D9FAE9695A59090A08E8C9D8A8A9E88677567
1A1A20212324191A1A191A1418170F18170E17180E23271A30392B4653405C6E56667C60
596C54586A5363765E91AB88566455536054505F522C322E363B33363C30353A2F353B30
373D30383D2F373C2F33392B
414B64434D6848526D4A54704A54734A53734A54724B56724B55704B556F4B566F4C586E
4F5A6F4F5A70515C74505C75505B764F5B77505B76525D77535E7956617A57627D596381
5A63835C66855E68855E6A84606C85626E86626E8763708963718A64718C65738E66728F
6775916875916975926A76926C77936B77936C7A936B78916A77906D79916E7992707C93
6F7B93707D95727E97717E95747F977680987882987B839A7B839C78829D78839B798599
7B85997C86997D869A7F889C7F8A9E808B9E828B9F828C9F848EA2838FA38591A38491A0
84939E8594A084939F85939E8795A18795A48997A78A97A88A97AA8C98AB8F9AAD919BAD
929CAD929DAC939FAD949FAD97A0AD97A1AB99A2AB9BA4AC9BA4AA9CA5A99AA5A79AA5A7
9AA6A79BA8A69AA8A69BA8A69AA7A59AA6A39AA7A299A7A097A69D95A59A96A7995C6262
313136363A373234303131294044365D664E565E4A45483E3938374848475D615B61665E
4C4D4C4748484544424543404D4D4A88948098A69096A59190A08E889A88889B886C7C6E
1B1B202021211D1D191C1D1518160D17150B15140A2327182E3525343D2D3F4C394F5F47
2A34272F3C2C26302584A07B72896A252B24455242191B19282B232D312730342A34382E
373C2F383E2E373F2E323929
414A61434D67464F6C48516E48517048527049527049526E48526F4A54714C55724B5571
4C57704D58704F5A734F5A75505B784F5A78505B78515C78525D7754607956617B58637E
5963815A64845B66855D68835E6982606C84606C85616E8763708A636F8E647290647191
6572926672916672926774936974946A75946B77946B77936B76926C78936D79946E7A96
6D7A966E7B976F7D98727F98747F98747E98747F9977829A778099767F99768199778398
7984987A86987B869A7D869B7E889C7F8A9D828B9D828B9D828C9E838DA0838EA182909F
83929D83929D84939D84939F8493A28594A38796A68896A78A97A98C97AB8E99AC8E99AD
8F9AAD919CAD929EAD939FAE94A0AD95A0AB97A2AA99A4AA9AA5A99BA5A89AA4A69BA6A7
9AA6A69AA6A59AA8A699A8A798A6A698A5A597A4A396A4A296A59F95A49A98A899666F6A
3433393D403D393B3635352F3D3F36575F4C575E4E4C51463B3E39586156616C62829381
606960595F584445444B4B484B4A497E8779919F8C91A08F90A08F889787869784718070
1E1F242122221D1C191C1C1518180F14130B13120B1F22162D3525384331313C2C20271C
1B22181A21160F140C607655657B58151A122E372A1416121F2119272A212D312734372C
383C2E353B2C343A2B2F3627
414A5F434C65454E6A47506D48526F48517049537249527048516E4B54724C54734C5573
4B55744C56734E58754E59755059774F5977505A78515B79525C79525D77545E7956617B
57627D5963835A64855A64835C67825E6983606B85616D86626E88636F8B636F8D636F90
636E90636E916470936572956672956873956773946974956B76956C79946C79956D7995
6E7A936F7B95707C97727D97747E96747E98757E9A757F9A77829B76819B75819977839B
77839977839978849B7B869C7C879E7D899F7F899F818A9D838D9F818C9E818D9F8290A0
82909E81909D82919C8392A08492A28695A68694A88895A98994AA8B96AB8A96AA8B97AC
8D99AD8F9BAC919CAB929EAC929EAB939FAA94A1A896A3A897A3A698A2A59AA4A799A4A6
9AA5A699A5A69AA8A899A7A997A5A795A3A595A3A394A3A195A4A094A49B98A99A6B746F
37373E4042413A3C39323431454A4052594C555D4F4F594C40473F535E51636F61849680
81907C7C85753E3B3E4845473D3840777F76929F8F8B988994A3918D9C8A899885798777
201F261E1D211C1B1A18181315150E14150D16170F252A1C262C1E242B1E22281C191F16
161C14161C1112170C2B362338452F1218101C221A141813131610252B1F2F3627333B2A
373E2C363E2B333A292E3324
414A5D444D62464F6949526E48526F4850704A53734B54744951714A53724B53734B5272
4B54744D56754D56754D56754E58764E58774F5977505B77525E79515D78535E7A55617D
5661805863835864855A64845C66835F6984606984606A84616C87626E89626D8B626D8D
626F8F636F90626F906371916573926673926672926974946B76946A75946B76946D7993
6E7A91707A92717B94727B93737D93747E95767E97777F9877819976819A74809A77829B
78839A78839A78829979839A7C869C7F879E81889F838A9F858D9F828C9F818C9F838EA0
8491A18593A28592A18591A28792A38894A58996A68996A78996A88B97AA8B96AA8B97AB
8E99AD8F9BAD909BAB919DAC929EAC929EAA93A1A995A1A997A2A697A1A598A2A798A3A7
99A4A798A4A699A6A699A7A897A4A696A4A396A4A296A4A296A5A196A59D98A89C737D76
3C3D424145443A3E3D333735393E39464E42535E4C454D42323634505851636D63869581
8D9D879AAA914B4A4A3D383E35303A6D746F90A0908794878F9F8E90A18D8A9C87798977
1F1F2419181B17161613120F11100A11110814150A2025172127181F23171E2116191E13
171C13141A1112170E12160F11151013181215191312161110140E20271A2D3624313A27
343E2A333D28333C262F3723
40495B434D6246506948516E47516E48516F4952724B54744A53724952724B54734A5272
4B53724C55744D56754D57764C57764C58774E5977505D79535E7A525D7A535E7C55607F
5862835862855863835963815A65825E6883606985616986606B88636D8A626D8B606C8B
606D8B616E8C63718F6472916774926774926773926A75936B75926D77946D77936F7991
6F7A91707A90717B90727C91747F93747F94767F9677819977819977829B76819A768198
7783977983977B84987C84987C84987E869A81899C848B9E858CA0838C9F838CA0828CA1
828CA0848FA18691A38792A48792A48792A38894A38895A38795A38997A78A99A88C99AB
8E99AD8F9AAE8F9BAC909DAC929EAA939EA9959FAA97A1AB96A1A897A2A997A1A897A3A7
98A4A898A5A899A6A797A5A596A4A498A5A498A3A397A3A298A4A197A49D98A79C7B867F
3938414143453D403F37393A3336373D423D525D4E4B5448383B3850564F646B62849080
90A08DA4B89F636A6339373D3A393F646D6591A38F8695848B9C898CA08B889D877B8E7C
22252A13141918191916161314130E13120B12130A17190E1A1F121A1F121B2013191D11
171A111418111218121216130F121312151514181613171412160F1F26182A331F2F3725
323C29313D29323D27303A23
3E485E404C62434F68454F6A47506C47506F4851704852714852714953724A54734B5474
4A53734C55754B54754C55764C56764C58774E5A784E5B79505B79515C7A525D7C545F7E
5762815863825864825863815964815C67835F69845F6986606B895F6A89606C89606C88
606D8B616F8C63718E6370906673926874916673926672916975916A76916B778F6D788F
6F788F707A92717B93717B93727D94737E96737D96757F9A75819C75809B768199778398
7783967782957A84957B85967B85977C869A7F899C808A9D838B9F828A9F838DA1838EA1
828D9F848D9F858FA18590A28791A48793A48994A38995A38794A28896A48A99A78B99AA
8C98AC8E9AAE8E9AAB8F9BAB929DAA959EAA969FAB97A0AB95A0A996A3AA96A3A897A4A6
96A3A697A5A698A7A696A5A496A4A399A5A398A3A196A19F97A29D96A19A99A69A78807B
38333F403E444142444346453E403F3B3F3C545F52525C4F494F474D524A626B5F839280
8B9B8998AB957C887A4041453C3D43636D679AAF99879A88899D8B889D8B8A9E8B819483
282C3314151D191C1E191A1916171213130D11110B14160E181C12181D121B1F131E2215
1D1F161C1D171B1D1A1A1D1E1A1B21191921181A1F15171810140E2028192B3420313925
333C29333D2A323C2A323A27
3E485F404C65424E68444F68444E69454F6C464F6E46516F475170495171485170495272
4A53734A52734B53744D57774D58774D59774E5A784D59784E5979505A79525C7D535D80
565F815862825763825763815763815A66835C67845D69855F6B895F6A8B5F6A8A5E6A89
606D8A616E8A616E8B626D8C636F8E65718E6571906470906974926975916A768F6C768E
6E778F6F7A926F7A956E79966E7A95727E98727E98747F9B75809D75819B758099768197
7783977882977983987A83987B859B7C889E7C889E7D899F7F8BA07F8BA0818DA0818C9E
808C9E818C9E838C9E858FA0858FA18691A38792A38592A28593A38695A58896A58998A6
8B99A98F9AAB919BAC919AAB939CAC959DAD979FAD979FAA95A0A895A2A894A2A693A2A3
93A3A294A4A296A4A395A4A395A4A297A5A397A4A296A2A096A2A095A19C99A79C6D7370
352E3A3D38404140454A4E4D414644393D3A515C4F505A4E51594E4B4F485C635A849280
8A99858B9B84899882454547302D38646E6B9AB09D86998A8B9D8C8697878A9B8880917F
24242C1A19201D1E1E19191715151212120E13120D181A121C1E141C1D152B3122282D1F
20231727272027252542454432343927272D26282918191913140F242A1A2A321E2E3623
323A25333B27333D28303924
404961414B65424D69434E6C434E6A444E6B444D6B444D6C47506E47506F464F6E474F6E
4951714951714A53724B53724C55744C56754D57754E58774F5878505978515A7B515A7D
545D8057608156628158637F57637E5965805A65805B66825C66865E68885F6A895F6989
5F6B89616C89626E8A636F8B646F8C64708E646F8E646F8E67718F68728E6A748F6C758F
6D768F6F79916E7A936F7B946F7C95717D95727C96747E99747E9B747E9C747F9B747F98
7781977982997A83997983997A839B7B869E7C879F7C89A17E8AA27F8BA27F8CA07F8B9E
7F8D9E808C9E828C9E848E9F858FA18690A28691A28592A18693A38795A58795A58896A6
8A96A68D98AA9099AC919AAA929BAA949CAB959DAB969EA8959EA795A0A893A1A593A1A3
94A3A394A3A395A3A294A3A293A2A195A2A295A2A197A2A296A2A194A09D98A69D727976
2D263444414744434944474B3A3E42373C3C4C574D4D594D505A504347446B756890A18B
78847587968183927D41414329243262696798AC9A8A9B8B8D9E8C8997858C9B878D9E86
29272B1E1B1C1C1B1717161114140E14140E15150E1B1D131F22181919144049373A4234
2E322A5861523C3F3D59625B3E4245292A2F292B2A141414191C14282D1D292F1C2B321F
2F3624323926333C272E3925
41485F404862424B68424B6B424C6B414B6B424C6B444D6C444D6C454E6E454E6E474F6E
464F6E48506E49526D49526F4A53714C54734C54724D55744E56775058774F5A77505B78
535D7B545F7D55617D55617B57627A58637C59647D5964805B66835E6985606985616987
606A87626C88626C89626D89616D8B636F8E64708E65728F67728F68738F6A748F6A748E
6B758E6D778E6E788F6E7990707A92707C94707C96717C97727D98727C98737D9A748099
767F997881987982977882977982987983997B869B7D899E7E8A9F7E8AA07E8B9E7D8A9D
7F8C9D808D9E818D9F828EA1838EA08590A08692A08792A28A95A48A95A58993A48A94A5
8B95A68E97AA8F96AA9099A9939CA9939CA8949DA8969FA896A0A796A1A795A2A596A3A5
96A3A496A2A396A2A395A2A395A1A395A1A395A1A396A1A295A19F95A19B96A49C7F8884
2B2835676F694C4E514A4D4E3E42453033384F58524F58514F57523D41426672669EB699
727F718595817683743B3B41312F3B5B61628191868696888E9E8B89978287967F8D9E83
2F2E2C1F1C1A1F1D161B1B1018190E17180D17190E1B1D111B1F1415191222271F4D5847
5A66566E7D6A646D636E796D5C655D484E48363C371B1C1C21231D262A1F292F202D3223
2F3425333927353D29303926
41485E424B63434C67424B69424A6B424A6C444D6F444D6E444C6D454E6E464F6C474F6C
48516D47506B47506B49526D49526F4C55734D56754D56764E567850587B4F5979505C79
525D7A55607D555F7B555F7A58627B58637B59637D5B64805B65815D65825F6783616885
616885626A84616A84616B85626C87646E8A646F8C65718D65728D66738C68748C69758C
6975896C768B6E788D6F7990707992717B94717B96707C97707C97717C98727C99747F9A
7580997681987580967982977B82987B83997C859A7D889C7F8A9D7F8A9D7E8A9C7E8A9D
7F8B9E818C9E828DA0838FA2848FA08590A08792A28993A38994A28893A18994A28994A2
8C96A68E96A98E96AA909AAA929CA8929CA6949DA696A0A796A1A695A1A596A1A696A2A5
96A2A598A3A698A3A697A3A697A2A597A2A396A2A296A2A195A19D94A09996A499869189
2F2C385054544D51504F55513E43422D2F345059534E56524E5650454B4850595394AC91
849882899E86788878565D5C40414B5F666B666E7185948A8FA08E8A9B8486947B7E8E72
2A2A251B18151E1C1519190F18190E181A0E181B0D1A1D0F1C1F121C1F1512120D4A5241
7B8A716F7A69737F70768375707F6F68776640473F2426242A2D262B2F232B31222D3323
2F3424303626343A28313727
434962444A66434A69424A6A42496A43496B43496D444B6C444A6B444B6A454E6A474F6A
464D69464D6948506A49526C4A536E4C53704D54744C54744B54754F577950597B505B7D
515B7C535D7D545E7D545E7C56617D58627C5A637C5C637E5D64805E64815E6481606882
616A84616A83606A81626B82646D85666E8766708964708B65728C65728A66738A677588
6874866A75876B75896D768C6F788E6F7A90707A91717B92707C94727C95737C97747E98
757F97747F95747F947781947A82967C83987C84997D85997D86997E889B7F8A9C7E879C
808A9F828AA0828BA0848CA0848E9F878F9F87909F8792A08892A08892A18893A38A94A5
8B95A68C95A78E96A88F99A99199A8939BA5969EA4959EA2959FA1959EA1949EA295A1A5
95A1A597A3A698A2A597A2A595A1A496A3A296A3A295A2A093A09D93A09A92A1978C9B8E
3A39404244465B635C49514C3A3F3C26292A4D574D4D554D4E564E4C52495F695B91A68B
7686767F907F8293837B897C5C60614C4B556F74757C84808D9B8D8A9A8686957E7D8E74
2829261C1B191C1C1717191017190E171B0F151A0C181B0C262A172A2C1E1714103F4137
7F8F756D7769727E70748374708170697A663C453C1C1F1C2B30272C32272C33252C3424
2D35252E37273038292F3729
43465F45486545496944496A454A6C45496C44486B44496B444A69444A68454C68454C69
464D6A454D6B464E6D49526E4B546F4C536E4C536F4C55704B54714C53734F5677505A7B
515B7C535C7D545E7E56607D56617C57627B59627A5B627B5D637D5F647F5D63805E6581
626A84626B84616B83636C84646D86656E88676F8967708A68708B68728C68738B6A7489
6A75876B75876B74896C758B6F788C6F798D6E778C6F788E707A90717B91727B92757E95
767E96777F96777F957881947B83957C84947B83957D85977D85977E86997F879B80889E
8189A18088A1818AA2828BA0838D9E868F9E868F9E88909F8991A08A92A38B93A58D95A8
8E95A98D94AA8E96A99098A99199A7949BA6969DA4969EA2969FA2959FA1949EA1949FA3
96A1A595A0A7959FA595A0A594A0A695A2A695A2A494A1A194A1A1919F9D8F9D9791A195
46484B4044457381724B524D3C413E27292B4B554B4C564C4D574C474D4450554A7E8D76
7785727B88768796838391807981753E3941646666767D788B978A8896868595817B8D77
30342F1919181E1F1A17191314160F15190F13170D11150A3743294D593D1614104E5447
7A88736C786B717E71738274718373697B68424D412D352D313B2F2E362B2C33272C3526
2C36252E39272E39282D3727
434660444865454967454967464968464869474A69464A69454A68454A69454B6A454B6B
444C6B454D6C464D6E4950714951704A526F4A536E4B556E4C566E4D56704E5774505978
515A7A535B7D555F7F55607D545F7B56607B59617B585F795A617A5D637C5E627F5F6481
606583606785606785616984646C86646B87656C87666E88676E8B686F8B687089697289
6972886972886A73896B748A6C76896E798C6E798B6D778A6F798B717B8D727B8E747C8F
767D91777F92777E927981937A82927B85937A84927B84957B84977D85997F879C8087A0
8188A28188A38189A1818AA0818A9D838C9D868F9D88909D87909F8891A18991A28C94A4
8E97A78F97A98F96A89096A79198A69299A6949BA4959DA4959EA5949EA3939DA1939DA1
95A0A4959FA6949FA594A0A794A1A893A0A892A0A6929FA2929F9F8F9D9B8E9B9792A299
6067672C2936677168535B544046412D2F2F4E584C4D574B4951473C3F3A41443D5B6354
75826B8494798A9B8286957F838F7D3A373E5B5D5E78807A859186849184849584778876
3135341B1B1C1F201D1A1B1715171212150D11140C0E100B35402C4B583F12100B454A3C
75826C6D786B6F7C7072817472837370826F4651472E352E323A2C2D35252C32232E3424
2D34232E37242E37242E3724
41455F42466244476446486646486846486A46496A454969454969444A69434B69434B68
434B69444C6A444C6A464E6C49516F4A52714A52714A54704C56704C56704D56714F5774
505775515979535C7D545D7D545E7B555F7B59617C59607A5A62795C627A5D617C5F637F
5F64815F6582606783636B82636B81656A83676B86686B87676C8A676D89676E88677089
67708969728A6A738A69728B68718A6A748B6974886A74866D77876D77866E7887727B8B
757D8D767F8F7880917981917982907984927883927983937B85957E86977F879A7F869D
7F869E7F879F818BA1818B9F828B9E848D9E858E9D87909D87909D88919F8891A08A93A1
8D95A38F97A49096A49297A69299A69299A5929AA3949DA4939FA3919EA1919EA0919E9F
939FA195A0A2959FA296A1A593A0A393A0A3939FA3939FA1929E9E919D9C919E9993A29A
6F7776292533454948424843373B37383B364D55494C54474D564942483F383C363F433B
65705C88987E92A38B899683859082403C466D747079837C869288859285859485798777
2C2D2F1C1C1E1F1F1E191A1614161011140B1012090F0E093E453456634B110F0F30322E
72816D6B796A6D7B6E70817271837270826F57665532382E292D212B301F2C321F2D3320
2E34212D35222C35232C3422
3E455C40465E454962474866474868464768444668444768444868424865424A64424B65
434C65444E66444D66434C66464F69474F6C48506F48506E4B53704C54704C56714E5773
4F5875505A78525C7B545C7C545E7C545E7C57607D59627C5A627B5C637B5D647C5D647D
5E657F606781616781626B8161697E62697F676C82686B83686B85686D88666D88666E89
666F8A65708967728A67718A666E87676F85666E83646C81656D81676F82656E81677182
6B74846D75866F7888717B88717C8774808A77838E7985917B87947D88967F89997F8899
7F899A7F8A9A818C9A828D99838D9A858E9D858E9D858F9C87919D8A92A08B92A18C93A3
8C93A58E94A69096A59097A49299A5939AA5939BA4929CA1909D9F909EA0919E9F909E9F
93A09F95A19F95A0A095A1A294A0A294A0A3939FA1939F9F919E9D8F9D9A8E9C9791A198
6D76742C28363534372D2D2E2322244C5445515B494F57464E56443F4536393E32353730
575E51A3B99A92A28E8B9988889484474449838C80858F848A95888894868492807E8C77
31322F1716171E1F1B1A1A1516170E14140A1212090E0C05424A3659654E161213363A37
67766964736867786C6A7D6E6C806E687C675565512E3529212619292F1E2C311F2C311F
2B33202D36222C35232A3322
3D445D3F4660434865454867454768454668434667434667424866424965424964434A64
444D65444D65444D66454D67464F6949516D4A516F4B50704C52724E55744D55744D5575
4E587850597A50597B525A7C545D7C545D7C555D7C58607E59617D5A627C5A637B5C667C
5D657D5F667F606781616781616880636A82656D83656C84666C84676E87676D8A676E8C
656F8D65708C67718B687289667087677086666E84656D81666C81666C83626A82626B81
646C81636D7F636B7E656E7F66717F6874806C78836F7B8873808D7582917986937A8894
7C89957D8A957F8C957F8D93808D94838F99848E9A848E9887919D8992A08A91A08A90A0
8B91A48D92A68D92A48F94A49297A4949AA4939AA5929BA2919C9F919C9E919D9E929E9F
94A1A095A1A0949FA0949FA2939EA3929EA5919EA2909D9E909E9E8F9E9C8A9A968EA096
727F782F2D363432332D2B2B1F1C1C575F4D5A65505059454C544131332932342A3A3D32
42453B9AAE8E97AA92909F8F8C9A8A5152518C9786939E908D988C8A988884958182957A
3F46391514121F20191D1D151D1C1319190F17160D110E083D4232616D56201D1F4C534D
66746B61706B5F716A5F716661746361745F343E342A3228272F22282F1F2A31202C3221
2D34212C34222B3322293222
3E435D404662424966434967444868444768434667434767424766434766444866444966
444B67444C67454D68464D6B464E6D48506E48506E4A506F4A51714C53734D53734E5375
515779525879535A7A545B7B565D7B575E7C575E7C585F7E575F7D57607C59627B5B647B
5C647C5E657E5F667F606681606682626883646B84646C85646C86666D87686E8A676D8C
666D8D676F8D69708D6A728C6A728C6A728C6C728B6C72896C72896C718A6A708A677089
666D87646C85636A81646C81656D82626B80636B80636C80666F816871826C75846F7885
717B86747F8975828B78868D7B888E7F8C91818D93848E9487919989919D8A929E8A919D
8B929F8C94A38D94A28E94A19197A29198A19299A0939B9F919A9B919B9C929B9C929C9D
949D9F969DA1959CA1949DA2949EA2929EA1919FA1909F9F909E9D8F9D9A8C9B968D9F95
7D8C823F42443737342F2D2825211E5C624F5B63504F55454A5241383E31353B2D3D4435
3739317B89729BAE9390A0908C9B8E69716E808C827E8984818E888C9E9084978581947C
3D4337161411201F191D1C171E1C171B1A1418161016130F4246386C7A62454B44606B5E
647165637167434C4B33393B4A584C677B61313A2F272F242A332529302129301E2A3220
2B33232C33222C332129301F
3B415A3E455F4047613F4561414563434665414564414765424665444766454767464868
454968454B69444A69444A6B454C6E464D6D454D6B464E6B474E6D494F6E4C50704E5273
4F5374505475525778535979545A79555B79565D79575E79595F7A59607B5A617B5B627A
5C637B5E647D5E637E606481636684636683636583646784646885666A87686C896A6D8B
696C8B686E8C68708C69708C6A718B6A708A6D728B6F758D70768D71768D70778E6F768E
6E768F6D768E6C758B6B73896B73886A70876B7186696F82676E7F676E7D686D7D6A6F7F
6A6F806B70816A70816A72806C76806E7981757E867982897F878D838A92858C94878F95
8890998C939D8D949D8D949C8F979E90989E91999E919A9B919A98929B9B929B9C939B9E
959C9E979DA0969DA1949CA0939D9E929E9D93A09E929F9D929E9D909C998E9C95919F94
7E897F47474A3937382C25254542397F886E575A4E51564B4E5548444B3D3F4737404538
41443B727C6896A58C92A18F8A978B838E87828F885E666B6E7C778DA28F7F927F80937B
3D42391B171621201C1C1A18191815181613151310181614474D3F697862606D5C667563
667463697967373B3C1A1A25282E31556755323D31272F252A33272A3124293122293222
2B34242B33212A321F2A311D
3C415A3D435D40466040455F414660424761424761404662404663414765444768454869
43466943486B444B6C454D6E464E6F444C6E444C6C454D6B464D6B4A506E4C51704D5271
4D52724D52734F5476515676525877545A78575D78575E77585E77595E785A607A5C637C
5C637C5D627E5D6180606383616485636685646785646883636783666986676A86696C86
696C86696D87696F886870896770896870896A718A6B728B6D748C70778C71788C72788F
7178906F788F70798F727B8F747D8F757D8E777E8F777E8E747C8A727A86717884727786
7174876E71876A6E84686D82676E80666E7D6A707F6D73816F7583727785767A88797E8C
7C838F808892838B93868E938993978B96988E999A909B9B909B9B939C9D919A9B939B9C
959D9C969E9B969E9C939D9C929D9B929C9B919D9B929C9B939C9B929B9B919B97919D93
8691864240463734392D282D646A5BA4B6924C4D424B4F444B5045454C3F4148393E4134
4141366A705E919D8595A28F8D988B8A958B7C8582575A62667170899C8C7D8F7F7D907E
3F46431513181F1F201A1A1A1717161716141614131613144950426E7E67647160687765
6B7967707E6C4248451817233942422C343328312B283127283126293126283125293324
2D35232C35212A311F292F1D
3D415A40435E42466142466141466042475F424760424761434762434665434666444667
43476842476943476A444B6C464E6D454C6B454C6B464C6D474D6E4A50704A51714C5272
4E5272505474515675525775535774555A75565C77555B77555B75575D765A60795B6179
5D637B5D627C5E617F60628360628262648365688565688265687F686A81686A836A6C84
6B6D856B6F886A6E87696E86686E876970876A70876C71896E748C6F758C70758B72778D
73798F73788E747A90757B91767B92787F92798092787F90777E8F79808F7B838F7D828F
7C7F8F7B7E91787C8F757A8E73778A7176887074876E72876E73876D71866E7186707386
737687767A8A767C89797F897C838A7F878C838C908890938A92948A93938D9695909897
939B99959C9A969E9B949C99949E99949D99939D9A929C9A919A99919A9B929B99929E94
869185444146322E34322F3177836B839173505445484D414A4F4443483D373A2F35362A
35322759594897A2878D94868E958D8C948D7C817F72777464696A89998B7E8F817C8F7F
3F464416141B1F1F211B1B1B1A1A19191916151311141211505A476F7E625D6754596253
5C66566C78654D554B19181D4953491E2122212623262E2527302528302328302128301F
2C34202D34202C311F2A2E1D
3F425740435941445D42446042456044475F43465E43465E434760424562424463414663
414762424863434965444966454B68474B68474D6B494E6E4A4E704A4F714A4F724C5072
4D51714F537050556F525670535770545A71565C72555B73565B73565C74585E765A6077
5C60795D617A5E627C5F627E61627F626281656683656882676A7F696D80676B7F686C81
696C836B6D846A6D846B6E856B6F866B6E856C6F856E71876F738A6F748A6F748A71768B
71778C73778C767A8E777A90777B91787D907A80907A808E797F8E7A808E7B828E7D838D
7D828F7E83917E84937F86957F84947F83957F85967E83957B8194787E91777C8F777A8B
787B8A767A89767A88757985777B85787C837C7E857E81877E8388808689848B8D868D8F
888F908E9595909795929996949C97949C97949D99929C9B919A9A909897919996929C93
8A9386423E432F282E4F514869715E5153474E4E46494A434B4F45484D413B3E31383A2B
3E3D2D52514098A1839096869AA1969399928589837577746C6E6A8F9D8B81907F7C8D7A
373C3A17161820201D1C1C191A1B17191B1513141016171355624A5D6A50373B2E33362D
4D53436570594F5645201F1C34382E1D1E1B212720232A21262E22272F22272F21282F1F
2B31202D33212D33212B301E
3F40543F415640435A42455D44465E43455C43455C43465C41455D42455F424561414862
3F4660424861444A62444A62454B64464A65464A67484D6B4A4F6E4A4F6E4A4E6E4B4F6F
4C51704D526D4E546E50556F51576F535A6E555C6D555C6F565C71575C73575C74585E76
585E775C60795D60785F627B61637E63637F65658164668065677E676B7E666B7C666B7D
64697D666A7E696B816A6D836A6E84696C836C6F836E70866F718870748A6F73886F748A
71758A73798A74788B76798E777B8F787C8E7A808F7B818F7A7F8D7B808D7C808D7C818E
7D82907E84927D84937D85937F8695808796838B9A848C9A848B9A838B99848B98838796
8185937E83907B808C797D88797D86797C847B7D837B7D827C7E837D81867F8488808588
818789858B8C888D8C8B908F8E9493909896939A98939D9A929C998F98948E98928F998E
8C9786413E41281D246B705E757E685B5E514A48444A4A454D52484A514444493B404434
4245324C4D3B8E9879939C86ACBAA59DA7998A91857F83796B6D658A978183917B798973
383D381412141E1E191A1A15171A14151913121610171C1337422E424D372F34252A2C21
4A513E677659515C451C1D1823261D22271E232920252A20262D20272E21272D22293022
2C32232E34222C32202A2F1D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.392007 0.97619 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0.0178571 0.00595238 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
480 string
160 120 8 [160 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 300},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001;2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`003Ooooon]0?n001[ooooo[@3oP00?ooooo`003OoooolF0?n000T0003o
1@3oP0020000o`030?n000000?l0003o02P0003oG03oP00JooooobP0oh002P000?l20?n001/0003o
GP3oP00?ooooo`003Oooool50?n000030000o`3oP000oh000080oh00E0000?l40?n000<0003oB03o
P00Jooooo`/0oh0000<0003o0?n000000?l00`3oP0020000o`@0oh0020000?l00`3oP000003o0000
o`0l0000o`<0oh0010000?m80?n000oooooo000=ooooo`80oh00I@000?m60?n001[ooooo0P3oP000
0`000?l0oh000?n0000=0?n000030000o`3oP000oh000580003oAP3oP00?ooooo`003Oooool20?n0
0080003o00@0oh000000o`3oP000oh001P000?l40?n005D0003oAP3oP00JoooooaD0oh00DP000?m6
0?n000oooooo000=ooooo`P0oh0010000?l50?n005@0003o00<0oh000000o`3oP000A@3oP00Joooo
o`T0oh0000<0003o0?n0003oP0001P3oP01E0000odH0oh003oooool000gooooo2@3oP0020000o`H0
oh00EP000?m60?n001[ooooo4@3oP0100000o`030?n000000?l0003o01<0003oAP3oP00?ooooo`00
3Oooool90?n00080003o1P3oP01F0000odH0oh006_oooolA0?n00400003o00<0oh000000o`000?l0
4`000?m60?n000oooooo000=ooooo`T0oh000`000?l50?n005H0003oAP3oP00Joooooa40oh00EP00
0?m60?n000oooooo000=ooooo`P0oh001P000?l30?n005H0003oAP3oP00Jooooo`X0oh000P000?l6
0?n005D0003oAP3oP00?ooooo`003Oooool80?n000H0003o0P3oP01F0000o`030?n000000?l0oh00
04@0oh006_ooool90?n000<0003o1P3oP01D0000o`030?n000000?l0oh0004@0oh003oooool000go
oooo0P3oP00010000?l0oh000?n0003oP01P0000o`030?n000000?l0oh0004@0oh006_ooool80?n0
00@0003o1`3oP0070000o`80oh00=@000?l00`3oP000003o0000o`0D0000odD0oh003oooool000go
oooo00<0oh000000o`000?l0I@000?m50?n001[ooooo203oP0080000o`80oh001`000?l00`3oP000
003o0000o`1<0000odD0oh003oooool000goooooIP000?l00`3oP000003o0?n000140?n001[ooooo
0P3oP0020000o`D0oh00G`000?m50?n000oooooo000=ooooo`030?n000000?l0003o06H0003oA03o
P00Jooooo`<0oh00IP000?m40?n000oooooo000=ooooo`80oh00IP000?m50?n001[ooooo0P3oP00>
0000o`030?n000000?l0003o05H0003oA03oP00?ooooo`003Oooool00`3oP000003o0000o`0=0000
o`030?n000000?l0003o05H0003oA03oP00Jooooo`<0oh0030000?l20?n005P0003oA03oP00?oooo
o`003Oooool20?n006H0003oA@3oP00Jooooo`@0oh00I@000?m40?n000oooooo000=ooooo`80oh00
I`000?m40?n001[ooooo103oP01U0000od@0oh003oooool000gooooo0P3oP01W0000od@0oh006_oo
ool30?n006H0003oA03oP00?ooooo`003Oooool20?n006P0003o@`3oP00Jooooo`<0oh00IP000?m4
0?n000oooooo000=ooooo`030?n000000?l0003o06L0003o@`3oP00Jooooo`80oh00J0000?m30?n0
00oooooo000=ooooo`030?n000000?l0003o06L0003o@`3oP00Jooooo`80oh00J0000?m30?n000oo
oooo000=ooooo`030?n000000?l0003o06L0003o@`3oP00Jooooo`030?n000000?l0003o06L0003o
@`3oP00?ooooo`003OoooomZ0000od<0oh006_ooool00`3oP000003o0000o`1W0000od<0oh003ooo
ool000goooooJP000?m30?n001[oooooJP000?m30?n000oooooo000=ooooofX0003o@`3oP00Joooo
ofX0003o@`3oP00?ooooo`003Ooooom[0000od80oh006_oooom[0000od80oh003oooool000gooooo
00<0oh000000o`000?l0J0000?m20?n001[ooooo00<0oh000000o`000?l0J0000?m20?n000oooooo
000=ooooo`80oh00J@000?m20?n001[ooooo0P3oP01Y0000od80oh003oooool000gooooo0P3oP01Y
0000od80oh006_ooool20?n006T0003o@P3oP00?ooooo`003Oooool00`3oP000003o0000o`1X0000
od80oh006_ooool20?n006T0003o@P3oP00?ooooo`003Ooooom/0000od40oh006_ooool20?n006T0
003o@P3oP00?ooooo`003Ooooom/0000od40oh006_ooool20?n006X0003o@@3oP00?ooooo`003Ooo
ool00`3oP000003o0000o`1Y0000od40oh006_ooool20?n006X0003o@@3oP00?ooooo`003Oooool0
0`3oP000003o0000o`1Y0000od40oh006_ooool30?n006T0003o@@3oP00?ooooo`003Oooool00`3o
P000003o0000o`1Y0000od40oh006_ooool30?n006T0003o@@3oP00?ooooo`003Oooool00`3oP000
003o0000o`1Y0000od40oh006_ooool20?n006X0003o@@3oP00?ooooo`003Oooool00`3oP000003o
0000o`1Y0000od40oh006_ooool00`3oP000003o0000o`1Y0000od40oh003oooool000goooooK000
0?m10?n001[ooooo00<0oh000000o`000?l0J@000?m10?n000oooooo000=ooooofd0003o@03oP00J
ooooo`80oh00J`000?m00?n000oooooo000=ooooo`030?n000000?l0003o06X0003o@03oP00Joooo
o`80oh00J`000?m00?n000oooooo000=ooooo`030?n000000?l0003o06X0003o@03oP00Jooooo`80
oh00J`000?m00?n000oooooo000=ooooofd0003o@03oP00Jooooo`80oh00J`000?m00?n000oooooo
000=ooooofd0003o@03oP00Jooooofd0003o@03oP00?ooooo`003Ooooom]0000od00oh006_oooom]
0000od00oh003oooool000goooooKP000?lo0?n001[oooooKP000?lo0?n000oooooo000=ooooofh0
003o?`3oP00Jooooofh0003o?`3oP00?ooooo`003Ooooom^0000ocl0oh006_oooom^0000ocl0oh00
3oooool000goooooKP000?lo0?n001[oooooKP000?lo0?n000oooooo000=ooooofh0003o?`3oP00J
ooooofh0003o?`3oP00?ooooo`003Ooooom^0000ocl0oh006_oooom^0000ocl0oh003oooool000go
ooooKP000?lo0?n001[ooooo00<0oh000000o`000?l0J`000?lo0?n000oooooo000=ooooofh0003o
303oP0000`000?l0oh000?n0000`0?n001[ooooo00<0oh000000o`000?l0J`000?l<0?n000030000
o`3oP000oh000300oh003oooool000goooooK`000?ln0?n001[oooooK`000?ln0?n000oooooo000=
ooooofl0003o?P3oP00Jooooofl0003o?P3oP00?ooooo`003Ooooom_0000och0oh006_oooom_0000
och0oh003oooool000goooooK`000?lB0?n000030000o`3oP000oh0002T0oh006_oooom_0000oa80
oh0000<0003o0?n0003oP000:@3oP00?ooooo`003Ooooom_0000oa00oh0000<0003o0?n000000?l0
:`3oP00Jooooofl0003o403oP0000`000?l0oh000000o`0[0?n000oooooo000=ooooofl0003o403o
P0030000ob/0oh006_oooom_0000oa00oh000`000?l[0?n000oooooo000=ooooofl0003o?P3oP00J
ooooofl0003o?P3oP00?ooooo`003Ooooom_0000och0oh006_oooom_0000och0oh003oooool000go
ooooL0000?lm0?n001[oooooL0000?lm0?n000oooooo000=ooooog00003o?@3oP00Jooooog00003o
?@3oP00?ooooo`003Ooooom`0000ocd0oh006_oooom`0000ocd0oh003oooool000goooooL0000?lm
0?n001[oooooL0000?lm0?n000oooooo000=ooooog00003o?@3oP00Jooooog00003o?@3oP00?oooo
o`003Ooooom`0000ocd0oh006_oooom`0000ocd0oh003oooool000goooooL0000?lm0?n001[ooooo
L0000?lm0?n000oooooo000=ooooog00003o?@3oP00Jooooog00003o?@3oP00?ooooo`003Ooooom`
0000ocd0oh006_oooom`0000ocd0oh003oooool000goooooL0000?lE0?n000030000o`3oP000oh00
02D0oh006_oooomb0000oa<0oh0000<0003o0?n0003oP0009@3oP00?ooooo`003Ooooomb0000oa<0
oh0000@0003o0?n000000?l0003o903oP00Jooooog80003o5@3oP0020000ob@0oh003oooool000go
ooooLP000?lF0?n000030000o`3oP000oh000280oh006_oooomb0000oaH0oh0000<0003o0?n0003o
P0008P3oP00?ooooo`003Ooooomb0000oaH0oh000P000?lS0?n001[oooooLP000?lk0?n000oooooo
000=ooooog80003o5`3oP0000`000?l0oh000?n0000Q0?n001[oooooLP000?lk0?n000oooooo000=
ooooog80003o>`3oP00Jooooog80003o>`3oP00?ooooo`003Ooooomb0000oa@0oh0000D0003o0?n0
00000?l0oh000000o`0R0?n001[oooooLP000?lF0?n000030000o`3oP000003o0280oh003oooool0
00goooooLP000?lD0?n000030000o`3oP000003o02@0oh006_oooomb0000oa@0oh0000<0003o0?n0
00000?l0903oP00?ooooo`003Ooooomb0000oa@0oh0000<0003o0?n000000?l0903oP00Jooooog80
003o503oP0000`000?l0oh000000o`0T0?n000oooooo000=ooooog<0003o4`3oP0000`000?l0oh00
0000o`020?n00080003o803oP00Jooooog<0003o4`3oP0000`000?l0oh000?n000020?n00080003o
803oP00?ooooo`003Ooooomc0000oa<0oh0000<0003o0?n000000?l010000?lP0?n001[oooooL`00
0?lC0?n000030000o`3oP000003o00@0003o803oP00?ooooo`003Ooooomc0000oa<0oh0000<0003o
0?n000000?l010000?lP0?n001[oooooL`000?lC0?n000050000o`3oP000003o0000o`3oP0000P00
0?lP0?n000oooooo000=ooooog<0003o4`3oP0000`000?l0oh000000o`040000ob00oh006_oooomc
0000oa<0oh0000<0003o0?n000000?l010000?lP0?n000oooooo000=ooooog<0003o4`3oP0000`00
0?l0oh000000o`040000ob00oh006_oooomc0000oa<0oh0000<0003o0?n000000?l010000?lP0?n0
00oooooo000=ooooog<0003o5@3oP0050000ob00oh006_oooomc0000oaD0oh001@000?lP0?n000oo
oooo000=ooooog<0003o5@3oP0050000ob00oh006_oooomc0000oaH0oh0010000?lP0?n000oooooo
000=ooooog<0003o503oP0060000ob00oh006_oooomc0000oaH0oh0010000?lP0?n000oooooo000=
ooooog<0003o503oP0060000ob00oh006_oooomc0000oa@0oh001P000?lP0?n000oooooo000=oooo
og<0003o503oP0070000oal0oh006_oooomc0000oa@0oh001P000?lP0?n000oooooo000=ooooog<0
003o503oP0070000oal0oh006_oooomc0000oa@0oh001P000?lP0?n000oooooo000=ooooog<0003o
503oP0070000oal0oh006_oooomc0000oa@0oh001`000?lO0?n000oooooo000=ooooog<0003o503o
P0070000oal0oh006_oooomc0000oa@0oh001`000?lO0?n000oooooo000=ooooog<0003o503oP007
0000oal0oh006_oooomc0000oa@0oh001`000?lO0?n000oooooo000=ooooog<0003o503oP0070000
oal0oh006_oooomc0000oa@0oh0000<0003o0?n000000?l010000?lO0?n000oooooo000=ooooog@0
003o4`3oP0070000oal0oh006_oooomd0000oa<0oh001`000?lO0?n000oooooo000=ooooog@0003o
4`3oP0070000oal0oh006_oooomd0000oa<0oh001`000?lO0?n000oooooo000=ooooog@0003o4`3o
P0070000oal0oh006_oooomd0000oa<0oh0000<0003o0?n000000?l010000?lO0?n000oooooo000=
ooooog@0003o4`3oP0070000oal0oh006_oooomd0000oa<0oh001P000?lP0?n000oooooo000=oooo
og@0003o4`3oP0060000ob00oh006_oooomd0000oa<0oh001P000?lP0?n000oooooo000=ooooog@0
003o4`3oP0070000oal0oh006_ooool00`3oP000003o0000o`1a0000oa<0oh001`000?lO0?n000oo
oooo000=ooooog@0003o4`3oP0070000oal0oh006_ooool00`3oP000003o0000o`1a0000oa<0oh00
1`000?lO0?n000oooooo000=ooooog@0003o4`3oP0070000o`h0oh000`000?l>0?n001[oooooM000
0?lC0?n000L0003o403oP0000`000?l0oh000?n0000<0?n000oooooo000=ooooog@0003o4`3oP007
0000oa00oh0000<0003o0?n0003oP000303oP00Jooooog@0003o4`3oP0070000oal0oh003oooool0
00goooooM0000?lC0?n000L0003o4@3oP0000`000?l0oh000?n0000;0?n001[oooooM0000?lC0?n0
00L0003o4@3oP0000`000?l0oh000?n0000;0?n000oooooo000=ooooog@0003o503oP0060000oal0
oh006_oooomd0000oa@0oh001P000?lO0?n000oooooo000=ooooog@0003o3@3oP0000`000?l0oh00
0?n000040?n000H0003o7`3oP00Jooooog@0003o3@3oP0000`000?l0oh000?n000040?n000H0003o
7`3oP00?ooooo`003Ooooomd0000o`d0oh0000<0003o0?n0003oP000103oP0060000oal0oh006_oo
oomd0000oa@0oh001P000?lO0?n000oooooo000=ooooog@0003o3@3oP0000`000?l0oh000?n00004
0?n000H0003o7`3oP00Jooooog@0003o503oP0060000oal0oh003oooool000goooooM0000?l=0?n0
00<0003o103oP0060000oal0oh006_oooomd0000o`d0oh000`000?l40?n000H0003o7`3oP00?oooo
o`003Ooooome0000o``0oh000`000?l40?n000H0003o7`3oP00Jooooo`030?n000000?l0003o0780
003o303oP0030000o`@0oh001P000?lO0?n000oooooo000=ooooogD0003o303oP0030000o`@0oh00
1`000?lN0?n001[oooooM@000?l<0?n000<0003o103oP0070000oah0oh003oooool000goooooM000
0?l=0?n000@0003o0`3oP0070000oah0oh006_oooomd0000o`d0oh0010000?l30?n000H0003o7`3o
P00?ooooo`003Ooooomd0000o`d0oh0000<0003o0?n000000?l0103oP0070000oah0oh006_oooome
0000o``0oh0000<0003o0?n0003oP000103oP0070000oah0oh003oooool000goooooM@000?l<0?n0
00030000o`3oP000003o00@0oh001@000?l00`3oP000003o0?n0000M0?n001[oooooM@000?l<0?n0
00030000o`3oP000003o00@0oh001@000?l00`3oP000003o0?n0000M0?n000oooooo000=ooooogD0
003o303oP0030000o`@0oh001@000?lP0?n001[oooooM@000?l<0?n000<0003o103oP0050000ob00
oh003oooool000goooooM@000?l<0?n000040000o`3oP000003o0000o`@0oh0010000?lP0?n001[o
ooooM@000?l<0?n000040000o`3oP000oh000000o`<0oh001@000?lP0?n000oooooo000=ooooogD0
003o3`3oP0020000o`@0oh0010000?lO0?n001[oooooM@000?l?0?n00080003o0`3oP0050000oal0
oh003oooool000goooooM@000?l?0?n000030000o`3oP000oh0000<0oh0010000?lO0?n001[ooooo
M@000?lD0?n000D0003o7`3oP00?ooooo`003Ooooome0000o`l0oh000`000?l20?n000D0003o7`3o
P00JooooogH0003o3P3oP0030000o`80oh001@000?lO0?n000oooooo000=ooooogD0003o3P3oP004
0000o`030?n000000?l0003o00@0003o7`3oP00JooooogD0003o3P3oP0040000o`030?n000000?l0
003o00@0003o7`3oP00?ooooo`003Ooooomf0000o`d0oh0010000?l00`3oP000003o0000o`040000
oal0oh006_oooome0000o`h0oh0010000?l00`3oP000003o0000o`040000oal0oh003oooool000go
ooooMP000?l=0?n000@0003o00<0oh000000o`000?l010000?lO0?n001[oooooM@000?l>0?n000@0
003o00<0oh000000o`000?l010000?lO0?n000oooooo000=ooooogH0003o3P3oP0030000o`030?n0
00000?l0003o00@0003o7`3oP00JooooogH0003o3P3oP0030000o`030?n000000?l0003o00@0003o
7`3oP00?ooooo`003Ooooomf0000o`h0oh001@000?l00`3oP000003o0000o`020000oal0oh006_oo
oomf0000o`h0oh001@000?l20?n00080003o803oP00?ooooo`003Ooooomf0000o`@0oh0000<0003o
0?n0003oP0001`3oP0050000o`80oh0010000?lN0?n001[oooooMP000?l40?n000030000o`3oP000
oh0000L0oh001@000?l20?n000<0003o7`3oP00?ooooo`003Ooooomf0000o`h0oh001@000?l20?n0
00@0003o7P3oP00JooooogH0003o3P3oP0050000o`80oh0010000?lN0?n000oooooo000=ooooo`03
0?n000000?l0003o07<0003o3P3oP0050000o`80oh000`000?lO0?n001[ooooo0P3oP01d0000o`l0
oh0010000?l20?n00080003o803oP00?ooooo`003Oooool20?n007@0003o3`3oP0040000o`80oh00
0P000?lP0?n001[ooooo0P3oP01d0000o`l0oh0010000?lT0?n000oooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo000=ooooo`0602lj6P0]
>QX0:STL02Xh8P0Z=bT0:SP/0P0[>2d02`0]>C40;3Pb02hg=P0`>CP0<3Ti034j>P0a>cP0<3/h034m
>@0c?CT0<cdj0080<S`i00/0<c`j03<m>`0c?CT0<S`j03<n?00d?Sd0=T4n03E0?@0e@Sh0=D4l03I4
>`0203I3>P0<03M4?00hASh0>DLo03]9@@0lBd80?D]203e;A00nCDH0?di7041?B010CTP0@4i90P11
D4X02`11D4T0@E18045@B@14DdX0A5=904ADBP14ED`0AUM=04AEB`14E4`0AUI>0080AeM>00/0AeQ>
04UICP1:FTl0Be]?04]LD01<GE40CEiA04aLCP1<GDl0CEe?04]MC`0404eND@0904]LC`1;G4h0BUY=
04YJB`1;GDP0@UDj01DP3P0@60L041H600802a0300@02@d200P<0P0830801`L00P071P0010030`00
0P<0004200000P0200<400<00`<000X00`8000D20`050PH01P@600<21@020P@010@200H60@061@40
2@T30P0;2`D02`0>3PP03a49018C2`0D5@d05AH=01DG3@0D5Pd04a<=010@2P0>3@T02`/800<030`8
00/02@X600L80`0620<01PL100D70@031@000`<0008200010P000P<000<3000200D60@0;00L80P05
1`4010D000H60P0:2P@03a0800lA2@0?40X0414;00lA2`0?40/00P0=40X02`0?4`/02`h900420001
0`000P<0004300000P000@40004200000`0000<10080008500H0008900013@0101000P0<00D41`00
0@0Jooooojd0oh003oooool000gooooo00H0@4e505EWEP12DDL0=T11038h@P0f>dX203PoBP0;03]1
C@0i?Td0?45C03i4E@0nAUH0@DUH04=<FP15D5`0Ae9M04QBG@18DE`00P18DU`01P19DUh0BE=O04MB
G`17DUl0AU9O04QCH080BEAP00<0BeIR04]EH01>Eel00P1<E5d0301>Ef00CeUR04eHHP1?FV<0DE]S
055KI01AFVL0DUaY05AMJ`1EGf`0EEeZ05IOK080F65^00/0FF=^05YTK01KIF/0G6I/05eWKP1NJG40
GVYb05iZL01OJg00Gf]b061]M002065_M00;06=aM@1WM7L0J7Ei06QeN01VMG/0IWEm06QhO@1XNGX0
JGYi06akNP1/Ng/00P1/Ngd02`1/Ngh0KGan06ilO@1^OG/0L7ik071oN01`OgL0KWmb05YXG01IJ5X0
FFMI0080Ef=G00`0EF5D05EPE01AG540=SXh03<g=@0`=380;34/02T^:00Y;BP0:2`Y02P[:@0W:BT2
02HW9`0;02DW9P0T9bD04a4G00l<4`0>3A402@X=00L92P072@H020X400T<1@0:3@@00P0930<01`0:
3@@02@d600/=1P0<3PH030d600lA2@0?4PX00P0?4`/0400?4P`03Q4=00hA300>4@`03Q0:00`>2009
30D02@`300T<0@0;40803A4400hA1P0>4PP03Q<:00dA2P0=40T200h@2@0500h?200<3PL02@/400X;
1@0;3PD00P0>4@P0100=40L02`h600T<10082`@200X=1@0;00T<100620401PT200H90P0620<01PP4
00T<1`082`H00`D100450@031@X00P0311@01P020aH010@H00P75`0<20/02`P300H70A[ooooo?P3o
P00D0000oe/0oh003oooool000gooooo00H0<SQ:03DlCP0d>Tl0=CU@03DiD@0e>E8203LlDP0;03Pm
DP0h?E<0>CiE03PmEP0i@5L0>d5H03U0E`0j@5L0>d9H03i5F`0oAU`00P11BE`02`12BU`0@T]M0459
G@10B5h0@4UN045;H014C600@d]P049:G`15C5l0AT]M0080AT]N00`0AdeR04Y?I@1:CfH0BU1U04]@
I01<DFH0C55X04eBJP1<DVT0CE=[04eBJ`1>DfT204mDJ@0;051EJP1@EVT0DUUY05=JJP1DFf`0EEa_
05IML01FGFl0Eem_05QOL01JHW800`1KIG<02P1OJ7H0H6Uh061ZN01OJWX0GVUk065/NP1RKWT0I6mj
06E_NP1VL7/306IaO00:06IbO01XM7d0JGAm06]fO@1/Mg/0KGUk06ilO01`OWh0LH1o0760O@80M89m
00`0MH9n07N2P01fPX00Lgmo07>0O`1bP7d0LX5j07>1N01dP7L0M7mg07F0N@1dOgX207=nNP0;071l
MP1`Og@0>Ce001/K8@0K71l04A@D00dA3P0:3@T02P`400T<0`0930800P082`400`062P000`H000<4
000200@5000600@400051P401@L100@50@061`<01`P30`061@802`071P<01PL300H80@062@403a<8
01DJ2`0H7@h06R0@01dS4`0L8Q<06R0B008071lB00/071hC01PJ400D5@`04A4800h?1`0<3@H02`d5
00X;10072P801PT000H8000200@6000300<4000210000P@000800`D000H01@L200T<1P0:3@H020/2
00<50003108200D5100600D6100=3`H051H;01TJ3@0F5`/04A8:6_oooom>0?n001T0003oAP3oP00?
ooooo`003Oooool00`0b>4/0<cQ?03<hD`0203<iDP0>03DkE00e>e<0=C]C03HlE00f?5<0>3iE03Po
EP0h?UH0>d=H03PoE00i@5D0>T9E03e5F00nAU/20418F`0;045:G@12BUl0@TYN04=9GP13BEl0@dYO
04A;H014C640ADaR04I=HP17CF800P18C6<03018CF@0B4eU04Y?IP1<DFL0CU5V04eAI@1?E6L0CeAX
04iCI`1<E6L0CUEY051FJP<0D5IY00X0DUYZ055JJ@1CFVT0E5]Z05IMK01FGFh0Eei_05MOK`1IH700
FV9b0P1LIGD02`1MIG@0GfQe05mXMP1QJWP0HF]i069/NP1RK7T0I6ij06M_NP1XL7/0Ig1k0080IW5k
00/0IW1i06UcN`1ZM7d0JGAn06YeOP1[N7h0KGUm06ekO01^O7`0Kgen071mO002075oO006079oOP1b
OWh0LWin079oO`1bP7l0M89n0P1ePW`0101ePG/0MH1k07F0N`1gPGh207EoOP0;07AoN`1cPWX0ATe@
020P:@0P8RD05aTJ010B400>4@X030h500P<0P0830<00P0930<02`093@801@P100<5000310000`D0
00@3000510001@D000T8000<2`<02`X3008020H200`01P@100P70P0720801PL100D80@0=4@H051P:
01PL3@0L81407R<D01lS5@0N8Q<201hR4@0;01dP400J70h05QL;018C2P0=3`P02``500T;1@0930D0
2@`400T<0P062P400P041`001P041@000`D000@70005204010H100@600801`X100<01@T000840002
0`000P030`001P040`002P/0014A1@0D50T04a<9014B2a[oooooC03oP0000`000?l0oh000000o`0H
0000odH0oh003oooool000gooooo00H0=CY<03DiD00d>E<0=CYC03DkD@0f?58203PmD`0;03TnE@0i
?UH0>T1F03U0E@0i?eH0>d9F03]1D`0j@E@0?DAE03m5E`0oAUX00P10B5/01`10Aed0@TUN04=:GP14
BUl0A4QP04=8H@13BF400P14Bf804016C6<0ADaT04M>I@17CVD0AdeT04Q>H`19CV<0BdmT04e@I01>
DVD0CeAV04iCIP1>E6H0CEAV04iFI`1?EFL2051EJ00;055FJP1BF6/0DEUZ059JJP1CFfX0EEa[05MN
K@1HGW00F5ia05UQLP1JHg800P1LI7<02`1MIG<0GfQd061YM01RJgH0HVag069/N01SKGT0IW1i06I_
N@1WKgX0J71k0080Ig5k00/0IW1h06QaM`1ZM7P0JWAi06]fN`1[Mgd0K7Qm06eiO01_Ng`0Lgin07Ao
P00207F0O`0<07>0O@1cP7`0Lh1n07>1O`1bPGh0M85m07F2O@1dPW/0Mh=m07R3OP1hPgl0MH1n0P1e
Ogd02`1dOg`0Lh5j051HFP0P7b`07R0V01TK7@0C51@03Pl=00`=2@092`H01`T400801`X300/020`2
00D900031P000P@00083000410001@D000@5000820002PT100X90`0200P7100<00D60P092PD02P/3
00X=0P0930402P`200h@1@0E5`T06Q`<01hP4@0O8Q<082@B0P0O8Pl02`0N8Pl071l>01LH2`0B5@/0
3Q8:00/>1`092`D02@`500P;0`0930<02@`400802@d200/020X000H900062@001`T100H80@051`00
20/000L:00031`000@<000<3000200@2000600@100071P003@d4014@1P0B4`P051D<6_oooom<0?n0
01/0003oAP3oP00?ooooo`003Oooool01P0d>T/0=3Q<03DjD00f>U40=c]@03TmD080?3mC00/0?3mF
03/oE`0i?UH0>CmD03]0E00m@U@0?T9D03m3E012AUL0@TEJ0496G@0204A:H0@0@dYP00L0@dQR04A8
H@14BV40AD]R04A;HP16C6<0AdeU0080B4iV00`0ADeU04M>I018CF80BTiR04a@I01>DVH0CU=V04eC
IP1?EFD0CeEV051EI`1@EFP2059GJ@0;05=HJP1BF6X0DUUZ05ALK01DFf`0EEa/05QNK`1HH780FF1b
05UQL`1KHg<00P1LI7<02`1MIW@0GVQd05mYL`1QJg@0HFad069]MP1TKgP0I71h06EaN@1VLW/0Ig9j
00<0J7=j00X0JG=h06UcMP1[M7L0K7Ih06agN@1/N7T0KgYh071kN@1bOWd0Lgim0P1dP7h207B1O@03
07B3O@1bPG`0LX9k0080LX5k00D0M8Al07N4O@1hPgh0N89n07J0O@0207J1N`0;07F0N@1dP7T0GfQV
02HV<`0N82P0720R01PK6P0A518030l=00X<2@0930D00P082`401@072P001@P000@700041`000`D0
00800`@000@010H000P90@092P802P`50P0:30H0300930H02@d600/=0`0=4P<03A8200/=0@0:3040
41@601HJ2@0K7`h07R8?01lU4P807R<A00P07B4@01`O400J7@l05Q/@018G300?4`T03@l700/>1@80
2`h400d02Ph200/@0P0;4080314100T=0@072`4020X200H80@041@001PP000H900031P000@@000<0
0@8000H00@4000<4000930@03a46014D1`0B5@XJooooodd0oh006P000?m60?n000oooooo000=oooo
o`0603@kB@0f?D`0>3i?03PmD`0h?U<0>SmB0P0l?e402`0k?e@0>T1G03ToEP0k@ED0?49C03e4D`0o
AE@0@DME04=:F@13BEh0@dIO0080A4MR00/0ADUT04I<I@16Bf@0AD]S04I;H`17C6<0AdeT04Q?IP16
CVD0AdiU04Q?IP0204Q@I`0<04I?I`19DFL0BE5T04]AHP1>DV@0Ce9V04iCIP1?EFH0D5MW051FJ01A
EVT0DeUZ0P1CFF/02`1DFF`0DeY/05AJK01DFfd0EE]]05MNKP1HGfl0FF1`05QOL01IHG80G6=c00<0
GFId00<0GVQe061[M01RK7@00P1QJg<01@1RKGD0I71h06A`N@1ULG/0IW9j0080JG=j00/0JgEl06ae
N`1[MGP0JgIh06agN01]NGP0K7Uf06ilMP1`OGT0LGim079oOP0207>0O@0<07:0O@1dPGd0MH=n07>2
O@1ePgh0M8=n07B2OP1fQ7l0Mh9n07R3OP1hPWd0MX5l0`1eP7/02P1gPW`0J79_02d^>P0T9Bl0828W
01lP8@0I6aP04A8?00/=2007208200D8000400L:00062P0010L000@70@800`D000D010H100D70@09
2P802P`400/?1@0200`@1@803A4800X0310700hC1P0>4`L0310600T<0`0=4@L04QL;01PN400K8A80
7RDC0P0O9AD02`0L8A<06alB01/O4P0I7a405ad@01HL400C60`03a@800/@100;40D02Pl400803144
00/03A8300/@0P0;3P<030d300P:00041@001@D000H700051`0010H0008300020002000600010000
0P001PP200`?1@0?4`P04QL;6_oooom:0?n001d0003oAP3oP00?ooooo`003Oooool01P0d>dT0=Se<
03PnC`0h?E<0>3iC03XoDP80?3mA00/0>cmD03Y0E`0i?eH0>d5E03a2D`0mA5<0?dED0457E@13BUT0
@dUN04=6G`0204A7HP0;04E9I016C6D0AT]T04E;H`16Bf<0AdaS04M=I018CfH0ATiU04M>I@18CfH0
0P18D6L03016CfL0BE5W04UAI01;DF80CU9T04mBIP1>DfH0CeEV051GI`1@EVP0DEIY05=IJP80DeU[
00/0E5U/05=JK01DFV`0E5]]05EKK@1GGVh0F5m_05UPL01HGg00FF5b05aSL`0305eVM00305iXM@1P
Jg@0HVad0080HF]c00D0HVee06A`N01TL7T0IG5k06IbNP0206UcNP0;06]eO01/MG/0JgEh06]fN01/
MgP0KGUh06aiMP1^O7H0L7ei075nO@1bOgh00P1cP7d0301bP7d0M85m07F3OP1cPWd0MH=n07B3OP1d
PWh0MXAo07N2OP1hPgh0N89m07J1O0<0MH1k00X0Mh9l06QbK`0];SX092D_020R9`0O82406A/H014B
3`0;3@P01`P20P05200010072P001PX000@700041`4200<5000500@60@051`402@X200X<100;3`D0
0P0<40D200dA200:00`@1`0>4`H03Q<700`@1P0930<03A47018G2`0H7Q006b4B01hU4`807bDE00/0
724C01/O4P0K7a806AlA01LM400F71004aP<00lD200;40@02a0500X?100200`A100;00dB0`0;4080
2`h300`=0`082P0010D000D500061`001@L000@600020`000P000P001P000@00008000H80P0<3`D0
3a<8018G2a[oooooBP3oP00M0000odH0oh003oooool000gooooo00H0=3]:03DkC@0f?4l0=Se@03Hm
D@0i?e8203Y0DP0;03ToD`0j@5D0>T9H03a4F00nAEL0?dMF03m8EP10B5H0@TYI04A;GP13B5h00P14
AV001`16B6D0B4aY04Q<J016BfD0B4aT04Q=H`19CfL00P18CfT02@18D6P0BE1W04YAJ01:DFP0BE5X
04YAIP1;DF@0C59T04mCI@02055DJ005055EI`1AEfP0DEIX059IJP1CFf`00P1DFfh02`1CFFh0DeY]
05AJKP1DFfl0EEa_05INL01GGfh0F5m^05UPL01LHW@0GF9d0080GVAe00/0GVMf05mYM`1RJgT0HVah
06=]N01TL7X0Hfii06E`N`1ULG/0IG9l06McO@0206UdOP0;06efO`1]MWd0JGAk06YfN`1/NGX0K7Yi
06ilN@1^OGT0Kgik071oO@1bP7h00P1gQ800101fPWl0Mh>007V4P@1gPh0207V4P@0607R4P01iQ800
Mh9o07Z3P01jPgl0N85m0P1gPG`02`1fPW`0MhAl075kM@0k?DD09RH`02@U:P0T9RH07QlM01LH4`0A
4P`02`d6008020/20P0830002@093@<02`h500P:10051`8010H300D60`082P@02Pd500X=100200`A
1@0<00/?1@0<3`H03A8800hC2P0?50/03a<:00`?1`0;3@H04AD;01PN4@0L8Q@07bDE0P0P9QL02`0N
91H07B8E01hR4`0J81<05Q`@01<I3@0@5P/03aD900`A1`0;40H02a4700803A8800/03A4500/@0P0;
3P803@h200T;00062@001@P000D700041`0010H000<4000200420006000100010@001PP200`?1@0>
4PP041@:6_oooom:0?n00080003o00<0oh000000o`000?l06@000?m50?n000oooooo000=ooooo`06
03<kC00e?500=SeA03DlD@0h?e80>3m@0P0h?e802`0i?e@0>T5G03]2FP0l@eX0?TEJ03i6F00mA5H0
?dIG0458F@11BE/0@TUN0080A4UR00/0AdYW04Q<J@18CFP0ATaW04M=IP18CVL0BE1W04Q?J@19D6T0
BU1Y04Y@I@0204aAI@0<04]AI01=DVD0C55U04eBI@1>DfH0CeAW055FJ01AEfL0D5MV055GI`1AF6T0
DUQZ0P1AF6/02`1CFV`0EE]/05EJK@1EFVh0EEa_05MOL01HH740FEm`05]QL@1MHW80GV9d0080GFAe
00/0GVMf061YN01RJgX0Hfej069/NP1SKW/0IG1k06IaO01UL7/0IG5k06McO00206]fO@0;06efOP1]
MG`0JW=l06]eO01/MW/0JgQj06ejN`1^Ng/0Kgak0760OP1bOgh00P1fPh001P1gQ840N8>107V3P@1i
Ph00NH=o07Z4P080NX>000@0N8=o07Z3O`1jPgl0O8B00P1kQ7h02`1hPg`0MX9j07R4N@1<CTl0928/
02HU:@0S92<0828N01dN5`0E5A00414:008030l600/020/300T<0`0<3`L03Q4:00`>2@092`P01`P7
00H61P082@L02P`800X<1P0200X=1P0<00T<100:3@@03A4700hC2P0@5@`041<:00d>1P082P803A06
01HL3`0L8Q@082LG0P0P9aP02`0P9AP07R<G01dR500K8A<05ad@01<G300@5@X03Q<900`@1`0;3`H0
2Pl600802`l600/020`300X=0P0930002P/000L800051P0010H000D700041P000`@0008300030042
0005000200031@002P`200d@1P0>4PT06_oooom80?n000@0003o00<0oh000000o`000?l06@000?m5
0?n000oooooo000=ooooo`0303DmCP0f?e00=T1@0080=cm@00h0>D1A03Q1D`0h@E<0>D1F03]3FP0k
@U/0?D=K03i5FP0oAUP0?dMF0459F@12BUX0@TYL04A;GP80ATaR00/0B4eU04U>I@17CF@0ATiT04M?
H`18Cf40BE5R04YBI@1;DfL0CE=Y04eBJ00204iCI`0504iBIP1?DVH0CU9V04eCIP1>EFL00P1@EVP0
1@1@EVL0DEQW055HI`1BFFP0DUY[0080DeU[00/0EE]/05MLK@1HGFh0FEia05UOL@1IHG<0Ff=d05aS
M01NIG@0GfId05iUM@0205eVM@0;05mWM`1QJWP0Hfai06=/N01SKWT0I71i06IaNP1WLg/0Ig=j06Mc
N`1YM7`00P1ZMW/02`1ZMG/0K7Ek06efO@1^MWd0KGMm06ahN`1]NgX0LGij07:0N`1eP7h0LWmo0080
Lh1n00/0Mh=o07R3P01jQH40NXB207^3P@1kPh00Nh>107^3P01kQH00NXAo07^5O`0307Z4OP0;07V3
O01fPGT0N8Ak05AJF@0S7bP092<W024Q8P0Q8Ql0828K01TJ4P0B4``00P0?4@/02`0>4@/0310900`?
2P0=40/03@l:00`=20092PH020P500T8100:2PL02P/800802@`700`020X400L90P0:3PH03a@:018G
3@0A5@/03Q0600/;0@0>40D05Q/>01XQ4`0N9AD201lV5`0;01hT5P0M91H07R@F01`R5@0H7A4051P=
010D2P0=4PP0310700/@1P0:3PD00P082`<02`072@802`d400T;000:300020T000D600041P001@L0
00H900041P000P@000800P<000H00@<00002000310002@X100`@100<3`HJooooodP0oh0080000?m5
0?n000oooooo000=ooooo`0603M0D@0g@580>45D03Q1D`0i@E<0>dAE0P0lA5P02`0kA5X0?4=L03e4
G@0nAed0?dMK03m9FP11BUX0@4UI049;F`14CUd0ATiO0080AdeP00D0B4iR04Q>H@17Cf40Ae1Q04QA
H@0204UBH@0404YAH`1=DVP0CU9/04mCK@80CeA/00`0D5AZ051EJ@1@EVT0CeAX051GJ@1AF6T0D5IV
051GI@1BFFL0DUYX05=JJP1EGFh205MNK`0;05QNK`1GGFl0FF1`05]RLP1MHW<0G6=e05aUMP1MIGH0
GVIc05mYM01NIgD00P1OJ7D01P1PJ7P0HV]h06A]N@1UL7X0IG5i06IcN080IgAh00<0J7Eh06UeNP1Z
MG/00P1[MG`02`1]Mgh0KGMm06iiO@1_NGh0Kg]o071mOP1`OWX0LX1h07>0NP1ePGd0M85n0080MX=o
00`0NHF007Z4P01kQ840OHN407j7Q@1mQH<0OXF307f5PP1lQX40NhEo07^6OP1jQGd207^6O@0;07^6
OP1iQ7/0NXQn061[I@0S8B/08b<X02<T9P0Q92807b<M01/N5P0F61000P0C50h02`0A4`d03a8<00h@
2P0=3`P03Pl800d=1@092`@020P000T:0P0:2P@02PX600802@X700`01`T700H81@0930P03a@<018G
3P0B5P`03Q0600X90@0?3`D05aT=01/P4P0M91H201lV5`0;024W6@0P9QT07bDI01hU600J81D05AX?
010E2`0=4@T02`h700X=1@082`<00P082P<01@07208020X200L900082@001PL0008010H000@010L0
00D80006200010H00P0310001P020`00008000D7000<3@803Q0400`>1A[ooooo@`3oP00U0000odD0
oh003oooool000gooooo00H0=ciB03LoE@0h@5L0>D5G03U1E@0j@UH203Y2E`0;03a3FP0nA5d0?dEN
0418G`10BF00@DYP04==H013CEl0A4iN04M@H016Cf000P17CV002`18Cf40B59R04QAH@18DF40B59Q
04]DI01<EFH0CEAW051EJP1?Df`0CeA^0080CeA]00<0CeA/04mEJP1AEfX00P1@EVT01`1AF6X0DEY[
05=KJ`1EGF/0E5a/05ELK@1GGfh00P1GGFh02`1HGFl0F5i`05UQLP1IHW80G6=d05eUMP1MIWL0GVMh
05eVMP1MIW@0GVMe0080GfQe00/0HVYg06A[NP1TK7X0I6ik06EaN`1VLGT0Ig=i06QeN01ZMWX0JWEk
06]dN`0206efO00;06ifO@1_N7`0KgUk079kO`1bOH00LGin07>0OP1ePGh0M89n07F1O`1gPX000P1h
Q840301jQH40NXF007b6PP1mQh<0OHJ407b5PP1mQH00OhN307n9P`1oR840OhV107n9P080OHQn00/0
OHMm07R4N`1jQg`0K7Q_02h^=P0Y:Rl0:Bh/028Y900J7aT05Q/D01<D3P02018C3@0;018B300A4@X0
40l900l>1P0?3`D02`/100P;0@062@0020/000P:0P0930D00P0:30H030092`L020X700/>2P0@5@`0
41@<00lC2@0?40H02PX100X90@0F60T07B4B020V5`808BLH00/08RHI024V6P0O9AT07RDI01XP500C
6@d03a<800`@1P0;3PD02Pd500X<100200P:0`801`T300H010H000<500010`000P@0008500041P02
00D7000900<500021@000PD0004300020P001@D000/;0P0@4@H03a0701[oooooA03oP00U0000od@0
oh003oooool000gooooo00H0=ceD03PoEP0k@UT0>T9I03Y2F00lA5H203Y1E@0;03a3F010AEd0@4IO
0417H@11BF<0@daR04E>H`14CV80ADiQ04I?H@16CV400P18Cf802`1:DF@0BE=T04M@HP18DF80BE5R
04UAI01;DfH0CUEX04mDJ`1?Df`0Ce=^0080CUA]00`0CeE^04mFK@1@EVX0D5MY055GJ@1BFF`0De]^
05ALKP1FGVl0EUe^05QML01IGW8205QML00;05UML01JGW80FV1e05YQM@1LI7H0GFEg05eVMP1OJ7H0
GfMf05mWM@1OJGH00P1PJGH0101RJWP0I6]l06A/O@1VKgh206MaO@0506UcO@1ZMGd0JWIm06YeO01/
MG/00P1`Mgh02`1aN7l0L7Qo071jP01aO880LWf207=mP01dOh00Mh:107J2P@1gPX40NH:20080NXB3
00<0NhF307Z4PP1lQX@00P1lQX@01`1mQh@0OHJ207j8P`1oRH<0P8Z307n:P`1oRH400P1nR7l02`1n
RGh0NhIl07R4N`1gQ7P0>3Xn02LX;@0/<Bd08BHP01HI5@0A51003Q4<00<03Q0:00X03Q0900d?1`0;
30<02P`200X<00082`0020`200/>0`0930<02Pd40P0:30@030082`<01`T300/<1P0>4@P0418700h@
100<3@802@P000T80@0E60T0728C01lU608082LI00L082HI01lT600N91L07R@F01TN4@0B5P/03A46
00802`h400l02Pd400X<10072P<01`X300H90P072@800`D0004300000P000040004200020`000`D0
00@6000310000P010`001P010P000`<000T90P0=3PD04148010B2A[oooooA03oP00U0000od@0oh00
3oooool000gooooo00H0>D1B03Y1E@0k@UP0?D=J03i5F`0oAU`203m6F`0;03m6G011Aed0@DQP049:
H`11BF<0@TYT04A=I014CF80A4iQ04I?HP18DF800P19DV@02`1<DfD0Be9U04UAI@18DVD0BE9W04UC
IP1<EFT0CeI]051EK`1@E6l0D5E`0080DEMb00`0DUQc05=ILP1CFW00E5]]05=JK01CFf`0EEa^05MO
L01HGfl0EUe_05UOLP1KH7D205YPM00;05YQL`1LHG@0GF9f05eSM`1OIWP0GVIf05eVM@1OJGD0HF]f
061ZMP1RK7P00P1SKGT02`1TK7X0Ifin06QaP@1XLX00Ig5n06QcOP1ZMGl0JgEn06afO`1^N7l0L7Z0
00<0LW^300X0Lgj4079mQ01bOXD0LWf307IoPP1gP840N86207R2PP1iPX80NH>20P1kQH@02`1lQH@0
O8F507b6Q@1nR8L0OhZ707n:Q@1oRH@0OhZ4082:Q021Rh<0P8^200<0PXb300/0PH^107j8OP1lQgd0
O8Um04E8B`0U92/0:B`[02@W8P0I6aL04A8A00l?2`0200h>2@0;00l?2@0?40P03@h600X;10092`@0
20X200L90@092`<02`h500/>1P0;3PD00P092`@030072P802@/400/=1@0;3P@02`h200X=0@0:3040
2@X000`?0`0H70d07B<D020W5`8082PI00/082LI01lT5`0P91H07bDF01/O4`0C5``03a8800/?1@0;
3P@02P`300P:0P0200H90`0300D70@0520000PD000<00P<00P010`000`0310001@H000@500020083
000600410003104030l5010D2P0B5``041@;6_oooom30?n002H0003oA03oP00?ooooo`003Oooool0
1P0k@e80?4=E03i4FP10AE`0@DEO0456H080@DQO00/0@DUN045:G`13Bel0@daR04=<H`13C680@TaO
04==G`15CUl0B51Q04]CI00204aDI@0;04eDIP1<DfH0BU=V04]EJ@1:E6X0BeE[04aFK01?F6l0DUU`
059ILP1BF7000P1BFW40301BFG40DeYb05ELLP1EG740EEa`05INK`1GGW00FF5b05QPL@1GGW00FF5d
05YRL`80FF5c00/0FV=c05eUM01NIWD0GfIf061VM`1OJ7L0GfUf061ZMP1RKGH0HVeg06=]M`0206A_
N`0;06E^O@1XL7l0JG6306UbP`1ZM8<0K7J206agP01]Mgh0KWQo071iP01`Nh800P1`O8<02`1bOX@0
M7j307AnPP1dOX<0MGj307R1PP1iPX80NX>207Z4P`1kQ8<0O8J40080OHN50P1nR8L02P1mR8L0OhV9
07n;R020RhL0OhV507n:QP1oRXD0P8Z5086;Q023SXH208B>QP0;08><Q020RX00OHMm082<OP1DF5L0
9b@]02PZ;@0V:BL07AlL01DE4P0?3`/00P0<3@L02`0=3PH03Pl600`<100:2@<02PP400X910092@80
20X200X<100<3PD02`d600802Pd600`020/500X<1P0:30H02@X400L:0`092`<02Pd300X=0@0@4PH0
6Ad@01lS5`0Q9QP202<X6@0;028W6@0Q9AP082<F01lT5@0K81805AT=010D2@0>4PL0310600/=1@0:
30D00P082P@00`0520800`D0004400020084000600<300000P000@<000@600051P000`D00P031000
1P020`000`@000hA200D6@d05AX>018F3Q[ooooo@@3oP00X0000od@0oh003oooool000gooooo00H0
>d9C03a3EP0oAUX0@4ML0456G@11Aeh20459G`0;03m7G`11B600@daQ04A=HP14CF<0ATmR04MAHP18
DEl0BU5O04eCHP1>E6D00P1>E6H02@1>EFL0CEIX04aEI`1<EFP0CEI[04iGJ`1?F6`0DEY/05=LKP02
05=KK`80EEa`0P1EFg000`1EFfl0EU]`05ELLP0205IMLP0505INL@1GGg40FF1b05UQLP1JHG400P1J
HW402`1KHg80G6Ed05iUMP1PIWH0HVMh069XN01SJgT0HV]h06A^N01UKgX0IFej0080IVim00/0JW1o
06]`P@1/LX@0K7>606mfQ`1^MHD0KgR306miP@1^NGh0KgUo075kP@02079lPP0707=nPP1fOh<0MWn2
07IoQ01fOhH0Mh6407R1Q00207^5Q00:07f7Q@1oRHL0OhV707n9Q`1oRXT0P8Z907j9R@20Rh`0PHf;
08:<R@80Phb800@0Phf9086<Q`21S8H0PHb50P24ShD02`25SX@0Phb107n8OP21S7l0GV=N02LT;P0X
:Bh092LU01/O6P0D5a4041<:00803A0700L030l600dA1`0;3PD02``400T80`081`<020X300802@/3
00<02P`300X<1@0:3@D00`0:3@D02P0930H020/600L:1@082`<02@`300P:0P0<3PD05Q/@01dR5P0Q
9QT202@X6@0;02<W6@0R9AP082@F020U5@0M8Q@06Ah@01DI300?50P0314600/>100;3PD00P0:30D0
2P072@<010H100<5000210000`@000@400020`000`@000@600041`0300840006008200030`403a89
01@H3P0F6Q805ATC6_ooooln0?n002/0003oA03oP00?ooooo`003Oooool01P0l@e<0?DEF03m7F@11
BE`0@DQL04=:GP80@TUO00/0@DQS0499H`14C6<0ATmS04E?H`17D6<0BU=S04YCHP1=Df80CeEU04mF
IP02051FJ00;04mGJ@1?F6T0CUQY04mHJ@1@F6X0DEQ[059IJ`1CFf`0E5]]05AKKP1EGFl00P1EG6h0
301FG6h0Eee_05]OL@1JGW80F5id05MNM01FGW80EEia05MOL01HH700FV9b05aTL`80GFEd00/0GVIe
05mVM`1QIgT0HVQg06AYN@1TJWX0IVak06E/N`1VKW/0IVmk06M_O00206U`OP0;06aaP01/Lh<0K7:3
06eeQ@1aN8H0L7R4075iQ01bNH<0LWZ0079kP01dO8000P1eOH802P1gOX<0N7n407MoQ@1hPHT0N86:
07V2R@1kPhT0OHJ807b6Q@1nQhH307n9Q`0<082:R021RhT0P8Z:08>=S@24SXd0QHj<08B=R@24SXP0
QHj908B>R@23SHH0Phj40P24Sh<02`24SX<0PXb1086:O`21S7h0J71X02l/=00_<380:2XY01dR7P0D
6A<04AH;00803a8900<030l700/>1`0:3@L00`0;3@P01@0:3@D02Pd400X=100:3@@02`h500802`d5
00`02`h600/?1P093@D020`500L;0`0830<02@h300X=0`0;3`D04QH<01XN4@0O91H202<W600;02@X
6@0S9aX08RHG028W5P0Q9QH07R8D01PL3`0C5`X03Q<700`@1@0;3P<00P0:3@<02@0930802@X100H8
00051@001PD000L600051@0010<000<30002008400800@8000H0004000@50P0C5`/05A/>01LL4@0E
610Jooooocd0oh00;0000?m40?n000oooooo000=ooooo`0603]3D`0mAUH0@4UJ0458F`10Aed0@DQN
0P12BV402@12BF<0@daU04E>I@17D6@0B59T04UBI@1:DfD0C5AV04eDI@0204iGI`80CeQY00/0CeQZ
04mIJP1?FVT0DE]Y05=KJP1CG6/0E5]/05ELK@1FGFh0EUe_05INL00205EKK`0<05ILL01GGG00FUmb
05YOLP1IGW<0FF1f05URM@1IHg<0FF5`05YRL01KI780GFId0P1OIgH02`1QJWL0HF]h065ZN01RJgP0
Hf]h06E]N@1VKWT0IFij06I_N`1VL7`0Ig5l0080J75l00/0Jg=o06idPP1/M840KGN1071iQ01cO8D0
LW^307AkPP1eO840MGj007InP00207MoP@0;07V1Q01jPHH0NH6807R1R@1iPHX0NX>:07^4RP1mQXX0
OhR8086:R021RhT00P21S8P03022S8T0Phf:08>=R`23SH/0QHn=08J?S026Sh/0Qi6;08N@RP26ShT0
QXj708F@Q@80Q8n400/0Phj208F?P`23SH40PXj0079kL@0g=S`0=3Hi03<g=P0R92<061XH01<F4@02
00hB2`0;00`?2P0;3@T020X800X<2@0;3PX030l900X<1@092`802`d300d>0`0=3`<00P0=3P@0300;
3@D02Ph500T>100:3`@02a0400hD100>50D04AL7010E1`0@50L05aX=01dR50808BLH00/08RPH028V
600Q9QH082DE024X600O9AL06b0C01HK3`0A50X03A4600X>0P0200P<000300T<000;2`402@T10080
1`H000H020L000H500040`000`<0008300020P02004100060002000210403A4601<I2`0H7@l061`=
6_oooolm0?n002d0003o@`3oP00?ooooo`003Oooool01P0lAE<0?TQF0419F@12BUh0@d]P04=<H080
@daQ00/0A4eQ04A>HP16DF<0Ae9T04UDIP1:E6H0BeIW04iGJ@1=EfT0CUQ[04iJJ`0204iJJP80CeYZ
00T0D5Y[04mJJP1AFfX0DUaZ05=LJP1CGF/0EUi]05MNKP1HGW000P1IGg4205UOLP0:05UPLP1IGg80
F5ic05UPM`1JHWH0FV=d05YSL@1KHg00GFEa05iVL`80H6Qf00<0HFYg069ZM`1RJgP00P1SJWT01P1U
K7X0IVmk06I^O01WL7d0J75n06UcOP80JGAn00/0KGEo06ieO`1/MGl0KGN1071jP`1cO8D0M7b507Em
Q@1gOXD0N7n507R0Q00207Z2QP0;07^2Q`1lPhX0Nh:;07Z2S01kPhd0O8B;07b5R@1oQhT0PHV908::
R@23S8X00P23SHX03024Sh/0Q8j;08B>R`26T8d0QXn=08J=R`26SX/0RI2=08V@S027Sh/0Qhn:08N@
R@80QI6800/0QI2508JAQ024T8<0QI6107V5N00n?d<0=STl03Dj>00O8R<06A/J018E4`0200hA3@0;
00`>2`0;3@X02@X900X<2@0:3@T02`d600X<0`0:3@803@h200h>0`0>3P800P0=3P401P0<30403@d2
00h@1@0A5@P04AL8010F1P8041D600@03a8400h?0`0D5@X07b4D0P0S9aP02`0R9aP07bDF01hU500M
91<082LE01lV5P0K8Q@06Ad@01@G2`0?4`P0310300802`l100/02Ph000/=0@0:30402@X000T80009
2@001`P000D60003100010D000<4000200@30006004200010`003@l601DH300H7Pl061/<6_oooolm
0?n002d0003o@`3oP00?ooooo`003Oooool01@0nAe<0@4UH045;FP12Beh0@d]O00<0A4eP00/0A4iQ
04I@H`18DVD0B5=V04YEJ01<EfT0CEMY04eHJ@1>FF`0CeY/051LK002051LJ`0;051JJP1?FV/0DEa^
051KKP1@Ff`0DUe]05=NK@1DH6h0EV1_05MPL01HGg000P1HGg40301HGg80FV9b05UQLP1JHG@0FV1e
05]RM`1KHgP0Ff=g05aTM@1MIWD0GVMd061XM@80H6Yf00/0HV]g065ZN01TKGX0IFaj06A/NP1SK7X0
IVmk06M`O01ZLWd0JgAm06]dO00206aeN`0;06igO01^Mgd0KWIo071gPP1aNH@0Lg^707AlQP1dOXD0
MWn707InR01gOhP00P1iPHX01@1jPX/0Nh>=07^2S@1kPhd0O8F<0080OHN;00@0P8V<08:;SP22S8h0
QHj?0P24SHh03024SXl0QXn?08J@T027TI40QY2@08J@T@26T8l0R96?08RBS@28Thd0R9><08RCR`80
Qi:<00/0QY>908FAQ`23T8D0Pi6407b=O@0k?d80;2lc02X]:`0L7Q`04aHB00hA300200`?2@802P`7
00T02@/600P:1@0:3@D02P`300`>0`0>40803Pl200h>0P0=30800P0>3P401P0=3@803`h3018B1P0A
4`T03Q4700/>0`802@/100@02`/100h>0`0G60`07R0C0P0R9AH02`0R9AL082@F01lT5P0P91D08RHF
020V5`0K8Q<06AlA01HL3`0A5PX03Q<60080314300/030l200`?0@0:30402`d100/<000:30002P`1
00P;0@062@001PP000D7000200<40006000200010P002``501<E2P0E60`05AL:6_ooooli0?n00340
003o@`3oP00?ooooo`003Oooool01P10AeD0@TYK04A=G`15CV00ADeQ04I>H@80ATmQ00/0AU1R04QA
I019E6D0BUEV04aFJ01>FFX0CeUZ055LK@1AG6h0DEa]055LJ`02051LJP0;055LJP1BG6X0Dei]05=N
L01CGg00EF5b05APL@1EH700Ef5a05QRLP1GGg<00P1IHGD00`1KI7@0FfAc05]TM00205]TM@0605aU
MP1MI7H0GFAg05aUM`1MIgP0H6Yh0`1RK7P02`1SK7T0Hfak06E^O@1VKW`0IFml06EaO@1WLW`0JG=l
06aeOP1]MGh0KWIn0080L7Mn00/0L7Uo079kPP1bNX@0LWZ307=jQ01cNhD0M7f707AnQP1fP8P0N869
07N0R@0207R2RP0507Z4R`1kQX/0NhJ;07^6R`1mR8`00P1nRX`01021S8h0Phj@08>=T026T98208F?
TP0<08J@T@28TI40R9:B08JATP26TY<0R9BC08NCT@27Thl0RIF>08ZFS029UHX0RYN;0P2:Uh`02`28
UHX0QYB908BCR024U8H0P9620498B00S9BT082<S01DH5P0?4Pd03@l8008030h500/020X100P:0P09
3@<02@/100X<0P0;3P803A0400hB1@0@4P@04Q86014B1P02014@1@0<00l?100?40H0410700l@200<
3PL02@/400L90P092`<030d4014B1`0G6@d07B4C0P0Q9QH02`0S9aP08RHG024U600Q9QL092TJ02D[
700P9aT07R@F01/R500H7a405A`>008051X<00/05AX;014E1`0>4`D03a8500hB100>4PH04AH900lD
1`0>4`D03A8400T=0@0200D800060085000210002@/3018D1`0E60/05aP<6_oooolh0?n00380003o
@`3oP00?ooooo`003Oooool01P10AeD0@TYK04A=G`15CV00ADeQ04I>H@80ATmQ00/0AU1R04QAI019
E6D0BUEV04aFJ01>FFX0CeUZ055LK@1AG6h0DEa]055LJ`02051LJP0;055LJP1BG6X0Dei]05=NL01C
Gg00EF5b05APL@1EH700Ef5a05QRLP1GGg<00P1IHGD00`1KI7@0FfAc05]TM00205]TM@0605aUMP1M
I7H0GFAg05aUM`1MIgP0H6Yh0`1RK7P02`1SK7T0Hfak06E^O@1VKW`0IFml06EaO@1WLW`0JG=l06ae
OP1]MGh0KWIn0080L7Mn00/0L7Uo079kPP1bNX@0LWZ307=jQ01cNhD0M7f707AnQP1fP8P0N86907N0
R@0207R2RP0507Z4R`1kQX/0NhJ;07^6R`1mR8`00P1nRX`01021S8h0Phj@08>=T026T98208F?TP0<
08J@T@28TI40R9:B08JATP26TY<0R9BC08NCT@27Thl0RIF>08ZFS029UHX0RYN;0P2:Uh`02`28UHX0
QYB908BCR024U8H0P9620498B00S9BT082<S01DH5P0?4Pd03@l8008030h500/020X100P:0P093@<0
2@/100X<0P0;3P803A0400hB1@0@4P@04Q86014B1P02014@1@0<00l?100?40H0410700l@200<3PL0
2@/400L90P092`<030d4014B1`0G6@d07B4C0P0Q9QH02`0S9aP08RHG024U600Q9QL092TJ02D[700P
9aT07R@F01/R500H7a405A`>008051X<00/05AX;014E1`0>4`D03a8500hB100>4PH04AH900lD1`0>
4`D03A8400T=0@0200D800060085000210002@/3018D1`0E60/05aP<6_oooolh0?n00380003o@`3o
P00?ooooo`003Oooool01P13BUT0A4aO04I>H`18D6H0B4mU04UAI@80Ae5T00/0BE=V04]FI`1<F6H0
CEUW051KJP1CG6`0Dee]05ANK`1CGFl0Dei^05=NK`0205=NKP0905AOK`1EGVh0EEi^05IOL@1FHG<0
EV1e05IPL`1HH7<0FF9c0080FV9d0P1LHgH0301MIGL0FfAd05]TL`1MIW<0G6Ec05aUM01NIWH0GfIg
05iVN@1NIg/0H6Yj069[N080Hfai00/0Hf]i06E[O@1WKH00J6n106M`P@1XLH40JG:106adP01^MH00
LGR1075gP@02075hP`0;07=jQ01dOHD0M7b507AkQ01fO8D0MWb607InR@1fOXP0NH::07V4RP1hPhT0
0P1iQ8X02`1kQX/0OXV<07f:R`1mRX`0P8b?086<SP20S8`0PXj>08B?S`25T8l0R9BA0080Qi:@00`0
R9:@08VBT@28TY00Qi:B08RETP28UI40RYFA08ZET02;UY00RYJ>08ZFS02;V8d208VGR`80RIJ900T0
QiF908JFR026V8H0CeUC02HY:P0M81h051LD00lB300<3PP00P0:30@010092`802`d400/>100<3`@2
00d>100500`?1@0>4@H041@8014B200B4`P00P0A4`P200hA1`0:00d?1P0;3@D02`h600X=1P0:3@D0
2`d400d@100@50L051P;01/P4P808BLF00/08bPG028X5`0Q9QL08bPH02<Z6@0T;1X08bXI020W5`0M
91H07B@E01dU500201hU500;01hT4`0H7@h051P9018F200B5`X041H;01@I3P0E6`h05a`?01TN3`0A
5@P00P0;30<01P061`0010@000L70@0A4`P05aP=01PJ3Q[ooooo=`3oP00c0000od<0oh003oooool0
00gooooo00H0ADaM04I>H@18DVD0BE=X04UBJ01;EFT204QBI@0;04QCIP1<F6T0CEYZ04mKJP1BGFd0
E5i_05EOK`1FH740E61b05AQL@1EHW400P1EHW802`1EH780EV1d05MPM01HHG@0Ef5d05EPM@1GH7D0
FV=f05]TMP1LI7D0GFAe0080GVIf00`0GVMf05aTL`1LIG80FfE`05eVL@1OJ7@0GfQh05mWN`1OJ7d0
H6]n061/O01RKG/206=^NP0;06E_O01VKWl0J72206UaQ01YLH80JG:106]dPP1/M880KWF3071hQ@1a
NHD00P1bNHL00`1bNHP0MGf807EmR00207ImR00607UoR`1iOhh0Mh2>07R2S@1iQHh0NHJ<0P1iQH`0
2`1jQhh0OHZA07f;T01nSI40P8b@08:=T@22Si40PY6C08BBT`26TY80RIJD0080RYFC00`0RIFC08ZF
T`2;UiD0RiJF08^FU@2:UID0S9JE08nIU@2?VI<0SYVB08fJTP2<VY0208fJSP80SIZ<00T0RiR:08RG
R02:VhP0H6]Q02`^<00O8B805aXI014D4P0=4@`00P0;3PL01@0:3@@03a4800lB2`0@4``04A<:0080
414800@0418800hA1`0>4@L041870P0A4`P0300?4PP03Q4800hA200<3`H02`h600/>1@0;3P@03A84
010D1@0A5PL061d>01dR4`808RLF00/08bPG02@Y5`0S:1P092PG02<X5P0S:AL08RTF028X5P0P9Q@0
7RHD01lW5@0201lX5@0;01lW5@0M8a@0724B01XO4@0H7Q405ad?01TO3`0K8A407R8C02<W5`0J6`l0
0P0B4PT01P0=3@D02PP300L70`0=3`P04aH<01HJ3a[ooooo=P3oP00d0000od<0oh003oooool000go
oooo00H0ATeQ04QAI@19E6T0BEEY04UCJ019EFP204UFJ00;04YFJ@1;EfT0CU][055MKP1BGFl0E5ma
05IQL@1FHW80EF9b05ESL@1FHg800P1EHg000`1EHW80EV9e05ERM@0205IRM00605EQL`1GHW@0F6Ad
05YTL`1KIG<0G6Id0P1LIW<0301LIg40FVE_05aXL01LIg00GfUc061ZMP1OJGP0GVQi05mZO01QK7l0
I6mo06E_OP80IG1o00/0IG1n06E^O`1WLH80J7>506UbQ01[M8@0K7F606ifQ`1_MhP0KgR906mjR@02
071kR@0;071kR01bOHP0LWf907EnRP1gP8/0Mgn<07N0S`1hPY40Mh>A07V5TP1iQY000P1jR9002`1j
Qi00O8RA07j;TP1oSI80P8bB086>T`22T9@0PI6E08>BU@25Ti@0QiBD0080R9FF00@0RIJF08^HUP2:
UiH0RYJF0P2<V9L01P2<UiD0SIRD08fITP2>VY80SIZB08fLT@80S9Z>00/0S9Z<08bKS@2<VX/0RYR8
08^JR01^Nfh0<C@g02HX:P0L82405QPI018C4`0200lA300;00d?1`0F6@l06A`D01HI500B5A0041<;
00lB2@0>4@P03A0700d@1P0@4`H00P0A4`H0300@4`L03Q8700hB200=4PH02`l400/@0`0<4@<04AL6
01@J2@0D6@T05QX;01XN3`807R8B00/082DE024W5`0Q:1L08BPF028X5P0T:AL08RTH024X5@0P9Q@0
82HE01lV5@0201hV4`0;01lW4`0N9Q@08RXG028Y5P0N9A@07RHB01hU4@0N8a0082DD02P]700R9AL0
0P0K71801P0C50`03Pd800T;200;3@T03Q<:010E2Q[ooooo=@3oP00f0000od80oh003oooool000go
oooo00<0A4eR04I@IP17DVP00P19EFP03P1:EVP0BUIY04YFJ@1:EfT0BUQY04eIJ`1AGFh0Dem_05AP
L@1EHG00EV9a05EQL01EHW40EfAb0P1GIG400`1HIG<0EfAe05MTMP0205ISM@0605MSM01HHg<0FF=d
05YUM@1JIGH0FVEe0P1IIG@0301IIW80F6M_05YXL01MJ780GfUe05mXMP1NJ7P0GVYk05iZO01PJgd0
HVel06=^O080IVj000/0IVn006I^P01XLH<0JW:506YaQ01ZLh@0K7J606efQP1^MhL0KgV:06mjR`02
071kRP0;071kQ`1aOXL0LWj807AnRP1fP8`0MX2=07N0S`1hPI40N8BC07V6U01iQY<00P1kQi802`1m
RI80OXV@07j9T020Ri80PXfC086?U022TYD0Pi>E08BDU026U9<0QiBC0080R9FD00/0RiNF08bHV02:
UYL0S9RF08^HU@2<VYH0S9ZE08bIT`2<VY80S9Z@08fJS`0308bJSP0;08jLT02?WHh0Si^<08bIR@2=
VhX0NHIj03e1A@0`<cL08bLY01dP8P0I6a`00P0D5Q@02`0F6180Ae8n02D[8P0A51804ADB00hB300<
3`P02`d600`=1P0=3PD03a4600803Q0600`03Q4700dA1`0<40L02`l400T>0P0:40403aH601@K2P0G
7@`05a`<01<F2@0D5PX201XL3`0;01hS500O9QL07bHG01lV5P0P9QL08RPI02<Y6@0Q:1H082LE020V
500Q9aH00P0P9QL02`0P9a@07bLC02<[5P0T;1P08RXG020X5P0O9a<07RHA01hT4P0V;A/09R/K0080
82DG00H06ahB01@F300>4@X03Q8:00`B20093@@JooooocH0oh00=@000?m20?n000oooooo000=oooo
o`0604A=H@17D6H0B5=Y04UDJ@1;EVX0C5IY0P1;EVP02P1<EfP0CEQX04mIJ@1CGF`0EF1_05EQL@1D
HG00EVAb05MULP1FHg4305ISLP0;05MTM@1GHgH0Ef=f05MRMP1FHWH0F6Af05UTMP1HHgH0FVAi05]T
NP1JI7X00P1JIGX0301IIGT0FFIg05UVM01KIWL0GFMg05eWN01NJ7X0H6Yl05mZO01OJg`0H6el06=_
OP80IFj100/0Ig6306Q`P`1YLH<0JG:106UbP01ZM880JgF406efQ@1_N8L0L7V;071jS@02071kS00;
079mR`1cPHT0MH>;07J2S01eP8h0MX6?07J2T@1hQ9<0N8FD07Z7U01kR9@00P1kQi802`1oRi40P8^?
07n;S`21SI40Q8nC08BAT`25Ti<0QiBE08NDT`29UID0RIFF0080RIJF00`0S9RH08jIV`2=VIX0SYZH
08fIU`2=ViL0SYbG08jLU02?W9<0T9fC096MT@2@W942092MTP0;09:OTP2AWHl0TIf@08jLS`2<Vh`0
PY2304]?DP0h>d00;2lc02L[;00U:2L00P0L7ah02`0I71T0BUQ3028Z8@0A5A404aLC010D3`0=4@X0
30h900`=1P0<3P@03A0500<03A4600/0310500d@1`0;3PH02Pd500X>0`0B60X05ad?01TN400E6`d0
3a@8014D2P0201LK400801`Q5@0O9AP082DI028W6@0Q9QP08RLI02<X6@0R:1L2024X5P0>028X5P0P
9QL082HG020V5P0O9AD08bXI02D]700R:Q/07bLH01hV5P0O:1@07RHA028Y500R:AL201lW5P0601hV
5@0I81404aL<010C2@0=4@L02@d46_oooole0?n003H0003o@P3oP00?ooooo`003Oooool01P19Ceh0
Be9T04aEJP1<EV`0BeE[04]EJP80C5IY00/0C5MW04eHI@1AFfP0EEi/05QRL01FHW40EF9a05ITL`1H
IWD0EfIc05ISLP0205ISL`0;05QTM@1IIGD0F6Ee05MSMP1GHWL0Ef=i05QTNP1HIGX0FVAj05]TN`1K
I7`00P1KI7d0301LIGd0G6Ml05eXNP1NJG`0GVUk05iYNP1NJW/0H6Ym05mYO@1RK7l0HVj106=_PP80
I72300/0IW6406MbQ01XLh<0J7>006]fP01]Mh80KWR506miQP1_NXP0LGb<075mSP0207=nSP0;07=o
S@1dPH/0MX><07N3S@1hPi40N8:C07N1U01hQYD0NHND07V7TP1kRI800P1lRY802`1nS940P8jA082=
T@21SY80Q8nC08B@T`24TI<0QY:D08VEU@2:UYL0RiNI0080S9VK00`0SIVL08jIV`2<VIX0SYZJ08nL
VP2@WIX0T9jI092NUP2AWY<0TYjA09:NT02AWY0309>OTP0:09:NTP2AWi80T9f@08nLSP2:UhP0F5eM
03Xj@@0f=S`0;Blb02``<0809RXY00/06QhL020U7`0P9Qd072<I01HJ4P0A5@`03Q<;00dA2`0<3`L0
2Pd300/?0`0200`@100<00`A1@0;40@03A4600`@1P0:30D02@/400dA1`0D60`061`@01PL4@0C5Pd0
41<<0P0F6Q402`0K8AD07bDG024V6@0Q:1T082LH01lV5`0P9aL08BPG020W5P0S:AP09BXH00808bTH
00/08BHG01hT5`0R:A/09RhN02</6`0O:1P07bLG020W5`0P9aH092/G028Y5`02020W5`06024W600K
8A<04AH;00lC1P0=40<02Pd26_oooold0?n003L0003o@P3oP00?ooooo`003Oooool01P1:DU/0CEAP
04mGJ01=EV/0C5I]04]FK080BUEY00/0BeMX04aHI`1@FfT0DEe[05AOK@1EHG00E61a05IRM@1GIGT0
EfEj05ITN@0205MUN080F6Eg00T0F6Eh05QTM`1IIGP0FF=i05USNP1II7P0FfEf05aVMP1LIWT00P1L
IG/0101MIWd0GFIl05mWO01OJ7/2061YNP06065ZN`1QJGd0HV]o06=]P@1RKH80Hfn30P1TKh<02`1U
L8<0Ig:206UcP`1ZM840K7J006iiPP1_NX80L7^4075lQ`1bO8/0Lgf=0080M7j>00/0M7f>07F0S@1f
P8h0Mh6?07Z3T`1kQ9H0NHBF07V6UP1kR9D0NhRD07b9U00207n<U@0;08:>UP23SiD0PhjE08:>U025
T9H0QI6E08BAU027TiH0R9FG08ZGV02;V9T00P2=VIX0302<V9/0S9VI08bHV02>VYT0SibJ096NVP2B
WiX0TIjI096MU@2BW980TYjB09>OTP80U:2C0P2CX9@02@2AWi40Sif?08nMSP2?W8`0HfMS03Xf?`0i
=cl0<30e02d_<P0202`_;@0:020T8`0L7ad071lK01dR6P0I7A@05AP@010C2`0@4PT03Q0600/?0`<0
310300`02a0300X>0`0<40H02`l600T<100:3@@03a8801@I300H6`l06QdA01LJ400A4`d201DH400;
01hR5P0S:1X08bPI02<Y6@0Q:1P07bLE01lX5P0P:AH08BPE028Y600Q:1P00P0P9aL02`0O9QL07bDG
028Y6`0U;1`08BXI01lW5P0O9A@07bDF01lT5@0O8QD07R8D00807R<D00H082DF01XQ4P0@5@X03a@6
00dA0`082P4Joooooc<0oh00>0000?m20?n000oooooo000=ooooo`0604E>F01:DUh0CUMW04iFJP1<
EVX0C5M[0P1;EfX02`1=FVX0CUUZ04mIJ`1@FV`0Dei_05AQL@1DH740EF5g05IRNP1GI7d0EfEl0080
F6Ek00/0Ef=j05ISN@1GI7X0F6Eh05UUN01JIGP0FfAi05]SN01LIGD0FfIe05aVM`0205aVN@0805aW
NP1NIg/0GVMk061YO01RJg/0HV]l069ZOP1QJWl206A]PP0?06=^P`1TL8@0Ig:506MbQ@1XLXD0JG>3
06]eP`1[MH80K7N106ehP@1/Mh40KgZ5079lRP1dO8d0M7f@0080MGjB00/0MX2B07R1T`1hP9<0NH:E
07b4U`1lQ9P0NhBG07b7U`1lQiH0OHRF07j8UP02082:U`0;08:<UP22SID0PhnF08B@U`26TIL0Qi>F
08NDU`29UIP0RIJH08ZGV02<V9T00P2>Vi/0302=VYX0SIVI08jJV`2>W9/0SYbI08nLV@2@WIT0TYfI
09>NV02EWiL0U9nG09BQUP80Tj2E00/0TZ2F09:OU02AWY80T9n@092NS@2@Wh/0LGY^04=3A@0o?d<0
<C0f02`^<@0202/^:`0;028U8P0N7a`0828N02<X800O9A/06AlD01@F300A4PP03a0600`>100<3`<0
0P0<40<0300;40<0310400`@200<40P03A0800lB2@0A5@/051P=01HI3P0F6@d051L<014C2P805QL=
00/08RHH02DY6`0T:AX08bPI024X600P:1L082PF024Z5`0Q:AH08RXG020X5`0201hV5P0:01hV5`0O
9QP082PJ024Y6`0O9aP07B<C01XQ400I7`l061d?01LK3`<05AP=0P0E6Ph0100B5P`03Q8800/?1007
2`4Joooooc80oh00>P000?m10?n000oooooo000=ooooo`0604I?F@19Df00CEQW051KJ`1@FV`0CUU/
0P1;Ef/02`1>FFd0Ce]^059ML01BGW00Df1`059PL01CHG40E69c05ERM01FI7L0EfEh0080EVEh00/0
EfEh05QUM`1HIWP0FFIi05QUN01JIGX0GFIl05iVO@1MIGX0GFIi05eVN00205mXN00<05mYN@1PJg/0
H6Uk061YO@1RJWh0Hfao06=/P01PJX40Hff406E_Q@1ULHL0Ig:70P1YLhH02`1ZLhD0JW>406egQ@1]
MhD0KGR606miR01_NHX0L7Z<07=lSP1dOI40MGjD0080MWnD00P0MGnD07IoT`1hPI<0NX:D07^3UP1l
QID0OHFG07n8V080P8VJ00h0PHZH086<V021S9P0PhfH08F>V025T9T0QY2I08JAV@28U9T0RIJK08ZF
V02:UiT0RiRI08fJV`80SifM0P2>WId02P2>W9d0SYfM092NW02@WYX0TInJ09>OW02DWi/0UJ2J09FP
V02DXIP209:PV00;09:PU`2@X9D0T9nC092PT@2AX8d0Tj>=07V5MP19C4/0ATU7034b=00[;Rh00P0[
<2X02`0U:b@08BDM02HZ800W;B8082HK01LK4@0B5@X04187010A1P0?4@L03A4600803Q<500`03A84
00dB1@0>4`P03A4:00lC2`0B5P`04QH;01<G2`0B5P/04QL:014F2P0@50T2018E2@0;01hQ4@0R9aL0
9BTI02@Z6@0U:QT092XI028Z6@0T:aX08RTH02@Z5P0T:AL00P0Q9aL02`0O9AP07RDH01`T5`0K8QD0
6R4C01LM400D6P`04QP:014E2@0?4`T03Q4800803A0800H03A8800lD2@0A50/04A<:00d@1`082`<J
oooooc80oh00>P000?m10?n000oooooo000=ooooo`0604MBGP19EF80C5QX04iIJP1?Ff`0CUY]0P1=
F6h02`1=FFl0CUY`055MLP1@G780D5a`055NL01BHG80DF1`05ARL@1EHg80EVAc0080F6Ie00L0FFMd
05YWM01JIW@0FfMg05YVM`1JIWT0FfIk0080GFIl0100GFMl05aWO01LIg`0G6Ml05iZO01OJg`0HF]m
065ZO@1QJWh0IFj106A]P`1SK8D0I6f506E_QP1VLXL0J7:70P1XLXD01P1[M8D0KGN706mhR01_MhP0
KgR9075iR`80LGZ=00<0LW^?07AmT@1fOi800P1fP9<02`1eOY80Mh2A07R2T01jQ940OHFC07j6U@1n
QYH0PHVH086:V@22RYX0PhZI0080Q8bI00/0Q8jI08N@VP28SiX0RI6L08RBW028Tid0RIBL08^EVP2;
UiX0S9VK08jMW`0208jNW`0<08jNWP2=WYd0SIfM08jNWP2BX9l0Tj6N09>PW@2BWi`0TinL09BPW@2D
X9/0Tj2H0P2AWiL02`2CXIT0TZ:G092QTP2AXY40T:6?09:RT01oSGh0DEEC04eBCP0b<cD0:R`/0080
:B`Z00/09b/V02<W800Q9Qh092TP028V7`0M7aP061T@01@G300B4`T04Q<8010B1P0200`A100<00/@
0`0<4@@03A4600d@200>4@T03a8:00lB2@0?4`T04QH<01@I3@0B5`/041@90P0B5@T02`0K7Pl08RHF
02@X600U:QP09R`G02@[5P0T:aL09bdI02@[600R:1H08RLE008082@E00/07B0C01TM4P0F71005A/?
01DJ3P0C60/041@9010D2P0?4PX03A4900/?2@0200/?200600/>1`0<3`L03A4800hA200=40L02@`4
6_ooool`0?n003`0003o@@3oP00?ooooo`003Oooool01P18Df00BeMT04eJJP1>FV`0CUY]04iKKP80
CUa`00/0CUY`04mKL01@G740D5aa055LL01@G6l0DV1a059OL01DHW40EfAb05QUL`0205YWM@0505UV
M01IIW<0G6Md05eXMP1LIgL00P1JIWT0101JIWX0FfIk05iXO01NJ7d205iXO00<05iZO01NJg`0Gf]l
069[O01SK7d0IFn106A^PP1TKh@0I6j506A`QP1TLHL0IG:70P1XLhH02`1ZLhH0K7J806mgR@1`MhT0
L7V:075iRP1`NHX0LG^<07=mSP1eOi00MX6A0080Mh6A00/0MX2A07N0T@1hPY40O8BC07f5T`1nQY@0
OhRE082:UP20RID0PX^G08B<V@0208>;V@0;08F=V@26SiT0QXnH08VBV`29Ti`0R9>K08VDVP2;UY/0
SIRM08jIWP2>Vil00P2=Vih0302>W9h0SYfM096OWP2BWih0Tj2N09FPW`2DX9d0TinK09>OW02DX9h0
U:6N09:OVP80TInH00/0TZ6I096QV02AXIH0TJ6D092OTP2AXI40P8f1051DDP1DGE@0<SHd02HY:002
02DW9@0902@W9@0S9R@092PU02P_:00[<2P08bHN01TK500D5@l0410800803a050P0=3P@0300;3P80
314300dA100>4PL030l:00X<2@0;3@T03A0;014E3`0C61004QL?00hC2`803Q<900/05a/>01lT5@0S
:1P09BXH02D/5P0S:a@092/E02</5`0Q:AL07RHF01lV5P0201lS5@0;01XL400E60d04aL<01<H2`0A
5PT03Q8600d@1P0>4PT041@=00`?300:3@T00P0:3@L01P0:30D02Pd500T<100930<02Ph400P;0a[o
oooo<@3oP00k0000od40oh003oooool000gooooo00H0Ae=M04YFH@1<FFP0CUY/04iJK@1=FVh204eK
K`0;04iKL01?FW40D5aa059ML@1BGFl0Dem_05=QL01CH6l0EF=_05QVLP1HIW@00P1IIWD02`1HIGH0
FVEg05aVN@1LIWT0FfIi05YWN`1KIg`0FFIk05YVNP1MJ7/0GfQm0080H6Un00`0HVb006=^PP1TKh80
I6j006E^P@1TKh80Hfn2069`PP1SL8@0I76406A`Q01VLX@206QcQ00;06YdQ01^MXH0KgN8079jR`1b
Nh/0L7Z;071jS01bOHd0Lgf>07MoT01iPI000P1iPHl02`1hPI00NX>B07^4T`1mQY@0OXNE07n8U@20
RID0PHZF086:U@21RiD0PhfH0080Q8jI00/0QY2K08J@VP26T9T0Qi6I08RBVP28U9/0RYJK08^GW02<
Uid0SYVO08jIWP0208jJW`0<092LW`2@WIl0Tj2P09BQX02DX9h0UJ2M09JRW@2FXih0UZ:N09JRW`2E
XYl0TYnL0P2CX9X02`2DXYX0UJ>I09JSV02DXiH0TZ:D09>RTP29VHH0C51;04iFC00i?ST0:2XZ0080
9BLV00/0:bh[02LZ:@0W:bX0:c8/02/a:00S9al06adH01DG4@0@4@X03@l700h@1`0200`?100<00/?
100<40@0310400`@1P0;3PP02Pd900X=200>50/051X?01@K4@0B6@l03Q@:0P0=4`T02`0E6`l072<E
024Y6@0S:aT08b/F02@[5@0U;1H092`G02<[600Q:AP082PG0080728C00/05a`@01@I3@0@5@/041D:
00lD200=4@P030l600dA1`0>4`T030l900X=1P0200P<100600L:0@082`401PX000D:000730001`/0
6_ooool`0?n003`0003o@@3oP00?ooooo`003Oooool01P17De`0BEIP04aII@1=FVX0CUY/04iJKP80
CEY^00/0CUYa04iJL`1?Fg@0DEac055LL@1CH740EF9b05=OK`1DH6l0EV=a05QUL`0205QUM00;05MT
M@1HI7L0FVEj05aUN`1KIWX0FVEk05]VO01JIW/0FVEj05eVN`1NIgd00P1QJWl00`1SJh00IFf206E]
P@0206A]P00706E_PP1UKh<0Hfn306=_PP1TLX80I76106McP@0206UdPP0;06]fPP1`NXD0LWZ707=j
R@1bNh/0L7Z<075lS`1bOI00Lgj@07EoT01gP8l00P1hPHh02`1jQ900OHJB07j5TP1lQ980OXNE0829
UP21RiL0PH^F086<UP22S9L0PhbI0080Q8jJ00/0Q8nK08F?V`26TI`0Qi6L08NBV`29U9/0RiNM08fH
W@2?VYd0TIbO096KWP0209>MX00909>MXP2BWJ80TYjS09>OY02EWj40UZ2Q09BOX02EXJ00UJ:P0080
Uj>P00h0U:6M09FQW02EXI`0UZ6K09JRV@2GXiH0UZ>D09BRTP2CXI00TZ>=05MLEP0g>CX0?44n030c
<P80:2X[00/0:bh[02T/:P0T9bL092TV020U8@0I7QX05APD01@H500?4`l03Q4;00hA2@0200dA1`0<
00d@1P0<40D03A4700`@1P0<40L0310800/@200=4`P04AP;01<K3@0B6@/03a@80P0<40L02`0H7Q40
7bLG028Z6@0T;1X09B`J02H/6@0W;AT092/G02@/600R:aL07RLC00806R8@00/05Qd?01@J3@0?50T0
310800/@1`0<40P0310700`@1P0=4@H02`h500X=100200P;0P0600D800062@0010L0008700021P00
0@@06_ooool`0?n003`0003o@@3oP00?ooooo`003Oooool01P17De`0BEIP04aII@1=FVX0CUY/04iJ
KP80CEY^00/0CUYa04iJL`1?Fg@0DEac055LL@1CH740EF9b05=OK`1DH6l0EV=a05QUL`0205QUM00;
05MTM@1HI7L0FVEj05aUN`1KIWX0FVEk05]VO01JIW/0FVEj05eVN`1NIgd00P1QJWl00`1SJh00IFf2
06E]P@0206A]P00706E_PP1UKh<0Hfn306=_PP1TLX80I76106McP@0206UdPP0;06]fPP1`NXD0LWZ7
07=jR@1bNh/0L7Z<075lS`1bOI00Lgj@07EoT01gP8l00P1hPHh02`1jQ900OHJB07j5TP1lQ980OXNE
0829UP21RiL0PH^F086<UP22S9L0PhbI0080Q8jJ00/0Q8nK08F?V`26TI`0Qi6L08NBV`29U9/0RiNM
08fHW@2?VYd0TIbO096KWP0209>MX00909>MXP2BWJ80TYjS09>OY02EWj40UZ2Q09BOX02EXJ00UJ:P
0080Uj>P00h0U:6M09FQW02EXI`0UZ6K09JRV@2GXiH0UZ>D09BRTP2CXI00TZ>=05MLEP0g>CX0?44n
030c<P80:2X[00/0:bh[02T/:P0T9bL092TV020U8@0I7QX05APD01@H500?4`l03Q4;00hA2@0200dA
1`0<00d@1P0<40D03A4700`@1P0<40L0310800/@200=4`P04AP;01<K3@0B6@/03a@80P0<40L02`0H
7Q407bLG028Z6@0T;1X09B`J02H/6@0W;AT092/G02@/600R:aL07RLC00806R8@00/05Qd?01@J3@0?
50T0310800/@1`0<40P0310700`@1P0=4@H02`h500X=100200P;0P0600D800062@0010L000870002
1P000@@06_ooool`0?n003`0003o@@3oP00?ooooo`003Oooool01P16DE`0BEEP04aIIP1<FFX0CUY]
04iJKP80CEY^00/0CU]`04mKL@1AGG<0DUec055LL@1BGW40E5ma05AOL01DH6h0EV=_05ISL00205MT
LP0705QULP1HI7@0FVEi05aVN`1LIG/0G6Aj05aUN00205eVN00705iWN@1QJG`0HFYm065ZO@1QJG`0
HVam06=]O@0206=/O00706A]O@1TKWh0IFn106E`P`1ULH<0IG:006QeP00206UeP@0806agPP1_NX<0
LWj707AmR@1cO8/0LGb;079mS@1dP8l207F0T00807N1T01gPHh0Mh6>07Z3S`1mQI40OhJD0826U@21
QiH308:;V080PXbG00X0PhfI08B>V@24SYT0QHnI08J@VP27TI/0R9:M08RCW02;UI`0SINK0P2AVYd0
1@2AVYl0TifQ09>OX`2CWj<0U9nT00<0U9jT00L0UIjS09NPX`2FWj80UYnR09NRXP2GXZ00UZ:N00<0
Uj>L00/0Uj>K09JRV02GXiD0UJ:C09BRTP2CXI00UJFA06M`J@0a<3H0?44o03Dg=P0202`];00;02/^
:`0Z;B/0:B/[02P[:P0N8B8061`M01@F500C5A004A@<00hC2@0>4`L00P0=4P@02`0=4080310200`?
0P0<3`<0310500dB1`0<4@P02a0700`B1`0>4`P03Q8700<0310500/06B0B024Y6@0R:aX09BhL02H]
700V;1/092TI028Y600R:QH082TD01`T4@0201TP400;01HM400E70h041H<00`A200:3`H0314800/@
1`0;3`@02`l300X=0`072P800P0620401P041`001@P000@700031`000@D0000301[ooooo;@3oP00o
0000od40oh003oooool000gooooo00H0AU5L04UCHP1<EfP0BeM/04eIL01?FW4204iJL00;04mLLP1@
GG<0DUib059ML@1CGW40EEmc05MSM01FHG80EEm`05MRL@1HHg800P1GHg8205QUL`0905]VMP1KIWT0
G6Ii05eVNP1NIgP0GfQg061YN01OJ7T0HFYl0080HVYm00`0HFYm06=/OP1TKWh0I6mm06A^O@1VKgh0
Ig1o06QaP01WLH<0J7:406UcPP1ZMH4206agP`0406ihQ01`NXH0Lgf807AnR080MGj900D0MX2>07Io
T01hPI00N86?07R2T00207R3T@0707Z5TP1lQI@0OHJF07n8V021R9T0PhVJ08>:V@0208B<V@0?08F=
V@26SY/0QhnL08N?W028TId0Qi:M08RBW029U9d0RIBL08^GVP2>VIX0TIbL096KW@2AVYl0TYfR0080
TIfS00`0TinT09FPY@2EX:@0UYnS09JPX`2HXJ80Uj6Q09NQW`2GXYl0Uj>N09RTW@2HY9`309NTV`0:
09JTV@2FXiP0UZ>G09JSUP2DXi@0UJJE06ehK`0a<cP0?49003Pl>P80<38a00/0<C@b02lb<00_=300
;c@`01`O800K7Ad05QPE014A300@4@P03A0500`A0`0200/@0@0<00`?0@0=40<030l400`?1P0<3`P0
3A8;00hB300=4PX0314700`@1`0=4@H03A850P0A5PP02`0M91808b/H02D]700U;Ad09BdN02@/7P0R
:Q`08b/K028Z600N9Q<06R8?00805Qd>00/051/>01<J3P0B6@h03aH=00dB2@0=4`T0314700/>100:
3@@02`d400P:0P0200D6000600<500061`0010L000<600021@000@<06_ooool]0?n00400003o@03o
P00?ooooo`003Oooool01P19Del0BeIV04aGJP1<F6d0CUY`051LL@80D5]b0P1AG7@02@1AGG@0DUed
05AMM01EGWH0Ef1f05IQM@1HHGD0FF9e05QRL`0205YSM@0;05YTM@1JIGH0FVIg05YVM`1LIgP0GVQi
05mXN01PJWT0HF]j061ZN`1QJWh00P1QJgh0301QK7l0IFn106A^O`1VKgl0Ig2106UbPP1YLH00J7:3
06UbQ01YLh@0JWB406efQ`80KgV900/0LGZ8075jQ`1cOHX0MGn:07EoR01gPH/0N82?07UoT@1jPI80
Nh:A07^3T@0207^4T@0;07b5T`1nQYD0OhRI0829V@23RYX0Q8ZL08B;W024S9`0Q8bK08F<V`28Sih0
0P29T9l02`2:TJ00RY>P08bDX02;UId0S9NM08fGVP2>VIX0TYbK09>MWP2EWZ00U9jR0080TYfQ00`0
U:2R09JQX`2GXZ<0VJ>R09RRXP2HXZ40V::P09NRWP2HXih0VJBN09VTX02JY:0209VTW@0;09VTWP2I
Y9`0Uj>J09NRV@2GXiL0UjFD09RXU@1fPWL0>C]10458AP0l@Ch00P0f>SL02`0i?cP0=CXc02hb:`0c
>3007QlM01`M6@0G61<04A<<00lB2@0>4@H031030080310200`03A4400dA1P0=4@P03Q8<00hB3@0=
4@`03Q8<00lD2`0>4PP03A4700hC1P0>4`D2018G1`0;01`T4@0S:aL0:30M02P`7`0W;R009B`P02D]
800R:ad08BTJ01hU5P0J8A800P0E70h02`0B6@`04QP<01<J3P0A60d03Q@:00`A200<40L02Pd400T<
100:30@020T200801PL100H01PD000H4000310000PD0004400010`0Jooooob`0oh00@@000?m00?n0
00oooooo000=ooooo`0604UFG`1<FF@0CEUY04mJKP1>FFl0CeY`0P1@FW002`1AG780DUab05ANL`1E
H7D0E5ie05AMMP1FGWL0Eeig05UQM`1IHgH0Ef9d0080F69d00/0F69e05QSM@1IIGL0FFEh05aWN@1M
IgT0GfUh061ZN@1OJGX0H6Yk061ZO@02065/OP06069/O`1UKX80IVn106M`P@1XL8<0JG640P1YLX@0
101XLX80JWB306afQ01_NHL2071jQ`09075kR@1bO8T0LWf;079mR`1cOXX0MH2<07MoS@1jP900O8:@
0080OHBA0P1nQY80201mQY40P8VE0829V021RYP0PHVI08:9VP21RY`0PhfN0P23S9h03026SYh0RI2M
08V@W@2:TYd0Ri>L08bEW@2=UI`0SYNL08nIW02@VI`0TibN09BMW`80UIjO0P2DWIh0302FWj00UZ2P
09NRXP2GXZ80Uj:Q09RRX02HXj00VJBQ09VTX02IY9h0VZBO09ZTWP80VJ>L00/0VZBK09bWW02JY9T0
V::G09RSUP2HYI80UjNA08>AP@0o@dH0A4Y803Xo?@0203<g<P0;03@j<P0d>S00;C0X02hb:@0M7QT0
6a`F01HG4@0A4`X03Q4700hA1@0<40@00P0<40<0300;40@02`h500`?200=40`03Q0<00`=2P0=3`X0
3Q4900hC2@0=4@D02a0200/>0@80310300/07RHA02<[5P0W;aX09blL02D^7P0T;Al09RhP02<[7@0Q
:A`07RLI01TP4`0201@L4007018I3@0?5@/03aD<00dC2`0=4`X02`l600P;0`0200P:0@0300L90@05
1P001PL000801PL000D01PH000<4000110000@<00002000Jooooob/0oh00@P000?m00?n000oooooo
000=ooooo`0604YHG01>Ff<0D5a[051KKP1@FW00D5Yb0P1AG7<02`1CGG80Dei`05IOL01FGg40EUmb
05EPM01EH7D0EUmg05QRN@1GHgT0EV9h0080EF5e00/0Ef9g05MSM`1HIGT0F6Aj05]WO01MJG`0GFUh
05i[N@1NJg/0GFYk05i[O002069^OP06069]O`1TKH00Ig2206QaP`1WL8<0J7630P1YLXD0101ZM8D0
JgF306egPP1_NH8206mjQ00;075kQ`1aO8L0LGf9075mRP1bOXX0Lgj<07J0S`1iPI40Nh>A07b4TP1l
Q9400P1mQXl02`1lQhh0OXVA0829UP20RYT0P8^L086;W@20RYd0PX^N08B=W`25SYl0QY2M0080R9:J
00/0RiFJ08bEV@2;UYT0RiFH08jHW02?VY`0SYRJ092KW@2AWIh0TYjN09>NW@0209BNW@0<09JOW`2E
X9l0UZ6R09JRXP2FXZ40Uj:P09RSX02KYZ40VjNQ09^VX02JYIl0VZFM0P2IYI/02`2HXiP0VJBH09VT
U`2HY9H0Uj>F09RTU02GYY80RiZ804Q;C010AD@0>3dk0080;C0]00/0:RdV02/_9P0Y:b<0;2lU01lQ
6P0J71@05AP?014C2P0?4PL03a4400hA100200`@1@0<00/>1@0:3@H02`h900d?300>40d03Q0;00l@
300>4P/041D;010E1`0>50D03Q840P0<3`<01P0L8`l08bXF02H[600W;QX09RhM02H^7`809BhO00<0
8R`M01hV600H7a@00P0C6Q002P0A60`041H<00dB2@0<40L0310600T>1008308020/000T<00082P04
00H8000500H80@041P000`@0004300010@006_oooolZ0?n004<0003o@03oP00?ooooo`003Oooool0
1P1:F5d0CEYS04mKJP1@Ffl0D5Yb051KM080DE]d00/0DUeb05AOL01EH6l0EV5_05EPK`1DH740EF5b
05IRMP1EH7L0EF9i05ERM`0205ERM@0805ITMP1IIWT0FVIk05]WO@1KJ7d0GFYk05aZM`1NK7P205iZ
N@0705m[NP1RL7`0HW1l069aO@1TLGd0J7>006QcPP0206QbQ00606QaQ@1YM8H0JGF506UdP`1]N8<0
L7V40P1`NHH02`1`NhL0LWj9079nR01cOhT0MH6<07IoS@1iPI80Nh:D07f4T`1mQY@0OHFC0080OHJB
0P1mQi402@1oRID0OhVG07n;VP21S9`0PHbM08><W@24SId0QhnO08VBW`0208VCW`0;08^DW@2;UI`0
S9JK08^FW02<V9d0SIVN08fIW@2>Vid0TInO096OX02CXJ000P2DXIl0302EXZ00UJ6R09>PXP2EXZ<0
UZBR09RUXP2IYZ80VZJR09^WX@2KYJ40W:NS09bXX@80VjJN00/0VZFL09ZVVP2JYYT0VZNH09NSUP2H
XiD0V:BD09FTT@1CEeH0>CXn03Tm?@0202/];@0;02DY900V:R808bHP02<V7`0P8a`071lG01PK4P0E
60l05QL=01DG2`0C5@T00P0>4PL0300<40L0310800`?2P0>4@d03a<=010C3@0A4`d04QH?018G3`0A
5P/041D9014E20804A@500/051L701dP400P9A<092XG02L_6`0W;ad09blN02D_7P0T;Qd08B/K01`T
5P0201PO4P0;01@J3`0@5P/03A0700`?1P0<40H03A4600/?100;3P<02`l300X=0P072@400P051`40
1P051P401`X300L:0P051`000`@0008201[ooooo:P3oP0000`000?l0oh000000o`100000od00oh00
3oooool000gooooo00H0BeUQ04eKI01@G6X0DEa^059LLP1BGG@2055KL`0;059ML`1BGG80E61a05ES
L@1EHW40EF=b05ETLP1GIGD0Ef=f05QUN01FI7D00P1FI7802`1GIG<0FFId05]XM`1LJG/0GVUm061[
OP1PK7`0H6ej061/N01RK7X0I6ml0080IG9n00`0Ig=n06MdO`1WLh40Ig>306QcP`1XLh@0J7:406Yd
Q01ZM8D0JgB506ihQ`1bNhT207=kR@0;07AmR@1dOh/0Lgj;07F0R`1hPX`0N86=07Z1S`1lPi80O8BB
07f5T`1lQI<00P1mQYD02`1mQiD0O8ND07n8UP1oRIH0P8^H08>=W024SY`0PhfJ08J@W028T9h0Ri>R
0080S9BT00/0S9FS08bFX@2<Uil0SIRQ08bHW`2>VYl0Si^N092LWP2BWil0Tj6P09FRX@0209FRX00<
09FSX@2FXj<0Uj:S09NTY02HYJ<0V:FQ09ZWX@2JYZ00VjNP09^VX02LYj00W:RP0P2LZ9h01@2MZ9d0
WJRK09bWVP2KYiT0VJFF0080VJBF00@0UjBC05QJFP0m?D80>C`m0P0]<3402`0X:bX09RXX02@X900O
8ah07b@K01lV6P0M8aL06b0E01dP4`0J7@h05AP;008041@900`03Q8800dA200;3`L0310:00lB3@0A
5A004aLA01<G3`0A5P`03a@:00hB1`0<4@<200`@0P0;00`=0@0L81008RLF02DZ600W;aT0:30J02L`
6P0V<1/09RlM02D^7@0P:1P00P0K8A<01`0G7A804AH<00hB2@0=4@L03A8700hC200>4PL00P0>4@L0
2P0;3PD01`T200H80@0620401@H100H80P072P<01@L1008400010P0Jooooob<0oh0000<0003o0?n0
003oP0000`3oP0140000od00oh003oooool000gooooo00H0BUIT04eIJ01@G6d0DEa^055KL@1CGG@2
05=MM@0405EPN01DGgL0Deie05AQL`80EF=b00D0EVEc05UWMP1IIWL0F6Eg05QUM@0205UVM@0;05YW
M@1JJ7H0FfUg05aYNP1NJWh0H6Yo061/OP1QKGd0HVik06A_O@1VLGl00P1VLGh0301VLWl0Ig:106Ia
PP1VLH80J7>206UePP1ZMH<0JgN406afQP1]MXL0KWN9075jR`80Lg^;00/0MGb;07AmS01dOXd0MH6=
07N2R`1hPX/0NH:<07Z3SP1kQI00NhBA07b5T`0207f8U@0307j8U@1oQiH0PHVI0080PX^J00H0Q8fL
08B>W025Si/0Qi6L08RAW@2:TYh208^DX00;08^EX@2<UZ40S9RQ08fIX@2=V:40SiZR092LX@2AWIl0
TinO09FQX@2FXJ800P2GXZ<0302GXj@0V:BT09VUY02JYjD0VZNT09VVXP2JYil0VjRN09^YW`2LZ:00
WZVO09jZW@80WZZK00@0W:VI09^WV@2JZ9T0VJNH0P2JYiL01@2JYYH0VZNE065SH00k>Cl0>CLj0080
;2/]00/09RHW02<T9P0U:RT07B4O02@Z8@0W;B4082HJ01dR5P0L7a<061X=01DG2`02018D2@0<014C
2@0>40L030h600`?200=4@X041@>014F3`0A5Pd03Q8800/?1P0830801`X10P072@002`0:2P407R8@
02@Y5P0W;AP09bhH02P`600X<AT09S0I02La6`0W<1`08b/I00807bDE00/06QlA018G300@50X03a@9
00hC200=4PH03A4600`@1P0=40H02`d400T;0`0200L90P0600D700041P4010H000<500020`000@<0
6_oooolW0?n004H0003o@03oP00?ooooo`003Oooool01P1:EFL0CEQ[055LL01BGG80DUad059MM080
E5me00/0EF1g05APMP1EH7L0EV9f05MTM01FIGD0EfEf05QVMP1IIWL0FFMg05]XN00205]YN00;05]X
N01LJGX0GFYl05eZO01OJgd0HVen06=^O`1SKH00IVn106MaP01YLh400P1XLh40301XLX80J7:306Uc
Q01[MHD0JgF606YeQ@1[MhD0KWV606egQ`1^NHT0KgZ;071jS@80LW^<00/0MGj=07AoSP1fPI00MX:A
07J2T01hQ940N8FA07V5T01jQI40NXNB07b9TP0207f;TP0;07n<U@22SIL0PXbI08B=VP23S9X0Q8fK
08B=W025Sid0R96O08ZDX@2;U:000P2:U9h02`2;UZ00SYNR08jHX@2=VJ00SiZQ096KX`2BWJ<0TinR
09JQXP2HXj<0VZBU0080V::U00`0VJ>U09ZUYP2LZ:D0VjRT09fZY@2LZJ@0VjRQ09ZWX02LZ:80WjVS
09jXX02NZIl209j[W@0309fZVP2MZiX0VjVI0080VJNH00H0VZRH09VVUP2LZYP0Mh5f03Xh?00g=3L2
02`Z;00;02HT9P0S8bD0;c<a02DX:00U9b@09BPS01hO6`0R9Ah08bHM01hQ5P0I6`l00P0D5@X0100B
4`T03a4800d?1`0<3`L300dB200500hC2@0?4PT03A4800T<0`0620400P061`00200;30<07B8@02D[
5`0Y;a`0:c4M02/b700[<ad0:34L0P0V;aX03P0T;1T082HG020V5`0L8Q@06AhB01@I3P0A5P/041D:
010E2@0A5@T03Q8700d@1P0<3`D030d40P0;3P@010082P<01`X200H80@041P0200<401[ooooo9@3o
P0190000ocl0oh003oooool000gooooo00H0BeQZ04mKKP1BGW@0Demd05=NM@1AGG<2055ML@0;05=P
LP1DH780EV9d05QUM@1GI7H0EfEh05ISMP1GIGH0F6Mg05QWN01KJ7X00P1IIgP02`1JJ7P0G6Uj05aY
O01NJgd0H6em065]O01TKgh0IG2006I`P@1VLH00IW5o0080J7:100D0JG>406UbQ01YLhD0JWB606Ye
QP0206]eQ`0506afR@1^NHX0KgV:071iS@1bNhl00P1cO8h02`1eOXh0M7n?07=oS`1eP940MX:C07R4
T`1hQI<0N8FB07Z6TP1lRI<0O8VB0080O8ZB0P20SI@02020RiH0PhfI08>=VP23SId0QY2O08N@WP28
TZ00RIBP0`2:UIl0102<Uj40SIRQ08nHX02@VJ0209:LXP0509>LXP2EWZ@0UZ2S09NQXP2HXZ<00P2H
Xj<209ZUY00:09fXYP2LZ:@0W:RT09fYYP2LZ:D0VjNU09fYYP2NZJD0WZZS09jZX@80Wj^P00<0WZZN
09j[W02LZIX00`2KZ9X01@2IZIL0VJVH08FDQ00m?d00<S8e0080;Bh^00/0:2LW028S8P0Z;2X0:Rd/
02@T9P0Q8b@07b0Q045:?@0`=R/07b4H01`O4`0201HH300<01<D200A4`P03a8800`@1@0=4@D03A87
00d@200=4@T03a<:00`@20082`<01PP10P051`001@0;3PD07B@B02<Z5P0W;aT0:C8L0080:S@L00@0
:34K02@]5`0R:QD07bHD0P0L8Q<02`0M8Q<0724D01/O4P0H7A4051P=018F2`0C5@X04A@8010D200?
4PP03A0500802Ph200H02Ph300/>1@0;3`D020X200H60@051@4JooooobD0oh00B@000?lo0?n000oo
oooo000=ooooo`0604aII`1?Ffd0DUmc059NL`1BGgD0DUib0P1BGW402`1AGVl0DUm_05AQL01EHW40
EFAc05ETMP1FI7H0EVIg05EUN@1HIgX0F6Ej0080FFIj00/0FfUi05aYNP1LJG`0Gf]n05m[N`1RKW`0
I71m06EaOP1TKgh0IW5o06QbP@0206QcP00<06YeP@1[MH<0JWB306YdQ@1YM8@0JWF506]fQP1/MhP0
KWR:06ihR@1^MhT0L7V<0P1bO8d01@1bOHl0Lgn?07B0T01fPY40Mh>B0080Mh>C00<0NHJC07^7U01n
RI@00`1nRI@02`21RiH0P8^F07n;V021RiX0PX^K08B=W@27Sil0RI2N08R@W@28TIl0RI:O0080S9FR
00/0S9JQ08fGXP2>Uj40T9NR096IXP2CVj40Ti^P09BLXP2GWZD0UYnT09RQX`0309NRXP0;09VTY02L
YZH0WJNW09fXYP2MZ:L0WZVX09bXY`2LYjH0WZVU09jYY02OZJ<00P2PZj802`2OZZ00WZZN09fYW02L
Yi/0W:RL09^YW02GYYL0UjRG08ZIR00o@D40;c0a0080;Rl_00/0:R/Z02HX9@0W:BD0:RdY028T8`0M
8B00<STb03Y4=`0[<RD07B0E01XM4@0201@F2P0<018C1`0B50P041D800dB1@0<4@H0310700/@200<
40P0310700X=1@062@4020T10P0620002`0:3P@072<A01lW500T;QT09c4L02Pb6`0Y<QX0:C4J02H^
5`0Q9a007R<?00806al?00/07B0B020S5@0N8A@07B0C01`O4`0J71005QL<01<C2@0B4`T05QT<01DJ
2P02014F1P0601<H200D6P/04QL900dB1P0:30@01@H16_oooolR0?n000@0003o00<0oh000000o`00
0?l0A@000?lo0?n000oooooo000=ooooo`0604eHIP1?FVd0DUmd05=PMP1DHGH0EF9e0P1DHG8205=Q
K`0905ASK`1EHg40EF=d05ETMP1FIGP0EfIi05MVN01IIgP0FVMh0080FVQi00/0G6Yi05eZN@1NJg`0
H6am065]N`1RKW`0HVmk06=_O01SKgd0IG5o06MaPP0206UdP`0<06]fPP1ZMX<0JWB306]eQ01ZMH@0
IgB306YgQP1[N8P0KGV906mjRP1`NX/0KgV;0P1aO8l02`1cOY40LgnA07F1T@1ePY40Mh>B07R5T`1h
Q9<0NHBC07b6U01nQiD0OhVF0080PHZH00/0PHZI082:V@1oRYX0P8VK086:W024S9`0QhjM08R?W@29
TId0Ri:N08^CWP0208fEW`0;08jFX02?Uj40T9RR09:JXP2AVJ40U9bP09BNX02FWj80Uj2S09NQX`2H
XJ@00P2HXj<0302HY:D0W:NX09bVY`2LYZL0WJNW09jYZ02NZJL0WJRU09fXYP2NZJ<0WjRS09nWXP80
XJVQ00/0XJZP0:2ZX@2OZ9h0WZRL09fYW02LZi/0UjRG09NZU`2>Wh`0ADY603Lk=`0203Lk=@0;030c
;`0Z;2L09bXT02da:@0R91l07AhJ03Y2<`0lAC<0=3`X028V5@0K70d00P0E50T02`0A4@L04A@900hB
1`0=4@D0314500/A1`0;3`H02`h600X>1@082P<01`L100<020P000/01`P101TM300R:AH09RhL02Pa
7P0X<A`0:c@L02/c6`0W;QT092TD028V4P0201hQ400;01lR4`0S9QL09BPJ02@Y6@0U:aX08bHG01lP
500I6@l05QL=020T5@0U:AP00P0Q9AD01P0Q9Q807RDA01dS400G7@`03a<600H90A[ooooo8P3oP01<
0000ocl0oh003oooool000gooooo00H0CEQW04mJKP1CGW@0E61g05ARM`1EHWD205=PLP0;05=QK`1C
HFh0E6=_05ETLP1DHW<0EVAe05UWN01JJ7X0FFMh05UWMP1KJGH00P1LJGD02`1MJWL0GVYg05eZN01N
JWT0H6ai065^N@1QKWX0Hfmk06EaO01WLWh0J7>10080J7:300H0JGB506YeQP1YMHH0JWF606UfQ`1X
MXP206YhR@0406ejRP1^NXT0KgZ:071jR`80L7^>00/0LWf?07=oT01dP8l0MX:A07R3U01iQI@0NHNE
07V4U01lQiH0OXZG07n:U`02082:V@0;086<V`20Ri`0Oh^L082;W021Ri`0Q8bM08N>W`27Sil0R92N
08V@W@2<Til00P2=UIh02`2?Uil0T9RQ096IXP2BVZ80TIVQ09BLY02EWZD0U9nU09FPY@2FXZ@0VJBV
0080V:>V00`0VJBW09ZVY`2LYjH0WJRW09jWZ02OZJT0WZZX09fXY@2NZJD0WjVT0:2ZY02OZJ<20:2Y
X`0;0:6[XP2QZZ<0WjRQ09nYX02NZId0W:ZK09VZVP2GZ9L0U:JA059HDP0e=cL00P0g>SH02`0^;b`0
92DR01hO700a=B/0:RhS020R6@0R9AX0@ddd04MC=@0N80l07Ah?008061L<00<051@;01<D2P0A4`T0
0P0>4PD01@0<4@H02`d500X=1@0:30@020T2008020H00P081`402`061P0061`?02<Y5`0X;a`0:C8N
02Tc7@0Z<QX0:C8I02D^5P0R:QD08BTD00807R<C00/08BDE02DZ6@0X;Ad0:S0O02/b7`0/<Ql0:BdM
02DY6P0Q9AT0:30P030h900202hd8@0602T`6`0X;AP09R/F024W500F6P`01`P16_oooolS0?n004/0
003o?`3oP00?ooooo`003Oooool01P1=F6L0CeY^05=NM01DH7L0E69g05ERM@80Df1b00/0Df5_05=Q
KP1DHfl0EFAb05ARL`1FI7D0FFMh05YXNP1IIgP0FFMf05]YMP0205aYM@0;05eZM`1NJWL0GFYh05iZ
N@1PK7T0HFii065^NP1SKg/0IG5l06MbOP1XLh400P1XLX<01P1YM8D0JWF606UeQP1ZMHH0JGJ706Qf
R080JWR900@0KGZ:06ijR@1_NXX0L7Z;0P1`Nhh02`1bOHl0Lgn@07B0S`1fPY40N8>D07V5U01iQiD0
NHBD07b7UP1nRYL0OhZG0080P8ZI00/0PHbK082;W01oRi`0P8^L086;W024S9d0QhjO08N?W`28T9h0
RI2M08bCW`0208fEWP0;08nGW`2@V:40TIVR09:JXP2AVJ40U9bT09FNY@2DWjD0UJ2U09JRY02IY:H0
0P2HXjH0302IY:L0VZJW09bWYP2MZ:L0WZNX09nYZ@2NZZP0WJRU09jYY@2OZJ@0X:ZT09nYX`80X:VS
00/0XJ^R0:6ZX`2OZ:40WjVP09jYW@2LZY/0VJZJ09NXU`2DYY40DUQB03Dg=`0203Lj=P0;02h_;00T
9B807QlL034e:`0Z;R<0828I028U6P13CC@0Ae<e01hP3`0M7Pl00P0H5``00`0D50/04a@:014C2@02
00hB1@0500`A1P0;3@D02Pd500X<10082@800P081P0200P70@0;00H6000H70l08bTG02P_700Y<Qh0
:C<M02Xb6P0Y<QT09BhF028Z5@0Q:A@00P0N8a<02`0Q9AD09BXI02P]7@0Z<1l0:c8O02`b7`0Y;Ad0
9BTJ024U6@0X<200<3PT0080;S@Q00H0:C0K02P]600V:aH08BLD01HJ3007204Jooooob<0oh00B`00
0?lo0?n000oooooo000=ooooo`0604]HI@1>FV/0DUib05=PM01DH7D0E65d0P1CGg402`1BGfl0DV9_
059RL@1FI7@0EVEg05MUN@1IIg/0FVQj05YWNP1KJ7T0FfMf0080G6Qe00/0GVQg061ZN@1OK7/0GVak
05m]N`1QKg/0HG1k06=`O01WLWl0JG>106QcP@0206MbQ00606QbQ@1XLhH0J7>706UeR01YMXX0JWN<
0P1]NHd0101^NXh0L7b=071lS01`O8`2075mS@0:075nSP1cOhl0M82?07J1T01iPY40NX>B07Z6T`1j
QI@0O8JF07j8U`<0Oh^H00/0P8ZK086;W021S9/0PXfK08B=W025SYh0Q8jO08F?X027TJ40RI:Q08bE
XP0208jFX@0;08nFX@2AV:<0TYZS09>KXP2CVj<0U9fU09FMYP2DWZH0UJ2X09NSZ02GY:P00P2GY:T0
2`2GXjX0VJFX09^VZ02MZ:P0WjZY0:6[Z`2PZZT0X:ZX0:6YY@2PZJ@0X:ZV00<0X:ZW00/0XJ^U0:6[
Y02OZZ80WjZQ09j[WP2NZi/0VjZI09VYU`2IZiL0H6UR03Dg>P0203<f>00;02PX:@0P8Ah061HE02T]
8`0a=RP0;C8S028T600i@2/0DV10020R5@0M7Q800P0I6100300D5@d051@<018C2P0@4PL041<600hB
1`0>4@L03@l500X;0`0:2P<030X300d<0`8030/400/020T201LK3@0S:1D0:BlJ02/a700Z<A/09blH
02D_5P0Q:Q4072D@01TQ3P0201XQ400;020W5P0U;1/0:RlO02`c8@0^=R80<CTT02hf8@0/=1l0;SDQ
034j9P0h@2`00P0f?BP01P0^=Al0:RlJ02P/600W:aP07B4A010A1Q[ooooo9@3oP0190000ocl0oh00
3oooool000gooooo00H0CEYU051MJP1BH6h0E65a05EPM01FHGD205EQL`0;05AQL@1FI780EfId05QU
M`1HIWT0F6Ij05YWN@1JJ7X0G6Uj05]XN@1KIgP00P1MJ7P02`1OJ7/0HFYl065[O@1QJgd0HFeo06=_
O`1RL7h0IG6006MaP@1XLh80Ig>20080IgB400`0Ig>506QbQ`1YLXT0JGB:06UdR`1/MXd0KWN>06ih
SP1`NXl0L7Z=071kS01aO8`2079nSP0607AoS`1ePI00MX:@07N3T01iPXl0NhF?0P1nQi400`1nQi<0
OXNE086:U`0208::V@0508>;V`24S9X0QXnK08J>W026Sid00`26T9l00`28TZ80RI>T08bEYP0208jF
YP0;08nFY@2@V:<0TIVR09:JX@2CW:80U9fS09FMY02EWZD0UYnW09NRZ@2HYJP00P2HY:L01P2JYZT0
WJVZ09fXY`2NZZL0Wj^X0:2[Z080X:ZU00@0XJZS0:6[X`2PZZ<0X:ZU0P2QZjH02`2R[:D0X:^S09jZ
X@2NZYl0WZ^N09j/W02LZiX0VZZH09Z[V01YLf`0=cPn0080<38e00/08R@T01hP7@0G61<07b8G02LZ
7@0^=2<09BTK04M@>@2=YWT0=3/Z018B300201PI4P0<01<C300A40T04107018B200A4`L04A@701@F
2@0D5PP04A<8014B200F60/06Ad>0P0F6@/00`0B50H07b<A02L/5`0202X`6@0602H[5@0R:1<07bPA
01/R3@0H7``05ad;0P0N91801P0W;Q/0:C0P02/b8@0]=280<3LT034i9080;cHQ00<0<STS03@i9@0f
?BP00P0d>bL01P0_=B00:S0L02L[6@0Y;AT09b/H01`O3a[ooooo803oP0020000o`D0oh00A`000?l<
0?n000030000o`3oP000oh000300oh003oooool000gooooo00H0BUQR04iLI`1BGfh0E61c05IQM`1F
HGP205EPMP0;05APM01FHW<0F6Ed05UUM@1IIWH0FVMj05]XO01KJG`0G6Yk05iZN01MJGP00P1MJ7X0
2`1OJGh0H6Un069[P01QJX00HVf306=^P`1TKh<0I72206EaP@1WLh40IWB30080IWB400H0IgB606Mc
Q`1YM8T0JgF;06]eS01/MH`206igS00406mhS@1_NXd0L7^<075kR`80LGb<00/0M7j>07F0T@1ePY40
MH2@07N2T01iQ940NXBA07b6TP1mQiD0OhVG082:V00208:;VP0508>;VP24SI/0QHjK08B=V`24SY`0
0P24T:001024T9l0Qi>Q08ZDX`2=UZH208fEYP0;08nGYP2AVJH0TIZU08nJX`2AWJ@0TYjT09BOY02D
WjD0UIjV09FPYP2FXZH00P2HY:H0102JYZP0VjNY09bXZ02NZZL209j/Y`0609j/YP2O[:@0XJfT0:2/
X`2O[:80X:^S0P2S[:D02`2T[JD0XJbT09n/X`2OZj40WjbP09n/W`2NZih0W:ZL09f/V`1fPGL0>3Pm
0080<cHe00/09b/X020T7P0M7aL071`B01dO4`0g?bX0?dTb04aI?P2E/H40A54j010A2P0201/N4P0<
01DE2P0A4P@04Q8401<C1@0B4`H051H901DG2P0I6``06A/>01PI3P0R:1H092`H0P0Q:AD02`0P9Q80
9bdI02Xa700X;aX092XD01hT3P0K8@d07B@?01hU4@0O9A008RLC00809b`I00/0:blM02`a800/<R80
;cHU038h9P0a>BD0<3LS030f8`0b>2@0=3TV03Pn:@0203Hm:@06034g9@0]<b80:BlN02L_700X;Q/0
92PG6_oooolO0?n000@0003o0P3oP01:0000o`/0oh0000<0003o0?n0003oP000<03oP00?ooooo`00
3Oooool01P1<F6D0Cea[059OL@1DGgH0E5mg05EOM`80E5if00/0EEmf05MRMP1HI7L0F6Ag05UUN01J
IWX0G6Ul05eYO@1MJW`0GV]k05aYN@0205aXNP0;05iYOP1OJGh0H6Yo069/P@1SKX80Hfj306=_Q01S
Kh<0Hg6206AaP@1ULh800P1WMHD0301WMHP0IW>606MdQ`1YMHT0KGN:06ihRP1]Mh/0KWN=06mhSP1`
NXd0LGb=079mS080LWj;00/0M82=07J1T01fPY80MH6A07J2S`1hQ900NHFC07Z5U@1lQiP0OHRH07n:
V@0207n:VP0;086;V`23SY`0PhfL08>>W022SYd0PXnN08>@W`24TJ40QY>S08VEY02;UJD00P2=UZD0
2`2?V:D0SiVT08nIX`2=VJ<0T9bT096NY02CWj@0U:2U09BPYP2EXJL0UZ6X0080Uj>Z00`0VjJ]09bV
[@2LZ:T0WJRX09j[Z@2N[:T0WJ^W09j[Y`2Q[:D0XJbS0:6/XP2R[J<20:B^Y00;0:B^X`2S[J@0XJbV
0:2[Y@2OZj<0WjZR0:2ZX02NZIh0WZbN07f7OP0m?4800P0h>CX02`0X:BP08R@O01hP600L7A407b0C
04]G?01CH4<0DUm308FOLP16DSP05aT<00807Qh@00`06AP801DE100G5`H0824@02LY6P0K71806adC
02<W6@0S:QX082LF02H^6P0Y<A/202Pa6P0;02Xb7@0[=1d0:S<N02P`6`0R:A@072<>01hV400S;1D0
9RlG02Xb6P0/<a`00P0]<b002`0]<R00;C8Q02le9P0b>2X0<cTY03Dl:@0c>BL0<3HT038g9@0h?R/0
?TD`0080>T8/00H0=C`Y02le9P0Z<2809bdN02H/6`0U:AXJoooooal0oh0010000?l00`3oP000003o
0000o`190000o`/0oh0000<0003o0?n0003oP000<03oP00?ooooo`003Oooool01P1>FFT0D5a]05=P
L`1CGgD0E5me059MM080E5ie00/0EF1f05IRM`1HIGP0EfAh05UUN@1KIW/0G6Ql05aYO@1NJWl0GV]n
05aYO00205]WO00805eXO@1NJGh0H6]o065/P01SKh40I6n106=`PP1TLX@206EcP`0<06EbPP1VLh<0
IW>306QdQ@1WMHD0IgB406QcQP1/MhT0KgZ;06miS01_NHh0L7Z=0P1aNhd3079nS@0;07B0S`1fPY00
N8BB07R3TP1hPhl0NHFA07Z7U@1lQiH0OXRI07j9V`20RY/00`21Ri/02P22SI/0PXfL08>>W`23T9l0
Pi2N08FAW`27Tj<0R9BU08ZDY@2<UZH2092HZ00;092IYP2AVZH0TIZV09:MYP2AWZ<0TZ2Q09>PX`2D
X:<0UJ6T09NSY`2HXjT00P2IXjX0302KYJd0WZN_09jX[02OZZX0X:^Z0:2[Z@2OZZP0X:^X0:6/Y@2Q
Zj<0XZbS0:>/X`80XZbS00/0XZbR0:>]XP2R[:@0XZbV0:6ZY02QZZ80XJ^Q09nZW`2P[J00PXV1040n
AP0203Ph?00;02d];@0Q8R407QlK01XJ4`0Z;Al0FFM805=P@P1;ES/0HgA@04mI>P12Ab/00P0b<Q`0
300X9Q808Ah=03Hh901DG4<0CeQ201lP600P8QT0:c0S02/b8P0Z<R00:S4N02`c7P80;3@O00/0;CHP
02/e7P0Z<Qd0;CHO02de7@0Y<1T0:C4J02Xc700[<a`0;SHN02he800202hd8P0;02db8@0^=280<3HU
03<i:00d>bT0=chZ03Hl:00f>bL0=C/V03i7<010BS800P0h@R/01P0c?BP0;3DS02H]7P0T:Q`092PK
028U61[ooooo7@3oP0020000o`@0oh000P000?l00`3oP000003o0000o`170000o`/0oh0000<0003o
0?n0003oP000<03oP00?ooooo`003Oooool01P1>F6X0D5a`059OM01BGW<0Deid05=MM@80E5ig00/0
EV5i05EQM`1GHgP0F6Ai05QUN@1IIGX0FfMl05aXN`1JIgX0G6Uk05e[O00205eZO00:05eZO@1NJWh0
GVYo05eZOP1QKX00Hfn006A`P01TLX40IG:106IcP`<0IgB300`0J7>306MeQ01YMHH0JgJ806egR@1^
N8T0KgR:071iR`1`NXX0L7^;075lS@1bOHh207=nT00;07=nT@1fPI@0Mh:C07V5TP1hQ900NXJA07^7
U@1mQiD0OhRG082:VP21RY`00`23Rih01`22Rid0PhfN08>=W`24T:40Q96P08JCX@29UJ<00P2;UJH0
3P2>UjP0T9NX092GZ02BVJP0TYZW09:JY@2CW:@0U9nS09BQX@2EXZ40Uj>R09VTY@2HXZD0VJ>X0P2K
YJX01@2LYZ/0WJJ]09jX[@2OZj/0XJ^Y0080XZ^Y00D0XZ^X0:6/Y`2PZjD0X:^U0:6[Y0020:>/YP0;
0::/Y@2S[:@0XZbT0:>/Y02QZZ40WjZP09nZX@2MZYl0WJZK08fHR`17B4`00P0h>Cd02`0^<3408bDT
01`M6`0F5Q<0=Sd/05IUB01DHTH0CEXo04===@1;ECX0Hg1<0080GFA400`0EEPl03di:P22SVh0R9Ui
04]B@`0];bH09bPO02hb9@0_=2D0;cDT02`c8`0[<b<202`e900;02li9@0_>RD0;SPS030j8@0`>B00
;C@M02`b6`0]=1d0;C@L02`c700]=1h00P0]<b0202db8@0902hd8`0a>2H0<cTX03@k:00f?BT0=SdX
03Hl9`11BC80?TL`0080=ChX00H0<S`V02Xc800T;1/092TK02DX7@0R91/Joooooal0oh000`000?l0
0`3oP000003o0000o`1:0000oa80oh000P000?lZ0?n000oooooo000=ooooo`0604aGJ01@G6h0Deic
059MM01DGWH0EUeg0P1FGWP02`1GH7T0F69h05QTM`1HIGL0FFEf05UVM`1LJGX0GFYi05aZN01MJgT0
G6Yi0080G6Uj00/0GV]m05i[OP1NJgl0Gfb1061/P@1QKX80HVj106A`PP1VLH<0Ig6306MbQ@0206Qd
QP0<06McQ@1XMHL0JGJ:06]gRP1]N8X0KGN:06ihRP1`NXX0L7Z;071jS@1bO900LWfA0P1eP9<02`1f
Oi80N86C07V3TP1iQI00NHB>07Z5T01kQI@0OXNG07j8V@21Rid0PHZL0080PX^M00/0PhfN08B=WP23
SIh0QHjO08F?X025TJ40QYBS08NDX`29UJ<0RiNV08nHY`02092IYP0;09:JY`2DVjL0U9fV09FOYP2D
WjD0U:2Q09FRX@2GXZ80VJBU09VSYP2JY:P00P2LYZX0102MYj`0WJN]0:2X[P2PZJ`20:6[[0060:6[
ZP2Q[:X0XJbZ09n/Z02OZjH0XJfW0P2R[:P02`2RZjP0Xj^Y0::/Y`2Q[:D0X:bS09n/X@2NZZ00WJZN
09j/V`2CXHl0CTm@0080>SXm00/0;S0a01lP8@0G6AP04A8A03<k;@1CH4L0Df5804iMA016Dc`0EfE:
06YkF`02071nG@0<08bKL`1LGdX0]<ZN08RHN`12Ac`0?44d03Lj;00g>BX0=SXY03Dl:P0d?2X0<3TW
0P0]=bH02`0^>BL0;CPV02hh900a>bD0<3XS02hf800/<Q/0;C@L02/b6`0Z;a/0;C<O00<0;S<Q00X0
;C8R02he9@0`=bL0<c`Z03Dn:`0f?R/0=SlZ03Hn:00nAbh0?4D]0P0e?BL01P0a>RD0:C<O02@/6`0S
:AT092PK02@V71[ooooo8`3oP01<0000o`d0oh0010000?l00`3oP000003o0000o`0Z0?n000oooooo
000=ooooo`0604aII`1@G6d0Deme05=PM`1EHGP0EV1h0P1FH7H02`1GH7D0FFAe05YWMP1HIWD0FFMf
05]XM`1LJgP0GFaj05a/NP1LK7T0FfYh0080G6Yi00/0Gfen061/O`1OJh00H6b1061/PP1QKHD0HFf4
06A`Q01ULH@0IW6406IbQP0206IcQ`80J7F600X0JGF706agR`1^N8d0KWR=06iiS01`NX`0LG^>075k
T01cO9<0M7jD0P1fPI@02`1gPI<0N8>B07Z5T`1jQI40NhJA07^5TP1nQiL0OXNJ07f8V`1nRY`0PH^K
0080PX^L00/0PhbN08F>X026Sj40QhnQ08J?XP25Sj<0QI6S08JCY028UJ@0RIJT08jIY`02096JYP0;
09:KY02CW:D0U9nX09FPZ@2EX:P0U:6V09BQY02EXJ@0V:>V09^UZ@2LYZ`00P2MYjd0302OZZh0X:Z^
0::Y[P2QZJ`0XZZ/0::[Z`2Q[:/0XJfZ0:6]Z@2R[ZP0XJfX0:6^Z080XJfX00/0XJbX0::[Y`2S[JH0
XZfT0:>^X`2R[J00XJbO09n]W`2O[Yd0V:NC055DD`0203De>00;02l_<00U9RD07b4P01PG600_<b/0
CUU6059NBP1@FdL0@d`k05=OB@1YN5`00P1YMU/0302Q^900QYEj0;gH[@1bOfL0BE0n0498=@0g>RT0
=3DU03<e9@0e>BL0=3`X02lg9080;3HT00H0;CLV02dg9@0_>2@0<C/V038l9`0_>2<202dc800302T_
700W;A/0:S0O0080;C@Q00/0;cHS02he900a>2P0<cXY03Do:P0f@2/0=3lZ03I0:P0e@2T0?TT]03M0
9@02038k8@0602df7P0Y<Q`09bhJ02L]6@0V:aT09bXL6_oooolR0?n004d0003o3@3oP0070000obX0
oh003oooool000gooooo00H0C5QW051MK@1CHG@0Df1g05EQN@1DH7L205EPM@0;05IQM`1HIGT0FFMj
05QWN@1JJ7X0FVQg05]YM`1KJgL0FfYj05][NP1KJWX00P1KJGT02P1MJW/0Gfam05m/O`1OJgl0GVV0
065/Q01QK8D0Hg2706AaQP1VLhH306EcQ@0<06MdP`1WMH80JGF306]fQ`1^MhT0KGR906ikS01_O8d0
L7b>079lS`1cOI40MGnD0P1fPI802`1fPY40N8BB07V5T@1iQY40NhRA07^8T`1mR9L0OhVJ07n9V`20
RYd0PX^M0080Ph^N00/0Ph^P08J>XP26Sj80QXnR08JAX`25T:80QI:R08JEX`28Uj<0RIRR08bIX`02
092KY@0;096LX`2CWJ@0U9jW09FOZ@2FXJT0UZ:W09FRYP2EXZL0UZ>X09VVZ`2KYjd00P2LZ:h0102M
ZZh0WjZ]09jXZP2NZJT20:6ZZP060::/ZP2T[Z/0Y:n[0:B^Z`2S[Z/0XZfY0P2Q[JT02`2R[ZP0XjfV
0:F^Y@2T[j<0XjfR0:>]WP2S[Yl0XJbO09n]WP2KZY/0FEeN0080;b`g00/0<Bld02PW:`0Q8B<071/M
02h_:`1CG4`0F65A04M<@P0`<B/0?3lc06McF@0205iXD`0<09faS@2/`Yd0Z/:K05UTCP0h?R`0=3PU
02DU5`0U9AP0:R`O02hb8`0]<R<0:RlP0P0X;R002`0Z<R80;3DR030i8`0b?2@0<S/U02lg8`0]=B80
:c<P02P`7P0W;ah0:34O0080:c@P00/0;CHR02hf8`0a>2D0=C`Y03Hm:P0f?B/0=CdZ03@l:00c?BP0
>dD]03@o9`02030j8P0602`e700X<QX09RhH02D/5P0U:QH09RXI6_oooolO0?n00500003o403oP003
0000ob/0oh003oooool000gooooo00H0CU]W055NK01DHG40E61d05EPMP1EGgL205=NM@0;05IQN@1H
IG/0FFIl05YWO01JJ7X0FFMf05]XMP1LJWP0FfUj05aYO01NJgd00P1MJG`02P1LJG`0GFYn05m/P01N
Jgl0GV^005m[PP1PK880HVn306A`Q@1WLhD306McQ00<06MdP`1YMH@0JGB206]eP`1]MhL0KGR806ij
S01_OHh0LGf?075mS@1aOHl0M7nB0P1fPY802`1gPi40N8F@07R5S`1iQhl0NhRA07j8U01nR9D0OhRF
07n9V@20RI`0PHVM0080PX^O00/0PhbP08J?XP27T:80QY2R08JBXP25TJ40QI>O08NFX028Uj40RYRR
08^IX`0208jJY@0308nJY@2BVjH0U9fX0080U9nX00D0UJ6Y09JRZ`2FXj`0V:F/09VV[00309^X[@07
09bY[02MZZd0WJRZ09jZZ@2PZjP0XJ^W0:B]Z@020:F^ZP030:F^[02T[Z`0Xjj[0080Xjn/00/0XJjX
0:6]Y02S[Z<0XjnS0:B^X`2R[J40XjfQ0:6]W`2O[Yd0WJfL05eRH@02030]>00;02d/<`0S8BP081dQ
020O800e>380GfYG0761J013Acl0<2l]030`;@1NJE<00P1JHdl0301gQFL0SZ9l086EL@1>FT80=Sd[
02X_7P0O8QD07AlE02<U6`0V:Ah0:2`O02L[7@809BTM00/09b`N02Xa7`0]=B00;cLO02`b7@0Y;ah0
:c8P02Xc800W<1h09blN02H`7@0202Pb7P0;02/f800]>240<3PP038i8P0c>BD0=3/W03Dl9`0a>2@0
<3LT03Y2:`0d?BP00P0]=R801P0Z<Qh0:30K02H]6@0S:QL092TG02H[6Q[ooooo8P3oP0020000o`03
0?n000000?l0003o04P0003o2@3oP0000`000?l0oh000?n000040?n000<0003o:`3oP00?ooooo`00
3Oooool01P1>FfP0DEi]05APL@1DGg80E5md05IQM`80EEmh00/0Ef9l05UUO`1IIWd0FFIk05YXNP1L
JGT0G6Yh05e[N@1LJGX0G6Um05eZOP0205eYO@0;05aYO01MJWd0GVao05eZOP1MJgh0GV]o065^P@1S
Kh80IW2506M`QP1YLXH00P1ZMHH0201[MHL0K7J806afQ`1/MXH0KGN806mjR`1_NXd0L7^>0`1bOXl0
3P1dPI00MH:A07F2T@1fPi40MhBA07R4T01jQi00NhR@07f9T@1mR980OhRD07n8U@20RIP0OhZJ0P21
Ri`02`24SId0Q8jO08F?X026T:00Qi6Q08NBX@26U:00QiFP08ZGX`2>VjH0Si^X0080T9^[00/0T9^Z
09>N[02DWZ/0U9nY09BPZ02FXZX0UZB[09JSZ`2HYJ/0VJNZ09VWZ`0209bZ[00<09bZZ`2NZZ/0Wj^[
09j[Z@2O[:L0XJfU0:B^Z02U[ZP0Y:jW0:F_Z@2U[ZT0Y:j[0P2T[Z`02`2S[Z/0XjjW0:>^Y02T[j@0
XZnR0:6^XP2Q[Z40X:jP09j^W@2M[Y/0Ifm[0080?T5600/0<34g02@T:@0R828071XK03Lk<`1FHTl0
HG1J05EPC`10AC/0=cXc05IQCP0205aXDP0<05AOB@1HID/0EfI:04mL@@0g?bd0:C0Q024V6P0M8AD0
8B@G02@X6P0W;1`09BXK0P0Q91H02`0R9AL092XJ02L]700U;1/082@H02H]800X<240:C4P02Pb7`0X
<A`0:34K0080:C8K00D0;3HN02hg7@0_=a`0;cHL02lf7P02038j8`0402dc800a>2@0>D4Z03@l9P80
<3LS00H0;3<P02/b7P0Z<1h09bdL02D[6P0W;QhJooooob00oh00C`000?ln0?n000oooooo000=oooo
o`0404eKI`1BGVh0Demd05=NMP80E5mg0P1EH7X02`1GHWd0FVF005YUP01JIW`0G6Ul05eZN`1LJG/0
GFYk05aYN@1MJWd0G6Qn0080GF]n00/0GFan05a/O01MKG/0GVij05m_O@1QL840Hg:206=aP`1TLH@0
IW6506MaQ@0206UcQP0<06]fQ`1[MHL0KGN906agR01^N8X0KgZ;06mjS@1`Nhh0LWf>07=oS`1cP8h0
M8:=0P1fPi002`1fPi40MhBB07R4TP1jR9<0NhVC07f;TP1mRI@0OhVE086;U@22S9P0PXfI0080PXbK
00/0PhfK08F>V`25T9`0QY6L08RCW`28Tih0R9BN08ZFX@2<V:@0SYVW08nIZ002096JZ`0;096KZ`2A
WJ/0Tij[09:NZ02DX:T0U:6X09FSZ02FY:P0V:FY09^XZP2LZJ`00P2MZJ`02`2NZJd0X:Z]0:6Z[`2Q
Zjd0XJ^Z0:B^Z@2U[jT0YJjY0:F^Y`2U[ZH0YJnX00@0Y[2Z00X0YJnW0:B_X`2T/:<0Y;2Q0::_W`2Q
[Ih0X:jO09f/W`2M[Yd0NHEl0P15BTd02`0f>Sd0;2h^02LX9@0R8Ad0<C8Z04M<?`1:DTD0D5a;04A>
?`0i@C<0EfI=0080H6mD00`0CEU104]G?`18Dc/0ADhg03Dk:P0]<R@09BPM01lR600R9AT092TL028X
6P0O9AH201dQ4`0;020U5P0S:AT09BXL02D[7@0I71@092PL02L]7P0W;ah0:C8N02/d7P0/=1d00P0]
=Ad02`0^=Ah0;cHO030g800^=Al0<3LO030f8@0^=200:c0N030f8@0h@2P0<cXQ0080;cLO00H0:c<O
02Xa7`0X<1h0:BhM02L]7P0[<B<Joooooa/0oh0000<0003o0?n0003oP000103oP01>0000ocd0oh00
3oooool000gooooo00@0C5YY055ML01CGgL0EEmk101EH7/02`1GH7`0FV=n05YUO@1MJ7d0G6Uk05iZ
O01NJg`0GVYm05eZO@1NJgh0GVYo00<0GVb000X0GFao05e^OP1MKW`0GVmm061`O`1SLH40HFn0069`
PP1TLH<0IW:50P1XLXH0301ZMHL0K7N806]gR@1/MhT0KgV:06mjR`1`Nhd0LWf>07=nSP1dP8h0MH6=
07J3S`80Mh>B00/0Mh>C07N2T`1hQ9@0NXNE07b8U@1oRiL0P8^G0829UP20RYD0PH^G08:=VP0208:=
W00;08>>W024SY/0Q8jK08JBW@28Til0R9:O08VDX02<UZ<0SiVW08nIZ02@VJT00P2AVJX02`2AVZX0
TIbZ09:NZ@2BWjL0U::Y09FRZ@2FXjX0UjFY09VVY`2MZ:X0WZV/0080X:Z_00X0X:V`0::Z/@2S[;80
Y:fb0:>[[P2T[J`0YJfY0:J]Z02X[jH0YjnV0P2V/:L20:J`YP0;0:NaY@2U/J80YK6Q0:B`W`2V/Il0
YK2N0:B^WP2Q[Yh0WjfN09f]W@22T8<00P18C4d02`0i>c`0;c4`02X[:00X9b80:BPR03Ph;`19CSl0
B59003m8>00g?bh0E6=70080I7IE00`0Cea004YF>`19DcP0@dTa03Hi9`0_<B80:2XN024S6@0Q9AX0
92/O028Z7P0O9aX201lV600;028Z6P0T:aX08RXI028X6@0F6Pl06QdA020R500R9aH09bhK02Xb7@0/
=1d00P0^=Qh02`0_=b00<CPS03<i9@0_=R<0<3HS02hd8P0]<R00:RlN034g900lA2`0<cXR0080;cLN
00H0:c<M02Tb7P0X;ah0:BhN02X_800]<b<JoooooaL0oh0010000?l70?n004h0003o3@3oP0020000
obh0oh003oooool000gooooo00H0CEY[055NLP1CGWH0E5mj05APO01EHGd205EQN`0305IRNP1IHgX0
FVAk0080GFQm00H0GFUl05eYNP1MJG/0GFYm05iZO`1LJGh205eZP00;05m/PP1MJh00GF^005e[O`1M
K7d0Gfim069aO`1QL7h0Hg9o06EcP01VLh800P1YMHH0301ZMHP0JgR906]hR@1/NXX0KWZ<071kS@1a
O8l0LWj>079oS@1cOh/0Lh2;07>1S@80MH>B00/0Mh>C07N3U01hQ9D0NhNF07f8UP20RYH0P8VF0828
U@21R9H0P8VI08><W00308:=W00:08B>W`25Sj00QY6P08JBX027TZ00RYBS08fHY`2?VZT0SiVY092J
Z080T9ZV00/0T9ZU09:MYP2BWZH0Tj2V09FSYP2EXjL0Uj>Z09VUZ`2JYJX0W:N[09nY[@020:6Z[`0<
0:6Y/02PZK00XZZ`0:>[/02SZjl0Xjb/0:F/Z@2V[ZT0Z:jW0:N^YP2W/:L0YjnY0P2V[ZL02`2W/JH0
Y[:T0:JaXP2T/:00YK6Q0:JaXP2U[j40XjjP0:2/W@2N[I`0RiN:0080B4Y>00/0=cHk038a<P0^;B`0
;2`Z02`/9`0b=2/0CEI304YD@00lAC<0<cX[04QC?P0206UjF`0<055M@`19DcX0BE4h04E;<P0j?RL0
<3@O02TZ6P0S91L08B<G028V6P0S:1/092TM0P0T:A`02`0S:Q/09R`K028W5`0L81805QP=018D2P0E
5P`06A`>02P]6P0/<Al0;S@P0080<3LS00/0<STU038i9`0d>bL0=C`X038h900_=280;S<Q02X_7P0a
=b@0>d<]03<k9@0202lh8@0602/d7@0[<al0:c8P02T_7`0W;Qd0:S4O6_oooolM0?n00080003o00<0
oh000000o`000?l0CP000?l=0?n00080003o;P3oP00?ooooo`003Oooool01P1=FV/0DEib05=NMP1D
GgX0E61l05EQO@80EF5k00<0EV9j05USNP1JI7/00P1MJ7d01P1MJG`0GFUj05eYN`1MJWd0GVYo05aY
OP80GFZ000/0Gfb205e[P01MJh00GF]o05e/O@1OKWd0HW5o065`OP1SLWl0IG>006IcPP0206UeQP0<
06YeR01[N8T0JgR906ajRP1^NX`0L7^=075lS`1bOXh0LWn=07=oR`1cP8/0Lh6=0P1ePi802`1gPi<0
Mh>D07R4U@1kQiH0OHRF082:UP20RIH0P8RE0868UP20RIT0PhbL00<0PXfL00X0Q8jO08F?X026TJ00
QY:P08NBX02:U:<0SIRW08nJZ@2?VJT0T9ZX0P2@VZH02`2@VZD0TYfV09:NYP2CX:H0UJ>V09FSY`2G
XjX0VJF[09ZUZP2LYj/0WjV]0080XJZ_00`0XJV`0:2Y/02RZ[00Xj^`0:>[[`2S[:`0YJbY0:J^Z@2X
[ZL0YjjV0:N`Y`2W[jT20:J^Y`0;0:NaYP2V/Z@0Y[6R0:B`X02U/J40Y[6R0:F_X@2S[Z00X:bM09j]
W02;UhX00P18BTh02`0g=S/0<S4b02h];00/;2X0;2`W038d:`1=ET<0BUA003a5<`0c>R/0B5<n0080
JGYK00`0DEe304UC>P19DCP0AD/b03Xn9`0`=1l0:BXJ02<T5`0Q8aL08RHJ02<X6`0T:Ad202@Y700;
02<Z6`0V;1/08RLG01`P4P0F60d04Q@:01DF300I70h0:2dJ02`a7`0^=2000P0`=b<02`0b>BD0<STW
03@k9`0e?2P0<SPT02ld8P0^<b40:RlN034g900k@bd0<c/U0080;cPQ00H0:c@M02/c7`0[<R00:BlO
02L^7@0Z<AlJoooooad0oh000P000?l00`3oP000003o0000o`1>0000o`d0oh000P000?l^0?n000oo
oooo000=ooooo`0604iIKP1BGG@0Demh05ANN@1FHGd0EEmm0P1DGg/02`1FHW/0F6El05YVO@1JIW`0
FfMm05]XO01JIg`0G6Ql05aYO@1NJH00GFR000<0GFZ100X0G6Z005i[P@1OK840H6f0061^O`1RL7h0
Hg9m06EdOP1UM7d0IW=o0P1YM8<02P1[MXL0K7J906]fR@1/N8X0KWZ=075jT01bO940M7f@07EoT01d
P8h207F1S@80MH6?00/0Mh>C07R4U`1hPiH0O8JH07j7V@1oR9P0P8RI0829V021RIP0PHZJ08>;V`02
08><V`0;08B>W024SYl0QY2Q08JAX@27TZ40Qi>P08VDX`2<UjH0SIRY08jHZP2?VZP00`2@VjH02P2B
WJL0TYfU09>OYP2CXJH0UJ:W09JRY`2IXjL0VZBY09fV[02OYZd20:2W[P0809nW/02OZ;00X:V`0::Z
/02SZk00Xj^_0:B/[@2T[:/20:J]Z`0?0:N^Z`2W[J/0YZfY0:J]Z@2T[ZH0Y:jT0:B_X`2S[Z40YJnR
0:F_X`2T[Z<0XjfR0::]W`2P[Ih0S9R<0080BDY@00/0?3e103Xk>`0h>3@0<S4]02h/:00b<b`0DU]8
059MB013C3T0=3/[049<=`0206UkFP0<05=OA01:Dc/0Adlf04E;<`12Abl0=cXW02l_7`0Z:Q`0:2LL
02PZ7P0V9ad092HN0P0S9Ad02`0P8aT07b8G01dQ500H6`h04aH:00lC1`0=3`H03a8702L_6P0/<ah0
<3HR0080<SPU00/0<cTV038h9`0b>BL0<STV030f8`0^=240;C8P02/`7P0]=280<C`V02dg8@0202/e
7P0602Pb700X<A`0:S4N02T_7`0V:ad0:S8P6_oooolL0?n000<0003o0`3oP01>0000o`d0oh000P00
0?l^0?n000oooooo000=ooooo`0604iIK@1AFW80Deih05ANN`1FGg`0EV5m0P1GHWd00`1HHgd0FFEm
05]XO@0205]XO@0605]WO@1JIgd0G6Qn05eZO`1NJH00G6J00P1LIgl02`1KJ7h0G6Yo05i[O`1OKH40
Gfb105m/O`1QKWl0HW1m06=aO01SLGd0IW:10080J7:500`0JW>706YcR01/MHX0KWN;071iS@1aNY00
M7bA07AmT01eOY00MX2A07F1T01fPY0207F2T@0;07N3U01hPiP0NH>H07Z4V01kQIT0OXNJ086:W@20
RYd0P8ZL08:<W022S9d00P23S9d01P23SIh0Q8jP08F?X026T:40Qi2R08NAY080RIBU00<0RYFV08bG
Z02<UZT00P2=V:T02`2?VjP0Si^V092MYP2CX:L0U:2X09JQZ@2GXJT0VZ>Y09bTZ`2NYJ`0WjN_0080
WjR_00L0X:N_0:6X/@2RZK00XZV`0::[/@2SZk00Xjb^0080Y:b^00<0YJf^0:F/[@2U[:/00P2U[JX0
2`2T[JP0Y:bW0:B^Y@2T[Z@0YJnS0:J`Y02S[J<0XZbR0:6[X02P[9l0TIjB0080CDiD00/0@TA804=7
@`0l?cP0<30Z02d/9@0`<2T0CE=404aC@P0nACH0;c@X03a4<@0206j2G@0<05IUA`17DCP0B58i04I>
=@15Bc@0@dLb03`m;00g>2/0<S<Z030`:P0Z:R@092@P0P0P8A`02`0N8AT07R4G01dQ5@0H6`l04aL;
010D1`0>4@H02P`4024X600_>2<0;cPR0080<CTT0P0`>BD02@0`>B@0;SHS02hf8@0^=Ql0;C<O02X_
7P0/=280;cXU02/e7`0202Tc700602Xc700[<A`0:c4N02/_7P0X:a`0:BhN6_oooolT0?n004`0003o
3@3oP0020000obh0oh003oooool000gooooo00H0CEUZ051JL01EGgL0EV1j05EONP1GHgd205QSOP09
05UTO`1IIGl0FVEn05]WO01MJ7d0FfQl05eXOP1MJ7l0GFR00080GVV10P1MJ8000`1MJGl0GVZ005i[
P002061]P006065]P@1RKh40I76106IcPP1VLH<0Ig:50P1YLhT0301ZMHX0JWB906efS01_N8h0L7V@
079kT@1dO980Lgb@07AmT@1eOi<0MH6C07J1T`80Mh:D00/0N8>F07V4V01jQIT0NXJI07Z5V01lQiX0
P8ZM086:W@20RIh0PHZN08>;W`0208><W`0;08B=X025SZ00QHjO08NAX@28TJ80R9:T08ZDYP2:UJD0
RiNW08bHZ02<UjX00P2=V:X02`2?VZX0T9fY09:NZ02DWZL0UZ6Z09VRZ`2IXZX0VjF[09bTZ`2NYZ`0
X:R_0080X:V`00L0X:Vb0:2Z]02QZ[<0X:Va0:2[/@2QZk00XZ^_0080YJf_00<0YJf^0:J][@2V[J`0
0P2U[Z/02`2U[ZT0YJjX0:B^YP2U/:L0YJnU0:F_Y02T[J@0XjfS0::/X`2PZj40UZ:H0080DU=H00/0
?3a30452@@0m?CP0<S4Z02l^9@0b<2L0BU1004U>?P0o@cD0<cH[03Xo<@020721G`0<05UWC015CSX0
BU@n04QA>`16CSP0Bdlj04M8=`15ACL0?She03Th<P0c<bh0:RTW0P0U9R802`0P8aX07B0D01XK400F
5Pd04aD;014D2@0?4PP02@`401dU5P0_>BD0;cPU0080<3TV00/0;SLU02dh900]>2<0;CPS02`f8@0]
=b00:c<O02Xa7`0Z<b00;3HR02Xd7`0202Td7P0602/d7`0[<ah0:c4L02T^700[;Qd0;C8P6_oooolR
0?n004h0003o3@3oP0020000obh0oh003oooool000gooooo00H0CEQY051KL01DGgD0EV1g05MQN@1I
I7`205YSOP0;05YTP01KIH40FVB005]WO`1LJ7d0FfQk05aYO01MJGl0GFR0061ZPP1PJX<00`1OJ880
2P1PJH<0H6Z2061[P01QKH40HVf1065^P@1SL8<0IW:606QcQP1YLhL206YdRP0<06afR`1/MH/0K7F<
06igT01_NI80LG^C07=mT`1dOY<0MH2C07B0TP1eP980Mh>C0P1hPi<02`1iPY<0NX>D07^4U`1nQYP0
OXRH07n8V@21RY/0PHZM0869WP21RYl0PX^O0080PhbO00/0Q8fO08F?X028T:40RI6Q08VAXP2:TjD0
RY>T08^DYP2<UjP0SINZ08jHZ`0208jIZ`0;08nIZP2BWJ`0U9j[09BNZ@2FWjX0V:6Z09VQZP2IXj/0
VZBZ09bVZ`2OZ:h00P2OZ:l0302NZK40WZRb09jZ/P2OZ[40WjZ_0:6/[`2R[:h0Y:f/0:B]Z`2U[Z/0
Yjf[0:R^ZP80YjnY00<0YZnW0:N`Y@2V[j<00P2U[j@20:J_Y@040:B^Y02R[:80X:ZQ09^XW080HFEU
00/0?Se30411@P0n?SX0=SD`03<a:`0c<BX0B4/l04]A@011ACL0<C<Y03Hj:`0206emF`0<06IeEP15
BcX0BU4o04Q@?P15C3X0DEI105eSB`1EFDD0C4dn0492=`12AC/0:BPV0P0V9b802`0Q8a`071hD01TI
3@0F5PT04a@9018D2P0@4PP03Q0601LJ300X;a`0:C0K0080:C0N00/09RdM02D]7@0X<B00;3LS02Xe
8P0X<Ah0:34M02Tb700Y<ad0;CPN02dh7@0202/d700602/c7@0[<Qd0:S0M02T_7P0[;al0;S<Q6_oo
oolP0?n00500003o3@3oP0030000obd0oh003oooool000gooooo00H0CEIY051IK`1CGG@0EUmf05QP
M`1JHgX205YSO00705YSO`1JI800FVF105]VP01KIgh0FVMk05aYO00205eXOP0605mYP01PJH40GVIo
05iVO`1OIh00HVZ10P1QJX001`1QKH80Hfj106A`PP1TL8<0IW6506QbQ@1YLXH00P1ZLhP01`1/LhT0
KGB906edRP1^Mhd0KgV?079lTP1eOY@00P1eOYD00`1eOiD0MGnD07J0U00207N2T`0;07R3U01iPi<0
NXBC07b5U01mQYD0P8RF0828V@1oR9X0P8VM07n;WP1oRYd00P1oRY/02`21SI`0Q8jM08J?WP28T9h0
R96O08RAX029Tj40RiFT08bEY`2<UZL0SYRX0080SiZY00/0T9^Y09:LZP2CWJX0UIjY09JNZ@2GX:T0
V::Y09VSZP2KYJ/0W:J[09jW[00209jX[@0<09jX[`2LZ;00W:V`09f[[`2OZj`0X:^Z0:6/ZP2T[JX0
YJjZ0:F]Z@2X[ZX0ZK2Y0P2X[jL02`2V[ZD0YZnS0:J^W`2V[Z00YjnS0:N_Y02W/:@0YJnS0:>]XP2Q
[:40X:jP0080J6e/00/0>CM00410@P0j>SP0?Slj0494?017Bcl0Be1104Y?@011AcP0<cL/038g:P02
06IgE`0<0721H014BST0Adhn04I=?P11ASP0E5]608VJMP1ZLUX0HfYF061XEP1=DdP0:b/Y0P0W:BD0
1P0P8A/061TA01<C2P0A40H040l5010@1P804Q<900<051H902<X500S:1800P0Q9A802`0M8A007R<C
02H/6`0Z<Ql09BdL01lU5P0R:AP09RlL02Tb700]>1h0;CLM0080;SHL00H0;C@L02dc700Z<1/0:RlM
02`a8@0]<b8Jooooob80oh00CP000?l=0?n000<0003o1@3oP0000`000?l0oh000?n0000U0?n000oo
oooo000=ooooo`06051IJ@1DG6h0Eemf05MPMP1IHWT0FFAj0P1IIGX02@1JIWd0FfMn05]XOP1MJ7l0
GFQn05]WO01LIg`0G6Mm05eXO@0205eYOP80GVUo00/0HF^0065[O`1SKH00HVj106=`PP1SKh40Ig>3
06QbP`1XLH@0J7:606UbQP0206YdQ`0<06]eR01_MXP0L7N8079jRP1bNhd0M7b@07MmU01gOIH0MGfG
07AnUP1eOiD0Mh2E0P1hPYH02`1hPiH0N8BD07R4T`1iQ9@0O8JE07n9UP21RIX0P8VK082:W01oRY`0
OhZM0080P8^L00/0PHbK08>>W024SY/0Qi2L08VBW@29TYh0RiFP08fFXP2>UZ<0SiNU096JZ00209:L
Z00;09>MZ02DWZP0UIjX09FMY`2EWZH0Uj2V09ZSY`2IXjL0WJJZ09fWZ`2NZJ`00P2OZJ`0302NZJd0
WZV^09fZ[P2NZZ`0Wj^Z0:2[Z02S[JT0YJf[0:N^[02X[Z/0Z:jY0:R_Y`80YjnU0P2U[Z<02@2V[j80
YZnQ0:J_XP2Y/:@0Z:nS0:F^XP2T[Z<0XJbR0:6_X`0206]`LP0;03Dc?P0o?cl0=cHc055EAP1CF4H0
GVA?05YPB`1?E4<0CEA303a2=@0i@3<00P1PL5H0301[O5l0BU=104UB@011AcT0=SX^04iFA02G[8P0
Rian08NENP26U7X0F5mB02TX:0809RPS00/07R0H01XL4P0E5P/04A8600l>100@3`D051<901HG300H
6Pd07B8@01hT3P0201/R3@0;01TO3@0I7@d09R/I02he8P0O8aL051H>020V600U;A`0:S<O02lg8@0_
=Qh00P0`=R001P0a=b40;cDP02`b7P0/<Ql0;C<S030g9Q[ooooo803oP01B0000o`/0oh000`000?l5
0?n000@0003o903oP00?ooooo`003Oooool01P1>F6T0Dei_05URN01JHg/0FF=k05QTN`80Ef=j00L0
FFEk05]VN`1KIW`0GVQn05mYO`1MJ7d0FfMl0080G6Ml00h0GFQl05mZOP1MJ7h0GFQn05iYO`1OJWl0
H6Yo065]P01QKX00HVj006EaPP1XLX<0J7:406UbQ`<0JWB600P0JWB506egR01_N8T0LGZ:079kS@1d
O8l0MGbB07InU@80MGjG00l0MWnF07V1U`1iPIP0NH6H07Z1U`1iPIH0NhBE07j7V@1oRIT0OhRI0869
W020R9d0OhNM0828W@21RYl00P23S:002`22Rih0PXbO08>=WP26Sid0R96N08ZBW`2;U9l0SIJP08jG
X@2@V:80TYVT0080Ti^V00/0U9^X09BMY`2DW:P0U9^X09FMZ02GX:T0VJ>X09ZSY`2MYZT0WZJZ09jX
Z@0209nZZ`0<09nYZ`2NZJ/0WJZZ09fZZ02OZZX0XJ^[0::[Z`2SZjX0YJb[0:J]Z`2X[JT0ZK2W0P2X
/:H30:J_Y0080:J_X`2W/J<0Z;2R0:N_X`2U[J<0XjfS0:2[X`2P[Z@207=jNP0;03hnA`0n@440=SPf
055IB@1?ED<0HVYA065YD@1AEdD0DU]9045:>`0k@cD00P1JJ4l0301YNU`0CeU304aE@010AC@0<c@Y
051FA02AY8<0SIn1096RQ02IZh`0K7MS028N7`8092<P00/0828I01XK4@0E5@/04Q87014?1P0A40H0
61/;01`O3P0N8A407R@B01dT4P0201XQ4@0:01LM3`0F6@l0<STY03e5<P0E5a802@X801hT600]=R<0
<3LR038i8P<0<3HO00H0<SHR02ld8P0]<R80;C<R02hd8`0_=RDJoooooal0oh00D`000?l=0?n00003
0000o`3oP000oh0000<0oh001@000?lS0?n000oooooo000=ooooo`0404aHJ`1AGG40EF5f05EPN@80
Ef9l0P1HHWX02`1IHgX0FVAj05]TN`1KI7`0FfMl05YWN`1LJG/0GFUk05aXNP1LJGX0GFUl0080GFMm
00/0H6Yo065[O`1OJWl0H6f1065]P@1RKX40I6n306EaQ01WLX@0J7:606UdQP0206YdQP0<06YdQ`1]
MX/0KgN<071hS@1aNhl0LWbA07=mT`1dOiD0MGnG07MnV01hOYP0NX2I0P1jP9P02`1iP9H0NH2D07b2
UP1oQ9L0P8FI0826VP20R9/0P8NK07n6V`20Qi`0P8VN0080PH^Q00/0PHbQ08><X@24SJ40QHfN08R@
WP28TZ00RY>P08bDX02;UJ40S9FQ08nFX`02096IY@0;09:JYP2CVjP0TIVX09:JZ@2DWJT0UYjY09NO
Z@2GWjP0V:6X09VSY`2KYJP00P2LYjP0302MZ:T0WZRZ09fXZ@2MZ:L0WZVY0:6YZ`2QZZ/0XZ^/0:>[
[02T[:/0YZfZ0:R^Z@80YZnU00/0Y[2U0:F_Y02T[Z<0YK2T0:B_X`2U[Z40YJjS0:J^X`2T[J<0XJbQ
0:2^XP0207n8PP0;04M8C@12ADD0>Shj0415?017CSl0F61;06QdFP1?ETD0DeY804E=?@0i@3400P1A
GTH0301ZOEX0EF=704iI@01:DS/0>Sh_04aB@@2>XH00RY]n08bLP@2FYXT0PHme02h]:@809B8O00/0
8R8L01`L5P0G5Ph04a89014A1`0B4PH061/;01/Q3P0L8A007bDC01hT500201dS500;01TL3`0C50`0
:RhT03i7>00J7AX02`d<01PN500`>RD0;SLQ03<j8`0a=al00P0`=R001P0a=b<0;S@S02db8`0^<bD0
<CLU038h9A[ooooo803oP01B0000o`d0oh0000<0003o0?n0003oP0000`3oP0050000ob<0oh003ooo
ool000gooooo00H0BeMZ04mKL@1DH7L0E5mg05MRNP1HHg`205QSN@0;05UTN01JIWT0G6Mk05aWO01K
IWX0FVMi05aXN`1NJW/0GFUi05iZN`1NJW`00P1MJ7h02`1OJGd0H6]o05mZO`1QKH40H6f1065^P@1T
Kh<0IW2406M`Q01WLXD0JG>70080JWB800T0JW>906adR`1aMhh0LgZ?07AlT@1dOY80MH2C07J0U@1f
OiL00P1gOiP02P1hP9P0N86G07R1U`1iPIH0Nh>E07f3U@1oPiD0OH6D07j4V01oQYX207n7V`0?07n9
W@1oRYh0OXZO07j:W`1oRih0PHfP08>=X025SJ00QXnP08RAX@28TZ80RiBT08^EY@2:UJD0S9JU0080
SYNV00L0TIZX09:KZ@2AVZP0TY^W09:MY`2DWJT0Uj2[0080V:6/0100Uj2Z09ZSZ`2KYJ/0VjF[09bV
[02MZ:d0WJV/09fXZP2NZJ`0XJZ^0::[[P2RZZl0Y:b`0:F]/@2T[:l0YJb[0P2U[ZP01@2V[jH0Y[2U
0:B_X`2U/J@0XjjS00<0Y:jS00<0Y:fS0:6/XP2Q[j@00P2;UXh02`17B4d0?d1103Tk>00o@S/0Be55
04eCAP1[NF80Be9504mGB@17D440=S`a0080BeM400`0KH5O05QWBP1=FD00BeLn04A>>@18D3h0Riek
08bMO`2:VWd0SYf208nMPP1=D4H202PU900;02DT8P0O7Q`06ATD01DD3`0D50d05AH<01XN3`0L8A<0
7B8C020U5@0Q9QH00P0O8Q@02`0J6Ph05QD<01hO5`0]<BP0?TLi00lA4@0?4`l0:C8Q02de8P0`=R<0
;cDR0080;SDQ00H0;cHS02ld8@0^<R00<C@S03@h9`0e>RPJooooob00oh000P000?l00`3oP000003o
0000o`1=0000o`H0oh0000<0003o0?n0003oP000103oP0000`000?l0oh000?n000030?n000D0003o
8`3oP00?ooooo`003Oooool01P1>FF`0D5]b059NM`1AGGH0Deig05APMP80EF5e00H0Ef=d05QUM01K
IgP0GFUl05]VN`1JIg/305]XO00505eYO@1NJWh0GFYn05eZOP1NJgl00P1OJh00201PK840HFf2061]
PP1SKh80IG2306I_Q01VL8@0J7670`1ZLhL02`1]MhX0KgV:071iRP1bNh`0Lgf=07AnSP1eOY40MX2D
07F0UP1eOiH0MH2G0080Mh:I00X0NH:H07N1UP1jPYD0O8>F07^1U@1kPYH0OHBH07f5V01nR9X0OhVM
0`20Rj402`1oS:00P8fP086=X023SIl0QY2Q08NAXP27T:80R9:U08VDY`28U:H0RYFV0080RiNV00/0
SIRV08nJY@2?Vj<0T9^T096MYP2BWZP0UJ2Z09JPZ`2GXJ`0V:6/09VR[@0209VT[P0<09ZV[`2LYk00
W:R`09fX[`2MZ:h0WZV]0:6Z[@2RZjh0Y:^`0:>[/02T[:l0Xjb[0P2T[:P02`2T[JL0XjnW0::_Y@2R
[j<0XZfR0:>]X`2T[Z@0XjfR0::]XP2PZj80X:fS0080SibC00/0BTYA03hnA00i>Sd0Ade705YSE@1@
ET`0J7ER04UAB01<ET/0ADm403Dl=@0204E@@P0<06UmH01IJDl0C5Q204aG@P17DCl0Ae1007n@LP2:
W7h0R9Mm08VHO`29Uh40JG=T0P0n@C`02`0V9bL08B8T01hO7`0I6QT061PD01XL4`0M81D08B<H028T
600T9aT09BLI0080828E00/06aT?01XH401AG4@0?dLh05UUD00A4Q404Q@A02D[7`0Z<B40;38Q02db
800202hc8@0402dc8@0_=240;c@O03<g8`80=STW6_oooolS0?n004l0003o1P3oP0000`000?l0oh00
0?n000040?n000030000o`3oP000oh0000<0oh001@000?lS0?n000oooooo000=ooooo`0604iJK01@
GG80Demg05=OM`1CH7L0EF9f0P1DHW<02`1FHg<0EfAd05UVMP1IIWP0FFIi05YVNP1KJ7`0FVMk05YX
N@1JIgL0G6Ui0080G6Ul00/0GVUn05mZO`1OJgl0Gf^005m[P@1NJh00HFj1069_PP1SL880IG6506Ia
QP0306UcQ`0;06agR@1_NX/0L7Z;079mS@1aO8d0LWf>07=oS`1eP980MH6C07F1U01eP9<00P1gP9D0
2`1gP9H0NH6F07Z2U`1iPYL0NX:G07Z3U`1jQ9H0O8JH07j7VP1oRId0PHZN0080PHZP00/0P8^Q082<
XP21SJ<0PXfR08B@XP25T:80QY6R08NBY028TZ@0R9>U08ZDYP0208^FY@0;08bGY02?VJ@0TI^S09:M
X`2CWZ@0TYfV09BNZ02FX:T0UZ6Y09RRZ`2HXZ`00P2IXjd0302KYk00W:Na09bW/02MZ:h0WJN/09jX
Z`2PZZ/0XJ^Z0:B[[02TZjd0Y:b]0:B/Z`80XjbY00D0XjbW0::/Y`2Q[JH0X:fT0:6]X`020:>^Y004
0::]XP2Q[J80WZZQ09bYWP80SY^@00/0CE1D04=5BP10A4D0CEA=06=]GP1BF4h0FfEH04aDB`1;E4P0
A4e103Dk<`0204MA@@0<065aEP1LJe40Ce]504eGA019DD80BE13082?M029VWh0R9In08VGP024TGd0
QI=m0P1bOFX02`0P7R407a`Q01/I7@0F51L05A<C01TJ5@0M81H0828G028T600W:Q/0:R`N00808R8F
00/071TA01TF4@1SL5L0IgMN04MAA00@41<05APH02lh;@0_>2`0;cPX02`d8P0202dd8@0602`d8@0]
<b40;C@Q030f8P0c>BD0=SXW6_oooolS0?n004l0003o3@3oP0000`000?l0oh000?n000030?n000P0
003o403oP0000`000?l0oh000?n0000=0?n000oooooo000=ooooo`0604YHJP1=Fg00D5id055OMP1B
GgL0E69g0P1EHgD01P1FI7D0EfEd05QUM@1IIWH0FVMg05]XN080FfQi00<0G6Yi05YWM`1KIgP00P1M
JGd02`1PJH00HF^4061[PP1QK8<0HFf105m/O`1QKWl0HW2106AaP`1ULXD0J7>80080K7J;00<0KGJ;
06ihS@1bO9000P1cOI401`1aO940LWfB07AoTP1fPI<0MX:B07J2T`1hPYH00`1gPID02P1hPYP0NX>K
07Z3V`1kQ9/0NhNK07b6VP1oRI`0P8RK082:WP20RYd2082;X00;082;X@21S:<0PXfV08:?YP23T:D0
PhnS08>?X@26TJ80R9>T08^FZ02=UjL00P2=UZD02`2>V:H0T9RU09:JYP2CVj@0TifT09BNY@2FWjD0
Uj2W09NQY`2HXZL0V::X0080VZB[00`0VjJ^09^V[`2KYZl0W:J^09fW[P2NZ:h0WZR]09nY[@2RZjd0
Y:b]0:>/[02R[:/20:>]ZP0;0::]Z@2R[JP0XZfY0:6]Z@2S[jX0XJfV0:6]Y@2OZj@0WJVP09^XWP2I
Yi/00P2=Vi002`1GG5h0ADQ>04YADP1QK600G6EG055GBP1BFD/0C5A704QAA00oASX0<cP^0080?THf
00`0I7AG065aEP1BGTP0C5I304Q?@015BCh0NXQ`08fOPP29V800RiZ308JCO`2<Vh<208FDO@0;02@R
8`0K5Q/07AXL01LD5P0D4140518@01TI4`0Q8aP0<C@T03Lj:@0c=RL00P0T9QX02`0L7A<05a@?05AL
B01nT6l0EF1?01`M7P0D5AT0<S`d03<m<P0]=bT0:C<R0080:S<Q00H0:S8P02Xc800Y<Al0:c<Q02lh
900c>RLJooooob00oh00DP000?l=0?n00080003o103oP0080000oa00oh0000<0003o0?n0003oP000
3@3oP00?ooooo`003Oooool01P18EVP0BeU/04mNL@1@GG@0DEed05=OMP80EF=f00/0EfEg05QUM@1I
IWD0FVIg05aXN01JIWT0FfMj05]WN`1KJ7`0FFIj05UVN`0205aXOP0;05mYP@1OJX80H6^3065]P`1Q
KX00HFin069_OP1SLGl0IG:306QcQP1ZMXT00P1/Mhd01P1_N8l0L7V@075jT01cO940LWfA07=nTP80
M82D00@0M82C07F0T`1fPID0N8>G0P1gPIH02`1gPYT0N8>J07V3V`1iPi/0NXFK07^6W01lQi/0OXRL
07n7W020RIh0OhZO0080OhZQ00@0Oh^R086<X`21SJD0PHjU0P24T:H01@23SjD0QY6T08RBY@2:UJL0
S9JW0080SINW00/0T9RX092HZ@2AVZT0TY^W09:LY@2DWZH0UZ2V09JPY`2FX:H0VJ>X09VSZ@0209ZT
[00409^T[@2KYJl0VjF^09bW[P80WJN_00H0WZR_09nY[`2RZk00XZ^]0:>/Z`2T[Z/20:>]ZP0;0::/
ZP2R[JX0XJbY0::]ZP2T/:`0XZj[0::^ZP2PZZL0WjZT09fYX@2LZZ000P2FY9X02`1VK6`0ADM<04a?
C@28Ugd0FEm@05AIBP1JHU80C5A803m6?P0d>3@0:RdZ0080=CXa00X0Hg=H06AdE`1FHTX0D5U404]B
@@13B3/0Lh1W09:UQ02;W800SIj30P29V7l208^KP00;034a;P0K5aX08b4N01/I5`0@3@d03@T:010=
300d>2X0FfM<061/D`1:DT400P0X:b@02`0T9Ql08R8O05YTDP1jRg00KWeV038g<@0D4aH0?4Lk038j
<00Y<BH09RhP00809RhO00H09blN02Tb7P0X<ah0:S<O02hf8@0b>2@Joooooal0oh00D`000?l30?n0
00030000o`3oP000oh0000L0oh000P000?l40?n000P0003o403oP0020000o`h0oh003oooool000go
oooo00H0B5IX04]IK01?GW40D5ed055MM01CGgH205ESMP0;05MUM`1HIGD0FFIe05YVM`1LJ7P0FVIi
05]WNP1KIg/0FfQl05UVNP1IIW/00P1LJ7h02`1OJH40GfZ2061[P`1QKH<0HFj0065^OP1RKgh0Hg5o
06EbP`1XLhH0JWJ90080K7N=00H0KgR?071iT01aNY00LgbA079mT@1cOY8207B0U00407B0T`1eP9<0
MX6E07R3U`80Mh6F00/0Mh:I07R3VP1iPi/0NH>K07Z5V`1kQY`0O8NK07j8W01oQi`0P8VN07n:W`02
07n:X@0407n;XP21S:<0PHfU086>Y@80Q92V00D0PhnU08JAY028TZD0RYFW08bFY`0208fGY`0;092H
Z02@V:T0TIZY09:KY`2BW:D0U9jV09JPYP2FX:L0UZ2V09VSZ02IXjT00P2JY:`0102KY:d0VjF_09^U
[P2LYjh209fW[`0609jX[`2OZJl0XZ^`0::[[@2S[:/0Y:j[0P2S[JX02`2R[:X0XZfZ0:6/Z@2R[JX0
Y;2/0::^Z`2R[ZX0X:ZW09nZY02MZJ40W:ZP0080UZBJ00/0IVa/04E7C01<Cdd0R9Mm05UOD01DFDX0
FV9B04aDB00oASh0=3Pd02X]:P0203Dj<@0:06=cF01TM5L0EV9:051IA01;DT40@dPk07>0I`2BYH@0
Rib008fNP`80RIQo0P2;Vh002`0a<Bh06aLJ02<Q7P0K6AL040d=00d92P0@3@`0=3PZ05]WC01PK5<0
BU910080:2/T00/092HO028R7`1JI580NX]`06imIP0b=c4051<F03a7>`0b>S00:C4V02H^800202H^
7`0602L_7P0Y<Qh0:3<N02Xc7`0^=R40<SPT6_oooolO0?n005<0003o0`3oP0000`000?l0oh000?n0
00070?n00080003o103oP0080000oa00oh000P000?l>0?n000oooooo000=ooooo`0604UEJ01;F6/0
Ce]a051MM01@G7D0DUig0P1DH7H02`1EHgH0EV=e05QUN01KIG/0G6Ek05UTO01JIGh0FfIn05aXO`1K
J7d0FfMm0080G6Qo00/0GFR005iZP01NJWl0GV^005m]P01QKWl0HVmm069`O`1TLX<0J7F706]jR`02
06ahR`0<06eiS01_NXd0L7^?071kS`1bOI00Lgn@07B0TP1cOY<0LgjD07AoU01eOiD0MX2F0P1fP9L0
1@1fPIP0MH2H07N1V@1hPiP0N8BH0080NXFJ00@0NhJJ07^5V@1mQih0OHVQ0P1mRJ80101lRJ40OX^Q
07n<XP21SZ@208B@YP0508>>YP24SjH0QY2V08NAY@2:UJL00P2=UjT02`2=UjP0SYRY092JZP2@VZT0
T9^X096LZ02CWZT0TijZ09>NZ@2EX:/0V::/0080VJ>^00`0V::^09ZT/02HXjl0VZFa09^V[`2MYjl0
WjV`0:2Y[`2RZJl0XZ^]0:>]Z`2T[ZX20:>]ZP0;0:>/ZP2R[:X0XZbZ0:6/ZP2Q[J/0XZj]0:>^Z`2Q
ZjP0XJ^V0:2[Y@2NZZD00P2KZZ@02`1[LWD0BD]A04E7AP1IH540CeA704]@A01OJEP0DU]?04A;A00j
@3d0;C4`0080<3Ha00`0EfMA05m^D`1FHTX0De]704eC@`11ASX0J7EO096UQ029VWd0SIb208bIP@2;
V80208nNQ00;0410>@0M5aP09B8O01/H5@0=2PP02@L500/92@15CSh0Q9Yh07jBM01fQfd00P0j?c/0
2`13BTD0CUI?06AbH@1cQ6d0Kh1Y04UBA@0K7A/0BEE3038g;@0[<RH09bdP00809B`N00H092dN02D_
7@0V<A`0:S<N02he800`=B4Joooooah0oh00E@000?lB0?n000P0003o203oP0030000o`D0oh000P00
0?l>0?n000oooooo000=ooooo`0404IBI`19EV`0CEYb04mJM080DEeg0P1CGgL0201DH7P0EV9h05MR
N@1II7X0FV=k05URO@1II7h0FFEm0P1IIG`03P1KIgd0FfMo05]WO`1LIh40GVV205aYP01MJWl0GV]n
05i[O@1PKGd0HFmn06EcPP1XMXD0JWR70P1ZNHT0201/NHX0KgZ;071kSP1`O900LGbA079mS`1bOXl0
LWf@0P1bO9800`1dOY80MGnD07EoU@0207EoU@0:07F0U`1fP9P0Mh6H07R2V@1iQ9T0NHFI07V5V01j
QIP0NhJJ07b7W080OHNM00D0OHVM07j;W`1nRih0Oh^P08:>X`02086>Y00408:?X`25TJ@0Qi>T08ZD
Y`80RiFY00X0RYFX08bHZ@2>VZX0SiZZ08jIZ@2?VZT0TIfZ096MZ@2AWJX0TYn[0`2DX:d0302DXJd0
Uj>^09RT[`2JYK00VZF_09bV[P2NZK00WjN^09nW[02QZJd0XJZ[0::/Z@80XjfZ00/0XZ^Y0:6ZZP2Q
ZZX0XJ^Z09n[Z@2OZZX0XJ^Z0::[Z@2PZZL0WjVV09fXY@0209f[Y00;06eeM`14Adh0@dM703i3?P12
Acl0@DLo06ajI`1CGU@0BE5<04=;AP0b=cD00P0a>3<03017DT80Dem:051JA`1?EDH0BDm403m2>`1X
MV<0T:B708RHP02<Vh@0S9V408^HPP80Sij500/0@44k01dH700U8R4071/H01<C3`0>3`/03Pl<02T_
9@1XNE`0Nhe]08>DM00205mXF00;06]fIP1aOVh0LH1^075oK@1aPFd0HFiL03m6?@1@FdX0=3``02/b
9P0W;Al00P0S:Q`01P0S:a`09RlM02H_700X<Ad0;CDP034h91[ooooo7@3oP01F0000o`D0oh0000<0
003o0?n0003oP0002P3oP0080000o`P0oh000`000?l20?n000D0003o3P3oP00?ooooo`003Oooool0
1017EfT0BU]^04iNL`1AGG@2055MM@80Demf00/0E5mh05APNP1EHG/0EV5i05MRN@1HHgT0FFEj05QU
N`1KIgd0G6Mo05aXO`0205]WO`0;05aXP@1NJH<0GFZ105i[O`1PKH00H6b0065]P01RL840IG>106Uh
Q01/NhH00P1]NhP02P1]NXX0KgZ;075kSP1aOI00LWb@075lT@1bOI40LWjA079lTP1cOY<407EoU00;
07N1UP1iPiP0N8:I07N1V01gPYT0N8FK07Z6VP1iQYP0NXJG07b8V@1lR9X00P1mRI/02`1nRid0OX^N
07n<WP1oS9l0PHfP082=X@21SZ80PhnS08BAXP27Tj@0RIBU0080RYFV00/0RiJW08bHZ@2<VJP0SIZW
08fIYP2=VZL0SYZW092LY`2AWZP0TZ2X09BQZP0209BPZ`0<09FQ[02FXJ`0V::^09VS[P2JY:h0W:J^
09fW[P2NZ:l0X:V^0:2Z[02QZZ/0XZ^Z0P2SZjX0102SZj/0Xjb^0::[[P2QZjd20:2/Z`050:6[Z`2P
ZZT0WjZW09jZY@2LZ:000P2N[:402`1fOgh0@D9;03a0@`0h?C/0?dHo04UAA`21U7T0GVYJ04M@AP15
CD@0<SHb0080<cP`00`0A4`n04]CA01?EdL0D5M804aAA@0l?ST0I6iO09BWRP2:VX00SIf308^KP`2:
VH42096RQP0504Q;@`0H4QD081hL01XJ600F5Q@00P0B50l0100F5a409RXN059LA022UG42075oIP0;
07J3K@1hQg40MhIa07F3K`1eQ700KgiZ06=`H01SLUh0>D0e02H[8@0V;Qh00P0S:aX01P0T;1T0:34L
02Tb7@0/=R00<3PT03<i9Q[ooooo7@3oP01F0000o`D0oh0000<0003o0?n0003oP0002`3oP0070000
o`X0oh002@000?l00`3oP000003o0?n0000:0?n000oooooo000=ooooo`0604UGJP1;Ffh0CUib04mM
LP1@G740DEeb0P1DH7H02P1EHGP0EV9j05EQN@1FHWP0EF5f05QTM`1HIWX0FFEk05YUO01MIgh305iX
P00;05iXPP1PJX<0H6b405m[PP1OJgl0H6b1069^PP1TLH<0J7F406aiQ01^O8D00P1_O8P00`1_Nh/0
L7^<075lSP02075lS`07075lT@1bOI<0L7fD079mU@1cOI@0LgjC07AoU00207F1UP0;07J0U@1gPYH0
N8>H07V3V@1hPYT0NHBK07R4V`1kR9/0NXJI07Z6VP1lR9/00P1mRY`02`1nRid0Oh^M082=WP21SIh0
PXjN08:>X022SJ40PhnS08>@XP24TJ80QiBT0080RYNT00/0S9RU08ZGY02;V:@0S9ZS08fKY02?VjH0
Si^W092LZ02AWJP0TZ2W09BRZ@0209FRZ`0309JQ[02GXJ`0VJ:]0080VJ>_00L0WJJ`09fV[P2OYjh0
X:V/0:2Z[02PZj/0XJ^/0080XZ^]00D0XZf/0:B/[@2RZjh0Xjb_0::/[@020::/[00409n[Z@2OZjP0
WjZV09fXX`80WZbQ00/0PHf504A7C00k@480=CLg03Xm>01@F4/0OHab06QdH018D4D0ATi3034e<002
02h_:P0<04E:?01=E4<0DEU7059JB@1?EDL0@48j05iVE`2EZ8T0RYZ008fMQ@2;Vh@0RYV20P2CYXT0
1@1HHE405Q4A01hL5`0H5Q<05ADC00804a@A00@051@A01XJ500e>b`0KWiO0P1GHD`02`1/NF00LX1W
07>0J@1dPF/0N8I`07J6L@1^Of/0KWmZ03Y1>00Y;R@0:c8S00809bhL00H09bhJ02Tb7@0[<al0;cHR
03@i9@0c>BHJoooooad0oh00EP000?l50?n000030000o`3oP000oh0000/0oh001`000?l:0?n00003
0000o`3oP000oh0000P0003o2`3oP00?ooooo`003Oooool01P19E6H0C5UZ04eKKP1<FFd0D5a`05=N
L`80E5mf00/0E61h05IQN@1FHWT0EV9h05IQM`1HI7T0FFEk05YVO01KIW`0GFMo05eWP00205eVO`0;
05eVP01NJ880H6Z305iYP@1NJX00H6f1069_PP1VLh40KGV306mjP`1`NX<00P1`NXH0301aNh/0LWb?
075lT@1bOI80LgjC079mT`1cOiD0LWjE07=nU`1bO9D0LWfE07EnU`80MX2G00<0MGnE07EoT`1fP9<0
0P1gPID01P1iPiP0NHBL07^5W01kQY/0NXFK07f6WP80OHRM00/0OXZL07n;W@20S9`0PXfL08>?W022
SI/0PhfL08B?WP23T:00Q96R08NDY00208ZFY00;08ZFX`2;V:80S9RS08bIX`2=VZ<0SYZT092LY@2@
W:H0T9bW092MYP2AWjL00P2DXJT02P2FX:T0Uj6Z09VQZ`2IXZ`0Vj>]09fU[`2NYZl0WJJ^09fW[@2O
ZJ`409jZZ@0309n[Z02OZZL0XJ^W0080XZ^X00H0XjbX0:>/Y`2R[JH0X:bU09jZY02MZ:8209j]XP0;
08JCR`17BTl0@DE503Hg=`0h>CH0DUQ<06QdG`1QJeT0EEi?0457?`0_<Rl00P0/;BT03010@cH0CE=1
059IA@1CFTL0CUA404I:?01JHDl0UZN708bKP@2=VhD0Ri^608ZJQ080SZ6700/0FfAE01TE5P0Q81/0
7Q/H01`J600E51804Q4>018B3P0F5@l0=S`Z04aG?P0203Dh:P0;03/n<@1[Mel0KW]U075oJ01hR700
NH]`07>6K01`PFL0=C/`02`a9P0/<B@00P0W;Al01P0V;1`0:C0N02Xa7P0/<R00<3HT03<h9a[ooooo
7@3oP01F0000oa<0oh001`000?l>0?n000L0003o2`3oP00?ooooo`003Oooool01P17DFL0BEEY04aI
K01?Ffh0DE]a05ANMP<0Deij00X0Demj05AQN@1EHWP0EV=i05MTNP1HIG/0FFIl05YWO@1MJ800G6Mo
0P1LIGl02`1KIGl0GFJ005mXP@1NJ840G6R1061/P@1SL880J7F206mkQ@1`NhH0L7Z70080LG^900`0
LG^;07=mS`1bO940LgjB07AoT`1bOY80LgjC079mT`1bO9@0LgbE07=mUP1dOYH207AoU@0;07AnU01f
Oi@0MH2B07N2U01gPY<0Mh:D07R4V01hPiT0NX>G07f5VP1mQI`00P1mQY`01P1mR9`0OXVK07n:VP21
SI/0PhjK08F>W080QHnN00<0QY2O08F?X@28TZ800P2:UJ800`2:UZ40RiNQ08bGXP0208fHXP0608fI
X`2?W:<0T9bS09:NY02AWZD0TInU0P2BX:H0302EXJL0Uj2V09RPY`2HXJL0VZ>Z09bTZ`2LYJ`0VjB/
09bV[02MZ:`0WZVY09jZZ@80WZZZ00/0WjZZ0:2[Z02PZjL0XJ^T0:2ZXP2QZj<0XZ^S0:6/XP2PZj40
WJVO09^XWP0209j]X@0;08VES@18BU00@TA703He=`0h>ST0F69E05URE01JI5<0E5i?04eFB@0i?CT0
0P0`<bl0300nA3L0BeA2055IAP1AF4D0Be0n04I:>`1BFDP0Sj:108fMP02<W8@0SIf608bNQP80Sj:8
00/0G6EG01TE600Q7ad07A/I01XJ5`0D5140418=014B300B4P/0=3/Y04eI?@0202la8@0;01`H4`1X
Le`0M8=[06moJ`1fR740NHab07J:K@1cQfP0=Sd`02T]9@0Y;B<00P0W:R401P0V:Qh0:2dN02X`7@0/
<Ad0;c@P034f91[ooooo703oP01G0000oa<0oh001`000?l?0?n000H0003o2`3oP00?ooooo`003Ooo
ool01P1:E6H0CEMZ04mJKP1?FW40D5]c055LM@80DUeh00@0E5mk05AQN`1CGgT0EF5j0P1FHg/01@1G
I7/0F6Ek05UUO01KIgh0FfIn0080FfJ000/0FfF205eWP`1NJ8<0GFR305eYPP1QKH@0IG6506UeQ@1^
NHL0LWf:075lRP02075kR`05071kS01aOHh0LGf?07=nTP1bOI<00`1aOI80101aOI<0LgjE07=nUP1e
P9H207F1UP0;07F1U@1ePI<0MX6B07N3T`1hQ9@0N8>E07V3V@1iPi/0Nh>K07j6V`1mQIX00P1nQY/0
2`1oQi/0OhVL082<W021SY/0PHjJ08>?W024Sih0QXnP08N@XP27T:40R9:Q0080RY>O00/0RYJP08^G
X02;Uil0RiNO08bIX02=Vj40SIbP08jLX@2@WZ<0TInU09:PZ002096OY`0<09FRZ02GXZL0V::W09VR
Z02IXjX0VZB[09^U[02LYjd0W:R[09bYZP2MZZ/0WZZZ0P2NZJP02`2PZjT0XZ^X0::[Y@2Q[:@0X:bT
0:2]Y02NZj@0WZ^S09n/XP2MZZ00WJ^N0080WJfO00/0SI^@04Y=DP10A4L0=cPj03Lg>01@ET`0CUA9
05END01<ETP0C5M904E>@`0203Dk=00<0417>P19Dd40CEM304mHA01;DD00@D@h0454>@2;WGh0S9j1
08ZKP@2;W8@0QYV20P2:WX@02`1QK5`07AXN028P800M7A`06QXG01LG4`0F5Q4051D>01@F3P0W:ah0
GF];0080?T8^00/0928L06IcG@1dQFh0KWi^07B5M01iS7D0NXec07R;K`0oAS`0:BdW030b:00202d^
900602X/8@0Z;Qh0:c0M02dc7P0`=R40<cLS6_oooolL0?n005L0003o4`3oP0070000o`l0oh001P00
0?l;0?n000oooooo000=ooooo`0604QAH`1<EFP0D5Y_051KLP1AFgD0DEag0P1BG7P02`1DGWX0E5mj
05EQO01FHW/0EV=k05ITN`1HI7/0FFEl05UVO01KIgh0FfMm0080FVEo00/0FfJ205eWP`1OJ8@0GfV4
061ZQ01SKXH0Ig:606YdQ`1_NXX0Lgj<07=oS00207=nS00:079mS@1aOHd0L7f?075mT@1cOY80LWjB
071mT01_O900LGnB079nT`80M7nE0P1cOi<02P1ePY<0MH6B07F1TP1fPY80Mh>E07V3V@1jPi`0NX>N
07f3WP1oQYd30827W0080829W020RY`0P8ZL082<V`20SY/0PXnL08B?V`24SY/208N@WP0>08RBWP2:
UJ00RYFP08^FX@2<V:80RiRP08ZGW@2<VId0SIbP08jKX@2?Vj<0SibU096NY`2BWjT2096OZ00409>Q
Z@2DXZT0V:BZ09VTZ`80V:>[00H0VJB/09^V[@2LZ:/0W:RY09jZZP2NZJP209jYY`0;0:2[YP2QZj<0
XZbS0::/X`2R[J<0XJfT09n/X`2NZj80WJ^Q09j[X02MZid00P2M[9`02`2BXI@0C4iB03i1AP0f>3d0
<C4c04mEBP1:CdD0BDi504I>@P1;ETP0Ae930080=3/`00`0>T<e04QC?P1:ECh0BeHm04M>>@0k?C00
<c@[082AM02=X880RY^108ZLQ@25V8<208RLQ@0;06]jJ@0O7b<092<S024P7P0N7QP06a/D01XJ4`0G
6A406AXC020T6P0_=BL00P0_<RP02`10B3X0LH=X07F7KP1aPVh0M8Ea07V<M@1lSWH0OHme04Q@A@0[
;BP0=3L]0080;c4V00H0:bdR02T/7P0X;Ad0;34P02ld8`0a=bDJoooooa`0oh00E`000?lC0?n000P0
003o3@3oP0070000o`/0oh003oooool000gooooo00H0BE5T04]CI`1>F6`0CeU`051JL`1AFgH2055K
M`0;05=MNP1FHG`0EV9m05IRO@1EHW/0EV9l05QTO01IIW`0FVIm05YUO01KJ7d00P1LJ7h02`1NJH00
H6V1061XP01SJh@0I6b506A^Q@1WLXH0J7>706ehRP1bOXd0MX:?0080N8B@00`0MX6?07B0T01dOi80
LgnA07=oTP1cOI80L7^A079lTP1cOi<0LWnB079nTP1dP9@207=oTP0;07F0TP1dP940MH2B07N3U01f
PY@0Mh:G07R2V@1jPi/0O8BM07j6WP1oR9h00P1oR9d0201oRId0PH^O086<W`21SIl0P8fO086>W@24
T9d0QI2M0P27TIl03P28TZ00RIBR08VDXP2:UZ<0RiNT08^HX`2<V:80S9VP08jKXP2?Vj<0T9^U096L
Z02BWZX0Tin[0P2CX:/0302EX:`0UJ6[09NS[02HY:`0VZB/09ZUZ`2IY:X0VZF[09bXZ`2MZJT0WjZY
0:2[Z080XZbW00/0XZ^V0::[X`2PZj40XZbP0:>^X@2Q[J40XJfR0::]XP2PZj40X:^R0:2/X00209n[
W00;09ZXV01EEeT0@D9603/n@00b<S@0BDi404iCAP19CT<0B4i304mJB`13C3l00P0a=R`0300e>bh0
DEi504iJ@@1=ESh0B4hi03i1<`0`;bX0N8I^08nQQ@2:Vh<0SIj808VJQ@80Rif700/0Ohml02TY;@0R
82808AlM024P600N7A<06AT>01@E300F5`h082@H024T6P0201lP6P0;024S7P1/OF80MXU]0761JP1h
R700OHed07j@MP24UGP0EUi>02l`:@0h>S400P0b=Rh01P0]<BT0:RdT02L/7`0/<B40;cDU038g:1[o
oooo7@3oP01F0000oa<0oh0020000?l=0?n000L0003o2`3oP00?ooooo`003Oooool01P17DFD0BE=X
04aHJ`1>FFd0CeY`051JL`80DE]f00X0DUah05=MN@1EH7/0EV5l05EQN`1FHW/0F6Ak05QUN`1IIGX0
FFIj0`1JIgX02`1KIg`0GFQm05iYO@1RK880Hff306A`P`1VLhD0IW>406UeQP1`OX`0MXF@0080N8NC
00`0MhBB07F3TP1dP980LgnC079nU01cOID0LGfD075lT`1aOi@0L7jC071nTP1bOY82079nT@<0MH2A
00P0Mh>A07R5TP1hQ9@0N8>F07Z5V@1mQY/0NXBK07^6WP80NXBM00/0NhJM07j9X020RYl0P8ZP086:
X023S:40Q8jP08B?X026Sj00QI2N08FAW`0208JBX00;08NCX@28U:40RYJS08bHY@2=VZ@0SI^U08nL
YP2@WJH0TIfX09:MZP2BWZ/00P2CWj/0302EX:d0UZ2/09FP[02HXjh0VZB^09ZU[P2JYJ`0VZJ/09bX
Z`2MZJT0X:ZX0:6[Z080XZZX00/0XZ^X0::[Y@2QZj<0XJ^S0:2/XP2O[:<0XJbT0::]Y@2P[:@0Wj^T
09n[X`0209bZWP0;09b/W01NHV40A4E904E6AP0f=CL0?d4l04M;@01<DT@0CEI7059MC@1;ETP00P0f
?S@0300g?c40FVU=05MUBP1@Fd@0CEA004I:?00f=c<0L7aZ09BWSP2:VH@0S9^708VHQP80S9^800/0
QI>002`Z<@0Q7R<08b8O020P5`0M7Q806a/>01<D2P0C5@/07b8G024V700202<Y7P0;01DE4@1NK5@0
MXQ[06enIP1hR6l0OXmd086BM`21TgH0DeY;03@e;`0j?C@00P0f>c001P0`=BT0:c0S02X^800^<R40
<cLV03<f9Q[ooooo7@3oP01F0000oa<0oh0020000?l>0?n000H0003o2`3oP00?ooooo`003Oooool0
1P16CfD0BE=Z04aHKP1=FFl0CUUa051JL`80DEae00/0Deeg05=NM`1EH7T0EfAk05IRNP1GI7/0FFEk
05QUNP1HI7T0FFIj05YWNP0205]WNP0;05YWN`1LJ7`0GVUn061ZP@1TKhH0IG:606IdP`1VM840IgF3
06akQ`1aPXd00P1dQI40301dQ940Lh6@079oS`1aOI00LGbC079nU@1bOYH0L7fE079oUP1bOiD0LWjE
07=oU080LgnC00/0MH6B07J2T@1gQ940MhBA07V6T@1hQ900N8>A07Z5U@1lQYP0NhJJ07^8W@0207^6
WP0407b8X@1nRJ80OXVQ07n:X@80PhbT00D0Q8fT08J?Y026Sj<0QY6Q08JBX00208NCX@0:08REX`2:
UZ<0RiNT08^HY02<VJH0RYRV08ZIY@2=VjD0SifW096MZ@<0TIj[00`0TYj[09>OZ`2EXJd0UZ:^09RT
/02JYK00VZJ`09bW/02LYZd0W:N[09nYZ`2NZ:X209nYZ@0;0:2ZZ@2RZjP0XjbY0::[ZP2Q[:T0X:bY
0:6/Z@2P[:P0Wj^X0:2[Z@2NZZH00P2JZ:402`2KZil0IFaZ0452A`12AD<0=3@d03i1?015Bd80CEI:
055LCP1CGe00CU]<0080?DXl00`0>THe05Y/D01IJ4`0Df1604aF@012AcX0>S/g07F3K`2EZ8d0Ri^6
08^JR028UXD208^JQP0;08BCP00^:c8081/S02<Q8@0N7QL06QX@01PI3@0D5P/06A/@02L/8@0_=b`0
0P0^=BX02`0Y;RD0G6YD07>5K01^OfP0M8E]07^<L`1oT7L0P9=h04mHC00e>C80>T4e0080=C/]00H0
<3HV02db8P0[<1l0;c@R03<f9@0c=bDJoooooa/0oh00F0000?l=0?n000030000o`3oP000oh0000<0
oh0020000?l>0?n000H0003o2`3oP00?ooooo`003Oooool01P17DFH0BEAZ04]FK@1=Eg00CeYc055L
MP80DUag00L0Deeh05ANN@1EGgT0EV1h05IQN@1FHGX0Ef9l0080F6An00l0F6Em05UVO01JIg`0FVMl
05YUO01LIgl0GVV105m[P`1TKhL0IG:806IdQ`1VM8H0IgF606QfQ`1[NXT00P1^OX`0301`Ohl0LWn@
079oT@1bOY80LWbC075lU01bOI@0LGbE07=nUP1dOIL0LWbF07=nUP80LgnE00/0M82E07F1T`1hQI<0
NHFC07R4T`1gQ980Mh>B07R4U01iQIH0NhNI07^8W00207b8W@0407b8WP1kQil0O8JP07j9X@80PH^S
00D0PhbT08J?Y@26Sj<0Qi2P08RCX00208VCX@0:08VDX@28U:40RIFS08VEXP2:UZ40RYJR08^GY02>
VJD0T9ZV09:MZ0<0TifY00`0TYfY09>OZ@2FXJX0UZ2[09NP[P2HXZl0VJ>a09^U/P2MY[00WZR`09nY
[`2NZ:d209jYZ`0;0:2ZZP2RZj/0XZb/0::/Z`2P[:X0X:bX09nZY`2NZJH0WZZW09j[Y`2LZJ@00P2I
Yil02`2L[Il0LG]c03`n@00m@Cd0;c4_04=9@01;E4T0C5I;05ESE01?GDl0?dXn0080=D0d00`0<S/_
05U[D01JJdh0DV1604]G@00g?C00<cD_07J6K@2EZh`0RYZ508^IR02:UhL208^JR00;08>AP00c<SH0
6aHM01lL7`0K6QP06aTD01XI4`0G610071hD02dc9P14Ccd00P0f?c802`1:EdL0H71L06j0J@1aPf/0
LhE_07J8M01jS7H0Nhig059ND@0g?CD0>D0c0080=3`^00H0<3HV02hd8P0/<R80;C<R038h9P0a=bDJ
oooooa/0oh00F@000?l<0?n000030000o`3oP000oh0000<0oh0020000?l=0?n000L0003o2`3oP00?
ooooo`003Oooool01P19DfL0BUI[04aHKP1>Efl0CeUb059MMP80E5ih00X0Deai05EMN`1FGgX0F61i
05MQN@1HH7T0Ef1j05URO@1HHWd0F6An0`1IIGl02`1KIX40GFN305iXQ@1OJXH0HVj906AaRP1XMH`0
J7J<06UfS@1YMX/0JgR;0080KW^=00P0L7b?075nTP1`OI80LGfA075lT01aNi80LWbC07=lUP<0M7fI
00h0LgfI07AmU`1dOIL0MWnG07J0UP1eP9@0Mh:E07J1U@1gPiH0N8BF07V4U`1iQIL0NXJI07^8V`80
O8RM0P1nRYl02@1nRJ00OhZR07n:X@20Rj40PXfQ08>?X025Sj00Qi6N08RAWP0208VDX00;08VDX@28
Tj00RIBQ08ZFXP2;UZ40S9JR08jHXP2?VZ<0TI^T09BMY@2DW:H00P2EWJL0302EWZX0U9j[09BPZP2E
X:/0V::]09VQ[P2JY;00VjBb09^T/02NZ;40WjV`09jZ[P80WZZ/00/0WjV[0:6[Z`2PZZX0X:ZX0:2[
Z@2R[ZT0X:fV09n/Y@2OZj@0Wj^S09fZX@0209^ZW@0;09b]W01cOW<0>cdn03e2?P0`<C00@dPn04iH
BP1AG4d0Df1@0459?`0c>S400P0X;bP0300W;RH0FFYA05]_D`19FD<0BEI0034f:P0];bP0L7eW09FY
R`2:VH<0SI^808fIR080S9^900/0Q9B303Hg>P0H4aX081dN01hL600O7AL071/F01HF4P0H6140;c@W
05m]E00205UUD@0;04YDA`1HIEL0LHE_0763KP1bQ6l0LH9_06j0K01bQfh0Df1>03Dj<00h?S000P0e
>bh01P0a=bT0;cDU02hd900^=B@0<STV034h91[ooooo6`3oP01I0000o`d0oh0000<0003o0?n0003o
P0000P3oP0080000o`h0oh001P000?l;0?n000oooooo000=ooooo`0604UCI`1:EV/0C5Q^04iGK`1?
FG80DUef0P1DGWP02P1CG7T0EEek05IONP1HH7T0Ef5i05QPN@1GH7X0FF9m05QRO@1HI7h305UUO`0;
05]VP@1MIh<0GVR505mZQP1RKXT0I76:06QeS01XMX`0JGJ=06UfR`1[N8/00P1^Nhd0201`O8l0LGjB
071mTP1aOI40LGb@075kTP1bO9<0LgbF0`1dOIT03P1cOIT0M7fG07AmU`1fOiL0MX2F07F0U01gPYD0
MX6E07N3UP1hQ9H0NHBG07V5U`1jQYT0NhRK0P1lR9d207j:W`0907j9X01oRZ80OhZQ082;X@22SJ40
PhnP08F?X027TIh0R96N0080RIBP00/0RIBQ08RCX029U:40RYJR08^FX@2<UZ80SYRR08nJX`2AVj@0
U9fU09BLYP0209FMY`0<09FNZP2DWZ/0U:2Z09FPZ`2HXZd0VJ6^09ZT/02KY;80VjB`09jX/@2OZK00
WZZ^0P2NZZ`02`2OZJ/0XJ^[0:2ZZP2PZZP0X:^Y0::^Z@2P[JH0WjbU09n[Y02OZj<0WJZQ0080VjZM
00/0W:fL07=nL`0k?Ch0?D8n030a<013B3h0CUQ:055LC@1CH500@DTo03<j<@0202P_:00<02L^9P1I
JU40FfmC04UI@`19ET00<CHZ02d_:01`OFL0UJV;08ZIP`2=VhP0SIV80P2<VhT02`24U8<0=SLj01PC
6P0P7Ah07Q`H01lM5`0L6aH05QHB01PH4@0_=2L0GfeD0080FFEA00/0BUA705QUE`1aQFl0LH=^07:4
K`1aPVl0KX1/07:7KP1CH4h0=CX`03Pn<00203Dk;P06034g:@0_=BD0;S@T02he900b>BH0<CPT6_oo
oolK0?n005T0003o3@3oP0000`000?l0oh000?n000020?n000P0003o3P3oP0060000o`/0oh003ooo
ool000gooooo00H0Ae5X04QEK@1<FW40CEY_04iJL01?FW42051KL`0;05=MM`1DGWP0Deef05EOMP1F
HGL0Ef9h05MQN01IHg/0FFAl05UUO@1JIX400P1IIH002`1KIH40G6N405iXQP1PJhP0Hfj:06AaR`1W
M8d0JGJ?06UfSP1YMXd0JgN<0080KGZ=00`0Kg^>06mmT@1_O980L7bA071lS`1bOY80LWfC079mU@1c
OIT0LWbH07=mV01dOiP207=mU`0;07EnUP1gP9D0M7jD07EoU01eP9@0Mh:E07R6V01hQIP0NhJK07b7
W@1mR9h00P1kR9h00`1nRYl0OhbO07j;WP0207n;X006082<W`20SYl0PHjO08B?W`26T9h0R96O0P28
TZ0208VEX00908VEXP2;V:@0S9ZU08bIY02=VZ<0SibS092LX`2BWJ<0TijU0080U9nX00`0U9j[09>O
[02DXJd0UJ6^09NR[`2HXjl0VJF_09ZS/02JY;00WJR`09fX[P2MZZd209jZ[P0;0:6[[`2QZZh0XJZ/
0:2ZZP2OZjT0X:bY0:2]Z02O[JH0X:bU09n/X`2NZj400P2KZid02`2K[9X0M81d03m4@`12Ad<0=STg
0417?P1?FT`0D5a>05=OD@10BCl0>40e0080<CT^00`0;C@Y04eKA@1FId`0AU8n04QE@00c>B`0;c4Z
06eiI@2BXhP0RIR108fMQ`2?WXX208jMR@0;08FFPP0g>C/06QLM028P8@0L6aT06aXF01TI5@0E5Q80
6QhG02Ta901`QFD00P1[OV802`1WN6<0ADi707^AN@1bR7<0HWAR03m;@P11CT<0Jh5U05MVCP0a=bX0
>3h^0080=S/[00H0<cPX034g9@0a=b@0<cTV03@l9`0b>bHJoooooa/0oh00F@000?lB0?n000P0003o
2@3oP0040000o`040?n000000?l0003o0000o`80oh0000<0003o0?n0003oP0002@3oP00?ooooo`00
3Oooool01P15DfP0AUE[04QHKP19FFl0BeY^04eJL080Ceab00/0DEed055NM@1BGW@0Df1d05APM01E
HGD0EV9h05MSNP1GI7`0F6En05YWP@0205QVP@0705YVP@1JIh40G6R205iYQ01RKhT0I7::06EcR`02
06MeS00@06IcRP1ZMh/0K7V;06aiR`1^O8d0KG^>071mT@1aOI<0KgfC07:0U@1bOY@0L7fD071mUP1`
O9H0L7fE075mU080LWjD00/0LgfD07F0U01ePID0LgnC07=oT01ePi<0MXFG07N5V01hQYX0NXNM07b9
W`0207^7W`0;07Z7WP1nRYl0OX^M07j;W@1nRih0OX^O07n=W`20SIh0PhjO08J@X025T:000P25TZ00
2`26U:40QYFQ08NFX`29V:@0RIVT08^JY@2<VZD0SI^S092KY02@W:@0TIjV0080TInX00`0TZ2/09:P
[@2CXJh0U::`09BQ[`2FXjh0V:F^09VU[P2KYjh0VjR^09ZX[@2JZ:`209bXZ`0609jZ[@2OZZh0X:^]
09n[Z`2OZjX0WZ^Y0P2NZjP00`2MZjL0W:^T09b[X@0209RXW`0;09Z/WP1kRH00A4Y<03m4A@0i?3h0
>d4o04I?A`1;F4d0EF=D04]GB@0lAc/00P0g?cD0300d>2h0>3l`045;=`0j@S00?dPf03Pn<@0_<2/0
H6UI09:TR028UX80S9b908jOSP80SIn<00/0QiV703Tm?`0D41T07A`N01LE5P0E51805AHA018D400U
:R80;cL[05i`EP0206n5I`0;06=dG`15CTL0NXii07J<MP1IJE/05QXM01XN7@0lASH0BE@o03@i:`0g
?2h00P0f>b/01P0d>RP0<SLU03@j9@0f>bL0=SdX03@k:1[ooooo6`3oP0030000o`030?n000000?l0
003o05<0003o4`3oP0070000o`T0oh0010000?l00`3oP000003o0000o`0?0?n000oooooo000=oooo
o`0604QFIP19EfX0BeU`04YHL@1<FG80C5Yc0P1>Fg800`1@G7@0D5if059NM@02059NL`0605=NL`1E
HGH0EV9i05MTO01GI7d0FFEo0P1IIH002`1HIGl0FFIn05UWO@1LJGl0H6j406=aQP1SLXL0IGB906Me
R`1XMX/0JWN;0080JgN<0P1]Nhh02P1`OI40LGjC071nU01_OI<0L7jB06imT01^O940KgfB075nT`1a
OY820760TP0;07:0T`1dPI@0Lh2E07:0U01bP980M8BD07J5U@1gQYT0MhJK07R5W01hQY/00P1kQid0
1@1jQid0O8RN07f9W`1lRIh0OH^N0080OHZM00@0OhbM086>W@23Sil0PhnP0P24TJ4208BCX@0908FE
XP27Uj<0RIRT08ZJY`2=VZP0SY^V092KYP2?VjL0TIfZ0080T9j[00X0TIj]092P[P2@X:h0TZ6^09>R
[@2CXjd0Tj>/09JT[02HYjd0VJR]0P2JZJd209b[[@0;09bY[02NZJd0WjZ]09jZZ`2NZZP0WZ^X09jZ
Y`2MZjL0VjZW09ZZY@2JZZ@00P2HZ:402`2JZj40NXJ204]?E00l@4H0ADa:04I=A`10Ad40D5a@05ER
D`18DT@0=S`c0080<cL_00`0;c<Y02/`900[<240:c0O034f9@0h?Bd0<C<Z069/F@2@XXD0QiF108ZI
Q`2:W8X208VLR`0;08:DQ@0a=3T05Q<L01XI7@0E51@0518?01DC3@0C4Ph09b/R030c:@1OK5D00P1g
RVh02`1XMf<0Hg1S0720L@1gRgT0DV1D00h@5@0F5aX04Q4A02DX800_=2H0<SHY0080<cTY00H0<STW
038h9P0d>RH0=S`Y03Ll;00e>B/Joooooa/0oh00F@000?lC0?n000L0003o2P3oP0030000o`030?n0
00000?l0003o00l0oh003oooool000gooooo00H0Ae5S04UDJ@1;EW00C5Mc04aFL`1;EW4204eIL`0;
04mKM@1@G7D0DUef05=OMP1CGWD0DUid05=OMP1DGgL0E65j05ESO01HI7h00P1II8002`1HI7l0FFIo
05UWOP1KJgl0Gff2065`PP1TLhD0I7>606MeR01XMXX0JGN;0080JWN;00`0KW^>075oT@1cP9<0Lh2E
071nU01^OI<0KWfA06elS`1^O8l0L7b@075lT01aOI4207>0T`0;07:1T`1aP980LX2D07>0U@1dPID0
MX>E07N5UP1hQIT0NHFL07R3V`1hQ9T00P1jQiX02`1lR9`0OHVM07j:WP1nRIh0OHVN07n;WP20SIh0
P8fM086?W`22T:00PY2Q0080Pi6R00/0PY6Q08>CX@25U:80QIBR08NEX`2:V:H0SI^V08jLYP2?VjH0
T9bX08nLZP0208nM[00<08nN[P2>W[00Sin`092O[P2DXjh0UJB/09JS[02EXj`0V:J]09VX[@2LZJh0
WJV]0P2NZZd209fY[00909fX[02NZJ`0WZVY09jZY`2MZZL0WJZX09bZY`2JZJD0VJVS0080UjRP00/0
VZ^R07^6P`19C5<0@4A80416A00m@c`0<SH_04QB@`1JIe<0Dei<03Y0=`02038g<00<02lc:`0^<bH0
:S0P02H[6P0Z;A/0=cTW03@d:P1PJEL0UZV;08ZJPP2<WHL0Rib70P28VHD02`23UH80=3Pi01DC6P0K
6Q`061LG01LG500G5Q805A@@020Q6@0X:Al0HFeC0080MXMZ00/0KgiV07>2K01bPVh0NXeh05QTF@0A
4AT04@hD00l:3@0P7QP0;c8U034d9002038f900603@j9P0d>BH0=3XV03Dl9`0f?B/0=S`^6_oooolK
0?n005T0003o4`3oP0070000o`X0oh001P000?l?0?n000oooooo000=ooooo`0404I?I019DVT0BeE_
04aELP@0CEIc00/0D5Yf04mKMP1AGGH0Deif05=OMP1CGWH0DUeg05=ON@1DHG/0Df5k05QTO`0205QU
O`0;05UVO`1IIX00FFJ005]XP01NJh00H6eo069`PP1ULhD0IWB506MeQ@1XMXL00P1`Ohh02@1kRYP0
OXfM07b:W01fPiT0L7fF071mU@1^OI<0KGbB06mlT@02075lT@0407=mTP1cOi<0LgnC07=oTP80Lh2A
00P0M82D07F1U01gPID0Mh:E07N3U@1hQ9L0NHBH07V5V@80NXJJ00/0NhNL07b8W@1lR9l0OHRO07n:
WP1oRih0P8bL082=W@22SZ00PhjQ08B?X@0208FAXP<0QI:R00P0QYBS08RFX`2;Uj<0SIVS08fKY02>
VjD0SibW096MZP80T9f/00`0Sif^08nM/@2@Wk40TZ2_09FR[P2EXjl0UZB_09NU[P2HYJh0VZN]09bX
[@2NZ:`209nYZ`0609jYZ@2NZZP0WZVY09jXZ`2NZ:X0WJVY0P2NZZT00`2MZZT0W:ZV09ZZY00209RX
X00;09VZW`25ThX0ADQ=0415AP0d>3P0;S8`02@U8`0k@SL0GfeG05UUD01;ETH00P0oASX02@0h?C80
<cP/02hd9P0]<R<0CePo0454=00g>340DeU>09BWS00208ZLQ@0>08^LQP28V880R9R208NFP@15B4D0
5Q8J020O800M7Q/071hI01XK5`0G5a<05QH@02@W6P1GHTP207^>J`0;0721I@1dQ6/0MXE]07N7L@1e
Q740=STi01`J7@0O71`08R0J030a8`0a<b800P0c=b@01P0c>2D0=3XV03Dk9`0e?2P0>3h/03Ll;A[o
oooo703oP01H0000oa<0oh001`000?l:0?n000L0003o3P3oP00?ooooo`003Oooool01P18D6<0BU=Y
04]EK`1<EG40CEIe04mHM`80CeQe00/0Ce]f055LM`1AG7H0Deef05=NM`1CGWP0Df1j05EQO@1FHGh0
Ef9o05QUP00205MTP00;05QVO`1IIWl0EfAn05YWP@1LJ800H6b1061]P@1SL8@0IG:606IdQP1/NXd0
0P1iRY/02`22U:<0QYNW082>X`1hQ9d0LGjH071lU01_O940KG^@06ikT01^Nhl0Kgb@00<0LgjB00/0
LgnA07B0T`1dP9<0MH2D07B0U01fPID0MX:E07N3U@1iQIL0NHFH07^8V`0207^7W00;07^8W01lR9`0
O8RO07f8X@1mRZ80OX^Q07j;WP20SIl0PHfP08B?X@24Sj<00P25Sj<02`26TJ80R9>R08RCX@29U:00
RYJQ08bJX`2=VJ80S9VS08fKY02?W:H0TIfY0080T9b[00`0Si^/096M[`2BWk00U:6_09FQ[@2FXjd0
UjB]09RU[@2IYZd0VZN]09bXZP2LZ:T209jYZP0;09nZY`2NZZD0WZZW09nZZP2OZZ`0WZZ/09j[[02M
ZjX0WJ^X09b[Y@2LZj@00P2JZj802`2JZil0Sj2B04M;C`0k?d00;c4b02X];@0T9BH0=3Td05i/F@1H
IE80EfAB0080CUY900`0?DDg03Dk;P0^<bL0;30V06akGP13B3X0>S`f04a@B02>WhH0SYn808bMQ`2>
X8T208ZKP`0;08VJP01AETh06aDL02<Q8`0M71`071/J01PI5`0G5aD05aPC028U6`1@G4D00P1oU740
2`1bPfP0M8E/07J6K`1eQW00MHQa06emJ01EHE40FFIA04UD@@0d>2X0>ch[0080>3/Y00H0<CDU038g
9P0c>RT0=3`Z03Lo;@0g?RhJoooooah0oh00EP000?l?0?n000040000o`3oP000oh000?n000L0003o
2P3oP0080000o`d0oh003oooool000gooooo00H0A4iM04M@I01:DV/0BU=_04aEM01>EWH204iHMP0;
04iIM`1@FgP0D5]h051LN01AGGP0D5ai055LN@1DH7/0E5ml05MRO`1II8000`1HIGl02P1HIWl0F6In
05]XP@1MJH<0GVZ305m/Q01SL8L0I72806I`R@1_OI<207b<X080P96T00X0O8^P07N3VP1dP9P0LWfD
075lT01_Nhh0KWZ>06ajSP1/NXl0Kgb@0P1aOI002`1bOI40LWjB07=oU@1eP9L0MX6H07F1U`1gPiL0
MX:G07J1U`1fPYP0N8BI0080NHFL00@0NHJM07^8WP1lR9h0O8VO0P1mRJ401@1oRil0OhfP082=X022
SYl0PhfP0080QI2S0P27T:D02@27TJ<0R9>Q08RCX029UZ80RYNR08^GX@2<V:80SY^T08nKYP0208jJ
Y`0:08nKZP2?Vj/0TIf]09>O[@2CWjX0TYnY09>QZ@2DXjX0V:J[09VWZP80VJNY0P2KZJT02`2MZJL0
WJVV09bYYP2NZjP0Wj^Z09fYZ@2KZZT0Vj^X09ZZYP2JZZ80VZZQ0080VJVN00/0VJ^L092ST`1>EeH0
?D91034d<P0/;B`0:b/[03@g<P1KJ5H0F6ED05IRDP02059NC00<04E??`0h@340;cHX02``900d>2X0
<c@Y03Dd;P19Bd@0T::8096RR`2>WhT0T::;0P2;WHH02`2;W8<0G6AG01XD6P0T8B807Q/L01XI600G
5QD05aLD01XI5P0Q81/0ATdm0080Q9Uf00/0M8I/07B6L01dQG<0M8Ab07>5K`1eRFl0MHU^07J9K01U
Le/0>Cd`03m3<@0203Pk:`0602lc9@0^<bD0<CLX03<k:00f?bX0=3/X6_oooolO0?n005D0003o4`3o
P0070000o`X0oh002`000?l:0?n000oooooo000=ooooo`0504A?G@17DF<0BUEZ04]EL01=EgD00`1<
EgD02`1;EgD0C5Ug04iKN@1>FgP0Ceeh04iLM`1AGGP0DUii05AONP1EHG/0EfAm0080EVAk00/0EF=l
05IUOP1GIGl0F6N205YXP`1KJ8<0GVZ4069^Q`1SKhP0IG2:06]fT@0207F1VP0907R6WP1hQid0M8>H
07:0U@1aOI@0L7^B06mkT@1_Ni80KGZA0080KGZ@00<0KWZ@071lT@1`O9400P1bOI<02@1cOi@0M7nF
07AoV01eP9P0MH2G07B0V01ePIT0MhBK07R4V`0207R5V`0;07R7WP1jRJ00NhVP07Z9X@1kRJ00O8ZO
07j<W@1oSId0P8fN08:?W`24Sj000P26T:@02`27T:H0QI2W08F@YP26TjH0Qi>T08NDY028UjD0RINU
08VHY02;VjD0S9ZW0080S9ZX00`0S9ZY08jJZP2@Vj/0TYj/09:OZ`2BX:X0T:6Y096RZP2CXjT0UJJX
09NVZ@2IYjX209^YZP0;09bYZ02KZ:H0W:RW09jZY`2N[:T0W:^Y09ZZY`2KZjL0Vj^U09VYXP2IZIl0
0P2GZI`02`2GZIT0TjNF05MQG`15C4`0=CTj030b<@0f>CD0?44j05MSD`1GIE@0EV=A0080DEa;00`0
B5A303U3=P0/=2T0;34V02/^900Y:B40:2DQ03ln>@2HZHh0VZbC08nOR`2>X8/208bORP0;08fNRP1[
MVP07AXO028S8P0L71/071`H01TJ4`0I6Q405aD?01lN5`12B3P00P29WW`02`1dQVh0LhAb07:2MP1c
Q7L0LXEb07:9K`1bRF`0MH]/05e[E@10ASX0?dHi0080>3ha00H0<cT/030e:P0a=bX0=C`/03Lo:`0e
?2XJoooooal0oh00E@000?lC0?n000P0003o2@3oP00:0000o`/0oh003oooool000gooooo00D0@diP
04MAIP19E6`0BeA`04]FM00304UFL`0;04aIM01<FGD0CEUf04aIMP1=FgH0Ceaf051LM`1BG7T0Deij
05AQNP1DHW/00P1EHW/02`1DH7X0EF=l05ETO`1GIX40FFN205]WPP1MJH<0GV^4061]QP1RKXP0IG2:
0080JGJ=00`0KW^B06mmT`1^OI<0KG^C06ejT@1^Ni<0K7VB06]hT`1ZMY80JgN@06eiT@1^NY4206ei
T@0606ijTP1`Ni<0LGfD075nU@1bOYL0LgjH0P1dOiT00`1ePIT0MX:J07N4VP0207N4V@0307R6V`1j
RIl0NXVQ0080NHVO00H0NXZM07b:W01lRi/0O8ZL082<WP23Sj0208B?XP80Q96U00D0Pi6T08FCY@26
U:D0QiBT08NEY@0208VGYP0@08^IY`2<VJL0RiVX08^IZ02=VJT0SiZ[092KZ`2CWJd0UIn]09FQ[@2D
XZ/0Tj:[09:QZ@2EY:/0UjJ/09VV[@80VZN/0P2LZ:/02@2NZ:X0WjVX09fZYP2LZZH0VZZU09ZYYP2I
Z:<0VZVS09ZZX@0209RXW@0;09JWV@2DYiH0FVEQ04I=C00`<SH0;c8b03]1?010B440FFEF05UVEP1G
I5@00P1AG4d0301?Fd/0ADm302da;00`<bh0;2dX02LT8@0S71h0>3@c09f]T@2R]9T0TZ6<092PS080
Sij:00/0SYn:06ahJ@0M72008b<S01dN6P0M7QL06AXA01LG3`0F50l08b8J04aB@@0208nUP00;07>7
KP1`QG40Kh=h06YoM`1gTX40FG1O05mfH@1[PFT0F6EF03m8@00nAC/00P0g?S<01P0b>Bd0<3L/030e
:`0d>Rd0=cd]03<k:A[ooooo803oP01D0000oa<0oh0020000?l90?n000X0003o2`3oP00?ooooo`00
3Oooool01P12CV<0AE1W04IBK01:E700BUAc04QBL`80Ae9c00D0B5=c04QDL`1;EW@0CEUd04iJM@02
04mJM@0404mJM`1AG7T0Demk05=PN`80E61j00/0Demi05EQN`1FHWh0EfF005UVP01KIh40FfJ005aX
P@1NJX<0H6b4069_Q@0206AbQ`0<06MeR@1YMh/0JWV>06]jT@1[NI80K7RE06YeU01YMI@0JgJE06]f
TP1[MY00K7N?0P1]N900201_NI80LGZC075kT`1cOID0LgnD079nUP1bP9P0Lh2G0P1ePIL03P1fPIP0
MX6I07J1V@1fPYX0N8BL07R5V`1iQYX0NXNK07^7V`1lR9/0OHZK07f:W01nRil0PHfQ0P21SZ402`22
Sj<0Pi2S08>@X`23T:40Q9:R08FCX`26Tj<0RIJV08ZGY`2:UZP0RYNX0080RiRY00/0S9VY08fIZ@2?
VZX0Tif[09FNZP2DX:T0TinX09BQZ`2EXJh0Uj>_09NT[P0309VU[P0;09ZU[02KYZ`0WJN[09fWZ02L
YjD0VjRT09^XY@2JYZ@0VjNS09^YX@2JZ9h00P2HYi`02`2FYYT0TZBD05AMF`0j?T40;S0d02d`<00i
?cP0?THl05aZF01JIUH0F69C0080DU]?00`0CeM<04mGB`0o@c`0=SLd02/X:00V82808aXO03Lb<`2P
/9@0Y;FJ09>SS@2@X8d208jNR@0;08fOQ`1WLfD061LL020Q8@0L7Q/06A/E01PI400G60l05QH?01hP
5`14CSd00P1nUG802`1ZP6@0JX1W0767LP1HJ600LHQh06UnK00oBd@0JgiZ05=PE00mA3h0?4<j0080
=Cdb00H0<ST_03<j;P0c>Bd0=CX]03Hl;@0d>RPJooooob80oh00DP000?lC0?n000L0003o2P3oP005
0000o`050?n000000?l0003o0?n000000?l02`3oP00?ooooo`003Oooool01P10C6D0@TmX04EAK@18
Dg00BU=c04YCM080BE=d00/0B5Ac04QDL@1:E6l0BeI^04eIL01?Fg00CUU`051KM01@FgL0DEai059N
NP0205=ONP0;05AONP1FHW`0Ef=m05QTO`1IIH00FVB105]VP`1MJ8<0GVV3065]Q@1RKX@00P1RKhD0
301TLXP0IWB906IdR`1WMXh0J7B@06QdT@1YMI80JWFC06afU01]Mi<0JgJB06]gT@80KWRA00/0KWR@
071jT@1aNi80LWfD079mT`1bOY@0LWjE07=oU@1fPYL0Mh>G07V2U`0207^4V`0407V3W@1gPY/0Mh:J
07Z5VP80O8NJ00D0O8JJ07n9W01oRYd0OhZN086;X002082;X080PXjQ00T0Pi2Q08B@X024TZ00Q9:P
08FBX@28U:<0RYJU08VFY`29UZP00P2;V:X01@2;VJX0S9ZZ092KZ`2AW:/0TibZ0080TifY00D0UZ2[
09NQ[@2HXZd0VJ>]09ZT[@0209bU[@0;09^T[02KYZX0VjJY09ZVY`2JZ:D0VjRT09ZWY02IYJ80VZNQ
09ZVW`2IYI`00P2HYY/02`2FYYT0TJ6C059HF00`<ST0=3Li02lb<@0a=2d0@DPj05i[E01IHdl0DUU:
0080BTe400`0BTa405AHCP19BT@0?chm03Hc=@0d;S40<2T]04<o?`2FY8d0WjjF09FUT02@X8h208bM
RP0;08ZNR01WMFL06QXP024S900I6QX06AXD01PG3`0H5`h05aP>02<W6P0`>B/00P16Dd002`1LKUH0
IWaP05U/E01HJU<0HgIN096[R01FI5D0Df1D051ODP0/<Rh0=S/c0080=S``00H0=CX_03Dk<00g?C00
>3d_03Ll;`0c>B/Jooooob<0oh000`000?l20?n004`0003o4`3oP0080000o`/0oh001P000?l=0?n0
00oooooo000=ooooo`06045;I013CFP0B59]04YDL01:E7<0BU=c0P1:E7802`1;EW80BeE`04]EK`1;
EVl0C5Q^04mJK`1?FW00DEad051LM@1@FgH0Ce]g0080D5]f00/0DUeg05=NN@1FHGX0Ef9m05USP@1J
Hh<0G6J505iXQ@1NJX@0H6b5069^QP02069^Q`0<06=`R@1SLHX0I76<06EcSP1VLXl0IgFA06QeT@1Y
MI80JWJB06agT`1[Mi<0K7ZC0P1[N9402`1ZMi00KGVA06iiTP1`O9<0Kg^C071mU@1bOYL0LGjE07Ao
U`1fP9P0N8:H0080Nh>J00/0Nh>L07R2W@1hPi/0NHFI07^5V@1lQYT0OHJJ07n8W01oRYh0P8^N08:;
W`0208:<W`0;08B>XP23Sj<0QI6S08BAX024Tih0QIBP08BCW`25Tih0QiFQ08NEY029UjL00P2:UjP0
302:UjX0S9R[08nJ[@2AVjd0TYb]09:M[02CWjd0U9n]09NP[@2GXJ/0VJ:[09^T[080VjBZ00/0W:FY
09ZUY`2JYJL0VZJW09^XYP2JZ:H0VjRV09ZWY@2JYZ<0VZNR09VWX00209NVW@0;09FUVP2FYiT0G69R
034a=P0f>SL0<S@`034a:@10A3H0GFI>05INBP15B3h00P0i>3L03018B4L0GF5K065VGP1<CD`0AdQ8
04E4@P15@d00CDe:08RDP02HYY00UZFA092PSP80R9Z800/0R9^806alKP0K6b00824Q01dM6@0L7AD0
61H=01LE2`0E50X08bLH02he9@0203@m;@0;03m<>@1?GdL0:S@W02ll;00V<2D0Q:1k07:9JP0U:b@0
AE9201TK6@0X:b<00P0]<BL01P0`=2X0=3P^03Ll;`0h?Rh0=cl^038i:A[ooooo9@3oP0000`000?l0
oh000000o`1<0000oa<0oh0020000?l@0?n00080003o303oP00?ooooo`003Oooool01P11BV40@deW
04I?K018DFh0B55`04QBL080BE9`00/0BE9^04QBK`1:E740C5Eb04]EL@1<Eg00CEQ`04mJL`1?FWD0
D5]h04mJN002051KN00;055LN01BGGL0E61i05IQN`1HHgh0FF>105YTQ01KIXD0GFR305iYPP1PK8@0
0P1PK8D0301QKXL0Hg2:06=_SP1TLY00I76A06EbTP1VLY40IW:B06MdT`1YM9@0JWFD06]gU080JgNC
00/0JgJB06ahT`1]NI@0KWZF06ejUP1^NiL0KgfH079oV01dOiP0M7jH07AoV@0207N2VP0:07N0V@1f
OiT0MX6I07N3V01iQ9P0NXJH07^6VP1mQY/0OXRL07n:W@<0PX^M00@0PXbN08>=X023SZ40PY2O0P23
TYd01@24Tid0Q9>O08BCXP25U:<0QiJV0080R9JW00`0RYNY08bGZ`2>VJ`0SYV]08nJ[@2AW:d0TYj]
09>O[P2DX:d0UJ2[09NRZP2IY:X209ZUZ@0;09^UZ02JY:H0VjJW09ZVYP2JYZD0VZRV09VXY`2HYZH0
V:FU09NTX`2FY:800P2FYIl02`2EY9X0V:RI06I_JP0d<cT0?D0m03Tk=P0e=Bl0?Clf05MOC01GGTh0
C5560080>chi00`0F65F065/HP22Th40H6UP05UOF014AD@0Bd]804]:B@1nQgT0TIn<096PS`2@X8l2
08RGQ`0;08JGQ01aP7007QlT024R8P0M71T071`E01PH3`0D4`/04a8;01lR5P0]=BD00P0h@c402`0a
?2`082LL01/R600J8AH03a@<061fE@1UNeP05AXB02hg:P0D5Q807b4I00809bXQ00H0;C4W03@g;00h
?2h0=C//03@j:`0_=RLJooooobX0oh0000<0003o0?n000000?l0A`000?l=0?n000030000o`3oP000
oh0000<0oh0020000?l@0?n00080003o303oP00?ooooo`003Oooool01P11BUl0@daU04E>JP17D6d0
B59_04QAL080BE=b00/0BE9`04QAKP1;E780C5Ac04aEL`1;EG@0C5Ic04iHM@1>FGD0D5Ug04mIM`02
051JN00;055KN@1BG7T0DUeg05ANN@1FHG/0Ef9m05USP`1JI8D0FVB305aWPP1NJH<00P1PJhD0301Q
KHH0HVj806=_R`1SKhd0Hfn@06=^T01SKY40I72C06EbU@1VLYD0J7>E06McU080JGBE00/0JgJE06ai
U01/NID0KGVE06ijT`1_NiD0L7bG079mU`1dOYH0M7jH07EnVP0207EoVP0407N2V`1fPI/0MH6I07N3
V`80Mh>I00D0N8BK07^6W01lQih0OHVO07n9W`02086:W@0;08>=W`21S9h0PHfO08:@X022T9h0PI2M
08:AW023TZ00Q9:R08JEYP26U:P00P28UJT03029U:X0RiJ[08ZFZP2;Uj`0SIV]08nK[02AW:/0TYj/
09:NZ`2CWjX0U:6X09JSZ080Uj>V00/0V::U09ZTY`2IY:H0VZFV09VUYP2JZ:P0VJNY09NUY`2EXjD0
UJ>S09BSX@0209FTX00;09BTV`2HZIX0JgA_03Lg?P10@T40>S`i038d<@15BT00DUU<05EMC`1?FD`0
0P10Acl0301CGU40HfmQ08BFP021T7`0O8Ee03hk?P18ADL0?CQ007MoMP2BWhl0RiR909BST@80SIb:
00/0RIR507V7M`0P7bH07QdQ01`K6P0H61<05AD>01@E3@0F5`l09BXL02H/7P0202@[7P0;028X700I
7aH05Q`D01HL4@0B5``0:cHS03Q5;`0B6100728J01@H4`0C5Q000P0U:al01P0_=RL0<c/Z03Ln;00f
?R/0<cXY02hc91[ooooo<03oP0150000o``0oh000`000?l30?n000P0003o7P3oP00?ooooo`003Ooo
ool01P11BUl0@daU04E>JP17D6d0B59_04QAL080BE=b00/0BE9`04QAKP1;E780C5Ac04aEL`1;EG@0
C5Ic04iHM@1>FGD0D5Ug04mIM`02051JN00;055KN@1BG7T0DUeg05ANN@1FHG/0Ef9m05USP`1JI8D0
FVB305aWPP1NJH<00P1PJhD0301QKHH0HVj806=_R`1SKhd0Hfn@06=^T01SKY40I72C06EbU@1VLYD0
J7>E06McU080JGBE00/0JgJE06aiU01/NID0KGVE06ijT`1_NiD0L7bG079mU`1dOYH0M7jH07EnVP02
07EoVP0407N2V`1fPI/0MH6I07N3V`80Mh>I00D0N8BK07^6W01lQih0OHVO07n9W`02086:W@0;08>=
W`21S9h0PHfO08:@X022T9h0PI2M08:AW023TZ00Q9:R08JEYP26U:P00P28UJT03029U:X0RiJ[08ZF
ZP2;Uj`0SIV]08nK[02AW:/0TYj/09:NZ`2CWjX0U:6X09JSZ080Uj>V00/0V::U09ZTY`2IY:H0VZFV
09VUYP2JZ:P0VJNY09NUY`2EXjD0UJ>S09BSX@0209FTX00;09BTV`2HZIX0JgA_03Lg?P10@T40>S`i
038d<@15BT00DUU<05EMC`1?FD`00P10Acl0301CGU40HfmQ08BFP021T7`0O8Ee03hk?P18ADL0?CQ0
07MoMP2BWhl0RiR909BST@80SIb:00/0RIR507V7M`0P7bH07QdQ01`K6P0H61<05AD>01@E3@0F5`l0
9BXL02H/7P0202@[7P0;028X700I7aH05Q`D01HL4@0B5``0:cHS03Q5;`0B6100728J01@H4`0C5Q00
0P0U:al01P0_=RL0<c/Z03Ln;00f?R/0<cXY02hc91[ooooo<03oP0150000o``0oh000`000?l30?n0
00P0003o7P3oP00?ooooo`003Oooool01P11BUd0A4eR04I?J@19DVh0B59_04Q@L080BU=c00H0BeAd
04UAL@1:Dg80Be=c04]BLP1;E7@304eFM@0?04iHMP1>F7L0CeUg04mIM`1@FgL0DUii055MN01CGWX0
EF5m05IQP01HHh<0F6B505YTQ01LIX<0GfV40080H6V400`0H6Z4065/Q`1RKXT0HVf;069]S@1RKhl0
Hfn@069_T01SLI40IG>B06IcTP1VLY8206UdU00;06]fU01ZMI@0JgJD06eiT`1^NY40L7ZB075kU01b
Ni<0LgfC07AnU@1fOYL00P1gOiP0101gPIT0MX6J07B0VP1gPY/207R3VP0507R2V@1iPiX0O8JL07n7
WP21R9l00P23RYl02`25SIl0PXbO086<W`23SZ00Q96Q08FCXP25TZ40QI6R08NBX`28U:D0RIJV0080
RIJW00`0RIJX08^GZP2;UZX0RiN[08jI[@2?Vjd0T9^[096M[02BWZ`0TYjZ09>QZ@2EXJT209NRYP09
09NQY@2HXZL0V:>W09VTY`2HY:H0VJJV09VWZ02GY:H0UZBS0080UZBR0P2FYJ402`2FYId0V:RL07=m
MP0l?D80@DE403Xn?@0c=cD0>Chi04I>@P1CGT`0ADe20080<SHd00`0D5QA06=]H`26UH40SIf709ZZ
T@1;BTX0?CPn03D`>P1]M6l0T:2@08NDQ`2?Whh2092QS@0;08ZLQ`1iRGL07alT01TH6`0G5QH04a8?
014@2P0A4@P051D:020U5`0Q9aP00P0O8aL02`0N8AH06AhC01LL4`0D6Q404QL>018F3`0A5A004aPB
01DI4`0B5Q4041@>008082LJ00H0;CHT034j9`0d?RX0<cdX03<l9P0_=b<Jooooob/0oh0000<0003o
0?n0003oP0000P3oP0150000o``0oh000`000?l30?n000P0003o7P3oP00?ooooo`003Oooool01P10
BE/0@deR04I@J@18DFh0Ae5^04QAK`80BE9b00/0BeAd04YCLP19DW80BeAc04YBLP1;Dg80C5Ed04eF
M@1=EgH0C5Mf04aHM`0204iIM`0;051MN@1CGWX0DUej05=NO01EH7l0F6:305QRQ@1HHh<0FF>105YU
PP1NJ8<00P1PJHD02@1QJHH0H6^806=]RP1RKH/0H6b;061]R`1QKX`0Hg6?06AbT@0206MdTP0>06Mc
TP1ZMI<0JWFC06]eTP1]Mi@0KGNC06miT@1_NY40L7Z@075kT01bO940M7nC07AoU01fOiH307N1V@06
07N2V`1fPIX0MX6H07N3U`1iPiL0NhBH0P1lQ9P02`1nQYX0PHVL08B;WP24Rih0QHbP08><W`23S:00
PXbQ08:<X024Sj40QY6S0080Qi:T0100Qi:S08RDX`28UJ<0R9FS08NEX`29UjL0RYVX08bIZ`2>VJd0
SiZ^08nK[02@WJ`0TYjZ09>NZ@2EWjX0Uj6[0P2FXJP02`2GXZT0Uj6X09NSY`2HY:P0V:FX09VVY`2G
YJD0UZBT09RUY02HXj<0Uj>R0080V:BQ00/0UjBM09RWW01kQWl0>CQ10453A@0m@3l0=cTj03<f=`0m
@Sd0DUe>04]DB00203Pk>00<051FC`1TJf80Q920092PS@2T^9l0HfYS03Tg?@0j>Cl0I6eU096SS`26
UH@0Rib90P2<X8/02P28WHL0Nhil028U:P0C51T061TI01HF4`0D4`h04a8;018C2P0G6@h301XO4P0;
01/P4`0I7A405aXA01@H4@0B61804QHC00lB4`0B5AD051PF01<G500B5Pl00P0O9QP01P0Z<al0;cLU
038l:@0a?BT0<SdW030j8a[ooooo:`3oP0020000o`030?n000000?l0003o04D0003o303oP0030000
o`@0oh001`000?lN0?n000oooooo000=ooooo`0603i8GP10C680@dmX04E?JP17D6`0Ae1_0P18DG02
04QBL@0904UCLP1:E7<0BeAd04YCL`1<EGD0BeAe04aEMP1<EWH0C5Qg0080CUYh00/0CU]i051KN@1A
G7X0DUel05AOOP1GHX40F6>205QTPP1HHh40FFB105aWP`0205mYQ00<05mYQP1PJhT0GfZ9061/R@1P
K8P0H6f;065_S01SLHh0Hg2@06IcTP1XM940IW>B0P1VLY401P1YMI40JWJA06]gS`1]N8l0KgR?071j
TP80LG^C00<0LWfD07=nUP1cOIH00P1eOiX02`1ePI`0MH2K07J1V@1gPiP0Mh>F07N2U@1jQ9D0NhFF
07^5U`1lQYX0OhVL0080P8ZM00/0Ph^O08::W`23SJ40PhjQ08:=W`24SIl0QHnQ08F@XP27TJ@0Qi>T
08VDX`0208VEX`0<08NDXP28UZ@0RYVW08^IZP2<V:`0SYZ^08jJZ`2?Vj/0TYfZ09FNZP2FWj/0Uj2[
0P2EX:T02`2FXjX0UZ>X09NTYP2FXjH0UjFV09RWYP2FYJ@0UZBS09VUX`2HXj40UZ6O0080Uj:M00/0
UZ6J09VVVP1hP7/0>3<o040nA011@T@0@dI503i0?`0k?c`0E5mB059LC`0204U?A`0<04eBBP1RJel0
Pi:008^KR@2HZiD0O8Qj0411A@0l?D<0HfeW09Z_V@27VXP0RIf;0P28WH/02`2:WX/0PIB302P/<`0D
5Ad06A`N01TJ6@0F5a804a<=014A2`0D5Ph061`B008061dB00/06alC01hR5@0M7aH071dG01/M6P0J
7Ah06Q/Q01TI8@0H6Ql05ALH010D3P02020X6@0602/d800a>BD0<c`Y03<m:P0b?2X0<SXW6_ooool`
0?n004D0003o303oP0040000o`<0oh001`000?lN0?n000oooooo000=ooooo`0603i8G`10C6D0@TiX
04A?J014CVT0ADm/0P16Cfh02`16DFl0Ae5`04UAL@18DG00BE9b04YCL`1:DW<0Be=d04eGM`1=F7L0
CEUg0080CUYh00P0CEUh04iIN@1@FWT0DUam05=MP01FGh40F6:205MSPP80Ef>100l0FVJ305aWQ01L
Ih@0GFV505m[R@1OJX/0GfZ:05iZR@1PKHX0HFj:065^R`1RKH`0Hfn>06EaSP1ULI000P1TL9002@1Y
M980JGFA06YfS`1/MXh0KWN?06mjTP1_NYD0KWVF06ijU@02079nV080M7nK00T0MH2M07F1V`1eP9T0
MX6G07N3U`1hPYL0NH>H07Z3V01kQI/00P1lR9h207f9W`80Oh^P00T0PHfP086<WP20S9h0PHbN08><
WP25Sj00QHnQ08JAX`27TZ<00P25TZ803025Tj<0QYFU08RFY@29V:H0RiVY08nJZ`2AVj`0TIZ[09>L
[02EWJd0Uin]09NOZP80UJ2X00X0UJ:X09BRYP2CXZ<0Tj>R09BTXP2FY:<0UJBS09FTXP2GYJ<0UjBR
0`2FXZ002`2EXI`0VJNL06ecL00e;SX0?CQ00450A@1:CTd0@DI403Tm>P1AG4l0D5Y>0080DEU>00`0
Bdm805aSFP24TX00RYV508^KQ029V880ADE7030]>01TKV/0V[2M08JIRP2;WH`208JGQ`0;08ZKR020
TGl092@/01XI800M7Qh06ATG01DE4P0B4Ph04a8=01PJ4P0L7Q@00P0L7AD02`0[<B80:2dO020S5`0W
9b009bDU0495A00b=3T09bL]02HX:@0H6AT04a@?008092XJ00H0:S8N02hf8`0b>RD0<c/W03<m:00`
>B@Joooooc40oh00A0000?l<0?n000@0003o0`3oP0070000oah0oh003oooool000gooooo00H0@4UQ
045;I@12CFT0@di/04=>JP14CV/204A=J`0504A=K017D6h0Ae1_04I?KP17Cfh00P19DG40101:Dg80
Be=b04aEM01<EWD204eGM@0;04iHM`1?F7P0D5Uh055JN`1AFWd0E5f005MPP@1FHX40F6=o05MSOP1I
IH000P1JIH002`1KIX80G6J605iXR01OJXT0GfV905m[R@1QK8T0HVj:06=_R`1TKh`0I72>00<0I6n>
00/0Ig6?06QbSP1ZM8l0K7F?06efS`1_NI40KWZC06mkU01_O9D0LGfE079lUP0207AnV@0;07AnV`1d
OY`0M7nK07AoV01gPIL0NH:I07Z3V@1iPiT0NX>K07^6WP1lQil00P1lRJ402`1nRZ80Oh^R07n<X01o
Rih0OhfN082<WP22S9h0Q8jO08F?X@26T:80QY6R0080QI:Q00`0QY>S08NEY@27UJD0R9JV08ZFYP2=
V:X0T9V/096JZP2BVjX0U9b[09FMZ`2FWZP209FNY`0309FPZ02CXJD0Tj6S0080U:>S00H0UJ>R09BS
XP2CXZ40UJ:R09FRX@2GXZ8209JRX@0;09BPW@2HYYd0LWUf02dV=014@DL0A4=904A7B`0j?T80=c`l
04aGC@1=FDd00P1@FU003013Ad@0JgEX092QR`1hQ7D0QiJ108>BO@11@D<0:B@b069YI`2H[9X0RY^;
08fNS080RIN500H0S9^708fNQP0Y9b/07Q/L01`K5`0G5Q4201@D3P0301DE3P0K7A<07b8H00806ATD
00/0@4Tg03Y2=00^<RX0F65B03`o?@1IHU/0?T9502TZ;`0Y:bX051@D01TL500202P]7@0602T_700[
<Ql0;cHT038i9P0c?2L0;STU6_oooolb0?n004<0003o2`3oP0050000o`<0oh001`000?lN0?n000oo
oooo000=ooooo`060458G`10B680@T]X049;J`12C6/0@D][0P12C6/204A=K080ADi^00L0Adm^04I?
KP18D6h0BE9]04UBK`1:Dg40C5Ac0080C5Ab00/0CEEd04iFM`1@F7L0CeYg051KN01CGG/0E5mm05EQ
O@1EHG/0Ef9j05QSO00205UTO@0<05UTP01KIX<0GVV5061YQ@1QJHL0H6Z7069/R01RK8T0HVf9065]
R`1SKhh0I72>0P1ULXl02`1WLXl0J7>?06YdS`1ZM8h0JgF>06egSP1^N8l0KWV@071jTP1`O9@0L7bF
0080LGbG00/0LWfH079lV01cOIX0M82I07IoV@1hPIP0NH:G07R2U`1iPYP0NH>I07^6V`0207f9WP0;
07j:W`1nRZ00OX^N07f:W@1oS9d0P8fN086=W`22SZ40PhjP08F@X026TZ000P27TZ80302:UJ@0RYFU
08VCY02:U:D0RiFV08jGZP2?UZX0T9VY09>LZ@2CW:P0U9fX09JOZ080UZ2W00@0UZ6W09FRY@2FXjD0
UZ>T0P2FXZ<01@2EXZ<0UJ6S09FQX`2EXJ<0UZ6R0080UJ6O00/0UJ6K09JTW01oR8@0:bPe06M_J@1<
CU40BTe>03i2A@0`<cP0CeQB04mHD@0204mGDP0<03e1@P1VLVH0W[JI079oL@25UH40MX=d03/k@@0a
;c/0Ff5R086AQP26UXP0SYj;0P29Uh802`27UWl0SIj302l^;00O71X07adF01/K400H6@h05aP=01LI
3P0K7A406alD00805ATB00/08RLO04eHA`1JIUH0KWeZ06A]H`1^NFd0G6EM04Q>B00f?3L06a`L024S
7@0202HZ7`0602T_800]<R<0;c@U03<i9`0e?BT0<3TV6_oooolb0?n004<0003o303oP0040000o`<0
oh001`000?l>0?n000030000o`3oP000003o00d0oh003oooool000gooooo00H0@DQN049;H`13C6L0
@T]Y049:J`12BV`204A=K`0604A=KP14C6d0ADi^04I?K017Cf`0B55]0P17D6/00`19DVd0BE9_04aE
L`0204eFM@0;04eFMP1>EWP0D5Qk04mIN@1@G7T0DUej05EPO@1EGg/0EEmj05QRN`1HHg/00P1IHgd0
101KI800FfF105eUPP1OIh<2065XQ@06069ZQ01QJX@0HF^5069/Q`1TKXX0I6n<0P1ULHd02`1ULXd0
IW><06QdS01YMH`0JGF906afR`1^N8d0KgV@071iTP1aNi@0LG^F00<0L7bG00X0LGbH079lV@1dOiX0
MH2I07J1V01eP9H0NH:G07^2V01kPiT0O8FJ0P1mR9`207n:W@0907j:W01nRYd0Oh^N086<WP22SJ00
PhnR08B?X025T:00Qi:R0080RI>S00`0RIBR08RCX@29U:80RIBR08bFYP2>UZT0SYJZ092JZP2BW:P0
TYbV09BMYP2FX:L209JQYP0409FQY@2FXJH0UZ:U09JRY@80V:>V00D0Uj>V09NRY@2GXZ<0UZ:R09JR
X@0209FQW@0;09BPV@2FY9T0QY6902l/>01@E5@0CE5@04mED@0n@d80;Bld051ID`1>EU800P1>EU00
3015BdP0D5UC09B/T@24V880RIj607R8N01FGE`0@45;05mVJ`1VKW40QIB:08nPSP80RY^400/0QYAk
07j>LP0Z:RD06aPE01hL5@0I6@l061T>01PJ3P0H6`d06Qd?01`O4P0201`O5@0;018B3@1:DT40NhYa
06mjJ@1cOg00MX=e071oK`1XMfH0@4Lo02@V900Z;BH00P0[;b<01P0[<B80;C<S02ld900`=RH0=3XX
034g9a[ooooo<`3oP0120000o``0oh0010000?l40?n000H0003o3@3oP0060000o`/0oh003oooool0
00gooooo00H0@dUR04A:IP13BVT0@TYZ0499JP13BF/204=9K@0504A;K014BV/0A4]Z04E>JP17CfX0
0P16CFT01018D6X0BE9/04YCKP1<Dg0204eDM00;04aDM01;E7D0CeMi051IN`1@Fgd0DE]l05=MO@1D
GWd0E5il05IQO@1HHW`00P1JHg`0301LHgh0GFB005iTP@1NI840H6R2065ZQ01QJX<0H6Z1069[PP1T
KHD0IVj706I`R@80I72;00/0IG:<06EbRP1VLhX0IgF806QdQP1ZMHL0JgF906efS01_N8h0KgZ@071j
T@02075kTP0;071lU01bO9D0LgbG07AnV01eOiL0M7nE07AoU01gPI@0NX:F07b3V01lQ9T00P1mQIT0
2`1mQYT0OXRK07n:W01nQi`0P8ZO08::X022Rj00Q8bP08B>W`27Sil0Qi2O0080Qi:P00`0R9:P08RB
X@28Tj<0RYBU08^EYP2<UJL0SYJX08nIZ@2AVJP0Ti^U09JNY02EWZ8209FOX@0809FNX@2DWZ80UJ6U
09FQY@2GXjH0V::U09NRY@2EXJ@209JSXP0>09FRX02CX9d0Tj2M09>PVP2BXIL0S9^>03Xi@012A4H0
Ff=L04UAC00j?c`09RTZ04eGC@1=EDd204iFCP0<04aBB@1OJE/0TJJ;07J6MP1oT7l0PY>307^9O01L
H640C4]E06mdM@1lQ800SI^=0P2:VXH02`26UGh0OHid02PY9P0L6aT071`G01LI400G6@h05a/?01DJ
300H6``09RXG0080:R`N00/05a@@03m1=`1oSgD0KGMY079nL01dPg@0L85`06UjIP0lAC`071lL02/`
9`0202`b9`0602`c9@0/=2@0;CDU02hg9`0`>2T0;cLY6_oooolc0?n000030000o`3oP000003o03l0
003o303oP0050000o`80oh001`000?l=0?n000H0003o2`3oP00?ooooo`003Oooool01P13AUl0ADQU
04E9J@14BFX0ADY/04E9K080A4Q[00/0A4U[04A:J@14BVP0ADaX04E<J@16CFX0ADe[04I>K@19DVh0
BeA_04aCKP0204aCK`0;04aEL01;E740C5=c04mFM`1@FW/0DE]l05=LO@1DGWh0EV1m05IQO01GHW/0
0P1IHWX0301KHW/0GF=m05mTO`1MHh00GVF1069ZQ01RJh@0HF^306=/Q01TKHH0IFj806M_R@80Ig2:
00/0J72;06QbS01XLh/0JWB906YeQ`1[MHL0JgB906aeR`1_N8`0KgV=06igS00206mhSP0;071jT01a
Ni40LW^B07EnU@1fOYH0MgnF07MoU@1hPI@0Nh>E07b4U01kPiD00`1mQIL0201nQYT0OhNK0828WP21
RJ40P8RQ086:XP22Rj00PhfN0P26Sih208R@W`0<08VAX02:TZ<0Ri>U08fEZ02>UJT0SIBZ08jFZ@2@
V:T0TIVW09BKYP2FWJ@0UYjR0P2FWj802P2EWj40U9jQ09BOX`2FXJD0UJ2W09FOY@2EX:D0U:2V09FR
YP2EXZ@309BQX@0;096OW@2?WIL0TJ6E04I8B`10A4D0Lh5b04]BC@0l@Ch09bT[04]EB`1<ET`00P1=
Ed`03017CD@0D5E:07j=MP1gQG80NhQf08NFP`23TH00NH5e03hi@@1TIVH0MWeh08^GRP80R9J600/0
QIF107^=M`0`=2l06ATH01hO6P0G6A<051H?01DI3`0C5`d04AD:03M3:@0204eI?@0;01HD401>E4L0
NXQc06ahJ`1aOW40Lh9d0763L`1YNfP0@Te102de;@0a>bl00P0^=R/01P0/<bL0;3DV02`f9@0^>BL0
;STX02dg9a[ooooo<`3oP0120000o`80oh0000<0003o0?n0003oP0001`3oP0060000o`80oh001P00
0?l=0?n000H0003o2`3oP00?ooooo`003Oooool01P13AV00A4QU04E9I`15BFL0ATUX04I8J@80AdYY
00/0ATYY04E:J015BVT0AD]Z04E;J`14C6/0ADe/04I=KP19D740BE5`04YBK`0204YCKP0;04]EKP1<
EVh0CEI`04iGM01@FGP0DEYj05=KO@1EGgl0EF1m05AON`1FH7/00P1IHG/01P1HGgT0FV5j05eSO01N
HWl0GfB1061UP`80H6N500@0HFV406A/QP1TJhL0IFb70P1VKXP0101WKX/0J6n;06Q`R@1YLXT206Ub
R00506YcR@1[M8X0K7J906iiS01^NH/00P1]MhX02`1_NH/0LG^=079kSP1dO8l0MWfA07MoTP1gOY80
NH6C07Z2TP1kQI<0NXBB0080NhBE00/0NhBG07f5V@1oQi`0P8NP0868XP21R:<0PHVQ086:X021RYd0
PhbM08J?W@0208R@W@0<08N@W`28TJ40RI6R08bDY02>UjL0SiNY08nFZ02@UZL0TIRV09:IYP2DVj@0
UIfT0P2EWZD02`2DWZ<0TifQ09>MX@2EX:@0UInV09BOY@2DX:L0U:6X09>PZ02BX:H0TYnR0080TYnO
00/0SifK08jKU`2BXYT0H6MW02`Y=P1WLFP0De]D0416@@0];bl0CUQ<04eGB`0204UAA`0<03`o>P11
A3d0Ff=D07F2J`24U7T0RY^208JEO`23Sgd0>SLn05]MGP1hP7X0QI660P24TH@02`24UH@0MhQf034e
=00K6a`07b0M01XK5`0E5a804QD=014D300>40/0=D0/0080BePo00/04Q0;04E:?01ePV`0KGQ[06ml
L01bPG@0LX=c0722K`16DDL0;SD^038j;00202de9@0302`b8`0^=2@0;C@S00<0;SLT6_oooolg0?n0
03h0003o3@3oP0050000o`80oh001P000?l=0?n000H0003o2`3oP00?ooooo`003Oooool01P11AEl0
@TIR04A7I016B6H0ATQX04I8JP80ATUZ0P15BFT01014BVT0@d]Y04=;J013BfT204A<JP0304I>K019
DFl0BU9a0080BU9a00/0BUA`04aFL01<EW00CEIa04mGM01@EgD0DEUi05=LO@1DGGd0E5ik05EON`02
05UQO00<05UPNP1JHWT0G69j05eQO01OHgl0GfB105mUPP1PIh<0Hf^206=[P@1UJX<0If^60P1XJhL0
0`1WK8X0Iff906M^R00206M`R@0606UbRP1ZLhX0JG:;06QaRP1ZM8/0JGB80P1ZM8H02`1]MhL0KGN6
06ihQ`1bNh/0MGf=07IoS`1hP940NH6A07V2T01iQ980N8>B0080NH>C00/0NhFE07j6U`1oQiX0OhJM
07n6WP1oQil0PH^Q086;W`22Rih0Q8fN08F>W@0308N@W@0;08RAW`28TJ00RY>Q08fEX`2?Uj@0T9JT
09:GYP2BVJH0TYVU09:JX`2DWJ@00P2CWj<01`2AWZ40TIjP096NW`2CWj40UJ2R09FOXP2FXJD00P2C
X:<03`2CWj<0TinQ09:NWP2BWYh0TIfL096NV@2CXYX0KgMf02TU<`15BDP0@TQ303Lk=`0h>cH0CEE9
04aDA`0204eFB@0<0498?`0h?3H0?d<k06E`G028V7h0TZ>;08VFP`25T880@3a606edL01iPg`0QY:8
0P25TXD02`25U8D0NHMg02`];`0L71h07alN01TJ5P0D5Q004A@;010B2@0?3PT0?TDd0080EV=;00/0
4@l?030b;P1bPFd0JgUZ06ekKP1`PG80LH=b0722K`1GIUD0<SP^02T]8@0202/`7`0602`b7`0]<b00
;S@Q02de8P0/=B<0;3@R6_ooooli0?n000030000o`3oP000003o03X0003o3@3oP0040000o`030?n0
00000?l0003o00D0003o3@3oP0060000o`/0oh003oooool000gooooo00H0?TEL0416GP15BF80AdQV
04M8J016AfP204A6J00;04A7J014B6P0@TQU049:I012BfD0@daU04A>IP14CFH0@daV04I?J@17Cf`0
0P18D6l02@18D6h0Be=`04aDL01<EW40CUMc04mHM@1@FWP0DUak05ALO00205ANO080Ef1m00`0FF9l
05YRN`1LHg/0GFAl05eTO@1NIGl0H6N1065WP@1RJh40HFUn069YO`1WK88206Q[P`0;06Q[Q@1XKHP0
IVf806I^R@1VKhX0IG2906MbRP1WLHX0IVj706M_Q@1VKX<00P1TK8402`1UKH40Ifn206E^P@1WLH80
JgB406eeQP1_N8P0LG^8075lQ`1dP8X0Mh>>0080NHFA00T0NhND07f8UP1oRIT0OhRI07n9VP1oRYX0
PHbJ08:=V@23SIX00P25SYd208F?W00<08NAW@2:TZ00Ri:Q08bCX`2<TjD0SYBV092FY@2@Uj@0TYVU
09>JY@2CVj@0TYbQ0P2@WIl02`2@WZ00TIjO092NW`2CX9l0UJ6O09FPX02EXJ80U:2R09BPX`2CWj40
TinO0080TIjM00/0SifJ08jLU`2AXIP0KGId02`X=P0e=3L0;Bd^02<R901<E4D0DE]904mGAP0204iF
A00<03m5=P0i?S80=CL`05MND@2S^IX0TZ:>08^IR028U8@0AdA908><P025Sh@0RYF80P28U8H02`24
TX00OXag034b;`0G5QL07QlK01XJ5@0F5`h051@:018B2@0>30D0@TXf0080FFE>00/05Q8C03Hj=`1W
MVT0I7=X06MhK01ZOFh0K81^06QlI`1EIE40;SDY024V6@0202T_7P80;34O00@0:c<P02df8P0/=B<0
:S<R6_oooom10?n003D0003o3@3oP0040000o`030?n000000?l0003o00D0003o3@3oP0060000o`/0
oh003oooool000gooooo00H0?DAM03m6H013B6D0ADQW04E7J015AVP304=6I`040498IP12BFD0@TUT
04=:I080A4eU00@0A4eV04E=I`16CfT0BE5]0P1:DFl02@1;D700C59b04iEM01=EG@0CEEe04iHN01@
FGX0D5Uk059JO00205AMO080EEel00`0F61n05UQO@1JHW`0FV=k05aVO01MIGd0GfIo061WP@1QIh40
HFR006=ZPP1UKH<206E/Q00;06I/Q01WKXL0Iff:06M^S01UKhd0IG2<06MaR`1XLXT0IW2706M`QP1V
KX@00P1UKH402`1VK840IVb3069ZPP1RJh40I6b106=]O`1SJgh0IFio06IaO`1XM800K7R30080Kg^8
00/0Lh2=07F2T@1iQY<0NXRD07b9U@1mRYD0OhbE07n=T`20SI@0PhnI08B>VP0208B>V00<08NAW@29
TZ00RY6P08Z@X02;TJ@0SI:V08fBY02?U:@0TYNT09BJY02CVZD0TY^R0P2AW9l02`2AW9h0TIfN09:N
W`2DXJ00UJ6P09BOX02DWj80TijS09:NY@2AWZ80T9fN0080T9jN00/0SijL08ZJUP2>X9H0LWmh02l]
=P0d<S<0;B/[01lL701GGdd0FVE@051IA@0204aD@@0<034c:@0b=2X0>Sdb0495>`2J[Xh0UjZB092O
S`2<VXX0DE9A08bGQP2CWY00SIR<0P2:V8P02`24UH40PYEj03m6>@0E51807b0I01dM5@0M71<06AT?
01LF3@0A3PP0?D8b0080HFeF00/081dO04aCC@1VM6/0HG1[05maJP1OLFH0HGAS065dG`0d?S@0:S8X
02L_8P0202P_7`0602Xa800/<R40;C@Q02`d8P0[<b80:C8R6_oooom70?n002l0003o3@3oP0040000
o`030?n000000?l0003o00D0003o3@3oP0000`000?l0oh000000o`030000o`/0oh003oooool000go
oooo00H0?DAM03m6H013B6D0ADQW04E7J015AVP304=6I`040498IP12BFD0@TUT04=:I080A4eU00@0
A4eV04E=I`16CfT0BE5]0P1:DFl02@1;D700C59b04iEM01=EG@0CEEe04iHN01@FGX0D5Uk059JO002
05AMO080EEel00`0F61n05UQO@1JHW`0FV=k05aVO01MIGd0GfIo061WP@1QIh40HFR006=ZPP1UKH<2
06E/Q00;06I/Q01WKXL0Iff:06M^S01UKhd0IG2<06MaR`1XLXT0IW2706M`QP1VKX@00P1UKH402`1V
K840IVb3069ZPP1RJh40I6b106=]O`1SJgh0IFio06IaO`1XM800K7R30080Kg^800/0Lh2=07F2T@1i
QY<0NXRD07b9U@1mRYD0OhbE07n=T`20SI@0PhnI08B>VP0208B>V00<08NAW@29TZ00RY6P08Z@X02;
TJ@0SI:V08fBY02?U:@0TYNT09BJY02CVZD0TY^R0P2AW9l02`2AW9h0TIfN09:NW`2DXJ00UJ6P09BO
X02DWj80TijS09:NY@2AWZ80T9fN0080T9jN00/0SijL08ZJUP2>X9H0LWmh02l]=P0d<S<0;B/[01lL
701GGdd0FVE@051IA@0204aD@@0<034c:@0b=2X0>Sdb0495>`2J[Xh0UjZB092OS`2<VXX0DE9A08bG
QP2CWY00SIR<0P2:V8P02`24UH40PYEj03m6>@0E51807b0I01dM5@0M71<06AT?01LF3@0A3PP0?D8b
0080HFeF00/081dO04aCC@1VM6/0HG1[05maJP1OLFH0HGAS065dG`0d?S@0:S8X02L_8P0202P_7`06
02Xa800/<R40;C@Q02`d8P0[<b80:C8R6_oooom70?n002l0003o3@3oP0040000o`030?n000000?l0
003o00D0003o3@3oP0000`000?l0oh000000o`030000o`/0oh003oooool000gooooo00H0?T=M0416
HP12BFH0@dUW04A8J014AfP204=6I`0:04=7I`12AfH0@dMV04A8IP14BFH0A4]W04A<I`15CFP0ATe[
04I>K@<0B51^00X0BU1_04YAL@1<Dg<0CE=c04iCM@1AEgT0DUQi05=JNP1DFg/0EUek0`1GGW`0301H
Ggh0Eemm05MPO01IHW/0FfAk05aTO01NIGh0GfIo061VP@1PIX80HVR306A[Q080I6b500L0I6b606I]
Q`1XKXX0Iff<06I]S@1WKhd0JG2=00<0JW:<00h0K7:;06abR@1/LXT0K7:906aaRP1ZL8X0Ig2906I]
Q`1TK8D0HfZ106A/P@1UKH80HV^006=[P080Hfb000/0IVn106QaPP1/MH@0KgR5075kQP1dOhT0MH:;
07R6S@1kR8h0OhbA086=T`0208B>U00<08NAV@29TId0RY:N08ZAW@2;TYl0S9BS08fDXP2>U:40TINR
096HX@2BVJ00Ti^O0P2AVY/02`2AVi`0TY^L09:LW@2DWIl0UYfQ09FLX@2DWJ80U9jR09:NX@2AWj40
T9nO0080T9jM00/0SifJ08bKUP2=WiD0OHb203m2A00g=c@0;bdX02DQ7P1LHTl0Ff=@04mEA@0204YB
@@0<03Pn<@0e>bd0?D@e03Li<@1kRG80VjjC092PT02<Vhh0JG5^082<PP1nRH@0PHj80P2<WY002`24
UhD0PIAl03e3=`0F514081lI01dL5`0N71L06aXD01PF400F4`l0@THh0080K7YR00/0AD]4061[GP1T
LFD0Hg5W04=<B`0c>C/0BUQ<06MkH@0a>Rl09blT02Xc9@0202T`8@0602T`7P0Z<R00:c<S02`c8P0/
<b40:C0O6_oooolj0?n000D0003o3@3oP00Z0000o`d0oh0010000?l00`3oP000003o0000o`050000
o`T0oh000P000?l70?n000030000o`3oP000oh0000T0oh003oooool000gooooo00H0>d5J03i5G`10
Af40?dEQ0455H`13AVD20455I00;0457I@12AVD0A4MV04E7I`16B6P0ADUX04E;J@14BVT0A4Y[04E<
KP16CFd00P15CF/02`16CV/0Adi]04U?KP1<D700CU9c04mCM01@E7D0DUMh05=IN@1DFWT0EE]i0080
EUei00`0Eeii05UONP1IH7/0FV5k05]RNP1LHg/0GVAm05iSOP1PI840HfJ406=VP`1SIH<206AWQ00;
06AXQ@1VJXL0J6b906Y]R`1YK8/0J6j<06Q`S01YL8`0JW6;06Y`RP1]LX/00P1_MHd02`1`MXd0LGJ=
071gSP1_MXh0KWJ?06efSP1/MH/0Jg>906]cR01ZL8L0Jg660080JFn200/0Ifio06M^O@1XKGd0JVmo
06Y_P01[L840JW2106YbP01/MX00KWV107EnQP0207V2R@0<07n7S@23RY80QHbD08N?U@28T9T0S9>M
08fDW@2=U9`0SiNN092HWP2AVIh0TIZK0P2AVYP02`2BVi/0TY^L09>KWP2EW9h0UifP09JMX@2DW:00
TifN09:NW@2CX9h0TYnM0080TYjM00/0T9bI08jLU@2AWi@0OXUo04M7BP0i=cP0;2DU04E2>@1oR6h0
EeY>055FB`0204iEB00<04A;?@0oAcL0@4Dh0454>`1bO6P0UZF<09:QS`2:Uh/0Phj708:?R01NIV/0
KWag0P2=XXl02`1oTWl0P9=k03e2>@0K5aH08B0L01`J600I61D061HC01DC400H5Q@0Addo0080JGQR
00/0H6eL06IeH`1VM6<0JGUW03Lk?00J6RD0:2ha05EWE@0b?C409blU02Xc9`0202Xa900602Ta8P0Y
<R80:c@T02/c8@0Z<Ql0:S4M6_oooolc0?n000030000o`3oP000oh0000@0oh0030000?l00`3oP000
003o0?n000060?n000030000o`3oP000oh0002@0003o103oP0000`000?l0oh000?n000060?n000H0
003o00<0oh000000o`000?l00`000?l90?n00080003o00@0oh000000o`000?l0003o3`3oP00?oooo
o`003Oooool01@0l@EX0?D=M0416H010AEl0@DIP00<0@TMQ00/0@4IR0416H`11AfD0A4MX04E8J@13
AVT0@dQ[04A;K015CFh0ATi_04A<KP0204A<K00;04E=J`16CF/0BU1^04aAL01=DW40CE9b04eBL`1?
E7H0DEIf059HM`1DFWP00P1GGGP0101GGWL0F5ig05UNN01JH7X205aSO00605eROP1MHH00H6>3065T
Q@1SIXD0I6N50P1TJ8<00`1SIh<0IVV606MZQP0206U/QP0606U]Q`1YKhP0J72906M`R@1XL8T0JW6:
0P1[LX/02`1]M8`0L7N<075hS01bN8l0LGR@06mhS`1`NHl0LW^?07AmS`1eOHh0Mgj?0080Mgj>00/0
M7b:079jQP1aN8@0LWN6075dQ`1^LHL0JVj406Q]PP1WKX00IVim06Y`O`0206ecP@0;06meP`1bMhD0
MWZ807UnS01lPhl0P8RB08>;T`26SY<0RI>G08^FV02>VIX00`2@Vi/02`2CW9d0TIZK09>KW02EWI`0
UYjK09JNW02CWI`0TYfK09:LV`2AWI/0TYbK0080TibK00/0TY^K096KU`2AWI<0QY660490AP0g=3T0
;BP]06AZF`2T]Y80C4e204]?A00204]@A@0<04E<?`11B3T0?T4d0451=P1ZL5h0TIf509FRS`2=V8/0
RYF;07b5PP1GFV80IW5`0P29W8`02`1mSgl0OI1n03m6@`0E4aP07alP01XJ6P0G5aH05aHD01HD4`0F
4a@0BE120080KWiW00/0I75P06QgI@1[NFL0L7i/0498A@0H5b<0>D9202`d<`0X<B/0:34W02Pa9P02
02Ta9P0602Pa9@0Y<b@0;CDS02`e8@0Z<Al0:BlM6_oooolk0?n001H0003o103oP00Q0000o`@0oh00
00<0003o0?n0003oP0001`3oP0050000o`80oh0010000?l90?n00080003o00@0oh000000o`000?l0
003o3`3oP00?ooooo`003Oooool01P0m@EX0@4=N0496H@12AV40@DIP0497G`80@TMP00X0@TMQ04=7
HP13AVD0@dIV04A6I`13AfP0@TMY04=7JP14Bf`0ATi]0`15C6/02`16C6d0Ade^04Y@L01:DG40C59b
04iBLP1@E7@0DEIe059GM@1CEg@0EEYe0080EUag00`0EE]g05EKM@1GGGH0FV1i05]QN@1MHg/0GF9l
05iQO`1PHX<0H6:2069TP`1UJ8D206EXPP0;06EXO`1XJX40J6Z306Y/Q01[KHD0Jfn806Y^Q`1YKXH0
J6j706U`Q`1ZL8L00P1/LHT02`1^M8`0KgF<071eR`1bMhd0LgV?07=hSP1dNY00MG^A07IkTP1hOi80
NH2B0080N7n@00/0Mgj?07V0S`1kPhl0OH:?07aoS`1kOY40N7b?07EjSP1cMhX0LGJ8071dQ`0206ib
Q`0<06icQ`1]LHH0KW66071cQP1cMXL0MWZ:07IlR@1iOhT0O8>:07n7S023S900R92C0P2:TY@02`2:
Ti<0SIJE092HU`2CViT0UIbJ09JNV`2DW9T0U9jI09BMV@2CWIX0TYbJ0080TIZI00/0TIZK09:KV@2B
WY@0QY6504A1AP0b;S@0<Rla07N3J`23TG<0D5A504Q=@@0204Y?A00<04=8?@0g>Rl0=CHZ03Db9`1I
FDP0Uj:708fDQP2>UHd0S9B=07b1O`1bMg@0I6UZ0P29VH/02`1nSh40O8mo03m6A00F51/07alQ01/K
6`0J6QT06ATF01DC4@0D4Q40D5Y70080KgiR00/0GFMD05URD`1LIUH0K7QU04eEB`0I61d0BE=901hQ
8P0Q9R<09RhU02L`9@0202P`8`0602P`8@0X<1l0;3@P02dd800/<Al0:RhM6_oooolc0?n000@0003o
103oP00k0000o`<0oh000P000?l90?n000H0003o00<0oh000000o`000?l00P000?l90?n00080003o
0`3oP0000`000?l0oh000?n0000=0?n000oooooo000=ooooo`0603m2E`10@eT0@DAM0494H012AF00
A4MO0`13AUh02P13Af00@TER0494H`11AV<0@DMR0498H`13BFD0A4UV04E;J017BfP204M=J`0;04U>
KP1:CW00BTma04Y?LP1<D780CE5a04mCL01@EFl0DUI`05=GL01DFW400P1FG780301EFg<0EU]c05IL
M01HGWH0FV1g05aPN@1MHGX0GV9l05mROP1QHWl0HV:106EVP`80IFR200/0IfYo06U]P01WJgl0J6b1
06U/P`1[KH@0JVf406]^Q@1[KhH0Jfj506a_Q@0206iaQ`0;06mcRP1_M8X0KgB:075fR`1aMh`0LgN<
07IjSP1gNY00Mg^A07QmT01jP9000P1jP8h02`1iOhh0NX2>07^2SP1mPhd0OH:?07j3T@1nQ9<0OhJE
07n4U01oPiD0OhFF0080OX>E00`0Nh6D07QnT@1gO8l0MgZ;07QkRP1fNXT0MWZ807EiQ@1gNhD0N7b3
07anQ@1nPHL207j3R0070826R@24Rhd0QXf?08R?T02>UID0T9NE09:IUP0209BLU`0?09BMV@2BW9/0
TIZJ096JVP2@V9L0TIVF09:LT`2:ThH0@Si302lX;P1?DDP0JG5N055CA`1>CTH0BDY30080Bdm500`0
B4e103/n<@0h>R/0?Sd]059A@02HXH<0T9J609ZQUP2CVI80QHV307EgM01/KVX208nMR`0;086@O`1l
SGX0=c`j01LF600P81d071`I01XK5`0I6aD04a@@01HG4`1EHTX00P1MJU002`0g>bh0<cH]04eC@`1U
L5T0CeI5020O700d>2h07AhK024W800S:R409RhR00809blR00<09blQ02P_7`0[<B000P0]<b400`0[
<1koooooooooo`0HooooocD0oh00@@000?l>0?n000/0003o7P3oP00?ooooo`003Oooool01@0o@5@0
?d5F0413FP12AEd0A4IN00<0@dEL00L0@dIL0455G@12AEl0@TEQ0458HP0oAV00@TQQ0080A4YR00D0
AD]T04I:I@16BVL0ATYW04Q=J`0204Y?KP0804Y>KP1;Cfl0C55`04eBK@1>E6h0D5E_055GK`1CFVh2
05ELK@0<05ELK`1FG740Eeac05MLM01HGWH0F5ig05aPN@1MH7P0Gf9k065SOP1SHgl0IFF10P1TIX00
2`1UIgh0If]n06I[O01VJgd0I6Um06IZOP1YJh40JVf306Y^Q01YK8<0K6n30080KW2600/0Kg68071d
RP1_LhP0KgB:075eRP1cNHX0M7R;07IiSP1gNhl0N7b>07Z0S`0207^1S`0;07YoS@1kP8d0O82=07b1
SP1mPY00OXBB07f4T`1mQI<0OhJE0827UP23RiX00P24S9X03024RiX0Ph^I08B;V023QiH0PHFC07j3
T01kP8`0NGf807UmQP1iO8@0Ngf307]mPP80O7j300/0OH6607n4R020QHP0PHN908F;S028SH`0Ri2?
08jDT`2@V9H0TiZH09>MVP0209:LV@0;08nHU02>V980SiV>08bGQP11?T40:1dT06]`GP1eOVP0FeiA
04Y8A01:BTD00P1=DTP0301:DD@0A4Tk0414=012AC80C4dk08jHN@2CW8H0[;ZU09fWV@2:THD0Oh=i
06]]I@80RYN100/0Pi5k07V9L`0h?CP0518D01hN6@0J6QD05aXD01DI4`0B5Q005a`C03M2;P02049=
=`0;02ld9@0Z;240BU4n06MfF@1AG4D071dH02<V7@0R9ah08bTP02DZ800V;B000P0W;R401P0W;B80
:C0R02`b8`0^=280;38P02X_7A[ooooo=P3oP0030000o`030?n000000?l0003o03X0003o0P3oP002
0000o`X0oh002`000?l>0?n000030000o`3oP000oh0000d0oh003oooool00?ooooooTOooool00?oo
ooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oo
ooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {299, 0}} -> {-0.0508884, -0.0375078, \
0.00526762, 0.00526762}, {{9.625, 190.438}, {291.875, 156.25}} -> {-12.9439, \
-9.62807, 0.929149, 0.929149}, {{208.5, 389.312}, {291.875, 156.25}} -> \
{-197.728, -9.62807, 0.929149, 0.929149}, {{9.625, 190.438}, {142.688, \
7.0625}} -> {-12.9439, -148.245, 0.929149, 0.929149}, {{208.5, 389.312}, \
{142.688, 7.0625}} -> {-197.728, -148.245, 0.929149, 0.929149}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 574}},
WindowSize->{779, 556},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 59, 0, 62, "Title"],
Cell[1816, 53, 204, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[2045, 62, 36, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2106, 66, 58, 0, 49, "Subsection"],
Cell[2167, 68, 123, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2327, 75, 38, 0, 49, "Subsection"],
Cell[2368, 77, 295, 6, 111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2700, 88, 42, 0, 49, "Subsection"],
Cell[2745, 90, 829, 16, 191, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3611, 111, 37, 0, 33, "Subsection"],
Cell[3651, 113, 535, 9, 159, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4223, 127, 55, 0, 33, "Subsection"],
Cell[4281, 129, 752, 13, 175, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5070, 147, 41, 0, 33, "Subsection"],
Cell[5114, 149, 170, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5321, 157, 41, 0, 33, "Subsection"],
Cell[5365, 159, 193, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5595, 167, 41, 0, 33, "Subsection"],
Cell[5639, 169, 664, 11, 175, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6340, 185, 41, 0, 33, "Subsection"],
Cell[6384, 187, 1101, 18, 223, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7522, 210, 53, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[7600, 214, 36, 0, 43, "Subsubsection"],
Cell[7639, 216, 168, 4, 63, "Input"],
Cell[7810, 222, 174, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8021, 230, 53, 0, 43, "Subsubsection"],
Cell[8077, 232, 207, 4, 63, "Input"],
Cell[8287, 238, 84, 1, 47, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8420, 245, 40, 0, 49, "Subsection"],
Cell[8463, 247, 67, 1, 47, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8579, 254, 35, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[8639, 258, 38, 0, 49, "Subsection"],
Cell[8680, 260, 143, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8860, 268, 42, 0, 49, "Subsection"],
Cell[8905, 270, 204, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9146, 279, 35, 0, 49, "Subsection"],
Cell[9184, 281, 147, 3, 47, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9380, 290, 57, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[9462, 294, 54, 0, 49, "Subsection"],
Cell[9519, 296, 333, 7, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9889, 308, 51, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[9965, 312, 115, 2, 47, "Input"],
Cell[10083, 316, 837506, 11449, 308, 470656, 6917, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[847638, 11771, 105, 3, 33, "Subsection"],
Cell[847746, 11776, 435, 7, 143, "Input"],
Cell[848184, 11785, 421, 9, 79, "Input"],
Cell[848608, 11796, 410, 7, 95, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[849055, 11808, 47, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[849127, 11812, 115, 2, 47, "Input"],
Cell[849245, 11816, 87195, 2279, 256, 20925, 1458, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[936489, 14101, 54, 0, 33, "Subsection"],
Cell[936546, 14103, 394, 9, 79, "Input"],
Cell[936943, 14114, 394, 9, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[937374, 14128, 49, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[937448, 14132, 117, 2, 47, "Input"],
Cell[937568, 14136, 604307, 8570, 308, 470656, 6917, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1541912, 22711, 117, 2, 47, "Input"],
Cell[1542032, 22715, 614266, 8693, 308, 470656, 6917, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2156359, 31415, 57, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[2156441, 31419, 51, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2156517, 31423, 115, 2, 47, "Input"],
Cell[2156635, 31427, 837506, 11449, 308, 470656, 6917, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2994190, 42882, 82, 1, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2994297, 42887, 33, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2994355, 42891, 395, 8, 79, "Input"],
Cell[2994753, 42901, 384822, 19640, 296, 363204, 19368, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3379624, 62547, 33, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3379682, 62551, 395, 8, 79, "Input"],
Cell[3380080, 62561, 387390, 19673, 296, 363075, 19368, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3767519, 82240, 33, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3767577, 82244, 395, 8, 79, "Input"],
Cell[3767975, 82254, 388159, 19683, 296, 363027, 19368, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4156195, 101944, 117, 3, 49, "Subsection"],
Cell[4156315, 101949, 831, 19, 143, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4157183, 101973, 54, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[4157262, 101977, 131, 2, 47, "Input"],
Cell[4157396, 101981, 292331, 6294, 333, 224954, 5459, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4449764, 108280, 131, 2, 47, "Input"],
Cell[4449898, 108284, 301042, 6496, 333, 227149, 5581, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4750977, 114785, 131, 2, 47, "Input"],
Cell[4751111, 114789, 303951, 6556, 333, 227705, 5612, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5055111, 121351, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[5055179, 121355, 33, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[5055237, 121359, 329, 6, 79, "Input"],
Cell[5055569, 121367, 410563, 21025, 199, 382836, 20680, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5466181, 142398, 33, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[5466239, 142402, 329, 6, 79, "Input"],
Cell[5466571, 142410, 415310, 21143, 199, 383877, 20752, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5881930, 163559, 33, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[5881988, 163563, 329, 6, 79, "Input"],
Cell[5882320, 163571, 415822, 21155, 199, 383895, 20758, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6298203, 184733, 44, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[6298272, 184737, 411, 7, 95, "Input"],
Cell[6298686, 184746, 23032, 583, 186, 3954, 343, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6321767, 185335, 54, 0, 49, "Subsection"],
Cell[6321824, 185337, 263, 5, 79, "Input"],
Cell[6322090, 185344, 263, 5, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6322390, 185354, 49, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[6322464, 185358, 120, 2, 47, "Input"],
Cell[6322587, 185362, 603368, 8559, 308, 470656, 6917, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6925992, 193926, 120, 2, 47, "Input"],
Cell[6926115, 193930, 611605, 8660, 308, 470656, 6917, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

